#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 8710
#define LARGE_STATE_COUNT 2665
#define SYMBOL_COUNT 558
#define ALIAS_COUNT 5
#define TOKEN_COUNT 239
#define EXTERNAL_TOKEN_COUNT 2
#define FIELD_COUNT 50
#define MAX_ALIAS_SEQUENCE_LENGTH 9
#define PRODUCTION_ID_COUNT 227

enum ts_symbol_identifiers {
  sym_identifier = 1,
  aux_sym_preproc_include_token1 = 2,
  aux_sym_preproc_include_token2 = 3,
  aux_sym_preproc_def_token1 = 4,
  anon_sym_LPAREN = 5,
  anon_sym_DOT_DOT_DOT = 6,
  anon_sym_COMMA = 7,
  anon_sym_RPAREN = 8,
  aux_sym_preproc_if_token1 = 9,
  anon_sym_LF = 10,
  aux_sym_preproc_if_token2 = 11,
  aux_sym_preproc_ifdef_token1 = 12,
  aux_sym_preproc_ifdef_token2 = 13,
  aux_sym_preproc_else_token1 = 14,
  aux_sym_preproc_elif_token1 = 15,
  aux_sym_preproc_elifdef_token1 = 16,
  aux_sym_preproc_elifdef_token2 = 17,
  sym_preproc_arg = 18,
  sym_preproc_directive = 19,
  anon_sym_LPAREN2 = 20,
  anon_sym_defined = 21,
  anon_sym_BANG = 22,
  anon_sym_TILDE = 23,
  anon_sym_DASH = 24,
  anon_sym_PLUS = 25,
  anon_sym_STAR = 26,
  anon_sym_SLASH = 27,
  anon_sym_PERCENT = 28,
  anon_sym_PIPE_PIPE = 29,
  anon_sym_AMP_AMP = 30,
  anon_sym_PIPE = 31,
  anon_sym_CARET = 32,
  anon_sym_AMP = 33,
  anon_sym_EQ_EQ = 34,
  anon_sym_BANG_EQ = 35,
  anon_sym_GT = 36,
  anon_sym_GT_EQ = 37,
  anon_sym_LT_EQ = 38,
  anon_sym_LT = 39,
  anon_sym_LT_LT = 40,
  anon_sym_GT_GT = 41,
  anon_sym_COLON = 42,
  anon_sym_SEMI = 43,
  anon_sym___extension__ = 44,
  anon_sym_typedef = 45,
  anon_sym_in = 46,
  anon_sym_out = 47,
  anon_sym_inout = 48,
  anon_sym_extern = 49,
  anon_sym___attribute__ = 50,
  anon_sym_COLON_COLON = 51,
  anon_sym_LBRACK_LBRACK = 52,
  anon_sym_RBRACK_RBRACK = 53,
  anon_sym___declspec = 54,
  anon_sym___based = 55,
  anon_sym___cdecl = 56,
  anon_sym___clrcall = 57,
  anon_sym___stdcall = 58,
  anon_sym___fastcall = 59,
  anon_sym___thiscall = 60,
  anon_sym___vectorcall = 61,
  sym_ms_restrict_modifier = 62,
  sym_ms_unsigned_ptr_modifier = 63,
  sym_ms_signed_ptr_modifier = 64,
  anon_sym__unaligned = 65,
  anon_sym___unaligned = 66,
  anon_sym_LBRACE = 67,
  anon_sym_RBRACE = 68,
  anon_sym_signed = 69,
  anon_sym_unsigned = 70,
  anon_sym_long = 71,
  anon_sym_short = 72,
  anon_sym_LBRACK = 73,
  anon_sym_static = 74,
  anon_sym_RBRACK = 75,
  anon_sym_EQ = 76,
  anon_sym_register = 77,
  anon_sym_inline = 78,
  anon_sym___inline = 79,
  anon_sym___inline__ = 80,
  anon_sym___forceinline = 81,
  anon_sym_thread_local = 82,
  anon_sym___thread = 83,
  anon_sym_const = 84,
  anon_sym_constexpr = 85,
  anon_sym_volatile = 86,
  anon_sym_restrict = 87,
  anon_sym___restrict__ = 88,
  anon_sym__Atomic = 89,
  anon_sym__Noreturn = 90,
  anon_sym_noreturn = 91,
  anon_sym_mutable = 92,
  anon_sym_constinit = 93,
  anon_sym_consteval = 94,
  anon_sym_alignas = 95,
  anon_sym__Alignas = 96,
  sym_primitive_type = 97,
  anon_sym_enum = 98,
  anon_sym_class = 99,
  anon_sym_struct = 100,
  anon_sym_union = 101,
  anon_sym_if = 102,
  anon_sym_else = 103,
  anon_sym_switch = 104,
  anon_sym_case = 105,
  anon_sym_default = 106,
  anon_sym_while = 107,
  anon_sym_do = 108,
  anon_sym_for = 109,
  anon_sym_return = 110,
  anon_sym_break = 111,
  anon_sym_continue = 112,
  anon_sym_goto = 113,
  anon_sym___try = 114,
  anon_sym___except = 115,
  anon_sym___finally = 116,
  anon_sym___leave = 117,
  anon_sym_QMARK = 118,
  anon_sym_STAR_EQ = 119,
  anon_sym_SLASH_EQ = 120,
  anon_sym_PERCENT_EQ = 121,
  anon_sym_PLUS_EQ = 122,
  anon_sym_DASH_EQ = 123,
  anon_sym_LT_LT_EQ = 124,
  anon_sym_GT_GT_EQ = 125,
  anon_sym_AMP_EQ = 126,
  anon_sym_CARET_EQ = 127,
  anon_sym_PIPE_EQ = 128,
  anon_sym_and_eq = 129,
  anon_sym_or_eq = 130,
  anon_sym_xor_eq = 131,
  anon_sym_not = 132,
  anon_sym_compl = 133,
  anon_sym_LT_EQ_GT = 134,
  anon_sym_or = 135,
  anon_sym_and = 136,
  anon_sym_bitor = 137,
  anon_sym_xor = 138,
  anon_sym_bitand = 139,
  anon_sym_not_eq = 140,
  anon_sym_DASH_DASH = 141,
  anon_sym_PLUS_PLUS = 142,
  anon_sym_sizeof = 143,
  anon_sym___alignof__ = 144,
  anon_sym___alignof = 145,
  anon_sym__alignof = 146,
  anon_sym_alignof = 147,
  anon_sym__Alignof = 148,
  anon_sym_offsetof = 149,
  anon_sym__Generic = 150,
  anon_sym_asm = 151,
  anon_sym___asm__ = 152,
  anon_sym_DOT = 153,
  anon_sym_DOT_STAR = 154,
  anon_sym_DASH_GT = 155,
  sym_number_literal = 156,
  anon_sym_L_SQUOTE = 157,
  anon_sym_u_SQUOTE = 158,
  anon_sym_U_SQUOTE = 159,
  anon_sym_u8_SQUOTE = 160,
  anon_sym_SQUOTE = 161,
  aux_sym_char_literal_token1 = 162,
  anon_sym_L_DQUOTE = 163,
  anon_sym_u_DQUOTE = 164,
  anon_sym_U_DQUOTE = 165,
  anon_sym_u8_DQUOTE = 166,
  anon_sym_DQUOTE = 167,
  aux_sym_string_literal_token1 = 168,
  sym_escape_sequence = 169,
  sym_system_lib_string = 170,
  sym_true = 171,
  sym_false = 172,
  anon_sym_NULL = 173,
  anon_sym_nullptr = 174,
  sym_comment = 175,
  sym_auto = 176,
  anon_sym_decltype = 177,
  anon_sym_final = 178,
  anon_sym_override = 179,
  sym_virtual = 180,
  anon_sym_explicit = 181,
  anon_sym_typename = 182,
  anon_sym_template = 183,
  anon_sym_GT2 = 184,
  anon_sym_operator = 185,
  anon_sym_try = 186,
  anon_sym_delete = 187,
  anon_sym_0 = 188,
  anon_sym_friend = 189,
  anon_sym_public = 190,
  anon_sym_private = 191,
  anon_sym_protected = 192,
  anon_sym_noexcept = 193,
  anon_sym_throw = 194,
  anon_sym_namespace = 195,
  anon_sym_using = 196,
  anon_sym_static_assert = 197,
  anon_sym_concept = 198,
  anon_sym_co_return = 199,
  anon_sym_co_yield = 200,
  anon_sym_catch = 201,
  anon_sym_R_DQUOTE = 202,
  anon_sym_LR_DQUOTE = 203,
  anon_sym_uR_DQUOTE = 204,
  anon_sym_UR_DQUOTE = 205,
  anon_sym_u8R_DQUOTE = 206,
  anon_sym_co_await = 207,
  anon_sym_new = 208,
  anon_sym_requires = 209,
  anon_sym_DASH_GT_STAR = 210,
  anon_sym_LPAREN_RPAREN = 211,
  anon_sym_LBRACK_RBRACK = 212,
  anon_sym_DQUOTE_DQUOTE = 213,
  sym_this = 214,
  sym_literal_suffix = 215,
  anon_sym_discard = 216,
  anon_sym_precise = 217,
  anon_sym_shared = 218,
  anon_sym_groupshared = 219,
  anon_sym_uniform = 220,
  anon_sym_row_major = 221,
  anon_sym_column_major = 222,
  anon_sym_globallycoherent = 223,
  anon_sym_centroid = 224,
  anon_sym_noperspective = 225,
  anon_sym_nointerpolation = 226,
  anon_sym_sample = 227,
  anon_sym_linear = 228,
  anon_sym_snorm = 229,
  anon_sym_unorm = 230,
  anon_sym_point = 231,
  anon_sym_line = 232,
  anon_sym_triangleadj = 233,
  anon_sym_lineadj = 234,
  anon_sym_triangle = 235,
  anon_sym_cbuffer = 236,
  sym_raw_string_delimiter = 237,
  sym_raw_string_content = 238,
  sym_translation_unit = 239,
  sym__top_level_item = 240,
  sym__block_item = 241,
  sym_preproc_include = 242,
  sym_preproc_def = 243,
  sym_preproc_function_def = 244,
  sym_preproc_params = 245,
  sym_preproc_call = 246,
  sym_preproc_if = 247,
  sym_preproc_ifdef = 248,
  sym_preproc_else = 249,
  sym_preproc_elif = 250,
  sym_preproc_elifdef = 251,
  sym_preproc_if_in_field_declaration_list = 252,
  sym_preproc_ifdef_in_field_declaration_list = 253,
  sym_preproc_else_in_field_declaration_list = 254,
  sym_preproc_elif_in_field_declaration_list = 255,
  sym_preproc_elifdef_in_field_declaration_list = 256,
  sym_preproc_if_in_enumerator_list = 257,
  sym_preproc_ifdef_in_enumerator_list = 258,
  sym_preproc_else_in_enumerator_list = 259,
  sym_preproc_elif_in_enumerator_list = 260,
  sym_preproc_elifdef_in_enumerator_list = 261,
  sym_preproc_if_in_enumerator_list_no_comma = 262,
  sym_preproc_ifdef_in_enumerator_list_no_comma = 263,
  sym_preproc_else_in_enumerator_list_no_comma = 264,
  sym_preproc_elif_in_enumerator_list_no_comma = 265,
  sym_preproc_elifdef_in_enumerator_list_no_comma = 266,
  sym__preproc_expression = 267,
  sym_preproc_parenthesized_expression = 268,
  sym_preproc_defined = 269,
  sym_preproc_unary_expression = 270,
  sym_preproc_call_expression = 271,
  sym_preproc_argument_list = 272,
  sym_preproc_binary_expression = 273,
  sym_function_definition = 274,
  sym_declaration = 275,
  sym_type_definition = 276,
  sym__type_definition_type = 277,
  sym__type_definition_declarators = 278,
  sym__declaration_modifiers = 279,
  sym__declaration_specifiers = 280,
  sym_linkage_specification = 281,
  sym_attribute_specifier = 282,
  sym_attribute = 283,
  sym_attribute_declaration = 284,
  sym_ms_declspec_modifier = 285,
  sym_ms_based_modifier = 286,
  sym_ms_call_modifier = 287,
  sym_ms_unaligned_ptr_modifier = 288,
  sym_ms_pointer_modifier = 289,
  sym_declaration_list = 290,
  sym__declarator = 291,
  sym__field_declarator = 292,
  sym__type_declarator = 293,
  sym__abstract_declarator = 294,
  sym_parenthesized_declarator = 295,
  sym_parenthesized_field_declarator = 296,
  sym_parenthesized_type_declarator = 297,
  sym_abstract_parenthesized_declarator = 298,
  sym_attributed_declarator = 299,
  sym_attributed_field_declarator = 300,
  sym_attributed_type_declarator = 301,
  sym_pointer_declarator = 302,
  sym_pointer_field_declarator = 303,
  sym_pointer_type_declarator = 304,
  sym_abstract_pointer_declarator = 305,
  sym_function_declarator = 306,
  sym_function_field_declarator = 307,
  sym_function_type_declarator = 308,
  sym_abstract_function_declarator = 309,
  sym_array_declarator = 310,
  sym_array_field_declarator = 311,
  sym_array_type_declarator = 312,
  sym_abstract_array_declarator = 313,
  sym_init_declarator = 314,
  sym_compound_statement = 315,
  sym_storage_class_specifier = 316,
  sym_type_qualifier = 317,
  sym_alignas_qualifier = 318,
  sym_type_specifier = 319,
  sym_sized_type_specifier = 320,
  sym_enum_specifier = 321,
  sym_enumerator_list = 322,
  sym_struct_specifier = 323,
  sym_union_specifier = 324,
  sym_field_declaration_list = 325,
  sym__field_declaration_list_item = 326,
  sym_field_declaration = 327,
  sym_bitfield_clause = 328,
  sym_enumerator = 329,
  sym_parameter_list = 330,
  sym_parameter_declaration = 331,
  sym_attributed_statement = 332,
  sym_statement = 333,
  sym__top_level_statement = 334,
  sym_labeled_statement = 335,
  sym__top_level_expression_statement = 336,
  sym_expression_statement = 337,
  sym_if_statement = 338,
  sym_else_clause = 339,
  sym_switch_statement = 340,
  sym_case_statement = 341,
  sym_while_statement = 342,
  sym_do_statement = 343,
  sym_for_statement = 344,
  sym__for_statement_body = 345,
  sym_return_statement = 346,
  sym_break_statement = 347,
  sym_continue_statement = 348,
  sym_goto_statement = 349,
  sym_seh_try_statement = 350,
  sym_seh_except_clause = 351,
  sym_seh_finally_clause = 352,
  sym_seh_leave_statement = 353,
  sym_expression = 354,
  sym__string = 355,
  sym_comma_expression = 356,
  sym_conditional_expression = 357,
  sym_assignment_expression = 358,
  sym_pointer_expression = 359,
  sym_unary_expression = 360,
  sym_binary_expression = 361,
  sym_update_expression = 362,
  sym_cast_expression = 363,
  sym_type_descriptor = 364,
  sym_sizeof_expression = 365,
  sym_alignof_expression = 366,
  sym_offsetof_expression = 367,
  sym_generic_expression = 368,
  sym_subscript_expression = 369,
  sym_call_expression = 370,
  sym_gnu_asm_expression = 371,
  sym_gnu_asm_qualifier = 372,
  sym_gnu_asm_output_operand_list = 373,
  sym_gnu_asm_output_operand = 374,
  sym_gnu_asm_input_operand_list = 375,
  sym_gnu_asm_input_operand = 376,
  sym_gnu_asm_clobber_list = 377,
  sym_gnu_asm_goto_list = 378,
  sym_argument_list = 379,
  sym_field_expression = 380,
  sym_compound_literal_expression = 381,
  sym_parenthesized_expression = 382,
  sym_initializer_list = 383,
  sym_initializer_pair = 384,
  sym_subscript_designator = 385,
  sym_subscript_range_designator = 386,
  sym_field_designator = 387,
  sym_char_literal = 388,
  sym_concatenated_string = 389,
  sym_string_literal = 390,
  sym_null = 391,
  sym__empty_declaration = 392,
  sym_placeholder_type_specifier = 393,
  sym_decltype_auto = 394,
  sym_decltype = 395,
  sym__class_declaration = 396,
  sym__class_declaration_item = 397,
  sym_class_specifier = 398,
  sym__class_name = 399,
  sym_virtual_specifier = 400,
  sym_explicit_function_specifier = 401,
  sym_base_class_clause = 402,
  sym__enum_base_clause = 403,
  sym_dependent_type = 404,
  sym_template_declaration = 405,
  sym_template_instantiation = 406,
  sym_template_parameter_list = 407,
  sym_type_parameter_declaration = 408,
  sym_variadic_type_parameter_declaration = 409,
  sym_optional_type_parameter_declaration = 410,
  sym_template_template_parameter_declaration = 411,
  sym_optional_parameter_declaration = 412,
  sym_variadic_parameter_declaration = 413,
  sym_variadic_declarator = 414,
  sym_variadic_reference_declarator = 415,
  sym_operator_cast = 416,
  sym_field_initializer_list = 417,
  sym_field_initializer = 418,
  sym_inline_method_definition = 419,
  sym__constructor_specifiers = 420,
  sym_operator_cast_definition = 421,
  sym_operator_cast_declaration = 422,
  sym_constructor_try_statement = 423,
  sym_constructor_or_destructor_definition = 424,
  sym_constructor_or_destructor_declaration = 425,
  sym_default_method_clause = 426,
  sym_delete_method_clause = 427,
  sym_pure_virtual_clause = 428,
  sym_friend_declaration = 429,
  sym_access_specifier = 430,
  sym_reference_declarator = 431,
  sym_reference_field_declarator = 432,
  sym_reference_type_declarator = 433,
  sym_abstract_reference_declarator = 434,
  sym_structured_binding_declarator = 435,
  sym_ref_qualifier = 436,
  sym__function_declarator_seq = 437,
  sym__function_attributes_start = 438,
  sym__function_exception_specification = 439,
  sym__function_attributes_end = 440,
  sym__function_postfix = 441,
  sym_trailing_return_type = 442,
  sym_noexcept = 443,
  sym_throw_specifier = 444,
  sym_template_type = 445,
  sym_template_method = 446,
  sym_template_function = 447,
  sym_template_argument_list = 448,
  sym_namespace_definition = 449,
  sym_namespace_alias_definition = 450,
  sym__namespace_specifier = 451,
  sym_nested_namespace_specifier = 452,
  sym_using_declaration = 453,
  sym_alias_declaration = 454,
  sym_static_assert_declaration = 455,
  sym_concept_definition = 456,
  sym_for_range_loop = 457,
  sym__for_range_loop_body = 458,
  sym_init_statement = 459,
  sym_condition_clause = 460,
  sym_condition_declaration = 461,
  sym_co_return_statement = 462,
  sym_co_yield_statement = 463,
  sym_throw_statement = 464,
  sym_try_statement = 465,
  sym_catch_clause = 466,
  sym_raw_string_literal = 467,
  sym_subscript_argument_list = 468,
  sym_co_await_expression = 469,
  sym_new_expression = 470,
  sym_new_declarator = 471,
  sym_delete_expression = 472,
  sym_type_requirement = 473,
  sym_compound_requirement = 474,
  sym__requirement = 475,
  sym_requirement_seq = 476,
  sym_constraint_conjunction = 477,
  sym_constraint_disjunction = 478,
  sym__requirement_clause_constraint = 479,
  sym_requires_clause = 480,
  sym_requires_parameter_list = 481,
  sym_requires_expression = 482,
  sym_lambda_expression = 483,
  sym_lambda_capture_specifier = 484,
  sym_lambda_default_capture = 485,
  sym__fold_operator = 486,
  sym__binary_fold_operator = 487,
  sym__unary_left_fold = 488,
  sym__unary_right_fold = 489,
  sym__binary_fold = 490,
  sym_fold_expression = 491,
  sym_parameter_pack_expansion = 492,
  sym_type_parameter_pack_expansion = 493,
  sym_destructor_name = 494,
  sym_dependent_identifier = 495,
  sym_dependent_field_identifier = 496,
  sym_dependent_type_identifier = 497,
  sym__scope_resolution = 498,
  sym_qualified_field_identifier = 499,
  sym_qualified_identifier = 500,
  sym_qualified_type_identifier = 501,
  sym_qualified_operator_cast_identifier = 502,
  sym__assignment_expression_lhs = 503,
  sym_operator_name = 504,
  sym_user_defined_literal = 505,
  sym_semantics = 506,
  sym_discard_statement = 507,
  sym_qualifiers = 508,
  sym_cbuffer_specifier = 509,
  sym_hlsl_attribute = 510,
  aux_sym_translation_unit_repeat1 = 511,
  aux_sym_preproc_params_repeat1 = 512,
  aux_sym_preproc_if_repeat1 = 513,
  aux_sym_preproc_if_in_field_declaration_list_repeat1 = 514,
  aux_sym_preproc_if_in_enumerator_list_repeat1 = 515,
  aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1 = 516,
  aux_sym_preproc_argument_list_repeat1 = 517,
  aux_sym_declaration_repeat1 = 518,
  aux_sym_type_definition_repeat1 = 519,
  aux_sym__type_definition_type_repeat1 = 520,
  aux_sym__type_definition_declarators_repeat1 = 521,
  aux_sym__declaration_specifiers_repeat1 = 522,
  aux_sym_attribute_declaration_repeat1 = 523,
  aux_sym_attributed_declarator_repeat1 = 524,
  aux_sym_pointer_declarator_repeat1 = 525,
  aux_sym_array_declarator_repeat1 = 526,
  aux_sym_sized_type_specifier_repeat1 = 527,
  aux_sym_enumerator_list_repeat1 = 528,
  aux_sym_field_declaration_repeat1 = 529,
  aux_sym_parameter_list_repeat1 = 530,
  aux_sym_case_statement_repeat1 = 531,
  aux_sym_generic_expression_repeat1 = 532,
  aux_sym_gnu_asm_expression_repeat1 = 533,
  aux_sym_gnu_asm_output_operand_list_repeat1 = 534,
  aux_sym_gnu_asm_input_operand_list_repeat1 = 535,
  aux_sym_gnu_asm_clobber_list_repeat1 = 536,
  aux_sym_gnu_asm_goto_list_repeat1 = 537,
  aux_sym_argument_list_repeat1 = 538,
  aux_sym_initializer_list_repeat1 = 539,
  aux_sym_initializer_pair_repeat1 = 540,
  aux_sym_char_literal_repeat1 = 541,
  aux_sym_concatenated_string_repeat1 = 542,
  aux_sym_string_literal_repeat1 = 543,
  aux_sym__class_declaration_repeat1 = 544,
  aux_sym_base_class_clause_repeat1 = 545,
  aux_sym_template_parameter_list_repeat1 = 546,
  aux_sym_field_initializer_list_repeat1 = 547,
  aux_sym_operator_cast_definition_repeat1 = 548,
  aux_sym_constructor_try_statement_repeat1 = 549,
  aux_sym_structured_binding_declarator_repeat1 = 550,
  aux_sym__function_postfix_repeat1 = 551,
  aux_sym_throw_specifier_repeat1 = 552,
  aux_sym_template_argument_list_repeat1 = 553,
  aux_sym_subscript_argument_list_repeat1 = 554,
  aux_sym_requirement_seq_repeat1 = 555,
  aux_sym_requires_parameter_list_repeat1 = 556,
  aux_sym_lambda_capture_specifier_repeat1 = 557,
  alias_sym_field_identifier = 558,
  alias_sym_namespace_identifier = 559,
  alias_sym_simple_requirement = 560,
  alias_sym_statement_identifier = 561,
  alias_sym_type_identifier = 562,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [aux_sym_preproc_include_token1] = "#include",
  [aux_sym_preproc_include_token2] = "preproc_include_token2",
  [aux_sym_preproc_def_token1] = "#define",
  [anon_sym_LPAREN] = "(",
  [anon_sym_DOT_DOT_DOT] = "...",
  [anon_sym_COMMA] = ",",
  [anon_sym_RPAREN] = ")",
  [aux_sym_preproc_if_token1] = "#if",
  [anon_sym_LF] = "\n",
  [aux_sym_preproc_if_token2] = "#endif",
  [aux_sym_preproc_ifdef_token1] = "#ifdef",
  [aux_sym_preproc_ifdef_token2] = "#ifndef",
  [aux_sym_preproc_else_token1] = "#else",
  [aux_sym_preproc_elif_token1] = "#elif",
  [aux_sym_preproc_elifdef_token1] = "#elifdef",
  [aux_sym_preproc_elifdef_token2] = "#elifndef",
  [sym_preproc_arg] = "preproc_arg",
  [sym_preproc_directive] = "preproc_directive",
  [anon_sym_LPAREN2] = "(",
  [anon_sym_defined] = "defined",
  [anon_sym_BANG] = "!",
  [anon_sym_TILDE] = "~",
  [anon_sym_DASH] = "-",
  [anon_sym_PLUS] = "+",
  [anon_sym_STAR] = "*",
  [anon_sym_SLASH] = "/",
  [anon_sym_PERCENT] = "%",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE] = "|",
  [anon_sym_CARET] = "^",
  [anon_sym_AMP] = "&",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_GT] = ">",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_LT] = "<",
  [anon_sym_LT_LT] = "<<",
  [anon_sym_GT_GT] = ">>",
  [anon_sym_COLON] = ":",
  [anon_sym_SEMI] = ";",
  [anon_sym___extension__] = "__extension__",
  [anon_sym_typedef] = "typedef",
  [anon_sym_in] = "in",
  [anon_sym_out] = "out",
  [anon_sym_inout] = "inout",
  [anon_sym_extern] = "extern",
  [anon_sym___attribute__] = "__attribute__",
  [anon_sym_COLON_COLON] = "::",
  [anon_sym_LBRACK_LBRACK] = "[[",
  [anon_sym_RBRACK_RBRACK] = "]]",
  [anon_sym___declspec] = "__declspec",
  [anon_sym___based] = "__based",
  [anon_sym___cdecl] = "__cdecl",
  [anon_sym___clrcall] = "__clrcall",
  [anon_sym___stdcall] = "__stdcall",
  [anon_sym___fastcall] = "__fastcall",
  [anon_sym___thiscall] = "__thiscall",
  [anon_sym___vectorcall] = "__vectorcall",
  [sym_ms_restrict_modifier] = "ms_restrict_modifier",
  [sym_ms_unsigned_ptr_modifier] = "ms_unsigned_ptr_modifier",
  [sym_ms_signed_ptr_modifier] = "ms_signed_ptr_modifier",
  [anon_sym__unaligned] = "_unaligned",
  [anon_sym___unaligned] = "__unaligned",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_signed] = "signed",
  [anon_sym_unsigned] = "unsigned",
  [anon_sym_long] = "long",
  [anon_sym_short] = "short",
  [anon_sym_LBRACK] = "[",
  [anon_sym_static] = "static",
  [anon_sym_RBRACK] = "]",
  [anon_sym_EQ] = "=",
  [anon_sym_register] = "register",
  [anon_sym_inline] = "inline",
  [anon_sym___inline] = "__inline",
  [anon_sym___inline__] = "__inline__",
  [anon_sym___forceinline] = "__forceinline",
  [anon_sym_thread_local] = "thread_local",
  [anon_sym___thread] = "__thread",
  [anon_sym_const] = "const",
  [anon_sym_constexpr] = "constexpr",
  [anon_sym_volatile] = "volatile",
  [anon_sym_restrict] = "restrict",
  [anon_sym___restrict__] = "__restrict__",
  [anon_sym__Atomic] = "_Atomic",
  [anon_sym__Noreturn] = "_Noreturn",
  [anon_sym_noreturn] = "noreturn",
  [anon_sym_mutable] = "mutable",
  [anon_sym_constinit] = "constinit",
  [anon_sym_consteval] = "consteval",
  [anon_sym_alignas] = "alignas",
  [anon_sym__Alignas] = "_Alignas",
  [sym_primitive_type] = "primitive_type",
  [anon_sym_enum] = "enum",
  [anon_sym_class] = "class",
  [anon_sym_struct] = "struct",
  [anon_sym_union] = "union",
  [anon_sym_if] = "if",
  [anon_sym_else] = "else",
  [anon_sym_switch] = "switch",
  [anon_sym_case] = "case",
  [anon_sym_default] = "default",
  [anon_sym_while] = "while",
  [anon_sym_do] = "do",
  [anon_sym_for] = "for",
  [anon_sym_return] = "return",
  [anon_sym_break] = "break",
  [anon_sym_continue] = "continue",
  [anon_sym_goto] = "goto",
  [anon_sym___try] = "__try",
  [anon_sym___except] = "__except",
  [anon_sym___finally] = "__finally",
  [anon_sym___leave] = "__leave",
  [anon_sym_QMARK] = "\?",
  [anon_sym_STAR_EQ] = "*=",
  [anon_sym_SLASH_EQ] = "/=",
  [anon_sym_PERCENT_EQ] = "%=",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_LT_LT_EQ] = "<<=",
  [anon_sym_GT_GT_EQ] = ">>=",
  [anon_sym_AMP_EQ] = "&=",
  [anon_sym_CARET_EQ] = "^=",
  [anon_sym_PIPE_EQ] = "|=",
  [anon_sym_and_eq] = "and_eq",
  [anon_sym_or_eq] = "or_eq",
  [anon_sym_xor_eq] = "xor_eq",
  [anon_sym_not] = "not",
  [anon_sym_compl] = "compl",
  [anon_sym_LT_EQ_GT] = "<=>",
  [anon_sym_or] = "or",
  [anon_sym_and] = "and",
  [anon_sym_bitor] = "bitor",
  [anon_sym_xor] = "xor",
  [anon_sym_bitand] = "bitand",
  [anon_sym_not_eq] = "not_eq",
  [anon_sym_DASH_DASH] = "--",
  [anon_sym_PLUS_PLUS] = "++",
  [anon_sym_sizeof] = "sizeof",
  [anon_sym___alignof__] = "__alignof__",
  [anon_sym___alignof] = "__alignof",
  [anon_sym__alignof] = "_alignof",
  [anon_sym_alignof] = "alignof",
  [anon_sym__Alignof] = "_Alignof",
  [anon_sym_offsetof] = "offsetof",
  [anon_sym__Generic] = "_Generic",
  [anon_sym_asm] = "asm",
  [anon_sym___asm__] = "__asm__",
  [anon_sym_DOT] = ".",
  [anon_sym_DOT_STAR] = ".*",
  [anon_sym_DASH_GT] = "->",
  [sym_number_literal] = "number_literal",
  [anon_sym_L_SQUOTE] = "L'",
  [anon_sym_u_SQUOTE] = "u'",
  [anon_sym_U_SQUOTE] = "U'",
  [anon_sym_u8_SQUOTE] = "u8'",
  [anon_sym_SQUOTE] = "'",
  [aux_sym_char_literal_token1] = "character",
  [anon_sym_L_DQUOTE] = "L\"",
  [anon_sym_u_DQUOTE] = "u\"",
  [anon_sym_U_DQUOTE] = "U\"",
  [anon_sym_u8_DQUOTE] = "u8\"",
  [anon_sym_DQUOTE] = "\"",
  [aux_sym_string_literal_token1] = "string_content",
  [sym_escape_sequence] = "escape_sequence",
  [sym_system_lib_string] = "system_lib_string",
  [sym_true] = "true",
  [sym_false] = "false",
  [anon_sym_NULL] = "NULL",
  [anon_sym_nullptr] = "nullptr",
  [sym_comment] = "comment",
  [sym_auto] = "auto",
  [anon_sym_decltype] = "decltype",
  [anon_sym_final] = "final",
  [anon_sym_override] = "override",
  [sym_virtual] = "virtual",
  [anon_sym_explicit] = "explicit",
  [anon_sym_typename] = "typename",
  [anon_sym_template] = "template",
  [anon_sym_GT2] = ">",
  [anon_sym_operator] = "operator",
  [anon_sym_try] = "try",
  [anon_sym_delete] = "delete",
  [anon_sym_0] = "0",
  [anon_sym_friend] = "friend",
  [anon_sym_public] = "public",
  [anon_sym_private] = "private",
  [anon_sym_protected] = "protected",
  [anon_sym_noexcept] = "noexcept",
  [anon_sym_throw] = "throw",
  [anon_sym_namespace] = "namespace",
  [anon_sym_using] = "using",
  [anon_sym_static_assert] = "static_assert",
  [anon_sym_concept] = "concept",
  [anon_sym_co_return] = "co_return",
  [anon_sym_co_yield] = "co_yield",
  [anon_sym_catch] = "catch",
  [anon_sym_R_DQUOTE] = "R\"",
  [anon_sym_LR_DQUOTE] = "LR\"",
  [anon_sym_uR_DQUOTE] = "uR\"",
  [anon_sym_UR_DQUOTE] = "UR\"",
  [anon_sym_u8R_DQUOTE] = "u8R\"",
  [anon_sym_co_await] = "co_await",
  [anon_sym_new] = "new",
  [anon_sym_requires] = "requires",
  [anon_sym_DASH_GT_STAR] = "->*",
  [anon_sym_LPAREN_RPAREN] = "()",
  [anon_sym_LBRACK_RBRACK] = "[]",
  [anon_sym_DQUOTE_DQUOTE] = "\"\"",
  [sym_this] = "this",
  [sym_literal_suffix] = "literal_suffix",
  [anon_sym_discard] = "discard",
  [anon_sym_precise] = "precise",
  [anon_sym_shared] = "shared",
  [anon_sym_groupshared] = "groupshared",
  [anon_sym_uniform] = "uniform",
  [anon_sym_row_major] = "row_major",
  [anon_sym_column_major] = "column_major",
  [anon_sym_globallycoherent] = "globallycoherent",
  [anon_sym_centroid] = "centroid",
  [anon_sym_noperspective] = "noperspective",
  [anon_sym_nointerpolation] = "nointerpolation",
  [anon_sym_sample] = "sample",
  [anon_sym_linear] = "linear",
  [anon_sym_snorm] = "snorm",
  [anon_sym_unorm] = "unorm",
  [anon_sym_point] = "point",
  [anon_sym_line] = "line",
  [anon_sym_triangleadj] = "triangleadj",
  [anon_sym_lineadj] = "lineadj",
  [anon_sym_triangle] = "triangle",
  [anon_sym_cbuffer] = "cbuffer",
  [sym_raw_string_delimiter] = "raw_string_delimiter",
  [sym_raw_string_content] = "raw_string_content",
  [sym_translation_unit] = "translation_unit",
  [sym__top_level_item] = "_top_level_item",
  [sym__block_item] = "_block_item",
  [sym_preproc_include] = "preproc_include",
  [sym_preproc_def] = "preproc_def",
  [sym_preproc_function_def] = "preproc_function_def",
  [sym_preproc_params] = "preproc_params",
  [sym_preproc_call] = "preproc_call",
  [sym_preproc_if] = "preproc_if",
  [sym_preproc_ifdef] = "preproc_ifdef",
  [sym_preproc_else] = "preproc_else",
  [sym_preproc_elif] = "preproc_elif",
  [sym_preproc_elifdef] = "preproc_elifdef",
  [sym_preproc_if_in_field_declaration_list] = "preproc_if",
  [sym_preproc_ifdef_in_field_declaration_list] = "preproc_ifdef",
  [sym_preproc_else_in_field_declaration_list] = "preproc_else",
  [sym_preproc_elif_in_field_declaration_list] = "preproc_elif",
  [sym_preproc_elifdef_in_field_declaration_list] = "preproc_elifdef",
  [sym_preproc_if_in_enumerator_list] = "preproc_if",
  [sym_preproc_ifdef_in_enumerator_list] = "preproc_ifdef",
  [sym_preproc_else_in_enumerator_list] = "preproc_else",
  [sym_preproc_elif_in_enumerator_list] = "preproc_elif",
  [sym_preproc_elifdef_in_enumerator_list] = "preproc_elifdef",
  [sym_preproc_if_in_enumerator_list_no_comma] = "preproc_if",
  [sym_preproc_ifdef_in_enumerator_list_no_comma] = "preproc_ifdef",
  [sym_preproc_else_in_enumerator_list_no_comma] = "preproc_else",
  [sym_preproc_elif_in_enumerator_list_no_comma] = "preproc_elif",
  [sym_preproc_elifdef_in_enumerator_list_no_comma] = "preproc_elifdef",
  [sym__preproc_expression] = "_preproc_expression",
  [sym_preproc_parenthesized_expression] = "parenthesized_expression",
  [sym_preproc_defined] = "preproc_defined",
  [sym_preproc_unary_expression] = "unary_expression",
  [sym_preproc_call_expression] = "call_expression",
  [sym_preproc_argument_list] = "argument_list",
  [sym_preproc_binary_expression] = "binary_expression",
  [sym_function_definition] = "function_definition",
  [sym_declaration] = "declaration",
  [sym_type_definition] = "type_definition",
  [sym__type_definition_type] = "_type_definition_type",
  [sym__type_definition_declarators] = "_type_definition_declarators",
  [sym__declaration_modifiers] = "_declaration_modifiers",
  [sym__declaration_specifiers] = "_declaration_specifiers",
  [sym_linkage_specification] = "linkage_specification",
  [sym_attribute_specifier] = "attribute_specifier",
  [sym_attribute] = "attribute",
  [sym_attribute_declaration] = "attribute_declaration",
  [sym_ms_declspec_modifier] = "ms_declspec_modifier",
  [sym_ms_based_modifier] = "ms_based_modifier",
  [sym_ms_call_modifier] = "ms_call_modifier",
  [sym_ms_unaligned_ptr_modifier] = "ms_unaligned_ptr_modifier",
  [sym_ms_pointer_modifier] = "ms_pointer_modifier",
  [sym_declaration_list] = "declaration_list",
  [sym__declarator] = "_declarator",
  [sym__field_declarator] = "_field_declarator",
  [sym__type_declarator] = "_type_declarator",
  [sym__abstract_declarator] = "_abstract_declarator",
  [sym_parenthesized_declarator] = "parenthesized_declarator",
  [sym_parenthesized_field_declarator] = "parenthesized_declarator",
  [sym_parenthesized_type_declarator] = "parenthesized_declarator",
  [sym_abstract_parenthesized_declarator] = "abstract_parenthesized_declarator",
  [sym_attributed_declarator] = "attributed_declarator",
  [sym_attributed_field_declarator] = "attributed_declarator",
  [sym_attributed_type_declarator] = "attributed_declarator",
  [sym_pointer_declarator] = "pointer_declarator",
  [sym_pointer_field_declarator] = "pointer_declarator",
  [sym_pointer_type_declarator] = "pointer_type_declarator",
  [sym_abstract_pointer_declarator] = "abstract_pointer_declarator",
  [sym_function_declarator] = "function_declarator",
  [sym_function_field_declarator] = "function_declarator",
  [sym_function_type_declarator] = "function_declarator",
  [sym_abstract_function_declarator] = "abstract_function_declarator",
  [sym_array_declarator] = "array_declarator",
  [sym_array_field_declarator] = "array_declarator",
  [sym_array_type_declarator] = "array_declarator",
  [sym_abstract_array_declarator] = "abstract_array_declarator",
  [sym_init_declarator] = "init_declarator",
  [sym_compound_statement] = "compound_statement",
  [sym_storage_class_specifier] = "storage_class_specifier",
  [sym_type_qualifier] = "type_qualifier",
  [sym_alignas_qualifier] = "alignas_qualifier",
  [sym_type_specifier] = "type_specifier",
  [sym_sized_type_specifier] = "sized_type_specifier",
  [sym_enum_specifier] = "enum_specifier",
  [sym_enumerator_list] = "enumerator_list",
  [sym_struct_specifier] = "struct_specifier",
  [sym_union_specifier] = "union_specifier",
  [sym_field_declaration_list] = "field_declaration_list",
  [sym__field_declaration_list_item] = "_field_declaration_list_item",
  [sym_field_declaration] = "field_declaration",
  [sym_bitfield_clause] = "bitfield_clause",
  [sym_enumerator] = "enumerator",
  [sym_parameter_list] = "parameter_list",
  [sym_parameter_declaration] = "parameter_declaration",
  [sym_attributed_statement] = "attributed_statement",
  [sym_statement] = "statement",
  [sym__top_level_statement] = "_top_level_statement",
  [sym_labeled_statement] = "labeled_statement",
  [sym__top_level_expression_statement] = "expression_statement",
  [sym_expression_statement] = "expression_statement",
  [sym_if_statement] = "if_statement",
  [sym_else_clause] = "else_clause",
  [sym_switch_statement] = "switch_statement",
  [sym_case_statement] = "case_statement",
  [sym_while_statement] = "while_statement",
  [sym_do_statement] = "do_statement",
  [sym_for_statement] = "for_statement",
  [sym__for_statement_body] = "_for_statement_body",
  [sym_return_statement] = "return_statement",
  [sym_break_statement] = "break_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_goto_statement] = "goto_statement",
  [sym_seh_try_statement] = "seh_try_statement",
  [sym_seh_except_clause] = "seh_except_clause",
  [sym_seh_finally_clause] = "seh_finally_clause",
  [sym_seh_leave_statement] = "seh_leave_statement",
  [sym_expression] = "expression",
  [sym__string] = "_string",
  [sym_comma_expression] = "comma_expression",
  [sym_conditional_expression] = "conditional_expression",
  [sym_assignment_expression] = "assignment_expression",
  [sym_pointer_expression] = "pointer_expression",
  [sym_unary_expression] = "unary_expression",
  [sym_binary_expression] = "binary_expression",
  [sym_update_expression] = "update_expression",
  [sym_cast_expression] = "cast_expression",
  [sym_type_descriptor] = "type_descriptor",
  [sym_sizeof_expression] = "sizeof_expression",
  [sym_alignof_expression] = "alignof_expression",
  [sym_offsetof_expression] = "offsetof_expression",
  [sym_generic_expression] = "generic_expression",
  [sym_subscript_expression] = "subscript_expression",
  [sym_call_expression] = "call_expression",
  [sym_gnu_asm_expression] = "gnu_asm_expression",
  [sym_gnu_asm_qualifier] = "gnu_asm_qualifier",
  [sym_gnu_asm_output_operand_list] = "gnu_asm_output_operand_list",
  [sym_gnu_asm_output_operand] = "gnu_asm_output_operand",
  [sym_gnu_asm_input_operand_list] = "gnu_asm_input_operand_list",
  [sym_gnu_asm_input_operand] = "gnu_asm_input_operand",
  [sym_gnu_asm_clobber_list] = "gnu_asm_clobber_list",
  [sym_gnu_asm_goto_list] = "gnu_asm_goto_list",
  [sym_argument_list] = "argument_list",
  [sym_field_expression] = "field_expression",
  [sym_compound_literal_expression] = "compound_literal_expression",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym_initializer_list] = "initializer_list",
  [sym_initializer_pair] = "initializer_pair",
  [sym_subscript_designator] = "subscript_designator",
  [sym_subscript_range_designator] = "subscript_range_designator",
  [sym_field_designator] = "field_designator",
  [sym_char_literal] = "char_literal",
  [sym_concatenated_string] = "concatenated_string",
  [sym_string_literal] = "string_literal",
  [sym_null] = "null",
  [sym__empty_declaration] = "_empty_declaration",
  [sym_placeholder_type_specifier] = "placeholder_type_specifier",
  [sym_decltype_auto] = "decltype",
  [sym_decltype] = "decltype",
  [sym__class_declaration] = "_class_declaration",
  [sym__class_declaration_item] = "_class_declaration_item",
  [sym_class_specifier] = "class_specifier",
  [sym__class_name] = "_class_name",
  [sym_virtual_specifier] = "virtual_specifier",
  [sym_explicit_function_specifier] = "explicit_function_specifier",
  [sym_base_class_clause] = "base_class_clause",
  [sym__enum_base_clause] = "_enum_base_clause",
  [sym_dependent_type] = "dependent_type",
  [sym_template_declaration] = "template_declaration",
  [sym_template_instantiation] = "template_instantiation",
  [sym_template_parameter_list] = "template_parameter_list",
  [sym_type_parameter_declaration] = "type_parameter_declaration",
  [sym_variadic_type_parameter_declaration] = "variadic_type_parameter_declaration",
  [sym_optional_type_parameter_declaration] = "optional_type_parameter_declaration",
  [sym_template_template_parameter_declaration] = "template_template_parameter_declaration",
  [sym_optional_parameter_declaration] = "optional_parameter_declaration",
  [sym_variadic_parameter_declaration] = "variadic_parameter_declaration",
  [sym_variadic_declarator] = "variadic_declarator",
  [sym_variadic_reference_declarator] = "reference_declarator",
  [sym_operator_cast] = "operator_cast",
  [sym_field_initializer_list] = "field_initializer_list",
  [sym_field_initializer] = "field_initializer",
  [sym_inline_method_definition] = "function_definition",
  [sym__constructor_specifiers] = "_constructor_specifiers",
  [sym_operator_cast_definition] = "function_definition",
  [sym_operator_cast_declaration] = "declaration",
  [sym_constructor_try_statement] = "try_statement",
  [sym_constructor_or_destructor_definition] = "function_definition",
  [sym_constructor_or_destructor_declaration] = "declaration",
  [sym_default_method_clause] = "default_method_clause",
  [sym_delete_method_clause] = "delete_method_clause",
  [sym_pure_virtual_clause] = "pure_virtual_clause",
  [sym_friend_declaration] = "friend_declaration",
  [sym_access_specifier] = "access_specifier",
  [sym_reference_declarator] = "reference_declarator",
  [sym_reference_field_declarator] = "reference_declarator",
  [sym_reference_type_declarator] = "reference_declarator",
  [sym_abstract_reference_declarator] = "abstract_reference_declarator",
  [sym_structured_binding_declarator] = "structured_binding_declarator",
  [sym_ref_qualifier] = "ref_qualifier",
  [sym__function_declarator_seq] = "_function_declarator_seq",
  [sym__function_attributes_start] = "_function_attributes_start",
  [sym__function_exception_specification] = "_function_exception_specification",
  [sym__function_attributes_end] = "_function_attributes_end",
  [sym__function_postfix] = "_function_postfix",
  [sym_trailing_return_type] = "trailing_return_type",
  [sym_noexcept] = "noexcept",
  [sym_throw_specifier] = "throw_specifier",
  [sym_template_type] = "template_type",
  [sym_template_method] = "template_method",
  [sym_template_function] = "template_function",
  [sym_template_argument_list] = "template_argument_list",
  [sym_namespace_definition] = "namespace_definition",
  [sym_namespace_alias_definition] = "namespace_alias_definition",
  [sym__namespace_specifier] = "_namespace_specifier",
  [sym_nested_namespace_specifier] = "nested_namespace_specifier",
  [sym_using_declaration] = "using_declaration",
  [sym_alias_declaration] = "alias_declaration",
  [sym_static_assert_declaration] = "static_assert_declaration",
  [sym_concept_definition] = "concept_definition",
  [sym_for_range_loop] = "for_range_loop",
  [sym__for_range_loop_body] = "_for_range_loop_body",
  [sym_init_statement] = "init_statement",
  [sym_condition_clause] = "condition_clause",
  [sym_condition_declaration] = "declaration",
  [sym_co_return_statement] = "co_return_statement",
  [sym_co_yield_statement] = "co_yield_statement",
  [sym_throw_statement] = "throw_statement",
  [sym_try_statement] = "try_statement",
  [sym_catch_clause] = "catch_clause",
  [sym_raw_string_literal] = "raw_string_literal",
  [sym_subscript_argument_list] = "subscript_argument_list",
  [sym_co_await_expression] = "co_await_expression",
  [sym_new_expression] = "new_expression",
  [sym_new_declarator] = "new_declarator",
  [sym_delete_expression] = "delete_expression",
  [sym_type_requirement] = "type_requirement",
  [sym_compound_requirement] = "compound_requirement",
  [sym__requirement] = "_requirement",
  [sym_requirement_seq] = "requirement_seq",
  [sym_constraint_conjunction] = "constraint_conjunction",
  [sym_constraint_disjunction] = "constraint_disjunction",
  [sym__requirement_clause_constraint] = "_requirement_clause_constraint",
  [sym_requires_clause] = "requires_clause",
  [sym_requires_parameter_list] = "parameter_list",
  [sym_requires_expression] = "requires_expression",
  [sym_lambda_expression] = "lambda_expression",
  [sym_lambda_capture_specifier] = "lambda_capture_specifier",
  [sym_lambda_default_capture] = "lambda_default_capture",
  [sym__fold_operator] = "_fold_operator",
  [sym__binary_fold_operator] = "_binary_fold_operator",
  [sym__unary_left_fold] = "_unary_left_fold",
  [sym__unary_right_fold] = "_unary_right_fold",
  [sym__binary_fold] = "_binary_fold",
  [sym_fold_expression] = "fold_expression",
  [sym_parameter_pack_expansion] = "parameter_pack_expansion",
  [sym_type_parameter_pack_expansion] = "parameter_pack_expansion",
  [sym_destructor_name] = "destructor_name",
  [sym_dependent_identifier] = "dependent_name",
  [sym_dependent_field_identifier] = "dependent_name",
  [sym_dependent_type_identifier] = "dependent_name",
  [sym__scope_resolution] = "_scope_resolution",
  [sym_qualified_field_identifier] = "qualified_identifier",
  [sym_qualified_identifier] = "qualified_identifier",
  [sym_qualified_type_identifier] = "qualified_identifier",
  [sym_qualified_operator_cast_identifier] = "qualified_identifier",
  [sym__assignment_expression_lhs] = "assignment_expression",
  [sym_operator_name] = "operator_name",
  [sym_user_defined_literal] = "user_defined_literal",
  [sym_semantics] = "semantics",
  [sym_discard_statement] = "discard_statement",
  [sym_qualifiers] = "qualifiers",
  [sym_cbuffer_specifier] = "cbuffer_specifier",
  [sym_hlsl_attribute] = "hlsl_attribute",
  [aux_sym_translation_unit_repeat1] = "translation_unit_repeat1",
  [aux_sym_preproc_params_repeat1] = "preproc_params_repeat1",
  [aux_sym_preproc_if_repeat1] = "preproc_if_repeat1",
  [aux_sym_preproc_if_in_field_declaration_list_repeat1] = "preproc_if_in_field_declaration_list_repeat1",
  [aux_sym_preproc_if_in_enumerator_list_repeat1] = "preproc_if_in_enumerator_list_repeat1",
  [aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1] = "preproc_if_in_enumerator_list_no_comma_repeat1",
  [aux_sym_preproc_argument_list_repeat1] = "preproc_argument_list_repeat1",
  [aux_sym_declaration_repeat1] = "declaration_repeat1",
  [aux_sym_type_definition_repeat1] = "type_definition_repeat1",
  [aux_sym__type_definition_type_repeat1] = "_type_definition_type_repeat1",
  [aux_sym__type_definition_declarators_repeat1] = "_type_definition_declarators_repeat1",
  [aux_sym__declaration_specifiers_repeat1] = "_declaration_specifiers_repeat1",
  [aux_sym_attribute_declaration_repeat1] = "attribute_declaration_repeat1",
  [aux_sym_attributed_declarator_repeat1] = "attributed_declarator_repeat1",
  [aux_sym_pointer_declarator_repeat1] = "pointer_declarator_repeat1",
  [aux_sym_array_declarator_repeat1] = "array_declarator_repeat1",
  [aux_sym_sized_type_specifier_repeat1] = "sized_type_specifier_repeat1",
  [aux_sym_enumerator_list_repeat1] = "enumerator_list_repeat1",
  [aux_sym_field_declaration_repeat1] = "field_declaration_repeat1",
  [aux_sym_parameter_list_repeat1] = "parameter_list_repeat1",
  [aux_sym_case_statement_repeat1] = "case_statement_repeat1",
  [aux_sym_generic_expression_repeat1] = "generic_expression_repeat1",
  [aux_sym_gnu_asm_expression_repeat1] = "gnu_asm_expression_repeat1",
  [aux_sym_gnu_asm_output_operand_list_repeat1] = "gnu_asm_output_operand_list_repeat1",
  [aux_sym_gnu_asm_input_operand_list_repeat1] = "gnu_asm_input_operand_list_repeat1",
  [aux_sym_gnu_asm_clobber_list_repeat1] = "gnu_asm_clobber_list_repeat1",
  [aux_sym_gnu_asm_goto_list_repeat1] = "gnu_asm_goto_list_repeat1",
  [aux_sym_argument_list_repeat1] = "argument_list_repeat1",
  [aux_sym_initializer_list_repeat1] = "initializer_list_repeat1",
  [aux_sym_initializer_pair_repeat1] = "initializer_pair_repeat1",
  [aux_sym_char_literal_repeat1] = "char_literal_repeat1",
  [aux_sym_concatenated_string_repeat1] = "concatenated_string_repeat1",
  [aux_sym_string_literal_repeat1] = "string_literal_repeat1",
  [aux_sym__class_declaration_repeat1] = "_class_declaration_repeat1",
  [aux_sym_base_class_clause_repeat1] = "base_class_clause_repeat1",
  [aux_sym_template_parameter_list_repeat1] = "template_parameter_list_repeat1",
  [aux_sym_field_initializer_list_repeat1] = "field_initializer_list_repeat1",
  [aux_sym_operator_cast_definition_repeat1] = "operator_cast_definition_repeat1",
  [aux_sym_constructor_try_statement_repeat1] = "constructor_try_statement_repeat1",
  [aux_sym_structured_binding_declarator_repeat1] = "structured_binding_declarator_repeat1",
  [aux_sym__function_postfix_repeat1] = "_function_postfix_repeat1",
  [aux_sym_throw_specifier_repeat1] = "throw_specifier_repeat1",
  [aux_sym_template_argument_list_repeat1] = "template_argument_list_repeat1",
  [aux_sym_subscript_argument_list_repeat1] = "subscript_argument_list_repeat1",
  [aux_sym_requirement_seq_repeat1] = "requirement_seq_repeat1",
  [aux_sym_requires_parameter_list_repeat1] = "requires_parameter_list_repeat1",
  [aux_sym_lambda_capture_specifier_repeat1] = "lambda_capture_specifier_repeat1",
  [alias_sym_field_identifier] = "field_identifier",
  [alias_sym_namespace_identifier] = "namespace_identifier",
  [alias_sym_simple_requirement] = "simple_requirement",
  [alias_sym_statement_identifier] = "statement_identifier",
  [alias_sym_type_identifier] = "type_identifier",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [aux_sym_preproc_include_token1] = aux_sym_preproc_include_token1,
  [aux_sym_preproc_include_token2] = aux_sym_preproc_include_token2,
  [aux_sym_preproc_def_token1] = aux_sym_preproc_def_token1,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_DOT_DOT_DOT] = anon_sym_DOT_DOT_DOT,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [aux_sym_preproc_if_token1] = aux_sym_preproc_if_token1,
  [anon_sym_LF] = anon_sym_LF,
  [aux_sym_preproc_if_token2] = aux_sym_preproc_if_token2,
  [aux_sym_preproc_ifdef_token1] = aux_sym_preproc_ifdef_token1,
  [aux_sym_preproc_ifdef_token2] = aux_sym_preproc_ifdef_token2,
  [aux_sym_preproc_else_token1] = aux_sym_preproc_else_token1,
  [aux_sym_preproc_elif_token1] = aux_sym_preproc_elif_token1,
  [aux_sym_preproc_elifdef_token1] = aux_sym_preproc_elifdef_token1,
  [aux_sym_preproc_elifdef_token2] = aux_sym_preproc_elifdef_token2,
  [sym_preproc_arg] = sym_preproc_arg,
  [sym_preproc_directive] = sym_preproc_directive,
  [anon_sym_LPAREN2] = anon_sym_LPAREN,
  [anon_sym_defined] = anon_sym_defined,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_LT_LT] = anon_sym_LT_LT,
  [anon_sym_GT_GT] = anon_sym_GT_GT,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym___extension__] = anon_sym___extension__,
  [anon_sym_typedef] = anon_sym_typedef,
  [anon_sym_in] = anon_sym_in,
  [anon_sym_out] = anon_sym_out,
  [anon_sym_inout] = anon_sym_inout,
  [anon_sym_extern] = anon_sym_extern,
  [anon_sym___attribute__] = anon_sym___attribute__,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [anon_sym_LBRACK_LBRACK] = anon_sym_LBRACK_LBRACK,
  [anon_sym_RBRACK_RBRACK] = anon_sym_RBRACK_RBRACK,
  [anon_sym___declspec] = anon_sym___declspec,
  [anon_sym___based] = anon_sym___based,
  [anon_sym___cdecl] = anon_sym___cdecl,
  [anon_sym___clrcall] = anon_sym___clrcall,
  [anon_sym___stdcall] = anon_sym___stdcall,
  [anon_sym___fastcall] = anon_sym___fastcall,
  [anon_sym___thiscall] = anon_sym___thiscall,
  [anon_sym___vectorcall] = anon_sym___vectorcall,
  [sym_ms_restrict_modifier] = sym_ms_restrict_modifier,
  [sym_ms_unsigned_ptr_modifier] = sym_ms_unsigned_ptr_modifier,
  [sym_ms_signed_ptr_modifier] = sym_ms_signed_ptr_modifier,
  [anon_sym__unaligned] = anon_sym__unaligned,
  [anon_sym___unaligned] = anon_sym___unaligned,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_signed] = anon_sym_signed,
  [anon_sym_unsigned] = anon_sym_unsigned,
  [anon_sym_long] = anon_sym_long,
  [anon_sym_short] = anon_sym_short,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_static] = anon_sym_static,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_register] = anon_sym_register,
  [anon_sym_inline] = anon_sym_inline,
  [anon_sym___inline] = anon_sym___inline,
  [anon_sym___inline__] = anon_sym___inline__,
  [anon_sym___forceinline] = anon_sym___forceinline,
  [anon_sym_thread_local] = anon_sym_thread_local,
  [anon_sym___thread] = anon_sym___thread,
  [anon_sym_const] = anon_sym_const,
  [anon_sym_constexpr] = anon_sym_constexpr,
  [anon_sym_volatile] = anon_sym_volatile,
  [anon_sym_restrict] = anon_sym_restrict,
  [anon_sym___restrict__] = anon_sym___restrict__,
  [anon_sym__Atomic] = anon_sym__Atomic,
  [anon_sym__Noreturn] = anon_sym__Noreturn,
  [anon_sym_noreturn] = anon_sym_noreturn,
  [anon_sym_mutable] = anon_sym_mutable,
  [anon_sym_constinit] = anon_sym_constinit,
  [anon_sym_consteval] = anon_sym_consteval,
  [anon_sym_alignas] = anon_sym_alignas,
  [anon_sym__Alignas] = anon_sym__Alignas,
  [sym_primitive_type] = sym_primitive_type,
  [anon_sym_enum] = anon_sym_enum,
  [anon_sym_class] = anon_sym_class,
  [anon_sym_struct] = anon_sym_struct,
  [anon_sym_union] = anon_sym_union,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_switch] = anon_sym_switch,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_default] = anon_sym_default,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_do] = anon_sym_do,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_return] = anon_sym_return,
  [anon_sym_break] = anon_sym_break,
  [anon_sym_continue] = anon_sym_continue,
  [anon_sym_goto] = anon_sym_goto,
  [anon_sym___try] = anon_sym___try,
  [anon_sym___except] = anon_sym___except,
  [anon_sym___finally] = anon_sym___finally,
  [anon_sym___leave] = anon_sym___leave,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_STAR_EQ] = anon_sym_STAR_EQ,
  [anon_sym_SLASH_EQ] = anon_sym_SLASH_EQ,
  [anon_sym_PERCENT_EQ] = anon_sym_PERCENT_EQ,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_LT_LT_EQ] = anon_sym_LT_LT_EQ,
  [anon_sym_GT_GT_EQ] = anon_sym_GT_GT_EQ,
  [anon_sym_AMP_EQ] = anon_sym_AMP_EQ,
  [anon_sym_CARET_EQ] = anon_sym_CARET_EQ,
  [anon_sym_PIPE_EQ] = anon_sym_PIPE_EQ,
  [anon_sym_and_eq] = anon_sym_and_eq,
  [anon_sym_or_eq] = anon_sym_or_eq,
  [anon_sym_xor_eq] = anon_sym_xor_eq,
  [anon_sym_not] = anon_sym_not,
  [anon_sym_compl] = anon_sym_compl,
  [anon_sym_LT_EQ_GT] = anon_sym_LT_EQ_GT,
  [anon_sym_or] = anon_sym_or,
  [anon_sym_and] = anon_sym_and,
  [anon_sym_bitor] = anon_sym_bitor,
  [anon_sym_xor] = anon_sym_xor,
  [anon_sym_bitand] = anon_sym_bitand,
  [anon_sym_not_eq] = anon_sym_not_eq,
  [anon_sym_DASH_DASH] = anon_sym_DASH_DASH,
  [anon_sym_PLUS_PLUS] = anon_sym_PLUS_PLUS,
  [anon_sym_sizeof] = anon_sym_sizeof,
  [anon_sym___alignof__] = anon_sym___alignof__,
  [anon_sym___alignof] = anon_sym___alignof,
  [anon_sym__alignof] = anon_sym__alignof,
  [anon_sym_alignof] = anon_sym_alignof,
  [anon_sym__Alignof] = anon_sym__Alignof,
  [anon_sym_offsetof] = anon_sym_offsetof,
  [anon_sym__Generic] = anon_sym__Generic,
  [anon_sym_asm] = anon_sym_asm,
  [anon_sym___asm__] = anon_sym___asm__,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_DOT_STAR] = anon_sym_DOT_STAR,
  [anon_sym_DASH_GT] = anon_sym_DASH_GT,
  [sym_number_literal] = sym_number_literal,
  [anon_sym_L_SQUOTE] = anon_sym_L_SQUOTE,
  [anon_sym_u_SQUOTE] = anon_sym_u_SQUOTE,
  [anon_sym_U_SQUOTE] = anon_sym_U_SQUOTE,
  [anon_sym_u8_SQUOTE] = anon_sym_u8_SQUOTE,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [aux_sym_char_literal_token1] = aux_sym_char_literal_token1,
  [anon_sym_L_DQUOTE] = anon_sym_L_DQUOTE,
  [anon_sym_u_DQUOTE] = anon_sym_u_DQUOTE,
  [anon_sym_U_DQUOTE] = anon_sym_U_DQUOTE,
  [anon_sym_u8_DQUOTE] = anon_sym_u8_DQUOTE,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [aux_sym_string_literal_token1] = aux_sym_string_literal_token1,
  [sym_escape_sequence] = sym_escape_sequence,
  [sym_system_lib_string] = sym_system_lib_string,
  [sym_true] = sym_true,
  [sym_false] = sym_false,
  [anon_sym_NULL] = anon_sym_NULL,
  [anon_sym_nullptr] = anon_sym_nullptr,
  [sym_comment] = sym_comment,
  [sym_auto] = sym_auto,
  [anon_sym_decltype] = anon_sym_decltype,
  [anon_sym_final] = anon_sym_final,
  [anon_sym_override] = anon_sym_override,
  [sym_virtual] = sym_virtual,
  [anon_sym_explicit] = anon_sym_explicit,
  [anon_sym_typename] = anon_sym_typename,
  [anon_sym_template] = anon_sym_template,
  [anon_sym_GT2] = anon_sym_GT,
  [anon_sym_operator] = anon_sym_operator,
  [anon_sym_try] = anon_sym_try,
  [anon_sym_delete] = anon_sym_delete,
  [anon_sym_0] = anon_sym_0,
  [anon_sym_friend] = anon_sym_friend,
  [anon_sym_public] = anon_sym_public,
  [anon_sym_private] = anon_sym_private,
  [anon_sym_protected] = anon_sym_protected,
  [anon_sym_noexcept] = anon_sym_noexcept,
  [anon_sym_throw] = anon_sym_throw,
  [anon_sym_namespace] = anon_sym_namespace,
  [anon_sym_using] = anon_sym_using,
  [anon_sym_static_assert] = anon_sym_static_assert,
  [anon_sym_concept] = anon_sym_concept,
  [anon_sym_co_return] = anon_sym_co_return,
  [anon_sym_co_yield] = anon_sym_co_yield,
  [anon_sym_catch] = anon_sym_catch,
  [anon_sym_R_DQUOTE] = anon_sym_R_DQUOTE,
  [anon_sym_LR_DQUOTE] = anon_sym_LR_DQUOTE,
  [anon_sym_uR_DQUOTE] = anon_sym_uR_DQUOTE,
  [anon_sym_UR_DQUOTE] = anon_sym_UR_DQUOTE,
  [anon_sym_u8R_DQUOTE] = anon_sym_u8R_DQUOTE,
  [anon_sym_co_await] = anon_sym_co_await,
  [anon_sym_new] = anon_sym_new,
  [anon_sym_requires] = anon_sym_requires,
  [anon_sym_DASH_GT_STAR] = anon_sym_DASH_GT_STAR,
  [anon_sym_LPAREN_RPAREN] = anon_sym_LPAREN_RPAREN,
  [anon_sym_LBRACK_RBRACK] = anon_sym_LBRACK_RBRACK,
  [anon_sym_DQUOTE_DQUOTE] = anon_sym_DQUOTE_DQUOTE,
  [sym_this] = sym_this,
  [sym_literal_suffix] = sym_literal_suffix,
  [anon_sym_discard] = anon_sym_discard,
  [anon_sym_precise] = anon_sym_precise,
  [anon_sym_shared] = anon_sym_shared,
  [anon_sym_groupshared] = anon_sym_groupshared,
  [anon_sym_uniform] = anon_sym_uniform,
  [anon_sym_row_major] = anon_sym_row_major,
  [anon_sym_column_major] = anon_sym_column_major,
  [anon_sym_globallycoherent] = anon_sym_globallycoherent,
  [anon_sym_centroid] = anon_sym_centroid,
  [anon_sym_noperspective] = anon_sym_noperspective,
  [anon_sym_nointerpolation] = anon_sym_nointerpolation,
  [anon_sym_sample] = anon_sym_sample,
  [anon_sym_linear] = anon_sym_linear,
  [anon_sym_snorm] = anon_sym_snorm,
  [anon_sym_unorm] = anon_sym_unorm,
  [anon_sym_point] = anon_sym_point,
  [anon_sym_line] = anon_sym_line,
  [anon_sym_triangleadj] = anon_sym_triangleadj,
  [anon_sym_lineadj] = anon_sym_lineadj,
  [anon_sym_triangle] = anon_sym_triangle,
  [anon_sym_cbuffer] = anon_sym_cbuffer,
  [sym_raw_string_delimiter] = sym_raw_string_delimiter,
  [sym_raw_string_content] = sym_raw_string_content,
  [sym_translation_unit] = sym_translation_unit,
  [sym__top_level_item] = sym__top_level_item,
  [sym__block_item] = sym__block_item,
  [sym_preproc_include] = sym_preproc_include,
  [sym_preproc_def] = sym_preproc_def,
  [sym_preproc_function_def] = sym_preproc_function_def,
  [sym_preproc_params] = sym_preproc_params,
  [sym_preproc_call] = sym_preproc_call,
  [sym_preproc_if] = sym_preproc_if,
  [sym_preproc_ifdef] = sym_preproc_ifdef,
  [sym_preproc_else] = sym_preproc_else,
  [sym_preproc_elif] = sym_preproc_elif,
  [sym_preproc_elifdef] = sym_preproc_elifdef,
  [sym_preproc_if_in_field_declaration_list] = sym_preproc_if,
  [sym_preproc_ifdef_in_field_declaration_list] = sym_preproc_ifdef,
  [sym_preproc_else_in_field_declaration_list] = sym_preproc_else,
  [sym_preproc_elif_in_field_declaration_list] = sym_preproc_elif,
  [sym_preproc_elifdef_in_field_declaration_list] = sym_preproc_elifdef,
  [sym_preproc_if_in_enumerator_list] = sym_preproc_if,
  [sym_preproc_ifdef_in_enumerator_list] = sym_preproc_ifdef,
  [sym_preproc_else_in_enumerator_list] = sym_preproc_else,
  [sym_preproc_elif_in_enumerator_list] = sym_preproc_elif,
  [sym_preproc_elifdef_in_enumerator_list] = sym_preproc_elifdef,
  [sym_preproc_if_in_enumerator_list_no_comma] = sym_preproc_if,
  [sym_preproc_ifdef_in_enumerator_list_no_comma] = sym_preproc_ifdef,
  [sym_preproc_else_in_enumerator_list_no_comma] = sym_preproc_else,
  [sym_preproc_elif_in_enumerator_list_no_comma] = sym_preproc_elif,
  [sym_preproc_elifdef_in_enumerator_list_no_comma] = sym_preproc_elifdef,
  [sym__preproc_expression] = sym__preproc_expression,
  [sym_preproc_parenthesized_expression] = sym_parenthesized_expression,
  [sym_preproc_defined] = sym_preproc_defined,
  [sym_preproc_unary_expression] = sym_unary_expression,
  [sym_preproc_call_expression] = sym_call_expression,
  [sym_preproc_argument_list] = sym_argument_list,
  [sym_preproc_binary_expression] = sym_binary_expression,
  [sym_function_definition] = sym_function_definition,
  [sym_declaration] = sym_declaration,
  [sym_type_definition] = sym_type_definition,
  [sym__type_definition_type] = sym__type_definition_type,
  [sym__type_definition_declarators] = sym__type_definition_declarators,
  [sym__declaration_modifiers] = sym__declaration_modifiers,
  [sym__declaration_specifiers] = sym__declaration_specifiers,
  [sym_linkage_specification] = sym_linkage_specification,
  [sym_attribute_specifier] = sym_attribute_specifier,
  [sym_attribute] = sym_attribute,
  [sym_attribute_declaration] = sym_attribute_declaration,
  [sym_ms_declspec_modifier] = sym_ms_declspec_modifier,
  [sym_ms_based_modifier] = sym_ms_based_modifier,
  [sym_ms_call_modifier] = sym_ms_call_modifier,
  [sym_ms_unaligned_ptr_modifier] = sym_ms_unaligned_ptr_modifier,
  [sym_ms_pointer_modifier] = sym_ms_pointer_modifier,
  [sym_declaration_list] = sym_declaration_list,
  [sym__declarator] = sym__declarator,
  [sym__field_declarator] = sym__field_declarator,
  [sym__type_declarator] = sym__type_declarator,
  [sym__abstract_declarator] = sym__abstract_declarator,
  [sym_parenthesized_declarator] = sym_parenthesized_declarator,
  [sym_parenthesized_field_declarator] = sym_parenthesized_declarator,
  [sym_parenthesized_type_declarator] = sym_parenthesized_declarator,
  [sym_abstract_parenthesized_declarator] = sym_abstract_parenthesized_declarator,
  [sym_attributed_declarator] = sym_attributed_declarator,
  [sym_attributed_field_declarator] = sym_attributed_declarator,
  [sym_attributed_type_declarator] = sym_attributed_declarator,
  [sym_pointer_declarator] = sym_pointer_declarator,
  [sym_pointer_field_declarator] = sym_pointer_declarator,
  [sym_pointer_type_declarator] = sym_pointer_type_declarator,
  [sym_abstract_pointer_declarator] = sym_abstract_pointer_declarator,
  [sym_function_declarator] = sym_function_declarator,
  [sym_function_field_declarator] = sym_function_declarator,
  [sym_function_type_declarator] = sym_function_declarator,
  [sym_abstract_function_declarator] = sym_abstract_function_declarator,
  [sym_array_declarator] = sym_array_declarator,
  [sym_array_field_declarator] = sym_array_declarator,
  [sym_array_type_declarator] = sym_array_declarator,
  [sym_abstract_array_declarator] = sym_abstract_array_declarator,
  [sym_init_declarator] = sym_init_declarator,
  [sym_compound_statement] = sym_compound_statement,
  [sym_storage_class_specifier] = sym_storage_class_specifier,
  [sym_type_qualifier] = sym_type_qualifier,
  [sym_alignas_qualifier] = sym_alignas_qualifier,
  [sym_type_specifier] = sym_type_specifier,
  [sym_sized_type_specifier] = sym_sized_type_specifier,
  [sym_enum_specifier] = sym_enum_specifier,
  [sym_enumerator_list] = sym_enumerator_list,
  [sym_struct_specifier] = sym_struct_specifier,
  [sym_union_specifier] = sym_union_specifier,
  [sym_field_declaration_list] = sym_field_declaration_list,
  [sym__field_declaration_list_item] = sym__field_declaration_list_item,
  [sym_field_declaration] = sym_field_declaration,
  [sym_bitfield_clause] = sym_bitfield_clause,
  [sym_enumerator] = sym_enumerator,
  [sym_parameter_list] = sym_parameter_list,
  [sym_parameter_declaration] = sym_parameter_declaration,
  [sym_attributed_statement] = sym_attributed_statement,
  [sym_statement] = sym_statement,
  [sym__top_level_statement] = sym__top_level_statement,
  [sym_labeled_statement] = sym_labeled_statement,
  [sym__top_level_expression_statement] = sym_expression_statement,
  [sym_expression_statement] = sym_expression_statement,
  [sym_if_statement] = sym_if_statement,
  [sym_else_clause] = sym_else_clause,
  [sym_switch_statement] = sym_switch_statement,
  [sym_case_statement] = sym_case_statement,
  [sym_while_statement] = sym_while_statement,
  [sym_do_statement] = sym_do_statement,
  [sym_for_statement] = sym_for_statement,
  [sym__for_statement_body] = sym__for_statement_body,
  [sym_return_statement] = sym_return_statement,
  [sym_break_statement] = sym_break_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_goto_statement] = sym_goto_statement,
  [sym_seh_try_statement] = sym_seh_try_statement,
  [sym_seh_except_clause] = sym_seh_except_clause,
  [sym_seh_finally_clause] = sym_seh_finally_clause,
  [sym_seh_leave_statement] = sym_seh_leave_statement,
  [sym_expression] = sym_expression,
  [sym__string] = sym__string,
  [sym_comma_expression] = sym_comma_expression,
  [sym_conditional_expression] = sym_conditional_expression,
  [sym_assignment_expression] = sym_assignment_expression,
  [sym_pointer_expression] = sym_pointer_expression,
  [sym_unary_expression] = sym_unary_expression,
  [sym_binary_expression] = sym_binary_expression,
  [sym_update_expression] = sym_update_expression,
  [sym_cast_expression] = sym_cast_expression,
  [sym_type_descriptor] = sym_type_descriptor,
  [sym_sizeof_expression] = sym_sizeof_expression,
  [sym_alignof_expression] = sym_alignof_expression,
  [sym_offsetof_expression] = sym_offsetof_expression,
  [sym_generic_expression] = sym_generic_expression,
  [sym_subscript_expression] = sym_subscript_expression,
  [sym_call_expression] = sym_call_expression,
  [sym_gnu_asm_expression] = sym_gnu_asm_expression,
  [sym_gnu_asm_qualifier] = sym_gnu_asm_qualifier,
  [sym_gnu_asm_output_operand_list] = sym_gnu_asm_output_operand_list,
  [sym_gnu_asm_output_operand] = sym_gnu_asm_output_operand,
  [sym_gnu_asm_input_operand_list] = sym_gnu_asm_input_operand_list,
  [sym_gnu_asm_input_operand] = sym_gnu_asm_input_operand,
  [sym_gnu_asm_clobber_list] = sym_gnu_asm_clobber_list,
  [sym_gnu_asm_goto_list] = sym_gnu_asm_goto_list,
  [sym_argument_list] = sym_argument_list,
  [sym_field_expression] = sym_field_expression,
  [sym_compound_literal_expression] = sym_compound_literal_expression,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym_initializer_list] = sym_initializer_list,
  [sym_initializer_pair] = sym_initializer_pair,
  [sym_subscript_designator] = sym_subscript_designator,
  [sym_subscript_range_designator] = sym_subscript_range_designator,
  [sym_field_designator] = sym_field_designator,
  [sym_char_literal] = sym_char_literal,
  [sym_concatenated_string] = sym_concatenated_string,
  [sym_string_literal] = sym_string_literal,
  [sym_null] = sym_null,
  [sym__empty_declaration] = sym__empty_declaration,
  [sym_placeholder_type_specifier] = sym_placeholder_type_specifier,
  [sym_decltype_auto] = sym_decltype,
  [sym_decltype] = sym_decltype,
  [sym__class_declaration] = sym__class_declaration,
  [sym__class_declaration_item] = sym__class_declaration_item,
  [sym_class_specifier] = sym_class_specifier,
  [sym__class_name] = sym__class_name,
  [sym_virtual_specifier] = sym_virtual_specifier,
  [sym_explicit_function_specifier] = sym_explicit_function_specifier,
  [sym_base_class_clause] = sym_base_class_clause,
  [sym__enum_base_clause] = sym__enum_base_clause,
  [sym_dependent_type] = sym_dependent_type,
  [sym_template_declaration] = sym_template_declaration,
  [sym_template_instantiation] = sym_template_instantiation,
  [sym_template_parameter_list] = sym_template_parameter_list,
  [sym_type_parameter_declaration] = sym_type_parameter_declaration,
  [sym_variadic_type_parameter_declaration] = sym_variadic_type_parameter_declaration,
  [sym_optional_type_parameter_declaration] = sym_optional_type_parameter_declaration,
  [sym_template_template_parameter_declaration] = sym_template_template_parameter_declaration,
  [sym_optional_parameter_declaration] = sym_optional_parameter_declaration,
  [sym_variadic_parameter_declaration] = sym_variadic_parameter_declaration,
  [sym_variadic_declarator] = sym_variadic_declarator,
  [sym_variadic_reference_declarator] = sym_reference_declarator,
  [sym_operator_cast] = sym_operator_cast,
  [sym_field_initializer_list] = sym_field_initializer_list,
  [sym_field_initializer] = sym_field_initializer,
  [sym_inline_method_definition] = sym_function_definition,
  [sym__constructor_specifiers] = sym__constructor_specifiers,
  [sym_operator_cast_definition] = sym_function_definition,
  [sym_operator_cast_declaration] = sym_declaration,
  [sym_constructor_try_statement] = sym_try_statement,
  [sym_constructor_or_destructor_definition] = sym_function_definition,
  [sym_constructor_or_destructor_declaration] = sym_declaration,
  [sym_default_method_clause] = sym_default_method_clause,
  [sym_delete_method_clause] = sym_delete_method_clause,
  [sym_pure_virtual_clause] = sym_pure_virtual_clause,
  [sym_friend_declaration] = sym_friend_declaration,
  [sym_access_specifier] = sym_access_specifier,
  [sym_reference_declarator] = sym_reference_declarator,
  [sym_reference_field_declarator] = sym_reference_declarator,
  [sym_reference_type_declarator] = sym_reference_declarator,
  [sym_abstract_reference_declarator] = sym_abstract_reference_declarator,
  [sym_structured_binding_declarator] = sym_structured_binding_declarator,
  [sym_ref_qualifier] = sym_ref_qualifier,
  [sym__function_declarator_seq] = sym__function_declarator_seq,
  [sym__function_attributes_start] = sym__function_attributes_start,
  [sym__function_exception_specification] = sym__function_exception_specification,
  [sym__function_attributes_end] = sym__function_attributes_end,
  [sym__function_postfix] = sym__function_postfix,
  [sym_trailing_return_type] = sym_trailing_return_type,
  [sym_noexcept] = sym_noexcept,
  [sym_throw_specifier] = sym_throw_specifier,
  [sym_template_type] = sym_template_type,
  [sym_template_method] = sym_template_method,
  [sym_template_function] = sym_template_function,
  [sym_template_argument_list] = sym_template_argument_list,
  [sym_namespace_definition] = sym_namespace_definition,
  [sym_namespace_alias_definition] = sym_namespace_alias_definition,
  [sym__namespace_specifier] = sym__namespace_specifier,
  [sym_nested_namespace_specifier] = sym_nested_namespace_specifier,
  [sym_using_declaration] = sym_using_declaration,
  [sym_alias_declaration] = sym_alias_declaration,
  [sym_static_assert_declaration] = sym_static_assert_declaration,
  [sym_concept_definition] = sym_concept_definition,
  [sym_for_range_loop] = sym_for_range_loop,
  [sym__for_range_loop_body] = sym__for_range_loop_body,
  [sym_init_statement] = sym_init_statement,
  [sym_condition_clause] = sym_condition_clause,
  [sym_condition_declaration] = sym_declaration,
  [sym_co_return_statement] = sym_co_return_statement,
  [sym_co_yield_statement] = sym_co_yield_statement,
  [sym_throw_statement] = sym_throw_statement,
  [sym_try_statement] = sym_try_statement,
  [sym_catch_clause] = sym_catch_clause,
  [sym_raw_string_literal] = sym_raw_string_literal,
  [sym_subscript_argument_list] = sym_subscript_argument_list,
  [sym_co_await_expression] = sym_co_await_expression,
  [sym_new_expression] = sym_new_expression,
  [sym_new_declarator] = sym_new_declarator,
  [sym_delete_expression] = sym_delete_expression,
  [sym_type_requirement] = sym_type_requirement,
  [sym_compound_requirement] = sym_compound_requirement,
  [sym__requirement] = sym__requirement,
  [sym_requirement_seq] = sym_requirement_seq,
  [sym_constraint_conjunction] = sym_constraint_conjunction,
  [sym_constraint_disjunction] = sym_constraint_disjunction,
  [sym__requirement_clause_constraint] = sym__requirement_clause_constraint,
  [sym_requires_clause] = sym_requires_clause,
  [sym_requires_parameter_list] = sym_parameter_list,
  [sym_requires_expression] = sym_requires_expression,
  [sym_lambda_expression] = sym_lambda_expression,
  [sym_lambda_capture_specifier] = sym_lambda_capture_specifier,
  [sym_lambda_default_capture] = sym_lambda_default_capture,
  [sym__fold_operator] = sym__fold_operator,
  [sym__binary_fold_operator] = sym__binary_fold_operator,
  [sym__unary_left_fold] = sym__unary_left_fold,
  [sym__unary_right_fold] = sym__unary_right_fold,
  [sym__binary_fold] = sym__binary_fold,
  [sym_fold_expression] = sym_fold_expression,
  [sym_parameter_pack_expansion] = sym_parameter_pack_expansion,
  [sym_type_parameter_pack_expansion] = sym_parameter_pack_expansion,
  [sym_destructor_name] = sym_destructor_name,
  [sym_dependent_identifier] = sym_dependent_identifier,
  [sym_dependent_field_identifier] = sym_dependent_identifier,
  [sym_dependent_type_identifier] = sym_dependent_identifier,
  [sym__scope_resolution] = sym__scope_resolution,
  [sym_qualified_field_identifier] = sym_qualified_identifier,
  [sym_qualified_identifier] = sym_qualified_identifier,
  [sym_qualified_type_identifier] = sym_qualified_identifier,
  [sym_qualified_operator_cast_identifier] = sym_qualified_identifier,
  [sym__assignment_expression_lhs] = sym_assignment_expression,
  [sym_operator_name] = sym_operator_name,
  [sym_user_defined_literal] = sym_user_defined_literal,
  [sym_semantics] = sym_semantics,
  [sym_discard_statement] = sym_discard_statement,
  [sym_qualifiers] = sym_qualifiers,
  [sym_cbuffer_specifier] = sym_cbuffer_specifier,
  [sym_hlsl_attribute] = sym_hlsl_attribute,
  [aux_sym_translation_unit_repeat1] = aux_sym_translation_unit_repeat1,
  [aux_sym_preproc_params_repeat1] = aux_sym_preproc_params_repeat1,
  [aux_sym_preproc_if_repeat1] = aux_sym_preproc_if_repeat1,
  [aux_sym_preproc_if_in_field_declaration_list_repeat1] = aux_sym_preproc_if_in_field_declaration_list_repeat1,
  [aux_sym_preproc_if_in_enumerator_list_repeat1] = aux_sym_preproc_if_in_enumerator_list_repeat1,
  [aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1] = aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
  [aux_sym_preproc_argument_list_repeat1] = aux_sym_preproc_argument_list_repeat1,
  [aux_sym_declaration_repeat1] = aux_sym_declaration_repeat1,
  [aux_sym_type_definition_repeat1] = aux_sym_type_definition_repeat1,
  [aux_sym__type_definition_type_repeat1] = aux_sym__type_definition_type_repeat1,
  [aux_sym__type_definition_declarators_repeat1] = aux_sym__type_definition_declarators_repeat1,
  [aux_sym__declaration_specifiers_repeat1] = aux_sym__declaration_specifiers_repeat1,
  [aux_sym_attribute_declaration_repeat1] = aux_sym_attribute_declaration_repeat1,
  [aux_sym_attributed_declarator_repeat1] = aux_sym_attributed_declarator_repeat1,
  [aux_sym_pointer_declarator_repeat1] = aux_sym_pointer_declarator_repeat1,
  [aux_sym_array_declarator_repeat1] = aux_sym_array_declarator_repeat1,
  [aux_sym_sized_type_specifier_repeat1] = aux_sym_sized_type_specifier_repeat1,
  [aux_sym_enumerator_list_repeat1] = aux_sym_enumerator_list_repeat1,
  [aux_sym_field_declaration_repeat1] = aux_sym_field_declaration_repeat1,
  [aux_sym_parameter_list_repeat1] = aux_sym_parameter_list_repeat1,
  [aux_sym_case_statement_repeat1] = aux_sym_case_statement_repeat1,
  [aux_sym_generic_expression_repeat1] = aux_sym_generic_expression_repeat1,
  [aux_sym_gnu_asm_expression_repeat1] = aux_sym_gnu_asm_expression_repeat1,
  [aux_sym_gnu_asm_output_operand_list_repeat1] = aux_sym_gnu_asm_output_operand_list_repeat1,
  [aux_sym_gnu_asm_input_operand_list_repeat1] = aux_sym_gnu_asm_input_operand_list_repeat1,
  [aux_sym_gnu_asm_clobber_list_repeat1] = aux_sym_gnu_asm_clobber_list_repeat1,
  [aux_sym_gnu_asm_goto_list_repeat1] = aux_sym_gnu_asm_goto_list_repeat1,
  [aux_sym_argument_list_repeat1] = aux_sym_argument_list_repeat1,
  [aux_sym_initializer_list_repeat1] = aux_sym_initializer_list_repeat1,
  [aux_sym_initializer_pair_repeat1] = aux_sym_initializer_pair_repeat1,
  [aux_sym_char_literal_repeat1] = aux_sym_char_literal_repeat1,
  [aux_sym_concatenated_string_repeat1] = aux_sym_concatenated_string_repeat1,
  [aux_sym_string_literal_repeat1] = aux_sym_string_literal_repeat1,
  [aux_sym__class_declaration_repeat1] = aux_sym__class_declaration_repeat1,
  [aux_sym_base_class_clause_repeat1] = aux_sym_base_class_clause_repeat1,
  [aux_sym_template_parameter_list_repeat1] = aux_sym_template_parameter_list_repeat1,
  [aux_sym_field_initializer_list_repeat1] = aux_sym_field_initializer_list_repeat1,
  [aux_sym_operator_cast_definition_repeat1] = aux_sym_operator_cast_definition_repeat1,
  [aux_sym_constructor_try_statement_repeat1] = aux_sym_constructor_try_statement_repeat1,
  [aux_sym_structured_binding_declarator_repeat1] = aux_sym_structured_binding_declarator_repeat1,
  [aux_sym__function_postfix_repeat1] = aux_sym__function_postfix_repeat1,
  [aux_sym_throw_specifier_repeat1] = aux_sym_throw_specifier_repeat1,
  [aux_sym_template_argument_list_repeat1] = aux_sym_template_argument_list_repeat1,
  [aux_sym_subscript_argument_list_repeat1] = aux_sym_subscript_argument_list_repeat1,
  [aux_sym_requirement_seq_repeat1] = aux_sym_requirement_seq_repeat1,
  [aux_sym_requires_parameter_list_repeat1] = aux_sym_requires_parameter_list_repeat1,
  [aux_sym_lambda_capture_specifier_repeat1] = aux_sym_lambda_capture_specifier_repeat1,
  [alias_sym_field_identifier] = alias_sym_field_identifier,
  [alias_sym_namespace_identifier] = alias_sym_namespace_identifier,
  [alias_sym_simple_requirement] = alias_sym_simple_requirement,
  [alias_sym_statement_identifier] = alias_sym_statement_identifier,
  [alias_sym_type_identifier] = alias_sym_type_identifier,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preproc_include_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_include_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_def_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_if_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LF] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_if_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_ifdef_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_ifdef_token2] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_else_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_elif_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_elifdef_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_elifdef_token2] = {
    .visible = true,
    .named = false,
  },
  [sym_preproc_arg] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_directive] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LPAREN2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_defined] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___extension__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_typedef] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_in] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_out] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_inout] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_extern] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___attribute__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___declspec] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___based] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___cdecl] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___clrcall] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___stdcall] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___fastcall] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___thiscall] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___vectorcall] = {
    .visible = true,
    .named = false,
  },
  [sym_ms_restrict_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_ms_unsigned_ptr_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_ms_signed_ptr_modifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym__unaligned] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___unaligned] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_signed] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unsigned] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_long] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_short] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_static] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_register] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_inline] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___inline] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___inline__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___forceinline] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_thread_local] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___thread] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_const] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_constexpr] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_volatile] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_restrict] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___restrict__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym__Atomic] = {
    .visible = true,
    .named = false,
  },
  [anon_sym__Noreturn] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_noreturn] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_mutable] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_constinit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_consteval] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_alignas] = {
    .visible = true,
    .named = false,
  },
  [anon_sym__Alignas] = {
    .visible = true,
    .named = false,
  },
  [sym_primitive_type] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_class] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_struct] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_union] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_switch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_default] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_do] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_break] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_continue] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_goto] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___try] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___except] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___finally] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___leave] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_and_eq] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_or_eq] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_xor_eq] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_not] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_compl] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_or] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_and] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bitor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_xor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bitand] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_not_eq] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sizeof] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___alignof__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___alignof] = {
    .visible = true,
    .named = false,
  },
  [anon_sym__alignof] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_alignof] = {
    .visible = true,
    .named = false,
  },
  [anon_sym__Alignof] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_offsetof] = {
    .visible = true,
    .named = false,
  },
  [anon_sym__Generic] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_asm] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___asm__] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [sym_number_literal] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_L_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_U_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u8_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_char_literal_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_L_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_U_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u8_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_string_literal_token1] = {
    .visible = true,
    .named = true,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_system_lib_string] = {
    .visible = true,
    .named = true,
  },
  [sym_true] = {
    .visible = true,
    .named = true,
  },
  [sym_false] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_NULL] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_nullptr] = {
    .visible = true,
    .named = false,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_auto] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_decltype] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_final] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_override] = {
    .visible = true,
    .named = false,
  },
  [sym_virtual] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_explicit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_typename] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_template] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_operator] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_try] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_delete] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_0] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_friend] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_public] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_private] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_protected] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_noexcept] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_throw] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_namespace] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_using] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_static_assert] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_concept] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_co_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_co_yield] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_catch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_R_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LR_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uR_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_UR_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u8R_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_co_await] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_new] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_requires] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DQUOTE_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [sym_this] = {
    .visible = true,
    .named = true,
  },
  [sym_literal_suffix] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_discard] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_precise] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_shared] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_groupshared] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uniform] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_row_major] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_column_major] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_globallycoherent] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_centroid] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_noperspective] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_nointerpolation] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sample] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_linear] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_snorm] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unorm] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_point] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_line] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_triangleadj] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_lineadj] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_triangle] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cbuffer] = {
    .visible = true,
    .named = false,
  },
  [sym_raw_string_delimiter] = {
    .visible = true,
    .named = true,
  },
  [sym_raw_string_content] = {
    .visible = true,
    .named = true,
  },
  [sym_translation_unit] = {
    .visible = true,
    .named = true,
  },
  [sym__top_level_item] = {
    .visible = false,
    .named = true,
  },
  [sym__block_item] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_include] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_def] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_function_def] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_params] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_call] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_if] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_ifdef] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_else] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elif] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elifdef] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_if_in_field_declaration_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_ifdef_in_field_declaration_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_else_in_field_declaration_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elif_in_field_declaration_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elifdef_in_field_declaration_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_if_in_enumerator_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_ifdef_in_enumerator_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_else_in_enumerator_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elif_in_enumerator_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elifdef_in_enumerator_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_if_in_enumerator_list_no_comma] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_ifdef_in_enumerator_list_no_comma] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_else_in_enumerator_list_no_comma] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elif_in_enumerator_list_no_comma] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elifdef_in_enumerator_list_no_comma] = {
    .visible = true,
    .named = true,
  },
  [sym__preproc_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_defined] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_function_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_type_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__type_definition_type] = {
    .visible = false,
    .named = true,
  },
  [sym__type_definition_declarators] = {
    .visible = false,
    .named = true,
  },
  [sym__declaration_modifiers] = {
    .visible = false,
    .named = true,
  },
  [sym__declaration_specifiers] = {
    .visible = false,
    .named = true,
  },
  [sym_linkage_specification] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_ms_declspec_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_ms_based_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_ms_call_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_ms_unaligned_ptr_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_ms_pointer_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_declaration_list] = {
    .visible = true,
    .named = true,
  },
  [sym__declarator] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__field_declarator] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__type_declarator] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__abstract_declarator] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_parenthesized_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_field_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_type_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_abstract_parenthesized_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_attributed_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_attributed_field_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_attributed_type_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_pointer_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_pointer_field_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_pointer_type_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_abstract_pointer_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_function_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_function_field_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_function_type_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_abstract_function_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_array_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_array_field_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_array_type_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_abstract_array_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_init_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_storage_class_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_type_qualifier] = {
    .visible = true,
    .named = true,
  },
  [sym_alignas_qualifier] = {
    .visible = true,
    .named = true,
  },
  [sym_type_specifier] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_sized_type_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_enumerator_list] = {
    .visible = true,
    .named = true,
  },
  [sym_struct_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_union_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_field_declaration_list] = {
    .visible = true,
    .named = true,
  },
  [sym__field_declaration_list_item] = {
    .visible = false,
    .named = true,
  },
  [sym_field_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_bitfield_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_enumerator] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter_list] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_attributed_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_statement] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__top_level_statement] = {
    .visible = false,
    .named = true,
  },
  [sym_labeled_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__top_level_expression_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_expression_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_else_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_case_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_do_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__for_statement_body] = {
    .visible = false,
    .named = true,
  },
  [sym_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_goto_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_seh_try_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_seh_except_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_seh_finally_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_seh_leave_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__string] = {
    .visible = false,
    .named = true,
  },
  [sym_comma_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_conditional_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_pointer_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_update_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_cast_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_type_descriptor] = {
    .visible = true,
    .named = true,
  },
  [sym_sizeof_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_alignof_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_offsetof_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_generic_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_subscript_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_gnu_asm_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_gnu_asm_qualifier] = {
    .visible = true,
    .named = true,
  },
  [sym_gnu_asm_output_operand_list] = {
    .visible = true,
    .named = true,
  },
  [sym_gnu_asm_output_operand] = {
    .visible = true,
    .named = true,
  },
  [sym_gnu_asm_input_operand_list] = {
    .visible = true,
    .named = true,
  },
  [sym_gnu_asm_input_operand] = {
    .visible = true,
    .named = true,
  },
  [sym_gnu_asm_clobber_list] = {
    .visible = true,
    .named = true,
  },
  [sym_gnu_asm_goto_list] = {
    .visible = true,
    .named = true,
  },
  [sym_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_field_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_literal_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_initializer_list] = {
    .visible = true,
    .named = true,
  },
  [sym_initializer_pair] = {
    .visible = true,
    .named = true,
  },
  [sym_subscript_designator] = {
    .visible = true,
    .named = true,
  },
  [sym_subscript_range_designator] = {
    .visible = true,
    .named = true,
  },
  [sym_field_designator] = {
    .visible = true,
    .named = true,
  },
  [sym_char_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_concatenated_string] = {
    .visible = true,
    .named = true,
  },
  [sym_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_null] = {
    .visible = true,
    .named = true,
  },
  [sym__empty_declaration] = {
    .visible = false,
    .named = true,
  },
  [sym_placeholder_type_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_decltype_auto] = {
    .visible = true,
    .named = true,
  },
  [sym_decltype] = {
    .visible = true,
    .named = true,
  },
  [sym__class_declaration] = {
    .visible = false,
    .named = true,
  },
  [sym__class_declaration_item] = {
    .visible = false,
    .named = true,
  },
  [sym_class_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym__class_name] = {
    .visible = false,
    .named = true,
  },
  [sym_virtual_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_explicit_function_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_base_class_clause] = {
    .visible = true,
    .named = true,
  },
  [sym__enum_base_clause] = {
    .visible = false,
    .named = true,
  },
  [sym_dependent_type] = {
    .visible = true,
    .named = true,
  },
  [sym_template_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_template_instantiation] = {
    .visible = true,
    .named = true,
  },
  [sym_template_parameter_list] = {
    .visible = true,
    .named = true,
  },
  [sym_type_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_variadic_type_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_optional_type_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_template_template_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_optional_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_variadic_parameter_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_variadic_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_variadic_reference_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_operator_cast] = {
    .visible = true,
    .named = true,
  },
  [sym_field_initializer_list] = {
    .visible = true,
    .named = true,
  },
  [sym_field_initializer] = {
    .visible = true,
    .named = true,
  },
  [sym_inline_method_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__constructor_specifiers] = {
    .visible = false,
    .named = true,
  },
  [sym_operator_cast_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_operator_cast_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_constructor_try_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_constructor_or_destructor_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_constructor_or_destructor_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_default_method_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_delete_method_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_pure_virtual_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_friend_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_access_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_reference_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_reference_field_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_reference_type_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_abstract_reference_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_structured_binding_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_ref_qualifier] = {
    .visible = true,
    .named = true,
  },
  [sym__function_declarator_seq] = {
    .visible = false,
    .named = true,
  },
  [sym__function_attributes_start] = {
    .visible = false,
    .named = true,
  },
  [sym__function_exception_specification] = {
    .visible = false,
    .named = true,
  },
  [sym__function_attributes_end] = {
    .visible = false,
    .named = true,
  },
  [sym__function_postfix] = {
    .visible = false,
    .named = true,
  },
  [sym_trailing_return_type] = {
    .visible = true,
    .named = true,
  },
  [sym_noexcept] = {
    .visible = true,
    .named = true,
  },
  [sym_throw_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_template_type] = {
    .visible = true,
    .named = true,
  },
  [sym_template_method] = {
    .visible = true,
    .named = true,
  },
  [sym_template_function] = {
    .visible = true,
    .named = true,
  },
  [sym_template_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_namespace_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_namespace_alias_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__namespace_specifier] = {
    .visible = false,
    .named = true,
  },
  [sym_nested_namespace_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_using_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_alias_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_static_assert_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_concept_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_for_range_loop] = {
    .visible = true,
    .named = true,
  },
  [sym__for_range_loop_body] = {
    .visible = false,
    .named = true,
  },
  [sym_init_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_condition_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_condition_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_co_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_co_yield_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_throw_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_try_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_catch_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_raw_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_subscript_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_co_await_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_new_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_new_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_delete_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_type_requirement] = {
    .visible = true,
    .named = true,
  },
  [sym_compound_requirement] = {
    .visible = true,
    .named = true,
  },
  [sym__requirement] = {
    .visible = false,
    .named = true,
  },
  [sym_requirement_seq] = {
    .visible = true,
    .named = true,
  },
  [sym_constraint_conjunction] = {
    .visible = true,
    .named = true,
  },
  [sym_constraint_disjunction] = {
    .visible = true,
    .named = true,
  },
  [sym__requirement_clause_constraint] = {
    .visible = false,
    .named = true,
  },
  [sym_requires_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_requires_parameter_list] = {
    .visible = true,
    .named = true,
  },
  [sym_requires_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_lambda_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_lambda_capture_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_lambda_default_capture] = {
    .visible = true,
    .named = true,
  },
  [sym__fold_operator] = {
    .visible = false,
    .named = true,
  },
  [sym__binary_fold_operator] = {
    .visible = false,
    .named = true,
  },
  [sym__unary_left_fold] = {
    .visible = false,
    .named = true,
  },
  [sym__unary_right_fold] = {
    .visible = false,
    .named = true,
  },
  [sym__binary_fold] = {
    .visible = false,
    .named = true,
  },
  [sym_fold_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter_pack_expansion] = {
    .visible = true,
    .named = true,
  },
  [sym_type_parameter_pack_expansion] = {
    .visible = true,
    .named = true,
  },
  [sym_destructor_name] = {
    .visible = true,
    .named = true,
  },
  [sym_dependent_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_dependent_field_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_dependent_type_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__scope_resolution] = {
    .visible = false,
    .named = true,
  },
  [sym_qualified_field_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_qualified_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_qualified_type_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_qualified_operator_cast_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__assignment_expression_lhs] = {
    .visible = true,
    .named = true,
  },
  [sym_operator_name] = {
    .visible = true,
    .named = true,
  },
  [sym_user_defined_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_semantics] = {
    .visible = true,
    .named = true,
  },
  [sym_discard_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_qualifiers] = {
    .visible = true,
    .named = true,
  },
  [sym_cbuffer_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_hlsl_attribute] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_translation_unit_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_params_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_if_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_if_in_field_declaration_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_if_in_enumerator_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__type_definition_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__type_definition_declarators_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__declaration_specifiers_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_attribute_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_attributed_declarator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_pointer_declarator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_array_declarator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_sized_type_specifier_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enumerator_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_field_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parameter_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_case_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_generic_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_gnu_asm_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_gnu_asm_output_operand_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_gnu_asm_input_operand_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_gnu_asm_clobber_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_gnu_asm_goto_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_initializer_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_initializer_pair_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_char_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_concatenated_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__class_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_base_class_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_template_parameter_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_field_initializer_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_operator_cast_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_constructor_try_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_structured_binding_declarator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__function_postfix_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_throw_specifier_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_template_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_subscript_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_requirement_seq_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_requires_parameter_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_lambda_capture_specifier_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_field_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_namespace_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_simple_requirement] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_statement_identifier] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_type_identifier] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_alternative = 1,
  field_argument = 2,
  field_arguments = 3,
  field_assembly_code = 4,
  field_base = 5,
  field_body = 6,
  field_captures = 7,
  field_clobbers = 8,
  field_condition = 9,
  field_consequence = 10,
  field_constraint = 11,
  field_declarator = 12,
  field_default_type = 13,
  field_default_value = 14,
  field_delimiter = 15,
  field_designator = 16,
  field_directive = 17,
  field_end = 18,
  field_field = 19,
  field_filter = 20,
  field_function = 21,
  field_goto_labels = 22,
  field_indices = 23,
  field_initializer = 24,
  field_input_operands = 25,
  field_label = 26,
  field_left = 27,
  field_length = 28,
  field_member = 29,
  field_message = 30,
  field_name = 31,
  field_operand = 32,
  field_operator = 33,
  field_output_operands = 34,
  field_parameters = 35,
  field_path = 36,
  field_pattern = 37,
  field_placement = 38,
  field_prefix = 39,
  field_register = 40,
  field_requirements = 41,
  field_right = 42,
  field_scope = 43,
  field_size = 44,
  field_start = 45,
  field_symbol = 46,
  field_template_parameters = 47,
  field_type = 48,
  field_update = 49,
  field_value = 50,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_alternative] = "alternative",
  [field_argument] = "argument",
  [field_arguments] = "arguments",
  [field_assembly_code] = "assembly_code",
  [field_base] = "base",
  [field_body] = "body",
  [field_captures] = "captures",
  [field_clobbers] = "clobbers",
  [field_condition] = "condition",
  [field_consequence] = "consequence",
  [field_constraint] = "constraint",
  [field_declarator] = "declarator",
  [field_default_type] = "default_type",
  [field_default_value] = "default_value",
  [field_delimiter] = "delimiter",
  [field_designator] = "designator",
  [field_directive] = "directive",
  [field_end] = "end",
  [field_field] = "field",
  [field_filter] = "filter",
  [field_function] = "function",
  [field_goto_labels] = "goto_labels",
  [field_indices] = "indices",
  [field_initializer] = "initializer",
  [field_input_operands] = "input_operands",
  [field_label] = "label",
  [field_left] = "left",
  [field_length] = "length",
  [field_member] = "member",
  [field_message] = "message",
  [field_name] = "name",
  [field_operand] = "operand",
  [field_operator] = "operator",
  [field_output_operands] = "output_operands",
  [field_parameters] = "parameters",
  [field_path] = "path",
  [field_pattern] = "pattern",
  [field_placement] = "placement",
  [field_prefix] = "prefix",
  [field_register] = "register",
  [field_requirements] = "requirements",
  [field_right] = "right",
  [field_scope] = "scope",
  [field_size] = "size",
  [field_start] = "start",
  [field_symbol] = "symbol",
  [field_template_parameters] = "template_parameters",
  [field_type] = "type",
  [field_update] = "update",
  [field_value] = "value",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [2] = {.index = 0, .length = 1},
  [3] = {.index = 1, .length = 1},
  [4] = {.index = 2, .length = 2},
  [5] = {.index = 4, .length = 1},
  [6] = {.index = 5, .length = 1},
  [7] = {.index = 6, .length = 2},
  [8] = {.index = 8, .length = 2},
  [9] = {.index = 10, .length = 1},
  [10] = {.index = 11, .length = 1},
  [11] = {.index = 12, .length = 1},
  [12] = {.index = 13, .length = 2},
  [13] = {.index = 15, .length = 2},
  [14] = {.index = 17, .length = 1},
  [15] = {.index = 18, .length = 1},
  [16] = {.index = 19, .length = 2},
  [17] = {.index = 19, .length = 2},
  [18] = {.index = 0, .length = 1},
  [20] = {.index = 21, .length = 1},
  [21] = {.index = 22, .length = 1},
  [22] = {.index = 23, .length = 1},
  [23] = {.index = 24, .length = 1},
  [24] = {.index = 25, .length = 2},
  [25] = {.index = 27, .length = 2},
  [26] = {.index = 29, .length = 1},
  [27] = {.index = 30, .length = 1},
  [28] = {.index = 31, .length = 1},
  [29] = {.index = 32, .length = 2},
  [30] = {.index = 34, .length = 2},
  [31] = {.index = 18, .length = 1},
  [32] = {.index = 36, .length = 2},
  [33] = {.index = 38, .length = 1},
  [34] = {.index = 39, .length = 2},
  [35] = {.index = 39, .length = 2},
  [36] = {.index = 21, .length = 1},
  [37] = {.index = 41, .length = 1},
  [38] = {.index = 42, .length = 2},
  [39] = {.index = 44, .length = 2},
  [40] = {.index = 46, .length = 3},
  [41] = {.index = 49, .length = 1},
  [44] = {.index = 50, .length = 2},
  [45] = {.index = 52, .length = 1},
  [46] = {.index = 53, .length = 1},
  [47] = {.index = 54, .length = 1},
  [48] = {.index = 55, .length = 2},
  [49] = {.index = 57, .length = 2},
  [50] = {.index = 59, .length = 2},
  [51] = {.index = 61, .length = 2},
  [52] = {.index = 63, .length = 2},
  [53] = {.index = 65, .length = 1},
  [54] = {.index = 66, .length = 1},
  [55] = {.index = 67, .length = 3},
  [56] = {.index = 70, .length = 1},
  [57] = {.index = 71, .length = 1},
  [58] = {.index = 72, .length = 2},
  [60] = {.index = 55, .length = 2},
  [61] = {.index = 74, .length = 2},
  [62] = {.index = 76, .length = 2},
  [63] = {.index = 78, .length = 2},
  [65] = {.index = 80, .length = 2},
  [66] = {.index = 82, .length = 2},
  [67] = {.index = 84, .length = 3},
  [68] = {.index = 87, .length = 2},
  [69] = {.index = 89, .length = 2},
  [70] = {.index = 91, .length = 3},
  [71] = {.index = 91, .length = 3},
  [72] = {.index = 94, .length = 3},
  [73] = {.index = 97, .length = 3},
  [74] = {.index = 100, .length = 3},
  [75] = {.index = 103, .length = 2},
  [76] = {.index = 105, .length = 2},
  [77] = {.index = 107, .length = 2},
  [78] = {.index = 109, .length = 1},
  [79] = {.index = 110, .length = 2},
  [80] = {.index = 112, .length = 2},
  [81] = {.index = 114, .length = 2},
  [82] = {.index = 116, .length = 3},
  [83] = {.index = 119, .length = 2},
  [84] = {.index = 121, .length = 1},
  [85] = {.index = 122, .length = 2},
  [86] = {.index = 124, .length = 2},
  [87] = {.index = 126, .length = 2},
  [88] = {.index = 128, .length = 2},
  [89] = {.index = 130, .length = 2},
  [90] = {.index = 132, .length = 2},
  [91] = {.index = 134, .length = 2},
  [92] = {.index = 136, .length = 2},
  [93] = {.index = 138, .length = 1},
  [94] = {.index = 136, .length = 2},
  [96] = {.index = 139, .length = 2},
  [97] = {.index = 141, .length = 1},
  [98] = {.index = 141, .length = 1},
  [99] = {.index = 142, .length = 3},
  [101] = {.index = 145, .length = 2},
  [102] = {.index = 147, .length = 2},
  [103] = {.index = 149, .length = 2},
  [104] = {.index = 151, .length = 3},
  [105] = {.index = 154, .length = 1},
  [106] = {.index = 155, .length = 1},
  [108] = {.index = 156, .length = 3},
  [109] = {.index = 159, .length = 3},
  [110] = {.index = 162, .length = 3},
  [111] = {.index = 165, .length = 3},
  [112] = {.index = 168, .length = 2},
  [113] = {.index = 170, .length = 3},
  [114] = {.index = 173, .length = 2},
  [115] = {.index = 175, .length = 3},
  [116] = {.index = 178, .length = 2},
  [117] = {.index = 19, .length = 2},
  [118] = {.index = 39, .length = 2},
  [119] = {.index = 180, .length = 2},
  [120] = {.index = 182, .length = 2},
  [121] = {.index = 184, .length = 1},
  [122] = {.index = 185, .length = 4},
  [123] = {.index = 189, .length = 4},
  [124] = {.index = 193, .length = 2},
  [125] = {.index = 195, .length = 3},
  [126] = {.index = 198, .length = 2},
  [127] = {.index = 200, .length = 2},
  [128] = {.index = 202, .length = 1},
  [129] = {.index = 203, .length = 2},
  [130] = {.index = 205, .length = 2},
  [131] = {.index = 207, .length = 3},
  [132] = {.index = 210, .length = 3},
  [133] = {.index = 213, .length = 3},
  [134] = {.index = 216, .length = 2},
  [135] = {.index = 218, .length = 2},
  [136] = {.index = 218, .length = 2},
  [137] = {.index = 220, .length = 2},
  [138] = {.index = 220, .length = 2},
  [139] = {.index = 222, .length = 2},
  [140] = {.index = 224, .length = 3},
  [141] = {.index = 227, .length = 2},
  [142] = {.index = 229, .length = 2},
  [143] = {.index = 231, .length = 3},
  [144] = {.index = 234, .length = 2},
  [145] = {.index = 236, .length = 3},
  [146] = {.index = 239, .length = 2},
  [147] = {.index = 241, .length = 1},
  [148] = {.index = 242, .length = 2},
  [149] = {.index = 244, .length = 2},
  [150] = {.index = 246, .length = 4},
  [151] = {.index = 250, .length = 5},
  [152] = {.index = 255, .length = 1},
  [153] = {.index = 256, .length = 1},
  [154] = {.index = 257, .length = 2},
  [155] = {.index = 259, .length = 1},
  [157] = {.index = 260, .length = 1},
  [158] = {.index = 261, .length = 2},
  [159] = {.index = 263, .length = 2},
  [160] = {.index = 11, .length = 1},
  [161] = {.index = 11, .length = 1},
  [162] = {.index = 265, .length = 2},
  [163] = {.index = 267, .length = 1},
  [164] = {.index = 268, .length = 1},
  [165] = {.index = 269, .length = 4},
  [166] = {.index = 273, .length = 4},
  [167] = {.index = 277, .length = 1},
  [168] = {.index = 278, .length = 3},
  [169] = {.index = 281, .length = 2},
  [170] = {.index = 283, .length = 3},
  [171] = {.index = 286, .length = 1},
  [172] = {.index = 287, .length = 5},
  [173] = {.index = 292, .length = 2},
  [174] = {.index = 294, .length = 3},
  [175] = {.index = 297, .length = 2},
  [176] = {.index = 299, .length = 2},
  [177] = {.index = 301, .length = 4},
  [178] = {.index = 305, .length = 2},
  [179] = {.index = 307, .length = 2},
  [180] = {.index = 309, .length = 1},
  [181] = {.index = 310, .length = 2},
  [182] = {.index = 312, .length = 3},
  [183] = {.index = 315, .length = 4},
  [184] = {.index = 319, .length = 4},
  [185] = {.index = 323, .length = 3},
  [186] = {.index = 326, .length = 2},
  [187] = {.index = 328, .length = 3},
  [188] = {.index = 331, .length = 3},
  [189] = {.index = 334, .length = 2},
  [190] = {.index = 336, .length = 2},
  [191] = {.index = 338, .length = 2},
  [192] = {.index = 340, .length = 2},
  [193] = {.index = 342, .length = 3},
  [194] = {.index = 345, .length = 2},
  [195] = {.index = 347, .length = 2},
  [196] = {.index = 349, .length = 3},
  [197] = {.index = 352, .length = 2},
  [198] = {.index = 354, .length = 3},
  [199] = {.index = 357, .length = 5},
  [200] = {.index = 362, .length = 3},
  [201] = {.index = 365, .length = 4},
  [202] = {.index = 369, .length = 3},
  [203] = {.index = 372, .length = 2},
  [204] = {.index = 374, .length = 2},
  [205] = {.index = 376, .length = 2},
  [206] = {.index = 378, .length = 4},
  [207] = {.index = 382, .length = 5},
  [208] = {.index = 387, .length = 3},
  [209] = {.index = 390, .length = 4},
  [210] = {.index = 394, .length = 2},
  [211] = {.index = 396, .length = 1},
  [212] = {.index = 397, .length = 4},
  [213] = {.index = 401, .length = 3},
  [214] = {.index = 404, .length = 2},
  [215] = {.index = 406, .length = 1},
  [216] = {.index = 407, .length = 5},
  [217] = {.index = 412, .length = 2},
  [218] = {.index = 414, .length = 2},
  [219] = {.index = 65, .length = 1},
  [220] = {.index = 416, .length = 5},
  [221] = {.index = 421, .length = 4},
  [222] = {.index = 425, .length = 2},
  [223] = {.index = 427, .length = 2},
  [224] = {.index = 429, .length = 5},
  [225] = {.index = 434, .length = 2},
  [226] = {.index = 436, .length = 3},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_type, 0},
  [1] =
    {field_directive, 0},
  [2] =
    {field_argument, 1},
    {field_operator, 0},
  [4] =
    {field_declarator, 1},
  [5] =
    {field_name, 0},
  [6] =
    {field_arguments, 1},
    {field_function, 0},
  [8] =
    {field_type, 0},
    {field_value, 1},
  [10] =
    {field_body, 1},
  [11] =
    {field_name, 1},
  [12] =
    {field_body, 0},
  [13] =
    {field_body, 1, .inherited = true},
    {field_name, 1, .inherited = true},
  [15] =
    {field_body, 0, .inherited = true},
    {field_name, 0, .inherited = true},
  [17] =
    {field_value, 1},
  [18] =
    {field_scope, 0},
  [19] =
    {field_arguments, 1},
    {field_name, 0},
  [21] =
    {field_type, 1},
  [22] =
    {field_requirements, 1},
  [23] =
    {field_constraint, 1},
  [24] =
    {field_parameters, 0},
  [25] =
    {field_declarator, 0},
    {field_parameters, 1, .inherited = true},
  [27] =
    {field_body, 1},
    {field_declarator, 0},
  [29] =
    {field_declarator, 0},
  [30] =
    {field_constraint, 0},
  [31] =
    {field_pattern, 0},
  [32] =
    {field_argument, 0},
    {field_operator, 1},
  [34] =
    {field_argument, 0},
    {field_indices, 1},
  [36] =
    {field_body, 1},
    {field_captures, 0},
  [38] =
    {field_parameters, 0, .inherited = true},
  [39] =
    {field_name, 1},
    {field_scope, 0, .inherited = true},
  [41] =
    {field_path, 1},
  [42] =
    {field_argument, 1},
    {field_directive, 0},
  [44] =
    {field_declarator, 1},
    {field_type, 0},
  [46] =
    {field_left, 1, .inherited = true},
    {field_operator, 1, .inherited = true},
    {field_right, 1, .inherited = true},
  [49] =
    {field_declarator, 2},
  [50] =
    {field_body, 2},
    {field_value, 1},
  [52] =
    {field_type, 2},
  [53] =
    {field_body, 2},
  [54] =
    {field_name, 2},
  [55] =
    {field_body, 2},
    {field_name, 1},
  [57] =
    {field_base, 2, .inherited = true},
    {field_name, 1},
  [59] =
    {field_body, 1},
    {field_name, 0},
  [61] =
    {field_condition, 1},
    {field_consequence, 2},
  [63] =
    {field_body, 2},
    {field_condition, 1},
  [65] =
    {field_label, 1},
  [66] =
    {field_label, 0},
  [67] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [70] =
    {field_type, 0, .inherited = true},
  [71] =
    {field_parameters, 1},
  [72] =
    {field_declarator, 2},
    {field_type, 1, .inherited = true},
  [74] =
    {field_arguments, 2},
    {field_type, 1},
  [76] =
    {field_declarator, 2},
    {field_type, 1},
  [78] =
    {field_placement, 1},
    {field_type, 2},
  [80] =
    {field_parameters, 1},
    {field_requirements, 2},
  [82] =
    {field_declarator, 1},
    {field_type, 0, .inherited = true},
  [84] =
    {field_body, 2},
    {field_declarator, 1},
    {field_type, 0, .inherited = true},
  [87] =
    {field_declarator, 0},
    {field_value, 1},
  [89] =
    {field_body, 2},
    {field_declarator, 0},
  [91] =
    {field_argument, 0},
    {field_field, 2},
    {field_operator, 1},
  [94] =
    {field_body, 2},
    {field_captures, 0},
    {field_declarator, 1},
  [97] =
    {field_body, 2},
    {field_captures, 0},
    {field_template_parameters, 1},
  [100] =
    {field_name, 1},
    {field_name, 2},
    {field_scope, 0, .inherited = true},
  [103] =
    {field_body, 2},
    {field_declarator, 1},
  [105] =
    {field_name, 1},
    {field_value, 2},
  [107] =
    {field_name, 1},
    {field_parameters, 2},
  [109] =
    {field_condition, 1},
  [110] =
    {field_alternative, 2},
    {field_name, 1},
  [112] =
    {field_declarator, 2},
    {field_type, 0},
  [114] =
    {field_left, 0},
    {field_right, 2},
  [116] =
    {field_left, 0},
    {field_operator, 1, .inherited = true},
    {field_right, 2},
  [119] =
    {field_type, 1},
    {field_value, 3},
  [121] =
    {field_declarator, 3},
  [122] =
    {field_declarator, 2, .inherited = true},
    {field_type, 1, .inherited = true},
  [124] =
    {field_declarator, 0},
    {field_parameters, 1},
  [126] =
    {field_declarator, 0},
    {field_declarator, 1, .inherited = true},
  [128] =
    {field_arguments, 3},
    {field_type, 2},
  [130] =
    {field_declarator, 3},
    {field_type, 2},
  [132] =
    {field_placement, 2},
    {field_type, 3},
  [134] =
    {field_name, 2},
    {field_prefix, 0},
  [136] =
    {field_body, 3},
    {field_name, 2},
  [138] =
    {field_body, 3},
  [139] =
    {field_base, 3, .inherited = true},
    {field_name, 2},
  [141] =
    {field_base, 1},
  [142] =
    {field_base, 2, .inherited = true},
    {field_body, 3},
    {field_name, 1},
  [145] =
    {field_body, 2, .inherited = true},
    {field_name, 2, .inherited = true},
  [147] =
    {field_body, 2},
    {field_name, 0},
  [149] =
    {field_condition, 2},
    {field_consequence, 3},
  [151] =
    {field_alternative, 3},
    {field_condition, 1},
    {field_consequence, 2},
  [154] =
    {field_initializer, 0},
  [155] =
    {field_assembly_code, 2},
  [156] =
    {field_arguments, 3},
    {field_declarator, 2},
    {field_type, 1},
  [159] =
    {field_arguments, 3},
    {field_placement, 1},
    {field_type, 2},
  [162] =
    {field_declarator, 3},
    {field_placement, 1},
    {field_type, 2},
  [165] =
    {field_body, 3},
    {field_declarator, 2},
    {field_type, 0, .inherited = true},
  [168] =
    {field_declarator, 0},
    {field_value, 2},
  [170] =
    {field_declarator, 1},
    {field_declarator, 2, .inherited = true},
    {field_type, 0, .inherited = true},
  [173] =
    {field_declarator, 0, .inherited = true},
    {field_declarator, 1, .inherited = true},
  [175] =
    {field_body, 3},
    {field_declarator, 2},
    {field_type, 1, .inherited = true},
  [178] =
    {field_declarator, 0},
    {field_size, 2},
  [180] =
    {field_alternative, 3},
    {field_condition, 0},
  [182] =
    {field_declarator, 0},
    {field_default_value, 2},
  [184] =
    {field_size, 1},
  [185] =
    {field_body, 3},
    {field_captures, 0},
    {field_declarator, 2},
    {field_template_parameters, 1},
  [189] =
    {field_body, 3},
    {field_captures, 0},
    {field_constraint, 2},
    {field_template_parameters, 1},
  [193] =
    {field_body, 3},
    {field_declarator, 1},
  [195] =
    {field_name, 1},
    {field_parameters, 2},
    {field_value, 3},
  [198] =
    {field_alternative, 3},
    {field_condition, 1},
  [200] =
    {field_alternative, 3},
    {field_name, 1},
  [202] =
    {field_operator, 0},
  [203] =
    {field_declarator, 3},
    {field_type, 1},
  [205] =
    {field_declarator, 3, .inherited = true},
    {field_type, 2, .inherited = true},
  [207] =
    {field_arguments, 4},
    {field_declarator, 3},
    {field_type, 2},
  [210] =
    {field_arguments, 4},
    {field_placement, 2},
    {field_type, 3},
  [213] =
    {field_declarator, 4},
    {field_placement, 2},
    {field_type, 3},
  [216] =
    {field_body, 3},
    {field_name, 1},
  [218] =
    {field_body, 4},
    {field_name, 3},
  [220] =
    {field_designator, 0},
    {field_value, 2},
  [222] =
    {field_name, 0},
    {field_value, 2},
  [224] =
    {field_base, 3, .inherited = true},
    {field_body, 4},
    {field_name, 2},
  [227] =
    {field_body, 3},
    {field_name, 0},
  [229] =
    {field_body, 3, .inherited = true},
    {field_name, 3, .inherited = true},
  [231] =
    {field_declarator, 1},
    {field_type, 0, .inherited = true},
    {field_value, 2},
  [234] =
    {field_initializer, 1},
    {field_value, 2},
  [236] =
    {field_alternative, 4},
    {field_condition, 2},
    {field_consequence, 3},
  [239] =
    {field_body, 1},
    {field_condition, 3},
  [241] =
    {field_update, 2},
  [242] =
    {field_initializer, 0},
    {field_update, 2},
  [244] =
    {field_condition, 1},
    {field_initializer, 0},
  [246] =
    {field_body, 4},
    {field_condition, 2, .inherited = true},
    {field_initializer, 2, .inherited = true},
    {field_update, 2, .inherited = true},
  [250] =
    {field_body, 4},
    {field_declarator, 2, .inherited = true},
    {field_initializer, 2, .inherited = true},
    {field_right, 2, .inherited = true},
    {field_type, 2, .inherited = true},
  [255] =
    {field_value, 3},
  [256] =
    {field_operand, 1},
  [257] =
    {field_assembly_code, 2},
    {field_output_operands, 3},
  [259] =
    {field_assembly_code, 3},
  [260] =
    {field_default_type, 2},
  [261] =
    {field_default_value, 2},
    {field_type, 0, .inherited = true},
  [263] =
    {field_body, 2},
    {field_parameters, 1},
  [265] =
    {field_name, 1},
    {field_type, 3},
  [267] =
    {field_condition, 2},
  [268] =
    {field_length, 1},
  [269] =
    {field_arguments, 4},
    {field_declarator, 3},
    {field_placement, 1},
    {field_type, 2},
  [273] =
    {field_declarator, 1},
    {field_declarator, 2},
    {field_declarator, 3},
    {field_type, 0, .inherited = true},
  [277] =
    {field_declarator, 4},
  [278] =
    {field_body, 4},
    {field_declarator, 3},
    {field_type, 1, .inherited = true},
  [281] =
    {field_declarator, 0},
    {field_size, 3},
  [283] =
    {field_alternative, 4},
    {field_condition, 0},
    {field_consequence, 2},
  [286] =
    {field_size, 2},
  [287] =
    {field_body, 4},
    {field_captures, 0},
    {field_constraint, 2},
    {field_declarator, 3},
    {field_template_parameters, 1},
  [292] =
    {field_condition, 3},
    {field_consequence, 4},
  [294] =
    {field_body, 4},
    {field_declarator, 3},
    {field_type, 2, .inherited = true},
  [297] =
    {field_declarator, 1},
    {field_default_value, 3},
  [299] =
    {field_alternative, 4},
    {field_condition, 1},
  [301] =
    {field_arguments, 5},
    {field_declarator, 4},
    {field_placement, 2},
    {field_type, 3},
  [305] =
    {field_body, 2},
    {field_filter, 1},
  [307] =
    {field_body, 4},
    {field_name, 2},
  [309] =
    {field_body, 4},
  [310] =
    {field_body, 4},
    {field_name, 1},
  [312] =
    {field_declarator, 1},
    {field_default_value, 2},
    {field_type, 0, .inherited = true},
  [315] =
    {field_declarator, 1},
    {field_declarator, 2, .inherited = true},
    {field_default_value, 2, .inherited = true},
    {field_type, 0, .inherited = true},
  [319] =
    {field_declarator, 0, .inherited = true},
    {field_declarator, 1, .inherited = true},
    {field_default_value, 0, .inherited = true},
    {field_default_value, 1, .inherited = true},
  [323] =
    {field_declarator, 1},
    {field_type, 0, .inherited = true},
    {field_value, 3},
  [326] =
    {field_condition, 1},
    {field_update, 3},
  [328] =
    {field_condition, 1},
    {field_initializer, 0},
    {field_update, 3},
  [331] =
    {field_declarator, 1},
    {field_right, 3},
    {field_type, 0, .inherited = true},
  [334] =
    {field_initializer, 0},
    {field_update, 3},
  [336] =
    {field_condition, 2},
    {field_initializer, 0},
  [338] =
    {field_member, 4},
    {field_type, 2},
  [340] =
    {field_operand, 1},
    {field_operand, 2, .inherited = true},
  [342] =
    {field_assembly_code, 2},
    {field_input_operands, 4},
    {field_output_operands, 3},
  [345] =
    {field_assembly_code, 3},
    {field_output_operands, 4},
  [347] =
    {field_default_type, 3},
    {field_name, 1},
  [349] =
    {field_declarator, 1},
    {field_default_value, 3},
    {field_type, 0, .inherited = true},
  [352] =
    {field_name, 1},
    {field_type, 4},
  [354] =
    {field_declarator, 1},
    {field_declarator, 2},
    {field_declarator, 3},
  [357] =
    {field_declarator, 1},
    {field_declarator, 2},
    {field_declarator, 3},
    {field_declarator, 4, .inherited = true},
    {field_type, 0, .inherited = true},
  [362] =
    {field_alternative, 5},
    {field_condition, 3},
    {field_consequence, 4},
  [365] =
    {field_body, 5},
    {field_condition, 3, .inherited = true},
    {field_initializer, 3, .inherited = true},
    {field_update, 3, .inherited = true},
  [369] =
    {field_body, 5},
    {field_declarator, 4},
    {field_type, 2, .inherited = true},
  [372] =
    {field_body, 5},
    {field_name, 2},
  [374] =
    {field_end, 3},
    {field_start, 1},
  [376] =
    {field_declarator, 1},
    {field_default_value, 2},
  [378] =
    {field_declarator, 1},
    {field_declarator, 3, .inherited = true},
    {field_default_value, 3, .inherited = true},
    {field_type, 0, .inherited = true},
  [382] =
    {field_declarator, 1},
    {field_declarator, 3, .inherited = true},
    {field_default_value, 2},
    {field_default_value, 3, .inherited = true},
    {field_type, 0, .inherited = true},
  [387] =
    {field_condition, 2},
    {field_initializer, 0},
    {field_update, 4},
  [390] =
    {field_declarator, 2},
    {field_initializer, 0},
    {field_right, 4},
    {field_type, 1, .inherited = true},
  [394] =
    {field_operand, 0, .inherited = true},
    {field_operand, 1, .inherited = true},
  [396] =
    {field_register, 1},
  [397] =
    {field_assembly_code, 2},
    {field_clobbers, 5},
    {field_input_operands, 4},
    {field_output_operands, 3},
  [401] =
    {field_assembly_code, 3},
    {field_input_operands, 5},
    {field_output_operands, 4},
  [404] =
    {field_condition, 2},
    {field_message, 4},
  [406] =
    {field_delimiter, 1},
  [407] =
    {field_declarator, 1},
    {field_declarator, 4, .inherited = true},
    {field_default_value, 3},
    {field_default_value, 4, .inherited = true},
    {field_type, 0, .inherited = true},
  [412] =
    {field_constraint, 0},
    {field_value, 2},
  [414] =
    {field_register, 1},
    {field_register, 2, .inherited = true},
  [416] =
    {field_assembly_code, 2},
    {field_clobbers, 5},
    {field_goto_labels, 6},
    {field_input_operands, 4},
    {field_output_operands, 3},
  [421] =
    {field_assembly_code, 3},
    {field_clobbers, 6},
    {field_input_operands, 5},
    {field_output_operands, 4},
  [425] =
    {field_register, 0, .inherited = true},
    {field_register, 1, .inherited = true},
  [427] =
    {field_label, 1},
    {field_label, 2, .inherited = true},
  [429] =
    {field_assembly_code, 3},
    {field_clobbers, 6},
    {field_goto_labels, 7},
    {field_input_operands, 5},
    {field_output_operands, 4},
  [434] =
    {field_label, 0, .inherited = true},
    {field_label, 1, .inherited = true},
  [436] =
    {field_constraint, 3},
    {field_symbol, 1},
    {field_value, 5},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [1] = {
    [0] = alias_sym_type_identifier,
  },
  [15] = {
    [0] = alias_sym_namespace_identifier,
  },
  [16] = {
    [0] = alias_sym_type_identifier,
  },
  [18] = {
    [0] = alias_sym_type_identifier,
  },
  [19] = {
    [0] = alias_sym_namespace_identifier,
  },
  [35] = {
    [1] = alias_sym_type_identifier,
  },
  [36] = {
    [1] = alias_sym_type_identifier,
  },
  [42] = {
    [0] = sym_primitive_type,
  },
  [43] = {
    [0] = sym_pointer_declarator,
  },
  [53] = {
    [1] = alias_sym_statement_identifier,
  },
  [54] = {
    [0] = alias_sym_statement_identifier,
  },
  [59] = {
    [1] = alias_sym_namespace_identifier,
  },
  [60] = {
    [1] = alias_sym_namespace_identifier,
  },
  [64] = {
    [0] = alias_sym_simple_requirement,
  },
  [70] = {
    [2] = alias_sym_field_identifier,
  },
  [92] = {
    [2] = alias_sym_namespace_identifier,
  },
  [95] = {
    [1] = alias_sym_field_identifier,
  },
  [98] = {
    [1] = alias_sym_type_identifier,
  },
  [100] = {
    [0] = alias_sym_field_identifier,
  },
  [107] = {
    [1] = alias_sym_type_identifier,
  },
  [117] = {
    [0] = alias_sym_field_identifier,
  },
  [118] = {
    [1] = alias_sym_field_identifier,
  },
  [135] = {
    [3] = alias_sym_namespace_identifier,
  },
  [137] = {
    [0] = alias_sym_field_identifier,
  },
  [156] = {
    [2] = alias_sym_type_identifier,
  },
  [160] = {
    [1] = alias_sym_namespace_identifier,
    [3] = alias_sym_namespace_identifier,
  },
  [161] = {
    [1] = alias_sym_namespace_identifier,
  },
  [162] = {
    [1] = alias_sym_type_identifier,
  },
  [166] = {
    [2] = sym_semantics,
    [3] = sym_semantics,
  },
  [191] = {
    [4] = alias_sym_field_identifier,
  },
  [195] = {
    [1] = alias_sym_type_identifier,
  },
  [197] = {
    [1] = alias_sym_type_identifier,
  },
  [198] = {
    [2] = sym_semantics,
    [3] = sym_semantics,
  },
  [199] = {
    [2] = sym_semantics,
    [3] = sym_semantics,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym_pointer_type_declarator, 2,
    sym_pointer_type_declarator,
    sym_pointer_declarator,
  sym_expression_statement, 2,
    sym_expression_statement,
    alias_sym_simple_requirement,
  sym_expression, 2,
    sym_expression,
    sym_semantics,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 2,
  [4] = 2,
  [5] = 2,
  [6] = 2,
  [7] = 2,
  [8] = 2,
  [9] = 2,
  [10] = 2,
  [11] = 2,
  [12] = 2,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 14,
  [17] = 17,
  [18] = 14,
  [19] = 19,
  [20] = 20,
  [21] = 13,
  [22] = 17,
  [23] = 13,
  [24] = 24,
  [25] = 25,
  [26] = 24,
  [27] = 24,
  [28] = 24,
  [29] = 13,
  [30] = 17,
  [31] = 17,
  [32] = 14,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 34,
  [37] = 34,
  [38] = 35,
  [39] = 35,
  [40] = 34,
  [41] = 34,
  [42] = 33,
  [43] = 34,
  [44] = 35,
  [45] = 35,
  [46] = 35,
  [47] = 47,
  [48] = 48,
  [49] = 34,
  [50] = 35,
  [51] = 34,
  [52] = 34,
  [53] = 34,
  [54] = 54,
  [55] = 33,
  [56] = 35,
  [57] = 34,
  [58] = 35,
  [59] = 34,
  [60] = 54,
  [61] = 47,
  [62] = 35,
  [63] = 35,
  [64] = 34,
  [65] = 34,
  [66] = 47,
  [67] = 34,
  [68] = 35,
  [69] = 35,
  [70] = 54,
  [71] = 34,
  [72] = 35,
  [73] = 54,
  [74] = 34,
  [75] = 35,
  [76] = 35,
  [77] = 35,
  [78] = 47,
  [79] = 79,
  [80] = 80,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 83,
  [88] = 82,
  [89] = 82,
  [90] = 82,
  [91] = 84,
  [92] = 84,
  [93] = 83,
  [94] = 85,
  [95] = 83,
  [96] = 85,
  [97] = 86,
  [98] = 85,
  [99] = 86,
  [100] = 86,
  [101] = 84,
  [102] = 86,
  [103] = 85,
  [104] = 84,
  [105] = 82,
  [106] = 83,
  [107] = 107,
  [108] = 107,
  [109] = 107,
  [110] = 107,
  [111] = 107,
  [112] = 107,
  [113] = 113,
  [114] = 114,
  [115] = 114,
  [116] = 114,
  [117] = 114,
  [118] = 114,
  [119] = 114,
  [120] = 120,
  [121] = 121,
  [122] = 121,
  [123] = 121,
  [124] = 121,
  [125] = 121,
  [126] = 121,
  [127] = 127,
  [128] = 128,
  [129] = 129,
  [130] = 130,
  [131] = 131,
  [132] = 132,
  [133] = 133,
  [134] = 134,
  [135] = 135,
  [136] = 136,
  [137] = 137,
  [138] = 138,
  [139] = 139,
  [140] = 140,
  [141] = 131,
  [142] = 142,
  [143] = 143,
  [144] = 144,
  [145] = 129,
  [146] = 146,
  [147] = 147,
  [148] = 148,
  [149] = 149,
  [150] = 134,
  [151] = 130,
  [152] = 132,
  [153] = 153,
  [154] = 136,
  [155] = 128,
  [156] = 135,
  [157] = 133,
  [158] = 133,
  [159] = 135,
  [160] = 160,
  [161] = 133,
  [162] = 135,
  [163] = 163,
  [164] = 164,
  [165] = 137,
  [166] = 140,
  [167] = 138,
  [168] = 139,
  [169] = 139,
  [170] = 170,
  [171] = 171,
  [172] = 172,
  [173] = 138,
  [174] = 138,
  [175] = 139,
  [176] = 176,
  [177] = 177,
  [178] = 178,
  [179] = 179,
  [180] = 180,
  [181] = 176,
  [182] = 182,
  [183] = 183,
  [184] = 184,
  [185] = 185,
  [186] = 186,
  [187] = 187,
  [188] = 176,
  [189] = 189,
  [190] = 190,
  [191] = 191,
  [192] = 192,
  [193] = 193,
  [194] = 194,
  [195] = 195,
  [196] = 196,
  [197] = 197,
  [198] = 198,
  [199] = 199,
  [200] = 200,
  [201] = 201,
  [202] = 202,
  [203] = 203,
  [204] = 204,
  [205] = 205,
  [206] = 206,
  [207] = 207,
  [208] = 208,
  [209] = 209,
  [210] = 210,
  [211] = 211,
  [212] = 212,
  [213] = 213,
  [214] = 214,
  [215] = 215,
  [216] = 216,
  [217] = 217,
  [218] = 218,
  [219] = 219,
  [220] = 220,
  [221] = 221,
  [222] = 222,
  [223] = 223,
  [224] = 224,
  [225] = 225,
  [226] = 226,
  [227] = 227,
  [228] = 228,
  [229] = 229,
  [230] = 230,
  [231] = 231,
  [232] = 232,
  [233] = 233,
  [234] = 234,
  [235] = 235,
  [236] = 236,
  [237] = 237,
  [238] = 238,
  [239] = 142,
  [240] = 240,
  [241] = 143,
  [242] = 242,
  [243] = 148,
  [244] = 244,
  [245] = 245,
  [246] = 246,
  [247] = 247,
  [248] = 248,
  [249] = 249,
  [250] = 250,
  [251] = 251,
  [252] = 144,
  [253] = 253,
  [254] = 254,
  [255] = 255,
  [256] = 256,
  [257] = 257,
  [258] = 130,
  [259] = 259,
  [260] = 260,
  [261] = 132,
  [262] = 262,
  [263] = 131,
  [264] = 264,
  [265] = 153,
  [266] = 266,
  [267] = 267,
  [268] = 268,
  [269] = 136,
  [270] = 129,
  [271] = 128,
  [272] = 134,
  [273] = 273,
  [274] = 274,
  [275] = 275,
  [276] = 153,
  [277] = 149,
  [278] = 278,
  [279] = 279,
  [280] = 280,
  [281] = 281,
  [282] = 282,
  [283] = 283,
  [284] = 148,
  [285] = 285,
  [286] = 286,
  [287] = 287,
  [288] = 288,
  [289] = 289,
  [290] = 290,
  [291] = 291,
  [292] = 292,
  [293] = 146,
  [294] = 147,
  [295] = 295,
  [296] = 296,
  [297] = 297,
  [298] = 298,
  [299] = 299,
  [300] = 128,
  [301] = 129,
  [302] = 149,
  [303] = 303,
  [304] = 304,
  [305] = 148,
  [306] = 306,
  [307] = 144,
  [308] = 134,
  [309] = 136,
  [310] = 310,
  [311] = 144,
  [312] = 312,
  [313] = 131,
  [314] = 132,
  [315] = 315,
  [316] = 316,
  [317] = 317,
  [318] = 318,
  [319] = 130,
  [320] = 320,
  [321] = 143,
  [322] = 142,
  [323] = 323,
  [324] = 146,
  [325] = 325,
  [326] = 147,
  [327] = 143,
  [328] = 328,
  [329] = 329,
  [330] = 149,
  [331] = 142,
  [332] = 332,
  [333] = 333,
  [334] = 334,
  [335] = 335,
  [336] = 336,
  [337] = 146,
  [338] = 153,
  [339] = 147,
  [340] = 340,
  [341] = 341,
  [342] = 342,
  [343] = 343,
  [344] = 344,
  [345] = 345,
  [346] = 346,
  [347] = 347,
  [348] = 160,
  [349] = 163,
  [350] = 163,
  [351] = 160,
  [352] = 171,
  [353] = 353,
  [354] = 354,
  [355] = 355,
  [356] = 170,
  [357] = 357,
  [358] = 164,
  [359] = 354,
  [360] = 355,
  [361] = 172,
  [362] = 172,
  [363] = 363,
  [364] = 164,
  [365] = 171,
  [366] = 140,
  [367] = 357,
  [368] = 368,
  [369] = 369,
  [370] = 137,
  [371] = 137,
  [372] = 171,
  [373] = 373,
  [374] = 164,
  [375] = 354,
  [376] = 140,
  [377] = 172,
  [378] = 363,
  [379] = 170,
  [380] = 357,
  [381] = 363,
  [382] = 355,
  [383] = 170,
  [384] = 201,
  [385] = 186,
  [386] = 187,
  [387] = 195,
  [388] = 196,
  [389] = 223,
  [390] = 209,
  [391] = 210,
  [392] = 215,
  [393] = 189,
  [394] = 221,
  [395] = 220,
  [396] = 212,
  [397] = 204,
  [398] = 203,
  [399] = 200,
  [400] = 224,
  [401] = 185,
  [402] = 186,
  [403] = 187,
  [404] = 195,
  [405] = 196,
  [406] = 221,
  [407] = 220,
  [408] = 200,
  [409] = 199,
  [410] = 198,
  [411] = 193,
  [412] = 212,
  [413] = 204,
  [414] = 203,
  [415] = 191,
  [416] = 178,
  [417] = 190,
  [418] = 199,
  [419] = 198,
  [420] = 193,
  [421] = 177,
  [422] = 208,
  [423] = 223,
  [424] = 209,
  [425] = 210,
  [426] = 215,
  [427] = 229,
  [428] = 219,
  [429] = 222,
  [430] = 230,
  [431] = 225,
  [432] = 218,
  [433] = 184,
  [434] = 217,
  [435] = 227,
  [436] = 228,
  [437] = 216,
  [438] = 214,
  [439] = 213,
  [440] = 211,
  [441] = 206,
  [442] = 183,
  [443] = 205,
  [444] = 192,
  [445] = 231,
  [446] = 191,
  [447] = 197,
  [448] = 194,
  [449] = 228,
  [450] = 227,
  [451] = 451,
  [452] = 189,
  [453] = 179,
  [454] = 177,
  [455] = 180,
  [456] = 182,
  [457] = 183,
  [458] = 184,
  [459] = 184,
  [460] = 183,
  [461] = 182,
  [462] = 180,
  [463] = 229,
  [464] = 179,
  [465] = 226,
  [466] = 230,
  [467] = 225,
  [468] = 178,
  [469] = 226,
  [470] = 189,
  [471] = 182,
  [472] = 180,
  [473] = 179,
  [474] = 194,
  [475] = 197,
  [476] = 201,
  [477] = 202,
  [478] = 205,
  [479] = 206,
  [480] = 211,
  [481] = 213,
  [482] = 214,
  [483] = 216,
  [484] = 178,
  [485] = 217,
  [486] = 218,
  [487] = 231,
  [488] = 219,
  [489] = 222,
  [490] = 192,
  [491] = 190,
  [492] = 215,
  [493] = 226,
  [494] = 207,
  [495] = 225,
  [496] = 230,
  [497] = 229,
  [498] = 177,
  [499] = 223,
  [500] = 228,
  [501] = 227,
  [502] = 224,
  [503] = 207,
  [504] = 208,
  [505] = 185,
  [506] = 222,
  [507] = 190,
  [508] = 219,
  [509] = 191,
  [510] = 231,
  [511] = 193,
  [512] = 198,
  [513] = 199,
  [514] = 218,
  [515] = 217,
  [516] = 200,
  [517] = 203,
  [518] = 204,
  [519] = 212,
  [520] = 220,
  [521] = 216,
  [522] = 194,
  [523] = 197,
  [524] = 221,
  [525] = 201,
  [526] = 192,
  [527] = 224,
  [528] = 202,
  [529] = 214,
  [530] = 202,
  [531] = 185,
  [532] = 186,
  [533] = 187,
  [534] = 206,
  [535] = 213,
  [536] = 536,
  [537] = 195,
  [538] = 538,
  [539] = 196,
  [540] = 208,
  [541] = 205,
  [542] = 209,
  [543] = 210,
  [544] = 207,
  [545] = 211,
  [546] = 329,
  [547] = 281,
  [548] = 273,
  [549] = 254,
  [550] = 256,
  [551] = 264,
  [552] = 289,
  [553] = 335,
  [554] = 238,
  [555] = 317,
  [556] = 318,
  [557] = 279,
  [558] = 248,
  [559] = 320,
  [560] = 247,
  [561] = 244,
  [562] = 275,
  [563] = 264,
  [564] = 245,
  [565] = 336,
  [566] = 259,
  [567] = 340,
  [568] = 289,
  [569] = 279,
  [570] = 248,
  [571] = 242,
  [572] = 247,
  [573] = 240,
  [574] = 235,
  [575] = 234,
  [576] = 332,
  [577] = 333,
  [578] = 323,
  [579] = 288,
  [580] = 280,
  [581] = 260,
  [582] = 246,
  [583] = 244,
  [584] = 242,
  [585] = 240,
  [586] = 237,
  [587] = 236,
  [588] = 235,
  [589] = 234,
  [590] = 296,
  [591] = 318,
  [592] = 317,
  [593] = 249,
  [594] = 250,
  [595] = 320,
  [596] = 251,
  [597] = 253,
  [598] = 255,
  [599] = 273,
  [600] = 257,
  [601] = 332,
  [602] = 333,
  [603] = 323,
  [604] = 288,
  [605] = 280,
  [606] = 274,
  [607] = 262,
  [608] = 278,
  [609] = 260,
  [610] = 246,
  [611] = 262,
  [612] = 274,
  [613] = 328,
  [614] = 325,
  [615] = 266,
  [616] = 267,
  [617] = 268,
  [618] = 341,
  [619] = 346,
  [620] = 299,
  [621] = 315,
  [622] = 296,
  [623] = 232,
  [624] = 340,
  [625] = 336,
  [626] = 245,
  [627] = 334,
  [628] = 282,
  [629] = 283,
  [630] = 286,
  [631] = 334,
  [632] = 335,
  [633] = 287,
  [634] = 249,
  [635] = 250,
  [636] = 251,
  [637] = 253,
  [638] = 343,
  [639] = 290,
  [640] = 297,
  [641] = 347,
  [642] = 325,
  [643] = 254,
  [644] = 255,
  [645] = 256,
  [646] = 257,
  [647] = 298,
  [648] = 328,
  [649] = 291,
  [650] = 292,
  [651] = 304,
  [652] = 346,
  [653] = 306,
  [654] = 295,
  [655] = 237,
  [656] = 233,
  [657] = 312,
  [658] = 344,
  [659] = 278,
  [660] = 342,
  [661] = 345,
  [662] = 341,
  [663] = 259,
  [664] = 345,
  [665] = 344,
  [666] = 285,
  [667] = 238,
  [668] = 266,
  [669] = 299,
  [670] = 267,
  [671] = 315,
  [672] = 268,
  [673] = 236,
  [674] = 316,
  [675] = 316,
  [676] = 285,
  [677] = 310,
  [678] = 232,
  [679] = 281,
  [680] = 282,
  [681] = 283,
  [682] = 286,
  [683] = 287,
  [684] = 290,
  [685] = 291,
  [686] = 292,
  [687] = 347,
  [688] = 343,
  [689] = 295,
  [690] = 297,
  [691] = 298,
  [692] = 303,
  [693] = 304,
  [694] = 306,
  [695] = 233,
  [696] = 310,
  [697] = 312,
  [698] = 275,
  [699] = 329,
  [700] = 303,
  [701] = 342,
  [702] = 702,
  [703] = 703,
  [704] = 163,
  [705] = 207,
  [706] = 160,
  [707] = 278,
  [708] = 344,
  [709] = 318,
  [710] = 710,
  [711] = 298,
  [712] = 710,
  [713] = 297,
  [714] = 333,
  [715] = 341,
  [716] = 332,
  [717] = 320,
  [718] = 266,
  [719] = 719,
  [720] = 719,
  [721] = 288,
  [722] = 267,
  [723] = 296,
  [724] = 268,
  [725] = 316,
  [726] = 303,
  [727] = 719,
  [728] = 315,
  [729] = 317,
  [730] = 253,
  [731] = 299,
  [732] = 244,
  [733] = 251,
  [734] = 719,
  [735] = 710,
  [736] = 347,
  [737] = 719,
  [738] = 343,
  [739] = 280,
  [740] = 710,
  [741] = 274,
  [742] = 742,
  [743] = 304,
  [744] = 702,
  [745] = 710,
  [746] = 306,
  [747] = 747,
  [748] = 710,
  [749] = 233,
  [750] = 250,
  [751] = 249,
  [752] = 242,
  [753] = 295,
  [754] = 329,
  [755] = 275,
  [756] = 346,
  [757] = 757,
  [758] = 325,
  [759] = 719,
  [760] = 323,
  [761] = 719,
  [762] = 762,
  [763] = 710,
  [764] = 282,
  [765] = 328,
  [766] = 710,
  [767] = 238,
  [768] = 340,
  [769] = 719,
  [770] = 710,
  [771] = 710,
  [772] = 719,
  [773] = 719,
  [774] = 710,
  [775] = 719,
  [776] = 345,
  [777] = 285,
  [778] = 336,
  [779] = 310,
  [780] = 710,
  [781] = 245,
  [782] = 247,
  [783] = 262,
  [784] = 719,
  [785] = 710,
  [786] = 248,
  [787] = 232,
  [788] = 257,
  [789] = 279,
  [790] = 342,
  [791] = 281,
  [792] = 312,
  [793] = 289,
  [794] = 719,
  [795] = 334,
  [796] = 259,
  [797] = 702,
  [798] = 256,
  [799] = 710,
  [800] = 240,
  [801] = 237,
  [802] = 335,
  [803] = 719,
  [804] = 235,
  [805] = 264,
  [806] = 292,
  [807] = 255,
  [808] = 291,
  [809] = 290,
  [810] = 236,
  [811] = 287,
  [812] = 234,
  [813] = 719,
  [814] = 246,
  [815] = 254,
  [816] = 286,
  [817] = 283,
  [818] = 260,
  [819] = 710,
  [820] = 820,
  [821] = 821,
  [822] = 821,
  [823] = 823,
  [824] = 824,
  [825] = 825,
  [826] = 823,
  [827] = 827,
  [828] = 827,
  [829] = 829,
  [830] = 824,
  [831] = 821,
  [832] = 832,
  [833] = 821,
  [834] = 834,
  [835] = 835,
  [836] = 824,
  [837] = 837,
  [838] = 825,
  [839] = 839,
  [840] = 827,
  [841] = 832,
  [842] = 842,
  [843] = 829,
  [844] = 829,
  [845] = 834,
  [846] = 823,
  [847] = 837,
  [848] = 821,
  [849] = 825,
  [850] = 827,
  [851] = 824,
  [852] = 829,
  [853] = 824,
  [854] = 842,
  [855] = 835,
  [856] = 821,
  [857] = 825,
  [858] = 839,
  [859] = 842,
  [860] = 834,
  [861] = 829,
  [862] = 835,
  [863] = 825,
  [864] = 837,
  [865] = 823,
  [866] = 829,
  [867] = 832,
  [868] = 824,
  [869] = 834,
  [870] = 835,
  [871] = 839,
  [872] = 839,
  [873] = 839,
  [874] = 837,
  [875] = 827,
  [876] = 832,
  [877] = 825,
  [878] = 835,
  [879] = 823,
  [880] = 835,
  [881] = 837,
  [882] = 837,
  [883] = 832,
  [884] = 842,
  [885] = 842,
  [886] = 834,
  [887] = 823,
  [888] = 839,
  [889] = 834,
  [890] = 832,
  [891] = 827,
  [892] = 892,
  [893] = 892,
  [894] = 894,
  [895] = 894,
  [896] = 896,
  [897] = 896,
  [898] = 896,
  [899] = 896,
  [900] = 896,
  [901] = 896,
  [902] = 896,
  [903] = 894,
  [904] = 904,
  [905] = 894,
  [906] = 906,
  [907] = 907,
  [908] = 908,
  [909] = 909,
  [910] = 908,
  [911] = 909,
  [912] = 908,
  [913] = 894,
  [914] = 135,
  [915] = 908,
  [916] = 907,
  [917] = 908,
  [918] = 909,
  [919] = 133,
  [920] = 909,
  [921] = 907,
  [922] = 907,
  [923] = 907,
  [924] = 909,
  [925] = 909,
  [926] = 907,
  [927] = 907,
  [928] = 909,
  [929] = 909,
  [930] = 909,
  [931] = 907,
  [932] = 909,
  [933] = 909,
  [934] = 894,
  [935] = 907,
  [936] = 907,
  [937] = 909,
  [938] = 908,
  [939] = 907,
  [940] = 907,
  [941] = 907,
  [942] = 909,
  [943] = 908,
  [944] = 138,
  [945] = 139,
  [946] = 946,
  [947] = 894,
  [948] = 134,
  [949] = 131,
  [950] = 144,
  [951] = 143,
  [952] = 146,
  [953] = 147,
  [954] = 149,
  [955] = 148,
  [956] = 153,
  [957] = 128,
  [958] = 142,
  [959] = 136,
  [960] = 130,
  [961] = 129,
  [962] = 132,
  [963] = 963,
  [964] = 963,
  [965] = 963,
  [966] = 963,
  [967] = 963,
  [968] = 968,
  [969] = 963,
  [970] = 963,
  [971] = 963,
  [972] = 963,
  [973] = 963,
  [974] = 963,
  [975] = 963,
  [976] = 963,
  [977] = 963,
  [978] = 963,
  [979] = 963,
  [980] = 963,
  [981] = 963,
  [982] = 963,
  [983] = 963,
  [984] = 963,
  [985] = 963,
  [986] = 986,
  [987] = 987,
  [988] = 164,
  [989] = 986,
  [990] = 171,
  [991] = 172,
  [992] = 992,
  [993] = 137,
  [994] = 987,
  [995] = 986,
  [996] = 170,
  [997] = 140,
  [998] = 200,
  [999] = 228,
  [1000] = 221,
  [1001] = 206,
  [1002] = 904,
  [1003] = 205,
  [1004] = 222,
  [1005] = 219,
  [1006] = 223,
  [1007] = 179,
  [1008] = 1008,
  [1009] = 220,
  [1010] = 208,
  [1011] = 211,
  [1012] = 212,
  [1013] = 204,
  [1014] = 203,
  [1015] = 224,
  [1016] = 213,
  [1017] = 226,
  [1018] = 189,
  [1019] = 184,
  [1020] = 199,
  [1021] = 177,
  [1022] = 198,
  [1023] = 1023,
  [1024] = 201,
  [1025] = 193,
  [1026] = 225,
  [1027] = 197,
  [1028] = 946,
  [1029] = 1008,
  [1030] = 227,
  [1031] = 906,
  [1032] = 191,
  [1033] = 190,
  [1034] = 202,
  [1035] = 1008,
  [1036] = 1008,
  [1037] = 185,
  [1038] = 186,
  [1039] = 187,
  [1040] = 195,
  [1041] = 196,
  [1042] = 209,
  [1043] = 194,
  [1044] = 210,
  [1045] = 180,
  [1046] = 229,
  [1047] = 214,
  [1048] = 216,
  [1049] = 231,
  [1050] = 182,
  [1051] = 1008,
  [1052] = 215,
  [1053] = 218,
  [1054] = 183,
  [1055] = 217,
  [1056] = 178,
  [1057] = 1008,
  [1058] = 230,
  [1059] = 192,
  [1060] = 1060,
  [1061] = 894,
  [1062] = 1062,
  [1063] = 1063,
  [1064] = 1062,
  [1065] = 1063,
  [1066] = 1063,
  [1067] = 1062,
  [1068] = 1063,
  [1069] = 1063,
  [1070] = 894,
  [1071] = 894,
  [1072] = 894,
  [1073] = 894,
  [1074] = 894,
  [1075] = 1075,
  [1076] = 136,
  [1077] = 129,
  [1078] = 132,
  [1079] = 131,
  [1080] = 130,
  [1081] = 134,
  [1082] = 128,
  [1083] = 1083,
  [1084] = 1084,
  [1085] = 1085,
  [1086] = 1085,
  [1087] = 1087,
  [1088] = 1088,
  [1089] = 1089,
  [1090] = 1090,
  [1091] = 1091,
  [1092] = 1087,
  [1093] = 1087,
  [1094] = 1094,
  [1095] = 1090,
  [1096] = 1088,
  [1097] = 1097,
  [1098] = 1098,
  [1099] = 1099,
  [1100] = 1091,
  [1101] = 1101,
  [1102] = 1087,
  [1103] = 1103,
  [1104] = 1090,
  [1105] = 1090,
  [1106] = 1089,
  [1107] = 1103,
  [1108] = 1108,
  [1109] = 1108,
  [1110] = 1108,
  [1111] = 1108,
  [1112] = 320,
  [1113] = 236,
  [1114] = 1083,
  [1115] = 1115,
  [1116] = 129,
  [1117] = 134,
  [1118] = 130,
  [1119] = 129,
  [1120] = 1083,
  [1121] = 130,
  [1122] = 136,
  [1123] = 131,
  [1124] = 134,
  [1125] = 136,
  [1126] = 131,
  [1127] = 128,
  [1128] = 128,
  [1129] = 1083,
  [1130] = 1084,
  [1131] = 132,
  [1132] = 132,
  [1133] = 1084,
  [1134] = 1084,
  [1135] = 1135,
  [1136] = 1135,
  [1137] = 131,
  [1138] = 136,
  [1139] = 132,
  [1140] = 130,
  [1141] = 1084,
  [1142] = 129,
  [1143] = 134,
  [1144] = 128,
  [1145] = 1145,
  [1146] = 1146,
  [1147] = 1147,
  [1148] = 1148,
  [1149] = 1145,
  [1150] = 1147,
  [1151] = 1146,
  [1152] = 1146,
  [1153] = 1147,
  [1154] = 1145,
  [1155] = 1147,
  [1156] = 1145,
  [1157] = 1146,
  [1158] = 1147,
  [1159] = 1147,
  [1160] = 1146,
  [1161] = 1146,
  [1162] = 1147,
  [1163] = 1145,
  [1164] = 1145,
  [1165] = 1145,
  [1166] = 1145,
  [1167] = 1147,
  [1168] = 1145,
  [1169] = 1147,
  [1170] = 1170,
  [1171] = 1171,
  [1172] = 1172,
  [1173] = 1172,
  [1174] = 1172,
  [1175] = 1172,
  [1176] = 1171,
  [1177] = 1171,
  [1178] = 1172,
  [1179] = 1171,
  [1180] = 1171,
  [1181] = 1172,
  [1182] = 1171,
  [1183] = 1183,
  [1184] = 1183,
  [1185] = 1185,
  [1186] = 1183,
  [1187] = 1183,
  [1188] = 1188,
  [1189] = 1084,
  [1190] = 1188,
  [1191] = 1188,
  [1192] = 1188,
  [1193] = 1188,
  [1194] = 1188,
  [1195] = 1188,
  [1196] = 1196,
  [1197] = 1196,
  [1198] = 1196,
  [1199] = 1196,
  [1200] = 1196,
  [1201] = 1196,
  [1202] = 1196,
  [1203] = 1203,
  [1204] = 1204,
  [1205] = 1205,
  [1206] = 1203,
  [1207] = 1207,
  [1208] = 1207,
  [1209] = 1205,
  [1210] = 1210,
  [1211] = 1207,
  [1212] = 1207,
  [1213] = 1205,
  [1214] = 1203,
  [1215] = 1205,
  [1216] = 1205,
  [1217] = 1207,
  [1218] = 1207,
  [1219] = 1207,
  [1220] = 1203,
  [1221] = 1207,
  [1222] = 1204,
  [1223] = 1204,
  [1224] = 1207,
  [1225] = 1225,
  [1226] = 1226,
  [1227] = 1227,
  [1228] = 1228,
  [1229] = 1229,
  [1230] = 1230,
  [1231] = 1226,
  [1232] = 1229,
  [1233] = 1226,
  [1234] = 1229,
  [1235] = 1229,
  [1236] = 1230,
  [1237] = 1237,
  [1238] = 1226,
  [1239] = 1237,
  [1240] = 1240,
  [1241] = 1230,
  [1242] = 1230,
  [1243] = 1243,
  [1244] = 1230,
  [1245] = 1230,
  [1246] = 1226,
  [1247] = 1229,
  [1248] = 1229,
  [1249] = 1230,
  [1250] = 1237,
  [1251] = 1226,
  [1252] = 1226,
  [1253] = 1237,
  [1254] = 1226,
  [1255] = 1255,
  [1256] = 1243,
  [1257] = 1237,
  [1258] = 1230,
  [1259] = 1259,
  [1260] = 1260,
  [1261] = 1237,
  [1262] = 1237,
  [1263] = 1263,
  [1264] = 1229,
  [1265] = 1237,
  [1266] = 1226,
  [1267] = 1267,
  [1268] = 1268,
  [1269] = 1237,
  [1270] = 1237,
  [1271] = 1226,
  [1272] = 1272,
  [1273] = 1237,
  [1274] = 1274,
  [1275] = 1230,
  [1276] = 1237,
  [1277] = 1277,
  [1278] = 1230,
  [1279] = 1279,
  [1280] = 1280,
  [1281] = 1226,
  [1282] = 1282,
  [1283] = 1226,
  [1284] = 1229,
  [1285] = 1229,
  [1286] = 1243,
  [1287] = 1229,
  [1288] = 1237,
  [1289] = 1230,
  [1290] = 1229,
  [1291] = 1291,
  [1292] = 1229,
  [1293] = 1230,
  [1294] = 1226,
  [1295] = 1230,
  [1296] = 1229,
  [1297] = 1255,
  [1298] = 1298,
  [1299] = 1299,
  [1300] = 1300,
  [1301] = 1301,
  [1302] = 1302,
  [1303] = 1303,
  [1304] = 1304,
  [1305] = 1299,
  [1306] = 1306,
  [1307] = 1307,
  [1308] = 1299,
  [1309] = 1309,
  [1310] = 1299,
  [1311] = 1309,
  [1312] = 1303,
  [1313] = 1301,
  [1314] = 1084,
  [1315] = 1301,
  [1316] = 1309,
  [1317] = 1317,
  [1318] = 1301,
  [1319] = 1301,
  [1320] = 1309,
  [1321] = 1321,
  [1322] = 1322,
  [1323] = 1323,
  [1324] = 1299,
  [1325] = 1325,
  [1326] = 1301,
  [1327] = 1303,
  [1328] = 1309,
  [1329] = 1299,
  [1330] = 1330,
  [1331] = 1301,
  [1332] = 1299,
  [1333] = 1309,
  [1334] = 1309,
  [1335] = 1301,
  [1336] = 1303,
  [1337] = 1309,
  [1338] = 1309,
  [1339] = 1309,
  [1340] = 1309,
  [1341] = 1301,
  [1342] = 1301,
  [1343] = 1301,
  [1344] = 1344,
  [1345] = 1309,
  [1346] = 1346,
  [1347] = 1347,
  [1348] = 1301,
  [1349] = 1349,
  [1350] = 1350,
  [1351] = 1351,
  [1352] = 1301,
  [1353] = 1353,
  [1354] = 1303,
  [1355] = 1309,
  [1356] = 1356,
  [1357] = 1303,
  [1358] = 1358,
  [1359] = 1359,
  [1360] = 1360,
  [1361] = 1303,
  [1362] = 1362,
  [1363] = 1363,
  [1364] = 1364,
  [1365] = 1365,
  [1366] = 1366,
  [1367] = 1367,
  [1368] = 1362,
  [1369] = 1369,
  [1370] = 1370,
  [1371] = 1362,
  [1372] = 1372,
  [1373] = 1373,
  [1374] = 1363,
  [1375] = 1375,
  [1376] = 1376,
  [1377] = 1377,
  [1378] = 1363,
  [1379] = 1379,
  [1380] = 1380,
  [1381] = 1381,
  [1382] = 1382,
  [1383] = 1383,
  [1384] = 1384,
  [1385] = 1362,
  [1386] = 1386,
  [1387] = 1362,
  [1388] = 1362,
  [1389] = 1384,
  [1390] = 1390,
  [1391] = 1391,
  [1392] = 1392,
  [1393] = 1393,
  [1394] = 1394,
  [1395] = 1395,
  [1396] = 1375,
  [1397] = 1365,
  [1398] = 1398,
  [1399] = 1363,
  [1400] = 1363,
  [1401] = 1375,
  [1402] = 1402,
  [1403] = 1363,
  [1404] = 1362,
  [1405] = 1370,
  [1406] = 1406,
  [1407] = 1370,
  [1408] = 1408,
  [1409] = 1363,
  [1410] = 1382,
  [1411] = 1406,
  [1412] = 1363,
  [1413] = 1406,
  [1414] = 1382,
  [1415] = 1415,
  [1416] = 1416,
  [1417] = 1417,
  [1418] = 1418,
  [1419] = 1419,
  [1420] = 1420,
  [1421] = 1393,
  [1422] = 1394,
  [1423] = 1392,
  [1424] = 1390,
  [1425] = 1372,
  [1426] = 1384,
  [1427] = 1373,
  [1428] = 1363,
  [1429] = 1377,
  [1430] = 1430,
  [1431] = 1386,
  [1432] = 1362,
  [1433] = 1408,
  [1434] = 1415,
  [1435] = 1362,
  [1436] = 1416,
  [1437] = 1437,
  [1438] = 1417,
  [1439] = 1419,
  [1440] = 1430,
  [1441] = 1437,
  [1442] = 1442,
  [1443] = 1443,
  [1444] = 1444,
  [1445] = 1383,
  [1446] = 1381,
  [1447] = 1391,
  [1448] = 1362,
  [1449] = 1370,
  [1450] = 1384,
  [1451] = 1442,
  [1452] = 1380,
  [1453] = 1362,
  [1454] = 1443,
  [1455] = 1379,
  [1456] = 1084,
  [1457] = 1376,
  [1458] = 1402,
  [1459] = 1382,
  [1460] = 1384,
  [1461] = 1363,
  [1462] = 1444,
  [1463] = 1420,
  [1464] = 1362,
  [1465] = 1382,
  [1466] = 1366,
  [1467] = 1375,
  [1468] = 1369,
  [1469] = 1362,
  [1470] = 1470,
  [1471] = 1471,
  [1472] = 1472,
  [1473] = 1473,
  [1474] = 1474,
  [1475] = 1475,
  [1476] = 1476,
  [1477] = 1477,
  [1478] = 1478,
  [1479] = 1475,
  [1480] = 1477,
  [1481] = 1481,
  [1482] = 1482,
  [1483] = 1474,
  [1484] = 1484,
  [1485] = 1485,
  [1486] = 1477,
  [1487] = 1487,
  [1488] = 1488,
  [1489] = 1489,
  [1490] = 1472,
  [1491] = 1489,
  [1492] = 1492,
  [1493] = 1493,
  [1494] = 1494,
  [1495] = 1495,
  [1496] = 1496,
  [1497] = 1497,
  [1498] = 1498,
  [1499] = 1474,
  [1500] = 1473,
  [1501] = 1472,
  [1502] = 1470,
  [1503] = 1503,
  [1504] = 1489,
  [1505] = 1505,
  [1506] = 1506,
  [1507] = 1507,
  [1508] = 1485,
  [1509] = 1487,
  [1510] = 1494,
  [1511] = 1476,
  [1512] = 1494,
  [1513] = 1471,
  [1514] = 1494,
  [1515] = 1487,
  [1516] = 1516,
  [1517] = 1471,
  [1518] = 1474,
  [1519] = 1519,
  [1520] = 1481,
  [1521] = 1476,
  [1522] = 1477,
  [1523] = 1507,
  [1524] = 1524,
  [1525] = 1525,
  [1526] = 1475,
  [1527] = 1507,
  [1528] = 1528,
  [1529] = 1475,
  [1530] = 1530,
  [1531] = 1472,
  [1532] = 1474,
  [1533] = 1474,
  [1534] = 1516,
  [1535] = 1495,
  [1536] = 1516,
  [1537] = 1477,
  [1538] = 1538,
  [1539] = 1472,
  [1540] = 1482,
  [1541] = 1477,
  [1542] = 1474,
  [1543] = 1543,
  [1544] = 1528,
  [1545] = 1503,
  [1546] = 1525,
  [1547] = 1482,
  [1548] = 1474,
  [1549] = 1549,
  [1550] = 1550,
  [1551] = 1482,
  [1552] = 1525,
  [1553] = 1497,
  [1554] = 1554,
  [1555] = 1524,
  [1556] = 1485,
  [1557] = 1470,
  [1558] = 1519,
  [1559] = 1471,
  [1560] = 1528,
  [1561] = 1498,
  [1562] = 1475,
  [1563] = 1543,
  [1564] = 1525,
  [1565] = 1565,
  [1566] = 1528,
  [1567] = 1524,
  [1568] = 1485,
  [1569] = 1472,
  [1570] = 1470,
  [1571] = 1498,
  [1572] = 1525,
  [1573] = 1493,
  [1574] = 1492,
  [1575] = 1524,
  [1576] = 1488,
  [1577] = 1577,
  [1578] = 1484,
  [1579] = 1485,
  [1580] = 1484,
  [1581] = 1493,
  [1582] = 1470,
  [1583] = 1492,
  [1584] = 1507,
  [1585] = 1488,
  [1586] = 1565,
  [1587] = 1484,
  [1588] = 1528,
  [1589] = 1498,
  [1590] = 1519,
  [1591] = 1482,
  [1592] = 1493,
  [1593] = 1492,
  [1594] = 1488,
  [1595] = 1497,
  [1596] = 1524,
  [1597] = 1472,
  [1598] = 1492,
  [1599] = 1505,
  [1600] = 1493,
  [1601] = 1485,
  [1602] = 1484,
  [1603] = 1530,
  [1604] = 1498,
  [1605] = 1605,
  [1606] = 1506,
  [1607] = 1470,
  [1608] = 1608,
  [1609] = 1482,
  [1610] = 1473,
  [1611] = 1498,
  [1612] = 1493,
  [1613] = 1492,
  [1614] = 1488,
  [1615] = 1474,
  [1616] = 1484,
  [1617] = 1473,
  [1618] = 1472,
  [1619] = 1474,
  [1620] = 1471,
  [1621] = 1516,
  [1622] = 1524,
  [1623] = 1525,
  [1624] = 1528,
  [1625] = 1494,
  [1626] = 1475,
  [1627] = 1471,
  [1628] = 1477,
  [1629] = 1477,
  [1630] = 1482,
  [1631] = 1475,
  [1632] = 1528,
  [1633] = 1476,
  [1634] = 1471,
  [1635] = 1543,
  [1636] = 1528,
  [1637] = 1488,
  [1638] = 1525,
  [1639] = 1528,
  [1640] = 1524,
  [1641] = 1525,
  [1642] = 1481,
  [1643] = 1605,
  [1644] = 1485,
  [1645] = 1476,
  [1646] = 1477,
  [1647] = 1470,
  [1648] = 1516,
  [1649] = 1498,
  [1650] = 1519,
  [1651] = 1476,
  [1652] = 1524,
  [1653] = 1493,
  [1654] = 1497,
  [1655] = 1485,
  [1656] = 1525,
  [1657] = 1497,
  [1658] = 1524,
  [1659] = 1494,
  [1660] = 1485,
  [1661] = 1481,
  [1662] = 1484,
  [1663] = 1475,
  [1664] = 1470,
  [1665] = 1519,
  [1666] = 1492,
  [1667] = 1475,
  [1668] = 1472,
  [1669] = 1477,
  [1670] = 1494,
  [1671] = 1470,
  [1672] = 1530,
  [1673] = 1565,
  [1674] = 1495,
  [1675] = 1495,
  [1676] = 1488,
  [1677] = 1481,
  [1678] = 1516,
  [1679] = 1495,
  [1680] = 1481,
  [1681] = 1497,
  [1682] = 1493,
  [1683] = 1683,
  [1684] = 1497,
  [1685] = 1492,
  [1686] = 1488,
  [1687] = 1484,
  [1688] = 1476,
  [1689] = 1498,
  [1690] = 1495,
  [1691] = 1471,
  [1692] = 1528,
  [1693] = 1525,
  [1694] = 1524,
  [1695] = 1475,
  [1696] = 1550,
  [1697] = 1485,
  [1698] = 1482,
  [1699] = 1471,
  [1700] = 1494,
  [1701] = 1701,
  [1702] = 1470,
  [1703] = 1498,
  [1704] = 1528,
  [1705] = 1525,
  [1706] = 1477,
  [1707] = 1524,
  [1708] = 1493,
  [1709] = 1492,
  [1710] = 1488,
  [1711] = 1485,
  [1712] = 1470,
  [1713] = 1498,
  [1714] = 1493,
  [1715] = 1492,
  [1716] = 1488,
  [1717] = 1484,
  [1718] = 1543,
  [1719] = 1493,
  [1720] = 1484,
  [1721] = 1471,
  [1722] = 1497,
  [1723] = 1723,
  [1724] = 1494,
  [1725] = 1497,
  [1726] = 1519,
  [1727] = 1492,
  [1728] = 1488,
  [1729] = 1484,
  [1730] = 1475,
  [1731] = 1482,
  [1732] = 1476,
  [1733] = 1484,
  [1734] = 1494,
  [1735] = 1477,
  [1736] = 1736,
  [1737] = 1487,
  [1738] = 1488,
  [1739] = 1472,
  [1740] = 1472,
  [1741] = 1741,
  [1742] = 1507,
  [1743] = 1475,
  [1744] = 1489,
  [1745] = 1474,
  [1746] = 1492,
  [1747] = 1493,
  [1748] = 1498,
  [1749] = 1473,
  [1750] = 1494,
  [1751] = 1751,
  [1752] = 1530,
  [1753] = 1528,
  [1754] = 1503,
  [1755] = 1473,
  [1756] = 1507,
  [1757] = 1470,
  [1758] = 1485,
  [1759] = 1524,
  [1760] = 1525,
  [1761] = 1481,
  [1762] = 1528,
  [1763] = 1471,
  [1764] = 1494,
  [1765] = 1525,
  [1766] = 1472,
  [1767] = 1497,
  [1768] = 1497,
  [1769] = 1524,
  [1770] = 1478,
  [1771] = 1485,
  [1772] = 1474,
  [1773] = 1497,
  [1774] = 1497,
  [1775] = 1477,
  [1776] = 1482,
  [1777] = 1470,
  [1778] = 1778,
  [1779] = 1471,
  [1780] = 1780,
  [1781] = 1781,
  [1782] = 1495,
  [1783] = 1783,
  [1784] = 1478,
  [1785] = 1475,
  [1786] = 1471,
  [1787] = 1476,
  [1788] = 1498,
  [1789] = 1498,
  [1790] = 1482,
  [1791] = 1487,
  [1792] = 1565,
  [1793] = 1487,
  [1794] = 1794,
  [1795] = 1489,
  [1796] = 1503,
  [1797] = 1474,
  [1798] = 1472,
  [1799] = 1489,
  [1800] = 1473,
  [1801] = 1482,
  [1802] = 1494,
  [1803] = 1493,
  [1804] = 1492,
  [1805] = 1488,
  [1806] = 1530,
  [1807] = 1565,
  [1808] = 1503,
  [1809] = 1507,
  [1810] = 1484,
  [1811] = 1489,
  [1812] = 1503,
  [1813] = 1482,
  [1814] = 163,
  [1815] = 1815,
  [1816] = 1816,
  [1817] = 147,
  [1818] = 160,
  [1819] = 153,
  [1820] = 1820,
  [1821] = 207,
  [1822] = 1820,
  [1823] = 1823,
  [1824] = 1823,
  [1825] = 1825,
  [1826] = 1820,
  [1827] = 207,
  [1828] = 1823,
  [1829] = 1820,
  [1830] = 1820,
  [1831] = 1820,
  [1832] = 1820,
  [1833] = 1823,
  [1834] = 172,
  [1835] = 140,
  [1836] = 137,
  [1837] = 1837,
  [1838] = 290,
  [1839] = 242,
  [1840] = 228,
  [1841] = 227,
  [1842] = 1842,
  [1843] = 245,
  [1844] = 256,
  [1845] = 240,
  [1846] = 226,
  [1847] = 1847,
  [1848] = 296,
  [1849] = 335,
  [1850] = 334,
  [1851] = 246,
  [1852] = 1852,
  [1853] = 1853,
  [1854] = 1854,
  [1855] = 316,
  [1856] = 278,
  [1857] = 254,
  [1858] = 260,
  [1859] = 1859,
  [1860] = 262,
  [1861] = 1861,
  [1862] = 344,
  [1863] = 253,
  [1864] = 340,
  [1865] = 249,
  [1866] = 275,
  [1867] = 274,
  [1868] = 238,
  [1869] = 251,
  [1870] = 1870,
  [1871] = 1871,
  [1872] = 1872,
  [1873] = 1873,
  [1874] = 325,
  [1875] = 1875,
  [1876] = 1876,
  [1877] = 1877,
  [1878] = 1878,
  [1879] = 1879,
  [1880] = 1880,
  [1881] = 1881,
  [1882] = 190,
  [1883] = 317,
  [1884] = 1884,
  [1885] = 1885,
  [1886] = 237,
  [1887] = 310,
  [1888] = 1888,
  [1889] = 1889,
  [1890] = 303,
  [1891] = 1891,
  [1892] = 1892,
  [1893] = 208,
  [1894] = 298,
  [1895] = 1895,
  [1896] = 315,
  [1897] = 297,
  [1898] = 247,
  [1899] = 320,
  [1900] = 318,
  [1901] = 1901,
  [1902] = 185,
  [1903] = 224,
  [1904] = 295,
  [1905] = 1905,
  [1906] = 244,
  [1907] = 299,
  [1908] = 248,
  [1909] = 346,
  [1910] = 1910,
  [1911] = 292,
  [1912] = 1912,
  [1913] = 1913,
  [1914] = 219,
  [1915] = 291,
  [1916] = 191,
  [1917] = 343,
  [1918] = 287,
  [1919] = 279,
  [1920] = 1920,
  [1921] = 286,
  [1922] = 283,
  [1923] = 1923,
  [1924] = 289,
  [1925] = 347,
  [1926] = 336,
  [1927] = 1927,
  [1928] = 222,
  [1929] = 1929,
  [1930] = 236,
  [1931] = 328,
  [1932] = 1932,
  [1933] = 250,
  [1934] = 259,
  [1935] = 1935,
  [1936] = 163,
  [1937] = 1937,
  [1938] = 1938,
  [1939] = 147,
  [1940] = 1940,
  [1941] = 1941,
  [1942] = 1942,
  [1943] = 1943,
  [1944] = 1941,
  [1945] = 1943,
  [1946] = 1946,
  [1947] = 1943,
  [1948] = 160,
  [1949] = 1949,
  [1950] = 1950,
  [1951] = 1951,
  [1952] = 1941,
  [1953] = 1943,
  [1954] = 1941,
  [1955] = 1943,
  [1956] = 1956,
  [1957] = 1957,
  [1958] = 1941,
  [1959] = 163,
  [1960] = 1960,
  [1961] = 1961,
  [1962] = 1943,
  [1963] = 1963,
  [1964] = 1964,
  [1965] = 1943,
  [1966] = 153,
  [1967] = 1967,
  [1968] = 1968,
  [1969] = 147,
  [1970] = 1941,
  [1971] = 1971,
  [1972] = 1941,
  [1973] = 1973,
  [1974] = 160,
  [1975] = 153,
  [1976] = 1976,
  [1977] = 1977,
  [1978] = 1976,
  [1979] = 1976,
  [1980] = 207,
  [1981] = 207,
  [1982] = 207,
  [1983] = 207,
  [1984] = 1976,
  [1985] = 137,
  [1986] = 140,
  [1987] = 139,
  [1988] = 138,
  [1989] = 1062,
  [1990] = 172,
  [1991] = 140,
  [1992] = 137,
  [1993] = 172,
  [1994] = 298,
  [1995] = 1888,
  [1996] = 224,
  [1997] = 298,
  [1998] = 1885,
  [1999] = 297,
  [2000] = 1888,
  [2001] = 1889,
  [2002] = 316,
  [2003] = 1891,
  [2004] = 1881,
  [2005] = 1892,
  [2006] = 1895,
  [2007] = 1905,
  [2008] = 347,
  [2009] = 1912,
  [2010] = 227,
  [2011] = 1879,
  [2012] = 328,
  [2013] = 1880,
  [2014] = 1876,
  [2015] = 1875,
  [2016] = 1873,
  [2017] = 1872,
  [2018] = 1871,
  [2019] = 1932,
  [2020] = 1929,
  [2021] = 1861,
  [2022] = 1870,
  [2023] = 343,
  [2024] = 238,
  [2025] = 219,
  [2026] = 1859,
  [2027] = 1853,
  [2028] = 1923,
  [2029] = 256,
  [2030] = 1927,
  [2031] = 1837,
  [2032] = 1842,
  [2033] = 222,
  [2034] = 1920,
  [2035] = 1913,
  [2036] = 1910,
  [2037] = 1901,
  [2038] = 1847,
  [2039] = 320,
  [2040] = 1852,
  [2041] = 1854,
  [2042] = 278,
  [2043] = 226,
  [2044] = 325,
  [2045] = 208,
  [2046] = 317,
  [2047] = 228,
  [2048] = 185,
  [2049] = 244,
  [2050] = 254,
  [2051] = 259,
  [2052] = 253,
  [2053] = 251,
  [2054] = 250,
  [2055] = 249,
  [2056] = 238,
  [2057] = 283,
  [2058] = 237,
  [2059] = 286,
  [2060] = 287,
  [2061] = 236,
  [2062] = 253,
  [2063] = 290,
  [2064] = 278,
  [2065] = 317,
  [2066] = 1878,
  [2067] = 191,
  [2068] = 190,
  [2069] = 251,
  [2070] = 328,
  [2071] = 318,
  [2072] = 291,
  [2073] = 292,
  [2074] = 299,
  [2075] = 315,
  [2076] = 1847,
  [2077] = 250,
  [2078] = 249,
  [2079] = 318,
  [2080] = 245,
  [2081] = 274,
  [2082] = 262,
  [2083] = 336,
  [2084] = 340,
  [2085] = 275,
  [2086] = 334,
  [2087] = 1877,
  [2088] = 296,
  [2089] = 1901,
  [2090] = 335,
  [2091] = 296,
  [2092] = 289,
  [2093] = 279,
  [2094] = 325,
  [2095] = 1910,
  [2096] = 1913,
  [2097] = 1870,
  [2098] = 1871,
  [2099] = 1872,
  [2100] = 1873,
  [2101] = 1875,
  [2102] = 1876,
  [2103] = 1879,
  [2104] = 248,
  [2105] = 346,
  [2106] = 247,
  [2107] = 344,
  [2108] = 340,
  [2109] = 1881,
  [2110] = 1062,
  [2111] = 275,
  [2112] = 336,
  [2113] = 295,
  [2114] = 246,
  [2115] = 260,
  [2116] = 245,
  [2117] = 262,
  [2118] = 274,
  [2119] = 1837,
  [2120] = 1927,
  [2121] = 1929,
  [2122] = 347,
  [2123] = 343,
  [2124] = 1932,
  [2125] = 228,
  [2126] = 227,
  [2127] = 297,
  [2128] = 190,
  [2129] = 191,
  [2130] = 254,
  [2131] = 256,
  [2132] = 246,
  [2133] = 259,
  [2134] = 303,
  [2135] = 289,
  [2136] = 260,
  [2137] = 310,
  [2138] = 279,
  [2139] = 244,
  [2140] = 1912,
  [2141] = 1905,
  [2142] = 226,
  [2143] = 237,
  [2144] = 240,
  [2145] = 242,
  [2146] = 310,
  [2147] = 242,
  [2148] = 1895,
  [2149] = 248,
  [2150] = 299,
  [2151] = 240,
  [2152] = 1892,
  [2153] = 1891,
  [2154] = 1889,
  [2155] = 1884,
  [2156] = 303,
  [2157] = 1854,
  [2158] = 1852,
  [2159] = 247,
  [2160] = 1885,
  [2161] = 344,
  [2162] = 346,
  [2163] = 1884,
  [2164] = 1880,
  [2165] = 283,
  [2166] = 295,
  [2167] = 208,
  [2168] = 1842,
  [2169] = 1920,
  [2170] = 286,
  [2171] = 222,
  [2172] = 287,
  [2173] = 1877,
  [2174] = 315,
  [2175] = 1923,
  [2176] = 1853,
  [2177] = 1859,
  [2178] = 320,
  [2179] = 335,
  [2180] = 1861,
  [2181] = 316,
  [2182] = 219,
  [2183] = 290,
  [2184] = 291,
  [2185] = 1878,
  [2186] = 334,
  [2187] = 185,
  [2188] = 292,
  [2189] = 224,
  [2190] = 236,
  [2191] = 128,
  [2192] = 136,
  [2193] = 148,
  [2194] = 148,
  [2195] = 142,
  [2196] = 2196,
  [2197] = 2197,
  [2198] = 143,
  [2199] = 143,
  [2200] = 2200,
  [2201] = 132,
  [2202] = 134,
  [2203] = 1062,
  [2204] = 2204,
  [2205] = 144,
  [2206] = 144,
  [2207] = 137,
  [2208] = 131,
  [2209] = 142,
  [2210] = 129,
  [2211] = 130,
  [2212] = 146,
  [2213] = 2213,
  [2214] = 140,
  [2215] = 149,
  [2216] = 904,
  [2217] = 906,
  [2218] = 2218,
  [2219] = 2219,
  [2220] = 2220,
  [2221] = 146,
  [2222] = 2222,
  [2223] = 2223,
  [2224] = 2224,
  [2225] = 2225,
  [2226] = 2226,
  [2227] = 2227,
  [2228] = 149,
  [2229] = 2229,
  [2230] = 2230,
  [2231] = 130,
  [2232] = 2197,
  [2233] = 2233,
  [2234] = 139,
  [2235] = 132,
  [2236] = 134,
  [2237] = 2237,
  [2238] = 2238,
  [2239] = 2239,
  [2240] = 2240,
  [2241] = 2241,
  [2242] = 138,
  [2243] = 128,
  [2244] = 131,
  [2245] = 136,
  [2246] = 2246,
  [2247] = 2247,
  [2248] = 129,
  [2249] = 2249,
  [2250] = 2250,
  [2251] = 192,
  [2252] = 2252,
  [2253] = 223,
  [2254] = 2254,
  [2255] = 2255,
  [2256] = 2254,
  [2257] = 2254,
  [2258] = 2254,
  [2259] = 2254,
  [2260] = 2255,
  [2261] = 2255,
  [2262] = 2262,
  [2263] = 2254,
  [2264] = 2264,
  [2265] = 2254,
  [2266] = 2255,
  [2267] = 2267,
  [2268] = 1946,
  [2269] = 2269,
  [2270] = 2270,
  [2271] = 2271,
  [2272] = 2272,
  [2273] = 2273,
  [2274] = 2274,
  [2275] = 2275,
  [2276] = 2276,
  [2277] = 2277,
  [2278] = 2278,
  [2279] = 2279,
  [2280] = 2280,
  [2281] = 2281,
  [2282] = 2282,
  [2283] = 2283,
  [2284] = 2284,
  [2285] = 2285,
  [2286] = 2286,
  [2287] = 2287,
  [2288] = 2288,
  [2289] = 2289,
  [2290] = 2290,
  [2291] = 1963,
  [2292] = 2292,
  [2293] = 2293,
  [2294] = 2294,
  [2295] = 2295,
  [2296] = 2296,
  [2297] = 2297,
  [2298] = 2298,
  [2299] = 2299,
  [2300] = 2300,
  [2301] = 2301,
  [2302] = 2302,
  [2303] = 2303,
  [2304] = 2304,
  [2305] = 2305,
  [2306] = 2306,
  [2307] = 2307,
  [2308] = 2308,
  [2309] = 2308,
  [2310] = 2308,
  [2311] = 2308,
  [2312] = 2308,
  [2313] = 2308,
  [2314] = 2308,
  [2315] = 2315,
  [2316] = 2316,
  [2317] = 2317,
  [2318] = 2318,
  [2319] = 2319,
  [2320] = 2320,
  [2321] = 2321,
  [2322] = 2322,
  [2323] = 2323,
  [2324] = 2324,
  [2325] = 2325,
  [2326] = 2326,
  [2327] = 2327,
  [2328] = 2328,
  [2329] = 2329,
  [2330] = 2330,
  [2331] = 1957,
  [2332] = 2332,
  [2333] = 2333,
  [2334] = 2334,
  [2335] = 2227,
  [2336] = 2336,
  [2337] = 2316,
  [2338] = 2338,
  [2339] = 2338,
  [2340] = 2340,
  [2341] = 2341,
  [2342] = 2342,
  [2343] = 2343,
  [2344] = 2344,
  [2345] = 2345,
  [2346] = 2340,
  [2347] = 2340,
  [2348] = 2340,
  [2349] = 2340,
  [2350] = 2340,
  [2351] = 2351,
  [2352] = 2326,
  [2353] = 2338,
  [2354] = 2338,
  [2355] = 2355,
  [2356] = 2340,
  [2357] = 2357,
  [2358] = 132,
  [2359] = 138,
  [2360] = 2273,
  [2361] = 906,
  [2362] = 904,
  [2363] = 149,
  [2364] = 2334,
  [2365] = 134,
  [2366] = 131,
  [2367] = 128,
  [2368] = 2220,
  [2369] = 2369,
  [2370] = 2370,
  [2371] = 129,
  [2372] = 139,
  [2373] = 2332,
  [2374] = 2197,
  [2375] = 136,
  [2376] = 130,
  [2377] = 2355,
  [2378] = 2378,
  [2379] = 2379,
  [2380] = 2380,
  [2381] = 129,
  [2382] = 130,
  [2383] = 131,
  [2384] = 136,
  [2385] = 128,
  [2386] = 2341,
  [2387] = 134,
  [2388] = 132,
  [2389] = 1083,
  [2390] = 146,
  [2391] = 2391,
  [2392] = 132,
  [2393] = 2380,
  [2394] = 2379,
  [2395] = 130,
  [2396] = 1083,
  [2397] = 134,
  [2398] = 128,
  [2399] = 2399,
  [2400] = 131,
  [2401] = 136,
  [2402] = 129,
  [2403] = 2403,
  [2404] = 1084,
  [2405] = 149,
  [2406] = 2333,
  [2407] = 2407,
  [2408] = 2197,
  [2409] = 2326,
  [2410] = 2226,
  [2411] = 1083,
  [2412] = 2229,
  [2413] = 1083,
  [2414] = 136,
  [2415] = 1084,
  [2416] = 142,
  [2417] = 2264,
  [2418] = 2418,
  [2419] = 148,
  [2420] = 134,
  [2421] = 128,
  [2422] = 132,
  [2423] = 129,
  [2424] = 130,
  [2425] = 1083,
  [2426] = 131,
  [2427] = 143,
  [2428] = 144,
  [2429] = 2252,
  [2430] = 2249,
  [2431] = 2336,
  [2432] = 2330,
  [2433] = 1084,
  [2434] = 2282,
  [2435] = 1957,
  [2436] = 1084,
  [2437] = 2283,
  [2438] = 2270,
  [2439] = 2305,
  [2440] = 2296,
  [2441] = 1084,
  [2442] = 2303,
  [2443] = 2230,
  [2444] = 2444,
  [2445] = 2280,
  [2446] = 2289,
  [2447] = 2288,
  [2448] = 2272,
  [2449] = 2449,
  [2450] = 2287,
  [2451] = 2306,
  [2452] = 2294,
  [2453] = 192,
  [2454] = 2271,
  [2455] = 2293,
  [2456] = 2290,
  [2457] = 2285,
  [2458] = 2326,
  [2459] = 2278,
  [2460] = 2274,
  [2461] = 2226,
  [2462] = 2297,
  [2463] = 2281,
  [2464] = 1083,
  [2465] = 2295,
  [2466] = 2229,
  [2467] = 2292,
  [2468] = 2298,
  [2469] = 138,
  [2470] = 2470,
  [2471] = 2269,
  [2472] = 1963,
  [2473] = 2473,
  [2474] = 2279,
  [2475] = 2277,
  [2476] = 2262,
  [2477] = 2275,
  [2478] = 2276,
  [2479] = 223,
  [2480] = 2284,
  [2481] = 2304,
  [2482] = 2286,
  [2483] = 2307,
  [2484] = 2302,
  [2485] = 2300,
  [2486] = 139,
  [2487] = 2487,
  [2488] = 2488,
  [2489] = 146,
  [2490] = 2490,
  [2491] = 2491,
  [2492] = 2444,
  [2493] = 142,
  [2494] = 2494,
  [2495] = 143,
  [2496] = 144,
  [2497] = 2449,
  [2498] = 148,
  [2499] = 2499,
  [2500] = 2333,
  [2501] = 1946,
  [2502] = 1084,
  [2503] = 2503,
  [2504] = 2491,
  [2505] = 2505,
  [2506] = 2494,
  [2507] = 2494,
  [2508] = 2299,
  [2509] = 2344,
  [2510] = 2343,
  [2511] = 2345,
  [2512] = 2333,
  [2513] = 2239,
  [2514] = 2343,
  [2515] = 2333,
  [2516] = 2247,
  [2517] = 2490,
  [2518] = 2518,
  [2519] = 2237,
  [2520] = 2233,
  [2521] = 2345,
  [2522] = 2333,
  [2523] = 2222,
  [2524] = 2301,
  [2525] = 2490,
  [2526] = 2518,
  [2527] = 2344,
  [2528] = 2250,
  [2529] = 149,
  [2530] = 2490,
  [2531] = 2490,
  [2532] = 2333,
  [2533] = 2240,
  [2534] = 2490,
  [2535] = 2241,
  [2536] = 2246,
  [2537] = 2537,
  [2538] = 2391,
  [2539] = 2344,
  [2540] = 2540,
  [2541] = 2541,
  [2542] = 2340,
  [2543] = 2503,
  [2544] = 2316,
  [2545] = 2230,
  [2546] = 2222,
  [2547] = 2226,
  [2548] = 2249,
  [2549] = 2252,
  [2550] = 2333,
  [2551] = 2551,
  [2552] = 2329,
  [2553] = 2325,
  [2554] = 2226,
  [2555] = 2333,
  [2556] = 2499,
  [2557] = 2230,
  [2558] = 2379,
  [2559] = 2264,
  [2560] = 2345,
  [2561] = 2343,
  [2562] = 2315,
  [2563] = 2318,
  [2564] = 2324,
  [2565] = 2380,
  [2566] = 2333,
  [2567] = 2333,
  [2568] = 2317,
  [2569] = 2328,
  [2570] = 2499,
  [2571] = 2230,
  [2572] = 2321,
  [2573] = 2316,
  [2574] = 2503,
  [2575] = 2575,
  [2576] = 2403,
  [2577] = 1083,
  [2578] = 2319,
  [2579] = 2320,
  [2580] = 2327,
  [2581] = 2197,
  [2582] = 2226,
  [2583] = 2322,
  [2584] = 2340,
  [2585] = 2229,
  [2586] = 1946,
  [2587] = 2239,
  [2588] = 2588,
  [2589] = 2294,
  [2590] = 2287,
  [2591] = 2288,
  [2592] = 223,
  [2593] = 192,
  [2594] = 2286,
  [2595] = 2283,
  [2596] = 2278,
  [2597] = 2355,
  [2598] = 2282,
  [2599] = 2341,
  [2600] = 2269,
  [2601] = 2292,
  [2602] = 2295,
  [2603] = 2297,
  [2604] = 2303,
  [2605] = 2293,
  [2606] = 320,
  [2607] = 2274,
  [2608] = 2290,
  [2609] = 185,
  [2610] = 2289,
  [2611] = 2306,
  [2612] = 2262,
  [2613] = 2271,
  [2614] = 2449,
  [2615] = 2275,
  [2616] = 2285,
  [2617] = 2276,
  [2618] = 236,
  [2619] = 2619,
  [2620] = 2620,
  [2621] = 2621,
  [2622] = 2622,
  [2623] = 2237,
  [2624] = 2624,
  [2625] = 2444,
  [2626] = 2300,
  [2627] = 2627,
  [2628] = 191,
  [2629] = 190,
  [2630] = 2247,
  [2631] = 2241,
  [2632] = 1115,
  [2633] = 2302,
  [2634] = 2449,
  [2635] = 2272,
  [2636] = 2636,
  [2637] = 2637,
  [2638] = 2296,
  [2639] = 2639,
  [2640] = 2197,
  [2641] = 2307,
  [2642] = 2642,
  [2643] = 2643,
  [2644] = 2304,
  [2645] = 1083,
  [2646] = 2646,
  [2647] = 2647,
  [2648] = 2246,
  [2649] = 2233,
  [2650] = 2298,
  [2651] = 2280,
  [2652] = 2652,
  [2653] = 2240,
  [2654] = 2284,
  [2655] = 2277,
  [2656] = 2281,
  [2657] = 2305,
  [2658] = 2658,
  [2659] = 2230,
  [2660] = 2660,
  [2661] = 2270,
  [2662] = 226,
  [2663] = 2279,
  [2664] = 2444,
  [2665] = 2240,
  [2666] = 2233,
  [2667] = 2250,
  [2668] = 2301,
  [2669] = 2237,
  [2670] = 2403,
  [2671] = 2241,
  [2672] = 2247,
  [2673] = 2247,
  [2674] = 2344,
  [2675] = 2239,
  [2676] = 2343,
  [2677] = 2241,
  [2678] = 2678,
  [2679] = 2679,
  [2680] = 2380,
  [2681] = 2379,
  [2682] = 2345,
  [2683] = 2250,
  [2684] = 2355,
  [2685] = 2299,
  [2686] = 2237,
  [2687] = 1084,
  [2688] = 2380,
  [2689] = 2233,
  [2690] = 2379,
  [2691] = 2691,
  [2692] = 1083,
  [2693] = 2391,
  [2694] = 2403,
  [2695] = 2391,
  [2696] = 2341,
  [2697] = 2240,
  [2698] = 2449,
  [2699] = 2444,
  [2700] = 2503,
  [2701] = 2239,
  [2702] = 2246,
  [2703] = 2246,
  [2704] = 2499,
  [2705] = 2705,
  [2706] = 2706,
  [2707] = 2380,
  [2708] = 2708,
  [2709] = 2325,
  [2710] = 2710,
  [2711] = 2711,
  [2712] = 2712,
  [2713] = 2713,
  [2714] = 2380,
  [2715] = 2379,
  [2716] = 2197,
  [2717] = 2222,
  [2718] = 2718,
  [2719] = 2327,
  [2720] = 2320,
  [2721] = 2721,
  [2722] = 2403,
  [2723] = 2723,
  [2724] = 2328,
  [2725] = 2324,
  [2726] = 2726,
  [2727] = 2315,
  [2728] = 2380,
  [2729] = 2318,
  [2730] = 904,
  [2731] = 2317,
  [2732] = 2732,
  [2733] = 2733,
  [2734] = 2379,
  [2735] = 2321,
  [2736] = 2736,
  [2737] = 2319,
  [2738] = 2250,
  [2739] = 2226,
  [2740] = 2229,
  [2741] = 2329,
  [2742] = 2742,
  [2743] = 2743,
  [2744] = 2391,
  [2745] = 2403,
  [2746] = 906,
  [2747] = 2379,
  [2748] = 2230,
  [2749] = 2749,
  [2750] = 2750,
  [2751] = 2322,
  [2752] = 2752,
  [2753] = 2229,
  [2754] = 2754,
  [2755] = 2755,
  [2756] = 2756,
  [2757] = 2403,
  [2758] = 2391,
  [2759] = 2391,
  [2760] = 2760,
  [2761] = 2761,
  [2762] = 1961,
  [2763] = 1967,
  [2764] = 2764,
  [2765] = 2765,
  [2766] = 2766,
  [2767] = 2379,
  [2768] = 1960,
  [2769] = 1935,
  [2770] = 2770,
  [2771] = 2771,
  [2772] = 2444,
  [2773] = 2773,
  [2774] = 2316,
  [2775] = 2775,
  [2776] = 2776,
  [2777] = 2341,
  [2778] = 1949,
  [2779] = 1937,
  [2780] = 1938,
  [2781] = 1964,
  [2782] = 1950,
  [2783] = 2200,
  [2784] = 2341,
  [2785] = 2230,
  [2786] = 2786,
  [2787] = 2449,
  [2788] = 1956,
  [2789] = 2789,
  [2790] = 2790,
  [2791] = 2213,
  [2792] = 1951,
  [2793] = 2793,
  [2794] = 2794,
  [2795] = 1971,
  [2796] = 2796,
  [2797] = 2797,
  [2798] = 2798,
  [2799] = 2799,
  [2800] = 2229,
  [2801] = 2801,
  [2802] = 2802,
  [2803] = 2803,
  [2804] = 2380,
  [2805] = 2805,
  [2806] = 2806,
  [2807] = 2222,
  [2808] = 2808,
  [2809] = 2809,
  [2810] = 1940,
  [2811] = 1973,
  [2812] = 2812,
  [2813] = 2813,
  [2814] = 2814,
  [2815] = 2815,
  [2816] = 2816,
  [2817] = 2817,
  [2818] = 2818,
  [2819] = 2226,
  [2820] = 2820,
  [2821] = 2821,
  [2822] = 2822,
  [2823] = 2823,
  [2824] = 2355,
  [2825] = 2197,
  [2826] = 2826,
  [2827] = 2827,
  [2828] = 2828,
  [2829] = 2829,
  [2830] = 2830,
  [2831] = 137,
  [2832] = 2832,
  [2833] = 2833,
  [2834] = 2834,
  [2835] = 2835,
  [2836] = 2836,
  [2837] = 2837,
  [2838] = 2403,
  [2839] = 2839,
  [2840] = 2840,
  [2841] = 2841,
  [2842] = 2842,
  [2843] = 140,
  [2844] = 2844,
  [2845] = 2845,
  [2846] = 2391,
  [2847] = 2847,
  [2848] = 2848,
  [2849] = 2849,
  [2850] = 2355,
  [2851] = 1084,
  [2852] = 2852,
  [2853] = 1968,
  [2854] = 2854,
  [2855] = 2380,
  [2856] = 2343,
  [2857] = 138,
  [2858] = 2299,
  [2859] = 2379,
  [2860] = 2246,
  [2861] = 2239,
  [2862] = 2237,
  [2863] = 2316,
  [2864] = 2301,
  [2865] = 2403,
  [2866] = 2240,
  [2867] = 139,
  [2868] = 2344,
  [2869] = 2391,
  [2870] = 2345,
  [2871] = 2233,
  [2872] = 2241,
  [2873] = 2247,
  [2874] = 131,
  [2875] = 128,
  [2876] = 2325,
  [2877] = 143,
  [2878] = 132,
  [2879] = 2380,
  [2880] = 2320,
  [2881] = 136,
  [2882] = 144,
  [2883] = 148,
  [2884] = 146,
  [2885] = 2226,
  [2886] = 2327,
  [2887] = 2319,
  [2888] = 139,
  [2889] = 2315,
  [2890] = 130,
  [2891] = 142,
  [2892] = 148,
  [2893] = 142,
  [2894] = 2321,
  [2895] = 146,
  [2896] = 2241,
  [2897] = 2230,
  [2898] = 2239,
  [2899] = 138,
  [2900] = 2247,
  [2901] = 2329,
  [2902] = 143,
  [2903] = 2240,
  [2904] = 2197,
  [2905] = 2324,
  [2906] = 2391,
  [2907] = 2317,
  [2908] = 2229,
  [2909] = 144,
  [2910] = 2910,
  [2911] = 2318,
  [2912] = 2341,
  [2913] = 2913,
  [2914] = 2322,
  [2915] = 134,
  [2916] = 2355,
  [2917] = 2403,
  [2918] = 2379,
  [2919] = 2250,
  [2920] = 2222,
  [2921] = 2237,
  [2922] = 2246,
  [2923] = 129,
  [2924] = 2233,
  [2925] = 2328,
  [2926] = 2316,
  [2927] = 138,
  [2928] = 2341,
  [2929] = 2249,
  [2930] = 2487,
  [2931] = 144,
  [2932] = 149,
  [2933] = 2488,
  [2934] = 223,
  [2935] = 2264,
  [2936] = 2285,
  [2937] = 2252,
  [2938] = 146,
  [2939] = 142,
  [2940] = 2250,
  [2941] = 149,
  [2942] = 148,
  [2943] = 2262,
  [2944] = 2278,
  [2945] = 139,
  [2946] = 192,
  [2947] = 143,
  [2948] = 2355,
  [2949] = 2470,
  [2950] = 2473,
  [2951] = 2292,
  [2952] = 2910,
  [2953] = 2275,
  [2954] = 2954,
  [2955] = 2233,
  [2956] = 2956,
  [2957] = 2290,
  [2958] = 2958,
  [2959] = 2272,
  [2960] = 2304,
  [2961] = 149,
  [2962] = 2269,
  [2963] = 2294,
  [2964] = 2246,
  [2965] = 2282,
  [2966] = 2966,
  [2967] = 2967,
  [2968] = 2241,
  [2969] = 2239,
  [2970] = 2913,
  [2971] = 2307,
  [2972] = 2296,
  [2973] = 2487,
  [2974] = 2289,
  [2975] = 2237,
  [2976] = 2470,
  [2977] = 2295,
  [2978] = 2910,
  [2979] = 2380,
  [2980] = 2298,
  [2981] = 2277,
  [2982] = 139,
  [2983] = 2293,
  [2984] = 1946,
  [2985] = 2913,
  [2986] = 2986,
  [2987] = 2987,
  [2988] = 2299,
  [2989] = 2270,
  [2990] = 2403,
  [2991] = 2281,
  [2992] = 2300,
  [2993] = 138,
  [2994] = 2274,
  [2995] = 2379,
  [2996] = 2240,
  [2997] = 2297,
  [2998] = 2284,
  [2999] = 2287,
  [3000] = 3000,
  [3001] = 2303,
  [3002] = 2473,
  [3003] = 2302,
  [3004] = 2391,
  [3005] = 3005,
  [3006] = 2283,
  [3007] = 3007,
  [3008] = 2271,
  [3009] = 2288,
  [3010] = 2306,
  [3011] = 2279,
  [3012] = 2280,
  [3013] = 3013,
  [3014] = 2276,
  [3015] = 3015,
  [3016] = 3016,
  [3017] = 3017,
  [3018] = 3018,
  [3019] = 2247,
  [3020] = 2301,
  [3021] = 3021,
  [3022] = 2305,
  [3023] = 2488,
  [3024] = 2286,
  [3025] = 3025,
  [3026] = 148,
  [3027] = 128,
  [3028] = 130,
  [3029] = 146,
  [3030] = 146,
  [3031] = 142,
  [3032] = 148,
  [3033] = 3033,
  [3034] = 2355,
  [3035] = 1084,
  [3036] = 2329,
  [3037] = 3037,
  [3038] = 2325,
  [3039] = 132,
  [3040] = 2315,
  [3041] = 149,
  [3042] = 2318,
  [3043] = 131,
  [3044] = 2317,
  [3045] = 231,
  [3046] = 2775,
  [3047] = 3047,
  [3048] = 2299,
  [3049] = 136,
  [3050] = 2821,
  [3051] = 129,
  [3052] = 2319,
  [3053] = 128,
  [3054] = 134,
  [3055] = 2322,
  [3056] = 2764,
  [3057] = 2770,
  [3058] = 3058,
  [3059] = 3059,
  [3060] = 134,
  [3061] = 3061,
  [3062] = 129,
  [3063] = 2847,
  [3064] = 2841,
  [3065] = 2839,
  [3066] = 143,
  [3067] = 144,
  [3068] = 2324,
  [3069] = 136,
  [3070] = 2328,
  [3071] = 2320,
  [3072] = 2837,
  [3073] = 2327,
  [3074] = 144,
  [3075] = 143,
  [3076] = 2835,
  [3077] = 3077,
  [3078] = 2820,
  [3079] = 2321,
  [3080] = 2341,
  [3081] = 3081,
  [3082] = 2822,
  [3083] = 2250,
  [3084] = 202,
  [3085] = 2301,
  [3086] = 130,
  [3087] = 131,
  [3088] = 142,
  [3089] = 132,
  [3090] = 2322,
  [3091] = 2541,
  [3092] = 2540,
  [3093] = 3081,
  [3094] = 2790,
  [3095] = 2327,
  [3096] = 2329,
  [3097] = 2473,
  [3098] = 2325,
  [3099] = 2967,
  [3100] = 2910,
  [3101] = 2913,
  [3102] = 149,
  [3103] = 2319,
  [3104] = 2487,
  [3105] = 2318,
  [3106] = 2987,
  [3107] = 2292,
  [3108] = 2285,
  [3109] = 3025,
  [3110] = 3021,
  [3111] = 3016,
  [3112] = 3112,
  [3113] = 3015,
  [3114] = 3013,
  [3115] = 3007,
  [3116] = 2966,
  [3117] = 2986,
  [3118] = 2317,
  [3119] = 2958,
  [3120] = 3061,
  [3121] = 2249,
  [3122] = 3122,
  [3123] = 2954,
  [3124] = 3122,
  [3125] = 2488,
  [3126] = 3000,
  [3127] = 2537,
  [3128] = 2551,
  [3129] = 3018,
  [3130] = 1083,
  [3131] = 2956,
  [3132] = 2320,
  [3133] = 2278,
  [3134] = 2321,
  [3135] = 2315,
  [3136] = 2262,
  [3137] = 2575,
  [3138] = 3112,
  [3139] = 3017,
  [3140] = 2470,
  [3141] = 3112,
  [3142] = 223,
  [3143] = 2324,
  [3144] = 2264,
  [3145] = 192,
  [3146] = 3059,
  [3147] = 2252,
  [3148] = 1083,
  [3149] = 2328,
  [3150] = 3005,
  [3151] = 1946,
  [3152] = 2281,
  [3153] = 2279,
  [3154] = 3154,
  [3155] = 2444,
  [3156] = 2537,
  [3157] = 3157,
  [3158] = 2277,
  [3159] = 2575,
  [3160] = 1083,
  [3161] = 2270,
  [3162] = 2305,
  [3163] = 2304,
  [3164] = 3164,
  [3165] = 2449,
  [3166] = 3164,
  [3167] = 3157,
  [3168] = 2307,
  [3169] = 3154,
  [3170] = 2302,
  [3171] = 2301,
  [3172] = 2284,
  [3173] = 2300,
  [3174] = 2285,
  [3175] = 2643,
  [3176] = 2280,
  [3177] = 2298,
  [3178] = 3178,
  [3179] = 2276,
  [3180] = 2275,
  [3181] = 3164,
  [3182] = 3182,
  [3183] = 3157,
  [3184] = 2660,
  [3185] = 2541,
  [3186] = 2269,
  [3187] = 2282,
  [3188] = 3157,
  [3189] = 3154,
  [3190] = 3182,
  [3191] = 2249,
  [3192] = 3154,
  [3193] = 3178,
  [3194] = 2551,
  [3195] = 1084,
  [3196] = 3178,
  [3197] = 2272,
  [3198] = 2274,
  [3199] = 2296,
  [3200] = 2619,
  [3201] = 2642,
  [3202] = 2292,
  [3203] = 3178,
  [3204] = 3182,
  [3205] = 2290,
  [3206] = 2293,
  [3207] = 3164,
  [3208] = 2294,
  [3209] = 2287,
  [3210] = 2286,
  [3211] = 2588,
  [3212] = 2288,
  [3213] = 192,
  [3214] = 2264,
  [3215] = 3182,
  [3216] = 2283,
  [3217] = 223,
  [3218] = 2636,
  [3219] = 3178,
  [3220] = 3164,
  [3221] = 3154,
  [3222] = 3182,
  [3223] = 2262,
  [3224] = 2295,
  [3225] = 2297,
  [3226] = 2303,
  [3227] = 2278,
  [3228] = 3154,
  [3229] = 2299,
  [3230] = 1084,
  [3231] = 2252,
  [3232] = 2306,
  [3233] = 2289,
  [3234] = 3157,
  [3235] = 2271,
  [3236] = 2540,
  [3237] = 2444,
  [3238] = 2986,
  [3239] = 2269,
  [3240] = 2750,
  [3241] = 2588,
  [3242] = 2327,
  [3243] = 2320,
  [3244] = 2328,
  [3245] = 2750,
  [3246] = 2324,
  [3247] = 1946,
  [3248] = 2277,
  [3249] = 2986,
  [3250] = 1084,
  [3251] = 3017,
  [3252] = 2275,
  [3253] = 2298,
  [3254] = 2967,
  [3255] = 2966,
  [3256] = 2958,
  [3257] = 3017,
  [3258] = 2276,
  [3259] = 2279,
  [3260] = 2712,
  [3261] = 2305,
  [3262] = 2691,
  [3263] = 2300,
  [3264] = 2284,
  [3265] = 2302,
  [3266] = 2280,
  [3267] = 3007,
  [3268] = 2958,
  [3269] = 3013,
  [3270] = 2723,
  [3271] = 3015,
  [3272] = 2966,
  [3273] = 3016,
  [3274] = 3021,
  [3275] = 3007,
  [3276] = 3013,
  [3277] = 3015,
  [3278] = 3016,
  [3279] = 2307,
  [3280] = 3021,
  [3281] = 2304,
  [3282] = 2954,
  [3283] = 2281,
  [3284] = 3025,
  [3285] = 3018,
  [3286] = 3005,
  [3287] = 228,
  [3288] = 227,
  [3289] = 2736,
  [3290] = 2743,
  [3291] = 2956,
  [3292] = 2274,
  [3293] = 3025,
  [3294] = 2282,
  [3295] = 3018,
  [3296] = 2967,
  [3297] = 2295,
  [3298] = 2297,
  [3299] = 3122,
  [3300] = 2956,
  [3301] = 2303,
  [3302] = 2705,
  [3303] = 2289,
  [3304] = 2636,
  [3305] = 222,
  [3306] = 2710,
  [3307] = 2325,
  [3308] = 2987,
  [3309] = 2306,
  [3310] = 2271,
  [3311] = 219,
  [3312] = 2987,
  [3313] = 2283,
  [3314] = 2288,
  [3315] = 224,
  [3316] = 2329,
  [3317] = 1083,
  [3318] = 2954,
  [3319] = 3000,
  [3320] = 3000,
  [3321] = 2660,
  [3322] = 2750,
  [3323] = 2286,
  [3324] = 2287,
  [3325] = 2449,
  [3326] = 2315,
  [3327] = 2749,
  [3328] = 2294,
  [3329] = 2296,
  [3330] = 2272,
  [3331] = 208,
  [3332] = 2643,
  [3333] = 2678,
  [3334] = 2321,
  [3335] = 3005,
  [3336] = 2322,
  [3337] = 2750,
  [3338] = 2319,
  [3339] = 2270,
  [3340] = 2317,
  [3341] = 2619,
  [3342] = 2293,
  [3343] = 2642,
  [3344] = 2318,
  [3345] = 2736,
  [3346] = 3122,
  [3347] = 2290,
  [3348] = 1084,
  [3349] = 2756,
  [3350] = 2760,
  [3351] = 2252,
  [3352] = 2620,
  [3353] = 2765,
  [3354] = 3122,
  [3355] = 3355,
  [3356] = 2987,
  [3357] = 2710,
  [3358] = 1084,
  [3359] = 3059,
  [3360] = 3061,
  [3361] = 2344,
  [3362] = 2229,
  [3363] = 3122,
  [3364] = 3000,
  [3365] = 2814,
  [3366] = 2847,
  [3367] = 3367,
  [3368] = 2967,
  [3369] = 2743,
  [3370] = 3018,
  [3371] = 3025,
  [3372] = 3021,
  [3373] = 3373,
  [3374] = 3373,
  [3375] = 3016,
  [3376] = 3015,
  [3377] = 3013,
  [3378] = 3007,
  [3379] = 2966,
  [3380] = 192,
  [3381] = 2749,
  [3382] = 3017,
  [3383] = 2832,
  [3384] = 2760,
  [3385] = 2756,
  [3386] = 2958,
  [3387] = 223,
  [3388] = 2820,
  [3389] = 2835,
  [3390] = 3355,
  [3391] = 3391,
  [3392] = 2790,
  [3393] = 2837,
  [3394] = 2712,
  [3395] = 2839,
  [3396] = 2841,
  [3397] = 2723,
  [3398] = 3059,
  [3399] = 3122,
  [3400] = 3005,
  [3401] = 2621,
  [3402] = 2736,
  [3403] = 2637,
  [3404] = 2639,
  [3405] = 2956,
  [3406] = 3061,
  [3407] = 3081,
  [3408] = 2986,
  [3409] = 2343,
  [3410] = 2264,
  [3411] = 2832,
  [3412] = 2705,
  [3413] = 2954,
  [3414] = 3373,
  [3415] = 3391,
  [3416] = 3373,
  [3417] = 2292,
  [3418] = 2721,
  [3419] = 3355,
  [3420] = 3373,
  [3421] = 3373,
  [3422] = 2710,
  [3423] = 2958,
  [3424] = 3373,
  [3425] = 2764,
  [3426] = 2624,
  [3427] = 2708,
  [3428] = 3122,
  [3429] = 2652,
  [3430] = 3373,
  [3431] = 2249,
  [3432] = 2712,
  [3433] = 2756,
  [3434] = 2760,
  [3435] = 3017,
  [3436] = 2749,
  [3437] = 904,
  [3438] = 3000,
  [3439] = 2987,
  [3440] = 2262,
  [3441] = 2646,
  [3442] = 2750,
  [3443] = 2647,
  [3444] = 2713,
  [3445] = 2278,
  [3446] = 2967,
  [3447] = 3373,
  [3448] = 2658,
  [3449] = 2679,
  [3450] = 2743,
  [3451] = 3018,
  [3452] = 3025,
  [3453] = 3021,
  [3454] = 2814,
  [3455] = 3016,
  [3456] = 2345,
  [3457] = 2750,
  [3458] = 3015,
  [3459] = 3013,
  [3460] = 3007,
  [3461] = 2966,
  [3462] = 2723,
  [3463] = 2691,
  [3464] = 3005,
  [3465] = 2956,
  [3466] = 2986,
  [3467] = 2765,
  [3468] = 3081,
  [3469] = 2285,
  [3470] = 2954,
  [3471] = 906,
  [3472] = 3472,
  [3473] = 2750,
  [3474] = 2750,
  [3475] = 2761,
  [3476] = 2222,
  [3477] = 2678,
  [3478] = 2627,
  [3479] = 2622,
  [3480] = 2271,
  [3481] = 2806,
  [3482] = 2288,
  [3483] = 1967,
  [3484] = 2283,
  [3485] = 2294,
  [3486] = 2793,
  [3487] = 2794,
  [3488] = 1950,
  [3489] = 2403,
  [3490] = 904,
  [3491] = 2293,
  [3492] = 2713,
  [3493] = 2290,
  [3494] = 1964,
  [3495] = 2765,
  [3496] = 2736,
  [3497] = 1946,
  [3498] = 2345,
  [3499] = 2803,
  [3500] = 2828,
  [3501] = 2833,
  [3502] = 1950,
  [3503] = 1964,
  [3504] = 137,
  [3505] = 3122,
  [3506] = 2829,
  [3507] = 2816,
  [3508] = 2619,
  [3509] = 2790,
  [3510] = 2830,
  [3511] = 2379,
  [3512] = 137,
  [3513] = 2316,
  [3514] = 2854,
  [3515] = 2796,
  [3516] = 2742,
  [3517] = 2789,
  [3518] = 2786,
  [3519] = 3081,
  [3520] = 2755,
  [3521] = 2754,
  [3522] = 2732,
  [3523] = 2776,
  [3524] = 140,
  [3525] = 3122,
  [3526] = 2200,
  [3527] = 1938,
  [3528] = 2316,
  [3529] = 2799,
  [3530] = 2298,
  [3531] = 2624,
  [3532] = 2277,
  [3533] = 2721,
  [3534] = 2821,
  [3535] = 1973,
  [3536] = 2706,
  [3537] = 2790,
  [3538] = 2646,
  [3539] = 2764,
  [3540] = 2647,
  [3541] = 2279,
  [3542] = 1968,
  [3543] = 2627,
  [3544] = 2814,
  [3545] = 2230,
  [3546] = 2620,
  [3547] = 2621,
  [3548] = 2637,
  [3549] = 2639,
  [3550] = 2797,
  [3551] = 2658,
  [3552] = 2380,
  [3553] = 2775,
  [3554] = 2643,
  [3555] = 2222,
  [3556] = 1961,
  [3557] = 2213,
  [3558] = 1951,
  [3559] = 2842,
  [3560] = 140,
  [3561] = 1961,
  [3562] = 2815,
  [3563] = 2818,
  [3564] = 2834,
  [3565] = 2622,
  [3566] = 2282,
  [3567] = 2269,
  [3568] = 2836,
  [3569] = 2840,
  [3570] = 2805,
  [3571] = 2679,
  [3572] = 2847,
  [3573] = 2275,
  [3574] = 2276,
  [3575] = 2750,
  [3576] = 1951,
  [3577] = 1940,
  [3578] = 1971,
  [3579] = 2300,
  [3580] = 2302,
  [3581] = 2773,
  [3582] = 2307,
  [3583] = 2841,
  [3584] = 2304,
  [3585] = 2750,
  [3586] = 2750,
  [3587] = 2287,
  [3588] = 2839,
  [3589] = 2837,
  [3590] = 2835,
  [3591] = 2817,
  [3592] = 2652,
  [3593] = 2820,
  [3594] = 1968,
  [3595] = 2343,
  [3596] = 2281,
  [3597] = 2766,
  [3598] = 2771,
  [3599] = 2852,
  [3600] = 2270,
  [3601] = 2305,
  [3602] = 3061,
  [3603] = 2849,
  [3604] = 2660,
  [3605] = 2284,
  [3606] = 1938,
  [3607] = 2280,
  [3608] = 2848,
  [3609] = 2844,
  [3610] = 3059,
  [3611] = 2822,
  [3612] = 2802,
  [3613] = 2718,
  [3614] = 2226,
  [3615] = 1949,
  [3616] = 1937,
  [3617] = 1956,
  [3618] = 2711,
  [3619] = 2274,
  [3620] = 1960,
  [3621] = 1971,
  [3622] = 2832,
  [3623] = 2286,
  [3624] = 1935,
  [3625] = 2272,
  [3626] = 1967,
  [3627] = 2296,
  [3628] = 2845,
  [3629] = 2827,
  [3630] = 2344,
  [3631] = 2761,
  [3632] = 906,
  [3633] = 2798,
  [3634] = 3122,
  [3635] = 2808,
  [3636] = 2826,
  [3637] = 2636,
  [3638] = 2801,
  [3639] = 2812,
  [3640] = 2823,
  [3641] = 2770,
  [3642] = 2809,
  [3643] = 2708,
  [3644] = 3122,
  [3645] = 2295,
  [3646] = 2297,
  [3647] = 1960,
  [3648] = 2303,
  [3649] = 2391,
  [3650] = 1973,
  [3651] = 2289,
  [3652] = 1940,
  [3653] = 2306,
  [3654] = 1956,
  [3655] = 1937,
  [3656] = 1949,
  [3657] = 1935,
  [3658] = 2813,
  [3659] = 2790,
  [3660] = 2835,
  [3661] = 2837,
  [3662] = 3017,
  [3663] = 2842,
  [3664] = 131,
  [3665] = 2773,
  [3666] = 2775,
  [3667] = 2790,
  [3668] = 2760,
  [3669] = 2237,
  [3670] = 2828,
  [3671] = 2705,
  [3672] = 2766,
  [3673] = 2749,
  [3674] = 136,
  [3675] = 2247,
  [3676] = 2241,
  [3677] = 129,
  [3678] = 128,
  [3679] = 3122,
  [3680] = 2954,
  [3681] = 2803,
  [3682] = 2813,
  [3683] = 2794,
  [3684] = 2793,
  [3685] = 2806,
  [3686] = 2986,
  [3687] = 3687,
  [3688] = 1940,
  [3689] = 2755,
  [3690] = 130,
  [3691] = 1973,
  [3692] = 1950,
  [3693] = 1964,
  [3694] = 3694,
  [3695] = 2449,
  [3696] = 2233,
  [3697] = 1971,
  [3698] = 2444,
  [3699] = 2213,
  [3700] = 1961,
  [3701] = 2956,
  [3702] = 2756,
  [3703] = 2832,
  [3704] = 132,
  [3705] = 2812,
  [3706] = 2815,
  [3707] = 2827,
  [3708] = 3122,
  [3709] = 2987,
  [3710] = 2830,
  [3711] = 2836,
  [3712] = 2829,
  [3713] = 2826,
  [3714] = 139,
  [3715] = 3715,
  [3716] = 2801,
  [3717] = 2239,
  [3718] = 2200,
  [3719] = 2771,
  [3720] = 2798,
  [3721] = 2246,
  [3722] = 2776,
  [3723] = 2802,
  [3724] = 2818,
  [3725] = 1084,
  [3726] = 2849,
  [3727] = 2848,
  [3728] = 2240,
  [3729] = 2844,
  [3730] = 134,
  [3731] = 2854,
  [3732] = 2816,
  [3733] = 2765,
  [3734] = 2823,
  [3735] = 2742,
  [3736] = 2790,
  [3737] = 2852,
  [3738] = 2789,
  [3739] = 3005,
  [3740] = 2833,
  [3741] = 2754,
  [3742] = 2790,
  [3743] = 2814,
  [3744] = 1951,
  [3745] = 3122,
  [3746] = 137,
  [3747] = 2840,
  [3748] = 2764,
  [3749] = 2706,
  [3750] = 2817,
  [3751] = 1960,
  [3752] = 1935,
  [3753] = 140,
  [3754] = 2822,
  [3755] = 2821,
  [3756] = 3122,
  [3757] = 2834,
  [3758] = 2967,
  [3759] = 2743,
  [3760] = 2197,
  [3761] = 2750,
  [3762] = 2723,
  [3763] = 2718,
  [3764] = 2711,
  [3765] = 3018,
  [3766] = 2732,
  [3767] = 138,
  [3768] = 3000,
  [3769] = 2770,
  [3770] = 1938,
  [3771] = 2712,
  [3772] = 2809,
  [3773] = 2808,
  [3774] = 3025,
  [3775] = 2958,
  [3776] = 2845,
  [3777] = 2786,
  [3778] = 3021,
  [3779] = 2796,
  [3780] = 2966,
  [3781] = 2797,
  [3782] = 1967,
  [3783] = 3016,
  [3784] = 2820,
  [3785] = 3015,
  [3786] = 2799,
  [3787] = 1968,
  [3788] = 2839,
  [3789] = 3007,
  [3790] = 2841,
  [3791] = 3122,
  [3792] = 2847,
  [3793] = 2805,
  [3794] = 3122,
  [3795] = 2790,
  [3796] = 1949,
  [3797] = 1937,
  [3798] = 1956,
  [3799] = 3013,
  [3800] = 131,
  [3801] = 132,
  [3802] = 3059,
  [3803] = 2705,
  [3804] = 3061,
  [3805] = 143,
  [3806] = 144,
  [3807] = 2449,
  [3808] = 148,
  [3809] = 3081,
  [3810] = 2355,
  [3811] = 142,
  [3812] = 2444,
  [3813] = 2250,
  [3814] = 146,
  [3815] = 130,
  [3816] = 129,
  [3817] = 136,
  [3818] = 3818,
  [3819] = 2341,
  [3820] = 128,
  [3821] = 1084,
  [3822] = 3687,
  [3823] = 3715,
  [3824] = 3824,
  [3825] = 134,
  [3826] = 2708,
  [3827] = 2403,
  [3828] = 2391,
  [3829] = 2380,
  [3830] = 2379,
  [3831] = 2836,
  [3832] = 1961,
  [3833] = 3833,
  [3834] = 140,
  [3835] = 3835,
  [3836] = 2771,
  [3837] = 3833,
  [3838] = 3835,
  [3839] = 3833,
  [3840] = 3840,
  [3841] = 1964,
  [3842] = 2793,
  [3843] = 2794,
  [3844] = 3835,
  [3845] = 2802,
  [3846] = 3833,
  [3847] = 3835,
  [3848] = 2487,
  [3849] = 2844,
  [3850] = 1950,
  [3851] = 3840,
  [3852] = 2822,
  [3853] = 3840,
  [3854] = 3833,
  [3855] = 2840,
  [3856] = 3856,
  [3857] = 2380,
  [3858] = 2379,
  [3859] = 3859,
  [3860] = 2803,
  [3861] = 3861,
  [3862] = 2403,
  [3863] = 2817,
  [3864] = 1938,
  [3865] = 2391,
  [3866] = 3833,
  [3867] = 3835,
  [3868] = 3856,
  [3869] = 2200,
  [3870] = 2470,
  [3871] = 139,
  [3872] = 1951,
  [3873] = 2786,
  [3874] = 2488,
  [3875] = 2796,
  [3876] = 1967,
  [3877] = 2712,
  [3878] = 2379,
  [3879] = 2803,
  [3880] = 3840,
  [3881] = 1949,
  [3882] = 3882,
  [3883] = 1937,
  [3884] = 3884,
  [3885] = 3840,
  [3886] = 3886,
  [3887] = 3856,
  [3888] = 3840,
  [3889] = 3886,
  [3890] = 2815,
  [3891] = 3122,
  [3892] = 3859,
  [3893] = 1956,
  [3894] = 3840,
  [3895] = 2797,
  [3896] = 2806,
  [3897] = 3856,
  [3898] = 3886,
  [3899] = 2808,
  [3900] = 2809,
  [3901] = 2813,
  [3902] = 2749,
  [3903] = 3886,
  [3904] = 3856,
  [3905] = 2723,
  [3906] = 2828,
  [3907] = 3886,
  [3908] = 3122,
  [3909] = 3856,
  [3910] = 2823,
  [3911] = 3886,
  [3912] = 3856,
  [3913] = 138,
  [3914] = 3886,
  [3915] = 2821,
  [3916] = 3884,
  [3917] = 3856,
  [3918] = 2827,
  [3919] = 3882,
  [3920] = 3886,
  [3921] = 3882,
  [3922] = 3859,
  [3923] = 2829,
  [3924] = 3884,
  [3925] = 2380,
  [3926] = 3840,
  [3927] = 3859,
  [3928] = 2845,
  [3929] = 3884,
  [3930] = 2743,
  [3931] = 2756,
  [3932] = 2830,
  [3933] = 1971,
  [3934] = 2818,
  [3935] = 2213,
  [3936] = 3886,
  [3937] = 3859,
  [3938] = 2760,
  [3939] = 2826,
  [3940] = 2845,
  [3941] = 3882,
  [3942] = 3835,
  [3943] = 3884,
  [3944] = 2833,
  [3945] = 2852,
  [3946] = 2766,
  [3947] = 3884,
  [3948] = 2812,
  [3949] = 3859,
  [3950] = 1973,
  [3951] = 2817,
  [3952] = 3859,
  [3953] = 1940,
  [3954] = 3856,
  [3955] = 2403,
  [3956] = 3884,
  [3957] = 137,
  [3958] = 3882,
  [3959] = 2708,
  [3960] = 2770,
  [3961] = 2773,
  [3962] = 2834,
  [3963] = 1935,
  [3964] = 2473,
  [3965] = 1960,
  [3966] = 3859,
  [3967] = 2848,
  [3968] = 1968,
  [3969] = 3859,
  [3970] = 2391,
  [3971] = 3840,
  [3972] = 3972,
  [3973] = 3973,
  [3974] = 3882,
  [3975] = 3884,
  [3976] = 2849,
  [3977] = 3884,
  [3978] = 3840,
  [3979] = 2842,
  [3980] = 2775,
  [3981] = 2771,
  [3982] = 149,
  [3983] = 3840,
  [3984] = 2815,
  [3985] = 2818,
  [3986] = 2813,
  [3987] = 3987,
  [3988] = 3987,
  [3989] = 2836,
  [3990] = 3987,
  [3991] = 3987,
  [3992] = 2809,
  [3993] = 2833,
  [3994] = 2852,
  [3995] = 3687,
  [3996] = 3715,
  [3997] = 3987,
  [3998] = 2766,
  [3999] = 2808,
  [4000] = 3987,
  [4001] = 2793,
  [4002] = 2794,
  [4003] = 2828,
  [4004] = 3987,
  [4005] = 2840,
  [4006] = 4006,
  [4007] = 2299,
  [4008] = 2806,
  [4009] = 2848,
  [4010] = 3987,
  [4011] = 3987,
  [4012] = 2797,
  [4013] = 4013,
  [4014] = 2379,
  [4015] = 2403,
  [4016] = 2773,
  [4017] = 2786,
  [4018] = 2812,
  [4019] = 2844,
  [4020] = 2222,
  [4021] = 2849,
  [4022] = 2796,
  [4023] = 2301,
  [4024] = 2834,
  [4025] = 2802,
  [4026] = 3987,
  [4027] = 2391,
  [4028] = 2826,
  [4029] = 2842,
  [4030] = 3987,
  [4031] = 2341,
  [4032] = 2355,
  [4033] = 2829,
  [4034] = 2823,
  [4035] = 3987,
  [4036] = 2830,
  [4037] = 2380,
  [4038] = 2827,
  [4039] = 3987,
  [4040] = 2473,
  [4041] = 4041,
  [4042] = 2320,
  [4043] = 2327,
  [4044] = 2321,
  [4045] = 2324,
  [4046] = 4046,
  [4047] = 4046,
  [4048] = 2315,
  [4049] = 3687,
  [4050] = 4046,
  [4051] = 4046,
  [4052] = 2328,
  [4053] = 3715,
  [4054] = 4041,
  [4055] = 4041,
  [4056] = 4056,
  [4057] = 4046,
  [4058] = 2636,
  [4059] = 2487,
  [4060] = 2470,
  [4061] = 2322,
  [4062] = 4056,
  [4063] = 4056,
  [4064] = 4041,
  [4065] = 2318,
  [4066] = 4041,
  [4067] = 4013,
  [4068] = 2660,
  [4069] = 4056,
  [4070] = 2643,
  [4071] = 2316,
  [4072] = 2329,
  [4073] = 2619,
  [4074] = 4056,
  [4075] = 2317,
  [4076] = 2325,
  [4077] = 2488,
  [4078] = 2319,
  [4079] = 2262,
  [4080] = 4080,
  [4081] = 2249,
  [4082] = 4082,
  [4083] = 2292,
  [4084] = 2252,
  [4085] = 2285,
  [4086] = 139,
  [4087] = 192,
  [4088] = 4088,
  [4089] = 2264,
  [4090] = 3715,
  [4091] = 3715,
  [4092] = 138,
  [4093] = 3687,
  [4094] = 2278,
  [4095] = 223,
  [4096] = 3687,
  [4097] = 4082,
  [4098] = 4098,
  [4099] = 4099,
  [4100] = 4098,
  [4101] = 4101,
  [4102] = 2277,
  [4103] = 2470,
  [4104] = 2293,
  [4105] = 4101,
  [4106] = 2298,
  [4107] = 2280,
  [4108] = 2487,
  [4109] = 2272,
  [4110] = 4099,
  [4111] = 4098,
  [4112] = 2307,
  [4113] = 3715,
  [4114] = 2304,
  [4115] = 2488,
  [4116] = 2296,
  [4117] = 2281,
  [4118] = 2274,
  [4119] = 2269,
  [4120] = 2282,
  [4121] = 4121,
  [4122] = 4099,
  [4123] = 4123,
  [4124] = 4124,
  [4125] = 2341,
  [4126] = 4126,
  [4127] = 4098,
  [4128] = 2355,
  [4129] = 4099,
  [4130] = 4121,
  [4131] = 2283,
  [4132] = 4099,
  [4133] = 4099,
  [4134] = 2473,
  [4135] = 2275,
  [4136] = 4121,
  [4137] = 4098,
  [4138] = 4098,
  [4139] = 4098,
  [4140] = 4121,
  [4141] = 3715,
  [4142] = 3687,
  [4143] = 4088,
  [4144] = 2271,
  [4145] = 2306,
  [4146] = 4121,
  [4147] = 2294,
  [4148] = 2276,
  [4149] = 2289,
  [4150] = 2279,
  [4151] = 3687,
  [4152] = 4101,
  [4153] = 2303,
  [4154] = 2270,
  [4155] = 4121,
  [4156] = 2288,
  [4157] = 4101,
  [4158] = 2287,
  [4159] = 3687,
  [4160] = 4101,
  [4161] = 2286,
  [4162] = 2297,
  [4163] = 2302,
  [4164] = 2290,
  [4165] = 4080,
  [4166] = 2295,
  [4167] = 3715,
  [4168] = 2305,
  [4169] = 4101,
  [4170] = 2300,
  [4171] = 2284,
  [4172] = 4099,
  [4173] = 4121,
  [4174] = 4101,
  [4175] = 2956,
  [4176] = 2822,
  [4177] = 3715,
  [4178] = 2987,
  [4179] = 2821,
  [4180] = 3017,
  [4181] = 2770,
  [4182] = 4182,
  [4183] = 2488,
  [4184] = 3687,
  [4185] = 2470,
  [4186] = 139,
  [4187] = 3000,
  [4188] = 2967,
  [4189] = 3018,
  [4190] = 3025,
  [4191] = 3021,
  [4192] = 3016,
  [4193] = 3015,
  [4194] = 3013,
  [4195] = 4182,
  [4196] = 3007,
  [4197] = 4197,
  [4198] = 2986,
  [4199] = 3005,
  [4200] = 2473,
  [4201] = 2966,
  [4202] = 138,
  [4203] = 4123,
  [4204] = 2487,
  [4205] = 4124,
  [4206] = 2954,
  [4207] = 2775,
  [4208] = 2958,
  [4209] = 3061,
  [4210] = 4210,
  [4211] = 4211,
  [4212] = 4212,
  [4213] = 2636,
  [4214] = 4210,
  [4215] = 3715,
  [4216] = 2619,
  [4217] = 4217,
  [4218] = 2643,
  [4219] = 4219,
  [4220] = 2222,
  [4221] = 4221,
  [4222] = 2316,
  [4223] = 4223,
  [4224] = 3059,
  [4225] = 4212,
  [4226] = 3687,
  [4227] = 4211,
  [4228] = 3081,
  [4229] = 4088,
  [4230] = 4080,
  [4231] = 4231,
  [4232] = 2660,
  [4233] = 4217,
  [4234] = 4234,
  [4235] = 2213,
  [4236] = 2230,
  [4237] = 3081,
  [4238] = 4088,
  [4239] = 4219,
  [4240] = 3061,
  [4241] = 2200,
  [4242] = 4231,
  [4243] = 4080,
  [4244] = 2222,
  [4245] = 4223,
  [4246] = 4246,
  [4247] = 2226,
  [4248] = 2200,
  [4249] = 3687,
  [4250] = 3059,
  [4251] = 2213,
  [4252] = 2197,
  [4253] = 4246,
  [4254] = 4221,
  [4255] = 4246,
  [4256] = 3715,
  [4257] = 3715,
  [4258] = 3687,
  [4259] = 2954,
  [4260] = 4260,
  [4261] = 4088,
  [4262] = 3016,
  [4263] = 2986,
  [4264] = 4080,
  [4265] = 1968,
  [4266] = 3025,
  [4267] = 2987,
  [4268] = 1949,
  [4269] = 3021,
  [4270] = 4234,
  [4271] = 3017,
  [4272] = 2226,
  [4273] = 140,
  [4274] = 1964,
  [4275] = 1940,
  [4276] = 2967,
  [4277] = 1937,
  [4278] = 1956,
  [4279] = 3018,
  [4280] = 1960,
  [4281] = 1935,
  [4282] = 137,
  [4283] = 4088,
  [4284] = 3005,
  [4285] = 138,
  [4286] = 2316,
  [4287] = 2966,
  [4288] = 1938,
  [4289] = 3007,
  [4290] = 4234,
  [4291] = 2230,
  [4292] = 1971,
  [4293] = 4080,
  [4294] = 4294,
  [4295] = 3013,
  [4296] = 4296,
  [4297] = 2197,
  [4298] = 4294,
  [4299] = 139,
  [4300] = 1951,
  [4301] = 1950,
  [4302] = 1967,
  [4303] = 3015,
  [4304] = 1973,
  [4305] = 1961,
  [4306] = 2958,
  [4307] = 3000,
  [4308] = 2956,
  [4309] = 2247,
  [4310] = 4310,
  [4311] = 2239,
  [4312] = 2233,
  [4313] = 4080,
  [4314] = 4314,
  [4315] = 4315,
  [4316] = 2619,
  [4317] = 4317,
  [4318] = 4318,
  [4319] = 4080,
  [4320] = 2240,
  [4321] = 4321,
  [4322] = 4322,
  [4323] = 4321,
  [4324] = 4223,
  [4325] = 4321,
  [4326] = 2250,
  [4327] = 4321,
  [4328] = 4328,
  [4329] = 4329,
  [4330] = 4330,
  [4331] = 4331,
  [4332] = 2643,
  [4333] = 4321,
  [4334] = 4334,
  [4335] = 2660,
  [4336] = 4336,
  [4337] = 4337,
  [4338] = 4321,
  [4339] = 4339,
  [4340] = 4321,
  [4341] = 4322,
  [4342] = 4321,
  [4343] = 4314,
  [4344] = 4310,
  [4345] = 4317,
  [4346] = 4317,
  [4347] = 1946,
  [4348] = 4321,
  [4349] = 4314,
  [4350] = 4318,
  [4351] = 3687,
  [4352] = 4322,
  [4353] = 4088,
  [4354] = 2241,
  [4355] = 4355,
  [4356] = 2636,
  [4357] = 2954,
  [4358] = 139,
  [4359] = 4359,
  [4360] = 3000,
  [4361] = 4318,
  [4362] = 4314,
  [4363] = 4318,
  [4364] = 4314,
  [4365] = 2237,
  [4366] = 4314,
  [4367] = 4317,
  [4368] = 4088,
  [4369] = 3715,
  [4370] = 4370,
  [4371] = 4322,
  [4372] = 4321,
  [4373] = 4219,
  [4374] = 4355,
  [4375] = 4375,
  [4376] = 4321,
  [4377] = 2987,
  [4378] = 4378,
  [4379] = 4318,
  [4380] = 4331,
  [4381] = 4331,
  [4382] = 4331,
  [4383] = 4383,
  [4384] = 4331,
  [4385] = 4318,
  [4386] = 2246,
  [4387] = 4331,
  [4388] = 4321,
  [4389] = 4331,
  [4390] = 4390,
  [4391] = 4321,
  [4392] = 2967,
  [4393] = 3018,
  [4394] = 4231,
  [4395] = 4088,
  [4396] = 3025,
  [4397] = 4321,
  [4398] = 2986,
  [4399] = 4322,
  [4400] = 3021,
  [4401] = 4322,
  [4402] = 3016,
  [4403] = 3015,
  [4404] = 3013,
  [4405] = 3007,
  [4406] = 2966,
  [4407] = 4337,
  [4408] = 4321,
  [4409] = 4321,
  [4410] = 2958,
  [4411] = 4317,
  [4412] = 4314,
  [4413] = 138,
  [4414] = 4080,
  [4415] = 3017,
  [4416] = 4336,
  [4417] = 4321,
  [4418] = 4337,
  [4419] = 4321,
  [4420] = 4317,
  [4421] = 2956,
  [4422] = 4321,
  [4423] = 4321,
  [4424] = 4321,
  [4425] = 4321,
  [4426] = 4221,
  [4427] = 4331,
  [4428] = 4318,
  [4429] = 3005,
  [4430] = 4331,
  [4431] = 2967,
  [4432] = 4432,
  [4433] = 2956,
  [4434] = 2954,
  [4435] = 3005,
  [4436] = 2986,
  [4437] = 2958,
  [4438] = 2966,
  [4439] = 3007,
  [4440] = 3013,
  [4441] = 3015,
  [4442] = 3016,
  [4443] = 3021,
  [4444] = 3025,
  [4445] = 3018,
  [4446] = 4446,
  [4447] = 2987,
  [4448] = 4448,
  [4449] = 3000,
  [4450] = 4450,
  [4451] = 2954,
  [4452] = 1963,
  [4453] = 4453,
  [4454] = 4454,
  [4455] = 4455,
  [4456] = 2222,
  [4457] = 4457,
  [4458] = 2712,
  [4459] = 4450,
  [4460] = 4460,
  [4461] = 4432,
  [4462] = 2956,
  [4463] = 4454,
  [4464] = 4432,
  [4465] = 2316,
  [4466] = 3017,
  [4467] = 1084,
  [4468] = 3005,
  [4469] = 4454,
  [4470] = 4432,
  [4471] = 4471,
  [4472] = 1957,
  [4473] = 4454,
  [4474] = 4453,
  [4475] = 4475,
  [4476] = 4329,
  [4477] = 4477,
  [4478] = 4197,
  [4479] = 4479,
  [4480] = 4480,
  [4481] = 4454,
  [4482] = 4482,
  [4483] = 4080,
  [4484] = 4450,
  [4485] = 4485,
  [4486] = 2958,
  [4487] = 4454,
  [4488] = 2966,
  [4489] = 3081,
  [4490] = 3007,
  [4491] = 4432,
  [4492] = 4492,
  [4493] = 4493,
  [4494] = 4454,
  [4495] = 4495,
  [4496] = 2237,
  [4497] = 2247,
  [4498] = 2241,
  [4499] = 3391,
  [4500] = 4485,
  [4501] = 4454,
  [4502] = 4502,
  [4503] = 2239,
  [4504] = 2246,
  [4505] = 4454,
  [4506] = 4506,
  [4507] = 3013,
  [4508] = 2986,
  [4509] = 4482,
  [4510] = 2233,
  [4511] = 4453,
  [4512] = 4512,
  [4513] = 2954,
  [4514] = 4453,
  [4515] = 2240,
  [4516] = 3015,
  [4517] = 3016,
  [4518] = 2705,
  [4519] = 3021,
  [4520] = 4088,
  [4521] = 3059,
  [4522] = 4454,
  [4523] = 3061,
  [4524] = 3025,
  [4525] = 4453,
  [4526] = 2986,
  [4527] = 3018,
  [4528] = 2723,
  [4529] = 2956,
  [4530] = 2967,
  [4531] = 4531,
  [4532] = 4454,
  [4533] = 4533,
  [4534] = 2743,
  [4535] = 4492,
  [4536] = 4223,
  [4537] = 4479,
  [4538] = 4219,
  [4539] = 4432,
  [4540] = 4234,
  [4541] = 4454,
  [4542] = 2987,
  [4543] = 2222,
  [4544] = 4231,
  [4545] = 4545,
  [4546] = 4546,
  [4547] = 3005,
  [4548] = 4548,
  [4549] = 2222,
  [4550] = 2987,
  [4551] = 4450,
  [4552] = 3000,
  [4553] = 4553,
  [4554] = 2756,
  [4555] = 2760,
  [4556] = 3017,
  [4557] = 2723,
  [4558] = 2749,
  [4559] = 4559,
  [4560] = 4432,
  [4561] = 4450,
  [4562] = 4562,
  [4563] = 2749,
  [4564] = 2760,
  [4565] = 2958,
  [4566] = 2966,
  [4567] = 3007,
  [4568] = 2756,
  [4569] = 3013,
  [4570] = 3015,
  [4571] = 3016,
  [4572] = 3021,
  [4573] = 3025,
  [4574] = 3018,
  [4575] = 2743,
  [4576] = 2967,
  [4577] = 4221,
  [4578] = 4454,
  [4579] = 2229,
  [4580] = 4580,
  [4581] = 3000,
  [4582] = 2712,
  [4583] = 3017,
  [4584] = 4453,
  [4585] = 4585,
  [4586] = 4586,
  [4587] = 4586,
  [4588] = 2229,
  [4589] = 4589,
  [4590] = 4585,
  [4591] = 4591,
  [4592] = 4592,
  [4593] = 4593,
  [4594] = 4594,
  [4595] = 4221,
  [4596] = 4593,
  [4597] = 4597,
  [4598] = 2355,
  [4599] = 4599,
  [4600] = 2341,
  [4601] = 4592,
  [4602] = 4593,
  [4603] = 4592,
  [4604] = 4231,
  [4605] = 4605,
  [4606] = 4606,
  [4607] = 4219,
  [4608] = 4591,
  [4609] = 4589,
  [4610] = 4610,
  [4611] = 4585,
  [4612] = 4612,
  [4613] = 4594,
  [4614] = 4614,
  [4615] = 4610,
  [4616] = 4610,
  [4617] = 4591,
  [4618] = 4618,
  [4619] = 4610,
  [4620] = 4620,
  [4621] = 4610,
  [4622] = 4622,
  [4623] = 4610,
  [4624] = 4597,
  [4625] = 2721,
  [4626] = 4620,
  [4627] = 4593,
  [4628] = 4586,
  [4629] = 4599,
  [4630] = 4592,
  [4631] = 4593,
  [4632] = 4597,
  [4633] = 4620,
  [4634] = 4586,
  [4635] = 4586,
  [4636] = 4599,
  [4637] = 4637,
  [4638] = 4597,
  [4639] = 4620,
  [4640] = 4640,
  [4641] = 4592,
  [4642] = 4642,
  [4643] = 4605,
  [4644] = 4223,
  [4645] = 4593,
  [4646] = 4586,
  [4647] = 4647,
  [4648] = 4648,
  [4649] = 4649,
  [4650] = 4592,
  [4651] = 4651,
  [4652] = 4591,
  [4653] = 4647,
  [4654] = 4589,
  [4655] = 4585,
  [4656] = 4294,
  [4657] = 4594,
  [4658] = 4658,
  [4659] = 4605,
  [4660] = 4593,
  [4661] = 4661,
  [4662] = 3081,
  [4663] = 4605,
  [4664] = 4620,
  [4665] = 146,
  [4666] = 142,
  [4667] = 4597,
  [4668] = 143,
  [4669] = 144,
  [4670] = 4670,
  [4671] = 148,
  [4672] = 4605,
  [4673] = 4597,
  [4674] = 4599,
  [4675] = 134,
  [4676] = 128,
  [4677] = 4677,
  [4678] = 2230,
  [4679] = 1957,
  [4680] = 4680,
  [4681] = 129,
  [4682] = 136,
  [4683] = 131,
  [4684] = 132,
  [4685] = 130,
  [4686] = 4599,
  [4687] = 4687,
  [4688] = 4688,
  [4689] = 4688,
  [4690] = 4677,
  [4691] = 1963,
  [4692] = 4591,
  [4693] = 2316,
  [4694] = 4620,
  [4695] = 3061,
  [4696] = 3059,
  [4697] = 4661,
  [4698] = 4698,
  [4699] = 4647,
  [4700] = 4700,
  [4701] = 4589,
  [4702] = 4647,
  [4703] = 4670,
  [4704] = 4594,
  [4705] = 4705,
  [4706] = 4585,
  [4707] = 4586,
  [4708] = 4589,
  [4709] = 4593,
  [4710] = 4223,
  [4711] = 4711,
  [4712] = 4661,
  [4713] = 4599,
  [4714] = 4651,
  [4715] = 4594,
  [4716] = 4716,
  [4717] = 4597,
  [4718] = 2708,
  [4719] = 4221,
  [4720] = 2761,
  [4721] = 2713,
  [4722] = 2250,
  [4723] = 4219,
  [4724] = 4687,
  [4725] = 4231,
  [4726] = 4592,
  [4727] = 4661,
  [4728] = 4728,
  [4729] = 4593,
  [4730] = 4620,
  [4731] = 4591,
  [4732] = 4732,
  [4733] = 4733,
  [4734] = 4231,
  [4735] = 4735,
  [4736] = 138,
  [4737] = 4221,
  [4738] = 4733,
  [4739] = 2822,
  [4740] = 2775,
  [4741] = 2812,
  [4742] = 2826,
  [4743] = 4743,
  [4744] = 4219,
  [4745] = 4745,
  [4746] = 2821,
  [4747] = 4732,
  [4748] = 2845,
  [4749] = 2793,
  [4750] = 2229,
  [4751] = 4088,
  [4752] = 2316,
  [4753] = 4080,
  [4754] = 2794,
  [4755] = 4755,
  [4756] = 4732,
  [4757] = 2213,
  [4758] = 4755,
  [4759] = 2803,
  [4760] = 2828,
  [4761] = 4223,
  [4762] = 2829,
  [4763] = 2830,
  [4764] = 2842,
  [4765] = 4221,
  [4766] = 4231,
  [4767] = 4219,
  [4768] = 4223,
  [4769] = 139,
  [4770] = 4221,
  [4771] = 4771,
  [4772] = 2773,
  [4773] = 2836,
  [4774] = 2766,
  [4775] = 2852,
  [4776] = 2833,
  [4777] = 4088,
  [4778] = 4778,
  [4779] = 4779,
  [4780] = 4743,
  [4781] = 4733,
  [4782] = 4733,
  [4783] = 4080,
  [4784] = 4771,
  [4785] = 4755,
  [4786] = 4771,
  [4787] = 4733,
  [4788] = 4745,
  [4789] = 2827,
  [4790] = 2823,
  [4791] = 4791,
  [4792] = 2815,
  [4793] = 4732,
  [4794] = 2770,
  [4795] = 2301,
  [4796] = 2813,
  [4797] = 2809,
  [4798] = 2808,
  [4799] = 2806,
  [4800] = 4745,
  [4801] = 2818,
  [4802] = 2797,
  [4803] = 4745,
  [4804] = 4743,
  [4805] = 4743,
  [4806] = 4771,
  [4807] = 2834,
  [4808] = 2817,
  [4809] = 4743,
  [4810] = 4733,
  [4811] = 4755,
  [4812] = 4223,
  [4813] = 4743,
  [4814] = 4743,
  [4815] = 2355,
  [4816] = 2771,
  [4817] = 4745,
  [4818] = 2802,
  [4819] = 4771,
  [4820] = 2844,
  [4821] = 2849,
  [4822] = 4732,
  [4823] = 2840,
  [4824] = 4755,
  [4825] = 4733,
  [4826] = 2299,
  [4827] = 4771,
  [4828] = 2848,
  [4829] = 149,
  [4830] = 4219,
  [4831] = 4745,
  [4832] = 4732,
  [4833] = 4771,
  [4834] = 4755,
  [4835] = 4732,
  [4836] = 4745,
  [4837] = 2796,
  [4838] = 4231,
  [4839] = 4755,
  [4840] = 2786,
  [4841] = 2200,
  [4842] = 2341,
  [4843] = 2299,
  [4844] = 2233,
  [4845] = 4670,
  [4846] = 4846,
  [4847] = 4670,
  [4848] = 2318,
  [4849] = 2246,
  [4850] = 2239,
  [4851] = 2321,
  [4852] = 4231,
  [4853] = 4221,
  [4854] = 2329,
  [4855] = 2325,
  [4856] = 2317,
  [4857] = 2247,
  [4858] = 2319,
  [4859] = 2241,
  [4860] = 2322,
  [4861] = 2240,
  [4862] = 2324,
  [4863] = 4223,
  [4864] = 2315,
  [4865] = 2320,
  [4866] = 2328,
  [4867] = 2229,
  [4868] = 2264,
  [4869] = 2237,
  [4870] = 2327,
  [4871] = 4219,
  [4872] = 4013,
  [4873] = 2301,
  [4874] = 4874,
  [4875] = 2271,
  [4876] = 2280,
  [4877] = 2321,
  [4878] = 2274,
  [4879] = 2295,
  [4880] = 2297,
  [4881] = 2302,
  [4882] = 2290,
  [4883] = 2293,
  [4884] = 4884,
  [4885] = 2279,
  [4886] = 2294,
  [4887] = 2287,
  [4888] = 2286,
  [4889] = 2324,
  [4890] = 2355,
  [4891] = 2328,
  [4892] = 2341,
  [4893] = 2288,
  [4894] = 2283,
  [4895] = 4080,
  [4896] = 192,
  [4897] = 4670,
  [4898] = 2277,
  [4899] = 2320,
  [4900] = 4900,
  [4901] = 4294,
  [4902] = 2327,
  [4903] = 2272,
  [4904] = 2296,
  [4905] = 2325,
  [4906] = 4670,
  [4907] = 2329,
  [4908] = 2316,
  [4909] = 4909,
  [4910] = 4088,
  [4911] = 2292,
  [4912] = 2278,
  [4913] = 2318,
  [4914] = 2306,
  [4915] = 2282,
  [4916] = 4231,
  [4917] = 4670,
  [4918] = 2317,
  [4919] = 2298,
  [4920] = 2284,
  [4921] = 2269,
  [4922] = 4909,
  [4923] = 4874,
  [4924] = 2262,
  [4925] = 2275,
  [4926] = 2315,
  [4927] = 2276,
  [4928] = 4928,
  [4929] = 2300,
  [4930] = 4670,
  [4931] = 2289,
  [4932] = 2305,
  [4933] = 2303,
  [4934] = 2270,
  [4935] = 4935,
  [4936] = 2307,
  [4937] = 4223,
  [4938] = 2304,
  [4939] = 2281,
  [4940] = 4935,
  [4941] = 223,
  [4942] = 2322,
  [4943] = 2319,
  [4944] = 4928,
  [4945] = 2285,
  [4946] = 4884,
  [4947] = 4947,
  [4948] = 4948,
  [4949] = 4221,
  [4950] = 4231,
  [4951] = 223,
  [4952] = 4223,
  [4953] = 2222,
  [4954] = 2250,
  [4955] = 4231,
  [4956] = 2249,
  [4957] = 2341,
  [4958] = 192,
  [4959] = 2264,
  [4960] = 2278,
  [4961] = 2355,
  [4962] = 4294,
  [4963] = 4221,
  [4964] = 4219,
  [4965] = 4670,
  [4966] = 2355,
  [4967] = 2285,
  [4968] = 4670,
  [4969] = 4670,
  [4970] = 2341,
  [4971] = 2355,
  [4972] = 2252,
  [4973] = 2341,
  [4974] = 2292,
  [4975] = 4219,
  [4976] = 4670,
  [4977] = 2262,
  [4978] = 4223,
  [4979] = 2297,
  [4980] = 2277,
  [4981] = 2305,
  [4982] = 4670,
  [4983] = 2307,
  [4984] = 4984,
  [4985] = 4984,
  [4986] = 2275,
  [4987] = 4670,
  [4988] = 4984,
  [4989] = 2304,
  [4990] = 2276,
  [4991] = 2284,
  [4992] = 4670,
  [4993] = 2283,
  [4994] = 2288,
  [4995] = 4995,
  [4996] = 2281,
  [4997] = 4995,
  [4998] = 2286,
  [4999] = 2287,
  [5000] = 2280,
  [5001] = 4909,
  [5002] = 2294,
  [5003] = 4995,
  [5004] = 4984,
  [5005] = 4984,
  [5006] = 2295,
  [5007] = 2270,
  [5008] = 4984,
  [5009] = 4984,
  [5010] = 4884,
  [5011] = 2341,
  [5012] = 4670,
  [5013] = 2293,
  [5014] = 2290,
  [5015] = 4123,
  [5016] = 4984,
  [5017] = 4995,
  [5018] = 2298,
  [5019] = 2302,
  [5020] = 2269,
  [5021] = 2227,
  [5022] = 4984,
  [5023] = 2301,
  [5024] = 4995,
  [5025] = 2282,
  [5026] = 1946,
  [5027] = 4124,
  [5028] = 4995,
  [5029] = 4670,
  [5030] = 4995,
  [5031] = 4884,
  [5032] = 2303,
  [5033] = 2289,
  [5034] = 4995,
  [5035] = 2272,
  [5036] = 2306,
  [5037] = 2271,
  [5038] = 4995,
  [5039] = 2296,
  [5040] = 2299,
  [5041] = 2355,
  [5042] = 2274,
  [5043] = 4670,
  [5044] = 4909,
  [5045] = 2279,
  [5046] = 2300,
  [5047] = 4884,
  [5048] = 5048,
  [5049] = 4219,
  [5050] = 2316,
  [5051] = 2299,
  [5052] = 5052,
  [5053] = 4231,
  [5054] = 4884,
  [5055] = 4909,
  [5056] = 4223,
  [5057] = 4884,
  [5058] = 4909,
  [5059] = 4909,
  [5060] = 4221,
  [5061] = 4909,
  [5062] = 4884,
  [5063] = 2301,
  [5064] = 5064,
  [5065] = 5065,
  [5066] = 2325,
  [5067] = 5067,
  [5068] = 5068,
  [5069] = 5069,
  [5070] = 2324,
  [5071] = 5069,
  [5072] = 5072,
  [5073] = 2329,
  [5074] = 5074,
  [5075] = 2240,
  [5076] = 2328,
  [5077] = 2320,
  [5078] = 2327,
  [5079] = 5079,
  [5080] = 2230,
  [5081] = 4670,
  [5082] = 5069,
  [5083] = 2233,
  [5084] = 4909,
  [5085] = 2246,
  [5086] = 2322,
  [5087] = 5072,
  [5088] = 5088,
  [5089] = 5089,
  [5090] = 5068,
  [5091] = 5065,
  [5092] = 2239,
  [5093] = 5088,
  [5094] = 5069,
  [5095] = 2319,
  [5096] = 5089,
  [5097] = 5065,
  [5098] = 2226,
  [5099] = 2317,
  [5100] = 5100,
  [5101] = 5064,
  [5102] = 5089,
  [5103] = 5103,
  [5104] = 2318,
  [5105] = 5088,
  [5106] = 5067,
  [5107] = 5089,
  [5108] = 5069,
  [5109] = 5088,
  [5110] = 5103,
  [5111] = 5069,
  [5112] = 5065,
  [5113] = 5100,
  [5114] = 5103,
  [5115] = 4884,
  [5116] = 5089,
  [5117] = 5088,
  [5118] = 5072,
  [5119] = 4909,
  [5120] = 5064,
  [5121] = 5100,
  [5122] = 5067,
  [5123] = 2321,
  [5124] = 4884,
  [5125] = 5065,
  [5126] = 5088,
  [5127] = 5069,
  [5128] = 2315,
  [5129] = 5103,
  [5130] = 5067,
  [5131] = 5072,
  [5132] = 5064,
  [5133] = 5100,
  [5134] = 2241,
  [5135] = 5068,
  [5136] = 2247,
  [5137] = 4884,
  [5138] = 5067,
  [5139] = 5065,
  [5140] = 4909,
  [5141] = 4884,
  [5142] = 5072,
  [5143] = 5069,
  [5144] = 5089,
  [5145] = 5088,
  [5146] = 5067,
  [5147] = 2237,
  [5148] = 5069,
  [5149] = 5069,
  [5150] = 5069,
  [5151] = 5089,
  [5152] = 5088,
  [5153] = 5088,
  [5154] = 5089,
  [5155] = 5088,
  [5156] = 2227,
  [5157] = 5089,
  [5158] = 5065,
  [5159] = 5068,
  [5160] = 5100,
  [5161] = 5064,
  [5162] = 5069,
  [5163] = 5088,
  [5164] = 5088,
  [5165] = 5103,
  [5166] = 5089,
  [5167] = 5065,
  [5168] = 5072,
  [5169] = 5065,
  [5170] = 5089,
  [5171] = 5065,
  [5172] = 5069,
  [5173] = 5067,
  [5174] = 5088,
  [5175] = 5089,
  [5176] = 5065,
  [5177] = 5069,
  [5178] = 5178,
  [5179] = 5088,
  [5180] = 5072,
  [5181] = 5068,
  [5182] = 5089,
  [5183] = 5065,
  [5184] = 5069,
  [5185] = 5100,
  [5186] = 5064,
  [5187] = 5065,
  [5188] = 5188,
  [5189] = 5089,
  [5190] = 5088,
  [5191] = 4670,
  [5192] = 5103,
  [5193] = 5103,
  [5194] = 5088,
  [5195] = 4909,
  [5196] = 5064,
  [5197] = 5100,
  [5198] = 5089,
  [5199] = 5065,
  [5200] = 4294,
  [5201] = 5089,
  [5202] = 5088,
  [5203] = 5065,
  [5204] = 5089,
  [5205] = 5069,
  [5206] = 5069,
  [5207] = 2227,
  [5208] = 5065,
  [5209] = 5067,
  [5210] = 5065,
  [5211] = 5089,
  [5212] = 5065,
  [5213] = 5068,
  [5214] = 5088,
  [5215] = 5072,
  [5216] = 5216,
  [5217] = 5072,
  [5218] = 5069,
  [5219] = 5069,
  [5220] = 5067,
  [5221] = 5069,
  [5222] = 2322,
  [5223] = 5223,
  [5224] = 4884,
  [5225] = 5225,
  [5226] = 5226,
  [5227] = 4909,
  [5228] = 5228,
  [5229] = 5226,
  [5230] = 5230,
  [5231] = 5223,
  [5232] = 2317,
  [5233] = 2318,
  [5234] = 5226,
  [5235] = 5235,
  [5236] = 4884,
  [5237] = 5230,
  [5238] = 5226,
  [5239] = 5239,
  [5240] = 5226,
  [5241] = 2319,
  [5242] = 5242,
  [5243] = 5226,
  [5244] = 5235,
  [5245] = 5245,
  [5246] = 5225,
  [5247] = 4884,
  [5248] = 4909,
  [5249] = 4909,
  [5250] = 5250,
  [5251] = 5230,
  [5252] = 5230,
  [5253] = 4909,
  [5254] = 5254,
  [5255] = 5235,
  [5256] = 5228,
  [5257] = 5230,
  [5258] = 5226,
  [5259] = 4884,
  [5260] = 4884,
  [5261] = 5228,
  [5262] = 5226,
  [5263] = 5225,
  [5264] = 5226,
  [5265] = 5228,
  [5266] = 5226,
  [5267] = 5223,
  [5268] = 5242,
  [5269] = 4909,
  [5270] = 4884,
  [5271] = 2321,
  [5272] = 5272,
  [5273] = 5226,
  [5274] = 5245,
  [5275] = 2327,
  [5276] = 5226,
  [5277] = 2315,
  [5278] = 5230,
  [5279] = 2320,
  [5280] = 5235,
  [5281] = 5225,
  [5282] = 4909,
  [5283] = 5235,
  [5284] = 5225,
  [5285] = 5226,
  [5286] = 5228,
  [5287] = 5226,
  [5288] = 5225,
  [5289] = 5230,
  [5290] = 5242,
  [5291] = 5223,
  [5292] = 5235,
  [5293] = 2329,
  [5294] = 5250,
  [5295] = 2325,
  [5296] = 5223,
  [5297] = 5242,
  [5298] = 5226,
  [5299] = 5235,
  [5300] = 5226,
  [5301] = 5226,
  [5302] = 5226,
  [5303] = 5303,
  [5304] = 5228,
  [5305] = 2328,
  [5306] = 5228,
  [5307] = 5272,
  [5308] = 2324,
  [5309] = 5225,
  [5310] = 5310,
  [5311] = 2250,
  [5312] = 5312,
  [5313] = 5272,
  [5314] = 5250,
  [5315] = 5245,
  [5316] = 5250,
  [5317] = 2336,
  [5318] = 5245,
  [5319] = 4884,
  [5320] = 4909,
  [5321] = 1963,
  [5322] = 4909,
  [5323] = 1957,
  [5324] = 4884,
  [5325] = 5272,
  [5326] = 5272,
  [5327] = 5327,
  [5328] = 5327,
  [5329] = 5250,
  [5330] = 5272,
  [5331] = 5272,
  [5332] = 5245,
  [5333] = 2588,
  [5334] = 5250,
  [5335] = 5245,
  [5336] = 5245,
  [5337] = 5327,
  [5338] = 5245,
  [5339] = 2330,
  [5340] = 5272,
  [5341] = 5250,
  [5342] = 5327,
  [5343] = 5250,
  [5344] = 5272,
  [5345] = 5245,
  [5346] = 5272,
  [5347] = 5347,
  [5348] = 5272,
  [5349] = 5250,
  [5350] = 5250,
  [5351] = 5250,
  [5352] = 5245,
  [5353] = 5353,
  [5354] = 5250,
  [5355] = 5347,
  [5356] = 5245,
  [5357] = 5245,
  [5358] = 5347,
  [5359] = 5347,
  [5360] = 5347,
  [5361] = 5272,
  [5362] = 5347,
  [5363] = 5347,
  [5364] = 5250,
  [5365] = 5245,
  [5366] = 5366,
  [5367] = 5353,
  [5368] = 5250,
  [5369] = 5272,
  [5370] = 5245,
  [5371] = 5245,
  [5372] = 5272,
  [5373] = 5272,
  [5374] = 5272,
  [5375] = 5250,
  [5376] = 5245,
  [5377] = 5272,
  [5378] = 5250,
  [5379] = 5245,
  [5380] = 5272,
  [5381] = 5245,
  [5382] = 5250,
  [5383] = 5250,
  [5384] = 5384,
  [5385] = 5384,
  [5386] = 5384,
  [5387] = 5387,
  [5388] = 5387,
  [5389] = 5272,
  [5390] = 5390,
  [5391] = 5387,
  [5392] = 5392,
  [5393] = 5245,
  [5394] = 5390,
  [5395] = 5392,
  [5396] = 5387,
  [5397] = 5390,
  [5398] = 5392,
  [5399] = 5387,
  [5400] = 5387,
  [5401] = 5392,
  [5402] = 5392,
  [5403] = 5387,
  [5404] = 5392,
  [5405] = 5392,
  [5406] = 5392,
  [5407] = 5390,
  [5408] = 5387,
  [5409] = 5409,
  [5410] = 5392,
  [5411] = 5390,
  [5412] = 5392,
  [5413] = 5409,
  [5414] = 5245,
  [5415] = 5409,
  [5416] = 5390,
  [5417] = 5387,
  [5418] = 5390,
  [5419] = 5272,
  [5420] = 5353,
  [5421] = 5250,
  [5422] = 5392,
  [5423] = 5387,
  [5424] = 5250,
  [5425] = 5425,
  [5426] = 5392,
  [5427] = 5387,
  [5428] = 5387,
  [5429] = 5387,
  [5430] = 5392,
  [5431] = 5392,
  [5432] = 5387,
  [5433] = 5433,
  [5434] = 5434,
  [5435] = 5434,
  [5436] = 5436,
  [5437] = 5437,
  [5438] = 5438,
  [5439] = 5439,
  [5440] = 5438,
  [5441] = 5425,
  [5442] = 5437,
  [5443] = 5443,
  [5444] = 5436,
  [5445] = 5437,
  [5446] = 5438,
  [5447] = 5437,
  [5448] = 5436,
  [5449] = 5439,
  [5450] = 5439,
  [5451] = 5437,
  [5452] = 5438,
  [5453] = 5438,
  [5454] = 5436,
  [5455] = 5439,
  [5456] = 5434,
  [5457] = 5436,
  [5458] = 5438,
  [5459] = 5438,
  [5460] = 5434,
  [5461] = 5439,
  [5462] = 5436,
  [5463] = 5437,
  [5464] = 5436,
  [5465] = 5438,
  [5466] = 5434,
  [5467] = 5439,
  [5468] = 5437,
  [5469] = 5469,
  [5470] = 5434,
  [5471] = 5439,
  [5472] = 5439,
  [5473] = 5439,
  [5474] = 5438,
  [5475] = 5437,
  [5476] = 5439,
  [5477] = 5437,
  [5478] = 5469,
  [5479] = 5437,
  [5480] = 5438,
  [5481] = 5439,
  [5482] = 5434,
  [5483] = 5436,
  [5484] = 5439,
  [5485] = 5436,
  [5486] = 5486,
  [5487] = 5486,
  [5488] = 5438,
  [5489] = 5436,
  [5490] = 5437,
  [5491] = 5434,
  [5492] = 5438,
  [5493] = 5437,
  [5494] = 5437,
  [5495] = 5439,
  [5496] = 5434,
  [5497] = 5436,
  [5498] = 5436,
  [5499] = 5434,
  [5500] = 5434,
  [5501] = 5436,
  [5502] = 5439,
  [5503] = 5353,
  [5504] = 5438,
  [5505] = 5469,
  [5506] = 5486,
  [5507] = 5439,
  [5508] = 5437,
  [5509] = 5434,
  [5510] = 5439,
  [5511] = 5436,
  [5512] = 5434,
  [5513] = 5438,
  [5514] = 5439,
  [5515] = 5438,
  [5516] = 5436,
  [5517] = 5434,
  [5518] = 5437,
  [5519] = 5434,
  [5520] = 5436,
  [5521] = 5434,
  [5522] = 5436,
  [5523] = 5438,
  [5524] = 5437,
  [5525] = 5434,
  [5526] = 5438,
  [5527] = 5434,
  [5528] = 5437,
  [5529] = 5438,
  [5530] = 5437,
  [5531] = 5439,
  [5532] = 5436,
  [5533] = 5533,
  [5534] = 5534,
  [5535] = 5533,
  [5536] = 5536,
  [5537] = 5537,
  [5538] = 5538,
  [5539] = 5539,
  [5540] = 5540,
  [5541] = 5541,
  [5542] = 5541,
  [5543] = 5543,
  [5544] = 5544,
  [5545] = 5545,
  [5546] = 5546,
  [5547] = 5533,
  [5548] = 5548,
  [5549] = 5534,
  [5550] = 5550,
  [5551] = 5551,
  [5552] = 5552,
  [5553] = 5553,
  [5554] = 5353,
  [5555] = 5544,
  [5556] = 5548,
  [5557] = 5557,
  [5558] = 5558,
  [5559] = 5559,
  [5560] = 5560,
  [5561] = 5539,
  [5562] = 5562,
  [5563] = 5545,
  [5564] = 5564,
  [5565] = 5534,
  [5566] = 5553,
  [5567] = 5567,
  [5568] = 5568,
  [5569] = 5534,
  [5570] = 5570,
  [5571] = 5560,
  [5572] = 5572,
  [5573] = 5573,
  [5574] = 5560,
  [5575] = 5570,
  [5576] = 5545,
  [5577] = 5534,
  [5578] = 5560,
  [5579] = 5579,
  [5580] = 5545,
  [5581] = 5545,
  [5582] = 5553,
  [5583] = 5583,
  [5584] = 5584,
  [5585] = 5585,
  [5586] = 3081,
  [5587] = 5562,
  [5588] = 5588,
  [5589] = 5545,
  [5590] = 5552,
  [5591] = 5591,
  [5592] = 5592,
  [5593] = 5546,
  [5594] = 5560,
  [5595] = 5553,
  [5596] = 5353,
  [5597] = 5545,
  [5598] = 5598,
  [5599] = 5599,
  [5600] = 5534,
  [5601] = 5601,
  [5602] = 5560,
  [5603] = 5534,
  [5604] = 5604,
  [5605] = 5560,
  [5606] = 5606,
  [5607] = 5560,
  [5608] = 5558,
  [5609] = 5559,
  [5610] = 5545,
  [5611] = 5611,
  [5612] = 5612,
  [5613] = 5564,
  [5614] = 5614,
  [5615] = 5615,
  [5616] = 5534,
  [5617] = 5617,
  [5618] = 5618,
  [5619] = 5619,
  [5620] = 5620,
  [5621] = 5534,
  [5622] = 5584,
  [5623] = 5560,
  [5624] = 5560,
  [5625] = 5560,
  [5626] = 5541,
  [5627] = 5627,
  [5628] = 5560,
  [5629] = 5629,
  [5630] = 5545,
  [5631] = 5573,
  [5632] = 5632,
  [5633] = 5579,
  [5634] = 5572,
  [5635] = 5551,
  [5636] = 5560,
  [5637] = 5604,
  [5638] = 5583,
  [5639] = 5560,
  [5640] = 5606,
  [5641] = 1935,
  [5642] = 5642,
  [5643] = 5643,
  [5644] = 5644,
  [5645] = 1968,
  [5646] = 5646,
  [5647] = 5647,
  [5648] = 1950,
  [5649] = 1964,
  [5650] = 5642,
  [5651] = 5539,
  [5652] = 5551,
  [5653] = 5646,
  [5654] = 1949,
  [5655] = 5655,
  [5656] = 5656,
  [5657] = 5657,
  [5658] = 5557,
  [5659] = 5646,
  [5660] = 5353,
  [5661] = 5661,
  [5662] = 5646,
  [5663] = 5663,
  [5664] = 5548,
  [5665] = 1951,
  [5666] = 5537,
  [5667] = 5656,
  [5668] = 5642,
  [5669] = 5669,
  [5670] = 5670,
  [5671] = 5655,
  [5672] = 5672,
  [5673] = 5570,
  [5674] = 5540,
  [5675] = 5675,
  [5676] = 5676,
  [5677] = 5677,
  [5678] = 5644,
  [5679] = 5677,
  [5680] = 5629,
  [5681] = 5614,
  [5682] = 3081,
  [5683] = 5642,
  [5684] = 5684,
  [5685] = 5620,
  [5686] = 5591,
  [5687] = 1960,
  [5688] = 5688,
  [5689] = 5548,
  [5690] = 5669,
  [5691] = 5618,
  [5692] = 5551,
  [5693] = 5646,
  [5694] = 5601,
  [5695] = 5642,
  [5696] = 5696,
  [5697] = 5642,
  [5698] = 5539,
  [5699] = 5615,
  [5700] = 2200,
  [5701] = 5701,
  [5702] = 1940,
  [5703] = 5617,
  [5704] = 5543,
  [5705] = 1973,
  [5706] = 5627,
  [5707] = 5353,
  [5708] = 5708,
  [5709] = 5708,
  [5710] = 5611,
  [5711] = 5643,
  [5712] = 5585,
  [5713] = 5655,
  [5714] = 5353,
  [5715] = 5715,
  [5716] = 5655,
  [5717] = 1971,
  [5718] = 5644,
  [5719] = 2213,
  [5720] = 1961,
  [5721] = 5675,
  [5722] = 5722,
  [5723] = 5570,
  [5724] = 5646,
  [5725] = 5656,
  [5726] = 5696,
  [5727] = 5727,
  [5728] = 5669,
  [5729] = 5669,
  [5730] = 5644,
  [5731] = 1967,
  [5732] = 5644,
  [5733] = 5642,
  [5734] = 5734,
  [5735] = 137,
  [5736] = 5736,
  [5737] = 5550,
  [5738] = 5599,
  [5739] = 5676,
  [5740] = 140,
  [5741] = 5644,
  [5742] = 1938,
  [5743] = 5567,
  [5744] = 1956,
  [5745] = 1937,
  [5746] = 5746,
  [5747] = 2588,
  [5748] = 5748,
  [5749] = 5749,
  [5750] = 5746,
  [5751] = 5746,
  [5752] = 5752,
  [5753] = 5753,
  [5754] = 5746,
  [5755] = 5746,
  [5756] = 5756,
  [5757] = 5353,
  [5758] = 5746,
  [5759] = 5746,
  [5760] = 5760,
  [5761] = 5761,
  [5762] = 2200,
  [5763] = 5763,
  [5764] = 5764,
  [5765] = 5764,
  [5766] = 1960,
  [5767] = 5767,
  [5768] = 1935,
  [5769] = 5769,
  [5770] = 1940,
  [5771] = 5708,
  [5772] = 5772,
  [5773] = 1973,
  [5774] = 5643,
  [5775] = 140,
  [5776] = 5769,
  [5777] = 5353,
  [5778] = 1951,
  [5779] = 2213,
  [5780] = 1967,
  [5781] = 1961,
  [5782] = 137,
  [5783] = 5675,
  [5784] = 1964,
  [5785] = 5763,
  [5786] = 1950,
  [5787] = 1938,
  [5788] = 5788,
  [5789] = 5763,
  [5790] = 5790,
  [5791] = 5769,
  [5792] = 5551,
  [5793] = 5769,
  [5794] = 2343,
  [5795] = 5748,
  [5796] = 5539,
  [5797] = 5676,
  [5798] = 5548,
  [5799] = 5676,
  [5800] = 5764,
  [5801] = 5763,
  [5802] = 1968,
  [5803] = 5570,
  [5804] = 5763,
  [5805] = 5769,
  [5806] = 5643,
  [5807] = 5769,
  [5808] = 1956,
  [5809] = 5675,
  [5810] = 1937,
  [5811] = 5764,
  [5812] = 5764,
  [5813] = 5764,
  [5814] = 5769,
  [5815] = 5767,
  [5816] = 1971,
  [5817] = 5817,
  [5818] = 1949,
  [5819] = 5760,
  [5820] = 5763,
  [5821] = 5769,
  [5822] = 5764,
  [5823] = 5764,
  [5824] = 5769,
  [5825] = 5764,
  [5826] = 5696,
  [5827] = 5570,
  [5828] = 5708,
  [5829] = 2344,
  [5830] = 5548,
  [5831] = 5831,
  [5832] = 5769,
  [5833] = 5696,
  [5834] = 2345,
  [5835] = 5551,
  [5836] = 5753,
  [5837] = 5539,
  [5838] = 5764,
  [5839] = 5790,
  [5840] = 5353,
  [5841] = 5841,
  [5842] = 5841,
  [5843] = 5841,
  [5844] = 5841,
  [5845] = 5841,
  [5846] = 5551,
  [5847] = 5570,
  [5848] = 5841,
  [5849] = 2213,
  [5850] = 5841,
  [5851] = 5841,
  [5852] = 906,
  [5853] = 5548,
  [5854] = 5841,
  [5855] = 5855,
  [5856] = 5841,
  [5857] = 5841,
  [5858] = 904,
  [5859] = 5859,
  [5860] = 5841,
  [5861] = 5841,
  [5862] = 5570,
  [5863] = 5841,
  [5864] = 5841,
  [5865] = 5841,
  [5866] = 5551,
  [5867] = 5539,
  [5868] = 5772,
  [5869] = 5869,
  [5870] = 5870,
  [5871] = 5871,
  [5872] = 5872,
  [5873] = 5548,
  [5874] = 5353,
  [5875] = 5841,
  [5876] = 2200,
  [5877] = 5877,
  [5878] = 5878,
  [5879] = 5841,
  [5880] = 5841,
  [5881] = 5881,
  [5882] = 5882,
  [5883] = 5539,
  [5884] = 5859,
  [5885] = 5708,
  [5886] = 5886,
  [5887] = 5887,
  [5888] = 5548,
  [5889] = 5548,
  [5890] = 5570,
  [5891] = 5891,
  [5892] = 5892,
  [5893] = 2200,
  [5894] = 5894,
  [5895] = 5895,
  [5896] = 5896,
  [5897] = 5897,
  [5898] = 5898,
  [5899] = 5899,
  [5900] = 5900,
  [5901] = 5901,
  [5902] = 5894,
  [5903] = 5903,
  [5904] = 5675,
  [5905] = 5895,
  [5906] = 5551,
  [5907] = 5907,
  [5908] = 5908,
  [5909] = 5895,
  [5910] = 5910,
  [5911] = 5908,
  [5912] = 5887,
  [5913] = 5908,
  [5914] = 5570,
  [5915] = 5915,
  [5916] = 5916,
  [5917] = 5917,
  [5918] = 5918,
  [5919] = 5919,
  [5920] = 5920,
  [5921] = 5887,
  [5922] = 5910,
  [5923] = 5539,
  [5924] = 5924,
  [5925] = 5887,
  [5926] = 5570,
  [5927] = 5927,
  [5928] = 5887,
  [5929] = 5570,
  [5930] = 5894,
  [5931] = 5643,
  [5932] = 5932,
  [5933] = 5933,
  [5934] = 2213,
  [5935] = 5910,
  [5936] = 5936,
  [5937] = 5910,
  [5938] = 5908,
  [5939] = 5939,
  [5940] = 5908,
  [5941] = 5941,
  [5942] = 5548,
  [5943] = 5943,
  [5944] = 5944,
  [5945] = 5887,
  [5946] = 5708,
  [5947] = 5947,
  [5948] = 5551,
  [5949] = 5895,
  [5950] = 5548,
  [5951] = 5696,
  [5952] = 5869,
  [5953] = 5870,
  [5954] = 5878,
  [5955] = 5882,
  [5956] = 5956,
  [5957] = 5957,
  [5958] = 5877,
  [5959] = 5871,
  [5960] = 5887,
  [5961] = 5539,
  [5962] = 5962,
  [5963] = 5910,
  [5964] = 5539,
  [5965] = 5887,
  [5966] = 5908,
  [5967] = 5895,
  [5968] = 5539,
  [5969] = 5969,
  [5970] = 5881,
  [5971] = 5895,
  [5972] = 5894,
  [5973] = 5676,
  [5974] = 5974,
  [5975] = 5887,
  [5976] = 5675,
  [5977] = 5551,
  [5978] = 5910,
  [5979] = 5887,
  [5980] = 5551,
  [5981] = 5908,
  [5982] = 5982,
  [5983] = 5983,
  [5984] = 5910,
  [5985] = 5643,
  [5986] = 5986,
  [5987] = 5696,
  [5988] = 5676,
  [5989] = 5353,
  [5990] = 5570,
  [5991] = 5991,
  [5992] = 5548,
  [5993] = 5993,
  [5994] = 2379,
  [5995] = 5995,
  [5996] = 5996,
  [5997] = 5991,
  [5998] = 5675,
  [5999] = 5991,
  [6000] = 5570,
  [6001] = 6001,
  [6002] = 5903,
  [6003] = 5991,
  [6004] = 6001,
  [6005] = 2575,
  [6006] = 5675,
  [6007] = 6007,
  [6008] = 2380,
  [6009] = 6009,
  [6010] = 5996,
  [6011] = 6001,
  [6012] = 5915,
  [6013] = 6001,
  [6014] = 6001,
  [6015] = 5551,
  [6016] = 5643,
  [6017] = 6017,
  [6018] = 6017,
  [6019] = 5708,
  [6020] = 5996,
  [6021] = 5918,
  [6022] = 5991,
  [6023] = 5907,
  [6024] = 6024,
  [6025] = 6017,
  [6026] = 5991,
  [6027] = 5927,
  [6028] = 5643,
  [6029] = 6001,
  [6030] = 5991,
  [6031] = 5676,
  [6032] = 5539,
  [6033] = 5941,
  [6034] = 5539,
  [6035] = 5996,
  [6036] = 6017,
  [6037] = 5539,
  [6038] = 5996,
  [6039] = 5676,
  [6040] = 6040,
  [6041] = 5996,
  [6042] = 5991,
  [6043] = 5570,
  [6044] = 5548,
  [6045] = 5991,
  [6046] = 5917,
  [6047] = 5551,
  [6048] = 6048,
  [6049] = 5991,
  [6050] = 5539,
  [6051] = 5891,
  [6052] = 5957,
  [6053] = 5991,
  [6054] = 2403,
  [6055] = 5991,
  [6056] = 2551,
  [6057] = 5991,
  [6058] = 6058,
  [6059] = 5991,
  [6060] = 6060,
  [6061] = 5991,
  [6062] = 6001,
  [6063] = 5570,
  [6064] = 5548,
  [6065] = 5551,
  [6066] = 5708,
  [6067] = 5539,
  [6068] = 5924,
  [6069] = 6017,
  [6070] = 5991,
  [6071] = 5956,
  [6072] = 5900,
  [6073] = 5696,
  [6074] = 5986,
  [6075] = 5551,
  [6076] = 5936,
  [6077] = 2540,
  [6078] = 5991,
  [6079] = 5548,
  [6080] = 5991,
  [6081] = 5551,
  [6082] = 5991,
  [6083] = 2391,
  [6084] = 2541,
  [6085] = 2736,
  [6086] = 5916,
  [6087] = 5570,
  [6088] = 2537,
  [6089] = 5548,
  [6090] = 5551,
  [6091] = 5991,
  [6092] = 5539,
  [6093] = 5892,
  [6094] = 5696,
  [6095] = 5548,
  [6096] = 5570,
  [6097] = 5933,
  [6098] = 6098,
  [6099] = 5898,
  [6100] = 5899,
  [6101] = 5996,
  [6102] = 6017,
  [6103] = 6103,
  [6104] = 5920,
  [6105] = 6017,
  [6106] = 6106,
  [6107] = 5901,
  [6108] = 6108,
  [6109] = 5676,
  [6110] = 6110,
  [6111] = 5869,
  [6112] = 2642,
  [6113] = 5870,
  [6114] = 6114,
  [6115] = 6115,
  [6116] = 6110,
  [6117] = 5676,
  [6118] = 5878,
  [6119] = 6119,
  [6120] = 6110,
  [6121] = 5859,
  [6122] = 5871,
  [6123] = 5570,
  [6124] = 2213,
  [6125] = 6125,
  [6126] = 6125,
  [6127] = 6125,
  [6128] = 5675,
  [6129] = 6108,
  [6130] = 6110,
  [6131] = 6114,
  [6132] = 5539,
  [6133] = 5570,
  [6134] = 6134,
  [6135] = 5551,
  [6136] = 6110,
  [6137] = 5877,
  [6138] = 5882,
  [6139] = 6134,
  [6140] = 6125,
  [6141] = 5675,
  [6142] = 6114,
  [6143] = 6108,
  [6144] = 5643,
  [6145] = 6108,
  [6146] = 6114,
  [6147] = 6108,
  [6148] = 6110,
  [6149] = 6149,
  [6150] = 6134,
  [6151] = 6108,
  [6152] = 6152,
  [6153] = 6125,
  [6154] = 5539,
  [6155] = 2765,
  [6156] = 6108,
  [6157] = 6157,
  [6158] = 6119,
  [6159] = 6115,
  [6160] = 6125,
  [6161] = 6161,
  [6162] = 5881,
  [6163] = 6110,
  [6164] = 2750,
  [6165] = 5643,
  [6166] = 6125,
  [6167] = 2832,
  [6168] = 5708,
  [6169] = 2200,
  [6170] = 5708,
  [6171] = 5548,
  [6172] = 5696,
  [6173] = 6115,
  [6174] = 6114,
  [6175] = 6110,
  [6176] = 5696,
  [6177] = 6134,
  [6178] = 5548,
  [6179] = 6125,
  [6180] = 5551,
  [6181] = 6125,
  [6182] = 6125,
  [6183] = 6110,
  [6184] = 6110,
  [6185] = 6115,
  [6186] = 6186,
  [6187] = 2540,
  [6188] = 2541,
  [6189] = 2316,
  [6190] = 6186,
  [6191] = 5878,
  [6192] = 6186,
  [6193] = 6186,
  [6194] = 6186,
  [6195] = 6186,
  [6196] = 6186,
  [6197] = 5882,
  [6198] = 2575,
  [6199] = 6186,
  [6200] = 6186,
  [6201] = 5881,
  [6202] = 6202,
  [6203] = 138,
  [6204] = 5871,
  [6205] = 2588,
  [6206] = 6186,
  [6207] = 6186,
  [6208] = 6208,
  [6209] = 6186,
  [6210] = 1084,
  [6211] = 5877,
  [6212] = 6212,
  [6213] = 6186,
  [6214] = 6214,
  [6215] = 2418,
  [6216] = 6212,
  [6217] = 5870,
  [6218] = 6186,
  [6219] = 6186,
  [6220] = 6220,
  [6221] = 6186,
  [6222] = 6186,
  [6223] = 6186,
  [6224] = 6186,
  [6225] = 5869,
  [6226] = 6226,
  [6227] = 5859,
  [6228] = 2551,
  [6229] = 6186,
  [6230] = 2537,
  [6231] = 6231,
  [6232] = 2627,
  [6233] = 6233,
  [6234] = 2839,
  [6235] = 6235,
  [6236] = 6236,
  [6237] = 5675,
  [6238] = 6231,
  [6239] = 138,
  [6240] = 6240,
  [6241] = 6241,
  [6242] = 6242,
  [6243] = 6243,
  [6244] = 2837,
  [6245] = 5643,
  [6246] = 5859,
  [6247] = 6242,
  [6248] = 6235,
  [6249] = 6243,
  [6250] = 2642,
  [6251] = 2835,
  [6252] = 6242,
  [6253] = 6242,
  [6254] = 6254,
  [6255] = 6236,
  [6256] = 6235,
  [6257] = 5869,
  [6258] = 6242,
  [6259] = 5870,
  [6260] = 6235,
  [6261] = 5859,
  [6262] = 6236,
  [6263] = 2820,
  [6264] = 6264,
  [6265] = 6265,
  [6266] = 2624,
  [6267] = 6267,
  [6268] = 6236,
  [6269] = 5643,
  [6270] = 6270,
  [6271] = 6271,
  [6272] = 2620,
  [6273] = 2621,
  [6274] = 6274,
  [6275] = 6275,
  [6276] = 6276,
  [6277] = 5708,
  [6278] = 2637,
  [6279] = 2639,
  [6280] = 5696,
  [6281] = 6281,
  [6282] = 6231,
  [6283] = 6283,
  [6284] = 6236,
  [6285] = 6265,
  [6286] = 2841,
  [6287] = 2847,
  [6288] = 6236,
  [6289] = 6289,
  [6290] = 5878,
  [6291] = 6291,
  [6292] = 5882,
  [6293] = 6293,
  [6294] = 6294,
  [6295] = 5939,
  [6296] = 6265,
  [6297] = 5881,
  [6298] = 6298,
  [6299] = 6293,
  [6300] = 6294,
  [6301] = 6301,
  [6302] = 6302,
  [6303] = 5676,
  [6304] = 2200,
  [6305] = 6242,
  [6306] = 6265,
  [6307] = 2652,
  [6308] = 6308,
  [6309] = 2814,
  [6310] = 5886,
  [6311] = 6231,
  [6312] = 6312,
  [6313] = 5871,
  [6314] = 6314,
  [6315] = 6315,
  [6316] = 6316,
  [6317] = 6293,
  [6318] = 6231,
  [6319] = 6319,
  [6320] = 5944,
  [6321] = 5871,
  [6322] = 2755,
  [6323] = 6231,
  [6324] = 6243,
  [6325] = 6325,
  [6326] = 5877,
  [6327] = 6293,
  [6328] = 6294,
  [6329] = 6294,
  [6330] = 5696,
  [6331] = 6294,
  [6332] = 6293,
  [6333] = 6235,
  [6334] = 6243,
  [6335] = 2622,
  [6336] = 6294,
  [6337] = 6243,
  [6338] = 6338,
  [6339] = 2213,
  [6340] = 6293,
  [6341] = 6235,
  [6342] = 5881,
  [6343] = 6343,
  [6344] = 6265,
  [6345] = 5983,
  [6346] = 6346,
  [6347] = 6347,
  [6348] = 6348,
  [6349] = 6349,
  [6350] = 6350,
  [6351] = 6351,
  [6352] = 6352,
  [6353] = 6243,
  [6354] = 5708,
  [6355] = 6265,
  [6356] = 2646,
  [6357] = 6357,
  [6358] = 5896,
  [6359] = 6359,
  [6360] = 6360,
  [6361] = 6242,
  [6362] = 6362,
  [6363] = 139,
  [6364] = 6364,
  [6365] = 2764,
  [6366] = 6265,
  [6367] = 6235,
  [6368] = 5882,
  [6369] = 2658,
  [6370] = 2647,
  [6371] = 6243,
  [6372] = 5878,
  [6373] = 6293,
  [6374] = 6294,
  [6375] = 6236,
  [6376] = 5870,
  [6377] = 5676,
  [6378] = 5869,
  [6379] = 5675,
  [6380] = 6231,
  [6381] = 5877,
  [6382] = 5871,
  [6383] = 6383,
  [6384] = 6383,
  [6385] = 6383,
  [6386] = 6383,
  [6387] = 6383,
  [6388] = 6383,
  [6389] = 5877,
  [6390] = 2355,
  [6391] = 2341,
  [6392] = 6392,
  [6393] = 6383,
  [6394] = 6394,
  [6395] = 5881,
  [6396] = 6226,
  [6397] = 5877,
  [6398] = 6398,
  [6399] = 5871,
  [6400] = 130,
  [6401] = 5881,
  [6402] = 6383,
  [6403] = 5870,
  [6404] = 132,
  [6405] = 131,
  [6406] = 5869,
  [6407] = 5859,
  [6408] = 5869,
  [6409] = 136,
  [6410] = 5877,
  [6411] = 5870,
  [6412] = 5882,
  [6413] = 5882,
  [6414] = 5878,
  [6415] = 5878,
  [6416] = 5859,
  [6417] = 5870,
  [6418] = 5869,
  [6419] = 5881,
  [6420] = 5882,
  [6421] = 6383,
  [6422] = 5878,
  [6423] = 6383,
  [6424] = 5871,
  [6425] = 6425,
  [6426] = 6383,
  [6427] = 6427,
  [6428] = 6428,
  [6429] = 6383,
  [6430] = 6383,
  [6431] = 6431,
  [6432] = 6161,
  [6433] = 134,
  [6434] = 128,
  [6435] = 6435,
  [6436] = 129,
  [6437] = 5859,
  [6438] = 6438,
  [6439] = 5944,
  [6440] = 6440,
  [6441] = 6441,
  [6442] = 6442,
  [6443] = 5869,
  [6444] = 5886,
  [6445] = 5881,
  [6446] = 5869,
  [6447] = 133,
  [6448] = 5871,
  [6449] = 6441,
  [6450] = 6440,
  [6451] = 6441,
  [6452] = 5870,
  [6453] = 6453,
  [6454] = 5881,
  [6455] = 6455,
  [6456] = 6441,
  [6457] = 6441,
  [6458] = 6441,
  [6459] = 6441,
  [6460] = 5859,
  [6461] = 6441,
  [6462] = 5882,
  [6463] = 2267,
  [6464] = 6441,
  [6465] = 135,
  [6466] = 6440,
  [6467] = 6441,
  [6468] = 5878,
  [6469] = 5870,
  [6470] = 6455,
  [6471] = 5871,
  [6472] = 6441,
  [6473] = 5877,
  [6474] = 6455,
  [6475] = 6441,
  [6476] = 6441,
  [6477] = 6098,
  [6478] = 6024,
  [6479] = 6441,
  [6480] = 6455,
  [6481] = 6441,
  [6482] = 6441,
  [6483] = 5983,
  [6484] = 6484,
  [6485] = 6441,
  [6486] = 6441,
  [6487] = 6487,
  [6488] = 6441,
  [6489] = 6441,
  [6490] = 6453,
  [6491] = 6455,
  [6492] = 6484,
  [6493] = 5896,
  [6494] = 6440,
  [6495] = 6484,
  [6496] = 5939,
  [6497] = 6441,
  [6498] = 6455,
  [6499] = 6453,
  [6500] = 6455,
  [6501] = 6441,
  [6502] = 6453,
  [6503] = 6484,
  [6504] = 6441,
  [6505] = 6441,
  [6506] = 6441,
  [6507] = 6507,
  [6508] = 6106,
  [6509] = 2575,
  [6510] = 6507,
  [6511] = 2551,
  [6512] = 2540,
  [6513] = 5871,
  [6514] = 6514,
  [6515] = 6515,
  [6516] = 6507,
  [6517] = 6517,
  [6518] = 6518,
  [6519] = 6519,
  [6520] = 6519,
  [6521] = 6521,
  [6522] = 6040,
  [6523] = 6523,
  [6524] = 6524,
  [6525] = 6024,
  [6526] = 5995,
  [6527] = 6524,
  [6528] = 6048,
  [6529] = 2537,
  [6530] = 5896,
  [6531] = 6531,
  [6532] = 6532,
  [6533] = 5944,
  [6534] = 6058,
  [6535] = 5939,
  [6536] = 2541,
  [6537] = 6537,
  [6538] = 6538,
  [6539] = 5870,
  [6540] = 6524,
  [6541] = 6517,
  [6542] = 6519,
  [6543] = 6543,
  [6544] = 6544,
  [6545] = 6545,
  [6546] = 5881,
  [6547] = 5869,
  [6548] = 5983,
  [6549] = 6507,
  [6550] = 5886,
  [6551] = 6507,
  [6552] = 6507,
  [6553] = 6519,
  [6554] = 2750,
  [6555] = 6098,
  [6556] = 6524,
  [6557] = 6557,
  [6558] = 6507,
  [6559] = 6559,
  [6560] = 6560,
  [6561] = 6561,
  [6562] = 5859,
  [6563] = 5882,
  [6564] = 5877,
  [6565] = 5869,
  [6566] = 6566,
  [6567] = 6567,
  [6568] = 6566,
  [6569] = 6569,
  [6570] = 6567,
  [6571] = 5871,
  [6572] = 6569,
  [6573] = 5870,
  [6574] = 5869,
  [6575] = 6575,
  [6576] = 5871,
  [6577] = 5881,
  [6578] = 5870,
  [6579] = 2225,
  [6580] = 6580,
  [6581] = 6566,
  [6582] = 6567,
  [6583] = 6583,
  [6584] = 2551,
  [6585] = 2537,
  [6586] = 6580,
  [6587] = 6567,
  [6588] = 6588,
  [6589] = 2540,
  [6590] = 5882,
  [6591] = 6580,
  [6592] = 5869,
  [6593] = 5859,
  [6594] = 5881,
  [6595] = 2642,
  [6596] = 2541,
  [6597] = 5878,
  [6598] = 5881,
  [6599] = 6599,
  [6600] = 5869,
  [6601] = 5870,
  [6602] = 5870,
  [6603] = 5881,
  [6604] = 6604,
  [6605] = 6566,
  [6606] = 2750,
  [6607] = 2223,
  [6608] = 5878,
  [6609] = 6569,
  [6610] = 6610,
  [6611] = 5877,
  [6612] = 6612,
  [6613] = 5871,
  [6614] = 6580,
  [6615] = 5871,
  [6616] = 6569,
  [6617] = 2575,
  [6618] = 2219,
  [6619] = 6619,
  [6620] = 6208,
  [6621] = 6621,
  [6622] = 6622,
  [6623] = 6214,
  [6624] = 6624,
  [6625] = 6622,
  [6626] = 6626,
  [6627] = 6622,
  [6628] = 6626,
  [6629] = 6626,
  [6630] = 6630,
  [6631] = 6626,
  [6632] = 6622,
  [6633] = 6633,
  [6634] = 6634,
  [6635] = 6626,
  [6636] = 6626,
  [6637] = 6637,
  [6638] = 6624,
  [6639] = 6639,
  [6640] = 2750,
  [6641] = 6621,
  [6642] = 6642,
  [6643] = 6622,
  [6644] = 6644,
  [6645] = 6639,
  [6646] = 6646,
  [6647] = 6202,
  [6648] = 6624,
  [6649] = 6622,
  [6650] = 2750,
  [6651] = 6624,
  [6652] = 6646,
  [6653] = 6621,
  [6654] = 6654,
  [6655] = 6624,
  [6656] = 6621,
  [6657] = 2642,
  [6658] = 6658,
  [6659] = 6659,
  [6660] = 6621,
  [6661] = 6624,
  [6662] = 6662,
  [6663] = 6663,
  [6664] = 6621,
  [6665] = 6665,
  [6666] = 6666,
  [6667] = 6667,
  [6668] = 6626,
  [6669] = 6622,
  [6670] = 6624,
  [6671] = 6621,
  [6672] = 6672,
  [6673] = 6673,
  [6674] = 6674,
  [6675] = 6675,
  [6676] = 6676,
  [6677] = 6677,
  [6678] = 6678,
  [6679] = 5877,
  [6680] = 6673,
  [6681] = 6677,
  [6682] = 6682,
  [6683] = 6683,
  [6684] = 6684,
  [6685] = 6682,
  [6686] = 5882,
  [6687] = 5878,
  [6688] = 6673,
  [6689] = 6689,
  [6690] = 6690,
  [6691] = 6691,
  [6692] = 6692,
  [6693] = 6672,
  [6694] = 5859,
  [6695] = 6695,
  [6696] = 2678,
  [6697] = 6697,
  [6698] = 6683,
  [6699] = 6699,
  [6700] = 6691,
  [6701] = 6690,
  [6702] = 6677,
  [6703] = 6689,
  [6704] = 6677,
  [6705] = 6678,
  [6706] = 6673,
  [6707] = 6672,
  [6708] = 6692,
  [6709] = 6691,
  [6710] = 6674,
  [6711] = 6690,
  [6712] = 6675,
  [6713] = 6689,
  [6714] = 6714,
  [6715] = 6715,
  [6716] = 6678,
  [6717] = 6674,
  [6718] = 6718,
  [6719] = 6692,
  [6720] = 2750,
  [6721] = 6675,
  [6722] = 2750,
  [6723] = 6723,
  [6724] = 6673,
  [6725] = 6725,
  [6726] = 6726,
  [6727] = 6727,
  [6728] = 6728,
  [6729] = 6729,
  [6730] = 6730,
  [6731] = 6731,
  [6732] = 6732,
  [6733] = 6729,
  [6734] = 6734,
  [6735] = 6735,
  [6736] = 6730,
  [6737] = 6737,
  [6738] = 6738,
  [6739] = 6739,
  [6740] = 6740,
  [6741] = 6741,
  [6742] = 6742,
  [6743] = 6743,
  [6744] = 6744,
  [6745] = 6744,
  [6746] = 6742,
  [6747] = 6747,
  [6748] = 6743,
  [6749] = 6729,
  [6750] = 6729,
  [6751] = 6737,
  [6752] = 6734,
  [6753] = 6735,
  [6754] = 6744,
  [6755] = 6755,
  [6756] = 6756,
  [6757] = 6742,
  [6758] = 6729,
  [6759] = 6743,
  [6760] = 6760,
  [6761] = 6739,
  [6762] = 6742,
  [6763] = 6763,
  [6764] = 6743,
  [6765] = 6737,
  [6766] = 6741,
  [6767] = 6744,
  [6768] = 6768,
  [6769] = 6729,
  [6770] = 6770,
  [6771] = 6771,
  [6772] = 6737,
  [6773] = 6760,
  [6774] = 6744,
  [6775] = 6775,
  [6776] = 6729,
  [6777] = 6777,
  [6778] = 6778,
  [6779] = 6737,
  [6780] = 6729,
  [6781] = 6777,
  [6782] = 6782,
  [6783] = 6771,
  [6784] = 6744,
  [6785] = 6742,
  [6786] = 6737,
  [6787] = 6787,
  [6788] = 6729,
  [6789] = 6768,
  [6790] = 6790,
  [6791] = 6791,
  [6792] = 6737,
  [6793] = 6763,
  [6794] = 6763,
  [6795] = 6768,
  [6796] = 6771,
  [6797] = 6791,
  [6798] = 6744,
  [6799] = 6770,
  [6800] = 6800,
  [6801] = 6787,
  [6802] = 6729,
  [6803] = 6800,
  [6804] = 6742,
  [6805] = 6732,
  [6806] = 6737,
  [6807] = 6756,
  [6808] = 6808,
  [6809] = 6760,
  [6810] = 6744,
  [6811] = 6791,
  [6812] = 6732,
  [6813] = 6744,
  [6814] = 6814,
  [6815] = 6729,
  [6816] = 6740,
  [6817] = 6740,
  [6818] = 6729,
  [6819] = 6741,
  [6820] = 6739,
  [6821] = 6791,
  [6822] = 6737,
  [6823] = 6787,
  [6824] = 6729,
  [6825] = 6825,
  [6826] = 6735,
  [6827] = 6734,
  [6828] = 6730,
  [6829] = 6744,
  [6830] = 6741,
  [6831] = 6744,
  [6832] = 6756,
  [6833] = 6742,
  [6834] = 6739,
  [6835] = 6791,
  [6836] = 6747,
  [6837] = 6787,
  [6838] = 6737,
  [6839] = 6771,
  [6840] = 6729,
  [6841] = 6841,
  [6842] = 6770,
  [6843] = 6768,
  [6844] = 6800,
  [6845] = 6770,
  [6846] = 6737,
  [6847] = 6760,
  [6848] = 6787,
  [6849] = 6841,
  [6850] = 6850,
  [6851] = 6851,
  [6852] = 6747,
  [6853] = 6727,
  [6854] = 6729,
  [6855] = 6855,
  [6856] = 6743,
  [6857] = 6744,
  [6858] = 6768,
  [6859] = 6787,
  [6860] = 6744,
  [6861] = 6755,
  [6862] = 6756,
  [6863] = 6863,
  [6864] = 6864,
  [6865] = 6763,
  [6866] = 6866,
  [6867] = 6740,
  [6868] = 6732,
  [6869] = 6730,
  [6870] = 6841,
  [6871] = 6747,
  [6872] = 6740,
  [6873] = 6747,
  [6874] = 6729,
  [6875] = 6756,
  [6876] = 6730,
  [6877] = 6728,
  [6878] = 6841,
  [6879] = 6732,
  [6880] = 6756,
  [6881] = 6729,
  [6882] = 6882,
  [6883] = 6791,
  [6884] = 6763,
  [6885] = 6743,
  [6886] = 6800,
  [6887] = 6727,
  [6888] = 6888,
  [6889] = 6787,
  [6890] = 6791,
  [6891] = 6737,
  [6892] = 6787,
  [6893] = 6755,
  [6894] = 6735,
  [6895] = 6737,
  [6896] = 6727,
  [6897] = 6791,
  [6898] = 6800,
  [6899] = 6727,
  [6900] = 6740,
  [6901] = 6727,
  [6902] = 6777,
  [6903] = 6903,
  [6904] = 6747,
  [6905] = 6730,
  [6906] = 6906,
  [6907] = 6743,
  [6908] = 6760,
  [6909] = 6760,
  [6910] = 6734,
  [6911] = 6730,
  [6912] = 6734,
  [6913] = 6735,
  [6914] = 6729,
  [6915] = 6744,
  [6916] = 6777,
  [6917] = 6917,
  [6918] = 6737,
  [6919] = 6787,
  [6920] = 6735,
  [6921] = 6743,
  [6922] = 6729,
  [6923] = 6727,
  [6924] = 6768,
  [6925] = 6763,
  [6926] = 6770,
  [6927] = 6732,
  [6928] = 6791,
  [6929] = 6929,
  [6930] = 6735,
  [6931] = 6734,
  [6932] = 6739,
  [6933] = 6755,
  [6934] = 6741,
  [6935] = 6763,
  [6936] = 6730,
  [6937] = 6737,
  [6938] = 6841,
  [6939] = 6728,
  [6940] = 6768,
  [6941] = 6729,
  [6942] = 6747,
  [6943] = 6943,
  [6944] = 6755,
  [6945] = 6756,
  [6946] = 6787,
  [6947] = 6756,
  [6948] = 6948,
  [6949] = 6755,
  [6950] = 6729,
  [6951] = 6727,
  [6952] = 6760,
  [6953] = 6737,
  [6954] = 6737,
  [6955] = 6740,
  [6956] = 6787,
  [6957] = 6957,
  [6958] = 6791,
  [6959] = 6744,
  [6960] = 6756,
  [6961] = 6800,
  [6962] = 6744,
  [6963] = 6756,
  [6964] = 6742,
  [6965] = 6965,
  [6966] = 6966,
  [6967] = 6730,
  [6968] = 6968,
  [6969] = 6744,
  [6970] = 6760,
  [6971] = 6734,
  [6972] = 6744,
  [6973] = 6744,
  [6974] = 6742,
  [6975] = 6770,
  [6976] = 6734,
  [6977] = 6735,
  [6978] = 6763,
  [6979] = 6743,
  [6980] = 6739,
  [6981] = 6728,
  [6982] = 6741,
  [6983] = 6727,
  [6984] = 6841,
  [6985] = 6728,
  [6986] = 6756,
  [6987] = 6768,
  [6988] = 6755,
  [6989] = 6791,
  [6990] = 6768,
  [6991] = 6756,
  [6992] = 6791,
  [6993] = 6770,
  [6994] = 6787,
  [6995] = 6737,
  [6996] = 6996,
  [6997] = 6763,
  [6998] = 6024,
  [6999] = 6771,
  [7000] = 6729,
  [7001] = 6760,
  [7002] = 6730,
  [7003] = 6755,
  [7004] = 6763,
  [7005] = 6727,
  [7006] = 6728,
  [7007] = 6734,
  [7008] = 6735,
  [7009] = 6755,
  [7010] = 6800,
  [7011] = 6737,
  [7012] = 6771,
  [7013] = 7013,
  [7014] = 7014,
  [7015] = 7015,
  [7016] = 7016,
  [7017] = 7017,
  [7018] = 7018,
  [7019] = 7019,
  [7020] = 7020,
  [7021] = 7021,
  [7022] = 7022,
  [7023] = 7023,
  [7024] = 7024,
  [7025] = 7025,
  [7026] = 7026,
  [7027] = 7027,
  [7028] = 7028,
  [7029] = 7029,
  [7030] = 7030,
  [7031] = 7031,
  [7032] = 7032,
  [7033] = 7033,
  [7034] = 7030,
  [7035] = 7035,
  [7036] = 7036,
  [7037] = 7037,
  [7038] = 7038,
  [7039] = 7039,
  [7040] = 7040,
  [7041] = 7041,
  [7042] = 7042,
  [7043] = 7043,
  [7044] = 7044,
  [7045] = 7045,
  [7046] = 7046,
  [7047] = 7046,
  [7048] = 7045,
  [7049] = 7044,
  [7050] = 7050,
  [7051] = 7051,
  [7052] = 7027,
  [7053] = 7053,
  [7054] = 7054,
  [7055] = 7019,
  [7056] = 7056,
  [7057] = 7057,
  [7058] = 7058,
  [7059] = 7023,
  [7060] = 7033,
  [7061] = 7061,
  [7062] = 7062,
  [7063] = 7063,
  [7064] = 7064,
  [7065] = 7065,
  [7066] = 7066,
  [7067] = 7067,
  [7068] = 7054,
  [7069] = 7019,
  [7070] = 7039,
  [7071] = 7025,
  [7072] = 7072,
  [7073] = 7057,
  [7074] = 7074,
  [7075] = 7075,
  [7076] = 7025,
  [7077] = 7018,
  [7078] = 7038,
  [7079] = 7079,
  [7080] = 7080,
  [7081] = 7081,
  [7082] = 7041,
  [7083] = 7040,
  [7084] = 7039,
  [7085] = 7085,
  [7086] = 7086,
  [7087] = 7087,
  [7088] = 7088,
  [7089] = 7044,
  [7090] = 7045,
  [7091] = 7091,
  [7092] = 7092,
  [7093] = 7065,
  [7094] = 7046,
  [7095] = 7037,
  [7096] = 7026,
  [7097] = 7050,
  [7098] = 7098,
  [7099] = 7029,
  [7100] = 7100,
  [7101] = 7017,
  [7102] = 7057,
  [7103] = 7018,
  [7104] = 7017,
  [7105] = 7018,
  [7106] = 7051,
  [7107] = 6544,
  [7108] = 7019,
  [7109] = 7085,
  [7110] = 170,
  [7111] = 7020,
  [7112] = 7023,
  [7113] = 7027,
  [7114] = 7037,
  [7115] = 7030,
  [7116] = 7058,
  [7117] = 7066,
  [7118] = 7016,
  [7119] = 7040,
  [7120] = 7041,
  [7121] = 7033,
  [7122] = 7086,
  [7123] = 7061,
  [7124] = 7038,
  [7125] = 7085,
  [7126] = 7065,
  [7127] = 7127,
  [7128] = 7067,
  [7129] = 7046,
  [7130] = 7045,
  [7131] = 7044,
  [7132] = 7132,
  [7133] = 7042,
  [7134] = 7134,
  [7135] = 7017,
  [7136] = 7044,
  [7137] = 7021,
  [7138] = 7019,
  [7139] = 7029,
  [7140] = 7045,
  [7141] = 7046,
  [7142] = 7142,
  [7143] = 7050,
  [7144] = 7051,
  [7145] = 7038,
  [7146] = 7075,
  [7147] = 7026,
  [7148] = 7021,
  [7149] = 7054,
  [7150] = 7057,
  [7151] = 7151,
  [7152] = 7026,
  [7153] = 7044,
  [7154] = 7045,
  [7155] = 7021,
  [7156] = 7156,
  [7157] = 7079,
  [7158] = 7029,
  [7159] = 7046,
  [7160] = 7041,
  [7161] = 7040,
  [7162] = 7050,
  [7163] = 7163,
  [7164] = 7029,
  [7165] = 7165,
  [7166] = 7040,
  [7167] = 7033,
  [7168] = 7041,
  [7169] = 7169,
  [7170] = 7051,
  [7171] = 7016,
  [7172] = 7037,
  [7173] = 7066,
  [7174] = 171,
  [7175] = 7175,
  [7176] = 7100,
  [7177] = 7037,
  [7178] = 7081,
  [7179] = 7156,
  [7180] = 7180,
  [7181] = 7181,
  [7182] = 7182,
  [7183] = 7030,
  [7184] = 7045,
  [7185] = 7046,
  [7186] = 7045,
  [7187] = 7044,
  [7188] = 7156,
  [7189] = 7066,
  [7190] = 7056,
  [7191] = 7191,
  [7192] = 7033,
  [7193] = 7033,
  [7194] = 7194,
  [7195] = 7042,
  [7196] = 7043,
  [7197] = 2750,
  [7198] = 7100,
  [7199] = 7199,
  [7200] = 7029,
  [7201] = 7201,
  [7202] = 7037,
  [7203] = 7026,
  [7204] = 7204,
  [7205] = 7205,
  [7206] = 7029,
  [7207] = 7042,
  [7208] = 7054,
  [7209] = 7051,
  [7210] = 7210,
  [7211] = 7021,
  [7212] = 7037,
  [7213] = 7046,
  [7214] = 7045,
  [7215] = 7044,
  [7216] = 7216,
  [7217] = 7040,
  [7218] = 7041,
  [7219] = 7219,
  [7220] = 7220,
  [7221] = 7025,
  [7222] = 7067,
  [7223] = 7079,
  [7224] = 7224,
  [7225] = 7079,
  [7226] = 7065,
  [7227] = 7227,
  [7228] = 7016,
  [7229] = 7081,
  [7230] = 7230,
  [7231] = 7016,
  [7232] = 7017,
  [7233] = 7029,
  [7234] = 7018,
  [7235] = 7156,
  [7236] = 7067,
  [7237] = 7237,
  [7238] = 7037,
  [7239] = 7046,
  [7240] = 7045,
  [7241] = 7044,
  [7242] = 7041,
  [7243] = 7058,
  [7244] = 7040,
  [7245] = 7245,
  [7246] = 7057,
  [7247] = 7247,
  [7248] = 7248,
  [7249] = 7249,
  [7250] = 7043,
  [7251] = 7251,
  [7252] = 7019,
  [7253] = 7051,
  [7254] = 7254,
  [7255] = 7029,
  [7256] = 7256,
  [7257] = 7023,
  [7258] = 7029,
  [7259] = 7027,
  [7260] = 7050,
  [7261] = 7046,
  [7262] = 7027,
  [7263] = 7037,
  [7264] = 7046,
  [7265] = 7045,
  [7266] = 7044,
  [7267] = 7044,
  [7268] = 7016,
  [7269] = 7042,
  [7270] = 7054,
  [7271] = 7271,
  [7272] = 7272,
  [7273] = 7030,
  [7274] = 7025,
  [7275] = 7056,
  [7276] = 7276,
  [7277] = 7038,
  [7278] = 7194,
  [7279] = 7067,
  [7280] = 7029,
  [7281] = 7075,
  [7282] = 7038,
  [7283] = 7039,
  [7284] = 7065,
  [7285] = 7037,
  [7286] = 7046,
  [7287] = 7045,
  [7288] = 7044,
  [7289] = 7021,
  [7290] = 7030,
  [7291] = 7291,
  [7292] = 7017,
  [7293] = 7018,
  [7294] = 7021,
  [7295] = 7019,
  [7296] = 7037,
  [7297] = 7297,
  [7298] = 7037,
  [7299] = 7019,
  [7300] = 7023,
  [7301] = 7029,
  [7302] = 7044,
  [7303] = 7045,
  [7304] = 7046,
  [7305] = 7027,
  [7306] = 7037,
  [7307] = 7046,
  [7308] = 7045,
  [7309] = 7044,
  [7310] = 7050,
  [7311] = 7311,
  [7312] = 7066,
  [7313] = 7313,
  [7314] = 7061,
  [7315] = 7027,
  [7316] = 7316,
  [7317] = 7023,
  [7318] = 7057,
  [7319] = 7019,
  [7320] = 7018,
  [7321] = 7029,
  [7322] = 7042,
  [7323] = 7026,
  [7324] = 7017,
  [7325] = 7037,
  [7326] = 7046,
  [7327] = 7045,
  [7328] = 7044,
  [7329] = 7058,
  [7330] = 7330,
  [7331] = 7331,
  [7332] = 7061,
  [7333] = 7030,
  [7334] = 7100,
  [7335] = 7335,
  [7336] = 7057,
  [7337] = 7065,
  [7338] = 7067,
  [7339] = 7029,
  [7340] = 7026,
  [7341] = 7054,
  [7342] = 7038,
  [7343] = 7037,
  [7344] = 7046,
  [7345] = 7045,
  [7346] = 7044,
  [7347] = 164,
  [7348] = 7348,
  [7349] = 7349,
  [7350] = 7026,
  [7351] = 7044,
  [7352] = 7045,
  [7353] = 7046,
  [7354] = 7354,
  [7355] = 7029,
  [7356] = 7356,
  [7357] = 7357,
  [7358] = 7050,
  [7359] = 7037,
  [7360] = 7046,
  [7361] = 7045,
  [7362] = 7044,
  [7363] = 7051,
  [7364] = 7057,
  [7365] = 7058,
  [7366] = 7079,
  [7367] = 7029,
  [7368] = 7057,
  [7369] = 7054,
  [7370] = 7085,
  [7371] = 7037,
  [7372] = 7046,
  [7373] = 7045,
  [7374] = 7044,
  [7375] = 7016,
  [7376] = 7376,
  [7377] = 7029,
  [7378] = 7057,
  [7379] = 7020,
  [7380] = 7037,
  [7381] = 7046,
  [7382] = 7045,
  [7383] = 7044,
  [7384] = 7016,
  [7385] = 7205,
  [7386] = 7065,
  [7387] = 7079,
  [7388] = 7037,
  [7389] = 7046,
  [7390] = 7045,
  [7391] = 7044,
  [7392] = 7029,
  [7393] = 7066,
  [7394] = 7033,
  [7395] = 7395,
  [7396] = 7037,
  [7397] = 7046,
  [7398] = 7045,
  [7399] = 7044,
  [7400] = 7043,
  [7401] = 7079,
  [7402] = 7041,
  [7403] = 7040,
  [7404] = 7404,
  [7405] = 7081,
  [7406] = 7406,
  [7407] = 7041,
  [7408] = 7040,
  [7409] = 7058,
  [7410] = 7043,
  [7411] = 7029,
  [7412] = 7057,
  [7413] = 7413,
  [7414] = 7414,
  [7415] = 7037,
  [7416] = 7025,
  [7417] = 7205,
  [7418] = 7021,
  [7419] = 7037,
  [7420] = 7023,
  [7421] = 7057,
  [7422] = 7100,
  [7423] = 7100,
  [7424] = 7424,
  [7425] = 7100,
  [7426] = 7029,
  [7427] = 7427,
  [7428] = 7043,
  [7429] = 7042,
  [7430] = 7085,
  [7431] = 7020,
  [7432] = 7026,
  [7433] = 7433,
  [7434] = 7085,
  [7435] = 7066,
  [7436] = 7029,
  [7437] = 7437,
  [7438] = 7033,
  [7439] = 7439,
  [7440] = 7440,
  [7441] = 2808,
  [7442] = 7442,
  [7443] = 7443,
  [7444] = 2809,
  [7445] = 7445,
  [7446] = 2823,
  [7447] = 2827,
  [7448] = 2833,
  [7449] = 7449,
  [7450] = 7450,
  [7451] = 7451,
  [7452] = 7452,
  [7453] = 7453,
  [7454] = 2852,
  [7455] = 2830,
  [7456] = 7456,
  [7457] = 7457,
  [7458] = 7458,
  [7459] = 7459,
  [7460] = 7460,
  [7461] = 7457,
  [7462] = 7439,
  [7463] = 7457,
  [7464] = 7457,
  [7465] = 7460,
  [7466] = 7466,
  [7467] = 7457,
  [7468] = 7457,
  [7469] = 7457,
  [7470] = 7460,
  [7471] = 7471,
  [7472] = 7457,
  [7473] = 7457,
  [7474] = 7460,
  [7475] = 7457,
  [7476] = 2829,
  [7477] = 7477,
  [7478] = 7457,
  [7479] = 7452,
  [7480] = 7480,
  [7481] = 7457,
  [7482] = 2834,
  [7483] = 7460,
  [7484] = 7477,
  [7485] = 2797,
  [7486] = 7457,
  [7487] = 7460,
  [7488] = 7477,
  [7489] = 7442,
  [7490] = 7451,
  [7491] = 7460,
  [7492] = 7457,
  [7493] = 7477,
  [7494] = 7450,
  [7495] = 7457,
  [7496] = 7496,
  [7497] = 7460,
  [7498] = 7450,
  [7499] = 7443,
  [7500] = 7477,
  [7501] = 7457,
  [7502] = 7502,
  [7503] = 7503,
  [7504] = 7504,
  [7505] = 7504,
  [7506] = 7460,
  [7507] = 7477,
  [7508] = 7477,
  [7509] = 7509,
  [7510] = 7503,
  [7511] = 7477,
  [7512] = 7456,
  [7513] = 7513,
  [7514] = 7514,
  [7515] = 7515,
  [7516] = 7516,
  [7517] = 7517,
  [7518] = 7518,
  [7519] = 7509,
  [7520] = 7515,
  [7521] = 7521,
  [7522] = 7522,
  [7523] = 7523,
  [7524] = 7524,
  [7525] = 7523,
  [7526] = 7516,
  [7527] = 7457,
  [7528] = 7517,
  [7529] = 7529,
  [7530] = 7440,
  [7531] = 7531,
  [7532] = 7532,
  [7533] = 7460,
  [7534] = 7534,
  [7535] = 7509,
  [7536] = 7460,
  [7537] = 7459,
  [7538] = 7445,
  [7539] = 7477,
  [7540] = 7540,
  [7541] = 7440,
  [7542] = 7542,
  [7543] = 7449,
  [7544] = 7517,
  [7545] = 7516,
  [7546] = 7546,
  [7547] = 7547,
  [7548] = 7548,
  [7549] = 7466,
  [7550] = 7515,
  [7551] = 7551,
  [7552] = 7453,
  [7553] = 7439,
  [7554] = 7509,
  [7555] = 7453,
  [7556] = 7456,
  [7557] = 7513,
  [7558] = 7558,
  [7559] = 7516,
  [7560] = 7517,
  [7561] = 7561,
  [7562] = 7562,
  [7563] = 7563,
  [7564] = 7440,
  [7565] = 7523,
  [7566] = 7460,
  [7567] = 7524,
  [7568] = 7458,
  [7569] = 7515,
  [7570] = 7570,
  [7571] = 7509,
  [7572] = 7572,
  [7573] = 7573,
  [7574] = 7515,
  [7575] = 7575,
  [7576] = 7516,
  [7577] = 7517,
  [7578] = 7578,
  [7579] = 7579,
  [7580] = 7580,
  [7581] = 7509,
  [7582] = 7582,
  [7583] = 7477,
  [7584] = 7584,
  [7585] = 7522,
  [7586] = 7586,
  [7587] = 7584,
  [7588] = 7442,
  [7589] = 7589,
  [7590] = 7590,
  [7591] = 7450,
  [7592] = 7503,
  [7593] = 7477,
  [7594] = 7594,
  [7595] = 7515,
  [7596] = 7570,
  [7597] = 7515,
  [7598] = 7598,
  [7599] = 7523,
  [7600] = 7600,
  [7601] = 7601,
  [7602] = 7524,
  [7603] = 7509,
  [7604] = 7456,
  [7605] = 7513,
  [7606] = 7516,
  [7607] = 7517,
  [7608] = 7608,
  [7609] = 7522,
  [7610] = 7610,
  [7611] = 7440,
  [7612] = 7612,
  [7613] = 7524,
  [7614] = 7529,
  [7615] = 7460,
  [7616] = 7616,
  [7617] = 7524,
  [7618] = 7618,
  [7619] = 7619,
  [7620] = 7534,
  [7621] = 7509,
  [7622] = 7622,
  [7623] = 7460,
  [7624] = 7521,
  [7625] = 7542,
  [7626] = 7540,
  [7627] = 7440,
  [7628] = 7477,
  [7629] = 7529,
  [7630] = 7516,
  [7631] = 7517,
  [7632] = 7449,
  [7633] = 7466,
  [7634] = 7453,
  [7635] = 7439,
  [7636] = 7445,
  [7637] = 7582,
  [7638] = 7570,
  [7639] = 7442,
  [7640] = 7445,
  [7641] = 7558,
  [7642] = 7523,
  [7643] = 7561,
  [7644] = 7439,
  [7645] = 7562,
  [7646] = 7523,
  [7647] = 7521,
  [7648] = 7534,
  [7649] = 7445,
  [7650] = 7443,
  [7651] = 7452,
  [7652] = 7515,
  [7653] = 7516,
  [7654] = 7517,
  [7655] = 7570,
  [7656] = 7440,
  [7657] = 7657,
  [7658] = 7572,
  [7659] = 7460,
  [7660] = 7534,
  [7661] = 7459,
  [7662] = 7529,
  [7663] = 7524,
  [7664] = 7664,
  [7665] = 7563,
  [7666] = 7582,
  [7667] = 7509,
  [7668] = 7558,
  [7669] = 7561,
  [7670] = 7670,
  [7671] = 7573,
  [7672] = 7521,
  [7673] = 7575,
  [7674] = 7578,
  [7675] = 7477,
  [7676] = 7579,
  [7677] = 7580,
  [7678] = 7445,
  [7679] = 7584,
  [7680] = 7443,
  [7681] = 7681,
  [7682] = 7584,
  [7683] = 7452,
  [7684] = 7684,
  [7685] = 7580,
  [7686] = 7579,
  [7687] = 7477,
  [7688] = 7578,
  [7689] = 7575,
  [7690] = 7563,
  [7691] = 7459,
  [7692] = 7466,
  [7693] = 7521,
  [7694] = 7570,
  [7695] = 7580,
  [7696] = 7515,
  [7697] = 7579,
  [7698] = 7578,
  [7699] = 7523,
  [7700] = 7562,
  [7701] = 7561,
  [7702] = 7558,
  [7703] = 7582,
  [7704] = 7460,
  [7705] = 7439,
  [7706] = 7575,
  [7707] = 7707,
  [7708] = 7708,
  [7709] = 7709,
  [7710] = 7710,
  [7711] = 7458,
  [7712] = 7503,
  [7713] = 7445,
  [7714] = 7443,
  [7715] = 7516,
  [7716] = 7517,
  [7717] = 7477,
  [7718] = 7440,
  [7719] = 7452,
  [7720] = 7563,
  [7721] = 7542,
  [7722] = 7523,
  [7723] = 7459,
  [7724] = 7509,
  [7725] = 7460,
  [7726] = 7513,
  [7727] = 7534,
  [7728] = 7570,
  [7729] = 7529,
  [7730] = 7524,
  [7731] = 7521,
  [7732] = 7522,
  [7733] = 7514,
  [7734] = 7509,
  [7735] = 7573,
  [7736] = 7524,
  [7737] = 7529,
  [7738] = 7442,
  [7739] = 7534,
  [7740] = 7460,
  [7741] = 7542,
  [7742] = 7540,
  [7743] = 7477,
  [7744] = 7458,
  [7745] = 7503,
  [7746] = 7440,
  [7747] = 7449,
  [7748] = 7442,
  [7749] = 7515,
  [7750] = 7445,
  [7751] = 7517,
  [7752] = 7516,
  [7753] = 7443,
  [7754] = 7451,
  [7755] = 7584,
  [7756] = 7452,
  [7757] = 7466,
  [7758] = 7758,
  [7759] = 7580,
  [7760] = 7579,
  [7761] = 7761,
  [7762] = 7563,
  [7763] = 7439,
  [7764] = 7578,
  [7765] = 7453,
  [7766] = 7575,
  [7767] = 7452,
  [7768] = 7459,
  [7769] = 7582,
  [7770] = 7451,
  [7771] = 7558,
  [7772] = 7450,
  [7773] = 7561,
  [7774] = 7562,
  [7775] = 7523,
  [7776] = 7443,
  [7777] = 7521,
  [7778] = 7514,
  [7779] = 7515,
  [7780] = 7780,
  [7781] = 7514,
  [7782] = 7542,
  [7783] = 7477,
  [7784] = 7570,
  [7785] = 7515,
  [7786] = 7572,
  [7787] = 7787,
  [7788] = 7573,
  [7789] = 7789,
  [7790] = 7523,
  [7791] = 7445,
  [7792] = 7449,
  [7793] = 7575,
  [7794] = 7578,
  [7795] = 7456,
  [7796] = 7458,
  [7797] = 7561,
  [7798] = 7558,
  [7799] = 7582,
  [7800] = 7579,
  [7801] = 7458,
  [7802] = 7516,
  [7803] = 7517,
  [7804] = 7456,
  [7805] = 7580,
  [7806] = 7449,
  [7807] = 7445,
  [7808] = 7477,
  [7809] = 7584,
  [7810] = 7540,
  [7811] = 7443,
  [7812] = 7450,
  [7813] = 7451,
  [7814] = 7452,
  [7815] = 7442,
  [7816] = 7516,
  [7817] = 7517,
  [7818] = 7503,
  [7819] = 7819,
  [7820] = 7440,
  [7821] = 7477,
  [7822] = 7572,
  [7823] = 7570,
  [7824] = 7563,
  [7825] = 7514,
  [7826] = 7542,
  [7827] = 7521,
  [7828] = 7460,
  [7829] = 7534,
  [7830] = 7830,
  [7831] = 7529,
  [7832] = 7524,
  [7833] = 7459,
  [7834] = 7513,
  [7835] = 7509,
  [7836] = 7453,
  [7837] = 7837,
  [7838] = 7838,
  [7839] = 7839,
  [7840] = 7840,
  [7841] = 7841,
  [7842] = 7842,
  [7843] = 7843,
  [7844] = 7844,
  [7845] = 7845,
  [7846] = 7846,
  [7847] = 7847,
  [7848] = 7848,
  [7849] = 7849,
  [7850] = 7850,
  [7851] = 7851,
  [7852] = 7852,
  [7853] = 7853,
  [7854] = 7854,
  [7855] = 7855,
  [7856] = 7856,
  [7857] = 7857,
  [7858] = 7837,
  [7859] = 7859,
  [7860] = 7860,
  [7861] = 7861,
  [7862] = 7862,
  [7863] = 7863,
  [7864] = 7864,
  [7865] = 7865,
  [7866] = 7866,
  [7867] = 7867,
  [7868] = 7865,
  [7869] = 7869,
  [7870] = 7848,
  [7871] = 7871,
  [7872] = 7872,
  [7873] = 7873,
  [7874] = 7874,
  [7875] = 7875,
  [7876] = 7844,
  [7877] = 7877,
  [7878] = 7878,
  [7879] = 7837,
  [7880] = 7880,
  [7881] = 7881,
  [7882] = 7882,
  [7883] = 7883,
  [7884] = 7884,
  [7885] = 7885,
  [7886] = 7886,
  [7887] = 7887,
  [7888] = 7888,
  [7889] = 7889,
  [7890] = 7890,
  [7891] = 7891,
  [7892] = 7892,
  [7893] = 7856,
  [7894] = 7894,
  [7895] = 7895,
  [7896] = 7855,
  [7897] = 7897,
  [7898] = 7898,
  [7899] = 7899,
  [7900] = 7900,
  [7901] = 7901,
  [7902] = 7838,
  [7903] = 7853,
  [7904] = 7904,
  [7905] = 7905,
  [7906] = 7906,
  [7907] = 7907,
  [7908] = 7908,
  [7909] = 7909,
  [7910] = 7910,
  [7911] = 7911,
  [7912] = 7912,
  [7913] = 7913,
  [7914] = 7914,
  [7915] = 7915,
  [7916] = 7916,
  [7917] = 7843,
  [7918] = 7918,
  [7919] = 7919,
  [7920] = 7920,
  [7921] = 7921,
  [7922] = 7922,
  [7923] = 7923,
  [7924] = 7872,
  [7925] = 7871,
  [7926] = 7906,
  [7927] = 7927,
  [7928] = 7863,
  [7929] = 7923,
  [7930] = 7930,
  [7931] = 7853,
  [7932] = 7862,
  [7933] = 7933,
  [7934] = 7933,
  [7935] = 7905,
  [7936] = 7923,
  [7937] = 7841,
  [7938] = 7847,
  [7939] = 7939,
  [7940] = 7845,
  [7941] = 7941,
  [7942] = 7922,
  [7943] = 7871,
  [7944] = 7841,
  [7945] = 7872,
  [7946] = 7846,
  [7947] = 7898,
  [7948] = 7948,
  [7949] = 7844,
  [7950] = 7922,
  [7951] = 7951,
  [7952] = 7952,
  [7953] = 7953,
  [7954] = 7918,
  [7955] = 7847,
  [7956] = 7939,
  [7957] = 7843,
  [7958] = 7916,
  [7959] = 7915,
  [7960] = 7837,
  [7961] = 7889,
  [7962] = 7888,
  [7963] = 7864,
  [7964] = 7914,
  [7965] = 7867,
  [7966] = 7913,
  [7967] = 7869,
  [7968] = 7968,
  [7969] = 7888,
  [7970] = 7933,
  [7971] = 7911,
  [7972] = 7910,
  [7973] = 7908,
  [7974] = 7898,
  [7975] = 7897,
  [7976] = 7904,
  [7977] = 7895,
  [7978] = 7851,
  [7979] = 7892,
  [7980] = 7905,
  [7981] = 7838,
  [7982] = 7900,
  [7983] = 7848,
  [7984] = 7899,
  [7985] = 7985,
  [7986] = 7986,
  [7987] = 7987,
  [7988] = 7856,
  [7989] = 7855,
  [7990] = 7866,
  [7991] = 7923,
  [7992] = 7851,
  [7993] = 7862,
  [7994] = 7994,
  [7995] = 7861,
  [7996] = 7906,
  [7997] = 7859,
  [7998] = 7998,
  [7999] = 7857,
  [8000] = 7854,
  [8001] = 7892,
  [8002] = 7839,
  [8003] = 7849,
  [8004] = 7939,
  [8005] = 7840,
  [8006] = 7895,
  [8007] = 7840,
  [8008] = 7842,
  [8009] = 7912,
  [8010] = 7846,
  [8011] = 7839,
  [8012] = 8012,
  [8013] = 7864,
  [8014] = 7851,
  [8015] = 7849,
  [8016] = 7850,
  [8017] = 7852,
  [8018] = 7998,
  [8019] = 8019,
  [8020] = 7854,
  [8021] = 7857,
  [8022] = 7837,
  [8023] = 8023,
  [8024] = 8024,
  [8025] = 7859,
  [8026] = 7867,
  [8027] = 7861,
  [8028] = 7869,
  [8029] = 7862,
  [8030] = 7888,
  [8031] = 7855,
  [8032] = 7856,
  [8033] = 7848,
  [8034] = 7866,
  [8035] = 5585,
  [8036] = 8036,
  [8037] = 7892,
  [8038] = 7895,
  [8039] = 7897,
  [8040] = 7908,
  [8041] = 7913,
  [8042] = 7921,
  [8043] = 7874,
  [8044] = 7875,
  [8045] = 8045,
  [8046] = 7877,
  [8047] = 7900,
  [8048] = 7906,
  [8049] = 7914,
  [8050] = 7915,
  [8051] = 7916,
  [8052] = 7843,
  [8053] = 7918,
  [8054] = 7922,
  [8055] = 7939,
  [8056] = 7871,
  [8057] = 7853,
  [8058] = 7994,
  [8059] = 7899,
  [8060] = 8060,
  [8061] = 7846,
  [8062] = 8062,
  [8063] = 8063,
  [8064] = 8064,
  [8065] = 7910,
  [8066] = 8066,
  [8067] = 8067,
  [8068] = 8068,
  [8069] = 7872,
  [8070] = 8070,
  [8071] = 8071,
  [8072] = 7838,
  [8073] = 7844,
  [8074] = 7904,
  [8075] = 7897,
  [8076] = 8076,
  [8077] = 7867,
  [8078] = 8078,
  [8079] = 7869,
  [8080] = 8080,
  [8081] = 7888,
  [8082] = 7911,
  [8083] = 7910,
  [8084] = 7904,
  [8085] = 8085,
  [8086] = 8086,
  [8087] = 7845,
  [8088] = 7900,
  [8089] = 7910,
  [8090] = 7911,
  [8091] = 8091,
  [8092] = 8092,
  [8093] = 8093,
  [8094] = 8094,
  [8095] = 8095,
  [8096] = 7906,
  [8097] = 7899,
  [8098] = 7838,
  [8099] = 7866,
  [8100] = 7862,
  [8101] = 7921,
  [8102] = 7861,
  [8103] = 7864,
  [8104] = 7859,
  [8105] = 8105,
  [8106] = 7846,
  [8107] = 7847,
  [8108] = 7857,
  [8109] = 7839,
  [8110] = 7844,
  [8111] = 7872,
  [8112] = 7871,
  [8113] = 7863,
  [8114] = 7845,
  [8115] = 7851,
  [8116] = 8116,
  [8117] = 7853,
  [8118] = 7933,
  [8119] = 7867,
  [8120] = 7848,
  [8121] = 7869,
  [8122] = 7892,
  [8123] = 7987,
  [8124] = 7897,
  [8125] = 7923,
  [8126] = 7908,
  [8127] = 7913,
  [8128] = 7906,
  [8129] = 7922,
  [8130] = 7914,
  [8131] = 7845,
  [8132] = 7846,
  [8133] = 7915,
  [8134] = 5543,
  [8135] = 7916,
  [8136] = 7869,
  [8137] = 7843,
  [8138] = 7918,
  [8139] = 7922,
  [8140] = 7923,
  [8141] = 7906,
  [8142] = 8142,
  [8143] = 7952,
  [8144] = 7846,
  [8145] = 8093,
  [8146] = 7953,
  [8147] = 7869,
  [8148] = 7918,
  [8149] = 7871,
  [8150] = 8150,
  [8151] = 7906,
  [8152] = 7846,
  [8153] = 7869,
  [8154] = 7872,
  [8155] = 7846,
  [8156] = 7869,
  [8157] = 7844,
  [8158] = 7846,
  [8159] = 7869,
  [8160] = 7846,
  [8161] = 7869,
  [8162] = 7846,
  [8163] = 7869,
  [8164] = 7846,
  [8165] = 7869,
  [8166] = 7846,
  [8167] = 7869,
  [8168] = 7846,
  [8169] = 7869,
  [8170] = 7843,
  [8171] = 8091,
  [8172] = 7916,
  [8173] = 8173,
  [8174] = 7915,
  [8175] = 8175,
  [8176] = 8176,
  [8177] = 8177,
  [8178] = 7914,
  [8179] = 7998,
  [8180] = 8180,
  [8181] = 7913,
  [8182] = 8182,
  [8183] = 8183,
  [8184] = 8184,
  [8185] = 7908,
  [8186] = 8186,
  [8187] = 7862,
  [8188] = 7897,
  [8189] = 8189,
  [8190] = 7895,
  [8191] = 7892,
  [8192] = 8192,
  [8193] = 7904,
  [8194] = 7841,
  [8195] = 7911,
  [8196] = 8196,
  [8197] = 7838,
  [8198] = 8198,
  [8199] = 7906,
  [8200] = 7852,
  [8201] = 7900,
  [8202] = 8202,
  [8203] = 7901,
  [8204] = 8204,
  [8205] = 8205,
  [8206] = 7848,
  [8207] = 7899,
  [8208] = 7856,
  [8209] = 7998,
  [8210] = 8150,
  [8211] = 7855,
  [8212] = 7862,
  [8213] = 7861,
  [8214] = 8214,
  [8215] = 7851,
  [8216] = 7859,
  [8217] = 7857,
  [8218] = 7994,
  [8219] = 8219,
  [8220] = 7845,
  [8221] = 7919,
  [8222] = 7892,
  [8223] = 8012,
  [8224] = 8224,
  [8225] = 7998,
  [8226] = 8226,
  [8227] = 8227,
  [8228] = 7843,
  [8229] = 8229,
  [8230] = 7867,
  [8231] = 8231,
  [8232] = 7869,
  [8233] = 7851,
  [8234] = 8234,
  [8235] = 8235,
  [8236] = 7839,
  [8237] = 8237,
  [8238] = 7840,
  [8239] = 7848,
  [8240] = 7842,
  [8241] = 7873,
  [8242] = 7912,
  [8243] = 8243,
  [8244] = 7892,
  [8245] = 7897,
  [8246] = 8202,
  [8247] = 7849,
  [8248] = 8248,
  [8249] = 7850,
  [8250] = 8250,
  [8251] = 7910,
  [8252] = 8252,
  [8253] = 7854,
  [8254] = 7916,
  [8255] = 7843,
  [8256] = 8256,
  [8257] = 7857,
  [8258] = 7859,
  [8259] = 7861,
  [8260] = 8205,
  [8261] = 7862,
  [8262] = 8262,
  [8263] = 7922,
  [8264] = 8264,
  [8265] = 7844,
  [8266] = 7866,
  [8267] = 8036,
  [8268] = 7910,
  [8269] = 5599,
  [8270] = 7874,
  [8271] = 7875,
  [8272] = 7869,
  [8273] = 7877,
  [8274] = 7939,
  [8275] = 7867,
  [8276] = 7908,
  [8277] = 8277,
  [8278] = 8278,
  [8279] = 8279,
  [8280] = 8280,
  [8281] = 8281,
  [8282] = 8282,
  [8283] = 8283,
  [8284] = 8284,
  [8285] = 8080,
  [8286] = 8286,
  [8287] = 8287,
  [8288] = 8288,
  [8289] = 8289,
  [8290] = 8086,
  [8291] = 8085,
  [8292] = 8080,
  [8293] = 8204,
  [8294] = 7839,
  [8295] = 8078,
  [8296] = 8076,
  [8297] = 7864,
  [8298] = 8298,
  [8299] = 8299,
  [8300] = 8300,
  [8301] = 8301,
  [8302] = 8302,
  [8303] = 8303,
  [8304] = 8304,
  [8305] = 8305,
  [8306] = 7899,
  [8307] = 7840,
  [8308] = 8062,
  [8309] = 8063,
  [8310] = 7900,
  [8311] = 8066,
  [8312] = 8067,
  [8313] = 8068,
  [8314] = 8070,
  [8315] = 8071,
  [8316] = 7838,
  [8317] = 7904,
  [8318] = 8076,
  [8319] = 8078,
  [8320] = 8320,
  [8321] = 8321,
  [8322] = 8322,
  [8323] = 8085,
  [8324] = 8324,
  [8325] = 8086,
  [8326] = 8326,
  [8327] = 7910,
  [8328] = 7911,
  [8329] = 8091,
  [8330] = 7904,
  [8331] = 7838,
  [8332] = 8332,
  [8333] = 8093,
  [8334] = 8334,
  [8335] = 7861,
  [8336] = 7859,
  [8337] = 7857,
  [8338] = 8338,
  [8339] = 8339,
  [8340] = 8340,
  [8341] = 7921,
  [8342] = 7864,
  [8343] = 7846,
  [8344] = 8344,
  [8345] = 7837,
  [8346] = 8346,
  [8347] = 8347,
  [8348] = 7844,
  [8349] = 7872,
  [8350] = 8198,
  [8351] = 7842,
  [8352] = 7892,
  [8353] = 7912,
  [8354] = 7871,
  [8355] = 7863,
  [8356] = 8356,
  [8357] = 8357,
  [8358] = 8358,
  [8359] = 8359,
  [8360] = 7853,
  [8361] = 8361,
  [8362] = 7933,
  [8363] = 8363,
  [8364] = 7986,
  [8365] = 7987,
  [8366] = 7923,
  [8367] = 8367,
  [8368] = 8368,
  [8369] = 7922,
  [8370] = 8370,
  [8371] = 7851,
  [8372] = 8196,
  [8373] = 7848,
  [8374] = 8374,
  [8375] = 8173,
  [8376] = 8176,
  [8377] = 8177,
  [8378] = 8180,
  [8379] = 7901,
  [8380] = 8182,
  [8381] = 7892,
  [8382] = 7897,
  [8383] = 7862,
  [8384] = 7952,
  [8385] = 7953,
  [8386] = 8196,
  [8387] = 8387,
  [8388] = 8198,
  [8389] = 8389,
  [8390] = 7918,
  [8391] = 8391,
  [8392] = 8204,
  [8393] = 8205,
  [8394] = 7998,
  [8395] = 8150,
  [8396] = 7916,
  [8397] = 7871,
  [8398] = 7892,
  [8399] = 8012,
  [8400] = 7843,
  [8401] = 8071,
  [8402] = 7916,
  [8403] = 7915,
  [8404] = 7873,
  [8405] = 8202,
  [8406] = 7914,
  [8407] = 7913,
  [8408] = 7922,
  [8409] = 8173,
  [8410] = 8176,
  [8411] = 8180,
  [8412] = 8412,
  [8413] = 8182,
  [8414] = 8414,
  [8415] = 7908,
  [8416] = 8196,
  [8417] = 7843,
  [8418] = 8198,
  [8419] = 8070,
  [8420] = 7897,
  [8421] = 8204,
  [8422] = 8205,
  [8423] = 7871,
  [8424] = 8012,
  [8425] = 7895,
  [8426] = 7892,
  [8427] = 7847,
  [8428] = 7841,
  [8429] = 7873,
  [8430] = 8202,
  [8431] = 7849,
  [8432] = 8068,
  [8433] = 8173,
  [8434] = 8176,
  [8435] = 8180,
  [8436] = 7844,
  [8437] = 8182,
  [8438] = 7910,
  [8439] = 7850,
  [8440] = 8196,
  [8441] = 8198,
  [8442] = 8067,
  [8443] = 7852,
  [8444] = 8204,
  [8445] = 8205,
  [8446] = 7838,
  [8447] = 8012,
  [8448] = 8448,
  [8449] = 8066,
  [8450] = 7848,
  [8451] = 7873,
  [8452] = 8202,
  [8453] = 8262,
  [8454] = 8173,
  [8455] = 8176,
  [8456] = 8180,
  [8457] = 8457,
  [8458] = 8182,
  [8459] = 8459,
  [8460] = 7856,
  [8461] = 8198,
  [8462] = 7855,
  [8463] = 8463,
  [8464] = 8204,
  [8465] = 8205,
  [8466] = 8466,
  [8467] = 8012,
  [8468] = 7948,
  [8469] = 8469,
  [8470] = 7851,
  [8471] = 7873,
  [8472] = 8202,
  [8473] = 8473,
  [8474] = 8173,
  [8475] = 8475,
  [8476] = 8182,
  [8477] = 8477,
  [8478] = 7994,
  [8479] = 8479,
  [8480] = 7845,
  [8481] = 8204,
  [8482] = 8205,
  [8483] = 7998,
  [8484] = 8484,
  [8485] = 8485,
  [8486] = 8486,
  [8487] = 7873,
  [8488] = 7900,
  [8489] = 8173,
  [8490] = 8182,
  [8491] = 8491,
  [8492] = 8205,
  [8493] = 7851,
  [8494] = 8494,
  [8495] = 7873,
  [8496] = 8496,
  [8497] = 8173,
  [8498] = 8182,
  [8499] = 8499,
  [8500] = 8205,
  [8501] = 8501,
  [8502] = 7873,
  [8503] = 8173,
  [8504] = 8182,
  [8505] = 8205,
  [8506] = 7873,
  [8507] = 8205,
  [8508] = 7873,
  [8509] = 8205,
  [8510] = 7873,
  [8511] = 8205,
  [8512] = 7873,
  [8513] = 8205,
  [8514] = 7873,
  [8515] = 8205,
  [8516] = 7873,
  [8517] = 8205,
  [8518] = 7873,
  [8519] = 8205,
  [8520] = 7873,
  [8521] = 8521,
  [8522] = 7854,
  [8523] = 8177,
  [8524] = 8524,
  [8525] = 8525,
  [8526] = 7848,
  [8527] = 7846,
  [8528] = 8528,
  [8529] = 7839,
  [8530] = 7916,
  [8531] = 8531,
  [8532] = 7840,
  [8533] = 7922,
  [8534] = 7844,
  [8535] = 8535,
  [8536] = 8536,
  [8537] = 8537,
  [8538] = 7842,
  [8539] = 8150,
  [8540] = 7912,
  [8541] = 7892,
  [8542] = 7939,
  [8543] = 7919,
  [8544] = 8339,
  [8545] = 7847,
  [8546] = 8256,
  [8547] = 7841,
  [8548] = 7838,
  [8549] = 7857,
  [8550] = 7859,
  [8551] = 7861,
  [8552] = 7862,
  [8553] = 8553,
  [8554] = 8554,
  [8555] = 8063,
  [8556] = 8062,
  [8557] = 8557,
  [8558] = 7849,
  [8559] = 7866,
  [8560] = 7850,
  [8561] = 7852,
  [8562] = 7865,
  [8563] = 8563,
  [8564] = 7854,
  [8565] = 8256,
  [8566] = 7857,
  [8567] = 7859,
  [8568] = 7862,
  [8569] = 8036,
  [8570] = 7861,
  [8571] = 8571,
  [8572] = 7862,
  [8573] = 8262,
  [8574] = 7899,
  [8575] = 7843,
  [8576] = 2380,
  [8577] = 7866,
  [8578] = 7862,
  [8579] = 8036,
  [8580] = 8580,
  [8581] = 8581,
  [8582] = 7905,
  [8583] = 8583,
  [8584] = 8584,
  [8585] = 7844,
  [8586] = 8586,
  [8587] = 7838,
  [8588] = 8525,
  [8589] = 8524,
  [8590] = 8590,
  [8591] = 8591,
  [8592] = 8592,
  [8593] = 8593,
  [8594] = 7874,
  [8595] = 8182,
  [8596] = 7875,
  [8597] = 8597,
  [8598] = 7877,
  [8599] = 8599,
  [8600] = 8600,
  [8601] = 8601,
  [8602] = 8602,
  [8603] = 8603,
  [8604] = 7843,
  [8605] = 8180,
  [8606] = 7898,
  [8607] = 8177,
  [8608] = 8524,
  [8609] = 8525,
  [8610] = 7844,
  [8611] = 7874,
  [8612] = 7875,
  [8613] = 8150,
  [8614] = 7919,
  [8615] = 8339,
  [8616] = 8177,
  [8617] = 7838,
  [8618] = 7877,
  [8619] = 8177,
  [8620] = 8524,
  [8621] = 8525,
  [8622] = 8116,
  [8623] = 7952,
  [8624] = 8150,
  [8625] = 7919,
  [8626] = 8339,
  [8627] = 7844,
  [8628] = 2379,
  [8629] = 6699,
  [8630] = 8524,
  [8631] = 8525,
  [8632] = 7838,
  [8633] = 7844,
  [8634] = 7919,
  [8635] = 8339,
  [8636] = 7838,
  [8637] = 8176,
  [8638] = 8524,
  [8639] = 8525,
  [8640] = 7953,
  [8641] = 8641,
  [8642] = 7919,
  [8643] = 8339,
  [8644] = 8175,
  [8645] = 7897,
  [8646] = 8524,
  [8647] = 8525,
  [8648] = 7838,
  [8649] = 7919,
  [8650] = 8339,
  [8651] = 8389,
  [8652] = 7918,
  [8653] = 7919,
  [8654] = 8339,
  [8655] = 8173,
  [8656] = 7906,
  [8657] = 8339,
  [8658] = 7844,
  [8659] = 8339,
  [8660] = 7838,
  [8661] = 8339,
  [8662] = 7844,
  [8663] = 8339,
  [8664] = 7838,
  [8665] = 8339,
  [8666] = 5557,
  [8667] = 8339,
  [8668] = 7913,
  [8669] = 8339,
  [8670] = 7914,
  [8671] = 8339,
  [8672] = 7915,
  [8673] = 8339,
  [8674] = 8602,
  [8675] = 8264,
  [8676] = 7916,
  [8677] = 8602,
  [8678] = 8264,
  [8679] = 7888,
  [8680] = 8602,
  [8681] = 8264,
  [8682] = 7889,
  [8683] = 8602,
  [8684] = 8264,
  [8685] = 8459,
  [8686] = 8602,
  [8687] = 8264,
  [8688] = 7898,
  [8689] = 8264,
  [8690] = 8264,
  [8691] = 8264,
  [8692] = 8264,
  [8693] = 8264,
  [8694] = 8264,
  [8695] = 8264,
  [8696] = 8264,
  [8697] = 8264,
  [8698] = 8264,
  [8699] = 8264,
  [8700] = 7844,
  [8701] = 7843,
  [8702] = 7889,
  [8703] = 7905,
  [8704] = 7888,
  [8705] = 8601,
  [8706] = 8601,
  [8707] = 8601,
  [8708] = 8601,
  [8709] = 8601,
};

static TSCharacterRange sym_identifier_character_set_1[] = {
  {'$', '$'}, {'A', 'Z'}, {'\\', '\\'}, {'_', '_'}, {'a', 'z'}, {0xaa, 0xaa}, {0xb5, 0xb5}, {0xba, 0xba},
  {0xc0, 0xd6}, {0xd8, 0xf6}, {0xf8, 0x2c1}, {0x2c6, 0x2d1}, {0x2e0, 0x2e4}, {0x2ec, 0x2ec}, {0x2ee, 0x2ee}, {0x370, 0x374},
  {0x376, 0x377}, {0x37b, 0x37d}, {0x37f, 0x37f}, {0x386, 0x386}, {0x388, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1}, {0x3a3, 0x3f5},
  {0x3f7, 0x481}, {0x48a, 0x52f}, {0x531, 0x556}, {0x559, 0x559}, {0x560, 0x588}, {0x5d0, 0x5ea}, {0x5ef, 0x5f2}, {0x620, 0x64a},
  {0x66e, 0x66f}, {0x671, 0x6d3}, {0x6d5, 0x6d5}, {0x6e5, 0x6e6}, {0x6ee, 0x6ef}, {0x6fa, 0x6fc}, {0x6ff, 0x6ff}, {0x710, 0x710},
  {0x712, 0x72f}, {0x74d, 0x7a5}, {0x7b1, 0x7b1}, {0x7ca, 0x7ea}, {0x7f4, 0x7f5}, {0x7fa, 0x7fa}, {0x800, 0x815}, {0x81a, 0x81a},
  {0x824, 0x824}, {0x828, 0x828}, {0x840, 0x858}, {0x860, 0x86a}, {0x870, 0x887}, {0x889, 0x88e}, {0x8a0, 0x8c9}, {0x904, 0x939},
  {0x93d, 0x93d}, {0x950, 0x950}, {0x958, 0x961}, {0x971, 0x980}, {0x985, 0x98c}, {0x98f, 0x990}, {0x993, 0x9a8}, {0x9aa, 0x9b0},
  {0x9b2, 0x9b2}, {0x9b6, 0x9b9}, {0x9bd, 0x9bd}, {0x9ce, 0x9ce}, {0x9dc, 0x9dd}, {0x9df, 0x9e1}, {0x9f0, 0x9f1}, {0x9fc, 0x9fc},
  {0xa05, 0xa0a}, {0xa0f, 0xa10}, {0xa13, 0xa28}, {0xa2a, 0xa30}, {0xa32, 0xa33}, {0xa35, 0xa36}, {0xa38, 0xa39}, {0xa59, 0xa5c},
  {0xa5e, 0xa5e}, {0xa72, 0xa74}, {0xa85, 0xa8d}, {0xa8f, 0xa91}, {0xa93, 0xaa8}, {0xaaa, 0xab0}, {0xab2, 0xab3}, {0xab5, 0xab9},
  {0xabd, 0xabd}, {0xad0, 0xad0}, {0xae0, 0xae1}, {0xaf9, 0xaf9}, {0xb05, 0xb0c}, {0xb0f, 0xb10}, {0xb13, 0xb28}, {0xb2a, 0xb30},
  {0xb32, 0xb33}, {0xb35, 0xb39}, {0xb3d, 0xb3d}, {0xb5c, 0xb5d}, {0xb5f, 0xb61}, {0xb71, 0xb71}, {0xb83, 0xb83}, {0xb85, 0xb8a},
  {0xb8e, 0xb90}, {0xb92, 0xb95}, {0xb99, 0xb9a}, {0xb9c, 0xb9c}, {0xb9e, 0xb9f}, {0xba3, 0xba4}, {0xba8, 0xbaa}, {0xbae, 0xbb9},
  {0xbd0, 0xbd0}, {0xc05, 0xc0c}, {0xc0e, 0xc10}, {0xc12, 0xc28}, {0xc2a, 0xc39}, {0xc3d, 0xc3d}, {0xc58, 0xc5a}, {0xc5d, 0xc5d},
  {0xc60, 0xc61}, {0xc80, 0xc80}, {0xc85, 0xc8c}, {0xc8e, 0xc90}, {0xc92, 0xca8}, {0xcaa, 0xcb3}, {0xcb5, 0xcb9}, {0xcbd, 0xcbd},
  {0xcdd, 0xcde}, {0xce0, 0xce1}, {0xcf1, 0xcf2}, {0xd04, 0xd0c}, {0xd0e, 0xd10}, {0xd12, 0xd3a}, {0xd3d, 0xd3d}, {0xd4e, 0xd4e},
  {0xd54, 0xd56}, {0xd5f, 0xd61}, {0xd7a, 0xd7f}, {0xd85, 0xd96}, {0xd9a, 0xdb1}, {0xdb3, 0xdbb}, {0xdbd, 0xdbd}, {0xdc0, 0xdc6},
  {0xe01, 0xe30}, {0xe32, 0xe32}, {0xe40, 0xe46}, {0xe81, 0xe82}, {0xe84, 0xe84}, {0xe86, 0xe8a}, {0xe8c, 0xea3}, {0xea5, 0xea5},
  {0xea7, 0xeb0}, {0xeb2, 0xeb2}, {0xebd, 0xebd}, {0xec0, 0xec4}, {0xec6, 0xec6}, {0xedc, 0xedf}, {0xf00, 0xf00}, {0xf40, 0xf47},
  {0xf49, 0xf6c}, {0xf88, 0xf8c}, {0x1000, 0x102a}, {0x103f, 0x103f}, {0x1050, 0x1055}, {0x105a, 0x105d}, {0x1061, 0x1061}, {0x1065, 0x1066},
  {0x106e, 0x1070}, {0x1075, 0x1081}, {0x108e, 0x108e}, {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fc, 0x1248},
  {0x124a, 0x124d}, {0x1250, 0x1256}, {0x1258, 0x1258}, {0x125a, 0x125d}, {0x1260, 0x1288}, {0x128a, 0x128d}, {0x1290, 0x12b0}, {0x12b2, 0x12b5},
  {0x12b8, 0x12be}, {0x12c0, 0x12c0}, {0x12c2, 0x12c5}, {0x12c8, 0x12d6}, {0x12d8, 0x1310}, {0x1312, 0x1315}, {0x1318, 0x135a}, {0x1380, 0x138f},
  {0x13a0, 0x13f5}, {0x13f8, 0x13fd}, {0x1401, 0x166c}, {0x166f, 0x167f}, {0x1681, 0x169a}, {0x16a0, 0x16ea}, {0x16ee, 0x16f8}, {0x1700, 0x1711},
  {0x171f, 0x1731}, {0x1740, 0x1751}, {0x1760, 0x176c}, {0x176e, 0x1770}, {0x1780, 0x17b3}, {0x17d7, 0x17d7}, {0x17dc, 0x17dc}, {0x1820, 0x1878},
  {0x1880, 0x18a8}, {0x18aa, 0x18aa}, {0x18b0, 0x18f5}, {0x1900, 0x191e}, {0x1950, 0x196d}, {0x1970, 0x1974}, {0x1980, 0x19ab}, {0x19b0, 0x19c9},
  {0x1a00, 0x1a16}, {0x1a20, 0x1a54}, {0x1aa7, 0x1aa7}, {0x1b05, 0x1b33}, {0x1b45, 0x1b4c}, {0x1b83, 0x1ba0}, {0x1bae, 0x1baf}, {0x1bba, 0x1be5},
  {0x1c00, 0x1c23}, {0x1c4d, 0x1c4f}, {0x1c5a, 0x1c7d}, {0x1c80, 0x1c88}, {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf}, {0x1ce9, 0x1cec}, {0x1cee, 0x1cf3},
  {0x1cf5, 0x1cf6}, {0x1cfa, 0x1cfa}, {0x1d00, 0x1dbf}, {0x1e00, 0x1f15}, {0x1f18, 0x1f1d}, {0x1f20, 0x1f45}, {0x1f48, 0x1f4d}, {0x1f50, 0x1f57},
  {0x1f59, 0x1f59}, {0x1f5b, 0x1f5b}, {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d}, {0x1f80, 0x1fb4}, {0x1fb6, 0x1fbc}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4},
  {0x1fc6, 0x1fcc}, {0x1fd0, 0x1fd3}, {0x1fd6, 0x1fdb}, {0x1fe0, 0x1fec}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffc}, {0x2071, 0x2071}, {0x207f, 0x207f},
  {0x2090, 0x209c}, {0x2102, 0x2102}, {0x2107, 0x2107}, {0x210a, 0x2113}, {0x2115, 0x2115}, {0x2118, 0x211d}, {0x2124, 0x2124}, {0x2126, 0x2126},
  {0x2128, 0x2128}, {0x212a, 0x2139}, {0x213c, 0x213f}, {0x2145, 0x2149}, {0x214e, 0x214e}, {0x2160, 0x2188}, {0x2c00, 0x2ce4}, {0x2ceb, 0x2cee},
  {0x2cf2, 0x2cf3}, {0x2d00, 0x2d25}, {0x2d27, 0x2d27}, {0x2d2d, 0x2d2d}, {0x2d30, 0x2d67}, {0x2d6f, 0x2d6f}, {0x2d80, 0x2d96}, {0x2da0, 0x2da6},
  {0x2da8, 0x2dae}, {0x2db0, 0x2db6}, {0x2db8, 0x2dbe}, {0x2dc0, 0x2dc6}, {0x2dc8, 0x2dce}, {0x2dd0, 0x2dd6}, {0x2dd8, 0x2dde}, {0x3005, 0x3007},
  {0x3021, 0x3029}, {0x3031, 0x3035}, {0x3038, 0x303c}, {0x3041, 0x3096}, {0x309d, 0x309f}, {0x30a1, 0x30fa}, {0x30fc, 0x30ff}, {0x3105, 0x312f},
  {0x3131, 0x318e}, {0x31a0, 0x31bf}, {0x31f0, 0x31ff}, {0x3400, 0x4dbf}, {0x4e00, 0xa48c}, {0xa4d0, 0xa4fd}, {0xa500, 0xa60c}, {0xa610, 0xa61f},
  {0xa62a, 0xa62b}, {0xa640, 0xa66e}, {0xa67f, 0xa69d}, {0xa6a0, 0xa6ef}, {0xa717, 0xa71f}, {0xa722, 0xa788}, {0xa78b, 0xa7ca}, {0xa7d0, 0xa7d1},
  {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7d9}, {0xa7f2, 0xa801}, {0xa803, 0xa805}, {0xa807, 0xa80a}, {0xa80c, 0xa822}, {0xa840, 0xa873}, {0xa882, 0xa8b3},
  {0xa8f2, 0xa8f7}, {0xa8fb, 0xa8fb}, {0xa8fd, 0xa8fe}, {0xa90a, 0xa925}, {0xa930, 0xa946}, {0xa960, 0xa97c}, {0xa984, 0xa9b2}, {0xa9cf, 0xa9cf},
  {0xa9e0, 0xa9e4}, {0xa9e6, 0xa9ef}, {0xa9fa, 0xa9fe}, {0xaa00, 0xaa28}, {0xaa40, 0xaa42}, {0xaa44, 0xaa4b}, {0xaa60, 0xaa76}, {0xaa7a, 0xaa7a},
  {0xaa7e, 0xaaaf}, {0xaab1, 0xaab1}, {0xaab5, 0xaab6}, {0xaab9, 0xaabd}, {0xaac0, 0xaac0}, {0xaac2, 0xaac2}, {0xaadb, 0xaadd}, {0xaae0, 0xaaea},
  {0xaaf2, 0xaaf4}, {0xab01, 0xab06}, {0xab09, 0xab0e}, {0xab11, 0xab16}, {0xab20, 0xab26}, {0xab28, 0xab2e}, {0xab30, 0xab5a}, {0xab5c, 0xab69},
  {0xab70, 0xabe2}, {0xac00, 0xd7a3}, {0xd7b0, 0xd7c6}, {0xd7cb, 0xd7fb}, {0xf900, 0xfa6d}, {0xfa70, 0xfad9}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17},
  {0xfb1d, 0xfb1d}, {0xfb1f, 0xfb28}, {0xfb2a, 0xfb36}, {0xfb38, 0xfb3c}, {0xfb3e, 0xfb3e}, {0xfb40, 0xfb41}, {0xfb43, 0xfb44}, {0xfb46, 0xfbb1},
  {0xfbd3, 0xfc5d}, {0xfc64, 0xfd3d}, {0xfd50, 0xfd8f}, {0xfd92, 0xfdc7}, {0xfdf0, 0xfdf9}, {0xfe71, 0xfe71}, {0xfe73, 0xfe73}, {0xfe77, 0xfe77},
  {0xfe79, 0xfe79}, {0xfe7b, 0xfe7b}, {0xfe7d, 0xfe7d}, {0xfe7f, 0xfefc}, {0xff21, 0xff3a}, {0xff41, 0xff5a}, {0xff66, 0xff9d}, {0xffa0, 0xffbe},
  {0xffc2, 0xffc7}, {0xffca, 0xffcf}, {0xffd2, 0xffd7}, {0xffda, 0xffdc}, {0x10000, 0x1000b}, {0x1000d, 0x10026}, {0x10028, 0x1003a}, {0x1003c, 0x1003d},
  {0x1003f, 0x1004d}, {0x10050, 0x1005d}, {0x10080, 0x100fa}, {0x10140, 0x10174}, {0x10280, 0x1029c}, {0x102a0, 0x102d0}, {0x10300, 0x1031f}, {0x1032d, 0x1034a},
  {0x10350, 0x10375}, {0x10380, 0x1039d}, {0x103a0, 0x103c3}, {0x103c8, 0x103cf}, {0x103d1, 0x103d5}, {0x10400, 0x1049d}, {0x104b0, 0x104d3}, {0x104d8, 0x104fb},
  {0x10500, 0x10527}, {0x10530, 0x10563}, {0x10570, 0x1057a}, {0x1057c, 0x1058a}, {0x1058c, 0x10592}, {0x10594, 0x10595}, {0x10597, 0x105a1}, {0x105a3, 0x105b1},
  {0x105b3, 0x105b9}, {0x105bb, 0x105bc}, {0x10600, 0x10736}, {0x10740, 0x10755}, {0x10760, 0x10767}, {0x10780, 0x10785}, {0x10787, 0x107b0}, {0x107b2, 0x107ba},
  {0x10800, 0x10805}, {0x10808, 0x10808}, {0x1080a, 0x10835}, {0x10837, 0x10838}, {0x1083c, 0x1083c}, {0x1083f, 0x10855}, {0x10860, 0x10876}, {0x10880, 0x1089e},
  {0x108e0, 0x108f2}, {0x108f4, 0x108f5}, {0x10900, 0x10915}, {0x10920, 0x10939}, {0x10980, 0x109b7}, {0x109be, 0x109bf}, {0x10a00, 0x10a00}, {0x10a10, 0x10a13},
  {0x10a15, 0x10a17}, {0x10a19, 0x10a35}, {0x10a60, 0x10a7c}, {0x10a80, 0x10a9c}, {0x10ac0, 0x10ac7}, {0x10ac9, 0x10ae4}, {0x10b00, 0x10b35}, {0x10b40, 0x10b55},
  {0x10b60, 0x10b72}, {0x10b80, 0x10b91}, {0x10c00, 0x10c48}, {0x10c80, 0x10cb2}, {0x10cc0, 0x10cf2}, {0x10d00, 0x10d23}, {0x10e80, 0x10ea9}, {0x10eb0, 0x10eb1},
  {0x10f00, 0x10f1c}, {0x10f27, 0x10f27}, {0x10f30, 0x10f45}, {0x10f70, 0x10f81}, {0x10fb0, 0x10fc4}, {0x10fe0, 0x10ff6}, {0x11003, 0x11037}, {0x11071, 0x11072},
  {0x11075, 0x11075}, {0x11083, 0x110af}, {0x110d0, 0x110e8}, {0x11103, 0x11126}, {0x11144, 0x11144}, {0x11147, 0x11147}, {0x11150, 0x11172}, {0x11176, 0x11176},
  {0x11183, 0x111b2}, {0x111c1, 0x111c4}, {0x111da, 0x111da}, {0x111dc, 0x111dc}, {0x11200, 0x11211}, {0x11213, 0x1122b}, {0x11280, 0x11286}, {0x11288, 0x11288},
  {0x1128a, 0x1128d}, {0x1128f, 0x1129d}, {0x1129f, 0x112a8}, {0x112b0, 0x112de}, {0x11305, 0x1130c}, {0x1130f, 0x11310}, {0x11313, 0x11328}, {0x1132a, 0x11330},
  {0x11332, 0x11333}, {0x11335, 0x11339}, {0x1133d, 0x1133d}, {0x11350, 0x11350}, {0x1135d, 0x11361}, {0x11400, 0x11434}, {0x11447, 0x1144a}, {0x1145f, 0x11461},
  {0x11480, 0x114af}, {0x114c4, 0x114c5}, {0x114c7, 0x114c7}, {0x11580, 0x115ae}, {0x115d8, 0x115db}, {0x11600, 0x1162f}, {0x11644, 0x11644}, {0x11680, 0x116aa},
  {0x116b8, 0x116b8}, {0x11700, 0x1171a}, {0x11740, 0x11746}, {0x11800, 0x1182b}, {0x118a0, 0x118df}, {0x118ff, 0x11906}, {0x11909, 0x11909}, {0x1190c, 0x11913},
  {0x11915, 0x11916}, {0x11918, 0x1192f}, {0x1193f, 0x1193f}, {0x11941, 0x11941}, {0x119a0, 0x119a7}, {0x119aa, 0x119d0}, {0x119e1, 0x119e1}, {0x119e3, 0x119e3},
  {0x11a00, 0x11a00}, {0x11a0b, 0x11a32}, {0x11a3a, 0x11a3a}, {0x11a50, 0x11a50}, {0x11a5c, 0x11a89}, {0x11a9d, 0x11a9d}, {0x11ab0, 0x11af8}, {0x11c00, 0x11c08},
  {0x11c0a, 0x11c2e}, {0x11c40, 0x11c40}, {0x11c72, 0x11c8f}, {0x11d00, 0x11d06}, {0x11d08, 0x11d09}, {0x11d0b, 0x11d30}, {0x11d46, 0x11d46}, {0x11d60, 0x11d65},
  {0x11d67, 0x11d68}, {0x11d6a, 0x11d89}, {0x11d98, 0x11d98}, {0x11ee0, 0x11ef2}, {0x11fb0, 0x11fb0}, {0x12000, 0x12399}, {0x12400, 0x1246e}, {0x12480, 0x12543},
  {0x12f90, 0x12ff0}, {0x13000, 0x1342e}, {0x14400, 0x14646}, {0x16800, 0x16a38}, {0x16a40, 0x16a5e}, {0x16a70, 0x16abe}, {0x16ad0, 0x16aed}, {0x16b00, 0x16b2f},
  {0x16b40, 0x16b43}, {0x16b63, 0x16b77}, {0x16b7d, 0x16b8f}, {0x16e40, 0x16e7f}, {0x16f00, 0x16f4a}, {0x16f50, 0x16f50}, {0x16f93, 0x16f9f}, {0x16fe0, 0x16fe1},
  {0x16fe3, 0x16fe3}, {0x17000, 0x187f7}, {0x18800, 0x18cd5}, {0x18d00, 0x18d08}, {0x1aff0, 0x1aff3}, {0x1aff5, 0x1affb}, {0x1affd, 0x1affe}, {0x1b000, 0x1b122},
  {0x1b150, 0x1b152}, {0x1b164, 0x1b167}, {0x1b170, 0x1b2fb}, {0x1bc00, 0x1bc6a}, {0x1bc70, 0x1bc7c}, {0x1bc80, 0x1bc88}, {0x1bc90, 0x1bc99}, {0x1d400, 0x1d454},
  {0x1d456, 0x1d49c}, {0x1d49e, 0x1d49f}, {0x1d4a2, 0x1d4a2}, {0x1d4a5, 0x1d4a6}, {0x1d4a9, 0x1d4ac}, {0x1d4ae, 0x1d4b9}, {0x1d4bb, 0x1d4bb}, {0x1d4bd, 0x1d4c3},
  {0x1d4c5, 0x1d505}, {0x1d507, 0x1d50a}, {0x1d50d, 0x1d514}, {0x1d516, 0x1d51c}, {0x1d51e, 0x1d539}, {0x1d53b, 0x1d53e}, {0x1d540, 0x1d544}, {0x1d546, 0x1d546},
  {0x1d54a, 0x1d550}, {0x1d552, 0x1d6a5}, {0x1d6a8, 0x1d6c0}, {0x1d6c2, 0x1d6da}, {0x1d6dc, 0x1d6fa}, {0x1d6fc, 0x1d714}, {0x1d716, 0x1d734}, {0x1d736, 0x1d74e},
  {0x1d750, 0x1d76e}, {0x1d770, 0x1d788}, {0x1d78a, 0x1d7a8}, {0x1d7aa, 0x1d7c2}, {0x1d7c4, 0x1d7cb}, {0x1df00, 0x1df1e}, {0x1e100, 0x1e12c}, {0x1e137, 0x1e13d},
  {0x1e14e, 0x1e14e}, {0x1e290, 0x1e2ad}, {0x1e2c0, 0x1e2eb}, {0x1e7e0, 0x1e7e6}, {0x1e7e8, 0x1e7eb}, {0x1e7ed, 0x1e7ee}, {0x1e7f0, 0x1e7fe}, {0x1e800, 0x1e8c4},
  {0x1e900, 0x1e943}, {0x1e94b, 0x1e94b}, {0x1ee00, 0x1ee03}, {0x1ee05, 0x1ee1f}, {0x1ee21, 0x1ee22}, {0x1ee24, 0x1ee24}, {0x1ee27, 0x1ee27}, {0x1ee29, 0x1ee32},
  {0x1ee34, 0x1ee37}, {0x1ee39, 0x1ee39}, {0x1ee3b, 0x1ee3b}, {0x1ee42, 0x1ee42}, {0x1ee47, 0x1ee47}, {0x1ee49, 0x1ee49}, {0x1ee4b, 0x1ee4b}, {0x1ee4d, 0x1ee4f},
  {0x1ee51, 0x1ee52}, {0x1ee54, 0x1ee54}, {0x1ee57, 0x1ee57}, {0x1ee59, 0x1ee59}, {0x1ee5b, 0x1ee5b}, {0x1ee5d, 0x1ee5d}, {0x1ee5f, 0x1ee5f}, {0x1ee61, 0x1ee62},
  {0x1ee64, 0x1ee64}, {0x1ee67, 0x1ee6a}, {0x1ee6c, 0x1ee72}, {0x1ee74, 0x1ee77}, {0x1ee79, 0x1ee7c}, {0x1ee7e, 0x1ee7e}, {0x1ee80, 0x1ee89}, {0x1ee8b, 0x1ee9b},
  {0x1eea1, 0x1eea3}, {0x1eea5, 0x1eea9}, {0x1eeab, 0x1eebb}, {0x20000, 0x2a6df}, {0x2a700, 0x2b738}, {0x2b740, 0x2b81d}, {0x2b820, 0x2cea1}, {0x2ceb0, 0x2ebe0},
  {0x2f800, 0x2fa1d}, {0x30000, 0x3134a},
};

static TSCharacterRange sym_identifier_character_set_2[] = {
  {'$', '$'}, {'0', '9'}, {'A', 'Z'}, {'\\', '\\'}, {'_', '_'}, {'a', 'z'}, {0xaa, 0xaa}, {0xb5, 0xb5},
  {0xb7, 0xb7}, {0xba, 0xba}, {0xc0, 0xd6}, {0xd8, 0xf6}, {0xf8, 0x2c1}, {0x2c6, 0x2d1}, {0x2e0, 0x2e4}, {0x2ec, 0x2ec},
  {0x2ee, 0x2ee}, {0x300, 0x374}, {0x376, 0x377}, {0x37b, 0x37d}, {0x37f, 0x37f}, {0x386, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1},
  {0x3a3, 0x3f5}, {0x3f7, 0x481}, {0x483, 0x487}, {0x48a, 0x52f}, {0x531, 0x556}, {0x559, 0x559}, {0x560, 0x588}, {0x591, 0x5bd},
  {0x5bf, 0x5bf}, {0x5c1, 0x5c2}, {0x5c4, 0x5c5}, {0x5c7, 0x5c7}, {0x5d0, 0x5ea}, {0x5ef, 0x5f2}, {0x610, 0x61a}, {0x620, 0x669},
  {0x66e, 0x6d3}, {0x6d5, 0x6dc}, {0x6df, 0x6e8}, {0x6ea, 0x6fc}, {0x6ff, 0x6ff}, {0x710, 0x74a}, {0x74d, 0x7b1}, {0x7c0, 0x7f5},
  {0x7fa, 0x7fa}, {0x7fd, 0x7fd}, {0x800, 0x82d}, {0x840, 0x85b}, {0x860, 0x86a}, {0x870, 0x887}, {0x889, 0x88e}, {0x898, 0x8e1},
  {0x8e3, 0x963}, {0x966, 0x96f}, {0x971, 0x983}, {0x985, 0x98c}, {0x98f, 0x990}, {0x993, 0x9a8}, {0x9aa, 0x9b0}, {0x9b2, 0x9b2},
  {0x9b6, 0x9b9}, {0x9bc, 0x9c4}, {0x9c7, 0x9c8}, {0x9cb, 0x9ce}, {0x9d7, 0x9d7}, {0x9dc, 0x9dd}, {0x9df, 0x9e3}, {0x9e6, 0x9f1},
  {0x9fc, 0x9fc}, {0x9fe, 0x9fe}, {0xa01, 0xa03}, {0xa05, 0xa0a}, {0xa0f, 0xa10}, {0xa13, 0xa28}, {0xa2a, 0xa30}, {0xa32, 0xa33},
  {0xa35, 0xa36}, {0xa38, 0xa39}, {0xa3c, 0xa3c}, {0xa3e, 0xa42}, {0xa47, 0xa48}, {0xa4b, 0xa4d}, {0xa51, 0xa51}, {0xa59, 0xa5c},
  {0xa5e, 0xa5e}, {0xa66, 0xa75}, {0xa81, 0xa83}, {0xa85, 0xa8d}, {0xa8f, 0xa91}, {0xa93, 0xaa8}, {0xaaa, 0xab0}, {0xab2, 0xab3},
  {0xab5, 0xab9}, {0xabc, 0xac5}, {0xac7, 0xac9}, {0xacb, 0xacd}, {0xad0, 0xad0}, {0xae0, 0xae3}, {0xae6, 0xaef}, {0xaf9, 0xaff},
  {0xb01, 0xb03}, {0xb05, 0xb0c}, {0xb0f, 0xb10}, {0xb13, 0xb28}, {0xb2a, 0xb30}, {0xb32, 0xb33}, {0xb35, 0xb39}, {0xb3c, 0xb44},
  {0xb47, 0xb48}, {0xb4b, 0xb4d}, {0xb55, 0xb57}, {0xb5c, 0xb5d}, {0xb5f, 0xb63}, {0xb66, 0xb6f}, {0xb71, 0xb71}, {0xb82, 0xb83},
  {0xb85, 0xb8a}, {0xb8e, 0xb90}, {0xb92, 0xb95}, {0xb99, 0xb9a}, {0xb9c, 0xb9c}, {0xb9e, 0xb9f}, {0xba3, 0xba4}, {0xba8, 0xbaa},
  {0xbae, 0xbb9}, {0xbbe, 0xbc2}, {0xbc6, 0xbc8}, {0xbca, 0xbcd}, {0xbd0, 0xbd0}, {0xbd7, 0xbd7}, {0xbe6, 0xbef}, {0xc00, 0xc0c},
  {0xc0e, 0xc10}, {0xc12, 0xc28}, {0xc2a, 0xc39}, {0xc3c, 0xc44}, {0xc46, 0xc48}, {0xc4a, 0xc4d}, {0xc55, 0xc56}, {0xc58, 0xc5a},
  {0xc5d, 0xc5d}, {0xc60, 0xc63}, {0xc66, 0xc6f}, {0xc80, 0xc83}, {0xc85, 0xc8c}, {0xc8e, 0xc90}, {0xc92, 0xca8}, {0xcaa, 0xcb3},
  {0xcb5, 0xcb9}, {0xcbc, 0xcc4}, {0xcc6, 0xcc8}, {0xcca, 0xccd}, {0xcd5, 0xcd6}, {0xcdd, 0xcde}, {0xce0, 0xce3}, {0xce6, 0xcef},
  {0xcf1, 0xcf2}, {0xd00, 0xd0c}, {0xd0e, 0xd10}, {0xd12, 0xd44}, {0xd46, 0xd48}, {0xd4a, 0xd4e}, {0xd54, 0xd57}, {0xd5f, 0xd63},
  {0xd66, 0xd6f}, {0xd7a, 0xd7f}, {0xd81, 0xd83}, {0xd85, 0xd96}, {0xd9a, 0xdb1}, {0xdb3, 0xdbb}, {0xdbd, 0xdbd}, {0xdc0, 0xdc6},
  {0xdca, 0xdca}, {0xdcf, 0xdd4}, {0xdd6, 0xdd6}, {0xdd8, 0xddf}, {0xde6, 0xdef}, {0xdf2, 0xdf3}, {0xe01, 0xe3a}, {0xe40, 0xe4e},
  {0xe50, 0xe59}, {0xe81, 0xe82}, {0xe84, 0xe84}, {0xe86, 0xe8a}, {0xe8c, 0xea3}, {0xea5, 0xea5}, {0xea7, 0xebd}, {0xec0, 0xec4},
  {0xec6, 0xec6}, {0xec8, 0xecd}, {0xed0, 0xed9}, {0xedc, 0xedf}, {0xf00, 0xf00}, {0xf18, 0xf19}, {0xf20, 0xf29}, {0xf35, 0xf35},
  {0xf37, 0xf37}, {0xf39, 0xf39}, {0xf3e, 0xf47}, {0xf49, 0xf6c}, {0xf71, 0xf84}, {0xf86, 0xf97}, {0xf99, 0xfbc}, {0xfc6, 0xfc6},
  {0x1000, 0x1049}, {0x1050, 0x109d}, {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fc, 0x1248}, {0x124a, 0x124d},
  {0x1250, 0x1256}, {0x1258, 0x1258}, {0x125a, 0x125d}, {0x1260, 0x1288}, {0x128a, 0x128d}, {0x1290, 0x12b0}, {0x12b2, 0x12b5}, {0x12b8, 0x12be},
  {0x12c0, 0x12c0}, {0x12c2, 0x12c5}, {0x12c8, 0x12d6}, {0x12d8, 0x1310}, {0x1312, 0x1315}, {0x1318, 0x135a}, {0x135d, 0x135f}, {0x1369, 0x1371},
  {0x1380, 0x138f}, {0x13a0, 0x13f5}, {0x13f8, 0x13fd}, {0x1401, 0x166c}, {0x166f, 0x167f}, {0x1681, 0x169a}, {0x16a0, 0x16ea}, {0x16ee, 0x16f8},
  {0x1700, 0x1715}, {0x171f, 0x1734}, {0x1740, 0x1753}, {0x1760, 0x176c}, {0x176e, 0x1770}, {0x1772, 0x1773}, {0x1780, 0x17d3}, {0x17d7, 0x17d7},
  {0x17dc, 0x17dd}, {0x17e0, 0x17e9}, {0x180b, 0x180d}, {0x180f, 0x1819}, {0x1820, 0x1878}, {0x1880, 0x18aa}, {0x18b0, 0x18f5}, {0x1900, 0x191e},
  {0x1920, 0x192b}, {0x1930, 0x193b}, {0x1946, 0x196d}, {0x1970, 0x1974}, {0x1980, 0x19ab}, {0x19b0, 0x19c9}, {0x19d0, 0x19da}, {0x1a00, 0x1a1b},
  {0x1a20, 0x1a5e}, {0x1a60, 0x1a7c}, {0x1a7f, 0x1a89}, {0x1a90, 0x1a99}, {0x1aa7, 0x1aa7}, {0x1ab0, 0x1abd}, {0x1abf, 0x1ace}, {0x1b00, 0x1b4c},
  {0x1b50, 0x1b59}, {0x1b6b, 0x1b73}, {0x1b80, 0x1bf3}, {0x1c00, 0x1c37}, {0x1c40, 0x1c49}, {0x1c4d, 0x1c7d}, {0x1c80, 0x1c88}, {0x1c90, 0x1cba},
  {0x1cbd, 0x1cbf}, {0x1cd0, 0x1cd2}, {0x1cd4, 0x1cfa}, {0x1d00, 0x1f15}, {0x1f18, 0x1f1d}, {0x1f20, 0x1f45}, {0x1f48, 0x1f4d}, {0x1f50, 0x1f57},
  {0x1f59, 0x1f59}, {0x1f5b, 0x1f5b}, {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d}, {0x1f80, 0x1fb4}, {0x1fb6, 0x1fbc}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4},
  {0x1fc6, 0x1fcc}, {0x1fd0, 0x1fd3}, {0x1fd6, 0x1fdb}, {0x1fe0, 0x1fec}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffc}, {0x203f, 0x2040}, {0x2054, 0x2054},
  {0x2071, 0x2071}, {0x207f, 0x207f}, {0x2090, 0x209c}, {0x20d0, 0x20dc}, {0x20e1, 0x20e1}, {0x20e5, 0x20f0}, {0x2102, 0x2102}, {0x2107, 0x2107},
  {0x210a, 0x2113}, {0x2115, 0x2115}, {0x2118, 0x211d}, {0x2124, 0x2124}, {0x2126, 0x2126}, {0x2128, 0x2128}, {0x212a, 0x2139}, {0x213c, 0x213f},
  {0x2145, 0x2149}, {0x214e, 0x214e}, {0x2160, 0x2188}, {0x2c00, 0x2ce4}, {0x2ceb, 0x2cf3}, {0x2d00, 0x2d25}, {0x2d27, 0x2d27}, {0x2d2d, 0x2d2d},
  {0x2d30, 0x2d67}, {0x2d6f, 0x2d6f}, {0x2d7f, 0x2d96}, {0x2da0, 0x2da6}, {0x2da8, 0x2dae}, {0x2db0, 0x2db6}, {0x2db8, 0x2dbe}, {0x2dc0, 0x2dc6},
  {0x2dc8, 0x2dce}, {0x2dd0, 0x2dd6}, {0x2dd8, 0x2dde}, {0x2de0, 0x2dff}, {0x3005, 0x3007}, {0x3021, 0x302f}, {0x3031, 0x3035}, {0x3038, 0x303c},
  {0x3041, 0x3096}, {0x3099, 0x309a}, {0x309d, 0x309f}, {0x30a1, 0x30fa}, {0x30fc, 0x30ff}, {0x3105, 0x312f}, {0x3131, 0x318e}, {0x31a0, 0x31bf},
  {0x31f0, 0x31ff}, {0x3400, 0x4dbf}, {0x4e00, 0xa48c}, {0xa4d0, 0xa4fd}, {0xa500, 0xa60c}, {0xa610, 0xa62b}, {0xa640, 0xa66f}, {0xa674, 0xa67d},
  {0xa67f, 0xa6f1}, {0xa717, 0xa71f}, {0xa722, 0xa788}, {0xa78b, 0xa7ca}, {0xa7d0, 0xa7d1}, {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7d9}, {0xa7f2, 0xa827},
  {0xa82c, 0xa82c}, {0xa840, 0xa873}, {0xa880, 0xa8c5}, {0xa8d0, 0xa8d9}, {0xa8e0, 0xa8f7}, {0xa8fb, 0xa8fb}, {0xa8fd, 0xa92d}, {0xa930, 0xa953},
  {0xa960, 0xa97c}, {0xa980, 0xa9c0}, {0xa9cf, 0xa9d9}, {0xa9e0, 0xa9fe}, {0xaa00, 0xaa36}, {0xaa40, 0xaa4d}, {0xaa50, 0xaa59}, {0xaa60, 0xaa76},
  {0xaa7a, 0xaac2}, {0xaadb, 0xaadd}, {0xaae0, 0xaaef}, {0xaaf2, 0xaaf6}, {0xab01, 0xab06}, {0xab09, 0xab0e}, {0xab11, 0xab16}, {0xab20, 0xab26},
  {0xab28, 0xab2e}, {0xab30, 0xab5a}, {0xab5c, 0xab69}, {0xab70, 0xabea}, {0xabec, 0xabed}, {0xabf0, 0xabf9}, {0xac00, 0xd7a3}, {0xd7b0, 0xd7c6},
  {0xd7cb, 0xd7fb}, {0xf900, 0xfa6d}, {0xfa70, 0xfad9}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17}, {0xfb1d, 0xfb28}, {0xfb2a, 0xfb36}, {0xfb38, 0xfb3c},
  {0xfb3e, 0xfb3e}, {0xfb40, 0xfb41}, {0xfb43, 0xfb44}, {0xfb46, 0xfbb1}, {0xfbd3, 0xfc5d}, {0xfc64, 0xfd3d}, {0xfd50, 0xfd8f}, {0xfd92, 0xfdc7},
  {0xfdf0, 0xfdf9}, {0xfe00, 0xfe0f}, {0xfe20, 0xfe2f}, {0xfe33, 0xfe34}, {0xfe4d, 0xfe4f}, {0xfe71, 0xfe71}, {0xfe73, 0xfe73}, {0xfe77, 0xfe77},
  {0xfe79, 0xfe79}, {0xfe7b, 0xfe7b}, {0xfe7d, 0xfe7d}, {0xfe7f, 0xfefc}, {0xff10, 0xff19}, {0xff21, 0xff3a}, {0xff3f, 0xff3f}, {0xff41, 0xff5a},
  {0xff66, 0xffbe}, {0xffc2, 0xffc7}, {0xffca, 0xffcf}, {0xffd2, 0xffd7}, {0xffda, 0xffdc}, {0x10000, 0x1000b}, {0x1000d, 0x10026}, {0x10028, 0x1003a},
  {0x1003c, 0x1003d}, {0x1003f, 0x1004d}, {0x10050, 0x1005d}, {0x10080, 0x100fa}, {0x10140, 0x10174}, {0x101fd, 0x101fd}, {0x10280, 0x1029c}, {0x102a0, 0x102d0},
  {0x102e0, 0x102e0}, {0x10300, 0x1031f}, {0x1032d, 0x1034a}, {0x10350, 0x1037a}, {0x10380, 0x1039d}, {0x103a0, 0x103c3}, {0x103c8, 0x103cf}, {0x103d1, 0x103d5},
  {0x10400, 0x1049d}, {0x104a0, 0x104a9}, {0x104b0, 0x104d3}, {0x104d8, 0x104fb}, {0x10500, 0x10527}, {0x10530, 0x10563}, {0x10570, 0x1057a}, {0x1057c, 0x1058a},
  {0x1058c, 0x10592}, {0x10594, 0x10595}, {0x10597, 0x105a1}, {0x105a3, 0x105b1}, {0x105b3, 0x105b9}, {0x105bb, 0x105bc}, {0x10600, 0x10736}, {0x10740, 0x10755},
  {0x10760, 0x10767}, {0x10780, 0x10785}, {0x10787, 0x107b0}, {0x107b2, 0x107ba}, {0x10800, 0x10805}, {0x10808, 0x10808}, {0x1080a, 0x10835}, {0x10837, 0x10838},
  {0x1083c, 0x1083c}, {0x1083f, 0x10855}, {0x10860, 0x10876}, {0x10880, 0x1089e}, {0x108e0, 0x108f2}, {0x108f4, 0x108f5}, {0x10900, 0x10915}, {0x10920, 0x10939},
  {0x10980, 0x109b7}, {0x109be, 0x109bf}, {0x10a00, 0x10a03}, {0x10a05, 0x10a06}, {0x10a0c, 0x10a13}, {0x10a15, 0x10a17}, {0x10a19, 0x10a35}, {0x10a38, 0x10a3a},
  {0x10a3f, 0x10a3f}, {0x10a60, 0x10a7c}, {0x10a80, 0x10a9c}, {0x10ac0, 0x10ac7}, {0x10ac9, 0x10ae6}, {0x10b00, 0x10b35}, {0x10b40, 0x10b55}, {0x10b60, 0x10b72},
  {0x10b80, 0x10b91}, {0x10c00, 0x10c48}, {0x10c80, 0x10cb2}, {0x10cc0, 0x10cf2}, {0x10d00, 0x10d27}, {0x10d30, 0x10d39}, {0x10e80, 0x10ea9}, {0x10eab, 0x10eac},
  {0x10eb0, 0x10eb1}, {0x10f00, 0x10f1c}, {0x10f27, 0x10f27}, {0x10f30, 0x10f50}, {0x10f70, 0x10f85}, {0x10fb0, 0x10fc4}, {0x10fe0, 0x10ff6}, {0x11000, 0x11046},
  {0x11066, 0x11075}, {0x1107f, 0x110ba}, {0x110c2, 0x110c2}, {0x110d0, 0x110e8}, {0x110f0, 0x110f9}, {0x11100, 0x11134}, {0x11136, 0x1113f}, {0x11144, 0x11147},
  {0x11150, 0x11173}, {0x11176, 0x11176}, {0x11180, 0x111c4}, {0x111c9, 0x111cc}, {0x111ce, 0x111da}, {0x111dc, 0x111dc}, {0x11200, 0x11211}, {0x11213, 0x11237},
  {0x1123e, 0x1123e}, {0x11280, 0x11286}, {0x11288, 0x11288}, {0x1128a, 0x1128d}, {0x1128f, 0x1129d}, {0x1129f, 0x112a8}, {0x112b0, 0x112ea}, {0x112f0, 0x112f9},
  {0x11300, 0x11303}, {0x11305, 0x1130c}, {0x1130f, 0x11310}, {0x11313, 0x11328}, {0x1132a, 0x11330}, {0x11332, 0x11333}, {0x11335, 0x11339}, {0x1133b, 0x11344},
  {0x11347, 0x11348}, {0x1134b, 0x1134d}, {0x11350, 0x11350}, {0x11357, 0x11357}, {0x1135d, 0x11363}, {0x11366, 0x1136c}, {0x11370, 0x11374}, {0x11400, 0x1144a},
  {0x11450, 0x11459}, {0x1145e, 0x11461}, {0x11480, 0x114c5}, {0x114c7, 0x114c7}, {0x114d0, 0x114d9}, {0x11580, 0x115b5}, {0x115b8, 0x115c0}, {0x115d8, 0x115dd},
  {0x11600, 0x11640}, {0x11644, 0x11644}, {0x11650, 0x11659}, {0x11680, 0x116b8}, {0x116c0, 0x116c9}, {0x11700, 0x1171a}, {0x1171d, 0x1172b}, {0x11730, 0x11739},
  {0x11740, 0x11746}, {0x11800, 0x1183a}, {0x118a0, 0x118e9}, {0x118ff, 0x11906}, {0x11909, 0x11909}, {0x1190c, 0x11913}, {0x11915, 0x11916}, {0x11918, 0x11935},
  {0x11937, 0x11938}, {0x1193b, 0x11943}, {0x11950, 0x11959}, {0x119a0, 0x119a7}, {0x119aa, 0x119d7}, {0x119da, 0x119e1}, {0x119e3, 0x119e4}, {0x11a00, 0x11a3e},
  {0x11a47, 0x11a47}, {0x11a50, 0x11a99}, {0x11a9d, 0x11a9d}, {0x11ab0, 0x11af8}, {0x11c00, 0x11c08}, {0x11c0a, 0x11c36}, {0x11c38, 0x11c40}, {0x11c50, 0x11c59},
  {0x11c72, 0x11c8f}, {0x11c92, 0x11ca7}, {0x11ca9, 0x11cb6}, {0x11d00, 0x11d06}, {0x11d08, 0x11d09}, {0x11d0b, 0x11d36}, {0x11d3a, 0x11d3a}, {0x11d3c, 0x11d3d},
  {0x11d3f, 0x11d47}, {0x11d50, 0x11d59}, {0x11d60, 0x11d65}, {0x11d67, 0x11d68}, {0x11d6a, 0x11d8e}, {0x11d90, 0x11d91}, {0x11d93, 0x11d98}, {0x11da0, 0x11da9},
  {0x11ee0, 0x11ef6}, {0x11fb0, 0x11fb0}, {0x12000, 0x12399}, {0x12400, 0x1246e}, {0x12480, 0x12543}, {0x12f90, 0x12ff0}, {0x13000, 0x1342e}, {0x14400, 0x14646},
  {0x16800, 0x16a38}, {0x16a40, 0x16a5e}, {0x16a60, 0x16a69}, {0x16a70, 0x16abe}, {0x16ac0, 0x16ac9}, {0x16ad0, 0x16aed}, {0x16af0, 0x16af4}, {0x16b00, 0x16b36},
  {0x16b40, 0x16b43}, {0x16b50, 0x16b59}, {0x16b63, 0x16b77}, {0x16b7d, 0x16b8f}, {0x16e40, 0x16e7f}, {0x16f00, 0x16f4a}, {0x16f4f, 0x16f87}, {0x16f8f, 0x16f9f},
  {0x16fe0, 0x16fe1}, {0x16fe3, 0x16fe4}, {0x16ff0, 0x16ff1}, {0x17000, 0x187f7}, {0x18800, 0x18cd5}, {0x18d00, 0x18d08}, {0x1aff0, 0x1aff3}, {0x1aff5, 0x1affb},
  {0x1affd, 0x1affe}, {0x1b000, 0x1b122}, {0x1b150, 0x1b152}, {0x1b164, 0x1b167}, {0x1b170, 0x1b2fb}, {0x1bc00, 0x1bc6a}, {0x1bc70, 0x1bc7c}, {0x1bc80, 0x1bc88},
  {0x1bc90, 0x1bc99}, {0x1bc9d, 0x1bc9e}, {0x1cf00, 0x1cf2d}, {0x1cf30, 0x1cf46}, {0x1d165, 0x1d169}, {0x1d16d, 0x1d172}, {0x1d17b, 0x1d182}, {0x1d185, 0x1d18b},
  {0x1d1aa, 0x1d1ad}, {0x1d242, 0x1d244}, {0x1d400, 0x1d454}, {0x1d456, 0x1d49c}, {0x1d49e, 0x1d49f}, {0x1d4a2, 0x1d4a2}, {0x1d4a5, 0x1d4a6}, {0x1d4a9, 0x1d4ac},
  {0x1d4ae, 0x1d4b9}, {0x1d4bb, 0x1d4bb}, {0x1d4bd, 0x1d4c3}, {0x1d4c5, 0x1d505}, {0x1d507, 0x1d50a}, {0x1d50d, 0x1d514}, {0x1d516, 0x1d51c}, {0x1d51e, 0x1d539},
  {0x1d53b, 0x1d53e}, {0x1d540, 0x1d544}, {0x1d546, 0x1d546}, {0x1d54a, 0x1d550}, {0x1d552, 0x1d6a5}, {0x1d6a8, 0x1d6c0}, {0x1d6c2, 0x1d6da}, {0x1d6dc, 0x1d6fa},
  {0x1d6fc, 0x1d714}, {0x1d716, 0x1d734}, {0x1d736, 0x1d74e}, {0x1d750, 0x1d76e}, {0x1d770, 0x1d788}, {0x1d78a, 0x1d7a8}, {0x1d7aa, 0x1d7c2}, {0x1d7c4, 0x1d7cb},
  {0x1d7ce, 0x1d7ff}, {0x1da00, 0x1da36}, {0x1da3b, 0x1da6c}, {0x1da75, 0x1da75}, {0x1da84, 0x1da84}, {0x1da9b, 0x1da9f}, {0x1daa1, 0x1daaf}, {0x1df00, 0x1df1e},
  {0x1e000, 0x1e006}, {0x1e008, 0x1e018}, {0x1e01b, 0x1e021}, {0x1e023, 0x1e024}, {0x1e026, 0x1e02a}, {0x1e100, 0x1e12c}, {0x1e130, 0x1e13d}, {0x1e140, 0x1e149},
  {0x1e14e, 0x1e14e}, {0x1e290, 0x1e2ae}, {0x1e2c0, 0x1e2f9}, {0x1e7e0, 0x1e7e6}, {0x1e7e8, 0x1e7eb}, {0x1e7ed, 0x1e7ee}, {0x1e7f0, 0x1e7fe}, {0x1e800, 0x1e8c4},
  {0x1e8d0, 0x1e8d6}, {0x1e900, 0x1e94b}, {0x1e950, 0x1e959}, {0x1ee00, 0x1ee03}, {0x1ee05, 0x1ee1f}, {0x1ee21, 0x1ee22}, {0x1ee24, 0x1ee24}, {0x1ee27, 0x1ee27},
  {0x1ee29, 0x1ee32}, {0x1ee34, 0x1ee37}, {0x1ee39, 0x1ee39}, {0x1ee3b, 0x1ee3b}, {0x1ee42, 0x1ee42}, {0x1ee47, 0x1ee47}, {0x1ee49, 0x1ee49}, {0x1ee4b, 0x1ee4b},
  {0x1ee4d, 0x1ee4f}, {0x1ee51, 0x1ee52}, {0x1ee54, 0x1ee54}, {0x1ee57, 0x1ee57}, {0x1ee59, 0x1ee59}, {0x1ee5b, 0x1ee5b}, {0x1ee5d, 0x1ee5d}, {0x1ee5f, 0x1ee5f},
  {0x1ee61, 0x1ee62}, {0x1ee64, 0x1ee64}, {0x1ee67, 0x1ee6a}, {0x1ee6c, 0x1ee72}, {0x1ee74, 0x1ee77}, {0x1ee79, 0x1ee7c}, {0x1ee7e, 0x1ee7e}, {0x1ee80, 0x1ee89},
  {0x1ee8b, 0x1ee9b}, {0x1eea1, 0x1eea3}, {0x1eea5, 0x1eea9}, {0x1eeab, 0x1eebb}, {0x1fbf0, 0x1fbf9}, {0x20000, 0x2a6df}, {0x2a700, 0x2b738}, {0x2b740, 0x2b81d},
  {0x2b820, 0x2cea1}, {0x2ceb0, 0x2ebe0}, {0x2f800, 0x2fa1d}, {0x30000, 0x3134a}, {0xe0100, 0xe01ef},
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(338);
      ADVANCE_MAP(
        '!', 405,
        '"', 525,
        '#', 285,
        '%', 429,
        '&', 439,
        '\'', 516,
        '(', 342,
        ')', 345,
        '*', 425,
        '+', 419,
        ',', 344,
        '-', 408,
        '.', 489,
        '/', 427,
        '0', 640,
        ':', 458,
        ';', 459,
        '<', 449,
        '=', 471,
        '>', 638,
        '?', 474,
        'F', 565,
        'L', 539,
        'R', 542,
        'T', 569,
        'U', 543,
        '[', 467,
        '\\', 2,
        ']', 469,
        '^', 436,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 574,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        't', 616,
        'u', 546,
        'v', 608,
        '{', 463,
        '|', 433,
        '}', 464,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(336);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 1:
      if (lookahead == '\n') SKIP(163);
      END_STATE();
    case 2:
      if (lookahead == '\n') SKIP(163);
      if (lookahead == '\r') SKIP(1);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 3:
      if (lookahead == '\n') SKIP(172);
      END_STATE();
    case 4:
      if (lookahead == '\n') SKIP(172);
      if (lookahead == '\r') SKIP(3);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 5:
      if (lookahead == '\n') SKIP(171);
      END_STATE();
    case 6:
      if (lookahead == '\n') SKIP(171);
      if (lookahead == '\r') SKIP(5);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 7:
      if (lookahead == '\n') SKIP(174);
      END_STATE();
    case 8:
      if (lookahead == '\n') SKIP(174);
      if (lookahead == '\r') SKIP(7);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 9:
      if (lookahead == '\n') SKIP(173);
      END_STATE();
    case 10:
      if (lookahead == '\n') SKIP(173);
      if (lookahead == '\r') SKIP(9);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 11:
      if (lookahead == '\n') SKIP(175);
      END_STATE();
    case 12:
      if (lookahead == '\n') SKIP(175);
      if (lookahead == '\r') SKIP(11);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 13:
      if (lookahead == '\n') SKIP(239);
      END_STATE();
    case 14:
      if (lookahead == '\n') SKIP(239);
      if (lookahead == '\r') SKIP(13);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 15:
      if (lookahead == '\n') SKIP(195);
      END_STATE();
    case 16:
      if (lookahead == '\n') SKIP(195);
      if (lookahead == '\r') SKIP(15);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 17:
      if (lookahead == '\n') SKIP(240);
      END_STATE();
    case 18:
      if (lookahead == '\n') SKIP(240);
      if (lookahead == '\r') SKIP(17);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 19:
      if (lookahead == '\n') SKIP(169);
      END_STATE();
    case 20:
      if (lookahead == '\n') SKIP(169);
      if (lookahead == '\r') SKIP(19);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 21:
      if (lookahead == '\n') SKIP(166);
      END_STATE();
    case 22:
      if (lookahead == '\n') SKIP(166);
      if (lookahead == '\r') SKIP(21);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 23:
      if (lookahead == '\n') SKIP(176);
      END_STATE();
    case 24:
      if (lookahead == '\n') SKIP(176);
      if (lookahead == '\r') SKIP(23);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 25:
      if (lookahead == '\n') SKIP(167);
      END_STATE();
    case 26:
      if (lookahead == '\n') SKIP(167);
      if (lookahead == '\r') SKIP(25);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 27:
      if (lookahead == '\n') SKIP(188);
      END_STATE();
    case 28:
      if (lookahead == '\n') SKIP(188);
      if (lookahead == '\r') SKIP(27);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 29:
      if (lookahead == '\n') SKIP(184);
      END_STATE();
    case 30:
      if (lookahead == '\n') SKIP(184);
      if (lookahead == '\r') SKIP(29);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 31:
      if (lookahead == '\n') SKIP(196);
      END_STATE();
    case 32:
      if (lookahead == '\n') SKIP(196);
      if (lookahead == '\r') SKIP(31);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 33:
      if (lookahead == '\n') SKIP(194);
      END_STATE();
    case 34:
      if (lookahead == '\n') SKIP(194);
      if (lookahead == '\r') SKIP(33);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 35:
      if (lookahead == '\n') SKIP(225);
      END_STATE();
    case 36:
      if (lookahead == '\n') SKIP(225);
      if (lookahead == '\r') SKIP(35);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 37:
      if (lookahead == '\n') SKIP(177);
      END_STATE();
    case 38:
      if (lookahead == '\n') SKIP(177);
      if (lookahead == '\r') SKIP(37);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 39:
      if (lookahead == '\n') SKIP(185);
      END_STATE();
    case 40:
      if (lookahead == '\n') SKIP(185);
      if (lookahead == '\r') SKIP(39);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 41:
      if (lookahead == '\n') SKIP(189);
      END_STATE();
    case 42:
      if (lookahead == '\n') SKIP(189);
      if (lookahead == '\r') SKIP(41);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 43:
      if (lookahead == '\n') SKIP(238);
      END_STATE();
    case 44:
      if (lookahead == '\n') SKIP(238);
      if (lookahead == '\r') SKIP(43);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 45:
      if (lookahead == '\n') SKIP(179);
      END_STATE();
    case 46:
      if (lookahead == '\n') SKIP(179);
      if (lookahead == '\r') SKIP(45);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 47:
      if (lookahead == '\n') SKIP(197);
      END_STATE();
    case 48:
      if (lookahead == '\n') SKIP(197);
      if (lookahead == '\r') SKIP(47);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 49:
      if (lookahead == '\n') SKIP(233);
      END_STATE();
    case 50:
      if (lookahead == '\n') SKIP(233);
      if (lookahead == '\r') SKIP(49);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 51:
      if (lookahead == '\n') SKIP(209);
      END_STATE();
    case 52:
      if (lookahead == '\n') SKIP(209);
      if (lookahead == '\r') SKIP(51);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 53:
      if (lookahead == '\n') SKIP(242);
      END_STATE();
    case 54:
      if (lookahead == '\n') SKIP(242);
      if (lookahead == '\r') SKIP(53);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 55:
      if (lookahead == '\n') SKIP(205);
      END_STATE();
    case 56:
      if (lookahead == '\n') SKIP(205);
      if (lookahead == '\r') SKIP(55);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 57:
      if (lookahead == '\n') SKIP(216);
      END_STATE();
    case 58:
      if (lookahead == '\n') SKIP(216);
      if (lookahead == '\r') SKIP(57);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 59:
      if (lookahead == '\n') SKIP(226);
      END_STATE();
    case 60:
      if (lookahead == '\n') SKIP(226);
      if (lookahead == '\r') SKIP(59);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 61:
      if (lookahead == '\n') SKIP(241);
      END_STATE();
    case 62:
      if (lookahead == '\n') SKIP(241);
      if (lookahead == '\r') SKIP(61);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 63:
      if (lookahead == '\n') SKIP(186);
      END_STATE();
    case 64:
      if (lookahead == '\n') SKIP(186);
      if (lookahead == '\r') SKIP(63);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 65:
      if (lookahead == '\n') SKIP(190);
      END_STATE();
    case 66:
      if (lookahead == '\n') SKIP(190);
      if (lookahead == '\r') SKIP(65);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 67:
      if (lookahead == '\n') SKIP(229);
      END_STATE();
    case 68:
      if (lookahead == '\n') SKIP(229);
      if (lookahead == '\r') SKIP(67);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 69:
      if (lookahead == '\n') SKIP(212);
      END_STATE();
    case 70:
      if (lookahead == '\n') SKIP(212);
      if (lookahead == '\r') SKIP(69);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 71:
      if (lookahead == '\n') SKIP(203);
      END_STATE();
    case 72:
      if (lookahead == '\n') SKIP(203);
      if (lookahead == '\r') SKIP(71);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 73:
      if (lookahead == '\n') SKIP(220);
      END_STATE();
    case 74:
      if (lookahead == '\n') SKIP(220);
      if (lookahead == '\r') SKIP(73);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 75:
      if (lookahead == '\n') SKIP(182);
      END_STATE();
    case 76:
      if (lookahead == '\n') SKIP(182);
      if (lookahead == '\r') SKIP(75);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 77:
      if (lookahead == '\n') SKIP(170);
      END_STATE();
    case 78:
      if (lookahead == '\n') SKIP(170);
      if (lookahead == '\r') SKIP(77);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 79:
      if (lookahead == '\n') SKIP(219);
      END_STATE();
    case 80:
      if (lookahead == '\n') SKIP(219);
      if (lookahead == '\r') SKIP(79);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 81:
      if (lookahead == '\n') SKIP(218);
      END_STATE();
    case 82:
      if (lookahead == '\n') SKIP(218);
      if (lookahead == '\r') SKIP(81);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 83:
      if (lookahead == '\n') SKIP(211);
      END_STATE();
    case 84:
      if (lookahead == '\n') SKIP(211);
      if (lookahead == '\r') SKIP(83);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 85:
      if (lookahead == '\n') SKIP(192);
      END_STATE();
    case 86:
      if (lookahead == '\n') SKIP(192);
      if (lookahead == '\r') SKIP(85);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 87:
      if (lookahead == '\n') SKIP(245);
      END_STATE();
    case 88:
      if (lookahead == '\n') SKIP(245);
      if (lookahead == '\r') SKIP(87);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 89:
      if (lookahead == '\n') SKIP(243);
      END_STATE();
    case 90:
      if (lookahead == '\n') SKIP(243);
      if (lookahead == '\r') SKIP(89);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 91:
      if (lookahead == '\n') SKIP(244);
      END_STATE();
    case 92:
      if (lookahead == '\n') SKIP(244);
      if (lookahead == '\r') SKIP(91);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 93:
      if (lookahead == '\n') SKIP(224);
      END_STATE();
    case 94:
      if (lookahead == '\n') SKIP(224);
      if (lookahead == '\r') SKIP(93);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 95:
      if (lookahead == '\n') SKIP(251);
      END_STATE();
    case 96:
      if (lookahead == '\n') SKIP(251);
      if (lookahead == '\r') SKIP(95);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 97:
      if (lookahead == '\n') SKIP(99);
      END_STATE();
    case 98:
      if (lookahead == '\n') SKIP(99);
      if (lookahead == '\r') SKIP(97);
      END_STATE();
    case 99:
      ADVANCE_MAP(
        '\n', 347,
        '!', 272,
        '%', 428,
        '&', 438,
        '(', 403,
        '*', 424,
        '+', 417,
        '-', 407,
        '/', 426,
        '<', 452,
        '=', 273,
        '>', 443,
      );
      if (lookahead == '\\') SKIP(98);
      if (lookahead == '^') ADVANCE(435);
      if (lookahead == '|') ADVANCE(434);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(99);
      END_STATE();
    case 100:
      if (lookahead == '\n') SKIP(178);
      END_STATE();
    case 101:
      if (lookahead == '\n') SKIP(178);
      if (lookahead == '\r') SKIP(100);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 102:
      if (lookahead == '\n') SKIP(234);
      END_STATE();
    case 103:
      if (lookahead == '\n') SKIP(234);
      if (lookahead == '\r') SKIP(102);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 104:
      if (lookahead == '\n') SKIP(250);
      END_STATE();
    case 105:
      if (lookahead == '\n') SKIP(250);
      if (lookahead == '\r') SKIP(104);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 106:
      if (lookahead == '\n') SKIP(235);
      END_STATE();
    case 107:
      if (lookahead == '\n') SKIP(235);
      if (lookahead == '\r') SKIP(106);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 108:
      if (lookahead == '\n') SKIP(247);
      if (lookahead == '\'') ADVANCE(516);
      if (lookahead == '/') ADVANCE(519);
      if (lookahead == '\\') ADVANCE(518);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(520);
      if (lookahead != 0) ADVANCE(517);
      END_STATE();
    case 109:
      if (lookahead == '\n') ADVANCE(532);
      if (lookahead == '\r') ADVANCE(531);
      if (lookahead == 'U') ADVANCE(334);
      if (lookahead == 'u') ADVANCE(326);
      if (lookahead == 'x') ADVANCE(322);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(534);
      if (lookahead != 0) ADVANCE(531);
      END_STATE();
    case 110:
      if (lookahead == '\n') SKIP(236);
      if (lookahead == '"') ADVANCE(525);
      if (lookahead == '/') ADVANCE(526);
      if (lookahead == '\\') ADVANCE(109);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(529);
      if (lookahead != 0) ADVANCE(530);
      END_STATE();
    case 111:
      if (lookahead == '\n') ADVANCE(340);
      if (lookahead == '\r') ADVANCE(115);
      if (lookahead == '(') ADVANCE(342);
      if (lookahead == '/') ADVANCE(368);
      if (lookahead == '\\') ADVANCE(363);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(264);
      if (lookahead != 0) ADVANCE(370);
      END_STATE();
    case 112:
      if (lookahead == '\n') ADVANCE(340);
      if (lookahead == '\r') ADVANCE(115);
      if (lookahead == '/') ADVANCE(368);
      if (lookahead == '\\') ADVANCE(363);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(264);
      if (lookahead != 0) ADVANCE(370);
      END_STATE();
    case 113:
      if (lookahead == '\n') ADVANCE(340);
      if (lookahead == '\r') ADVANCE(114);
      if (lookahead == '(') ADVANCE(403);
      if (lookahead == '/') ADVANCE(255);
      if (lookahead == '\\') SKIP(117);
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(252);
      END_STATE();
    case 114:
      if (lookahead == '\n') ADVANCE(340);
      if (lookahead == '(') ADVANCE(403);
      if (lookahead == '/') ADVANCE(255);
      if (lookahead == '\\') SKIP(117);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(252);
      END_STATE();
    case 115:
      if (lookahead == '\n') ADVANCE(340);
      if (lookahead == '/') ADVANCE(368);
      if (lookahead == '\\') ADVANCE(363);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(264);
      if (lookahead != 0) ADVANCE(370);
      END_STATE();
    case 116:
      if (lookahead == '\n') SKIP(252);
      END_STATE();
    case 117:
      if (lookahead == '\n') SKIP(252);
      if (lookahead == '\r') SKIP(116);
      END_STATE();
    case 118:
      if (lookahead == '\n') SKIP(164);
      END_STATE();
    case 119:
      if (lookahead == '\n') SKIP(164);
      if (lookahead == '\r') SKIP(118);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 120:
      if (lookahead == '\n') SKIP(168);
      END_STATE();
    case 121:
      if (lookahead == '\n') SKIP(168);
      if (lookahead == '\r') SKIP(120);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 122:
      if (lookahead == '\n') SKIP(180);
      END_STATE();
    case 123:
      if (lookahead == '\n') SKIP(180);
      if (lookahead == '\r') SKIP(122);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 124:
      if (lookahead == '\n') SKIP(200);
      END_STATE();
    case 125:
      if (lookahead == '\n') SKIP(200);
      if (lookahead == '\r') SKIP(124);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 126:
      if (lookahead == '\n') SKIP(210);
      END_STATE();
    case 127:
      if (lookahead == '\n') SKIP(210);
      if (lookahead == '\r') SKIP(126);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 128:
      if (lookahead == '\n') SKIP(199);
      END_STATE();
    case 129:
      if (lookahead == '\n') SKIP(199);
      if (lookahead == '\r') SKIP(128);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 130:
      if (lookahead == '\n') SKIP(230);
      END_STATE();
    case 131:
      if (lookahead == '\n') SKIP(230);
      if (lookahead == '\r') SKIP(130);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 132:
      if (lookahead == '\n') SKIP(227);
      END_STATE();
    case 133:
      if (lookahead == '\n') SKIP(227);
      if (lookahead == '\r') SKIP(132);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 134:
      if (lookahead == '\n') SKIP(202);
      END_STATE();
    case 135:
      if (lookahead == '\n') SKIP(202);
      if (lookahead == '\r') SKIP(134);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 136:
      if (lookahead == '\n') SKIP(223);
      END_STATE();
    case 137:
      if (lookahead == '\n') SKIP(223);
      if (lookahead == '\r') SKIP(136);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 138:
      if (lookahead == '\n') SKIP(214);
      END_STATE();
    case 139:
      if (lookahead == '\n') SKIP(214);
      if (lookahead == '\r') SKIP(138);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 140:
      if (lookahead == '\n') SKIP(246);
      END_STATE();
    case 141:
      if (lookahead == '\n') SKIP(246);
      if (lookahead == '\r') SKIP(140);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 142:
      if (lookahead == '\n') SKIP(165);
      END_STATE();
    case 143:
      if (lookahead == '\n') SKIP(165);
      if (lookahead == '\r') SKIP(142);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 144:
      if (lookahead == '\n') SKIP(206);
      END_STATE();
    case 145:
      if (lookahead == '\n') SKIP(206);
      if (lookahead == '\r') SKIP(144);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 146:
      if (lookahead == '\n') SKIP(217);
      END_STATE();
    case 147:
      if (lookahead == '\n') SKIP(217);
      if (lookahead == '\r') SKIP(146);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 148:
      if (lookahead == '\n') SKIP(208);
      END_STATE();
    case 149:
      if (lookahead == '\n') SKIP(208);
      if (lookahead == '\r') SKIP(148);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 150:
      if (lookahead == '\n') SKIP(222);
      END_STATE();
    case 151:
      if (lookahead == '\n') SKIP(222);
      if (lookahead == '\r') SKIP(150);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 152:
      if (lookahead == '\n') SKIP(215);
      END_STATE();
    case 153:
      if (lookahead == '\n') SKIP(215);
      if (lookahead == '\r') SKIP(152);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 154:
      if (lookahead == '\n') SKIP(198);
      END_STATE();
    case 155:
      if (lookahead == '\n') SKIP(198);
      if (lookahead == '\r') SKIP(154);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 156:
      if (lookahead == '\n') SKIP(228);
      END_STATE();
    case 157:
      if (lookahead == '\n') SKIP(228);
      if (lookahead == '\r') SKIP(156);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 158:
      if (lookahead == '\n') SKIP(232);
      END_STATE();
    case 159:
      if (lookahead == '\n') SKIP(232);
      if (lookahead == '\r') SKIP(158);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 160:
      if (lookahead == '\n') SKIP(204);
      END_STATE();
    case 161:
      if (lookahead == '\n') SKIP(204);
      if (lookahead == '\r') SKIP(160);
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 162:
      if (lookahead == '\r') ADVANCE(637);
      if (lookahead == '\\') ADVANCE(631);
      if (lookahead != 0) ADVANCE(636);
      END_STATE();
    case 163:
      ADVANCE_MAP(
        '!', 405,
        '"', 525,
        '#', 285,
        '%', 429,
        '&', 439,
        '\'', 516,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 419,
        ',', 344,
        '-', 408,
        '.', 489,
        '/', 427,
        '0', 640,
        ':', 458,
        ';', 459,
        '<', 449,
        '=', 471,
        '>', 638,
        '?', 474,
        'F', 565,
        'L', 539,
        'R', 542,
        'T', 569,
        'U', 543,
        '[', 467,
        '\\', 2,
        ']', 469,
        '^', 436,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 574,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        't', 616,
        'u', 546,
        'v', 608,
        '{', 463,
        '|', 433,
        '}', 464,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(163);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 164:
      ADVANCE_MAP(
        '!', 405,
        '"', 525,
        '#', 294,
        '%', 429,
        '&', 439,
        '\'', 516,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 419,
        ',', 344,
        '-', 409,
        '.', 489,
        '/', 427,
        '0', 498,
        ':', 458,
        ';', 459,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        'F', 565,
        'L', 539,
        'R', 542,
        'T', 569,
        'U', 543,
        '[', 465,
        '\\', 119,
        ']', 469,
        '^', 436,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 574,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        't', 616,
        'u', 546,
        'v', 608,
        '{', 463,
        '|', 433,
        '}', 464,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(164);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 165:
      ADVANCE_MAP(
        '!', 405,
        '"', 525,
        '#', 294,
        '%', 428,
        '&', 438,
        '\'', 516,
        '(', 403,
        ')', 345,
        '*', 424,
        '+', 420,
        ',', 344,
        '-', 410,
        '.', 489,
        '/', 426,
        '0', 498,
        ':', 458,
        ';', 459,
        '<', 451,
        '=', 273,
        '>', 443,
        '?', 474,
        'F', 565,
        'L', 539,
        'R', 542,
        'T', 569,
        'U', 543,
        '[', 465,
        '\\', 143,
        ']', 469,
        '^', 435,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 574,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        't', 616,
        'u', 546,
        'v', 608,
        '{', 463,
        '|', 434,
        '}', 464,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(165);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 166:
      ADVANCE_MAP(
        '!', 405,
        '"', 525,
        '%', 429,
        '&', 439,
        '\'', 516,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 419,
        ',', 344,
        '-', 408,
        '.', 489,
        '/', 427,
        '0', 498,
        ':', 271,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        'F', 565,
        'L', 539,
        'R', 542,
        'T', 569,
        'U', 543,
        '[', 465,
        '\\', 22,
        '^', 436,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 574,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        't', 616,
        'u', 546,
        'v', 608,
        '{', 463,
        '|', 433,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(166);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 167:
      ADVANCE_MAP(
        '!', 405,
        '"', 525,
        '%', 429,
        '&', 439,
        '\'', 516,
        '(', 403,
        '*', 425,
        '+', 419,
        ',', 344,
        '-', 409,
        '.', 489,
        '/', 427,
        '0', 498,
        ':', 271,
        '<', 449,
        '=', 471,
        '>', 638,
        '?', 474,
        'F', 565,
        'L', 539,
        'R', 542,
        'T', 569,
        'U', 543,
        '[', 465,
        '\\', 26,
        '^', 436,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 574,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        't', 616,
        'u', 546,
        'v', 608,
        '{', 463,
        '|', 433,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(167);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 168:
      ADVANCE_MAP(
        '!', 405,
        '"', 525,
        '%', 428,
        '&', 438,
        '\'', 516,
        '(', 403,
        '*', 424,
        '+', 420,
        ',', 344,
        '-', 410,
        '.', 489,
        '/', 426,
        '0', 498,
        ':', 271,
        '<', 451,
        '=', 273,
        '>', 638,
        '?', 474,
        'F', 565,
        'L', 539,
        'R', 542,
        'T', 569,
        'U', 543,
        '[', 465,
        '\\', 121,
        '^', 435,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 574,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        't', 616,
        'u', 546,
        'v', 608,
        '{', 463,
        '|', 434,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(168);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 169:
      ADVANCE_MAP(
        '!', 405,
        '"', 237,
        '%', 429,
        '&', 439,
        '(', 253,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 412,
        '/', 427,
        ':', 271,
        '<', 449,
        '=', 471,
        '>', 444,
        '[', 282,
        '\\', 20,
        '^', 436,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 603,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        'u', 596,
        'v', 608,
        '|', 433,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(169);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 170:
      ADVANCE_MAP(
        '!', 405,
        '"', 237,
        '%', 429,
        '&', 439,
        '(', 253,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 412,
        '/', 427,
        '<', 449,
        '=', 471,
        '>', 444,
        '[', 283,
        '\\', 78,
        '^', 436,
        '|', 433,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(170);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 171:
      ADVANCE_MAP(
        '!', 404,
        '"', 525,
        '#', 285,
        '&', 438,
        '\'', 516,
        '(', 403,
        '*', 424,
        '+', 420,
        ',', 344,
        '-', 411,
        '.', 314,
        '/', 255,
        '0', 498,
        ':', 458,
        ';', 459,
        '<', 448,
        '>', 274,
        'F', 565,
        'L', 539,
        'R', 542,
        'T', 569,
        'U', 543,
        '[', 466,
        '\\', 6,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 574,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        't', 616,
        'u', 546,
        'v', 608,
        '{', 463,
        '|', 432,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(171);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 172:
      ADVANCE_MAP(
        '!', 404,
        '"', 525,
        '#', 289,
        '%', 428,
        '&', 438,
        '\'', 516,
        '(', 403,
        ')', 345,
        '*', 424,
        '+', 420,
        ',', 344,
        '-', 411,
        '.', 492,
        '/', 426,
        '0', 498,
        ':', 458,
        ';', 459,
        '<', 448,
        '=', 470,
        '>', 638,
        'F', 565,
        'L', 539,
        'R', 542,
        'T', 569,
        'U', 543,
        '[', 466,
        '\\', 4,
        ']', 284,
        '^', 435,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 574,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        't', 616,
        'u', 546,
        'v', 608,
        '{', 463,
        '|', 308,
        '}', 464,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(172);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 173:
      ADVANCE_MAP(
        '!', 404,
        '"', 525,
        '#', 293,
        '&', 437,
        '\'', 516,
        '(', 403,
        ')', 345,
        '*', 424,
        '+', 420,
        '-', 411,
        '.', 261,
        '/', 255,
        '0', 498,
        ':', 458,
        ';', 459,
        '<', 448,
        '>', 442,
        'F', 565,
        'L', 539,
        'R', 542,
        'T', 569,
        'U', 543,
        '[', 466,
        '\\', 10,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 574,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        't', 616,
        'u', 546,
        'v', 608,
        '{', 463,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(173);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 174:
      ADVANCE_MAP(
        '!', 404,
        '"', 525,
        '#', 287,
        '&', 438,
        '\'', 516,
        '(', 403,
        '*', 424,
        '+', 420,
        ',', 344,
        '-', 411,
        '.', 314,
        '/', 255,
        '0', 498,
        ':', 458,
        ';', 459,
        '<', 448,
        '>', 276,
        'F', 565,
        'L', 539,
        'R', 542,
        'T', 569,
        'U', 543,
        '[', 466,
        '\\', 8,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 574,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        't', 616,
        'u', 546,
        'v', 608,
        '{', 463,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(174);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 175:
      ADVANCE_MAP(
        '!', 404,
        '"', 525,
        '&', 438,
        '\'', 516,
        '(', 403,
        ')', 345,
        '*', 424,
        '+', 420,
        ',', 344,
        '-', 411,
        '.', 491,
        '/', 255,
        '0', 498,
        ':', 271,
        ';', 459,
        '<', 448,
        '=', 470,
        '>', 638,
        'F', 565,
        'L', 539,
        'R', 542,
        'T', 569,
        'U', 543,
        '[', 465,
        '\\', 12,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 574,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        't', 616,
        'u', 546,
        'v', 608,
        '{', 463,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(175);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 176:
      ADVANCE_MAP(
        '!', 404,
        '"', 525,
        '&', 437,
        '\'', 516,
        '(', 403,
        ')', 345,
        '*', 424,
        '+', 420,
        ',', 344,
        '-', 411,
        '.', 491,
        '/', 255,
        '0', 498,
        ':', 458,
        ';', 459,
        '<', 448,
        '=', 470,
        '>', 638,
        'F', 565,
        'L', 539,
        'R', 542,
        'T', 569,
        'U', 543,
        '[', 465,
        '\\', 24,
        ']', 469,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 574,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        't', 616,
        'u', 546,
        'v', 608,
        '{', 463,
        '}', 464,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(176);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 177:
      ADVANCE_MAP(
        '!', 404,
        '"', 525,
        '&', 437,
        '\'', 516,
        '(', 403,
        '*', 424,
        '+', 420,
        '-', 411,
        '.', 314,
        '/', 255,
        '0', 640,
        ':', 271,
        'F', 565,
        'L', 539,
        'R', 542,
        'T', 569,
        'U', 543,
        '[', 465,
        '\\', 38,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 574,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        't', 616,
        'u', 546,
        'v', 608,
        '{', 463,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(177);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 178:
      ADVANCE_MAP(
        '!', 404,
        '\'', 516,
        '(', 403,
        ')', 345,
        '+', 422,
        '-', 415,
        '.', 314,
        '/', 255,
        '0', 498,
        'L', 557,
        'U', 558,
        '\\', 101,
        'u', 559,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(178);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 179:
      ADVANCE_MAP(
        '!', 272,
        '"', 525,
        '#', 294,
        '%', 429,
        '&', 439,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 413,
        '.', 488,
        '/', 427,
        ':', 458,
        ';', 459,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        'L', 540,
        'R', 542,
        'U', 544,
        '[', 465,
        '\\', 46,
        ']', 469,
        '^', 436,
        'u', 547,
        '{', 463,
        '|', 433,
        '}', 464,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(179);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 180:
      ADVANCE_MAP(
        '!', 272,
        '"', 525,
        '#', 294,
        '%', 429,
        '&', 439,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 413,
        '.', 488,
        '/', 427,
        ':', 457,
        ';', 459,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        'L', 540,
        'R', 542,
        'U', 544,
        '[', 465,
        '\\', 123,
        ']', 469,
        '^', 436,
        'u', 547,
        '{', 463,
        '|', 433,
        '}', 464,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(180);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 181:
      ADVANCE_MAP(
        '!', 272,
        '"', 525,
        '#', 294,
        '%', 429,
        '&', 439,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 413,
        '.', 488,
        '/', 427,
        ':', 457,
        ';', 459,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        'L', 650,
        'R', 651,
        'U', 652,
        '[', 465,
        '\\', 123,
        ']', 469,
        '^', 436,
        'u', 653,
        '{', 463,
        '|', 433,
        '}', 464,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(180);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(659);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 182:
      ADVANCE_MAP(
        '!', 272,
        '"', 525,
        '#', 294,
        '%', 428,
        '&', 438,
        '(', 403,
        ')', 345,
        '*', 424,
        '+', 418,
        ',', 344,
        '-', 414,
        '.', 488,
        '/', 426,
        ':', 457,
        ';', 459,
        '<', 451,
        '=', 273,
        '>', 443,
        '?', 474,
        'L', 540,
        'R', 542,
        'U', 544,
        '[', 465,
        '\\', 76,
        ']', 469,
        '^', 435,
        'u', 547,
        '|', 434,
        '}', 464,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(182);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 183:
      ADVANCE_MAP(
        '!', 272,
        '"', 525,
        '#', 294,
        '%', 428,
        '&', 438,
        '(', 403,
        ')', 345,
        '*', 424,
        '+', 418,
        ',', 344,
        '-', 414,
        '.', 488,
        '/', 426,
        ':', 457,
        ';', 459,
        '<', 451,
        '=', 273,
        '>', 443,
        '?', 474,
        'L', 650,
        'R', 651,
        'U', 652,
        '[', 465,
        '\\', 76,
        ']', 469,
        '^', 435,
        'u', 653,
        '|', 434,
        '}', 464,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(182);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(659);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 184:
      ADVANCE_MAP(
        '!', 272,
        '"', 525,
        '%', 429,
        '&', 439,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 412,
        '.', 488,
        '/', 427,
        ':', 458,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        'L', 540,
        'R', 542,
        'U', 544,
        '[', 466,
        '\\', 30,
        '^', 436,
        'u', 547,
        '{', 463,
        '|', 433,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(184);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 185:
      ADVANCE_MAP(
        '!', 272,
        '"', 525,
        '%', 429,
        '&', 439,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 412,
        '.', 488,
        '/', 427,
        ':', 271,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        'L', 540,
        'R', 542,
        'U', 544,
        '[', 465,
        '\\', 40,
        '^', 436,
        'u', 547,
        '{', 463,
        '|', 433,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(185);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 186:
      ADVANCE_MAP(
        '!', 272,
        '"', 525,
        '%', 429,
        '&', 439,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 412,
        '.', 488,
        '/', 427,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        'L', 540,
        'R', 542,
        'U', 544,
        '[', 465,
        '\\', 64,
        '^', 436,
        'u', 547,
        '|', 433,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(186);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 187:
      ADVANCE_MAP(
        '!', 272,
        '"', 525,
        '%', 429,
        '&', 439,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 412,
        '.', 488,
        '/', 427,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        'L', 650,
        'R', 651,
        'U', 652,
        '[', 465,
        '\\', 64,
        '^', 436,
        'u', 653,
        '|', 433,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(186);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(659);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 188:
      ADVANCE_MAP(
        '!', 272,
        '"', 525,
        '%', 429,
        '&', 439,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 413,
        '.', 488,
        '/', 427,
        ':', 458,
        ';', 459,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        'L', 540,
        'R', 542,
        'U', 544,
        '[', 466,
        '\\', 28,
        '^', 436,
        'u', 547,
        '{', 463,
        '|', 433,
        '}', 464,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(188);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 189:
      ADVANCE_MAP(
        '!', 272,
        '"', 525,
        '%', 429,
        '&', 439,
        '(', 403,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 413,
        '.', 488,
        '/', 427,
        ':', 271,
        '<', 449,
        '=', 471,
        '>', 638,
        '?', 474,
        'L', 540,
        'R', 542,
        'U', 544,
        '[', 465,
        '\\', 42,
        '^', 436,
        'u', 547,
        '{', 463,
        '|', 433,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(189);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 190:
      ADVANCE_MAP(
        '!', 272,
        '"', 525,
        '%', 429,
        '&', 439,
        '(', 403,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 413,
        '.', 488,
        '/', 427,
        ':', 457,
        '<', 449,
        '=', 471,
        '>', 638,
        '?', 474,
        'L', 540,
        'R', 542,
        'U', 544,
        '[', 465,
        '\\', 66,
        '^', 436,
        'u', 547,
        '|', 433,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(190);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 191:
      ADVANCE_MAP(
        '!', 272,
        '"', 525,
        '%', 429,
        '&', 439,
        '(', 403,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 413,
        '.', 488,
        '/', 427,
        ':', 457,
        '<', 449,
        '=', 471,
        '>', 638,
        '?', 474,
        'L', 650,
        'R', 651,
        'U', 652,
        '[', 465,
        '\\', 66,
        '^', 436,
        'u', 653,
        '|', 433,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(190);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(659);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 192:
      ADVANCE_MAP(
        '!', 272,
        '"', 525,
        '%', 428,
        '&', 438,
        '(', 403,
        '*', 424,
        '+', 418,
        ',', 344,
        '-', 414,
        '.', 488,
        '/', 426,
        '<', 451,
        '=', 273,
        '>', 638,
        '?', 474,
        'L', 540,
        'R', 542,
        'U', 544,
        '[', 465,
        '\\', 86,
        '^', 435,
        'u', 547,
        '|', 434,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(192);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 193:
      ADVANCE_MAP(
        '!', 272,
        '"', 525,
        '%', 428,
        '&', 438,
        '(', 403,
        '*', 424,
        '+', 418,
        ',', 344,
        '-', 414,
        '.', 488,
        '/', 426,
        '<', 451,
        '=', 273,
        '>', 638,
        '?', 474,
        'L', 650,
        'R', 651,
        'U', 652,
        '[', 465,
        '\\', 86,
        '^', 435,
        'u', 653,
        '|', 434,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(192);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(659);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 194:
      ADVANCE_MAP(
        '!', 272,
        '#', 305,
        '%', 429,
        '&', 439,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 412,
        '.', 488,
        '/', 427,
        ':', 458,
        ';', 459,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        '[', 466,
        '\\', 34,
        '^', 436,
        '{', 463,
        '|', 433,
        '}', 464,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(194);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 195:
      ADVANCE_MAP(
        '!', 272,
        '#', 290,
        '%', 428,
        '&', 438,
        '(', 403,
        ')', 345,
        '*', 424,
        '+', 417,
        ',', 344,
        '-', 407,
        '/', 426,
        ':', 271,
        ';', 459,
        '<', 452,
        '=', 273,
        '>', 443,
        '[', 466,
        '\\', 16,
        '^', 435,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 603,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        'u', 596,
        'v', 608,
        '|', 434,
        '}', 464,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(195);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 196:
      ADVANCE_MAP(
        '!', 272,
        '#', 294,
        '%', 429,
        '&', 439,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 413,
        '.', 488,
        '/', 427,
        '0', 639,
        ':', 458,
        ';', 459,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        '[', 466,
        '\\', 32,
        '^', 436,
        '{', 463,
        '|', 433,
        '}', 464,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(196);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 197:
      ADVANCE_MAP(
        '!', 272,
        '#', 294,
        '%', 429,
        '&', 439,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 413,
        '.', 488,
        '/', 427,
        ':', 458,
        ';', 459,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        '[', 465,
        '\\', 48,
        ']', 469,
        '^', 436,
        '{', 463,
        '|', 433,
        '}', 464,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(197);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 198:
      ADVANCE_MAP(
        '!', 272,
        '#', 294,
        '%', 429,
        '&', 439,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 413,
        '.', 488,
        '/', 427,
        ':', 457,
        ';', 459,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        '[', 466,
        '\\', 155,
        ']', 469,
        '^', 436,
        '{', 463,
        '|', 433,
        '}', 464,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(198);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 199:
      ADVANCE_MAP(
        '!', 272,
        '#', 294,
        '%', 429,
        '&', 439,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 413,
        '.', 488,
        '/', 427,
        ':', 457,
        ';', 459,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        '[', 465,
        '\\', 129,
        ']', 469,
        '^', 436,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 603,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        'u', 596,
        'v', 608,
        '{', 463,
        '|', 433,
        '}', 464,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(199);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 200:
      ADVANCE_MAP(
        '!', 272,
        '#', 294,
        '%', 429,
        '&', 439,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 413,
        '.', 488,
        '/', 427,
        ':', 457,
        ';', 459,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        '[', 465,
        '\\', 125,
        ']', 469,
        '^', 436,
        '{', 463,
        '|', 433,
        '}', 464,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(200);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 201:
      ADVANCE_MAP(
        '!', 272,
        '#', 294,
        '%', 429,
        '&', 439,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 413,
        '.', 488,
        '/', 427,
        ':', 457,
        ';', 459,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        '[', 465,
        '\\', 135,
        ']', 469,
        '^', 436,
        '|', 433,
        '}', 464,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(202);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(659);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 202:
      ADVANCE_MAP(
        '!', 272,
        '#', 294,
        '%', 429,
        '&', 439,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 413,
        '.', 488,
        '/', 427,
        ':', 457,
        ';', 459,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        '[', 465,
        '\\', 135,
        ']', 469,
        '^', 436,
        '|', 433,
        '}', 464,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(202);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 203:
      ADVANCE_MAP(
        '!', 272,
        '#', 294,
        '%', 429,
        '&', 439,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 413,
        '.', 488,
        '/', 427,
        ':', 457,
        ';', 459,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        '[', 468,
        '\\', 72,
        ']', 469,
        '^', 436,
        '|', 433,
        '}', 464,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(203);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 204:
      ADVANCE_MAP(
        '!', 272,
        '#', 294,
        '%', 428,
        '&', 438,
        '(', 403,
        ')', 345,
        '*', 424,
        '+', 418,
        ',', 344,
        '-', 414,
        '.', 488,
        '/', 426,
        ':', 458,
        ';', 459,
        '<', 451,
        '=', 273,
        '>', 443,
        '?', 474,
        '[', 465,
        '\\', 161,
        ']', 469,
        '^', 435,
        '{', 463,
        '|', 434,
        '}', 464,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(204);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 205:
      ADVANCE_MAP(
        '!', 272,
        '#', 294,
        '%', 428,
        '&', 438,
        '(', 403,
        ')', 345,
        '*', 424,
        '+', 418,
        ',', 344,
        '-', 414,
        '.', 488,
        '/', 426,
        ':', 457,
        ';', 459,
        '<', 451,
        '=', 273,
        '>', 443,
        '?', 474,
        '[', 465,
        '\\', 56,
        ']', 469,
        '^', 435,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 603,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        'u', 596,
        'v', 608,
        '{', 463,
        '|', 434,
        '}', 464,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(205);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 206:
      ADVANCE_MAP(
        '!', 272,
        '#', 294,
        '%', 428,
        '&', 438,
        '(', 403,
        ')', 345,
        '*', 424,
        '+', 418,
        ',', 344,
        '-', 414,
        '.', 488,
        '/', 426,
        ':', 457,
        ';', 459,
        '<', 451,
        '=', 273,
        '>', 443,
        '?', 474,
        '[', 465,
        '\\', 145,
        ']', 469,
        '^', 435,
        '{', 463,
        '|', 434,
        '}', 464,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(206);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 207:
      ADVANCE_MAP(
        '!', 272,
        '#', 294,
        '%', 428,
        '&', 438,
        '(', 403,
        ')', 345,
        '*', 424,
        '+', 418,
        ',', 344,
        '-', 414,
        '.', 488,
        '/', 426,
        ':', 457,
        ';', 459,
        '<', 451,
        '=', 273,
        '>', 443,
        '?', 474,
        '[', 465,
        '\\', 149,
        ']', 469,
        '^', 435,
        '|', 434,
        '}', 464,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(208);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(659);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 208:
      ADVANCE_MAP(
        '!', 272,
        '#', 294,
        '%', 428,
        '&', 438,
        '(', 403,
        ')', 345,
        '*', 424,
        '+', 418,
        ',', 344,
        '-', 414,
        '.', 488,
        '/', 426,
        ':', 457,
        ';', 459,
        '<', 451,
        '=', 273,
        '>', 443,
        '?', 474,
        '[', 465,
        '\\', 149,
        ']', 469,
        '^', 435,
        '|', 434,
        '}', 464,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(208);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 209:
      ADVANCE_MAP(
        '!', 272,
        '%', 429,
        '&', 439,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 412,
        '.', 488,
        '/', 427,
        ':', 458,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        '[', 465,
        '\\', 52,
        '^', 436,
        '{', 463,
        '|', 433,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(209);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 210:
      ADVANCE_MAP(
        '!', 272,
        '%', 429,
        '&', 439,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 412,
        '.', 488,
        '/', 427,
        ':', 457,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        '[', 465,
        '\\', 127,
        '^', 436,
        '{', 463,
        '|', 433,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(210);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 211:
      ADVANCE_MAP(
        '!', 272,
        '%', 429,
        '&', 439,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 412,
        '.', 488,
        '/', 427,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        '[', 467,
        '\\', 84,
        '^', 436,
        '|', 433,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(211);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 212:
      ADVANCE_MAP(
        '!', 272,
        '%', 429,
        '&', 439,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 412,
        '.', 488,
        '/', 427,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        '[', 465,
        '\\', 70,
        '^', 436,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 603,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        'u', 596,
        'v', 608,
        '{', 463,
        '|', 433,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(212);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 213:
      ADVANCE_MAP(
        '!', 272,
        '%', 429,
        '&', 439,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 412,
        '.', 488,
        '/', 427,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        '[', 465,
        '\\', 139,
        '^', 436,
        '|', 433,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(214);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(659);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 214:
      ADVANCE_MAP(
        '!', 272,
        '%', 429,
        '&', 439,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 412,
        '.', 488,
        '/', 427,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        '[', 465,
        '\\', 139,
        '^', 436,
        '|', 433,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(214);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 215:
      ADVANCE_MAP(
        '!', 272,
        '%', 429,
        '&', 439,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 412,
        '.', 488,
        '/', 427,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        '[', 468,
        '\\', 153,
        '^', 436,
        '|', 433,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(215);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 216:
      ADVANCE_MAP(
        '!', 272,
        '%', 429,
        '&', 439,
        '(', 403,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 413,
        '.', 488,
        '/', 427,
        ':', 458,
        '<', 449,
        '=', 471,
        '>', 638,
        '?', 474,
        '[', 465,
        '\\', 58,
        '^', 436,
        '{', 463,
        '|', 433,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(216);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 217:
      ADVANCE_MAP(
        '!', 272,
        '%', 429,
        '&', 439,
        '(', 403,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 413,
        '.', 488,
        '/', 427,
        ':', 457,
        '<', 449,
        '=', 471,
        '>', 638,
        '?', 474,
        '[', 465,
        '\\', 147,
        '^', 436,
        '{', 463,
        '|', 433,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(217);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 218:
      ADVANCE_MAP(
        '!', 272,
        '%', 429,
        '&', 439,
        '(', 403,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 413,
        '.', 488,
        '/', 427,
        ';', 459,
        '<', 449,
        '=', 471,
        '>', 444,
        '?', 474,
        '[', 467,
        '\\', 82,
        '^', 436,
        '|', 433,
        '}', 464,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(218);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 219:
      ADVANCE_MAP(
        '!', 272,
        '%', 429,
        '&', 439,
        '(', 403,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 413,
        '.', 488,
        '/', 427,
        '<', 449,
        '=', 471,
        '>', 638,
        '?', 474,
        '[', 466,
        '\\', 80,
        '^', 436,
        '|', 433,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(219);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 220:
      ADVANCE_MAP(
        '!', 272,
        '%', 429,
        '&', 439,
        '(', 403,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 413,
        '.', 488,
        '/', 427,
        '<', 449,
        '=', 471,
        '>', 638,
        '?', 474,
        '[', 465,
        '\\', 74,
        '^', 436,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 603,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        'u', 596,
        'v', 608,
        '{', 463,
        '|', 433,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(220);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 221:
      ADVANCE_MAP(
        '!', 272,
        '%', 429,
        '&', 439,
        '(', 403,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 413,
        '.', 488,
        '/', 427,
        '<', 449,
        '=', 471,
        '>', 638,
        '?', 474,
        '[', 465,
        '\\', 151,
        '^', 436,
        '|', 433,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(222);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(659);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 222:
      ADVANCE_MAP(
        '!', 272,
        '%', 429,
        '&', 439,
        '(', 403,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 413,
        '.', 488,
        '/', 427,
        '<', 449,
        '=', 471,
        '>', 638,
        '?', 474,
        '[', 465,
        '\\', 151,
        '^', 436,
        '|', 433,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(222);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 223:
      ADVANCE_MAP(
        '!', 272,
        '%', 429,
        '&', 439,
        '(', 403,
        '*', 425,
        '+', 421,
        ',', 344,
        '-', 413,
        '.', 488,
        '/', 427,
        '<', 449,
        '=', 471,
        '>', 638,
        '?', 474,
        '[', 468,
        '\\', 137,
        '^', 436,
        '|', 433,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(223);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 224:
      ADVANCE_MAP(
        '!', 272,
        '%', 429,
        '&', 439,
        '*', 425,
        '+', 423,
        ',', 344,
        '-', 416,
        '.', 254,
        '/', 427,
        '<', 450,
        '=', 471,
        '>', 444,
        '\\', 94,
        '^', 436,
        '|', 433,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(224);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 225:
      ADVANCE_MAP(
        '!', 272,
        '%', 428,
        '&', 438,
        '(', 403,
        ')', 345,
        '*', 424,
        '+', 418,
        ',', 344,
        '-', 414,
        '.', 488,
        '/', 426,
        ':', 458,
        ';', 459,
        '<', 451,
        '=', 471,
        '>', 443,
        '?', 474,
        '[', 466,
        '\\', 36,
        '^', 435,
        '{', 463,
        '|', 434,
        '}', 464,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(225);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 226:
      ADVANCE_MAP(
        '!', 272,
        '%', 428,
        '&', 438,
        '(', 403,
        ')', 345,
        '*', 424,
        '+', 418,
        ',', 344,
        '-', 414,
        '.', 488,
        '/', 426,
        ':', 458,
        ';', 459,
        '<', 451,
        '=', 273,
        '>', 443,
        '?', 474,
        '[', 465,
        '\\', 60,
        ']', 469,
        '^', 435,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 603,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        'u', 596,
        'v', 608,
        '{', 463,
        '|', 434,
        '}', 464,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(226);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 227:
      ADVANCE_MAP(
        '!', 272,
        '%', 428,
        '&', 438,
        '(', 403,
        ')', 345,
        '*', 424,
        '+', 418,
        ',', 344,
        '-', 414,
        '.', 488,
        '/', 426,
        ':', 271,
        ';', 459,
        '<', 451,
        '=', 273,
        '>', 443,
        '?', 474,
        '[', 465,
        '\\', 133,
        ']', 284,
        '^', 435,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 603,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        'u', 596,
        'v', 608,
        '{', 463,
        '|', 434,
        '}', 464,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(227);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 228:
      ADVANCE_MAP(
        '!', 272,
        '%', 428,
        '&', 438,
        '(', 403,
        '*', 424,
        '+', 418,
        ',', 344,
        '-', 414,
        '.', 488,
        '/', 426,
        ':', 458,
        '<', 451,
        '=', 273,
        '>', 638,
        '?', 474,
        '[', 465,
        '\\', 157,
        '^', 435,
        '{', 463,
        '|', 434,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(228);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 229:
      ADVANCE_MAP(
        '!', 272,
        '%', 428,
        '&', 438,
        '(', 403,
        '*', 424,
        '+', 418,
        ',', 344,
        '-', 414,
        '.', 488,
        '/', 426,
        ':', 457,
        '<', 451,
        '=', 273,
        '>', 638,
        '?', 474,
        '[', 465,
        '\\', 68,
        '^', 435,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 603,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        'u', 596,
        'v', 608,
        '{', 463,
        '|', 434,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(229);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 230:
      ADVANCE_MAP(
        '!', 272,
        '%', 428,
        '&', 438,
        '(', 403,
        '*', 424,
        '+', 418,
        ',', 344,
        '-', 414,
        '.', 488,
        '/', 426,
        ':', 457,
        '<', 451,
        '=', 273,
        '>', 638,
        '?', 474,
        '[', 465,
        '\\', 131,
        '^', 435,
        '{', 463,
        '|', 434,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(230);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 231:
      ADVANCE_MAP(
        '!', 272,
        '%', 428,
        '&', 438,
        '(', 403,
        '*', 424,
        '+', 418,
        ',', 344,
        '-', 414,
        '.', 488,
        '/', 426,
        '<', 451,
        '=', 273,
        '>', 638,
        '?', 474,
        '[', 465,
        '\\', 159,
        '^', 435,
        '|', 434,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(232);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(659);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 232:
      ADVANCE_MAP(
        '!', 272,
        '%', 428,
        '&', 438,
        '(', 403,
        '*', 424,
        '+', 418,
        ',', 344,
        '-', 414,
        '.', 488,
        '/', 426,
        '<', 451,
        '=', 273,
        '>', 638,
        '?', 474,
        '[', 465,
        '\\', 159,
        '^', 435,
        '|', 434,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(232);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 233:
      ADVANCE_MAP(
        '"', 525,
        '&', 438,
        '(', 403,
        '*', 424,
        '/', 255,
        ':', 271,
        'L', 541,
        'U', 545,
        '[', 466,
        '\\', 50,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 603,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        'u', 548,
        'v', 608,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(233);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 234:
      ADVANCE_MAP(
        '"', 525,
        ')', 345,
        ',', 344,
        '/', 255,
        ':', 457,
        'L', 540,
        'R', 542,
        'U', 544,
        '\\', 103,
        'u', 547,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(234);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 235:
      if (lookahead == '"') ADVANCE(525);
      if (lookahead == '/') ADVANCE(255);
      if (lookahead == '<') ADVANCE(278);
      if (lookahead == 'L') ADVANCE(541);
      if (lookahead == 'U') ADVANCE(545);
      if (lookahead == '\\') ADVANCE(107);
      if (lookahead == 'u') ADVANCE(549);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(235);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 236:
      if (lookahead == '"') ADVANCE(525);
      if (lookahead == '/') ADVANCE(255);
      if (lookahead == '\\') ADVANCE(109);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(236);
      END_STATE();
    case 237:
      if (lookahead == '"') ADVANCE(649);
      END_STATE();
    case 238:
      ADVANCE_MAP(
        '#', 294,
        '&', 438,
        '(', 403,
        ')', 345,
        '*', 424,
        ',', 344,
        '-', 277,
        '.', 260,
        '/', 255,
        ':', 458,
        ';', 459,
        '<', 448,
        '=', 470,
        '>', 638,
        '[', 466,
        '\\', 44,
        '{', 463,
        '|', 308,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(238);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 239:
      ADVANCE_MAP(
        '#', 286,
        '&', 438,
        '(', 403,
        ')', 345,
        '*', 424,
        '+', 417,
        ',', 344,
        '-', 277,
        '.', 490,
        '/', 255,
        ':', 458,
        ';', 459,
        '<', 448,
        '=', 470,
        '>', 638,
        '[', 466,
        '\\', 14,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 603,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        'u', 596,
        'v', 608,
        '{', 463,
        '|', 308,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(239);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 240:
      ADVANCE_MAP(
        '#', 288,
        '&', 438,
        '(', 403,
        '*', 424,
        ',', 344,
        '/', 255,
        ':', 271,
        ';', 459,
        '[', 466,
        '\\', 18,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 603,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        'u', 596,
        'v', 608,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(240);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 241:
      ADVANCE_MAP(
        '&', 438,
        '(', 403,
        ')', 345,
        '*', 424,
        ',', 344,
        '-', 277,
        '.', 260,
        '/', 255,
        ':', 458,
        ';', 459,
        '<', 448,
        '=', 470,
        '>', 638,
        '[', 465,
        '\\', 62,
        '{', 463,
        '|', 308,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(241);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 242:
      ADVANCE_MAP(
        '&', 438,
        '(', 403,
        ')', 345,
        '*', 424,
        ',', 344,
        '-', 277,
        '.', 260,
        '/', 255,
        ':', 457,
        ';', 459,
        '<', 448,
        '=', 470,
        '>', 638,
        '[', 466,
        '\\', 54,
        '{', 463,
        '|', 308,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(242);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 243:
      ADVANCE_MAP(
        '&', 438,
        '(', 403,
        ')', 345,
        '*', 424,
        ',', 344,
        '-', 277,
        '.', 260,
        '/', 255,
        ':', 457,
        ';', 459,
        '=', 470,
        '>', 638,
        '[', 465,
        '\\', 90,
        '{', 463,
        '|', 308,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(243);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 244:
      ADVANCE_MAP(
        '&', 438,
        '(', 403,
        ')', 345,
        '*', 424,
        ',', 344,
        '/', 255,
        ':', 458,
        ';', 459,
        '<', 448,
        '[', 465,
        '\\', 92,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 603,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        'u', 596,
        'v', 608,
        '{', 463,
        '|', 308,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(244);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 245:
      ADVANCE_MAP(
        '&', 438,
        '(', 403,
        ')', 345,
        '*', 424,
        ',', 344,
        '/', 255,
        ':', 457,
        ';', 459,
        '=', 470,
        '>', 638,
        '[', 466,
        '\\', 88,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 603,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        'u', 596,
        'v', 608,
        '{', 463,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(245);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 246:
      ADVANCE_MAP(
        '&', 438,
        '(', 403,
        ')', 345,
        '*', 424,
        ',', 344,
        '/', 255,
        ':', 457,
        ';', 459,
        '=', 470,
        '>', 638,
        '[', 465,
        '\\', 141,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 603,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        'u', 596,
        'v', 608,
        '{', 463,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(246);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 247:
      if (lookahead == '\'') ADVANCE(516);
      if (lookahead == '/') ADVANCE(255);
      if (lookahead == '\\') ADVANCE(109);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(247);
      END_STATE();
    case 248:
      if (lookahead == '\'') ADVANCE(319);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(309);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(248);
      END_STATE();
    case 249:
      if (lookahead == '\'') ADVANCE(315);
      if (lookahead == '.') ADVANCE(505);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(309);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(249);
      END_STATE();
    case 250:
      ADVANCE_MAP(
        '(', 403,
        ')', 345,
        ',', 344,
        '/', 255,
        ':', 457,
        ';', 459,
        '<', 448,
        '=', 470,
        '>', 638,
        '[', 467,
        '\\', 105,
        '{', 463,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(250);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 251:
      ADVANCE_MAP(
        '(', 403,
        '/', 255,
        ':', 271,
        'F', 565,
        'T', 569,
        '[', 465,
        '\\', 96,
        'f', 575,
        't', 616,
        '{', 463,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(251);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 252:
      if (lookahead == '(') ADVANCE(403);
      if (lookahead == '/') ADVANCE(255);
      if (lookahead == '\\') SKIP(117);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(252);
      END_STATE();
    case 253:
      if (lookahead == ')') ADVANCE(647);
      END_STATE();
    case 254:
      if (lookahead == '*') ADVANCE(493);
      END_STATE();
    case 255:
      if (lookahead == '*') ADVANCE(258);
      if (lookahead == '/') ADVANCE(636);
      END_STATE();
    case 256:
      if (lookahead == '*') ADVANCE(646);
      END_STATE();
    case 257:
      if (lookahead == '*') ADVANCE(257);
      if (lookahead == '/') ADVANCE(629);
      if (lookahead != 0) ADVANCE(258);
      END_STATE();
    case 258:
      if (lookahead == '*') ADVANCE(257);
      if (lookahead != 0) ADVANCE(258);
      END_STATE();
    case 259:
      if (lookahead == '*') ADVANCE(257);
      if (lookahead != 0) ADVANCE(361);
      END_STATE();
    case 260:
      if (lookahead == '.') ADVANCE(262);
      END_STATE();
    case 261:
      if (lookahead == '.') ADVANCE(262);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(497);
      END_STATE();
    case 262:
      if (lookahead == '.') ADVANCE(343);
      END_STATE();
    case 263:
      if (lookahead == '.') ADVANCE(319);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(503);
      END_STATE();
    case 264:
      if (lookahead == '/') ADVANCE(368);
      if (lookahead == '\\') ADVANCE(363);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(264);
      if (lookahead != 0) ADVANCE(370);
      END_STATE();
    case 265:
      if (lookahead == '1') ADVANCE(269);
      END_STATE();
    case 266:
      if (lookahead == '2') ADVANCE(496);
      END_STATE();
    case 267:
      if (lookahead == '2') ADVANCE(270);
      if (lookahead == '6') ADVANCE(496);
      END_STATE();
    case 268:
      if (lookahead == '4') ADVANCE(496);
      END_STATE();
    case 269:
      if (lookahead == '6') ADVANCE(496);
      END_STATE();
    case 270:
      if (lookahead == '8') ADVANCE(496);
      END_STATE();
    case 271:
      if (lookahead == ':') ADVANCE(460);
      END_STATE();
    case 272:
      if (lookahead == '=') ADVANCE(441);
      END_STATE();
    case 273:
      if (lookahead == '=') ADVANCE(440);
      END_STATE();
    case 274:
      if (lookahead == '=') ADVANCE(445);
      if (lookahead == '>') ADVANCE(275);
      END_STATE();
    case 275:
      if (lookahead == '=') ADVANCE(481);
      END_STATE();
    case 276:
      if (lookahead == '>') ADVANCE(455);
      END_STATE();
    case 277:
      if (lookahead == '>') ADVANCE(494);
      END_STATE();
    case 278:
      if (lookahead == '>') ADVANCE(535);
      if (lookahead == '\\') ADVANCE(279);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(278);
      END_STATE();
    case 279:
      if (lookahead == '>') ADVANCE(536);
      if (lookahead == '\\') ADVANCE(279);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(278);
      END_STATE();
    case 280:
      if (lookahead == 'F') ADVANCE(265);
      END_STATE();
    case 281:
      if (lookahead == 'U') ADVANCE(333);
      if (lookahead == 'u') ADVANCE(325);
      END_STATE();
    case 282:
      if (lookahead == '[') ADVANCE(461);
      if (lookahead == ']') ADVANCE(648);
      END_STATE();
    case 283:
      if (lookahead == ']') ADVANCE(648);
      END_STATE();
    case 284:
      if (lookahead == ']') ADVANCE(462);
      END_STATE();
    case 285:
      if (lookahead == 'd') ADVANCE(377);
      if (lookahead == 'e') ADVANCE(397);
      if (lookahead == 'i') ADVANCE(385);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(285);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 286:
      if (lookahead == 'd') ADVANCE(377);
      if (lookahead == 'e') ADVANCE(397);
      if (lookahead == 'i') ADVANCE(386);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(286);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 287:
      if (lookahead == 'd') ADVANCE(377);
      if (lookahead == 'e') ADVANCE(399);
      if (lookahead == 'i') ADVANCE(385);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(287);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 288:
      if (lookahead == 'd') ADVANCE(377);
      if (lookahead == 'e') ADVANCE(399);
      if (lookahead == 'i') ADVANCE(386);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(288);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 289:
      if (lookahead == 'd') ADVANCE(377);
      if (lookahead == 'i') ADVANCE(385);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(289);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 290:
      if (lookahead == 'd') ADVANCE(377);
      if (lookahead == 'i') ADVANCE(386);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(290);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 291:
      if (lookahead == 'd') ADVANCE(303);
      END_STATE();
    case 292:
      if (lookahead == 'd') ADVANCE(297);
      END_STATE();
    case 293:
      if (lookahead == 'e') ADVANCE(307);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(293);
      END_STATE();
    case 294:
      if (lookahead == 'e') ADVANCE(306);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(294);
      END_STATE();
    case 295:
      if (lookahead == 'e') ADVANCE(352);
      END_STATE();
    case 296:
      if (lookahead == 'e') ADVANCE(301);
      END_STATE();
    case 297:
      if (lookahead == 'e') ADVANCE(302);
      END_STATE();
    case 298:
      if (lookahead == 'f') ADVANCE(265);
      END_STATE();
    case 299:
      if (lookahead == 'f') ADVANCE(348);
      END_STATE();
    case 300:
      if (lookahead == 'f') ADVANCE(354);
      END_STATE();
    case 301:
      if (lookahead == 'f') ADVANCE(356);
      END_STATE();
    case 302:
      if (lookahead == 'f') ADVANCE(358);
      END_STATE();
    case 303:
      if (lookahead == 'i') ADVANCE(299);
      END_STATE();
    case 304:
      if (lookahead == 'i') ADVANCE(300);
      if (lookahead == 's') ADVANCE(295);
      END_STATE();
    case 305:
      if (lookahead == 'i') ADVANCE(386);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(305);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 306:
      if (lookahead == 'l') ADVANCE(304);
      if (lookahead == 'n') ADVANCE(291);
      END_STATE();
    case 307:
      if (lookahead == 'n') ADVANCE(291);
      END_STATE();
    case 308:
      if (lookahead == '|') ADVANCE(430);
      END_STATE();
    case 309:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(316);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(502);
      END_STATE();
    case 310:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(309);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(248);
      END_STATE();
    case 311:
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(500);
      END_STATE();
    case 312:
      if (lookahead == '8' ||
          lookahead == '9') ADVANCE(249);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(499);
      END_STATE();
    case 313:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(501);
      END_STATE();
    case 314:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(497);
      END_STATE();
    case 315:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(249);
      END_STATE();
    case 316:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(502);
      END_STATE();
    case 317:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(628);
      END_STATE();
    case 318:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(503);
      END_STATE();
    case 319:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(248);
      END_STATE();
    case 320:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(531);
      END_STATE();
    case 321:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(317);
      END_STATE();
    case 322:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(320);
      END_STATE();
    case 323:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(321);
      END_STATE();
    case 324:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(322);
      END_STATE();
    case 325:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(323);
      END_STATE();
    case 326:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(324);
      END_STATE();
    case 327:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(325);
      END_STATE();
    case 328:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(326);
      END_STATE();
    case 329:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(327);
      END_STATE();
    case 330:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(328);
      END_STATE();
    case 331:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(329);
      END_STATE();
    case 332:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(330);
      END_STATE();
    case 333:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(331);
      END_STATE();
    case 334:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(332);
      END_STATE();
    case 335:
      if (lookahead != 0 &&
          lookahead != '*') ADVANCE(370);
      END_STATE();
    case 336:
      if (eof) ADVANCE(338);
      ADVANCE_MAP(
        '!', 405,
        '"', 525,
        '#', 285,
        '%', 429,
        '&', 439,
        '\'', 516,
        '(', 403,
        ')', 345,
        '*', 425,
        '+', 419,
        ',', 344,
        '-', 408,
        '.', 489,
        '/', 427,
        '0', 640,
        ':', 458,
        ';', 459,
        '<', 449,
        '=', 471,
        '>', 638,
        '?', 474,
        'F', 565,
        'L', 539,
        'R', 542,
        'T', 569,
        'U', 543,
        '[', 467,
        '\\', 2,
        ']', 469,
        '^', 436,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 574,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        't', 616,
        'u', 546,
        'v', 608,
        '{', 463,
        '|', 433,
        '}', 464,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(336);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 337:
      if (eof) ADVANCE(338);
      ADVANCE_MAP(
        '!', 404,
        '"', 525,
        '#', 289,
        '%', 428,
        '&', 438,
        '\'', 516,
        '(', 403,
        ')', 345,
        '*', 424,
        '+', 420,
        ',', 344,
        '-', 411,
        '.', 492,
        '/', 426,
        '0', 498,
        ':', 458,
        ';', 459,
        '<', 448,
        '=', 470,
        '>', 638,
        'F', 565,
        'L', 539,
        'R', 542,
        'T', 569,
        'U', 543,
        '[', 466,
        '\\', 4,
        ']', 284,
        '^', 435,
        'b', 611,
        'c', 590,
        'd', 607,
        'f', 574,
        'i', 604,
        'm', 576,
        'n', 624,
        'p', 621,
        's', 591,
        't', 616,
        'u', 546,
        'v', 608,
        '{', 463,
        '|', 308,
        '}', 464,
        '~', 406,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(337);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      if (set_contains(sym_identifier_character_set_1, 658, lookahead)) ADVANCE(628);
      END_STATE();
    case 338:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 339:
      ACCEPT_TOKEN(aux_sym_preproc_include_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 340:
      ACCEPT_TOKEN(aux_sym_preproc_include_token2);
      END_STATE();
    case 341:
      ACCEPT_TOKEN(aux_sym_preproc_def_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 342:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 343:
      ACCEPT_TOKEN(anon_sym_DOT_DOT_DOT);
      END_STATE();
    case 344:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 345:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 346:
      ACCEPT_TOKEN(aux_sym_preproc_if_token1);
      if (lookahead == 'd') ADVANCE(381);
      if (lookahead == 'n') ADVANCE(375);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 347:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(347);
      END_STATE();
    case 348:
      ACCEPT_TOKEN(aux_sym_preproc_if_token2);
      END_STATE();
    case 349:
      ACCEPT_TOKEN(aux_sym_preproc_if_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 350:
      ACCEPT_TOKEN(aux_sym_preproc_ifdef_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 351:
      ACCEPT_TOKEN(aux_sym_preproc_ifdef_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 352:
      ACCEPT_TOKEN(aux_sym_preproc_else_token1);
      END_STATE();
    case 353:
      ACCEPT_TOKEN(aux_sym_preproc_else_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 354:
      ACCEPT_TOKEN(aux_sym_preproc_elif_token1);
      if (lookahead == 'd') ADVANCE(296);
      if (lookahead == 'n') ADVANCE(292);
      END_STATE();
    case 355:
      ACCEPT_TOKEN(aux_sym_preproc_elif_token1);
      if (lookahead == 'd') ADVANCE(383);
      if (lookahead == 'n') ADVANCE(376);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 356:
      ACCEPT_TOKEN(aux_sym_preproc_elifdef_token1);
      END_STATE();
    case 357:
      ACCEPT_TOKEN(aux_sym_preproc_elifdef_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 358:
      ACCEPT_TOKEN(aux_sym_preproc_elifdef_token2);
      END_STATE();
    case 359:
      ACCEPT_TOKEN(aux_sym_preproc_elifdef_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 360:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\n') ADVANCE(258);
      if (lookahead == '*') ADVANCE(360);
      if (lookahead == '/') ADVANCE(629);
      if (lookahead == '\\') ADVANCE(366);
      if (lookahead != 0) ADVANCE(361);
      END_STATE();
    case 361:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\n') ADVANCE(258);
      if (lookahead == '*') ADVANCE(360);
      if (lookahead == '/') ADVANCE(259);
      if (lookahead == '\\') ADVANCE(366);
      if (lookahead != 0) ADVANCE(361);
      END_STATE();
    case 362:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\n') ADVANCE(636);
      if (lookahead == '\r') ADVANCE(630);
      if (lookahead == '/') ADVANCE(633);
      if (lookahead == '\\') ADVANCE(632);
      if (lookahead != 0) ADVANCE(634);
      END_STATE();
    case 363:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\n') SKIP(264);
      if (lookahead == '\r') ADVANCE(364);
      if (lookahead == '/') ADVANCE(335);
      if (lookahead == '\\') ADVANCE(365);
      if (lookahead != 0) ADVANCE(370);
      END_STATE();
    case 364:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\n') SKIP(264);
      if (lookahead == '/') ADVANCE(335);
      if (lookahead == '\\') ADVANCE(365);
      if (lookahead != 0) ADVANCE(370);
      END_STATE();
    case 365:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\r') ADVANCE(371);
      if (lookahead == '/') ADVANCE(335);
      if (lookahead == '\\') ADVANCE(365);
      if (lookahead != 0) ADVANCE(370);
      END_STATE();
    case 366:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\r') ADVANCE(369);
      if (lookahead == '*') ADVANCE(360);
      if (lookahead == '/') ADVANCE(259);
      if (lookahead == '\\') ADVANCE(366);
      if (lookahead != 0) ADVANCE(361);
      END_STATE();
    case 367:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\r') ADVANCE(635);
      if (lookahead == '/') ADVANCE(633);
      if (lookahead == '\\') ADVANCE(632);
      if (lookahead != 0) ADVANCE(634);
      END_STATE();
    case 368:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '*') ADVANCE(361);
      if (lookahead == '/') ADVANCE(633);
      if (lookahead == '\\') ADVANCE(365);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(370);
      END_STATE();
    case 369:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '*') ADVANCE(360);
      if (lookahead == '/') ADVANCE(259);
      if (lookahead == '\\') ADVANCE(366);
      if (lookahead != 0) ADVANCE(361);
      END_STATE();
    case 370:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(335);
      if (lookahead == '\\') ADVANCE(365);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(370);
      END_STATE();
    case 371:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(335);
      if (lookahead == '\\') ADVANCE(365);
      if (lookahead != 0) ADVANCE(370);
      END_STATE();
    case 372:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'c') ADVANCE(398);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 373:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'd') ADVANCE(396);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 374:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'd') ADVANCE(380);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 375:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'd') ADVANCE(382);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 376:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'd') ADVANCE(384);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 377:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(387);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 378:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(353);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 379:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(341);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 380:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(339);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 381:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(390);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 382:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(391);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 383:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(392);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 384:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'e') ADVANCE(393);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 385:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(346);
      if (lookahead == 'n') ADVANCE(372);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 386:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(346);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 387:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(394);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 388:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(355);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 389:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(349);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 390:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(350);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 391:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(351);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 392:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(357);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 393:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'f') ADVANCE(359);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 394:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'i') ADVANCE(400);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 395:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'i') ADVANCE(388);
      if (lookahead == 's') ADVANCE(378);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 396:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'i') ADVANCE(389);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 397:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'l') ADVANCE(395);
      if (lookahead == 'n') ADVANCE(373);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 398:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'l') ADVANCE(401);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 399:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'n') ADVANCE(373);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 400:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'n') ADVANCE(379);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 401:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (lookahead == 'u') ADVANCE(374);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 402:
      ACCEPT_TOKEN(sym_preproc_directive);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(402);
      END_STATE();
    case 403:
      ACCEPT_TOKEN(anon_sym_LPAREN2);
      END_STATE();
    case 404:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 405:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(441);
      END_STATE();
    case 406:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 407:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 408:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(486);
      if (lookahead == '.') ADVANCE(314);
      if (lookahead == '0') ADVANCE(498);
      if (lookahead == '=') ADVANCE(479);
      if (lookahead == '>') ADVANCE(495);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      END_STATE();
    case 409:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(486);
      if (lookahead == '.') ADVANCE(314);
      if (lookahead == '0') ADVANCE(498);
      if (lookahead == '=') ADVANCE(479);
      if (lookahead == '>') ADVANCE(494);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      END_STATE();
    case 410:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(486);
      if (lookahead == '.') ADVANCE(314);
      if (lookahead == '0') ADVANCE(498);
      if (lookahead == '>') ADVANCE(494);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      END_STATE();
    case 411:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(486);
      if (lookahead == '.') ADVANCE(314);
      if (lookahead == '0') ADVANCE(498);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      END_STATE();
    case 412:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(486);
      if (lookahead == '=') ADVANCE(479);
      if (lookahead == '>') ADVANCE(495);
      END_STATE();
    case 413:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(486);
      if (lookahead == '=') ADVANCE(479);
      if (lookahead == '>') ADVANCE(494);
      END_STATE();
    case 414:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(486);
      if (lookahead == '>') ADVANCE(494);
      END_STATE();
    case 415:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '.') ADVANCE(314);
      if (lookahead == '0') ADVANCE(498);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      END_STATE();
    case 416:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '=') ADVANCE(479);
      if (lookahead == '>') ADVANCE(256);
      END_STATE();
    case 417:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 418:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(487);
      END_STATE();
    case 419:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(487);
      if (lookahead == '.') ADVANCE(314);
      if (lookahead == '0') ADVANCE(498);
      if (lookahead == '=') ADVANCE(478);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      END_STATE();
    case 420:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(487);
      if (lookahead == '.') ADVANCE(314);
      if (lookahead == '0') ADVANCE(498);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      END_STATE();
    case 421:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(487);
      if (lookahead == '=') ADVANCE(478);
      END_STATE();
    case 422:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '.') ADVANCE(314);
      if (lookahead == '0') ADVANCE(498);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(501);
      END_STATE();
    case 423:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '=') ADVANCE(478);
      END_STATE();
    case 424:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 425:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '=') ADVANCE(475);
      END_STATE();
    case 426:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(258);
      if (lookahead == '/') ADVANCE(636);
      END_STATE();
    case 427:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(258);
      if (lookahead == '/') ADVANCE(636);
      if (lookahead == '=') ADVANCE(476);
      END_STATE();
    case 428:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 429:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '=') ADVANCE(477);
      END_STATE();
    case 430:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 431:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 432:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 433:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '=') ADVANCE(484);
      if (lookahead == '|') ADVANCE(430);
      END_STATE();
    case 434:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(430);
      END_STATE();
    case 435:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 436:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '=') ADVANCE(483);
      END_STATE();
    case 437:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 438:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(431);
      END_STATE();
    case 439:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(431);
      if (lookahead == '=') ADVANCE(482);
      END_STATE();
    case 440:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 441:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 442:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 443:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(445);
      if (lookahead == '>') ADVANCE(455);
      END_STATE();
    case 444:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(445);
      if (lookahead == '>') ADVANCE(456);
      END_STATE();
    case 445:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 446:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 447:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      if (lookahead == '>') ADVANCE(485);
      END_STATE();
    case 448:
      ACCEPT_TOKEN(anon_sym_LT);
      END_STATE();
    case 449:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(454);
      if (lookahead == '=') ADVANCE(447);
      END_STATE();
    case 450:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(454);
      if (lookahead == '=') ADVANCE(446);
      END_STATE();
    case 451:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(453);
      if (lookahead == '=') ADVANCE(447);
      END_STATE();
    case 452:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(453);
      if (lookahead == '=') ADVANCE(446);
      END_STATE();
    case 453:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      END_STATE();
    case 454:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      if (lookahead == '=') ADVANCE(480);
      END_STATE();
    case 455:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      END_STATE();
    case 456:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '=') ADVANCE(481);
      END_STATE();
    case 457:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 458:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(460);
      END_STATE();
    case 459:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 460:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      END_STATE();
    case 461:
      ACCEPT_TOKEN(anon_sym_LBRACK_LBRACK);
      END_STATE();
    case 462:
      ACCEPT_TOKEN(anon_sym_RBRACK_RBRACK);
      END_STATE();
    case 463:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 464:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 465:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 466:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '[') ADVANCE(461);
      END_STATE();
    case 467:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == '[') ADVANCE(461);
      if (lookahead == ']') ADVANCE(648);
      END_STATE();
    case 468:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == ']') ADVANCE(648);
      END_STATE();
    case 469:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 470:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 471:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(440);
      END_STATE();
    case 472:
      ACCEPT_TOKEN(sym_primitive_type);
      if (lookahead == '1') ADVANCE(564);
      if (lookahead == '3') ADVANCE(562);
      if (lookahead == '6') ADVANCE(563);
      if (lookahead == '8') ADVANCE(573);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'p') ADVANCE(622);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 473:
      ACCEPT_TOKEN(sym_primitive_type);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 474:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 475:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      END_STATE();
    case 476:
      ACCEPT_TOKEN(anon_sym_SLASH_EQ);
      END_STATE();
    case 477:
      ACCEPT_TOKEN(anon_sym_PERCENT_EQ);
      END_STATE();
    case 478:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 479:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 480:
      ACCEPT_TOKEN(anon_sym_LT_LT_EQ);
      END_STATE();
    case 481:
      ACCEPT_TOKEN(anon_sym_GT_GT_EQ);
      END_STATE();
    case 482:
      ACCEPT_TOKEN(anon_sym_AMP_EQ);
      END_STATE();
    case 483:
      ACCEPT_TOKEN(anon_sym_CARET_EQ);
      END_STATE();
    case 484:
      ACCEPT_TOKEN(anon_sym_PIPE_EQ);
      END_STATE();
    case 485:
      ACCEPT_TOKEN(anon_sym_LT_EQ_GT);
      END_STATE();
    case 486:
      ACCEPT_TOKEN(anon_sym_DASH_DASH);
      END_STATE();
    case 487:
      ACCEPT_TOKEN(anon_sym_PLUS_PLUS);
      END_STATE();
    case 488:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '*') ADVANCE(493);
      if (lookahead == '.') ADVANCE(262);
      END_STATE();
    case 489:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '*') ADVANCE(493);
      if (lookahead == '.') ADVANCE(262);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(497);
      END_STATE();
    case 490:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(262);
      END_STATE();
    case 491:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(262);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(497);
      END_STATE();
    case 492:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(497);
      END_STATE();
    case 493:
      ACCEPT_TOKEN(anon_sym_DOT_STAR);
      END_STATE();
    case 494:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      END_STATE();
    case 495:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      if (lookahead == '*') ADVANCE(646);
      END_STATE();
    case 496:
      ACCEPT_TOKEN(sym_number_literal);
      END_STATE();
    case 497:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        '\'', 314,
        'B', 280,
        'b', 298,
        'E', 309,
        'e', 309,
        'F', 504,
        'f', 504,
        'L', 496,
        'l', 496,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(497);
      END_STATE();
    case 498:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        '\'', 312,
        '.', 505,
        'L', 506,
        'l', 509,
        'B', 311,
        'b', 311,
        'E', 309,
        'e', 309,
        'U', 508,
        'u', 508,
        'X', 263,
        'x', 263,
        'Z', 511,
        'z', 511,
        '8', 249,
        '9', 249,
      );
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(499);
      END_STATE();
    case 499:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        '\'', 312,
        '.', 505,
        'L', 506,
        'l', 509,
        'E', 309,
        'e', 309,
        'U', 508,
        'u', 508,
        'Z', 511,
        'z', 511,
        '8', 249,
        '9', 249,
      );
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(499);
      END_STATE();
    case 500:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        '\'', 311,
        'L', 506,
        'l', 509,
        'U', 508,
        'u', 508,
        'Z', 511,
        'z', 511,
        '0', 500,
        '1', 500,
      );
      END_STATE();
    case 501:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        '\'', 313,
        '.', 505,
        'L', 506,
        'l', 509,
        'E', 309,
        'e', 309,
        'U', 508,
        'u', 508,
        'Z', 511,
        'z', 511,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(501);
      END_STATE();
    case 502:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == '\'') ADVANCE(316);
      if (lookahead == 'B') ADVANCE(280);
      if (lookahead == 'b') ADVANCE(298);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(504);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(496);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(502);
      END_STATE();
    case 503:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        '\'', 318,
        '.', 310,
        'L', 506,
        'l', 509,
        'P', 309,
        'p', 309,
        'U', 508,
        'u', 508,
        'Z', 511,
        'z', 511,
      );
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(503);
      END_STATE();
    case 504:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == '1') ADVANCE(267);
      if (lookahead == '3') ADVANCE(266);
      if (lookahead == '6') ADVANCE(268);
      END_STATE();
    case 505:
      ACCEPT_TOKEN(sym_number_literal);
      ADVANCE_MAP(
        'B', 280,
        'b', 298,
        'E', 309,
        'e', 309,
        'F', 504,
        'f', 504,
        'L', 496,
        'l', 496,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(497);
      END_STATE();
    case 506:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == 'L') ADVANCE(511);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(496);
      END_STATE();
    case 507:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == 'L') ADVANCE(496);
      END_STATE();
    case 508:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == 'L') ADVANCE(507);
      if (lookahead == 'l') ADVANCE(510);
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(496);
      END_STATE();
    case 509:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == 'l') ADVANCE(511);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(496);
      END_STATE();
    case 510:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == 'l') ADVANCE(496);
      END_STATE();
    case 511:
      ACCEPT_TOKEN(sym_number_literal);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(496);
      END_STATE();
    case 512:
      ACCEPT_TOKEN(anon_sym_L_SQUOTE);
      END_STATE();
    case 513:
      ACCEPT_TOKEN(anon_sym_u_SQUOTE);
      END_STATE();
    case 514:
      ACCEPT_TOKEN(anon_sym_U_SQUOTE);
      END_STATE();
    case 515:
      ACCEPT_TOKEN(anon_sym_u8_SQUOTE);
      END_STATE();
    case 516:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 517:
      ACCEPT_TOKEN(aux_sym_char_literal_token1);
      END_STATE();
    case 518:
      ACCEPT_TOKEN(aux_sym_char_literal_token1);
      if (lookahead == '\n') ADVANCE(532);
      if (lookahead == '\r') ADVANCE(531);
      if (lookahead == 'U') ADVANCE(334);
      if (lookahead == 'u') ADVANCE(326);
      if (lookahead == 'x') ADVANCE(322);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(534);
      if (lookahead != 0) ADVANCE(531);
      END_STATE();
    case 519:
      ACCEPT_TOKEN(aux_sym_char_literal_token1);
      if (lookahead == '*') ADVANCE(258);
      if (lookahead == '/') ADVANCE(636);
      END_STATE();
    case 520:
      ACCEPT_TOKEN(aux_sym_char_literal_token1);
      if (lookahead == '\\') ADVANCE(109);
      END_STATE();
    case 521:
      ACCEPT_TOKEN(anon_sym_L_DQUOTE);
      END_STATE();
    case 522:
      ACCEPT_TOKEN(anon_sym_u_DQUOTE);
      END_STATE();
    case 523:
      ACCEPT_TOKEN(anon_sym_U_DQUOTE);
      END_STATE();
    case 524:
      ACCEPT_TOKEN(anon_sym_u8_DQUOTE);
      END_STATE();
    case 525:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 526:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead == '*') ADVANCE(528);
      if (lookahead == '/') ADVANCE(530);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(530);
      END_STATE();
    case 527:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead == '*') ADVANCE(527);
      if (lookahead == '/') ADVANCE(530);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(528);
      END_STATE();
    case 528:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead == '*') ADVANCE(527);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(528);
      END_STATE();
    case 529:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead == '/') ADVANCE(526);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(529);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(530);
      END_STATE();
    case 530:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(530);
      END_STATE();
    case 531:
      ACCEPT_TOKEN(sym_escape_sequence);
      END_STATE();
    case 532:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (lookahead == '\\') ADVANCE(109);
      END_STATE();
    case 533:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(531);
      END_STATE();
    case 534:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(533);
      END_STATE();
    case 535:
      ACCEPT_TOKEN(sym_system_lib_string);
      END_STATE();
    case 536:
      ACCEPT_TOKEN(sym_system_lib_string);
      if (lookahead == '>') ADVANCE(535);
      if (lookahead == '\\') ADVANCE(279);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(278);
      END_STATE();
    case 537:
      ACCEPT_TOKEN(sym_true);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 538:
      ACCEPT_TOKEN(sym_false);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 539:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(521);
      if (lookahead == '\'') ADVANCE(512);
      if (lookahead == 'R') ADVANCE(550);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 540:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(521);
      if (lookahead == 'R') ADVANCE(550);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 541:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(521);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 542:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(641);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 543:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(523);
      if (lookahead == '\'') ADVANCE(514);
      if (lookahead == 'R') ADVANCE(551);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 544:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(523);
      if (lookahead == 'R') ADVANCE(551);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 545:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(523);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 546:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(522);
      if (lookahead == '\'') ADVANCE(513);
      if (lookahead == '8') ADVANCE(552);
      if (lookahead == 'R') ADVANCE(555);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'i') ADVANCE(606);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 547:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(522);
      if (lookahead == '8') ADVANCE(553);
      if (lookahead == 'R') ADVANCE(555);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 548:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(522);
      if (lookahead == '8') ADVANCE(554);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'i') ADVANCE(606);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 549:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(522);
      if (lookahead == '8') ADVANCE(554);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 550:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(642);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 551:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(644);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 552:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(524);
      if (lookahead == '\'') ADVANCE(515);
      if (lookahead == 'R') ADVANCE(556);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 553:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(524);
      if (lookahead == 'R') ADVANCE(556);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 554:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(524);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 555:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(643);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 556:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(645);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 557:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\'') ADVANCE(512);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 558:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\'') ADVANCE(514);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 559:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\'') ADVANCE(513);
      if (lookahead == '8') ADVANCE(560);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 560:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\'') ADVANCE(515);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 561:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '1') ADVANCE(564);
      if (lookahead == '3') ADVANCE(562);
      if (lookahead == '6') ADVANCE(563);
      if (lookahead == '8') ADVANCE(573);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'p') ADVANCE(622);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 562:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '2') ADVANCE(573);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 563:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '4') ADVANCE(573);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 564:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '6') ADVANCE(573);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 565:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'A') ADVANCE(568);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 566:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'E') ADVANCE(537);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 567:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'E') ADVANCE(538);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 568:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'L') ADVANCE(570);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 569:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'R') ADVANCE(571);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 570:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'S') ADVANCE(567);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 571:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'U') ADVANCE(566);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 572:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == '_') ADVANCE(579);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 573:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == '_') ADVANCE(619);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 574:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'a') ADVANCE(597);
      if (lookahead == 'l') ADVANCE(609);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 575:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'a') ADVANCE(597);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 576:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'a') ADVANCE(626);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 577:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'a') ADVANCE(613);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 578:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'a') ADVANCE(619);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 579:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'a') ADVANCE(601);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 580:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'b') ADVANCE(602);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 581:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'd') ADVANCE(473);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 582:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'd') ADVANCE(593);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 583:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'e') ADVANCE(537);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 584:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'e') ADVANCE(473);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 585:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'e') ADVANCE(538);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 586:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'e') ADVANCE(573);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 587:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'f') ADVANCE(573);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 588:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'f') ADVANCE(587);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 589:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'g') ADVANCE(605);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 590:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'h') ADVANCE(577);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 591:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'i') ADVANCE(627);
      if (lookahead == 's') ADVANCE(592);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 592:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'i') ADVANCE(627);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 593:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'i') ADVANCE(588);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 594:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'i') ADVANCE(589);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 595:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'i') ADVANCE(581);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 596:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'i') ADVANCE(606);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 597:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'l') ADVANCE(617);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 598:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'l') ADVANCE(473);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 599:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'l') ADVANCE(612);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 600:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'l') ADVANCE(599);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 601:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'l') ADVANCE(594);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 602:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'l') ADVANCE(584);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 603:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'l') ADVANCE(609);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 604:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'n') ADVANCE(618);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 605:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'n') ADVANCE(573);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 606:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'n') ADVANCE(620);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 607:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'o') ADVANCE(623);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 608:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'o') ADVANCE(595);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 609:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'o') ADVANCE(578);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 610:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'o') ADVANCE(598);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 611:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'o') ADVANCE(610);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 612:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'p') ADVANCE(622);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 613:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'r') ADVANCE(472);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 614:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'r') ADVANCE(582);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 615:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'r') ADVANCE(573);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 616:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'r') ADVANCE(625);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 617:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 's') ADVANCE(585);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 618:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 't') ADVANCE(472);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 619:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 't') ADVANCE(473);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 620:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 't') ADVANCE(561);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 621:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 't') ADVANCE(614);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 622:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 't') ADVANCE(615);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 623:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'u') ADVANCE(580);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 624:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'u') ADVANCE(600);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 625:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'u') ADVANCE(583);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 626:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'x') ADVANCE(572);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 627:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (lookahead == 'z') ADVANCE(586);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 628:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\\') ADVANCE(281);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 629:
      ACCEPT_TOKEN(sym_comment);
      END_STATE();
    case 630:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\n') ADVANCE(636);
      if (lookahead == '/') ADVANCE(633);
      if (lookahead == '\\') ADVANCE(367);
      if (lookahead != 0) ADVANCE(634);
      END_STATE();
    case 631:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\r') ADVANCE(637);
      if (lookahead == '\\') ADVANCE(631);
      if (lookahead != 0) ADVANCE(636);
      END_STATE();
    case 632:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\r') ADVANCE(635);
      if (lookahead == '/') ADVANCE(633);
      if (lookahead == '\\') ADVANCE(632);
      if (lookahead != 0) ADVANCE(634);
      END_STATE();
    case 633:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '*') ADVANCE(636);
      if (lookahead == '\\') ADVANCE(362);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(634);
      END_STATE();
    case 634:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '/') ADVANCE(633);
      if (lookahead == '\\') ADVANCE(367);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(634);
      END_STATE();
    case 635:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '/') ADVANCE(633);
      if (lookahead == '\\') ADVANCE(367);
      if (lookahead != 0) ADVANCE(634);
      END_STATE();
    case 636:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\\') ADVANCE(162);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(636);
      END_STATE();
    case 637:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\\') ADVANCE(162);
      if (lookahead != 0) ADVANCE(636);
      END_STATE();
    case 638:
      ACCEPT_TOKEN(anon_sym_GT2);
      END_STATE();
    case 639:
      ACCEPT_TOKEN(anon_sym_0);
      END_STATE();
    case 640:
      ACCEPT_TOKEN(anon_sym_0);
      ADVANCE_MAP(
        '\'', 312,
        '.', 505,
        'L', 506,
        'l', 509,
        'B', 311,
        'b', 311,
        'E', 309,
        'e', 309,
        'U', 508,
        'u', 508,
        'X', 263,
        'x', 263,
        'Z', 511,
        'z', 511,
        '8', 249,
        '9', 249,
      );
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(499);
      END_STATE();
    case 641:
      ACCEPT_TOKEN(anon_sym_R_DQUOTE);
      END_STATE();
    case 642:
      ACCEPT_TOKEN(anon_sym_LR_DQUOTE);
      END_STATE();
    case 643:
      ACCEPT_TOKEN(anon_sym_uR_DQUOTE);
      END_STATE();
    case 644:
      ACCEPT_TOKEN(anon_sym_UR_DQUOTE);
      END_STATE();
    case 645:
      ACCEPT_TOKEN(anon_sym_u8R_DQUOTE);
      END_STATE();
    case 646:
      ACCEPT_TOKEN(anon_sym_DASH_GT_STAR);
      END_STATE();
    case 647:
      ACCEPT_TOKEN(anon_sym_LPAREN_RPAREN);
      END_STATE();
    case 648:
      ACCEPT_TOKEN(anon_sym_LBRACK_RBRACK);
      END_STATE();
    case 649:
      ACCEPT_TOKEN(anon_sym_DQUOTE_DQUOTE);
      END_STATE();
    case 650:
      ACCEPT_TOKEN(sym_literal_suffix);
      if (lookahead == '"') ADVANCE(521);
      if (lookahead == 'R') ADVANCE(654);
      if (lookahead == '\\') ADVANCE(281);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(659);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 651:
      ACCEPT_TOKEN(sym_literal_suffix);
      if (lookahead == '"') ADVANCE(641);
      if (lookahead == '\\') ADVANCE(281);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(659);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 652:
      ACCEPT_TOKEN(sym_literal_suffix);
      if (lookahead == '"') ADVANCE(523);
      if (lookahead == 'R') ADVANCE(655);
      if (lookahead == '\\') ADVANCE(281);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(659);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 653:
      ACCEPT_TOKEN(sym_literal_suffix);
      if (lookahead == '"') ADVANCE(522);
      if (lookahead == '8') ADVANCE(656);
      if (lookahead == 'R') ADVANCE(657);
      if (lookahead == '\\') ADVANCE(281);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(659);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 654:
      ACCEPT_TOKEN(sym_literal_suffix);
      if (lookahead == '"') ADVANCE(642);
      if (lookahead == '\\') ADVANCE(281);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(659);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 655:
      ACCEPT_TOKEN(sym_literal_suffix);
      if (lookahead == '"') ADVANCE(644);
      if (lookahead == '\\') ADVANCE(281);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(659);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 656:
      ACCEPT_TOKEN(sym_literal_suffix);
      if (lookahead == '"') ADVANCE(524);
      if (lookahead == 'R') ADVANCE(658);
      if (lookahead == '\\') ADVANCE(281);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(659);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 657:
      ACCEPT_TOKEN(sym_literal_suffix);
      if (lookahead == '"') ADVANCE(643);
      if (lookahead == '\\') ADVANCE(281);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(659);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 658:
      ACCEPT_TOKEN(sym_literal_suffix);
      if (lookahead == '"') ADVANCE(645);
      if (lookahead == '\\') ADVANCE(281);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(659);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    case 659:
      ACCEPT_TOKEN(sym_literal_suffix);
      if (lookahead == '\\') ADVANCE(281);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(659);
      if (set_contains(sym_identifier_character_set_2, 765, lookahead)) ADVANCE(628);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (lookahead == 'N') ADVANCE(1);
      if (lookahead == '\\') SKIP(2);
      if (lookahead == '_') ADVANCE(3);
      if (lookahead == 'a') ADVANCE(4);
      if (lookahead == 'b') ADVANCE(5);
      if (lookahead == 'c') ADVANCE(6);
      if (lookahead == 'd') ADVANCE(7);
      if (lookahead == 'e') ADVANCE(8);
      if (lookahead == 'f') ADVANCE(9);
      if (lookahead == 'g') ADVANCE(10);
      if (lookahead == 'i') ADVANCE(11);
      if (lookahead == 'l') ADVANCE(12);
      if (lookahead == 'm') ADVANCE(13);
      if (lookahead == 'n') ADVANCE(14);
      if (lookahead == 'o') ADVANCE(15);
      if (lookahead == 'p') ADVANCE(16);
      if (lookahead == 'r') ADVANCE(17);
      if (lookahead == 's') ADVANCE(18);
      if (lookahead == 't') ADVANCE(19);
      if (lookahead == 'u') ADVANCE(20);
      if (lookahead == 'v') ADVANCE(21);
      if (lookahead == 'w') ADVANCE(22);
      if (lookahead == 'x') ADVANCE(23);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      END_STATE();
    case 1:
      if (lookahead == 'U') ADVANCE(24);
      END_STATE();
    case 2:
      if (lookahead == '\n') SKIP(0);
      if (lookahead == '\r') SKIP(25);
      END_STATE();
    case 3:
      if (lookahead == 'A') ADVANCE(26);
      if (lookahead == 'G') ADVANCE(27);
      if (lookahead == 'N') ADVANCE(28);
      if (lookahead == '_') ADVANCE(29);
      if (lookahead == 'a') ADVANCE(30);
      if (lookahead == 'u') ADVANCE(31);
      END_STATE();
    case 4:
      if (lookahead == 'l') ADVANCE(32);
      if (lookahead == 'n') ADVANCE(33);
      if (lookahead == 's') ADVANCE(34);
      if (lookahead == 'u') ADVANCE(35);
      END_STATE();
    case 5:
      if (lookahead == 'i') ADVANCE(36);
      if (lookahead == 'r') ADVANCE(37);
      END_STATE();
    case 6:
      if (lookahead == 'a') ADVANCE(38);
      if (lookahead == 'b') ADVANCE(39);
      if (lookahead == 'e') ADVANCE(40);
      if (lookahead == 'l') ADVANCE(41);
      if (lookahead == 'o') ADVANCE(42);
      END_STATE();
    case 7:
      if (lookahead == 'e') ADVANCE(43);
      if (lookahead == 'i') ADVANCE(44);
      if (lookahead == 'o') ADVANCE(45);
      END_STATE();
    case 8:
      if (lookahead == 'l') ADVANCE(46);
      if (lookahead == 'n') ADVANCE(47);
      if (lookahead == 'x') ADVANCE(48);
      END_STATE();
    case 9:
      if (lookahead == 'i') ADVANCE(49);
      if (lookahead == 'o') ADVANCE(50);
      if (lookahead == 'r') ADVANCE(51);
      END_STATE();
    case 10:
      if (lookahead == 'l') ADVANCE(52);
      if (lookahead == 'o') ADVANCE(53);
      if (lookahead == 'r') ADVANCE(54);
      END_STATE();
    case 11:
      if (lookahead == 'f') ADVANCE(55);
      if (lookahead == 'n') ADVANCE(56);
      END_STATE();
    case 12:
      if (lookahead == 'i') ADVANCE(57);
      if (lookahead == 'o') ADVANCE(58);
      END_STATE();
    case 13:
      if (lookahead == 'u') ADVANCE(59);
      END_STATE();
    case 14:
      if (lookahead == 'a') ADVANCE(60);
      if (lookahead == 'e') ADVANCE(61);
      if (lookahead == 'o') ADVANCE(62);
      if (lookahead == 'u') ADVANCE(63);
      END_STATE();
    case 15:
      if (lookahead == 'f') ADVANCE(64);
      if (lookahead == 'p') ADVANCE(65);
      if (lookahead == 'r') ADVANCE(66);
      if (lookahead == 'u') ADVANCE(67);
      if (lookahead == 'v') ADVANCE(68);
      END_STATE();
    case 16:
      if (lookahead == 'o') ADVANCE(69);
      if (lookahead == 'r') ADVANCE(70);
      if (lookahead == 'u') ADVANCE(71);
      END_STATE();
    case 17:
      if (lookahead == 'e') ADVANCE(72);
      if (lookahead == 'o') ADVANCE(73);
      END_STATE();
    case 18:
      if (lookahead == 'a') ADVANCE(74);
      if (lookahead == 'h') ADVANCE(75);
      if (lookahead == 'i') ADVANCE(76);
      if (lookahead == 'n') ADVANCE(77);
      if (lookahead == 't') ADVANCE(78);
      if (lookahead == 'w') ADVANCE(79);
      END_STATE();
    case 19:
      if (lookahead == 'e') ADVANCE(80);
      if (lookahead == 'h') ADVANCE(81);
      if (lookahead == 'r') ADVANCE(82);
      if (lookahead == 'y') ADVANCE(83);
      END_STATE();
    case 20:
      if (lookahead == 'n') ADVANCE(84);
      if (lookahead == 's') ADVANCE(85);
      END_STATE();
    case 21:
      if (lookahead == 'i') ADVANCE(86);
      if (lookahead == 'o') ADVANCE(87);
      END_STATE();
    case 22:
      if (lookahead == 'h') ADVANCE(88);
      END_STATE();
    case 23:
      if (lookahead == 'o') ADVANCE(89);
      END_STATE();
    case 24:
      if (lookahead == 'L') ADVANCE(90);
      END_STATE();
    case 25:
      if (lookahead == '\n') SKIP(0);
      END_STATE();
    case 26:
      if (lookahead == 'l') ADVANCE(91);
      if (lookahead == 't') ADVANCE(92);
      END_STATE();
    case 27:
      if (lookahead == 'e') ADVANCE(93);
      END_STATE();
    case 28:
      if (lookahead == 'o') ADVANCE(94);
      END_STATE();
    case 29:
      ADVANCE_MAP(
        'a', 95,
        'b', 96,
        'c', 97,
        'd', 98,
        'e', 99,
        'f', 100,
        'i', 101,
        'l', 102,
        'r', 103,
        's', 104,
        't', 105,
        'u', 106,
        'v', 107,
      );
      END_STATE();
    case 30:
      if (lookahead == 'l') ADVANCE(108);
      END_STATE();
    case 31:
      if (lookahead == 'n') ADVANCE(109);
      END_STATE();
    case 32:
      if (lookahead == 'i') ADVANCE(110);
      END_STATE();
    case 33:
      if (lookahead == 'd') ADVANCE(111);
      END_STATE();
    case 34:
      if (lookahead == 'm') ADVANCE(112);
      END_STATE();
    case 35:
      if (lookahead == 't') ADVANCE(113);
      END_STATE();
    case 36:
      if (lookahead == 't') ADVANCE(114);
      END_STATE();
    case 37:
      if (lookahead == 'e') ADVANCE(115);
      END_STATE();
    case 38:
      if (lookahead == 's') ADVANCE(116);
      if (lookahead == 't') ADVANCE(117);
      END_STATE();
    case 39:
      if (lookahead == 'u') ADVANCE(118);
      END_STATE();
    case 40:
      if (lookahead == 'n') ADVANCE(119);
      END_STATE();
    case 41:
      if (lookahead == 'a') ADVANCE(120);
      END_STATE();
    case 42:
      if (lookahead == '_') ADVANCE(121);
      if (lookahead == 'l') ADVANCE(122);
      if (lookahead == 'm') ADVANCE(123);
      if (lookahead == 'n') ADVANCE(124);
      END_STATE();
    case 43:
      if (lookahead == 'c') ADVANCE(125);
      if (lookahead == 'f') ADVANCE(126);
      if (lookahead == 'l') ADVANCE(127);
      END_STATE();
    case 44:
      if (lookahead == 's') ADVANCE(128);
      END_STATE();
    case 45:
      ACCEPT_TOKEN(anon_sym_do);
      END_STATE();
    case 46:
      if (lookahead == 's') ADVANCE(129);
      END_STATE();
    case 47:
      if (lookahead == 'u') ADVANCE(130);
      END_STATE();
    case 48:
      if (lookahead == 'p') ADVANCE(131);
      if (lookahead == 't') ADVANCE(132);
      END_STATE();
    case 49:
      if (lookahead == 'n') ADVANCE(133);
      END_STATE();
    case 50:
      if (lookahead == 'r') ADVANCE(134);
      END_STATE();
    case 51:
      if (lookahead == 'i') ADVANCE(135);
      END_STATE();
    case 52:
      if (lookahead == 'o') ADVANCE(136);
      END_STATE();
    case 53:
      if (lookahead == 't') ADVANCE(137);
      END_STATE();
    case 54:
      if (lookahead == 'o') ADVANCE(138);
      END_STATE();
    case 55:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(anon_sym_in);
      if (lookahead == 'l') ADVANCE(139);
      if (lookahead == 'o') ADVANCE(140);
      END_STATE();
    case 57:
      if (lookahead == 'n') ADVANCE(141);
      END_STATE();
    case 58:
      if (lookahead == 'n') ADVANCE(142);
      END_STATE();
    case 59:
      if (lookahead == 't') ADVANCE(143);
      END_STATE();
    case 60:
      if (lookahead == 'm') ADVANCE(144);
      END_STATE();
    case 61:
      if (lookahead == 'w') ADVANCE(145);
      END_STATE();
    case 62:
      if (lookahead == 'e') ADVANCE(146);
      if (lookahead == 'i') ADVANCE(147);
      if (lookahead == 'p') ADVANCE(148);
      if (lookahead == 'r') ADVANCE(149);
      if (lookahead == 't') ADVANCE(150);
      END_STATE();
    case 63:
      if (lookahead == 'l') ADVANCE(151);
      END_STATE();
    case 64:
      if (lookahead == 'f') ADVANCE(152);
      END_STATE();
    case 65:
      if (lookahead == 'e') ADVANCE(153);
      END_STATE();
    case 66:
      ACCEPT_TOKEN(anon_sym_or);
      if (lookahead == '_') ADVANCE(154);
      END_STATE();
    case 67:
      if (lookahead == 't') ADVANCE(155);
      END_STATE();
    case 68:
      if (lookahead == 'e') ADVANCE(156);
      END_STATE();
    case 69:
      if (lookahead == 'i') ADVANCE(157);
      END_STATE();
    case 70:
      if (lookahead == 'e') ADVANCE(158);
      if (lookahead == 'i') ADVANCE(159);
      if (lookahead == 'o') ADVANCE(160);
      END_STATE();
    case 71:
      if (lookahead == 'b') ADVANCE(161);
      END_STATE();
    case 72:
      if (lookahead == 'g') ADVANCE(162);
      if (lookahead == 'q') ADVANCE(163);
      if (lookahead == 's') ADVANCE(164);
      if (lookahead == 't') ADVANCE(165);
      END_STATE();
    case 73:
      if (lookahead == 'w') ADVANCE(166);
      END_STATE();
    case 74:
      if (lookahead == 'm') ADVANCE(167);
      END_STATE();
    case 75:
      if (lookahead == 'a') ADVANCE(168);
      if (lookahead == 'o') ADVANCE(169);
      END_STATE();
    case 76:
      if (lookahead == 'g') ADVANCE(170);
      if (lookahead == 'z') ADVANCE(171);
      END_STATE();
    case 77:
      if (lookahead == 'o') ADVANCE(172);
      END_STATE();
    case 78:
      if (lookahead == 'a') ADVANCE(173);
      if (lookahead == 'r') ADVANCE(174);
      END_STATE();
    case 79:
      if (lookahead == 'i') ADVANCE(175);
      END_STATE();
    case 80:
      if (lookahead == 'm') ADVANCE(176);
      END_STATE();
    case 81:
      if (lookahead == 'i') ADVANCE(177);
      if (lookahead == 'r') ADVANCE(178);
      END_STATE();
    case 82:
      if (lookahead == 'i') ADVANCE(179);
      if (lookahead == 'y') ADVANCE(180);
      END_STATE();
    case 83:
      if (lookahead == 'p') ADVANCE(181);
      END_STATE();
    case 84:
      if (lookahead == 'i') ADVANCE(182);
      if (lookahead == 'o') ADVANCE(183);
      if (lookahead == 's') ADVANCE(184);
      END_STATE();
    case 85:
      if (lookahead == 'i') ADVANCE(185);
      END_STATE();
    case 86:
      if (lookahead == 'r') ADVANCE(186);
      END_STATE();
    case 87:
      if (lookahead == 'l') ADVANCE(187);
      END_STATE();
    case 88:
      if (lookahead == 'i') ADVANCE(188);
      END_STATE();
    case 89:
      if (lookahead == 'r') ADVANCE(189);
      END_STATE();
    case 90:
      if (lookahead == 'L') ADVANCE(190);
      END_STATE();
    case 91:
      if (lookahead == 'i') ADVANCE(191);
      END_STATE();
    case 92:
      if (lookahead == 'o') ADVANCE(192);
      END_STATE();
    case 93:
      if (lookahead == 'n') ADVANCE(193);
      END_STATE();
    case 94:
      if (lookahead == 'r') ADVANCE(194);
      END_STATE();
    case 95:
      if (lookahead == 'l') ADVANCE(195);
      if (lookahead == 's') ADVANCE(196);
      if (lookahead == 't') ADVANCE(197);
      END_STATE();
    case 96:
      if (lookahead == 'a') ADVANCE(198);
      END_STATE();
    case 97:
      if (lookahead == 'd') ADVANCE(199);
      if (lookahead == 'l') ADVANCE(200);
      END_STATE();
    case 98:
      if (lookahead == 'e') ADVANCE(201);
      END_STATE();
    case 99:
      if (lookahead == 'x') ADVANCE(202);
      END_STATE();
    case 100:
      if (lookahead == 'a') ADVANCE(203);
      if (lookahead == 'i') ADVANCE(204);
      if (lookahead == 'o') ADVANCE(205);
      END_STATE();
    case 101:
      if (lookahead == 'n') ADVANCE(206);
      END_STATE();
    case 102:
      if (lookahead == 'e') ADVANCE(207);
      END_STATE();
    case 103:
      if (lookahead == 'e') ADVANCE(208);
      END_STATE();
    case 104:
      if (lookahead == 'p') ADVANCE(209);
      if (lookahead == 't') ADVANCE(210);
      END_STATE();
    case 105:
      if (lookahead == 'h') ADVANCE(211);
      if (lookahead == 'r') ADVANCE(212);
      END_STATE();
    case 106:
      if (lookahead == 'n') ADVANCE(213);
      if (lookahead == 'p') ADVANCE(214);
      END_STATE();
    case 107:
      if (lookahead == 'e') ADVANCE(215);
      END_STATE();
    case 108:
      if (lookahead == 'i') ADVANCE(216);
      END_STATE();
    case 109:
      if (lookahead == 'a') ADVANCE(217);
      END_STATE();
    case 110:
      if (lookahead == 'g') ADVANCE(218);
      END_STATE();
    case 111:
      ACCEPT_TOKEN(anon_sym_and);
      if (lookahead == '_') ADVANCE(219);
      END_STATE();
    case 112:
      ACCEPT_TOKEN(anon_sym_asm);
      END_STATE();
    case 113:
      if (lookahead == 'o') ADVANCE(220);
      END_STATE();
    case 114:
      if (lookahead == 'a') ADVANCE(221);
      if (lookahead == 'o') ADVANCE(222);
      END_STATE();
    case 115:
      if (lookahead == 'a') ADVANCE(223);
      END_STATE();
    case 116:
      if (lookahead == 'e') ADVANCE(224);
      END_STATE();
    case 117:
      if (lookahead == 'c') ADVANCE(225);
      END_STATE();
    case 118:
      if (lookahead == 'f') ADVANCE(226);
      END_STATE();
    case 119:
      if (lookahead == 't') ADVANCE(227);
      END_STATE();
    case 120:
      if (lookahead == 's') ADVANCE(228);
      END_STATE();
    case 121:
      if (lookahead == 'a') ADVANCE(229);
      if (lookahead == 'r') ADVANCE(230);
      if (lookahead == 'y') ADVANCE(231);
      END_STATE();
    case 122:
      if (lookahead == 'u') ADVANCE(232);
      END_STATE();
    case 123:
      if (lookahead == 'p') ADVANCE(233);
      END_STATE();
    case 124:
      if (lookahead == 'c') ADVANCE(234);
      if (lookahead == 's') ADVANCE(235);
      if (lookahead == 't') ADVANCE(236);
      END_STATE();
    case 125:
      if (lookahead == 'l') ADVANCE(237);
      END_STATE();
    case 126:
      if (lookahead == 'a') ADVANCE(238);
      if (lookahead == 'i') ADVANCE(239);
      END_STATE();
    case 127:
      if (lookahead == 'e') ADVANCE(240);
      END_STATE();
    case 128:
      if (lookahead == 'c') ADVANCE(241);
      END_STATE();
    case 129:
      if (lookahead == 'e') ADVANCE(242);
      END_STATE();
    case 130:
      if (lookahead == 'm') ADVANCE(243);
      END_STATE();
    case 131:
      if (lookahead == 'l') ADVANCE(244);
      END_STATE();
    case 132:
      if (lookahead == 'e') ADVANCE(245);
      END_STATE();
    case 133:
      if (lookahead == 'a') ADVANCE(246);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 135:
      if (lookahead == 'e') ADVANCE(247);
      END_STATE();
    case 136:
      if (lookahead == 'b') ADVANCE(248);
      END_STATE();
    case 137:
      if (lookahead == 'o') ADVANCE(249);
      END_STATE();
    case 138:
      if (lookahead == 'u') ADVANCE(250);
      END_STATE();
    case 139:
      if (lookahead == 'i') ADVANCE(251);
      END_STATE();
    case 140:
      if (lookahead == 'u') ADVANCE(252);
      END_STATE();
    case 141:
      if (lookahead == 'e') ADVANCE(253);
      END_STATE();
    case 142:
      if (lookahead == 'g') ADVANCE(254);
      END_STATE();
    case 143:
      if (lookahead == 'a') ADVANCE(255);
      END_STATE();
    case 144:
      if (lookahead == 'e') ADVANCE(256);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(anon_sym_new);
      END_STATE();
    case 146:
      if (lookahead == 'x') ADVANCE(257);
      END_STATE();
    case 147:
      if (lookahead == 'n') ADVANCE(258);
      END_STATE();
    case 148:
      if (lookahead == 'e') ADVANCE(259);
      END_STATE();
    case 149:
      if (lookahead == 'e') ADVANCE(260);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(anon_sym_not);
      if (lookahead == '_') ADVANCE(261);
      END_STATE();
    case 151:
      if (lookahead == 'l') ADVANCE(262);
      END_STATE();
    case 152:
      if (lookahead == 's') ADVANCE(263);
      END_STATE();
    case 153:
      if (lookahead == 'r') ADVANCE(264);
      END_STATE();
    case 154:
      if (lookahead == 'e') ADVANCE(265);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(anon_sym_out);
      END_STATE();
    case 156:
      if (lookahead == 'r') ADVANCE(266);
      END_STATE();
    case 157:
      if (lookahead == 'n') ADVANCE(267);
      END_STATE();
    case 158:
      if (lookahead == 'c') ADVANCE(268);
      END_STATE();
    case 159:
      if (lookahead == 'v') ADVANCE(269);
      END_STATE();
    case 160:
      if (lookahead == 't') ADVANCE(270);
      END_STATE();
    case 161:
      if (lookahead == 'l') ADVANCE(271);
      END_STATE();
    case 162:
      if (lookahead == 'i') ADVANCE(272);
      END_STATE();
    case 163:
      if (lookahead == 'u') ADVANCE(273);
      END_STATE();
    case 164:
      if (lookahead == 't') ADVANCE(274);
      END_STATE();
    case 165:
      if (lookahead == 'u') ADVANCE(275);
      END_STATE();
    case 166:
      if (lookahead == '_') ADVANCE(276);
      END_STATE();
    case 167:
      if (lookahead == 'p') ADVANCE(277);
      END_STATE();
    case 168:
      if (lookahead == 'r') ADVANCE(278);
      END_STATE();
    case 169:
      if (lookahead == 'r') ADVANCE(279);
      END_STATE();
    case 170:
      if (lookahead == 'n') ADVANCE(280);
      END_STATE();
    case 171:
      if (lookahead == 'e') ADVANCE(281);
      END_STATE();
    case 172:
      if (lookahead == 'r') ADVANCE(282);
      END_STATE();
    case 173:
      if (lookahead == 't') ADVANCE(283);
      END_STATE();
    case 174:
      if (lookahead == 'u') ADVANCE(284);
      END_STATE();
    case 175:
      if (lookahead == 't') ADVANCE(285);
      END_STATE();
    case 176:
      if (lookahead == 'p') ADVANCE(286);
      END_STATE();
    case 177:
      if (lookahead == 's') ADVANCE(287);
      END_STATE();
    case 178:
      if (lookahead == 'e') ADVANCE(288);
      if (lookahead == 'o') ADVANCE(289);
      END_STATE();
    case 179:
      if (lookahead == 'a') ADVANCE(290);
      END_STATE();
    case 180:
      ACCEPT_TOKEN(anon_sym_try);
      END_STATE();
    case 181:
      if (lookahead == 'e') ADVANCE(291);
      END_STATE();
    case 182:
      if (lookahead == 'f') ADVANCE(292);
      if (lookahead == 'o') ADVANCE(293);
      END_STATE();
    case 183:
      if (lookahead == 'r') ADVANCE(294);
      END_STATE();
    case 184:
      if (lookahead == 'i') ADVANCE(295);
      END_STATE();
    case 185:
      if (lookahead == 'n') ADVANCE(296);
      END_STATE();
    case 186:
      if (lookahead == 't') ADVANCE(297);
      END_STATE();
    case 187:
      if (lookahead == 'a') ADVANCE(298);
      END_STATE();
    case 188:
      if (lookahead == 'l') ADVANCE(299);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(anon_sym_xor);
      if (lookahead == '_') ADVANCE(300);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(anon_sym_NULL);
      END_STATE();
    case 191:
      if (lookahead == 'g') ADVANCE(301);
      END_STATE();
    case 192:
      if (lookahead == 'm') ADVANCE(302);
      END_STATE();
    case 193:
      if (lookahead == 'e') ADVANCE(303);
      END_STATE();
    case 194:
      if (lookahead == 'e') ADVANCE(304);
      END_STATE();
    case 195:
      if (lookahead == 'i') ADVANCE(305);
      END_STATE();
    case 196:
      if (lookahead == 'm') ADVANCE(306);
      END_STATE();
    case 197:
      if (lookahead == 't') ADVANCE(307);
      END_STATE();
    case 198:
      if (lookahead == 's') ADVANCE(308);
      END_STATE();
    case 199:
      if (lookahead == 'e') ADVANCE(309);
      END_STATE();
    case 200:
      if (lookahead == 'r') ADVANCE(310);
      END_STATE();
    case 201:
      if (lookahead == 'c') ADVANCE(311);
      END_STATE();
    case 202:
      if (lookahead == 'c') ADVANCE(312);
      if (lookahead == 't') ADVANCE(313);
      END_STATE();
    case 203:
      if (lookahead == 's') ADVANCE(314);
      END_STATE();
    case 204:
      if (lookahead == 'n') ADVANCE(315);
      END_STATE();
    case 205:
      if (lookahead == 'r') ADVANCE(316);
      END_STATE();
    case 206:
      if (lookahead == 'l') ADVANCE(317);
      END_STATE();
    case 207:
      if (lookahead == 'a') ADVANCE(318);
      END_STATE();
    case 208:
      if (lookahead == 's') ADVANCE(319);
      END_STATE();
    case 209:
      if (lookahead == 't') ADVANCE(320);
      END_STATE();
    case 210:
      if (lookahead == 'd') ADVANCE(321);
      END_STATE();
    case 211:
      if (lookahead == 'i') ADVANCE(322);
      if (lookahead == 'r') ADVANCE(323);
      END_STATE();
    case 212:
      if (lookahead == 'y') ADVANCE(324);
      END_STATE();
    case 213:
      if (lookahead == 'a') ADVANCE(325);
      END_STATE();
    case 214:
      if (lookahead == 't') ADVANCE(326);
      END_STATE();
    case 215:
      if (lookahead == 'c') ADVANCE(327);
      END_STATE();
    case 216:
      if (lookahead == 'g') ADVANCE(328);
      END_STATE();
    case 217:
      if (lookahead == 'l') ADVANCE(329);
      END_STATE();
    case 218:
      if (lookahead == 'n') ADVANCE(330);
      END_STATE();
    case 219:
      if (lookahead == 'e') ADVANCE(331);
      END_STATE();
    case 220:
      ACCEPT_TOKEN(sym_auto);
      END_STATE();
    case 221:
      if (lookahead == 'n') ADVANCE(332);
      END_STATE();
    case 222:
      if (lookahead == 'r') ADVANCE(333);
      END_STATE();
    case 223:
      if (lookahead == 'k') ADVANCE(334);
      END_STATE();
    case 224:
      ACCEPT_TOKEN(anon_sym_case);
      END_STATE();
    case 225:
      if (lookahead == 'h') ADVANCE(335);
      END_STATE();
    case 226:
      if (lookahead == 'f') ADVANCE(336);
      END_STATE();
    case 227:
      if (lookahead == 'r') ADVANCE(337);
      END_STATE();
    case 228:
      if (lookahead == 's') ADVANCE(338);
      END_STATE();
    case 229:
      if (lookahead == 'w') ADVANCE(339);
      END_STATE();
    case 230:
      if (lookahead == 'e') ADVANCE(340);
      END_STATE();
    case 231:
      if (lookahead == 'i') ADVANCE(341);
      END_STATE();
    case 232:
      if (lookahead == 'm') ADVANCE(342);
      END_STATE();
    case 233:
      if (lookahead == 'l') ADVANCE(343);
      END_STATE();
    case 234:
      if (lookahead == 'e') ADVANCE(344);
      END_STATE();
    case 235:
      if (lookahead == 't') ADVANCE(345);
      END_STATE();
    case 236:
      if (lookahead == 'i') ADVANCE(346);
      END_STATE();
    case 237:
      if (lookahead == 't') ADVANCE(347);
      END_STATE();
    case 238:
      if (lookahead == 'u') ADVANCE(348);
      END_STATE();
    case 239:
      if (lookahead == 'n') ADVANCE(349);
      END_STATE();
    case 240:
      if (lookahead == 't') ADVANCE(350);
      END_STATE();
    case 241:
      if (lookahead == 'a') ADVANCE(351);
      END_STATE();
    case 242:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 243:
      ACCEPT_TOKEN(anon_sym_enum);
      END_STATE();
    case 244:
      if (lookahead == 'i') ADVANCE(352);
      END_STATE();
    case 245:
      if (lookahead == 'r') ADVANCE(353);
      END_STATE();
    case 246:
      if (lookahead == 'l') ADVANCE(354);
      END_STATE();
    case 247:
      if (lookahead == 'n') ADVANCE(355);
      END_STATE();
    case 248:
      if (lookahead == 'a') ADVANCE(356);
      END_STATE();
    case 249:
      ACCEPT_TOKEN(anon_sym_goto);
      END_STATE();
    case 250:
      if (lookahead == 'p') ADVANCE(357);
      END_STATE();
    case 251:
      if (lookahead == 'n') ADVANCE(358);
      END_STATE();
    case 252:
      if (lookahead == 't') ADVANCE(359);
      END_STATE();
    case 253:
      ACCEPT_TOKEN(anon_sym_line);
      if (lookahead == 'a') ADVANCE(360);
      END_STATE();
    case 254:
      ACCEPT_TOKEN(anon_sym_long);
      END_STATE();
    case 255:
      if (lookahead == 'b') ADVANCE(361);
      END_STATE();
    case 256:
      if (lookahead == 's') ADVANCE(362);
      END_STATE();
    case 257:
      if (lookahead == 'c') ADVANCE(363);
      END_STATE();
    case 258:
      if (lookahead == 't') ADVANCE(364);
      END_STATE();
    case 259:
      if (lookahead == 'r') ADVANCE(365);
      END_STATE();
    case 260:
      if (lookahead == 't') ADVANCE(366);
      END_STATE();
    case 261:
      if (lookahead == 'e') ADVANCE(367);
      END_STATE();
    case 262:
      if (lookahead == 'p') ADVANCE(368);
      END_STATE();
    case 263:
      if (lookahead == 'e') ADVANCE(369);
      END_STATE();
    case 264:
      if (lookahead == 'a') ADVANCE(370);
      END_STATE();
    case 265:
      if (lookahead == 'q') ADVANCE(371);
      END_STATE();
    case 266:
      if (lookahead == 'r') ADVANCE(372);
      END_STATE();
    case 267:
      if (lookahead == 't') ADVANCE(373);
      END_STATE();
    case 268:
      if (lookahead == 'i') ADVANCE(374);
      END_STATE();
    case 269:
      if (lookahead == 'a') ADVANCE(375);
      END_STATE();
    case 270:
      if (lookahead == 'e') ADVANCE(376);
      END_STATE();
    case 271:
      if (lookahead == 'i') ADVANCE(377);
      END_STATE();
    case 272:
      if (lookahead == 's') ADVANCE(378);
      END_STATE();
    case 273:
      if (lookahead == 'i') ADVANCE(379);
      END_STATE();
    case 274:
      if (lookahead == 'r') ADVANCE(380);
      END_STATE();
    case 275:
      if (lookahead == 'r') ADVANCE(381);
      END_STATE();
    case 276:
      if (lookahead == 'm') ADVANCE(382);
      END_STATE();
    case 277:
      if (lookahead == 'l') ADVANCE(383);
      END_STATE();
    case 278:
      if (lookahead == 'e') ADVANCE(384);
      END_STATE();
    case 279:
      if (lookahead == 't') ADVANCE(385);
      END_STATE();
    case 280:
      if (lookahead == 'e') ADVANCE(386);
      END_STATE();
    case 281:
      if (lookahead == 'o') ADVANCE(387);
      END_STATE();
    case 282:
      if (lookahead == 'm') ADVANCE(388);
      END_STATE();
    case 283:
      if (lookahead == 'i') ADVANCE(389);
      END_STATE();
    case 284:
      if (lookahead == 'c') ADVANCE(390);
      END_STATE();
    case 285:
      if (lookahead == 'c') ADVANCE(391);
      END_STATE();
    case 286:
      if (lookahead == 'l') ADVANCE(392);
      END_STATE();
    case 287:
      ACCEPT_TOKEN(sym_this);
      END_STATE();
    case 288:
      if (lookahead == 'a') ADVANCE(393);
      END_STATE();
    case 289:
      if (lookahead == 'w') ADVANCE(394);
      END_STATE();
    case 290:
      if (lookahead == 'n') ADVANCE(395);
      END_STATE();
    case 291:
      if (lookahead == 'd') ADVANCE(396);
      if (lookahead == 'n') ADVANCE(397);
      END_STATE();
    case 292:
      if (lookahead == 'o') ADVANCE(398);
      END_STATE();
    case 293:
      if (lookahead == 'n') ADVANCE(399);
      END_STATE();
    case 294:
      if (lookahead == 'm') ADVANCE(400);
      END_STATE();
    case 295:
      if (lookahead == 'g') ADVANCE(401);
      END_STATE();
    case 296:
      if (lookahead == 'g') ADVANCE(402);
      END_STATE();
    case 297:
      if (lookahead == 'u') ADVANCE(403);
      END_STATE();
    case 298:
      if (lookahead == 't') ADVANCE(404);
      END_STATE();
    case 299:
      if (lookahead == 'e') ADVANCE(405);
      END_STATE();
    case 300:
      if (lookahead == 'e') ADVANCE(406);
      END_STATE();
    case 301:
      if (lookahead == 'n') ADVANCE(407);
      END_STATE();
    case 302:
      if (lookahead == 'i') ADVANCE(408);
      END_STATE();
    case 303:
      if (lookahead == 'r') ADVANCE(409);
      END_STATE();
    case 304:
      if (lookahead == 't') ADVANCE(410);
      END_STATE();
    case 305:
      if (lookahead == 'g') ADVANCE(411);
      END_STATE();
    case 306:
      if (lookahead == '_') ADVANCE(412);
      END_STATE();
    case 307:
      if (lookahead == 'r') ADVANCE(413);
      END_STATE();
    case 308:
      if (lookahead == 'e') ADVANCE(414);
      END_STATE();
    case 309:
      if (lookahead == 'c') ADVANCE(415);
      END_STATE();
    case 310:
      if (lookahead == 'c') ADVANCE(416);
      END_STATE();
    case 311:
      if (lookahead == 'l') ADVANCE(417);
      END_STATE();
    case 312:
      if (lookahead == 'e') ADVANCE(418);
      END_STATE();
    case 313:
      if (lookahead == 'e') ADVANCE(419);
      END_STATE();
    case 314:
      if (lookahead == 't') ADVANCE(420);
      END_STATE();
    case 315:
      if (lookahead == 'a') ADVANCE(421);
      END_STATE();
    case 316:
      if (lookahead == 'c') ADVANCE(422);
      END_STATE();
    case 317:
      if (lookahead == 'i') ADVANCE(423);
      END_STATE();
    case 318:
      if (lookahead == 'v') ADVANCE(424);
      END_STATE();
    case 319:
      if (lookahead == 't') ADVANCE(425);
      END_STATE();
    case 320:
      if (lookahead == 'r') ADVANCE(426);
      END_STATE();
    case 321:
      if (lookahead == 'c') ADVANCE(427);
      END_STATE();
    case 322:
      if (lookahead == 's') ADVANCE(428);
      END_STATE();
    case 323:
      if (lookahead == 'e') ADVANCE(429);
      END_STATE();
    case 324:
      ACCEPT_TOKEN(anon_sym___try);
      END_STATE();
    case 325:
      if (lookahead == 'l') ADVANCE(430);
      END_STATE();
    case 326:
      if (lookahead == 'r') ADVANCE(431);
      END_STATE();
    case 327:
      if (lookahead == 't') ADVANCE(432);
      END_STATE();
    case 328:
      if (lookahead == 'n') ADVANCE(433);
      END_STATE();
    case 329:
      if (lookahead == 'i') ADVANCE(434);
      END_STATE();
    case 330:
      if (lookahead == 'a') ADVANCE(435);
      if (lookahead == 'o') ADVANCE(436);
      END_STATE();
    case 331:
      if (lookahead == 'q') ADVANCE(437);
      END_STATE();
    case 332:
      if (lookahead == 'd') ADVANCE(438);
      END_STATE();
    case 333:
      ACCEPT_TOKEN(anon_sym_bitor);
      END_STATE();
    case 334:
      ACCEPT_TOKEN(anon_sym_break);
      END_STATE();
    case 335:
      ACCEPT_TOKEN(anon_sym_catch);
      END_STATE();
    case 336:
      if (lookahead == 'e') ADVANCE(439);
      END_STATE();
    case 337:
      if (lookahead == 'o') ADVANCE(440);
      END_STATE();
    case 338:
      ACCEPT_TOKEN(anon_sym_class);
      END_STATE();
    case 339:
      if (lookahead == 'a') ADVANCE(441);
      END_STATE();
    case 340:
      if (lookahead == 't') ADVANCE(442);
      END_STATE();
    case 341:
      if (lookahead == 'e') ADVANCE(443);
      END_STATE();
    case 342:
      if (lookahead == 'n') ADVANCE(444);
      END_STATE();
    case 343:
      ACCEPT_TOKEN(anon_sym_compl);
      END_STATE();
    case 344:
      if (lookahead == 'p') ADVANCE(445);
      END_STATE();
    case 345:
      ACCEPT_TOKEN(anon_sym_const);
      if (lookahead == 'e') ADVANCE(446);
      if (lookahead == 'i') ADVANCE(447);
      END_STATE();
    case 346:
      if (lookahead == 'n') ADVANCE(448);
      END_STATE();
    case 347:
      if (lookahead == 'y') ADVANCE(449);
      END_STATE();
    case 348:
      if (lookahead == 'l') ADVANCE(450);
      END_STATE();
    case 349:
      if (lookahead == 'e') ADVANCE(451);
      END_STATE();
    case 350:
      if (lookahead == 'e') ADVANCE(452);
      END_STATE();
    case 351:
      if (lookahead == 'r') ADVANCE(453);
      END_STATE();
    case 352:
      if (lookahead == 'c') ADVANCE(454);
      END_STATE();
    case 353:
      if (lookahead == 'n') ADVANCE(455);
      END_STATE();
    case 354:
      ACCEPT_TOKEN(anon_sym_final);
      END_STATE();
    case 355:
      if (lookahead == 'd') ADVANCE(456);
      END_STATE();
    case 356:
      if (lookahead == 'l') ADVANCE(457);
      END_STATE();
    case 357:
      if (lookahead == 's') ADVANCE(458);
      END_STATE();
    case 358:
      if (lookahead == 'e') ADVANCE(459);
      END_STATE();
    case 359:
      ACCEPT_TOKEN(anon_sym_inout);
      END_STATE();
    case 360:
      if (lookahead == 'd') ADVANCE(460);
      if (lookahead == 'r') ADVANCE(461);
      END_STATE();
    case 361:
      if (lookahead == 'l') ADVANCE(462);
      END_STATE();
    case 362:
      if (lookahead == 'p') ADVANCE(463);
      END_STATE();
    case 363:
      if (lookahead == 'e') ADVANCE(464);
      END_STATE();
    case 364:
      if (lookahead == 'e') ADVANCE(465);
      END_STATE();
    case 365:
      if (lookahead == 's') ADVANCE(466);
      END_STATE();
    case 366:
      if (lookahead == 'u') ADVANCE(467);
      END_STATE();
    case 367:
      if (lookahead == 'q') ADVANCE(468);
      END_STATE();
    case 368:
      if (lookahead == 't') ADVANCE(469);
      END_STATE();
    case 369:
      if (lookahead == 't') ADVANCE(470);
      END_STATE();
    case 370:
      if (lookahead == 't') ADVANCE(471);
      END_STATE();
    case 371:
      ACCEPT_TOKEN(anon_sym_or_eq);
      END_STATE();
    case 372:
      if (lookahead == 'i') ADVANCE(472);
      END_STATE();
    case 373:
      ACCEPT_TOKEN(anon_sym_point);
      END_STATE();
    case 374:
      if (lookahead == 's') ADVANCE(473);
      END_STATE();
    case 375:
      if (lookahead == 't') ADVANCE(474);
      END_STATE();
    case 376:
      if (lookahead == 'c') ADVANCE(475);
      END_STATE();
    case 377:
      if (lookahead == 'c') ADVANCE(476);
      END_STATE();
    case 378:
      if (lookahead == 't') ADVANCE(477);
      END_STATE();
    case 379:
      if (lookahead == 'r') ADVANCE(478);
      END_STATE();
    case 380:
      if (lookahead == 'i') ADVANCE(479);
      END_STATE();
    case 381:
      if (lookahead == 'n') ADVANCE(480);
      END_STATE();
    case 382:
      if (lookahead == 'a') ADVANCE(481);
      END_STATE();
    case 383:
      if (lookahead == 'e') ADVANCE(482);
      END_STATE();
    case 384:
      if (lookahead == 'd') ADVANCE(483);
      END_STATE();
    case 385:
      ACCEPT_TOKEN(anon_sym_short);
      END_STATE();
    case 386:
      if (lookahead == 'd') ADVANCE(484);
      END_STATE();
    case 387:
      if (lookahead == 'f') ADVANCE(485);
      END_STATE();
    case 388:
      ACCEPT_TOKEN(anon_sym_snorm);
      END_STATE();
    case 389:
      if (lookahead == 'c') ADVANCE(486);
      END_STATE();
    case 390:
      if (lookahead == 't') ADVANCE(487);
      END_STATE();
    case 391:
      if (lookahead == 'h') ADVANCE(488);
      END_STATE();
    case 392:
      if (lookahead == 'a') ADVANCE(489);
      END_STATE();
    case 393:
      if (lookahead == 'd') ADVANCE(490);
      END_STATE();
    case 394:
      ACCEPT_TOKEN(anon_sym_throw);
      END_STATE();
    case 395:
      if (lookahead == 'g') ADVANCE(491);
      END_STATE();
    case 396:
      if (lookahead == 'e') ADVANCE(492);
      END_STATE();
    case 397:
      if (lookahead == 'a') ADVANCE(493);
      END_STATE();
    case 398:
      if (lookahead == 'r') ADVANCE(494);
      END_STATE();
    case 399:
      ACCEPT_TOKEN(anon_sym_union);
      END_STATE();
    case 400:
      ACCEPT_TOKEN(anon_sym_unorm);
      END_STATE();
    case 401:
      if (lookahead == 'n') ADVANCE(495);
      END_STATE();
    case 402:
      ACCEPT_TOKEN(anon_sym_using);
      END_STATE();
    case 403:
      if (lookahead == 'a') ADVANCE(496);
      END_STATE();
    case 404:
      if (lookahead == 'i') ADVANCE(497);
      END_STATE();
    case 405:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 406:
      if (lookahead == 'q') ADVANCE(498);
      END_STATE();
    case 407:
      if (lookahead == 'a') ADVANCE(499);
      if (lookahead == 'o') ADVANCE(500);
      END_STATE();
    case 408:
      if (lookahead == 'c') ADVANCE(501);
      END_STATE();
    case 409:
      if (lookahead == 'i') ADVANCE(502);
      END_STATE();
    case 410:
      if (lookahead == 'u') ADVANCE(503);
      END_STATE();
    case 411:
      if (lookahead == 'n') ADVANCE(504);
      END_STATE();
    case 412:
      if (lookahead == '_') ADVANCE(505);
      END_STATE();
    case 413:
      if (lookahead == 'i') ADVANCE(506);
      END_STATE();
    case 414:
      if (lookahead == 'd') ADVANCE(507);
      END_STATE();
    case 415:
      if (lookahead == 'l') ADVANCE(508);
      END_STATE();
    case 416:
      if (lookahead == 'a') ADVANCE(509);
      END_STATE();
    case 417:
      if (lookahead == 's') ADVANCE(510);
      END_STATE();
    case 418:
      if (lookahead == 'p') ADVANCE(511);
      END_STATE();
    case 419:
      if (lookahead == 'n') ADVANCE(512);
      END_STATE();
    case 420:
      if (lookahead == 'c') ADVANCE(513);
      END_STATE();
    case 421:
      if (lookahead == 'l') ADVANCE(514);
      END_STATE();
    case 422:
      if (lookahead == 'e') ADVANCE(515);
      END_STATE();
    case 423:
      if (lookahead == 'n') ADVANCE(516);
      END_STATE();
    case 424:
      if (lookahead == 'e') ADVANCE(517);
      END_STATE();
    case 425:
      if (lookahead == 'r') ADVANCE(518);
      END_STATE();
    case 426:
      ACCEPT_TOKEN(sym_ms_signed_ptr_modifier);
      END_STATE();
    case 427:
      if (lookahead == 'a') ADVANCE(519);
      END_STATE();
    case 428:
      if (lookahead == 'c') ADVANCE(520);
      END_STATE();
    case 429:
      if (lookahead == 'a') ADVANCE(521);
      END_STATE();
    case 430:
      if (lookahead == 'i') ADVANCE(522);
      END_STATE();
    case 431:
      ACCEPT_TOKEN(sym_ms_unsigned_ptr_modifier);
      END_STATE();
    case 432:
      if (lookahead == 'o') ADVANCE(523);
      END_STATE();
    case 433:
      if (lookahead == 'o') ADVANCE(524);
      END_STATE();
    case 434:
      if (lookahead == 'g') ADVANCE(525);
      END_STATE();
    case 435:
      if (lookahead == 's') ADVANCE(526);
      END_STATE();
    case 436:
      if (lookahead == 'f') ADVANCE(527);
      END_STATE();
    case 437:
      ACCEPT_TOKEN(anon_sym_and_eq);
      END_STATE();
    case 438:
      ACCEPT_TOKEN(anon_sym_bitand);
      END_STATE();
    case 439:
      if (lookahead == 'r') ADVANCE(528);
      END_STATE();
    case 440:
      if (lookahead == 'i') ADVANCE(529);
      END_STATE();
    case 441:
      if (lookahead == 'i') ADVANCE(530);
      END_STATE();
    case 442:
      if (lookahead == 'u') ADVANCE(531);
      END_STATE();
    case 443:
      if (lookahead == 'l') ADVANCE(532);
      END_STATE();
    case 444:
      if (lookahead == '_') ADVANCE(533);
      END_STATE();
    case 445:
      if (lookahead == 't') ADVANCE(534);
      END_STATE();
    case 446:
      if (lookahead == 'v') ADVANCE(535);
      if (lookahead == 'x') ADVANCE(536);
      END_STATE();
    case 447:
      if (lookahead == 'n') ADVANCE(537);
      END_STATE();
    case 448:
      if (lookahead == 'u') ADVANCE(538);
      END_STATE();
    case 449:
      if (lookahead == 'p') ADVANCE(539);
      END_STATE();
    case 450:
      if (lookahead == 't') ADVANCE(540);
      END_STATE();
    case 451:
      if (lookahead == 'd') ADVANCE(541);
      END_STATE();
    case 452:
      ACCEPT_TOKEN(anon_sym_delete);
      END_STATE();
    case 453:
      if (lookahead == 'd') ADVANCE(542);
      END_STATE();
    case 454:
      if (lookahead == 'i') ADVANCE(543);
      END_STATE();
    case 455:
      ACCEPT_TOKEN(anon_sym_extern);
      END_STATE();
    case 456:
      ACCEPT_TOKEN(anon_sym_friend);
      END_STATE();
    case 457:
      if (lookahead == 'l') ADVANCE(544);
      END_STATE();
    case 458:
      if (lookahead == 'h') ADVANCE(545);
      END_STATE();
    case 459:
      ACCEPT_TOKEN(anon_sym_inline);
      END_STATE();
    case 460:
      if (lookahead == 'j') ADVANCE(546);
      END_STATE();
    case 461:
      ACCEPT_TOKEN(anon_sym_linear);
      END_STATE();
    case 462:
      if (lookahead == 'e') ADVANCE(547);
      END_STATE();
    case 463:
      if (lookahead == 'a') ADVANCE(548);
      END_STATE();
    case 464:
      if (lookahead == 'p') ADVANCE(549);
      END_STATE();
    case 465:
      if (lookahead == 'r') ADVANCE(550);
      END_STATE();
    case 466:
      if (lookahead == 'p') ADVANCE(551);
      END_STATE();
    case 467:
      if (lookahead == 'r') ADVANCE(552);
      END_STATE();
    case 468:
      ACCEPT_TOKEN(anon_sym_not_eq);
      END_STATE();
    case 469:
      if (lookahead == 'r') ADVANCE(553);
      END_STATE();
    case 470:
      if (lookahead == 'o') ADVANCE(554);
      END_STATE();
    case 471:
      if (lookahead == 'o') ADVANCE(555);
      END_STATE();
    case 472:
      if (lookahead == 'd') ADVANCE(556);
      END_STATE();
    case 473:
      if (lookahead == 'e') ADVANCE(557);
      END_STATE();
    case 474:
      if (lookahead == 'e') ADVANCE(558);
      END_STATE();
    case 475:
      if (lookahead == 't') ADVANCE(559);
      END_STATE();
    case 476:
      ACCEPT_TOKEN(anon_sym_public);
      END_STATE();
    case 477:
      if (lookahead == 'e') ADVANCE(560);
      END_STATE();
    case 478:
      if (lookahead == 'e') ADVANCE(561);
      END_STATE();
    case 479:
      if (lookahead == 'c') ADVANCE(562);
      END_STATE();
    case 480:
      ACCEPT_TOKEN(anon_sym_return);
      END_STATE();
    case 481:
      if (lookahead == 'j') ADVANCE(563);
      END_STATE();
    case 482:
      ACCEPT_TOKEN(anon_sym_sample);
      END_STATE();
    case 483:
      ACCEPT_TOKEN(anon_sym_shared);
      END_STATE();
    case 484:
      ACCEPT_TOKEN(anon_sym_signed);
      END_STATE();
    case 485:
      ACCEPT_TOKEN(anon_sym_sizeof);
      END_STATE();
    case 486:
      ACCEPT_TOKEN(anon_sym_static);
      if (lookahead == '_') ADVANCE(564);
      END_STATE();
    case 487:
      ACCEPT_TOKEN(anon_sym_struct);
      END_STATE();
    case 488:
      ACCEPT_TOKEN(anon_sym_switch);
      END_STATE();
    case 489:
      if (lookahead == 't') ADVANCE(565);
      END_STATE();
    case 490:
      if (lookahead == '_') ADVANCE(566);
      END_STATE();
    case 491:
      if (lookahead == 'l') ADVANCE(567);
      END_STATE();
    case 492:
      if (lookahead == 'f') ADVANCE(568);
      END_STATE();
    case 493:
      if (lookahead == 'm') ADVANCE(569);
      END_STATE();
    case 494:
      if (lookahead == 'm') ADVANCE(570);
      END_STATE();
    case 495:
      if (lookahead == 'e') ADVANCE(571);
      END_STATE();
    case 496:
      if (lookahead == 'l') ADVANCE(572);
      END_STATE();
    case 497:
      if (lookahead == 'l') ADVANCE(573);
      END_STATE();
    case 498:
      ACCEPT_TOKEN(anon_sym_xor_eq);
      END_STATE();
    case 499:
      if (lookahead == 's') ADVANCE(574);
      END_STATE();
    case 500:
      if (lookahead == 'f') ADVANCE(575);
      END_STATE();
    case 501:
      ACCEPT_TOKEN(anon_sym__Atomic);
      END_STATE();
    case 502:
      if (lookahead == 'c') ADVANCE(576);
      END_STATE();
    case 503:
      if (lookahead == 'r') ADVANCE(577);
      END_STATE();
    case 504:
      if (lookahead == 'o') ADVANCE(578);
      END_STATE();
    case 505:
      ACCEPT_TOKEN(anon_sym___asm__);
      END_STATE();
    case 506:
      if (lookahead == 'b') ADVANCE(579);
      END_STATE();
    case 507:
      ACCEPT_TOKEN(anon_sym___based);
      END_STATE();
    case 508:
      ACCEPT_TOKEN(anon_sym___cdecl);
      END_STATE();
    case 509:
      if (lookahead == 'l') ADVANCE(580);
      END_STATE();
    case 510:
      if (lookahead == 'p') ADVANCE(581);
      END_STATE();
    case 511:
      if (lookahead == 't') ADVANCE(582);
      END_STATE();
    case 512:
      if (lookahead == 's') ADVANCE(583);
      END_STATE();
    case 513:
      if (lookahead == 'a') ADVANCE(584);
      END_STATE();
    case 514:
      if (lookahead == 'l') ADVANCE(585);
      END_STATE();
    case 515:
      if (lookahead == 'i') ADVANCE(586);
      END_STATE();
    case 516:
      if (lookahead == 'e') ADVANCE(587);
      END_STATE();
    case 517:
      ACCEPT_TOKEN(anon_sym___leave);
      END_STATE();
    case 518:
      if (lookahead == 'i') ADVANCE(588);
      END_STATE();
    case 519:
      if (lookahead == 'l') ADVANCE(589);
      END_STATE();
    case 520:
      if (lookahead == 'a') ADVANCE(590);
      END_STATE();
    case 521:
      if (lookahead == 'd') ADVANCE(591);
      END_STATE();
    case 522:
      if (lookahead == 'g') ADVANCE(592);
      END_STATE();
    case 523:
      if (lookahead == 'r') ADVANCE(593);
      END_STATE();
    case 524:
      if (lookahead == 'f') ADVANCE(594);
      END_STATE();
    case 525:
      if (lookahead == 'n') ADVANCE(595);
      END_STATE();
    case 526:
      ACCEPT_TOKEN(anon_sym_alignas);
      END_STATE();
    case 527:
      ACCEPT_TOKEN(anon_sym_alignof);
      END_STATE();
    case 528:
      ACCEPT_TOKEN(anon_sym_cbuffer);
      END_STATE();
    case 529:
      if (lookahead == 'd') ADVANCE(596);
      END_STATE();
    case 530:
      if (lookahead == 't') ADVANCE(597);
      END_STATE();
    case 531:
      if (lookahead == 'r') ADVANCE(598);
      END_STATE();
    case 532:
      if (lookahead == 'd') ADVANCE(599);
      END_STATE();
    case 533:
      if (lookahead == 'm') ADVANCE(600);
      END_STATE();
    case 534:
      ACCEPT_TOKEN(anon_sym_concept);
      END_STATE();
    case 535:
      if (lookahead == 'a') ADVANCE(601);
      END_STATE();
    case 536:
      if (lookahead == 'p') ADVANCE(602);
      END_STATE();
    case 537:
      if (lookahead == 'i') ADVANCE(603);
      END_STATE();
    case 538:
      if (lookahead == 'e') ADVANCE(604);
      END_STATE();
    case 539:
      if (lookahead == 'e') ADVANCE(605);
      END_STATE();
    case 540:
      ACCEPT_TOKEN(anon_sym_default);
      END_STATE();
    case 541:
      ACCEPT_TOKEN(anon_sym_defined);
      END_STATE();
    case 542:
      ACCEPT_TOKEN(anon_sym_discard);
      END_STATE();
    case 543:
      if (lookahead == 't') ADVANCE(606);
      END_STATE();
    case 544:
      if (lookahead == 'y') ADVANCE(607);
      END_STATE();
    case 545:
      if (lookahead == 'a') ADVANCE(608);
      END_STATE();
    case 546:
      ACCEPT_TOKEN(anon_sym_lineadj);
      END_STATE();
    case 547:
      ACCEPT_TOKEN(anon_sym_mutable);
      END_STATE();
    case 548:
      if (lookahead == 'c') ADVANCE(609);
      END_STATE();
    case 549:
      if (lookahead == 't') ADVANCE(610);
      END_STATE();
    case 550:
      if (lookahead == 'p') ADVANCE(611);
      END_STATE();
    case 551:
      if (lookahead == 'e') ADVANCE(612);
      END_STATE();
    case 552:
      if (lookahead == 'n') ADVANCE(613);
      END_STATE();
    case 553:
      ACCEPT_TOKEN(anon_sym_nullptr);
      END_STATE();
    case 554:
      if (lookahead == 'f') ADVANCE(614);
      END_STATE();
    case 555:
      if (lookahead == 'r') ADVANCE(615);
      END_STATE();
    case 556:
      if (lookahead == 'e') ADVANCE(616);
      END_STATE();
    case 557:
      ACCEPT_TOKEN(anon_sym_precise);
      END_STATE();
    case 558:
      ACCEPT_TOKEN(anon_sym_private);
      END_STATE();
    case 559:
      if (lookahead == 'e') ADVANCE(617);
      END_STATE();
    case 560:
      if (lookahead == 'r') ADVANCE(618);
      END_STATE();
    case 561:
      if (lookahead == 's') ADVANCE(619);
      END_STATE();
    case 562:
      if (lookahead == 't') ADVANCE(620);
      END_STATE();
    case 563:
      if (lookahead == 'o') ADVANCE(621);
      END_STATE();
    case 564:
      if (lookahead == 'a') ADVANCE(622);
      END_STATE();
    case 565:
      if (lookahead == 'e') ADVANCE(623);
      END_STATE();
    case 566:
      if (lookahead == 'l') ADVANCE(624);
      END_STATE();
    case 567:
      if (lookahead == 'e') ADVANCE(625);
      END_STATE();
    case 568:
      ACCEPT_TOKEN(anon_sym_typedef);
      END_STATE();
    case 569:
      if (lookahead == 'e') ADVANCE(626);
      END_STATE();
    case 570:
      ACCEPT_TOKEN(anon_sym_uniform);
      END_STATE();
    case 571:
      if (lookahead == 'd') ADVANCE(627);
      END_STATE();
    case 572:
      ACCEPT_TOKEN(sym_virtual);
      END_STATE();
    case 573:
      if (lookahead == 'e') ADVANCE(628);
      END_STATE();
    case 574:
      ACCEPT_TOKEN(anon_sym__Alignas);
      END_STATE();
    case 575:
      ACCEPT_TOKEN(anon_sym__Alignof);
      END_STATE();
    case 576:
      ACCEPT_TOKEN(anon_sym__Generic);
      END_STATE();
    case 577:
      if (lookahead == 'n') ADVANCE(629);
      END_STATE();
    case 578:
      if (lookahead == 'f') ADVANCE(630);
      END_STATE();
    case 579:
      if (lookahead == 'u') ADVANCE(631);
      END_STATE();
    case 580:
      if (lookahead == 'l') ADVANCE(632);
      END_STATE();
    case 581:
      if (lookahead == 'e') ADVANCE(633);
      END_STATE();
    case 582:
      ACCEPT_TOKEN(anon_sym___except);
      END_STATE();
    case 583:
      if (lookahead == 'i') ADVANCE(634);
      END_STATE();
    case 584:
      if (lookahead == 'l') ADVANCE(635);
      END_STATE();
    case 585:
      if (lookahead == 'y') ADVANCE(636);
      END_STATE();
    case 586:
      if (lookahead == 'n') ADVANCE(637);
      END_STATE();
    case 587:
      ACCEPT_TOKEN(anon_sym___inline);
      if (lookahead == '_') ADVANCE(638);
      END_STATE();
    case 588:
      if (lookahead == 'c') ADVANCE(639);
      END_STATE();
    case 589:
      if (lookahead == 'l') ADVANCE(640);
      END_STATE();
    case 590:
      if (lookahead == 'l') ADVANCE(641);
      END_STATE();
    case 591:
      ACCEPT_TOKEN(anon_sym___thread);
      END_STATE();
    case 592:
      if (lookahead == 'n') ADVANCE(642);
      END_STATE();
    case 593:
      if (lookahead == 'c') ADVANCE(643);
      END_STATE();
    case 594:
      ACCEPT_TOKEN(anon_sym__alignof);
      END_STATE();
    case 595:
      if (lookahead == 'e') ADVANCE(644);
      END_STATE();
    case 596:
      ACCEPT_TOKEN(anon_sym_centroid);
      END_STATE();
    case 597:
      ACCEPT_TOKEN(anon_sym_co_await);
      END_STATE();
    case 598:
      if (lookahead == 'n') ADVANCE(645);
      END_STATE();
    case 599:
      ACCEPT_TOKEN(anon_sym_co_yield);
      END_STATE();
    case 600:
      if (lookahead == 'a') ADVANCE(646);
      END_STATE();
    case 601:
      if (lookahead == 'l') ADVANCE(647);
      END_STATE();
    case 602:
      if (lookahead == 'r') ADVANCE(648);
      END_STATE();
    case 603:
      if (lookahead == 't') ADVANCE(649);
      END_STATE();
    case 604:
      ACCEPT_TOKEN(anon_sym_continue);
      END_STATE();
    case 605:
      ACCEPT_TOKEN(anon_sym_decltype);
      END_STATE();
    case 606:
      ACCEPT_TOKEN(anon_sym_explicit);
      END_STATE();
    case 607:
      if (lookahead == 'c') ADVANCE(650);
      END_STATE();
    case 608:
      if (lookahead == 'r') ADVANCE(651);
      END_STATE();
    case 609:
      if (lookahead == 'e') ADVANCE(652);
      END_STATE();
    case 610:
      ACCEPT_TOKEN(anon_sym_noexcept);
      END_STATE();
    case 611:
      if (lookahead == 'o') ADVANCE(653);
      END_STATE();
    case 612:
      if (lookahead == 'c') ADVANCE(654);
      END_STATE();
    case 613:
      ACCEPT_TOKEN(anon_sym_noreturn);
      END_STATE();
    case 614:
      ACCEPT_TOKEN(anon_sym_offsetof);
      END_STATE();
    case 615:
      ACCEPT_TOKEN(anon_sym_operator);
      END_STATE();
    case 616:
      ACCEPT_TOKEN(anon_sym_override);
      END_STATE();
    case 617:
      if (lookahead == 'd') ADVANCE(655);
      END_STATE();
    case 618:
      ACCEPT_TOKEN(anon_sym_register);
      END_STATE();
    case 619:
      ACCEPT_TOKEN(anon_sym_requires);
      END_STATE();
    case 620:
      ACCEPT_TOKEN(anon_sym_restrict);
      END_STATE();
    case 621:
      if (lookahead == 'r') ADVANCE(656);
      END_STATE();
    case 622:
      if (lookahead == 's') ADVANCE(657);
      END_STATE();
    case 623:
      ACCEPT_TOKEN(anon_sym_template);
      END_STATE();
    case 624:
      if (lookahead == 'o') ADVANCE(658);
      END_STATE();
    case 625:
      ACCEPT_TOKEN(anon_sym_triangle);
      if (lookahead == 'a') ADVANCE(659);
      END_STATE();
    case 626:
      ACCEPT_TOKEN(anon_sym_typename);
      END_STATE();
    case 627:
      ACCEPT_TOKEN(anon_sym_unsigned);
      END_STATE();
    case 628:
      ACCEPT_TOKEN(anon_sym_volatile);
      END_STATE();
    case 629:
      ACCEPT_TOKEN(anon_sym__Noreturn);
      END_STATE();
    case 630:
      ACCEPT_TOKEN(anon_sym___alignof);
      if (lookahead == '_') ADVANCE(660);
      END_STATE();
    case 631:
      if (lookahead == 't') ADVANCE(661);
      END_STATE();
    case 632:
      ACCEPT_TOKEN(anon_sym___clrcall);
      END_STATE();
    case 633:
      if (lookahead == 'c') ADVANCE(662);
      END_STATE();
    case 634:
      if (lookahead == 'o') ADVANCE(663);
      END_STATE();
    case 635:
      if (lookahead == 'l') ADVANCE(664);
      END_STATE();
    case 636:
      ACCEPT_TOKEN(anon_sym___finally);
      END_STATE();
    case 637:
      if (lookahead == 'l') ADVANCE(665);
      END_STATE();
    case 638:
      if (lookahead == '_') ADVANCE(666);
      END_STATE();
    case 639:
      if (lookahead == 't') ADVANCE(667);
      END_STATE();
    case 640:
      ACCEPT_TOKEN(anon_sym___stdcall);
      END_STATE();
    case 641:
      if (lookahead == 'l') ADVANCE(668);
      END_STATE();
    case 642:
      if (lookahead == 'e') ADVANCE(669);
      END_STATE();
    case 643:
      if (lookahead == 'a') ADVANCE(670);
      END_STATE();
    case 644:
      if (lookahead == 'd') ADVANCE(671);
      END_STATE();
    case 645:
      ACCEPT_TOKEN(anon_sym_co_return);
      END_STATE();
    case 646:
      if (lookahead == 'j') ADVANCE(672);
      END_STATE();
    case 647:
      ACCEPT_TOKEN(anon_sym_consteval);
      END_STATE();
    case 648:
      ACCEPT_TOKEN(anon_sym_constexpr);
      END_STATE();
    case 649:
      ACCEPT_TOKEN(anon_sym_constinit);
      END_STATE();
    case 650:
      if (lookahead == 'o') ADVANCE(673);
      END_STATE();
    case 651:
      if (lookahead == 'e') ADVANCE(674);
      END_STATE();
    case 652:
      ACCEPT_TOKEN(anon_sym_namespace);
      END_STATE();
    case 653:
      if (lookahead == 'l') ADVANCE(675);
      END_STATE();
    case 654:
      if (lookahead == 't') ADVANCE(676);
      END_STATE();
    case 655:
      ACCEPT_TOKEN(anon_sym_protected);
      END_STATE();
    case 656:
      ACCEPT_TOKEN(anon_sym_row_major);
      END_STATE();
    case 657:
      if (lookahead == 's') ADVANCE(677);
      END_STATE();
    case 658:
      if (lookahead == 'c') ADVANCE(678);
      END_STATE();
    case 659:
      if (lookahead == 'd') ADVANCE(679);
      END_STATE();
    case 660:
      if (lookahead == '_') ADVANCE(680);
      END_STATE();
    case 661:
      if (lookahead == 'e') ADVANCE(681);
      END_STATE();
    case 662:
      ACCEPT_TOKEN(anon_sym___declspec);
      END_STATE();
    case 663:
      if (lookahead == 'n') ADVANCE(682);
      END_STATE();
    case 664:
      ACCEPT_TOKEN(anon_sym___fastcall);
      END_STATE();
    case 665:
      if (lookahead == 'i') ADVANCE(683);
      END_STATE();
    case 666:
      ACCEPT_TOKEN(anon_sym___inline__);
      END_STATE();
    case 667:
      ACCEPT_TOKEN(sym_ms_restrict_modifier);
      if (lookahead == '_') ADVANCE(684);
      END_STATE();
    case 668:
      ACCEPT_TOKEN(anon_sym___thiscall);
      END_STATE();
    case 669:
      if (lookahead == 'd') ADVANCE(685);
      END_STATE();
    case 670:
      if (lookahead == 'l') ADVANCE(686);
      END_STATE();
    case 671:
      ACCEPT_TOKEN(anon_sym__unaligned);
      END_STATE();
    case 672:
      if (lookahead == 'o') ADVANCE(687);
      END_STATE();
    case 673:
      if (lookahead == 'h') ADVANCE(688);
      END_STATE();
    case 674:
      if (lookahead == 'd') ADVANCE(689);
      END_STATE();
    case 675:
      if (lookahead == 'a') ADVANCE(690);
      END_STATE();
    case 676:
      if (lookahead == 'i') ADVANCE(691);
      END_STATE();
    case 677:
      if (lookahead == 'e') ADVANCE(692);
      END_STATE();
    case 678:
      if (lookahead == 'a') ADVANCE(693);
      END_STATE();
    case 679:
      if (lookahead == 'j') ADVANCE(694);
      END_STATE();
    case 680:
      ACCEPT_TOKEN(anon_sym___alignof__);
      END_STATE();
    case 681:
      if (lookahead == '_') ADVANCE(695);
      END_STATE();
    case 682:
      if (lookahead == '_') ADVANCE(696);
      END_STATE();
    case 683:
      if (lookahead == 'n') ADVANCE(697);
      END_STATE();
    case 684:
      if (lookahead == '_') ADVANCE(698);
      END_STATE();
    case 685:
      ACCEPT_TOKEN(anon_sym___unaligned);
      END_STATE();
    case 686:
      if (lookahead == 'l') ADVANCE(699);
      END_STATE();
    case 687:
      if (lookahead == 'r') ADVANCE(700);
      END_STATE();
    case 688:
      if (lookahead == 'e') ADVANCE(701);
      END_STATE();
    case 689:
      ACCEPT_TOKEN(anon_sym_groupshared);
      END_STATE();
    case 690:
      if (lookahead == 't') ADVANCE(702);
      END_STATE();
    case 691:
      if (lookahead == 'v') ADVANCE(703);
      END_STATE();
    case 692:
      if (lookahead == 'r') ADVANCE(704);
      END_STATE();
    case 693:
      if (lookahead == 'l') ADVANCE(705);
      END_STATE();
    case 694:
      ACCEPT_TOKEN(anon_sym_triangleadj);
      END_STATE();
    case 695:
      if (lookahead == '_') ADVANCE(706);
      END_STATE();
    case 696:
      if (lookahead == '_') ADVANCE(707);
      END_STATE();
    case 697:
      if (lookahead == 'e') ADVANCE(708);
      END_STATE();
    case 698:
      ACCEPT_TOKEN(anon_sym___restrict__);
      END_STATE();
    case 699:
      ACCEPT_TOKEN(anon_sym___vectorcall);
      END_STATE();
    case 700:
      ACCEPT_TOKEN(anon_sym_column_major);
      END_STATE();
    case 701:
      if (lookahead == 'r') ADVANCE(709);
      END_STATE();
    case 702:
      if (lookahead == 'i') ADVANCE(710);
      END_STATE();
    case 703:
      if (lookahead == 'e') ADVANCE(711);
      END_STATE();
    case 704:
      if (lookahead == 't') ADVANCE(712);
      END_STATE();
    case 705:
      ACCEPT_TOKEN(anon_sym_thread_local);
      END_STATE();
    case 706:
      ACCEPT_TOKEN(anon_sym___attribute__);
      END_STATE();
    case 707:
      ACCEPT_TOKEN(anon_sym___extension__);
      END_STATE();
    case 708:
      ACCEPT_TOKEN(anon_sym___forceinline);
      END_STATE();
    case 709:
      if (lookahead == 'e') ADVANCE(713);
      END_STATE();
    case 710:
      if (lookahead == 'o') ADVANCE(714);
      END_STATE();
    case 711:
      ACCEPT_TOKEN(anon_sym_noperspective);
      END_STATE();
    case 712:
      ACCEPT_TOKEN(anon_sym_static_assert);
      END_STATE();
    case 713:
      if (lookahead == 'n') ADVANCE(715);
      END_STATE();
    case 714:
      if (lookahead == 'n') ADVANCE(716);
      END_STATE();
    case 715:
      if (lookahead == 't') ADVANCE(717);
      END_STATE();
    case 716:
      ACCEPT_TOKEN(anon_sym_nointerpolation);
      END_STATE();
    case 717:
      ACCEPT_TOKEN(anon_sym_globallycoherent);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 337},
  [2] = {.lex_state = 337},
  [3] = {.lex_state = 337},
  [4] = {.lex_state = 337},
  [5] = {.lex_state = 337},
  [6] = {.lex_state = 337},
  [7] = {.lex_state = 337},
  [8] = {.lex_state = 337},
  [9] = {.lex_state = 337},
  [10] = {.lex_state = 337},
  [11] = {.lex_state = 337},
  [12] = {.lex_state = 337},
  [13] = {.lex_state = 171},
  [14] = {.lex_state = 171},
  [15] = {.lex_state = 171},
  [16] = {.lex_state = 171},
  [17] = {.lex_state = 171},
  [18] = {.lex_state = 171},
  [19] = {.lex_state = 171},
  [20] = {.lex_state = 171},
  [21] = {.lex_state = 171},
  [22] = {.lex_state = 171},
  [23] = {.lex_state = 171},
  [24] = {.lex_state = 171},
  [25] = {.lex_state = 171},
  [26] = {.lex_state = 171},
  [27] = {.lex_state = 171},
  [28] = {.lex_state = 171},
  [29] = {.lex_state = 171},
  [30] = {.lex_state = 171},
  [31] = {.lex_state = 171},
  [32] = {.lex_state = 171},
  [33] = {.lex_state = 171},
  [34] = {.lex_state = 337},
  [35] = {.lex_state = 337},
  [36] = {.lex_state = 337},
  [37] = {.lex_state = 337},
  [38] = {.lex_state = 337},
  [39] = {.lex_state = 337},
  [40] = {.lex_state = 337},
  [41] = {.lex_state = 337},
  [42] = {.lex_state = 337},
  [43] = {.lex_state = 337},
  [44] = {.lex_state = 337},
  [45] = {.lex_state = 337},
  [46] = {.lex_state = 337},
  [47] = {.lex_state = 337},
  [48] = {.lex_state = 174},
  [49] = {.lex_state = 337},
  [50] = {.lex_state = 337},
  [51] = {.lex_state = 337},
  [52] = {.lex_state = 337},
  [53] = {.lex_state = 337},
  [54] = {.lex_state = 337},
  [55] = {.lex_state = 174},
  [56] = {.lex_state = 337},
  [57] = {.lex_state = 337},
  [58] = {.lex_state = 337},
  [59] = {.lex_state = 337},
  [60] = {.lex_state = 337},
  [61] = {.lex_state = 337},
  [62] = {.lex_state = 337},
  [63] = {.lex_state = 337},
  [64] = {.lex_state = 337},
  [65] = {.lex_state = 337},
  [66] = {.lex_state = 337},
  [67] = {.lex_state = 337},
  [68] = {.lex_state = 337},
  [69] = {.lex_state = 337},
  [70] = {.lex_state = 337},
  [71] = {.lex_state = 337},
  [72] = {.lex_state = 337},
  [73] = {.lex_state = 337},
  [74] = {.lex_state = 337},
  [75] = {.lex_state = 337},
  [76] = {.lex_state = 337},
  [77] = {.lex_state = 337},
  [78] = {.lex_state = 337},
  [79] = {.lex_state = 174},
  [80] = {.lex_state = 337},
  [81] = {.lex_state = 337},
  [82] = {.lex_state = 171},
  [83] = {.lex_state = 171},
  [84] = {.lex_state = 171},
  [85] = {.lex_state = 171},
  [86] = {.lex_state = 171},
  [87] = {.lex_state = 337},
  [88] = {.lex_state = 337},
  [89] = {.lex_state = 174},
  [90] = {.lex_state = 337},
  [91] = {.lex_state = 337},
  [92] = {.lex_state = 174},
  [93] = {.lex_state = 337},
  [94] = {.lex_state = 337},
  [95] = {.lex_state = 174},
  [96] = {.lex_state = 337},
  [97] = {.lex_state = 174},
  [98] = {.lex_state = 174},
  [99] = {.lex_state = 337},
  [100] = {.lex_state = 337},
  [101] = {.lex_state = 337},
  [102] = {.lex_state = 173},
  [103] = {.lex_state = 173},
  [104] = {.lex_state = 173},
  [105] = {.lex_state = 173},
  [106] = {.lex_state = 173},
  [107] = {.lex_state = 173},
  [108] = {.lex_state = 173},
  [109] = {.lex_state = 173},
  [110] = {.lex_state = 173},
  [111] = {.lex_state = 173},
  [112] = {.lex_state = 173},
  [113] = {.lex_state = 173},
  [114] = {.lex_state = 173},
  [115] = {.lex_state = 173},
  [116] = {.lex_state = 173},
  [117] = {.lex_state = 173},
  [118] = {.lex_state = 173},
  [119] = {.lex_state = 173},
  [120] = {.lex_state = 173},
  [121] = {.lex_state = 173},
  [122] = {.lex_state = 173},
  [123] = {.lex_state = 173},
  [124] = {.lex_state = 173},
  [125] = {.lex_state = 173},
  [126] = {.lex_state = 173},
  [127] = {.lex_state = 173},
  [128] = {.lex_state = 337},
  [129] = {.lex_state = 337},
  [130] = {.lex_state = 337},
  [131] = {.lex_state = 337},
  [132] = {.lex_state = 337},
  [133] = {.lex_state = 171},
  [134] = {.lex_state = 337},
  [135] = {.lex_state = 171},
  [136] = {.lex_state = 337},
  [137] = {.lex_state = 337},
  [138] = {.lex_state = 171},
  [139] = {.lex_state = 171},
  [140] = {.lex_state = 337},
  [141] = {.lex_state = 171},
  [142] = {.lex_state = 171},
  [143] = {.lex_state = 171},
  [144] = {.lex_state = 171},
  [145] = {.lex_state = 171},
  [146] = {.lex_state = 171},
  [147] = {.lex_state = 171},
  [148] = {.lex_state = 171},
  [149] = {.lex_state = 171},
  [150] = {.lex_state = 171},
  [151] = {.lex_state = 171},
  [152] = {.lex_state = 171},
  [153] = {.lex_state = 171},
  [154] = {.lex_state = 171},
  [155] = {.lex_state = 171},
  [156] = {.lex_state = 337},
  [157] = {.lex_state = 337},
  [158] = {.lex_state = 337},
  [159] = {.lex_state = 337},
  [160] = {.lex_state = 171},
  [161] = {.lex_state = 174},
  [162] = {.lex_state = 174},
  [163] = {.lex_state = 171},
  [164] = {.lex_state = 171},
  [165] = {.lex_state = 171},
  [166] = {.lex_state = 171},
  [167] = {.lex_state = 337},
  [168] = {.lex_state = 337},
  [169] = {.lex_state = 174},
  [170] = {.lex_state = 171},
  [171] = {.lex_state = 171},
  [172] = {.lex_state = 171},
  [173] = {.lex_state = 174},
  [174] = {.lex_state = 337},
  [175] = {.lex_state = 337},
  [176] = {.lex_state = 175},
  [177] = {.lex_state = 171},
  [178] = {.lex_state = 171},
  [179] = {.lex_state = 171},
  [180] = {.lex_state = 171},
  [181] = {.lex_state = 175},
  [182] = {.lex_state = 171},
  [183] = {.lex_state = 171},
  [184] = {.lex_state = 171},
  [185] = {.lex_state = 171},
  [186] = {.lex_state = 171},
  [187] = {.lex_state = 171},
  [188] = {.lex_state = 175},
  [189] = {.lex_state = 171},
  [190] = {.lex_state = 171},
  [191] = {.lex_state = 171},
  [192] = {.lex_state = 171},
  [193] = {.lex_state = 171},
  [194] = {.lex_state = 171},
  [195] = {.lex_state = 171},
  [196] = {.lex_state = 171},
  [197] = {.lex_state = 171},
  [198] = {.lex_state = 171},
  [199] = {.lex_state = 171},
  [200] = {.lex_state = 171},
  [201] = {.lex_state = 171},
  [202] = {.lex_state = 171},
  [203] = {.lex_state = 171},
  [204] = {.lex_state = 171},
  [205] = {.lex_state = 171},
  [206] = {.lex_state = 171},
  [207] = {.lex_state = 171},
  [208] = {.lex_state = 171},
  [209] = {.lex_state = 171},
  [210] = {.lex_state = 171},
  [211] = {.lex_state = 171},
  [212] = {.lex_state = 171},
  [213] = {.lex_state = 171},
  [214] = {.lex_state = 171},
  [215] = {.lex_state = 171},
  [216] = {.lex_state = 171},
  [217] = {.lex_state = 171},
  [218] = {.lex_state = 171},
  [219] = {.lex_state = 171},
  [220] = {.lex_state = 171},
  [221] = {.lex_state = 171},
  [222] = {.lex_state = 171},
  [223] = {.lex_state = 171},
  [224] = {.lex_state = 171},
  [225] = {.lex_state = 171},
  [226] = {.lex_state = 171},
  [227] = {.lex_state = 171},
  [228] = {.lex_state = 171},
  [229] = {.lex_state = 171},
  [230] = {.lex_state = 171},
  [231] = {.lex_state = 171},
  [232] = {.lex_state = 171},
  [233] = {.lex_state = 171},
  [234] = {.lex_state = 171},
  [235] = {.lex_state = 171},
  [236] = {.lex_state = 171},
  [237] = {.lex_state = 171},
  [238] = {.lex_state = 171},
  [239] = {.lex_state = 174},
  [240] = {.lex_state = 171},
  [241] = {.lex_state = 174},
  [242] = {.lex_state = 171},
  [243] = {.lex_state = 174},
  [244] = {.lex_state = 171},
  [245] = {.lex_state = 171},
  [246] = {.lex_state = 171},
  [247] = {.lex_state = 171},
  [248] = {.lex_state = 171},
  [249] = {.lex_state = 171},
  [250] = {.lex_state = 171},
  [251] = {.lex_state = 171},
  [252] = {.lex_state = 174},
  [253] = {.lex_state = 171},
  [254] = {.lex_state = 171},
  [255] = {.lex_state = 171},
  [256] = {.lex_state = 171},
  [257] = {.lex_state = 171},
  [258] = {.lex_state = 174},
  [259] = {.lex_state = 171},
  [260] = {.lex_state = 171},
  [261] = {.lex_state = 174},
  [262] = {.lex_state = 171},
  [263] = {.lex_state = 174},
  [264] = {.lex_state = 171},
  [265] = {.lex_state = 337},
  [266] = {.lex_state = 171},
  [267] = {.lex_state = 171},
  [268] = {.lex_state = 171},
  [269] = {.lex_state = 174},
  [270] = {.lex_state = 174},
  [271] = {.lex_state = 174},
  [272] = {.lex_state = 174},
  [273] = {.lex_state = 171},
  [274] = {.lex_state = 171},
  [275] = {.lex_state = 171},
  [276] = {.lex_state = 337},
  [277] = {.lex_state = 174},
  [278] = {.lex_state = 171},
  [279] = {.lex_state = 171},
  [280] = {.lex_state = 171},
  [281] = {.lex_state = 171},
  [282] = {.lex_state = 171},
  [283] = {.lex_state = 171},
  [284] = {.lex_state = 337},
  [285] = {.lex_state = 171},
  [286] = {.lex_state = 171},
  [287] = {.lex_state = 171},
  [288] = {.lex_state = 171},
  [289] = {.lex_state = 171},
  [290] = {.lex_state = 171},
  [291] = {.lex_state = 171},
  [292] = {.lex_state = 171},
  [293] = {.lex_state = 174},
  [294] = {.lex_state = 174},
  [295] = {.lex_state = 171},
  [296] = {.lex_state = 171},
  [297] = {.lex_state = 171},
  [298] = {.lex_state = 171},
  [299] = {.lex_state = 171},
  [300] = {.lex_state = 337},
  [301] = {.lex_state = 337},
  [302] = {.lex_state = 337},
  [303] = {.lex_state = 171},
  [304] = {.lex_state = 171},
  [305] = {.lex_state = 337},
  [306] = {.lex_state = 171},
  [307] = {.lex_state = 337},
  [308] = {.lex_state = 337},
  [309] = {.lex_state = 337},
  [310] = {.lex_state = 171},
  [311] = {.lex_state = 337},
  [312] = {.lex_state = 171},
  [313] = {.lex_state = 337},
  [314] = {.lex_state = 337},
  [315] = {.lex_state = 171},
  [316] = {.lex_state = 171},
  [317] = {.lex_state = 171},
  [318] = {.lex_state = 171},
  [319] = {.lex_state = 337},
  [320] = {.lex_state = 171},
  [321] = {.lex_state = 337},
  [322] = {.lex_state = 337},
  [323] = {.lex_state = 171},
  [324] = {.lex_state = 337},
  [325] = {.lex_state = 171},
  [326] = {.lex_state = 337},
  [327] = {.lex_state = 337},
  [328] = {.lex_state = 171},
  [329] = {.lex_state = 171},
  [330] = {.lex_state = 337},
  [331] = {.lex_state = 337},
  [332] = {.lex_state = 171},
  [333] = {.lex_state = 171},
  [334] = {.lex_state = 171},
  [335] = {.lex_state = 171},
  [336] = {.lex_state = 171},
  [337] = {.lex_state = 337},
  [338] = {.lex_state = 174},
  [339] = {.lex_state = 337},
  [340] = {.lex_state = 171},
  [341] = {.lex_state = 171},
  [342] = {.lex_state = 171},
  [343] = {.lex_state = 171},
  [344] = {.lex_state = 171},
  [345] = {.lex_state = 171},
  [346] = {.lex_state = 171},
  [347] = {.lex_state = 171},
  [348] = {.lex_state = 337},
  [349] = {.lex_state = 174},
  [350] = {.lex_state = 337},
  [351] = {.lex_state = 174},
  [352] = {.lex_state = 174},
  [353] = {.lex_state = 239},
  [354] = {.lex_state = 239},
  [355] = {.lex_state = 239},
  [356] = {.lex_state = 174},
  [357] = {.lex_state = 239},
  [358] = {.lex_state = 337},
  [359] = {.lex_state = 239},
  [360] = {.lex_state = 239},
  [361] = {.lex_state = 174},
  [362] = {.lex_state = 337},
  [363] = {.lex_state = 239},
  [364] = {.lex_state = 337},
  [365] = {.lex_state = 337},
  [366] = {.lex_state = 174},
  [367] = {.lex_state = 239},
  [368] = {.lex_state = 239},
  [369] = {.lex_state = 239},
  [370] = {.lex_state = 337},
  [371] = {.lex_state = 174},
  [372] = {.lex_state = 337},
  [373] = {.lex_state = 239},
  [374] = {.lex_state = 174},
  [375] = {.lex_state = 239},
  [376] = {.lex_state = 337},
  [377] = {.lex_state = 337},
  [378] = {.lex_state = 239},
  [379] = {.lex_state = 337},
  [380] = {.lex_state = 239},
  [381] = {.lex_state = 239},
  [382] = {.lex_state = 239},
  [383] = {.lex_state = 337},
  [384] = {.lex_state = 174},
  [385] = {.lex_state = 174},
  [386] = {.lex_state = 174},
  [387] = {.lex_state = 174},
  [388] = {.lex_state = 174},
  [389] = {.lex_state = 174},
  [390] = {.lex_state = 174},
  [391] = {.lex_state = 174},
  [392] = {.lex_state = 174},
  [393] = {.lex_state = 337},
  [394] = {.lex_state = 337},
  [395] = {.lex_state = 337},
  [396] = {.lex_state = 337},
  [397] = {.lex_state = 337},
  [398] = {.lex_state = 337},
  [399] = {.lex_state = 174},
  [400] = {.lex_state = 337},
  [401] = {.lex_state = 337},
  [402] = {.lex_state = 337},
  [403] = {.lex_state = 337},
  [404] = {.lex_state = 337},
  [405] = {.lex_state = 337},
  [406] = {.lex_state = 174},
  [407] = {.lex_state = 174},
  [408] = {.lex_state = 337},
  [409] = {.lex_state = 337},
  [410] = {.lex_state = 337},
  [411] = {.lex_state = 337},
  [412] = {.lex_state = 174},
  [413] = {.lex_state = 174},
  [414] = {.lex_state = 174},
  [415] = {.lex_state = 337},
  [416] = {.lex_state = 337},
  [417] = {.lex_state = 337},
  [418] = {.lex_state = 174},
  [419] = {.lex_state = 174},
  [420] = {.lex_state = 174},
  [421] = {.lex_state = 174},
  [422] = {.lex_state = 337},
  [423] = {.lex_state = 337},
  [424] = {.lex_state = 337},
  [425] = {.lex_state = 337},
  [426] = {.lex_state = 337},
  [427] = {.lex_state = 174},
  [428] = {.lex_state = 174},
  [429] = {.lex_state = 174},
  [430] = {.lex_state = 174},
  [431] = {.lex_state = 174},
  [432] = {.lex_state = 174},
  [433] = {.lex_state = 337},
  [434] = {.lex_state = 174},
  [435] = {.lex_state = 337},
  [436] = {.lex_state = 337},
  [437] = {.lex_state = 174},
  [438] = {.lex_state = 174},
  [439] = {.lex_state = 174},
  [440] = {.lex_state = 174},
  [441] = {.lex_state = 174},
  [442] = {.lex_state = 337},
  [443] = {.lex_state = 174},
  [444] = {.lex_state = 337},
  [445] = {.lex_state = 337},
  [446] = {.lex_state = 174},
  [447] = {.lex_state = 174},
  [448] = {.lex_state = 174},
  [449] = {.lex_state = 174},
  [450] = {.lex_state = 174},
  [451] = {.lex_state = 173},
  [452] = {.lex_state = 174},
  [453] = {.lex_state = 337},
  [454] = {.lex_state = 337},
  [455] = {.lex_state = 337},
  [456] = {.lex_state = 337},
  [457] = {.lex_state = 337},
  [458] = {.lex_state = 337},
  [459] = {.lex_state = 174},
  [460] = {.lex_state = 174},
  [461] = {.lex_state = 174},
  [462] = {.lex_state = 174},
  [463] = {.lex_state = 337},
  [464] = {.lex_state = 174},
  [465] = {.lex_state = 174},
  [466] = {.lex_state = 337},
  [467] = {.lex_state = 337},
  [468] = {.lex_state = 174},
  [469] = {.lex_state = 337},
  [470] = {.lex_state = 337},
  [471] = {.lex_state = 337},
  [472] = {.lex_state = 337},
  [473] = {.lex_state = 337},
  [474] = {.lex_state = 337},
  [475] = {.lex_state = 337},
  [476] = {.lex_state = 337},
  [477] = {.lex_state = 337},
  [478] = {.lex_state = 337},
  [479] = {.lex_state = 337},
  [480] = {.lex_state = 337},
  [481] = {.lex_state = 337},
  [482] = {.lex_state = 337},
  [483] = {.lex_state = 337},
  [484] = {.lex_state = 337},
  [485] = {.lex_state = 337},
  [486] = {.lex_state = 337},
  [487] = {.lex_state = 337},
  [488] = {.lex_state = 337},
  [489] = {.lex_state = 337},
  [490] = {.lex_state = 174},
  [491] = {.lex_state = 174},
  [492] = {.lex_state = 337},
  [493] = {.lex_state = 337},
  [494] = {.lex_state = 337},
  [495] = {.lex_state = 337},
  [496] = {.lex_state = 337},
  [497] = {.lex_state = 337},
  [498] = {.lex_state = 337},
  [499] = {.lex_state = 337},
  [500] = {.lex_state = 337},
  [501] = {.lex_state = 337},
  [502] = {.lex_state = 174},
  [503] = {.lex_state = 337},
  [504] = {.lex_state = 174},
  [505] = {.lex_state = 174},
  [506] = {.lex_state = 337},
  [507] = {.lex_state = 337},
  [508] = {.lex_state = 337},
  [509] = {.lex_state = 337},
  [510] = {.lex_state = 174},
  [511] = {.lex_state = 337},
  [512] = {.lex_state = 337},
  [513] = {.lex_state = 337},
  [514] = {.lex_state = 337},
  [515] = {.lex_state = 337},
  [516] = {.lex_state = 337},
  [517] = {.lex_state = 337},
  [518] = {.lex_state = 337},
  [519] = {.lex_state = 337},
  [520] = {.lex_state = 337},
  [521] = {.lex_state = 337},
  [522] = {.lex_state = 337},
  [523] = {.lex_state = 337},
  [524] = {.lex_state = 337},
  [525] = {.lex_state = 337},
  [526] = {.lex_state = 337},
  [527] = {.lex_state = 337},
  [528] = {.lex_state = 174},
  [529] = {.lex_state = 337},
  [530] = {.lex_state = 337},
  [531] = {.lex_state = 337},
  [532] = {.lex_state = 337},
  [533] = {.lex_state = 337},
  [534] = {.lex_state = 337},
  [535] = {.lex_state = 337},
  [536] = {.lex_state = 173},
  [537] = {.lex_state = 337},
  [538] = {.lex_state = 173},
  [539] = {.lex_state = 337},
  [540] = {.lex_state = 337},
  [541] = {.lex_state = 337},
  [542] = {.lex_state = 337},
  [543] = {.lex_state = 337},
  [544] = {.lex_state = 174},
  [545] = {.lex_state = 337},
  [546] = {.lex_state = 174},
  [547] = {.lex_state = 174},
  [548] = {.lex_state = 174},
  [549] = {.lex_state = 174},
  [550] = {.lex_state = 174},
  [551] = {.lex_state = 174},
  [552] = {.lex_state = 174},
  [553] = {.lex_state = 337},
  [554] = {.lex_state = 337},
  [555] = {.lex_state = 337},
  [556] = {.lex_state = 337},
  [557] = {.lex_state = 174},
  [558] = {.lex_state = 174},
  [559] = {.lex_state = 337},
  [560] = {.lex_state = 174},
  [561] = {.lex_state = 174},
  [562] = {.lex_state = 174},
  [563] = {.lex_state = 337},
  [564] = {.lex_state = 174},
  [565] = {.lex_state = 174},
  [566] = {.lex_state = 337},
  [567] = {.lex_state = 174},
  [568] = {.lex_state = 337},
  [569] = {.lex_state = 337},
  [570] = {.lex_state = 337},
  [571] = {.lex_state = 174},
  [572] = {.lex_state = 337},
  [573] = {.lex_state = 174},
  [574] = {.lex_state = 174},
  [575] = {.lex_state = 174},
  [576] = {.lex_state = 174},
  [577] = {.lex_state = 174},
  [578] = {.lex_state = 174},
  [579] = {.lex_state = 174},
  [580] = {.lex_state = 174},
  [581] = {.lex_state = 174},
  [582] = {.lex_state = 174},
  [583] = {.lex_state = 337},
  [584] = {.lex_state = 337},
  [585] = {.lex_state = 337},
  [586] = {.lex_state = 337},
  [587] = {.lex_state = 337},
  [588] = {.lex_state = 337},
  [589] = {.lex_state = 337},
  [590] = {.lex_state = 174},
  [591] = {.lex_state = 174},
  [592] = {.lex_state = 174},
  [593] = {.lex_state = 174},
  [594] = {.lex_state = 174},
  [595] = {.lex_state = 174},
  [596] = {.lex_state = 174},
  [597] = {.lex_state = 174},
  [598] = {.lex_state = 174},
  [599] = {.lex_state = 337},
  [600] = {.lex_state = 174},
  [601] = {.lex_state = 337},
  [602] = {.lex_state = 337},
  [603] = {.lex_state = 337},
  [604] = {.lex_state = 337},
  [605] = {.lex_state = 337},
  [606] = {.lex_state = 337},
  [607] = {.lex_state = 337},
  [608] = {.lex_state = 174},
  [609] = {.lex_state = 337},
  [610] = {.lex_state = 337},
  [611] = {.lex_state = 174},
  [612] = {.lex_state = 174},
  [613] = {.lex_state = 174},
  [614] = {.lex_state = 174},
  [615] = {.lex_state = 174},
  [616] = {.lex_state = 174},
  [617] = {.lex_state = 174},
  [618] = {.lex_state = 337},
  [619] = {.lex_state = 337},
  [620] = {.lex_state = 174},
  [621] = {.lex_state = 174},
  [622] = {.lex_state = 337},
  [623] = {.lex_state = 174},
  [624] = {.lex_state = 337},
  [625] = {.lex_state = 337},
  [626] = {.lex_state = 337},
  [627] = {.lex_state = 337},
  [628] = {.lex_state = 174},
  [629] = {.lex_state = 174},
  [630] = {.lex_state = 174},
  [631] = {.lex_state = 174},
  [632] = {.lex_state = 174},
  [633] = {.lex_state = 174},
  [634] = {.lex_state = 337},
  [635] = {.lex_state = 337},
  [636] = {.lex_state = 337},
  [637] = {.lex_state = 337},
  [638] = {.lex_state = 174},
  [639] = {.lex_state = 174},
  [640] = {.lex_state = 174},
  [641] = {.lex_state = 174},
  [642] = {.lex_state = 337},
  [643] = {.lex_state = 337},
  [644] = {.lex_state = 337},
  [645] = {.lex_state = 337},
  [646] = {.lex_state = 337},
  [647] = {.lex_state = 174},
  [648] = {.lex_state = 337},
  [649] = {.lex_state = 174},
  [650] = {.lex_state = 174},
  [651] = {.lex_state = 174},
  [652] = {.lex_state = 174},
  [653] = {.lex_state = 174},
  [654] = {.lex_state = 174},
  [655] = {.lex_state = 174},
  [656] = {.lex_state = 174},
  [657] = {.lex_state = 174},
  [658] = {.lex_state = 174},
  [659] = {.lex_state = 337},
  [660] = {.lex_state = 174},
  [661] = {.lex_state = 174},
  [662] = {.lex_state = 174},
  [663] = {.lex_state = 174},
  [664] = {.lex_state = 337},
  [665] = {.lex_state = 337},
  [666] = {.lex_state = 337},
  [667] = {.lex_state = 174},
  [668] = {.lex_state = 337},
  [669] = {.lex_state = 337},
  [670] = {.lex_state = 337},
  [671] = {.lex_state = 337},
  [672] = {.lex_state = 337},
  [673] = {.lex_state = 174},
  [674] = {.lex_state = 337},
  [675] = {.lex_state = 174},
  [676] = {.lex_state = 174},
  [677] = {.lex_state = 174},
  [678] = {.lex_state = 337},
  [679] = {.lex_state = 337},
  [680] = {.lex_state = 337},
  [681] = {.lex_state = 337},
  [682] = {.lex_state = 337},
  [683] = {.lex_state = 337},
  [684] = {.lex_state = 337},
  [685] = {.lex_state = 337},
  [686] = {.lex_state = 337},
  [687] = {.lex_state = 337},
  [688] = {.lex_state = 337},
  [689] = {.lex_state = 337},
  [690] = {.lex_state = 337},
  [691] = {.lex_state = 337},
  [692] = {.lex_state = 337},
  [693] = {.lex_state = 337},
  [694] = {.lex_state = 337},
  [695] = {.lex_state = 337},
  [696] = {.lex_state = 337},
  [697] = {.lex_state = 337},
  [698] = {.lex_state = 337},
  [699] = {.lex_state = 337},
  [700] = {.lex_state = 174},
  [701] = {.lex_state = 337},
  [702] = {.lex_state = 239},
  [703] = {.lex_state = 173},
  [704] = {.lex_state = 337},
  [705] = {.lex_state = 337},
  [706] = {.lex_state = 337},
  [707] = {.lex_state = 337},
  [708] = {.lex_state = 337},
  [709] = {.lex_state = 337},
  [710] = {.lex_state = 195},
  [711] = {.lex_state = 337},
  [712] = {.lex_state = 195},
  [713] = {.lex_state = 337},
  [714] = {.lex_state = 337},
  [715] = {.lex_state = 337},
  [716] = {.lex_state = 337},
  [717] = {.lex_state = 337},
  [718] = {.lex_state = 337},
  [719] = {.lex_state = 195},
  [720] = {.lex_state = 195},
  [721] = {.lex_state = 337},
  [722] = {.lex_state = 337},
  [723] = {.lex_state = 337},
  [724] = {.lex_state = 337},
  [725] = {.lex_state = 337},
  [726] = {.lex_state = 337},
  [727] = {.lex_state = 195},
  [728] = {.lex_state = 337},
  [729] = {.lex_state = 337},
  [730] = {.lex_state = 337},
  [731] = {.lex_state = 337},
  [732] = {.lex_state = 337},
  [733] = {.lex_state = 337},
  [734] = {.lex_state = 195},
  [735] = {.lex_state = 195},
  [736] = {.lex_state = 337},
  [737] = {.lex_state = 195},
  [738] = {.lex_state = 337},
  [739] = {.lex_state = 337},
  [740] = {.lex_state = 195},
  [741] = {.lex_state = 337},
  [742] = {.lex_state = 337},
  [743] = {.lex_state = 337},
  [744] = {.lex_state = 240},
  [745] = {.lex_state = 195},
  [746] = {.lex_state = 337},
  [747] = {.lex_state = 240},
  [748] = {.lex_state = 195},
  [749] = {.lex_state = 337},
  [750] = {.lex_state = 337},
  [751] = {.lex_state = 337},
  [752] = {.lex_state = 337},
  [753] = {.lex_state = 337},
  [754] = {.lex_state = 337},
  [755] = {.lex_state = 337},
  [756] = {.lex_state = 337},
  [757] = {.lex_state = 337},
  [758] = {.lex_state = 337},
  [759] = {.lex_state = 195},
  [760] = {.lex_state = 337},
  [761] = {.lex_state = 195},
  [762] = {.lex_state = 240},
  [763] = {.lex_state = 195},
  [764] = {.lex_state = 337},
  [765] = {.lex_state = 337},
  [766] = {.lex_state = 195},
  [767] = {.lex_state = 337},
  [768] = {.lex_state = 337},
  [769] = {.lex_state = 195},
  [770] = {.lex_state = 195},
  [771] = {.lex_state = 195},
  [772] = {.lex_state = 195},
  [773] = {.lex_state = 195},
  [774] = {.lex_state = 195},
  [775] = {.lex_state = 195},
  [776] = {.lex_state = 337},
  [777] = {.lex_state = 337},
  [778] = {.lex_state = 337},
  [779] = {.lex_state = 337},
  [780] = {.lex_state = 195},
  [781] = {.lex_state = 337},
  [782] = {.lex_state = 337},
  [783] = {.lex_state = 337},
  [784] = {.lex_state = 195},
  [785] = {.lex_state = 195},
  [786] = {.lex_state = 337},
  [787] = {.lex_state = 337},
  [788] = {.lex_state = 337},
  [789] = {.lex_state = 337},
  [790] = {.lex_state = 337},
  [791] = {.lex_state = 337},
  [792] = {.lex_state = 337},
  [793] = {.lex_state = 337},
  [794] = {.lex_state = 195},
  [795] = {.lex_state = 337},
  [796] = {.lex_state = 337},
  [797] = {.lex_state = 195},
  [798] = {.lex_state = 337},
  [799] = {.lex_state = 195},
  [800] = {.lex_state = 337},
  [801] = {.lex_state = 337},
  [802] = {.lex_state = 337},
  [803] = {.lex_state = 195},
  [804] = {.lex_state = 337},
  [805] = {.lex_state = 337},
  [806] = {.lex_state = 337},
  [807] = {.lex_state = 337},
  [808] = {.lex_state = 337},
  [809] = {.lex_state = 337},
  [810] = {.lex_state = 337},
  [811] = {.lex_state = 337},
  [812] = {.lex_state = 337},
  [813] = {.lex_state = 195},
  [814] = {.lex_state = 337},
  [815] = {.lex_state = 337},
  [816] = {.lex_state = 337},
  [817] = {.lex_state = 337},
  [818] = {.lex_state = 337},
  [819] = {.lex_state = 195},
  [820] = {.lex_state = 173},
  [821] = {.lex_state = 173},
  [822] = {.lex_state = 173},
  [823] = {.lex_state = 173},
  [824] = {.lex_state = 173},
  [825] = {.lex_state = 173},
  [826] = {.lex_state = 173},
  [827] = {.lex_state = 173},
  [828] = {.lex_state = 173},
  [829] = {.lex_state = 173},
  [830] = {.lex_state = 173},
  [831] = {.lex_state = 173},
  [832] = {.lex_state = 173},
  [833] = {.lex_state = 173},
  [834] = {.lex_state = 173},
  [835] = {.lex_state = 173},
  [836] = {.lex_state = 173},
  [837] = {.lex_state = 173},
  [838] = {.lex_state = 173},
  [839] = {.lex_state = 173},
  [840] = {.lex_state = 173},
  [841] = {.lex_state = 173},
  [842] = {.lex_state = 173},
  [843] = {.lex_state = 173},
  [844] = {.lex_state = 173},
  [845] = {.lex_state = 173},
  [846] = {.lex_state = 173},
  [847] = {.lex_state = 173},
  [848] = {.lex_state = 173},
  [849] = {.lex_state = 173},
  [850] = {.lex_state = 173},
  [851] = {.lex_state = 173},
  [852] = {.lex_state = 173},
  [853] = {.lex_state = 173},
  [854] = {.lex_state = 173},
  [855] = {.lex_state = 173},
  [856] = {.lex_state = 173},
  [857] = {.lex_state = 173},
  [858] = {.lex_state = 173},
  [859] = {.lex_state = 173},
  [860] = {.lex_state = 173},
  [861] = {.lex_state = 173},
  [862] = {.lex_state = 173},
  [863] = {.lex_state = 173},
  [864] = {.lex_state = 173},
  [865] = {.lex_state = 173},
  [866] = {.lex_state = 173},
  [867] = {.lex_state = 173},
  [868] = {.lex_state = 173},
  [869] = {.lex_state = 173},
  [870] = {.lex_state = 173},
  [871] = {.lex_state = 173},
  [872] = {.lex_state = 173},
  [873] = {.lex_state = 173},
  [874] = {.lex_state = 173},
  [875] = {.lex_state = 173},
  [876] = {.lex_state = 173},
  [877] = {.lex_state = 173},
  [878] = {.lex_state = 173},
  [879] = {.lex_state = 173},
  [880] = {.lex_state = 173},
  [881] = {.lex_state = 173},
  [882] = {.lex_state = 173},
  [883] = {.lex_state = 173},
  [884] = {.lex_state = 173},
  [885] = {.lex_state = 173},
  [886] = {.lex_state = 173},
  [887] = {.lex_state = 173},
  [888] = {.lex_state = 173},
  [889] = {.lex_state = 173},
  [890] = {.lex_state = 173},
  [891] = {.lex_state = 173},
  [892] = {.lex_state = 169},
  [893] = {.lex_state = 169},
  [894] = {.lex_state = 164},
  [895] = {.lex_state = 164},
  [896] = {.lex_state = 239},
  [897] = {.lex_state = 239},
  [898] = {.lex_state = 239},
  [899] = {.lex_state = 239},
  [900] = {.lex_state = 239},
  [901] = {.lex_state = 239},
  [902] = {.lex_state = 239},
  [903] = {.lex_state = 166},
  [904] = {.lex_state = 337},
  [905] = {.lex_state = 164},
  [906] = {.lex_state = 337},
  [907] = {.lex_state = 176},
  [908] = {.lex_state = 239},
  [909] = {.lex_state = 176},
  [910] = {.lex_state = 239},
  [911] = {.lex_state = 176},
  [912] = {.lex_state = 239},
  [913] = {.lex_state = 167},
  [914] = {.lex_state = 173},
  [915] = {.lex_state = 239},
  [916] = {.lex_state = 176},
  [917] = {.lex_state = 239},
  [918] = {.lex_state = 176},
  [919] = {.lex_state = 173},
  [920] = {.lex_state = 176},
  [921] = {.lex_state = 176},
  [922] = {.lex_state = 176},
  [923] = {.lex_state = 176},
  [924] = {.lex_state = 176},
  [925] = {.lex_state = 176},
  [926] = {.lex_state = 176},
  [927] = {.lex_state = 176},
  [928] = {.lex_state = 176},
  [929] = {.lex_state = 176},
  [930] = {.lex_state = 176},
  [931] = {.lex_state = 176},
  [932] = {.lex_state = 176},
  [933] = {.lex_state = 176},
  [934] = {.lex_state = 164},
  [935] = {.lex_state = 176},
  [936] = {.lex_state = 176},
  [937] = {.lex_state = 176},
  [938] = {.lex_state = 239},
  [939] = {.lex_state = 176},
  [940] = {.lex_state = 176},
  [941] = {.lex_state = 176},
  [942] = {.lex_state = 176},
  [943] = {.lex_state = 239},
  [944] = {.lex_state = 173},
  [945] = {.lex_state = 173},
  [946] = {.lex_state = 337},
  [947] = {.lex_state = 166},
  [948] = {.lex_state = 173},
  [949] = {.lex_state = 173},
  [950] = {.lex_state = 173},
  [951] = {.lex_state = 173},
  [952] = {.lex_state = 173},
  [953] = {.lex_state = 173},
  [954] = {.lex_state = 173},
  [955] = {.lex_state = 173},
  [956] = {.lex_state = 173},
  [957] = {.lex_state = 173},
  [958] = {.lex_state = 173},
  [959] = {.lex_state = 173},
  [960] = {.lex_state = 173},
  [961] = {.lex_state = 173},
  [962] = {.lex_state = 173},
  [963] = {.lex_state = 176},
  [964] = {.lex_state = 176},
  [965] = {.lex_state = 176},
  [966] = {.lex_state = 176},
  [967] = {.lex_state = 176},
  [968] = {.lex_state = 188},
  [969] = {.lex_state = 176},
  [970] = {.lex_state = 176},
  [971] = {.lex_state = 176},
  [972] = {.lex_state = 176},
  [973] = {.lex_state = 176},
  [974] = {.lex_state = 176},
  [975] = {.lex_state = 176},
  [976] = {.lex_state = 176},
  [977] = {.lex_state = 176},
  [978] = {.lex_state = 176},
  [979] = {.lex_state = 176},
  [980] = {.lex_state = 176},
  [981] = {.lex_state = 176},
  [982] = {.lex_state = 176},
  [983] = {.lex_state = 176},
  [984] = {.lex_state = 176},
  [985] = {.lex_state = 176},
  [986] = {.lex_state = 188},
  [987] = {.lex_state = 175},
  [988] = {.lex_state = 173},
  [989] = {.lex_state = 188},
  [990] = {.lex_state = 173},
  [991] = {.lex_state = 173},
  [992] = {.lex_state = 176},
  [993] = {.lex_state = 173},
  [994] = {.lex_state = 175},
  [995] = {.lex_state = 188},
  [996] = {.lex_state = 173},
  [997] = {.lex_state = 173},
  [998] = {.lex_state = 173},
  [999] = {.lex_state = 173},
  [1000] = {.lex_state = 173},
  [1001] = {.lex_state = 173},
  [1002] = {.lex_state = 173},
  [1003] = {.lex_state = 173},
  [1004] = {.lex_state = 173},
  [1005] = {.lex_state = 173},
  [1006] = {.lex_state = 173},
  [1007] = {.lex_state = 173},
  [1008] = {.lex_state = 176},
  [1009] = {.lex_state = 173},
  [1010] = {.lex_state = 173},
  [1011] = {.lex_state = 173},
  [1012] = {.lex_state = 173},
  [1013] = {.lex_state = 173},
  [1014] = {.lex_state = 173},
  [1015] = {.lex_state = 173},
  [1016] = {.lex_state = 173},
  [1017] = {.lex_state = 173},
  [1018] = {.lex_state = 173},
  [1019] = {.lex_state = 173},
  [1020] = {.lex_state = 173},
  [1021] = {.lex_state = 173},
  [1022] = {.lex_state = 173},
  [1023] = {.lex_state = 188},
  [1024] = {.lex_state = 173},
  [1025] = {.lex_state = 173},
  [1026] = {.lex_state = 173},
  [1027] = {.lex_state = 173},
  [1028] = {.lex_state = 173},
  [1029] = {.lex_state = 176},
  [1030] = {.lex_state = 173},
  [1031] = {.lex_state = 173},
  [1032] = {.lex_state = 173},
  [1033] = {.lex_state = 173},
  [1034] = {.lex_state = 173},
  [1035] = {.lex_state = 176},
  [1036] = {.lex_state = 176},
  [1037] = {.lex_state = 173},
  [1038] = {.lex_state = 173},
  [1039] = {.lex_state = 173},
  [1040] = {.lex_state = 173},
  [1041] = {.lex_state = 173},
  [1042] = {.lex_state = 173},
  [1043] = {.lex_state = 173},
  [1044] = {.lex_state = 173},
  [1045] = {.lex_state = 173},
  [1046] = {.lex_state = 173},
  [1047] = {.lex_state = 173},
  [1048] = {.lex_state = 173},
  [1049] = {.lex_state = 173},
  [1050] = {.lex_state = 173},
  [1051] = {.lex_state = 176},
  [1052] = {.lex_state = 173},
  [1053] = {.lex_state = 173},
  [1054] = {.lex_state = 173},
  [1055] = {.lex_state = 173},
  [1056] = {.lex_state = 173},
  [1057] = {.lex_state = 176},
  [1058] = {.lex_state = 173},
  [1059] = {.lex_state = 173},
  [1060] = {.lex_state = 239},
  [1061] = {.lex_state = 165},
  [1062] = {.lex_state = 184},
  [1063] = {.lex_state = 188},
  [1064] = {.lex_state = 188},
  [1065] = {.lex_state = 188},
  [1066] = {.lex_state = 188},
  [1067] = {.lex_state = 188},
  [1068] = {.lex_state = 188},
  [1069] = {.lex_state = 188},
  [1070] = {.lex_state = 165},
  [1071] = {.lex_state = 165},
  [1072] = {.lex_state = 165},
  [1073] = {.lex_state = 168},
  [1074] = {.lex_state = 165},
  [1075] = {.lex_state = 165},
  [1076] = {.lex_state = 196},
  [1077] = {.lex_state = 196},
  [1078] = {.lex_state = 196},
  [1079] = {.lex_state = 196},
  [1080] = {.lex_state = 196},
  [1081] = {.lex_state = 196},
  [1082] = {.lex_state = 196},
  [1083] = {.lex_state = 196},
  [1084] = {.lex_state = 196},
  [1085] = {.lex_state = 239},
  [1086] = {.lex_state = 239},
  [1087] = {.lex_state = 176},
  [1088] = {.lex_state = 176},
  [1089] = {.lex_state = 176},
  [1090] = {.lex_state = 176},
  [1091] = {.lex_state = 176},
  [1092] = {.lex_state = 176},
  [1093] = {.lex_state = 176},
  [1094] = {.lex_state = 176},
  [1095] = {.lex_state = 176},
  [1096] = {.lex_state = 176},
  [1097] = {.lex_state = 176},
  [1098] = {.lex_state = 176},
  [1099] = {.lex_state = 176},
  [1100] = {.lex_state = 176},
  [1101] = {.lex_state = 176},
  [1102] = {.lex_state = 176},
  [1103] = {.lex_state = 176},
  [1104] = {.lex_state = 176},
  [1105] = {.lex_state = 176},
  [1106] = {.lex_state = 176},
  [1107] = {.lex_state = 176},
  [1108] = {.lex_state = 239},
  [1109] = {.lex_state = 239},
  [1110] = {.lex_state = 239},
  [1111] = {.lex_state = 239},
  [1112] = {.lex_state = 173},
  [1113] = {.lex_state = 173},
  [1114] = {.lex_state = 194},
  [1115] = {.lex_state = 173},
  [1116] = {.lex_state = 225},
  [1117] = {.lex_state = 225},
  [1118] = {.lex_state = 225},
  [1119] = {.lex_state = 194},
  [1120] = {.lex_state = 196},
  [1121] = {.lex_state = 194},
  [1122] = {.lex_state = 194},
  [1123] = {.lex_state = 194},
  [1124] = {.lex_state = 194},
  [1125] = {.lex_state = 225},
  [1126] = {.lex_state = 225},
  [1127] = {.lex_state = 194},
  [1128] = {.lex_state = 225},
  [1129] = {.lex_state = 196},
  [1130] = {.lex_state = 194},
  [1131] = {.lex_state = 194},
  [1132] = {.lex_state = 225},
  [1133] = {.lex_state = 196},
  [1134] = {.lex_state = 196},
  [1135] = {.lex_state = 175},
  [1136] = {.lex_state = 175},
  [1137] = {.lex_state = 194},
  [1138] = {.lex_state = 194},
  [1139] = {.lex_state = 194},
  [1140] = {.lex_state = 194},
  [1141] = {.lex_state = 194},
  [1142] = {.lex_state = 194},
  [1143] = {.lex_state = 194},
  [1144] = {.lex_state = 194},
  [1145] = {.lex_state = 176},
  [1146] = {.lex_state = 176},
  [1147] = {.lex_state = 176},
  [1148] = {.lex_state = 176},
  [1149] = {.lex_state = 176},
  [1150] = {.lex_state = 176},
  [1151] = {.lex_state = 176},
  [1152] = {.lex_state = 176},
  [1153] = {.lex_state = 176},
  [1154] = {.lex_state = 176},
  [1155] = {.lex_state = 176},
  [1156] = {.lex_state = 176},
  [1157] = {.lex_state = 176},
  [1158] = {.lex_state = 176},
  [1159] = {.lex_state = 176},
  [1160] = {.lex_state = 176},
  [1161] = {.lex_state = 176},
  [1162] = {.lex_state = 176},
  [1163] = {.lex_state = 176},
  [1164] = {.lex_state = 176},
  [1165] = {.lex_state = 176},
  [1166] = {.lex_state = 176},
  [1167] = {.lex_state = 176},
  [1168] = {.lex_state = 176},
  [1169] = {.lex_state = 176},
  [1170] = {.lex_state = 176},
  [1171] = {.lex_state = 176},
  [1172] = {.lex_state = 176},
  [1173] = {.lex_state = 176},
  [1174] = {.lex_state = 176},
  [1175] = {.lex_state = 176},
  [1176] = {.lex_state = 176},
  [1177] = {.lex_state = 176},
  [1178] = {.lex_state = 176},
  [1179] = {.lex_state = 176},
  [1180] = {.lex_state = 176},
  [1181] = {.lex_state = 176},
  [1182] = {.lex_state = 176},
  [1183] = {.lex_state = 239},
  [1184] = {.lex_state = 239},
  [1185] = {.lex_state = 176},
  [1186] = {.lex_state = 239},
  [1187] = {.lex_state = 239},
  [1188] = {.lex_state = 239},
  [1189] = {.lex_state = 225},
  [1190] = {.lex_state = 239},
  [1191] = {.lex_state = 239},
  [1192] = {.lex_state = 239},
  [1193] = {.lex_state = 239},
  [1194] = {.lex_state = 239},
  [1195] = {.lex_state = 239},
  [1196] = {.lex_state = 176},
  [1197] = {.lex_state = 176},
  [1198] = {.lex_state = 176},
  [1199] = {.lex_state = 176},
  [1200] = {.lex_state = 176},
  [1201] = {.lex_state = 176},
  [1202] = {.lex_state = 176},
  [1203] = {.lex_state = 239},
  [1204] = {.lex_state = 177},
  [1205] = {.lex_state = 176},
  [1206] = {.lex_state = 239},
  [1207] = {.lex_state = 176},
  [1208] = {.lex_state = 176},
  [1209] = {.lex_state = 176},
  [1210] = {.lex_state = 176},
  [1211] = {.lex_state = 176},
  [1212] = {.lex_state = 176},
  [1213] = {.lex_state = 176},
  [1214] = {.lex_state = 239},
  [1215] = {.lex_state = 176},
  [1216] = {.lex_state = 176},
  [1217] = {.lex_state = 176},
  [1218] = {.lex_state = 176},
  [1219] = {.lex_state = 176},
  [1220] = {.lex_state = 239},
  [1221] = {.lex_state = 176},
  [1222] = {.lex_state = 177},
  [1223] = {.lex_state = 177},
  [1224] = {.lex_state = 176},
  [1225] = {.lex_state = 176},
  [1226] = {.lex_state = 175},
  [1227] = {.lex_state = 176},
  [1228] = {.lex_state = 176},
  [1229] = {.lex_state = 175},
  [1230] = {.lex_state = 176},
  [1231] = {.lex_state = 175},
  [1232] = {.lex_state = 175},
  [1233] = {.lex_state = 175},
  [1234] = {.lex_state = 175},
  [1235] = {.lex_state = 175},
  [1236] = {.lex_state = 176},
  [1237] = {.lex_state = 176},
  [1238] = {.lex_state = 175},
  [1239] = {.lex_state = 176},
  [1240] = {.lex_state = 176},
  [1241] = {.lex_state = 176},
  [1242] = {.lex_state = 176},
  [1243] = {.lex_state = 176},
  [1244] = {.lex_state = 176},
  [1245] = {.lex_state = 176},
  [1246] = {.lex_state = 175},
  [1247] = {.lex_state = 175},
  [1248] = {.lex_state = 175},
  [1249] = {.lex_state = 176},
  [1250] = {.lex_state = 176},
  [1251] = {.lex_state = 175},
  [1252] = {.lex_state = 175},
  [1253] = {.lex_state = 176},
  [1254] = {.lex_state = 175},
  [1255] = {.lex_state = 239},
  [1256] = {.lex_state = 176},
  [1257] = {.lex_state = 176},
  [1258] = {.lex_state = 176},
  [1259] = {.lex_state = 176},
  [1260] = {.lex_state = 176},
  [1261] = {.lex_state = 176},
  [1262] = {.lex_state = 176},
  [1263] = {.lex_state = 176},
  [1264] = {.lex_state = 175},
  [1265] = {.lex_state = 176},
  [1266] = {.lex_state = 175},
  [1267] = {.lex_state = 176},
  [1268] = {.lex_state = 176},
  [1269] = {.lex_state = 176},
  [1270] = {.lex_state = 176},
  [1271] = {.lex_state = 175},
  [1272] = {.lex_state = 176},
  [1273] = {.lex_state = 176},
  [1274] = {.lex_state = 176},
  [1275] = {.lex_state = 176},
  [1276] = {.lex_state = 176},
  [1277] = {.lex_state = 176},
  [1278] = {.lex_state = 176},
  [1279] = {.lex_state = 176},
  [1280] = {.lex_state = 176},
  [1281] = {.lex_state = 175},
  [1282] = {.lex_state = 176},
  [1283] = {.lex_state = 175},
  [1284] = {.lex_state = 175},
  [1285] = {.lex_state = 175},
  [1286] = {.lex_state = 176},
  [1287] = {.lex_state = 175},
  [1288] = {.lex_state = 176},
  [1289] = {.lex_state = 176},
  [1290] = {.lex_state = 175},
  [1291] = {.lex_state = 176},
  [1292] = {.lex_state = 175},
  [1293] = {.lex_state = 176},
  [1294] = {.lex_state = 175},
  [1295] = {.lex_state = 176},
  [1296] = {.lex_state = 175},
  [1297] = {.lex_state = 239},
  [1298] = {.lex_state = 176},
  [1299] = {.lex_state = 176},
  [1300] = {.lex_state = 176},
  [1301] = {.lex_state = 176},
  [1302] = {.lex_state = 176},
  [1303] = {.lex_state = 239},
  [1304] = {.lex_state = 176},
  [1305] = {.lex_state = 176},
  [1306] = {.lex_state = 176},
  [1307] = {.lex_state = 176},
  [1308] = {.lex_state = 176},
  [1309] = {.lex_state = 176},
  [1310] = {.lex_state = 176},
  [1311] = {.lex_state = 176},
  [1312] = {.lex_state = 239},
  [1313] = {.lex_state = 176},
  [1314] = {.lex_state = 225},
  [1315] = {.lex_state = 176},
  [1316] = {.lex_state = 176},
  [1317] = {.lex_state = 176},
  [1318] = {.lex_state = 176},
  [1319] = {.lex_state = 176},
  [1320] = {.lex_state = 176},
  [1321] = {.lex_state = 176},
  [1322] = {.lex_state = 176},
  [1323] = {.lex_state = 176},
  [1324] = {.lex_state = 176},
  [1325] = {.lex_state = 176},
  [1326] = {.lex_state = 176},
  [1327] = {.lex_state = 239},
  [1328] = {.lex_state = 176},
  [1329] = {.lex_state = 176},
  [1330] = {.lex_state = 239},
  [1331] = {.lex_state = 176},
  [1332] = {.lex_state = 176},
  [1333] = {.lex_state = 176},
  [1334] = {.lex_state = 176},
  [1335] = {.lex_state = 176},
  [1336] = {.lex_state = 239},
  [1337] = {.lex_state = 176},
  [1338] = {.lex_state = 176},
  [1339] = {.lex_state = 176},
  [1340] = {.lex_state = 176},
  [1341] = {.lex_state = 176},
  [1342] = {.lex_state = 176},
  [1343] = {.lex_state = 176},
  [1344] = {.lex_state = 176},
  [1345] = {.lex_state = 176},
  [1346] = {.lex_state = 176},
  [1347] = {.lex_state = 176},
  [1348] = {.lex_state = 176},
  [1349] = {.lex_state = 176},
  [1350] = {.lex_state = 176},
  [1351] = {.lex_state = 176},
  [1352] = {.lex_state = 176},
  [1353] = {.lex_state = 176},
  [1354] = {.lex_state = 239},
  [1355] = {.lex_state = 176},
  [1356] = {.lex_state = 176},
  [1357] = {.lex_state = 239},
  [1358] = {.lex_state = 176},
  [1359] = {.lex_state = 176},
  [1360] = {.lex_state = 176},
  [1361] = {.lex_state = 239},
  [1362] = {.lex_state = 176},
  [1363] = {.lex_state = 176},
  [1364] = {.lex_state = 176},
  [1365] = {.lex_state = 176},
  [1366] = {.lex_state = 176},
  [1367] = {.lex_state = 176},
  [1368] = {.lex_state = 176},
  [1369] = {.lex_state = 176},
  [1370] = {.lex_state = 176},
  [1371] = {.lex_state = 176},
  [1372] = {.lex_state = 176},
  [1373] = {.lex_state = 176},
  [1374] = {.lex_state = 176},
  [1375] = {.lex_state = 176},
  [1376] = {.lex_state = 176},
  [1377] = {.lex_state = 176},
  [1378] = {.lex_state = 176},
  [1379] = {.lex_state = 176},
  [1380] = {.lex_state = 176},
  [1381] = {.lex_state = 176},
  [1382] = {.lex_state = 176},
  [1383] = {.lex_state = 176},
  [1384] = {.lex_state = 176},
  [1385] = {.lex_state = 176},
  [1386] = {.lex_state = 176},
  [1387] = {.lex_state = 176},
  [1388] = {.lex_state = 176},
  [1389] = {.lex_state = 176},
  [1390] = {.lex_state = 176},
  [1391] = {.lex_state = 176},
  [1392] = {.lex_state = 176},
  [1393] = {.lex_state = 176},
  [1394] = {.lex_state = 176},
  [1395] = {.lex_state = 176},
  [1396] = {.lex_state = 176},
  [1397] = {.lex_state = 176},
  [1398] = {.lex_state = 176},
  [1399] = {.lex_state = 176},
  [1400] = {.lex_state = 176},
  [1401] = {.lex_state = 176},
  [1402] = {.lex_state = 176},
  [1403] = {.lex_state = 176},
  [1404] = {.lex_state = 176},
  [1405] = {.lex_state = 176},
  [1406] = {.lex_state = 176},
  [1407] = {.lex_state = 176},
  [1408] = {.lex_state = 176},
  [1409] = {.lex_state = 176},
  [1410] = {.lex_state = 176},
  [1411] = {.lex_state = 176},
  [1412] = {.lex_state = 176},
  [1413] = {.lex_state = 176},
  [1414] = {.lex_state = 176},
  [1415] = {.lex_state = 176},
  [1416] = {.lex_state = 176},
  [1417] = {.lex_state = 176},
  [1418] = {.lex_state = 176},
  [1419] = {.lex_state = 176},
  [1420] = {.lex_state = 176},
  [1421] = {.lex_state = 176},
  [1422] = {.lex_state = 176},
  [1423] = {.lex_state = 176},
  [1424] = {.lex_state = 176},
  [1425] = {.lex_state = 176},
  [1426] = {.lex_state = 176},
  [1427] = {.lex_state = 176},
  [1428] = {.lex_state = 176},
  [1429] = {.lex_state = 176},
  [1430] = {.lex_state = 176},
  [1431] = {.lex_state = 176},
  [1432] = {.lex_state = 176},
  [1433] = {.lex_state = 176},
  [1434] = {.lex_state = 176},
  [1435] = {.lex_state = 176},
  [1436] = {.lex_state = 176},
  [1437] = {.lex_state = 176},
  [1438] = {.lex_state = 176},
  [1439] = {.lex_state = 176},
  [1440] = {.lex_state = 176},
  [1441] = {.lex_state = 176},
  [1442] = {.lex_state = 176},
  [1443] = {.lex_state = 176},
  [1444] = {.lex_state = 176},
  [1445] = {.lex_state = 176},
  [1446] = {.lex_state = 176},
  [1447] = {.lex_state = 176},
  [1448] = {.lex_state = 176},
  [1449] = {.lex_state = 176},
  [1450] = {.lex_state = 176},
  [1451] = {.lex_state = 176},
  [1452] = {.lex_state = 176},
  [1453] = {.lex_state = 176},
  [1454] = {.lex_state = 176},
  [1455] = {.lex_state = 176},
  [1456] = {.lex_state = 225},
  [1457] = {.lex_state = 176},
  [1458] = {.lex_state = 176},
  [1459] = {.lex_state = 176},
  [1460] = {.lex_state = 176},
  [1461] = {.lex_state = 176},
  [1462] = {.lex_state = 176},
  [1463] = {.lex_state = 176},
  [1464] = {.lex_state = 176},
  [1465] = {.lex_state = 176},
  [1466] = {.lex_state = 176},
  [1467] = {.lex_state = 176},
  [1468] = {.lex_state = 176},
  [1469] = {.lex_state = 176},
  [1470] = {.lex_state = 176},
  [1471] = {.lex_state = 176},
  [1472] = {.lex_state = 176},
  [1473] = {.lex_state = 176},
  [1474] = {.lex_state = 176},
  [1475] = {.lex_state = 176},
  [1476] = {.lex_state = 176},
  [1477] = {.lex_state = 176},
  [1478] = {.lex_state = 176},
  [1479] = {.lex_state = 176},
  [1480] = {.lex_state = 176},
  [1481] = {.lex_state = 176},
  [1482] = {.lex_state = 176},
  [1483] = {.lex_state = 176},
  [1484] = {.lex_state = 176},
  [1485] = {.lex_state = 176},
  [1486] = {.lex_state = 176},
  [1487] = {.lex_state = 176},
  [1488] = {.lex_state = 176},
  [1489] = {.lex_state = 176},
  [1490] = {.lex_state = 176},
  [1491] = {.lex_state = 176},
  [1492] = {.lex_state = 176},
  [1493] = {.lex_state = 176},
  [1494] = {.lex_state = 176},
  [1495] = {.lex_state = 176},
  [1496] = {.lex_state = 176},
  [1497] = {.lex_state = 176},
  [1498] = {.lex_state = 176},
  [1499] = {.lex_state = 176},
  [1500] = {.lex_state = 176},
  [1501] = {.lex_state = 176},
  [1502] = {.lex_state = 176},
  [1503] = {.lex_state = 176},
  [1504] = {.lex_state = 176},
  [1505] = {.lex_state = 176},
  [1506] = {.lex_state = 176},
  [1507] = {.lex_state = 176},
  [1508] = {.lex_state = 176},
  [1509] = {.lex_state = 176},
  [1510] = {.lex_state = 176},
  [1511] = {.lex_state = 176},
  [1512] = {.lex_state = 176},
  [1513] = {.lex_state = 176},
  [1514] = {.lex_state = 176},
  [1515] = {.lex_state = 176},
  [1516] = {.lex_state = 176},
  [1517] = {.lex_state = 176},
  [1518] = {.lex_state = 176},
  [1519] = {.lex_state = 176},
  [1520] = {.lex_state = 176},
  [1521] = {.lex_state = 176},
  [1522] = {.lex_state = 176},
  [1523] = {.lex_state = 176},
  [1524] = {.lex_state = 176},
  [1525] = {.lex_state = 176},
  [1526] = {.lex_state = 176},
  [1527] = {.lex_state = 176},
  [1528] = {.lex_state = 176},
  [1529] = {.lex_state = 176},
  [1530] = {.lex_state = 176},
  [1531] = {.lex_state = 176},
  [1532] = {.lex_state = 176},
  [1533] = {.lex_state = 176},
  [1534] = {.lex_state = 176},
  [1535] = {.lex_state = 176},
  [1536] = {.lex_state = 176},
  [1537] = {.lex_state = 176},
  [1538] = {.lex_state = 176},
  [1539] = {.lex_state = 176},
  [1540] = {.lex_state = 176},
  [1541] = {.lex_state = 176},
  [1542] = {.lex_state = 176},
  [1543] = {.lex_state = 239},
  [1544] = {.lex_state = 176},
  [1545] = {.lex_state = 176},
  [1546] = {.lex_state = 176},
  [1547] = {.lex_state = 176},
  [1548] = {.lex_state = 176},
  [1549] = {.lex_state = 176},
  [1550] = {.lex_state = 176},
  [1551] = {.lex_state = 176},
  [1552] = {.lex_state = 176},
  [1553] = {.lex_state = 176},
  [1554] = {.lex_state = 176},
  [1555] = {.lex_state = 176},
  [1556] = {.lex_state = 176},
  [1557] = {.lex_state = 176},
  [1558] = {.lex_state = 176},
  [1559] = {.lex_state = 176},
  [1560] = {.lex_state = 176},
  [1561] = {.lex_state = 176},
  [1562] = {.lex_state = 176},
  [1563] = {.lex_state = 239},
  [1564] = {.lex_state = 176},
  [1565] = {.lex_state = 176},
  [1566] = {.lex_state = 176},
  [1567] = {.lex_state = 176},
  [1568] = {.lex_state = 176},
  [1569] = {.lex_state = 176},
  [1570] = {.lex_state = 176},
  [1571] = {.lex_state = 176},
  [1572] = {.lex_state = 176},
  [1573] = {.lex_state = 176},
  [1574] = {.lex_state = 176},
  [1575] = {.lex_state = 176},
  [1576] = {.lex_state = 176},
  [1577] = {.lex_state = 176},
  [1578] = {.lex_state = 176},
  [1579] = {.lex_state = 176},
  [1580] = {.lex_state = 176},
  [1581] = {.lex_state = 176},
  [1582] = {.lex_state = 176},
  [1583] = {.lex_state = 176},
  [1584] = {.lex_state = 176},
  [1585] = {.lex_state = 176},
  [1586] = {.lex_state = 176},
  [1587] = {.lex_state = 176},
  [1588] = {.lex_state = 176},
  [1589] = {.lex_state = 176},
  [1590] = {.lex_state = 176},
  [1591] = {.lex_state = 176},
  [1592] = {.lex_state = 176},
  [1593] = {.lex_state = 176},
  [1594] = {.lex_state = 176},
  [1595] = {.lex_state = 176},
  [1596] = {.lex_state = 176},
  [1597] = {.lex_state = 176},
  [1598] = {.lex_state = 176},
  [1599] = {.lex_state = 176},
  [1600] = {.lex_state = 176},
  [1601] = {.lex_state = 176},
  [1602] = {.lex_state = 176},
  [1603] = {.lex_state = 176},
  [1604] = {.lex_state = 176},
  [1605] = {.lex_state = 176},
  [1606] = {.lex_state = 176},
  [1607] = {.lex_state = 176},
  [1608] = {.lex_state = 176},
  [1609] = {.lex_state = 176},
  [1610] = {.lex_state = 176},
  [1611] = {.lex_state = 176},
  [1612] = {.lex_state = 176},
  [1613] = {.lex_state = 176},
  [1614] = {.lex_state = 176},
  [1615] = {.lex_state = 176},
  [1616] = {.lex_state = 176},
  [1617] = {.lex_state = 176},
  [1618] = {.lex_state = 176},
  [1619] = {.lex_state = 176},
  [1620] = {.lex_state = 176},
  [1621] = {.lex_state = 176},
  [1622] = {.lex_state = 176},
  [1623] = {.lex_state = 176},
  [1624] = {.lex_state = 176},
  [1625] = {.lex_state = 176},
  [1626] = {.lex_state = 176},
  [1627] = {.lex_state = 176},
  [1628] = {.lex_state = 176},
  [1629] = {.lex_state = 176},
  [1630] = {.lex_state = 176},
  [1631] = {.lex_state = 176},
  [1632] = {.lex_state = 176},
  [1633] = {.lex_state = 176},
  [1634] = {.lex_state = 176},
  [1635] = {.lex_state = 239},
  [1636] = {.lex_state = 176},
  [1637] = {.lex_state = 176},
  [1638] = {.lex_state = 176},
  [1639] = {.lex_state = 176},
  [1640] = {.lex_state = 176},
  [1641] = {.lex_state = 176},
  [1642] = {.lex_state = 176},
  [1643] = {.lex_state = 176},
  [1644] = {.lex_state = 176},
  [1645] = {.lex_state = 176},
  [1646] = {.lex_state = 176},
  [1647] = {.lex_state = 176},
  [1648] = {.lex_state = 176},
  [1649] = {.lex_state = 176},
  [1650] = {.lex_state = 176},
  [1651] = {.lex_state = 176},
  [1652] = {.lex_state = 176},
  [1653] = {.lex_state = 176},
  [1654] = {.lex_state = 176},
  [1655] = {.lex_state = 176},
  [1656] = {.lex_state = 176},
  [1657] = {.lex_state = 176},
  [1658] = {.lex_state = 176},
  [1659] = {.lex_state = 176},
  [1660] = {.lex_state = 176},
  [1661] = {.lex_state = 176},
  [1662] = {.lex_state = 176},
  [1663] = {.lex_state = 176},
  [1664] = {.lex_state = 176},
  [1665] = {.lex_state = 176},
  [1666] = {.lex_state = 176},
  [1667] = {.lex_state = 176},
  [1668] = {.lex_state = 176},
  [1669] = {.lex_state = 176},
  [1670] = {.lex_state = 176},
  [1671] = {.lex_state = 176},
  [1672] = {.lex_state = 176},
  [1673] = {.lex_state = 176},
  [1674] = {.lex_state = 176},
  [1675] = {.lex_state = 176},
  [1676] = {.lex_state = 176},
  [1677] = {.lex_state = 176},
  [1678] = {.lex_state = 176},
  [1679] = {.lex_state = 176},
  [1680] = {.lex_state = 176},
  [1681] = {.lex_state = 176},
  [1682] = {.lex_state = 176},
  [1683] = {.lex_state = 176},
  [1684] = {.lex_state = 176},
  [1685] = {.lex_state = 176},
  [1686] = {.lex_state = 176},
  [1687] = {.lex_state = 176},
  [1688] = {.lex_state = 176},
  [1689] = {.lex_state = 176},
  [1690] = {.lex_state = 176},
  [1691] = {.lex_state = 176},
  [1692] = {.lex_state = 176},
  [1693] = {.lex_state = 176},
  [1694] = {.lex_state = 176},
  [1695] = {.lex_state = 176},
  [1696] = {.lex_state = 176},
  [1697] = {.lex_state = 176},
  [1698] = {.lex_state = 176},
  [1699] = {.lex_state = 176},
  [1700] = {.lex_state = 176},
  [1701] = {.lex_state = 176},
  [1702] = {.lex_state = 176},
  [1703] = {.lex_state = 176},
  [1704] = {.lex_state = 176},
  [1705] = {.lex_state = 176},
  [1706] = {.lex_state = 176},
  [1707] = {.lex_state = 176},
  [1708] = {.lex_state = 176},
  [1709] = {.lex_state = 176},
  [1710] = {.lex_state = 176},
  [1711] = {.lex_state = 176},
  [1712] = {.lex_state = 176},
  [1713] = {.lex_state = 176},
  [1714] = {.lex_state = 176},
  [1715] = {.lex_state = 176},
  [1716] = {.lex_state = 176},
  [1717] = {.lex_state = 176},
  [1718] = {.lex_state = 239},
  [1719] = {.lex_state = 176},
  [1720] = {.lex_state = 176},
  [1721] = {.lex_state = 176},
  [1722] = {.lex_state = 176},
  [1723] = {.lex_state = 176},
  [1724] = {.lex_state = 176},
  [1725] = {.lex_state = 176},
  [1726] = {.lex_state = 176},
  [1727] = {.lex_state = 176},
  [1728] = {.lex_state = 176},
  [1729] = {.lex_state = 176},
  [1730] = {.lex_state = 176},
  [1731] = {.lex_state = 176},
  [1732] = {.lex_state = 176},
  [1733] = {.lex_state = 176},
  [1734] = {.lex_state = 176},
  [1735] = {.lex_state = 176},
  [1736] = {.lex_state = 176},
  [1737] = {.lex_state = 176},
  [1738] = {.lex_state = 176},
  [1739] = {.lex_state = 176},
  [1740] = {.lex_state = 176},
  [1741] = {.lex_state = 176},
  [1742] = {.lex_state = 176},
  [1743] = {.lex_state = 176},
  [1744] = {.lex_state = 176},
  [1745] = {.lex_state = 176},
  [1746] = {.lex_state = 176},
  [1747] = {.lex_state = 176},
  [1748] = {.lex_state = 176},
  [1749] = {.lex_state = 176},
  [1750] = {.lex_state = 176},
  [1751] = {.lex_state = 176},
  [1752] = {.lex_state = 176},
  [1753] = {.lex_state = 176},
  [1754] = {.lex_state = 176},
  [1755] = {.lex_state = 176},
  [1756] = {.lex_state = 176},
  [1757] = {.lex_state = 176},
  [1758] = {.lex_state = 176},
  [1759] = {.lex_state = 176},
  [1760] = {.lex_state = 176},
  [1761] = {.lex_state = 176},
  [1762] = {.lex_state = 176},
  [1763] = {.lex_state = 176},
  [1764] = {.lex_state = 176},
  [1765] = {.lex_state = 176},
  [1766] = {.lex_state = 176},
  [1767] = {.lex_state = 176},
  [1768] = {.lex_state = 176},
  [1769] = {.lex_state = 176},
  [1770] = {.lex_state = 176},
  [1771] = {.lex_state = 176},
  [1772] = {.lex_state = 176},
  [1773] = {.lex_state = 176},
  [1774] = {.lex_state = 176},
  [1775] = {.lex_state = 176},
  [1776] = {.lex_state = 176},
  [1777] = {.lex_state = 176},
  [1778] = {.lex_state = 176},
  [1779] = {.lex_state = 176},
  [1780] = {.lex_state = 176},
  [1781] = {.lex_state = 176},
  [1782] = {.lex_state = 176},
  [1783] = {.lex_state = 176},
  [1784] = {.lex_state = 176},
  [1785] = {.lex_state = 176},
  [1786] = {.lex_state = 176},
  [1787] = {.lex_state = 176},
  [1788] = {.lex_state = 176},
  [1789] = {.lex_state = 176},
  [1790] = {.lex_state = 176},
  [1791] = {.lex_state = 176},
  [1792] = {.lex_state = 176},
  [1793] = {.lex_state = 176},
  [1794] = {.lex_state = 176},
  [1795] = {.lex_state = 176},
  [1796] = {.lex_state = 176},
  [1797] = {.lex_state = 176},
  [1798] = {.lex_state = 176},
  [1799] = {.lex_state = 176},
  [1800] = {.lex_state = 176},
  [1801] = {.lex_state = 176},
  [1802] = {.lex_state = 176},
  [1803] = {.lex_state = 176},
  [1804] = {.lex_state = 176},
  [1805] = {.lex_state = 176},
  [1806] = {.lex_state = 176},
  [1807] = {.lex_state = 176},
  [1808] = {.lex_state = 176},
  [1809] = {.lex_state = 176},
  [1810] = {.lex_state = 176},
  [1811] = {.lex_state = 176},
  [1812] = {.lex_state = 176},
  [1813] = {.lex_state = 176},
  [1814] = {.lex_state = 239},
  [1815] = {.lex_state = 239},
  [1816] = {.lex_state = 239},
  [1817] = {.lex_state = 239},
  [1818] = {.lex_state = 239},
  [1819] = {.lex_state = 239},
  [1820] = {.lex_state = 225},
  [1821] = {.lex_state = 239},
  [1822] = {.lex_state = 225},
  [1823] = {.lex_state = 225},
  [1824] = {.lex_state = 225},
  [1825] = {.lex_state = 239},
  [1826] = {.lex_state = 225},
  [1827] = {.lex_state = 239},
  [1828] = {.lex_state = 225},
  [1829] = {.lex_state = 225},
  [1830] = {.lex_state = 225},
  [1831] = {.lex_state = 225},
  [1832] = {.lex_state = 225},
  [1833] = {.lex_state = 225},
  [1834] = {.lex_state = 239},
  [1835] = {.lex_state = 239},
  [1836] = {.lex_state = 239},
  [1837] = {.lex_state = 239},
  [1838] = {.lex_state = 239},
  [1839] = {.lex_state = 239},
  [1840] = {.lex_state = 239},
  [1841] = {.lex_state = 239},
  [1842] = {.lex_state = 239},
  [1843] = {.lex_state = 239},
  [1844] = {.lex_state = 239},
  [1845] = {.lex_state = 239},
  [1846] = {.lex_state = 239},
  [1847] = {.lex_state = 239},
  [1848] = {.lex_state = 239},
  [1849] = {.lex_state = 239},
  [1850] = {.lex_state = 239},
  [1851] = {.lex_state = 239},
  [1852] = {.lex_state = 239},
  [1853] = {.lex_state = 239},
  [1854] = {.lex_state = 239},
  [1855] = {.lex_state = 239},
  [1856] = {.lex_state = 239},
  [1857] = {.lex_state = 239},
  [1858] = {.lex_state = 239},
  [1859] = {.lex_state = 239},
  [1860] = {.lex_state = 239},
  [1861] = {.lex_state = 239},
  [1862] = {.lex_state = 239},
  [1863] = {.lex_state = 239},
  [1864] = {.lex_state = 239},
  [1865] = {.lex_state = 239},
  [1866] = {.lex_state = 239},
  [1867] = {.lex_state = 239},
  [1868] = {.lex_state = 239},
  [1869] = {.lex_state = 239},
  [1870] = {.lex_state = 239},
  [1871] = {.lex_state = 239},
  [1872] = {.lex_state = 239},
  [1873] = {.lex_state = 239},
  [1874] = {.lex_state = 239},
  [1875] = {.lex_state = 239},
  [1876] = {.lex_state = 239},
  [1877] = {.lex_state = 239},
  [1878] = {.lex_state = 239},
  [1879] = {.lex_state = 239},
  [1880] = {.lex_state = 239},
  [1881] = {.lex_state = 239},
  [1882] = {.lex_state = 239},
  [1883] = {.lex_state = 239},
  [1884] = {.lex_state = 239},
  [1885] = {.lex_state = 239},
  [1886] = {.lex_state = 239},
  [1887] = {.lex_state = 239},
  [1888] = {.lex_state = 239},
  [1889] = {.lex_state = 239},
  [1890] = {.lex_state = 239},
  [1891] = {.lex_state = 239},
  [1892] = {.lex_state = 239},
  [1893] = {.lex_state = 239},
  [1894] = {.lex_state = 239},
  [1895] = {.lex_state = 239},
  [1896] = {.lex_state = 239},
  [1897] = {.lex_state = 239},
  [1898] = {.lex_state = 239},
  [1899] = {.lex_state = 239},
  [1900] = {.lex_state = 239},
  [1901] = {.lex_state = 239},
  [1902] = {.lex_state = 239},
  [1903] = {.lex_state = 239},
  [1904] = {.lex_state = 239},
  [1905] = {.lex_state = 239},
  [1906] = {.lex_state = 239},
  [1907] = {.lex_state = 239},
  [1908] = {.lex_state = 239},
  [1909] = {.lex_state = 239},
  [1910] = {.lex_state = 239},
  [1911] = {.lex_state = 239},
  [1912] = {.lex_state = 239},
  [1913] = {.lex_state = 239},
  [1914] = {.lex_state = 239},
  [1915] = {.lex_state = 239},
  [1916] = {.lex_state = 239},
  [1917] = {.lex_state = 239},
  [1918] = {.lex_state = 239},
  [1919] = {.lex_state = 239},
  [1920] = {.lex_state = 239},
  [1921] = {.lex_state = 239},
  [1922] = {.lex_state = 239},
  [1923] = {.lex_state = 239},
  [1924] = {.lex_state = 239},
  [1925] = {.lex_state = 239},
  [1926] = {.lex_state = 239},
  [1927] = {.lex_state = 239},
  [1928] = {.lex_state = 239},
  [1929] = {.lex_state = 239},
  [1930] = {.lex_state = 239},
  [1931] = {.lex_state = 239},
  [1932] = {.lex_state = 239},
  [1933] = {.lex_state = 239},
  [1934] = {.lex_state = 239},
  [1935] = {.lex_state = 239},
  [1936] = {.lex_state = 240},
  [1937] = {.lex_state = 239},
  [1938] = {.lex_state = 239},
  [1939] = {.lex_state = 195},
  [1940] = {.lex_state = 239},
  [1941] = {.lex_state = 239},
  [1942] = {.lex_state = 239},
  [1943] = {.lex_state = 239},
  [1944] = {.lex_state = 239},
  [1945] = {.lex_state = 239},
  [1946] = {.lex_state = 239},
  [1947] = {.lex_state = 239},
  [1948] = {.lex_state = 195},
  [1949] = {.lex_state = 239},
  [1950] = {.lex_state = 239},
  [1951] = {.lex_state = 239},
  [1952] = {.lex_state = 239},
  [1953] = {.lex_state = 239},
  [1954] = {.lex_state = 239},
  [1955] = {.lex_state = 239},
  [1956] = {.lex_state = 239},
  [1957] = {.lex_state = 239},
  [1958] = {.lex_state = 239},
  [1959] = {.lex_state = 195},
  [1960] = {.lex_state = 239},
  [1961] = {.lex_state = 239},
  [1962] = {.lex_state = 239},
  [1963] = {.lex_state = 239},
  [1964] = {.lex_state = 239},
  [1965] = {.lex_state = 239},
  [1966] = {.lex_state = 240},
  [1967] = {.lex_state = 239},
  [1968] = {.lex_state = 239},
  [1969] = {.lex_state = 240},
  [1970] = {.lex_state = 239},
  [1971] = {.lex_state = 239},
  [1972] = {.lex_state = 239},
  [1973] = {.lex_state = 239},
  [1974] = {.lex_state = 240},
  [1975] = {.lex_state = 195},
  [1976] = {.lex_state = 239},
  [1977] = {.lex_state = 184},
  [1978] = {.lex_state = 239},
  [1979] = {.lex_state = 239},
  [1980] = {.lex_state = 240},
  [1981] = {.lex_state = 195},
  [1982] = {.lex_state = 240},
  [1983] = {.lex_state = 195},
  [1984] = {.lex_state = 239},
  [1985] = {.lex_state = 195},
  [1986] = {.lex_state = 240},
  [1987] = {.lex_state = 239},
  [1988] = {.lex_state = 239},
  [1989] = {.lex_state = 185},
  [1990] = {.lex_state = 195},
  [1991] = {.lex_state = 195},
  [1992] = {.lex_state = 240},
  [1993] = {.lex_state = 240},
  [1994] = {.lex_state = 240},
  [1995] = {.lex_state = 195},
  [1996] = {.lex_state = 195},
  [1997] = {.lex_state = 195},
  [1998] = {.lex_state = 240},
  [1999] = {.lex_state = 195},
  [2000] = {.lex_state = 240},
  [2001] = {.lex_state = 240},
  [2002] = {.lex_state = 195},
  [2003] = {.lex_state = 240},
  [2004] = {.lex_state = 195},
  [2005] = {.lex_state = 240},
  [2006] = {.lex_state = 240},
  [2007] = {.lex_state = 240},
  [2008] = {.lex_state = 195},
  [2009] = {.lex_state = 240},
  [2010] = {.lex_state = 195},
  [2011] = {.lex_state = 195},
  [2012] = {.lex_state = 240},
  [2013] = {.lex_state = 240},
  [2014] = {.lex_state = 195},
  [2015] = {.lex_state = 195},
  [2016] = {.lex_state = 195},
  [2017] = {.lex_state = 195},
  [2018] = {.lex_state = 195},
  [2019] = {.lex_state = 240},
  [2020] = {.lex_state = 240},
  [2021] = {.lex_state = 240},
  [2022] = {.lex_state = 195},
  [2023] = {.lex_state = 195},
  [2024] = {.lex_state = 195},
  [2025] = {.lex_state = 240},
  [2026] = {.lex_state = 240},
  [2027] = {.lex_state = 240},
  [2028] = {.lex_state = 240},
  [2029] = {.lex_state = 240},
  [2030] = {.lex_state = 240},
  [2031] = {.lex_state = 240},
  [2032] = {.lex_state = 240},
  [2033] = {.lex_state = 240},
  [2034] = {.lex_state = 240},
  [2035] = {.lex_state = 240},
  [2036] = {.lex_state = 240},
  [2037] = {.lex_state = 240},
  [2038] = {.lex_state = 240},
  [2039] = {.lex_state = 195},
  [2040] = {.lex_state = 240},
  [2041] = {.lex_state = 240},
  [2042] = {.lex_state = 195},
  [2043] = {.lex_state = 240},
  [2044] = {.lex_state = 240},
  [2045] = {.lex_state = 195},
  [2046] = {.lex_state = 195},
  [2047] = {.lex_state = 195},
  [2048] = {.lex_state = 195},
  [2049] = {.lex_state = 240},
  [2050] = {.lex_state = 240},
  [2051] = {.lex_state = 195},
  [2052] = {.lex_state = 195},
  [2053] = {.lex_state = 195},
  [2054] = {.lex_state = 195},
  [2055] = {.lex_state = 195},
  [2056] = {.lex_state = 240},
  [2057] = {.lex_state = 240},
  [2058] = {.lex_state = 195},
  [2059] = {.lex_state = 240},
  [2060] = {.lex_state = 240},
  [2061] = {.lex_state = 195},
  [2062] = {.lex_state = 240},
  [2063] = {.lex_state = 240},
  [2064] = {.lex_state = 240},
  [2065] = {.lex_state = 240},
  [2066] = {.lex_state = 195},
  [2067] = {.lex_state = 195},
  [2068] = {.lex_state = 195},
  [2069] = {.lex_state = 240},
  [2070] = {.lex_state = 195},
  [2071] = {.lex_state = 240},
  [2072] = {.lex_state = 240},
  [2073] = {.lex_state = 240},
  [2074] = {.lex_state = 195},
  [2075] = {.lex_state = 195},
  [2076] = {.lex_state = 195},
  [2077] = {.lex_state = 240},
  [2078] = {.lex_state = 240},
  [2079] = {.lex_state = 195},
  [2080] = {.lex_state = 240},
  [2081] = {.lex_state = 195},
  [2082] = {.lex_state = 195},
  [2083] = {.lex_state = 240},
  [2084] = {.lex_state = 240},
  [2085] = {.lex_state = 240},
  [2086] = {.lex_state = 195},
  [2087] = {.lex_state = 195},
  [2088] = {.lex_state = 195},
  [2089] = {.lex_state = 195},
  [2090] = {.lex_state = 195},
  [2091] = {.lex_state = 240},
  [2092] = {.lex_state = 195},
  [2093] = {.lex_state = 195},
  [2094] = {.lex_state = 195},
  [2095] = {.lex_state = 195},
  [2096] = {.lex_state = 195},
  [2097] = {.lex_state = 240},
  [2098] = {.lex_state = 240},
  [2099] = {.lex_state = 240},
  [2100] = {.lex_state = 240},
  [2101] = {.lex_state = 240},
  [2102] = {.lex_state = 240},
  [2103] = {.lex_state = 240},
  [2104] = {.lex_state = 195},
  [2105] = {.lex_state = 195},
  [2106] = {.lex_state = 195},
  [2107] = {.lex_state = 195},
  [2108] = {.lex_state = 195},
  [2109] = {.lex_state = 240},
  [2110] = {.lex_state = 189},
  [2111] = {.lex_state = 195},
  [2112] = {.lex_state = 195},
  [2113] = {.lex_state = 240},
  [2114] = {.lex_state = 240},
  [2115] = {.lex_state = 240},
  [2116] = {.lex_state = 195},
  [2117] = {.lex_state = 240},
  [2118] = {.lex_state = 240},
  [2119] = {.lex_state = 195},
  [2120] = {.lex_state = 195},
  [2121] = {.lex_state = 195},
  [2122] = {.lex_state = 240},
  [2123] = {.lex_state = 240},
  [2124] = {.lex_state = 195},
  [2125] = {.lex_state = 240},
  [2126] = {.lex_state = 240},
  [2127] = {.lex_state = 240},
  [2128] = {.lex_state = 240},
  [2129] = {.lex_state = 240},
  [2130] = {.lex_state = 195},
  [2131] = {.lex_state = 195},
  [2132] = {.lex_state = 195},
  [2133] = {.lex_state = 240},
  [2134] = {.lex_state = 240},
  [2135] = {.lex_state = 240},
  [2136] = {.lex_state = 195},
  [2137] = {.lex_state = 240},
  [2138] = {.lex_state = 240},
  [2139] = {.lex_state = 195},
  [2140] = {.lex_state = 195},
  [2141] = {.lex_state = 195},
  [2142] = {.lex_state = 195},
  [2143] = {.lex_state = 240},
  [2144] = {.lex_state = 240},
  [2145] = {.lex_state = 195},
  [2146] = {.lex_state = 195},
  [2147] = {.lex_state = 240},
  [2148] = {.lex_state = 195},
  [2149] = {.lex_state = 240},
  [2150] = {.lex_state = 240},
  [2151] = {.lex_state = 195},
  [2152] = {.lex_state = 195},
  [2153] = {.lex_state = 195},
  [2154] = {.lex_state = 195},
  [2155] = {.lex_state = 240},
  [2156] = {.lex_state = 195},
  [2157] = {.lex_state = 195},
  [2158] = {.lex_state = 195},
  [2159] = {.lex_state = 240},
  [2160] = {.lex_state = 195},
  [2161] = {.lex_state = 240},
  [2162] = {.lex_state = 240},
  [2163] = {.lex_state = 195},
  [2164] = {.lex_state = 195},
  [2165] = {.lex_state = 195},
  [2166] = {.lex_state = 195},
  [2167] = {.lex_state = 240},
  [2168] = {.lex_state = 195},
  [2169] = {.lex_state = 195},
  [2170] = {.lex_state = 195},
  [2171] = {.lex_state = 195},
  [2172] = {.lex_state = 195},
  [2173] = {.lex_state = 240},
  [2174] = {.lex_state = 240},
  [2175] = {.lex_state = 195},
  [2176] = {.lex_state = 195},
  [2177] = {.lex_state = 195},
  [2178] = {.lex_state = 240},
  [2179] = {.lex_state = 240},
  [2180] = {.lex_state = 195},
  [2181] = {.lex_state = 240},
  [2182] = {.lex_state = 195},
  [2183] = {.lex_state = 195},
  [2184] = {.lex_state = 195},
  [2185] = {.lex_state = 240},
  [2186] = {.lex_state = 240},
  [2187] = {.lex_state = 240},
  [2188] = {.lex_state = 195},
  [2189] = {.lex_state = 240},
  [2190] = {.lex_state = 240},
  [2191] = {.lex_state = 239},
  [2192] = {.lex_state = 239},
  [2193] = {.lex_state = 238},
  [2194] = {.lex_state = 239},
  [2195] = {.lex_state = 238},
  [2196] = {.lex_state = 238},
  [2197] = {.lex_state = 239},
  [2198] = {.lex_state = 239},
  [2199] = {.lex_state = 238},
  [2200] = {.lex_state = 239},
  [2201] = {.lex_state = 239},
  [2202] = {.lex_state = 239},
  [2203] = {.lex_state = 179},
  [2204] = {.lex_state = 238},
  [2205] = {.lex_state = 238},
  [2206] = {.lex_state = 239},
  [2207] = {.lex_state = 239},
  [2208] = {.lex_state = 239},
  [2209] = {.lex_state = 239},
  [2210] = {.lex_state = 239},
  [2211] = {.lex_state = 239},
  [2212] = {.lex_state = 239},
  [2213] = {.lex_state = 239},
  [2214] = {.lex_state = 239},
  [2215] = {.lex_state = 239},
  [2216] = {.lex_state = 238},
  [2217] = {.lex_state = 238},
  [2218] = {.lex_state = 238},
  [2219] = {.lex_state = 239},
  [2220] = {.lex_state = 238},
  [2221] = {.lex_state = 238},
  [2222] = {.lex_state = 238},
  [2223] = {.lex_state = 239},
  [2224] = {.lex_state = 238},
  [2225] = {.lex_state = 239},
  [2226] = {.lex_state = 239},
  [2227] = {.lex_state = 238},
  [2228] = {.lex_state = 238},
  [2229] = {.lex_state = 238},
  [2230] = {.lex_state = 239},
  [2231] = {.lex_state = 197},
  [2232] = {.lex_state = 238},
  [2233] = {.lex_state = 238},
  [2234] = {.lex_state = 238},
  [2235] = {.lex_state = 197},
  [2236] = {.lex_state = 197},
  [2237] = {.lex_state = 238},
  [2238] = {.lex_state = 239},
  [2239] = {.lex_state = 238},
  [2240] = {.lex_state = 238},
  [2241] = {.lex_state = 238},
  [2242] = {.lex_state = 238},
  [2243] = {.lex_state = 197},
  [2244] = {.lex_state = 197},
  [2245] = {.lex_state = 197},
  [2246] = {.lex_state = 238},
  [2247] = {.lex_state = 238},
  [2248] = {.lex_state = 197},
  [2249] = {.lex_state = 238},
  [2250] = {.lex_state = 238},
  [2251] = {.lex_state = 238},
  [2252] = {.lex_state = 238},
  [2253] = {.lex_state = 238},
  [2254] = {.lex_state = 225},
  [2255] = {.lex_state = 233},
  [2256] = {.lex_state = 225},
  [2257] = {.lex_state = 225},
  [2258] = {.lex_state = 225},
  [2259] = {.lex_state = 225},
  [2260] = {.lex_state = 233},
  [2261] = {.lex_state = 233},
  [2262] = {.lex_state = 238},
  [2263] = {.lex_state = 225},
  [2264] = {.lex_state = 238},
  [2265] = {.lex_state = 225},
  [2266] = {.lex_state = 233},
  [2267] = {.lex_state = 239},
  [2268] = {.lex_state = 238},
  [2269] = {.lex_state = 238},
  [2270] = {.lex_state = 238},
  [2271] = {.lex_state = 238},
  [2272] = {.lex_state = 238},
  [2273] = {.lex_state = 238},
  [2274] = {.lex_state = 238},
  [2275] = {.lex_state = 238},
  [2276] = {.lex_state = 238},
  [2277] = {.lex_state = 238},
  [2278] = {.lex_state = 238},
  [2279] = {.lex_state = 238},
  [2280] = {.lex_state = 238},
  [2281] = {.lex_state = 238},
  [2282] = {.lex_state = 238},
  [2283] = {.lex_state = 238},
  [2284] = {.lex_state = 238},
  [2285] = {.lex_state = 238},
  [2286] = {.lex_state = 238},
  [2287] = {.lex_state = 238},
  [2288] = {.lex_state = 238},
  [2289] = {.lex_state = 238},
  [2290] = {.lex_state = 238},
  [2291] = {.lex_state = 238},
  [2292] = {.lex_state = 238},
  [2293] = {.lex_state = 238},
  [2294] = {.lex_state = 238},
  [2295] = {.lex_state = 238},
  [2296] = {.lex_state = 238},
  [2297] = {.lex_state = 238},
  [2298] = {.lex_state = 238},
  [2299] = {.lex_state = 238},
  [2300] = {.lex_state = 238},
  [2301] = {.lex_state = 238},
  [2302] = {.lex_state = 238},
  [2303] = {.lex_state = 238},
  [2304] = {.lex_state = 238},
  [2305] = {.lex_state = 238},
  [2306] = {.lex_state = 238},
  [2307] = {.lex_state = 238},
  [2308] = {.lex_state = 225},
  [2309] = {.lex_state = 225},
  [2310] = {.lex_state = 225},
  [2311] = {.lex_state = 225},
  [2312] = {.lex_state = 225},
  [2313] = {.lex_state = 225},
  [2314] = {.lex_state = 225},
  [2315] = {.lex_state = 238},
  [2316] = {.lex_state = 238},
  [2317] = {.lex_state = 238},
  [2318] = {.lex_state = 238},
  [2319] = {.lex_state = 238},
  [2320] = {.lex_state = 238},
  [2321] = {.lex_state = 238},
  [2322] = {.lex_state = 238},
  [2323] = {.lex_state = 238},
  [2324] = {.lex_state = 238},
  [2325] = {.lex_state = 238},
  [2326] = {.lex_state = 238},
  [2327] = {.lex_state = 238},
  [2328] = {.lex_state = 238},
  [2329] = {.lex_state = 238},
  [2330] = {.lex_state = 238},
  [2331] = {.lex_state = 238},
  [2332] = {.lex_state = 238},
  [2333] = {.lex_state = 179},
  [2334] = {.lex_state = 238},
  [2335] = {.lex_state = 238},
  [2336] = {.lex_state = 238},
  [2337] = {.lex_state = 238},
  [2338] = {.lex_state = 239},
  [2339] = {.lex_state = 239},
  [2340] = {.lex_state = 239},
  [2341] = {.lex_state = 225},
  [2342] = {.lex_state = 173},
  [2343] = {.lex_state = 181},
  [2344] = {.lex_state = 181},
  [2345] = {.lex_state = 181},
  [2346] = {.lex_state = 239},
  [2347] = {.lex_state = 239},
  [2348] = {.lex_state = 239},
  [2349] = {.lex_state = 239},
  [2350] = {.lex_state = 239},
  [2351] = {.lex_state = 173},
  [2352] = {.lex_state = 238},
  [2353] = {.lex_state = 239},
  [2354] = {.lex_state = 239},
  [2355] = {.lex_state = 225},
  [2356] = {.lex_state = 239},
  [2357] = {.lex_state = 238},
  [2358] = {.lex_state = 209},
  [2359] = {.lex_state = 238},
  [2360] = {.lex_state = 239},
  [2361] = {.lex_state = 239},
  [2362] = {.lex_state = 239},
  [2363] = {.lex_state = 242},
  [2364] = {.lex_state = 239},
  [2365] = {.lex_state = 209},
  [2366] = {.lex_state = 209},
  [2367] = {.lex_state = 209},
  [2368] = {.lex_state = 239},
  [2369] = {.lex_state = 239},
  [2370] = {.lex_state = 225},
  [2371] = {.lex_state = 209},
  [2372] = {.lex_state = 238},
  [2373] = {.lex_state = 239},
  [2374] = {.lex_state = 205},
  [2375] = {.lex_state = 209},
  [2376] = {.lex_state = 209},
  [2377] = {.lex_state = 238},
  [2378] = {.lex_state = 238},
  [2379] = {.lex_state = 239},
  [2380] = {.lex_state = 239},
  [2381] = {.lex_state = 216},
  [2382] = {.lex_state = 216},
  [2383] = {.lex_state = 216},
  [2384] = {.lex_state = 216},
  [2385] = {.lex_state = 216},
  [2386] = {.lex_state = 238},
  [2387] = {.lex_state = 216},
  [2388] = {.lex_state = 216},
  [2389] = {.lex_state = 238},
  [2390] = {.lex_state = 226},
  [2391] = {.lex_state = 181},
  [2392] = {.lex_state = 238},
  [2393] = {.lex_state = 181},
  [2394] = {.lex_state = 181},
  [2395] = {.lex_state = 238},
  [2396] = {.lex_state = 194},
  [2397] = {.lex_state = 238},
  [2398] = {.lex_state = 238},
  [2399] = {.lex_state = 176},
  [2400] = {.lex_state = 238},
  [2401] = {.lex_state = 238},
  [2402] = {.lex_state = 238},
  [2403] = {.lex_state = 181},
  [2404] = {.lex_state = 194},
  [2405] = {.lex_state = 205},
  [2406] = {.lex_state = 179},
  [2407] = {.lex_state = 239},
  [2408] = {.lex_state = 199},
  [2409] = {.lex_state = 238},
  [2410] = {.lex_state = 239},
  [2411] = {.lex_state = 209},
  [2412] = {.lex_state = 200},
  [2413] = {.lex_state = 238},
  [2414] = {.lex_state = 226},
  [2415] = {.lex_state = 209},
  [2416] = {.lex_state = 226},
  [2417] = {.lex_state = 205},
  [2418] = {.lex_state = 239},
  [2419] = {.lex_state = 226},
  [2420] = {.lex_state = 226},
  [2421] = {.lex_state = 226},
  [2422] = {.lex_state = 226},
  [2423] = {.lex_state = 226},
  [2424] = {.lex_state = 226},
  [2425] = {.lex_state = 216},
  [2426] = {.lex_state = 226},
  [2427] = {.lex_state = 226},
  [2428] = {.lex_state = 226},
  [2429] = {.lex_state = 226},
  [2430] = {.lex_state = 226},
  [2431] = {.lex_state = 225},
  [2432] = {.lex_state = 225},
  [2433] = {.lex_state = 225},
  [2434] = {.lex_state = 205},
  [2435] = {.lex_state = 176},
  [2436] = {.lex_state = 216},
  [2437] = {.lex_state = 205},
  [2438] = {.lex_state = 205},
  [2439] = {.lex_state = 205},
  [2440] = {.lex_state = 205},
  [2441] = {.lex_state = 238},
  [2442] = {.lex_state = 205},
  [2443] = {.lex_state = 205},
  [2444] = {.lex_state = 181},
  [2445] = {.lex_state = 205},
  [2446] = {.lex_state = 205},
  [2447] = {.lex_state = 205},
  [2448] = {.lex_state = 205},
  [2449] = {.lex_state = 181},
  [2450] = {.lex_state = 205},
  [2451] = {.lex_state = 205},
  [2452] = {.lex_state = 205},
  [2453] = {.lex_state = 205},
  [2454] = {.lex_state = 205},
  [2455] = {.lex_state = 205},
  [2456] = {.lex_state = 205},
  [2457] = {.lex_state = 205},
  [2458] = {.lex_state = 238},
  [2459] = {.lex_state = 205},
  [2460] = {.lex_state = 205},
  [2461] = {.lex_state = 205},
  [2462] = {.lex_state = 205},
  [2463] = {.lex_state = 205},
  [2464] = {.lex_state = 197},
  [2465] = {.lex_state = 205},
  [2466] = {.lex_state = 242},
  [2467] = {.lex_state = 205},
  [2468] = {.lex_state = 205},
  [2469] = {.lex_state = 197},
  [2470] = {.lex_state = 200},
  [2471] = {.lex_state = 205},
  [2472] = {.lex_state = 176},
  [2473] = {.lex_state = 200},
  [2474] = {.lex_state = 205},
  [2475] = {.lex_state = 205},
  [2476] = {.lex_state = 205},
  [2477] = {.lex_state = 205},
  [2478] = {.lex_state = 205},
  [2479] = {.lex_state = 205},
  [2480] = {.lex_state = 205},
  [2481] = {.lex_state = 205},
  [2482] = {.lex_state = 205},
  [2483] = {.lex_state = 205},
  [2484] = {.lex_state = 205},
  [2485] = {.lex_state = 205},
  [2486] = {.lex_state = 197},
  [2487] = {.lex_state = 200},
  [2488] = {.lex_state = 200},
  [2489] = {.lex_state = 197},
  [2490] = {.lex_state = 179},
  [2491] = {.lex_state = 188},
  [2492] = {.lex_state = 181},
  [2493] = {.lex_state = 197},
  [2494] = {.lex_state = 188},
  [2495] = {.lex_state = 197},
  [2496] = {.lex_state = 197},
  [2497] = {.lex_state = 181},
  [2498] = {.lex_state = 197},
  [2499] = {.lex_state = 241},
  [2500] = {.lex_state = 179},
  [2501] = {.lex_state = 206},
  [2502] = {.lex_state = 197},
  [2503] = {.lex_state = 241},
  [2504] = {.lex_state = 184},
  [2505] = {.lex_state = 179},
  [2506] = {.lex_state = 184},
  [2507] = {.lex_state = 188},
  [2508] = {.lex_state = 200},
  [2509] = {.lex_state = 187},
  [2510] = {.lex_state = 181},
  [2511] = {.lex_state = 187},
  [2512] = {.lex_state = 185},
  [2513] = {.lex_state = 206},
  [2514] = {.lex_state = 187},
  [2515] = {.lex_state = 185},
  [2516] = {.lex_state = 206},
  [2517] = {.lex_state = 179},
  [2518] = {.lex_state = 179},
  [2519] = {.lex_state = 206},
  [2520] = {.lex_state = 206},
  [2521] = {.lex_state = 181},
  [2522] = {.lex_state = 179},
  [2523] = {.lex_state = 197},
  [2524] = {.lex_state = 200},
  [2525] = {.lex_state = 179},
  [2526] = {.lex_state = 179},
  [2527] = {.lex_state = 181},
  [2528] = {.lex_state = 206},
  [2529] = {.lex_state = 200},
  [2530] = {.lex_state = 179},
  [2531] = {.lex_state = 179},
  [2532] = {.lex_state = 179},
  [2533] = {.lex_state = 206},
  [2534] = {.lex_state = 179},
  [2535] = {.lex_state = 206},
  [2536] = {.lex_state = 206},
  [2537] = {.lex_state = 198},
  [2538] = {.lex_state = 181},
  [2539] = {.lex_state = 191},
  [2540] = {.lex_state = 198},
  [2541] = {.lex_state = 198},
  [2542] = {.lex_state = 239},
  [2543] = {.lex_state = 241},
  [2544] = {.lex_state = 197},
  [2545] = {.lex_state = 199},
  [2546] = {.lex_state = 197},
  [2547] = {.lex_state = 229},
  [2548] = {.lex_state = 197},
  [2549] = {.lex_state = 197},
  [2550] = {.lex_state = 189},
  [2551] = {.lex_state = 198},
  [2552] = {.lex_state = 200},
  [2553] = {.lex_state = 200},
  [2554] = {.lex_state = 199},
  [2555] = {.lex_state = 189},
  [2556] = {.lex_state = 241},
  [2557] = {.lex_state = 199},
  [2558] = {.lex_state = 181},
  [2559] = {.lex_state = 200},
  [2560] = {.lex_state = 191},
  [2561] = {.lex_state = 191},
  [2562] = {.lex_state = 200},
  [2563] = {.lex_state = 200},
  [2564] = {.lex_state = 200},
  [2565] = {.lex_state = 181},
  [2566] = {.lex_state = 179},
  [2567] = {.lex_state = 179},
  [2568] = {.lex_state = 200},
  [2569] = {.lex_state = 200},
  [2570] = {.lex_state = 241},
  [2571] = {.lex_state = 229},
  [2572] = {.lex_state = 200},
  [2573] = {.lex_state = 197},
  [2574] = {.lex_state = 241},
  [2575] = {.lex_state = 198},
  [2576] = {.lex_state = 181},
  [2577] = {.lex_state = 238},
  [2578] = {.lex_state = 200},
  [2579] = {.lex_state = 200},
  [2580] = {.lex_state = 200},
  [2581] = {.lex_state = 229},
  [2582] = {.lex_state = 199},
  [2583] = {.lex_state = 200},
  [2584] = {.lex_state = 239},
  [2585] = {.lex_state = 206},
  [2586] = {.lex_state = 200},
  [2587] = {.lex_state = 197},
  [2588] = {.lex_state = 198},
  [2589] = {.lex_state = 200},
  [2590] = {.lex_state = 200},
  [2591] = {.lex_state = 200},
  [2592] = {.lex_state = 200},
  [2593] = {.lex_state = 200},
  [2594] = {.lex_state = 200},
  [2595] = {.lex_state = 200},
  [2596] = {.lex_state = 200},
  [2597] = {.lex_state = 242},
  [2598] = {.lex_state = 200},
  [2599] = {.lex_state = 242},
  [2600] = {.lex_state = 200},
  [2601] = {.lex_state = 200},
  [2602] = {.lex_state = 200},
  [2603] = {.lex_state = 200},
  [2604] = {.lex_state = 200},
  [2605] = {.lex_state = 200},
  [2606] = {.lex_state = 239},
  [2607] = {.lex_state = 200},
  [2608] = {.lex_state = 200},
  [2609] = {.lex_state = 239},
  [2610] = {.lex_state = 200},
  [2611] = {.lex_state = 200},
  [2612] = {.lex_state = 200},
  [2613] = {.lex_state = 200},
  [2614] = {.lex_state = 187},
  [2615] = {.lex_state = 200},
  [2616] = {.lex_state = 200},
  [2617] = {.lex_state = 200},
  [2618] = {.lex_state = 239},
  [2619] = {.lex_state = 200},
  [2620] = {.lex_state = 198},
  [2621] = {.lex_state = 198},
  [2622] = {.lex_state = 198},
  [2623] = {.lex_state = 197},
  [2624] = {.lex_state = 198},
  [2625] = {.lex_state = 181},
  [2626] = {.lex_state = 200},
  [2627] = {.lex_state = 198},
  [2628] = {.lex_state = 239},
  [2629] = {.lex_state = 239},
  [2630] = {.lex_state = 197},
  [2631] = {.lex_state = 197},
  [2632] = {.lex_state = 239},
  [2633] = {.lex_state = 200},
  [2634] = {.lex_state = 181},
  [2635] = {.lex_state = 200},
  [2636] = {.lex_state = 200},
  [2637] = {.lex_state = 198},
  [2638] = {.lex_state = 200},
  [2639] = {.lex_state = 198},
  [2640] = {.lex_state = 197},
  [2641] = {.lex_state = 200},
  [2642] = {.lex_state = 198},
  [2643] = {.lex_state = 200},
  [2644] = {.lex_state = 200},
  [2645] = {.lex_state = 197},
  [2646] = {.lex_state = 198},
  [2647] = {.lex_state = 198},
  [2648] = {.lex_state = 197},
  [2649] = {.lex_state = 197},
  [2650] = {.lex_state = 200},
  [2651] = {.lex_state = 200},
  [2652] = {.lex_state = 198},
  [2653] = {.lex_state = 197},
  [2654] = {.lex_state = 200},
  [2655] = {.lex_state = 200},
  [2656] = {.lex_state = 200},
  [2657] = {.lex_state = 200},
  [2658] = {.lex_state = 198},
  [2659] = {.lex_state = 239},
  [2660] = {.lex_state = 200},
  [2661] = {.lex_state = 200},
  [2662] = {.lex_state = 239},
  [2663] = {.lex_state = 200},
  [2664] = {.lex_state = 187},
  [2665] = {.lex_state = 200},
  [2666] = {.lex_state = 230},
  [2667] = {.lex_state = 200},
  [2668] = {.lex_state = 206},
  [2669] = {.lex_state = 230},
  [2670] = {.lex_state = 187},
  [2671] = {.lex_state = 200},
  [2672] = {.lex_state = 200},
  [2673] = {.lex_state = 230},
  [2674] = {.lex_state = 187},
  [2675] = {.lex_state = 200},
  [2676] = {.lex_state = 187},
  [2677] = {.lex_state = 230},
  [2678] = {.lex_state = 197},
  [2679] = {.lex_state = 197},
  [2680] = {.lex_state = 187},
  [2681] = {.lex_state = 181},
  [2682] = {.lex_state = 187},
  [2683] = {.lex_state = 197},
  [2684] = {.lex_state = 200},
  [2685] = {.lex_state = 206},
  [2686] = {.lex_state = 200},
  [2687] = {.lex_state = 197},
  [2688] = {.lex_state = 181},
  [2689] = {.lex_state = 200},
  [2690] = {.lex_state = 187},
  [2691] = {.lex_state = 197},
  [2692] = {.lex_state = 238},
  [2693] = {.lex_state = 181},
  [2694] = {.lex_state = 181},
  [2695] = {.lex_state = 187},
  [2696] = {.lex_state = 200},
  [2697] = {.lex_state = 230},
  [2698] = {.lex_state = 191},
  [2699] = {.lex_state = 191},
  [2700] = {.lex_state = 241},
  [2701] = {.lex_state = 230},
  [2702] = {.lex_state = 230},
  [2703] = {.lex_state = 200},
  [2704] = {.lex_state = 241},
  [2705] = {.lex_state = 200},
  [2706] = {.lex_state = 200},
  [2707] = {.lex_state = 191},
  [2708] = {.lex_state = 200},
  [2709] = {.lex_state = 206},
  [2710] = {.lex_state = 197},
  [2711] = {.lex_state = 200},
  [2712] = {.lex_state = 197},
  [2713] = {.lex_state = 198},
  [2714] = {.lex_state = 181},
  [2715] = {.lex_state = 191},
  [2716] = {.lex_state = 212},
  [2717] = {.lex_state = 209},
  [2718] = {.lex_state = 200},
  [2719] = {.lex_state = 206},
  [2720] = {.lex_state = 206},
  [2721] = {.lex_state = 198},
  [2722] = {.lex_state = 187},
  [2723] = {.lex_state = 197},
  [2724] = {.lex_state = 206},
  [2725] = {.lex_state = 206},
  [2726] = {.lex_state = 225},
  [2727] = {.lex_state = 206},
  [2728] = {.lex_state = 187},
  [2729] = {.lex_state = 206},
  [2730] = {.lex_state = 198},
  [2731] = {.lex_state = 206},
  [2732] = {.lex_state = 200},
  [2733] = {.lex_state = 225},
  [2734] = {.lex_state = 181},
  [2735] = {.lex_state = 206},
  [2736] = {.lex_state = 203},
  [2737] = {.lex_state = 206},
  [2738] = {.lex_state = 230},
  [2739] = {.lex_state = 212},
  [2740] = {.lex_state = 230},
  [2741] = {.lex_state = 206},
  [2742] = {.lex_state = 200},
  [2743] = {.lex_state = 197},
  [2744] = {.lex_state = 191},
  [2745] = {.lex_state = 191},
  [2746] = {.lex_state = 198},
  [2747] = {.lex_state = 187},
  [2748] = {.lex_state = 212},
  [2749] = {.lex_state = 197},
  [2750] = {.lex_state = 200},
  [2751] = {.lex_state = 206},
  [2752] = {.lex_state = 225},
  [2753] = {.lex_state = 210},
  [2754] = {.lex_state = 200},
  [2755] = {.lex_state = 200},
  [2756] = {.lex_state = 197},
  [2757] = {.lex_state = 181},
  [2758] = {.lex_state = 181},
  [2759] = {.lex_state = 187},
  [2760] = {.lex_state = 197},
  [2761] = {.lex_state = 198},
  [2762] = {.lex_state = 200},
  [2763] = {.lex_state = 200},
  [2764] = {.lex_state = 200},
  [2765] = {.lex_state = 200},
  [2766] = {.lex_state = 200},
  [2767] = {.lex_state = 191},
  [2768] = {.lex_state = 200},
  [2769] = {.lex_state = 200},
  [2770] = {.lex_state = 200},
  [2771] = {.lex_state = 200},
  [2772] = {.lex_state = 187},
  [2773] = {.lex_state = 200},
  [2774] = {.lex_state = 209},
  [2775] = {.lex_state = 200},
  [2776] = {.lex_state = 200},
  [2777] = {.lex_state = 242},
  [2778] = {.lex_state = 200},
  [2779] = {.lex_state = 200},
  [2780] = {.lex_state = 200},
  [2781] = {.lex_state = 200},
  [2782] = {.lex_state = 200},
  [2783] = {.lex_state = 200},
  [2784] = {.lex_state = 200},
  [2785] = {.lex_state = 220},
  [2786] = {.lex_state = 200},
  [2787] = {.lex_state = 187},
  [2788] = {.lex_state = 200},
  [2789] = {.lex_state = 200},
  [2790] = {.lex_state = 200},
  [2791] = {.lex_state = 200},
  [2792] = {.lex_state = 200},
  [2793] = {.lex_state = 200},
  [2794] = {.lex_state = 200},
  [2795] = {.lex_state = 200},
  [2796] = {.lex_state = 200},
  [2797] = {.lex_state = 200},
  [2798] = {.lex_state = 200},
  [2799] = {.lex_state = 200},
  [2800] = {.lex_state = 217},
  [2801] = {.lex_state = 200},
  [2802] = {.lex_state = 200},
  [2803] = {.lex_state = 200},
  [2804] = {.lex_state = 191},
  [2805] = {.lex_state = 200},
  [2806] = {.lex_state = 200},
  [2807] = {.lex_state = 216},
  [2808] = {.lex_state = 200},
  [2809] = {.lex_state = 200},
  [2810] = {.lex_state = 200},
  [2811] = {.lex_state = 200},
  [2812] = {.lex_state = 200},
  [2813] = {.lex_state = 200},
  [2814] = {.lex_state = 200},
  [2815] = {.lex_state = 200},
  [2816] = {.lex_state = 200},
  [2817] = {.lex_state = 200},
  [2818] = {.lex_state = 200},
  [2819] = {.lex_state = 220},
  [2820] = {.lex_state = 200},
  [2821] = {.lex_state = 200},
  [2822] = {.lex_state = 200},
  [2823] = {.lex_state = 200},
  [2824] = {.lex_state = 200},
  [2825] = {.lex_state = 220},
  [2826] = {.lex_state = 200},
  [2827] = {.lex_state = 200},
  [2828] = {.lex_state = 200},
  [2829] = {.lex_state = 200},
  [2830] = {.lex_state = 200},
  [2831] = {.lex_state = 200},
  [2832] = {.lex_state = 200},
  [2833] = {.lex_state = 200},
  [2834] = {.lex_state = 200},
  [2835] = {.lex_state = 200},
  [2836] = {.lex_state = 200},
  [2837] = {.lex_state = 200},
  [2838] = {.lex_state = 191},
  [2839] = {.lex_state = 200},
  [2840] = {.lex_state = 200},
  [2841] = {.lex_state = 200},
  [2842] = {.lex_state = 200},
  [2843] = {.lex_state = 200},
  [2844] = {.lex_state = 200},
  [2845] = {.lex_state = 200},
  [2846] = {.lex_state = 191},
  [2847] = {.lex_state = 200},
  [2848] = {.lex_state = 200},
  [2849] = {.lex_state = 200},
  [2850] = {.lex_state = 242},
  [2851] = {.lex_state = 225},
  [2852] = {.lex_state = 200},
  [2853] = {.lex_state = 200},
  [2854] = {.lex_state = 200},
  [2855] = {.lex_state = 187},
  [2856] = {.lex_state = 183},
  [2857] = {.lex_state = 209},
  [2858] = {.lex_state = 230},
  [2859] = {.lex_state = 187},
  [2860] = {.lex_state = 209},
  [2861] = {.lex_state = 209},
  [2862] = {.lex_state = 209},
  [2863] = {.lex_state = 216},
  [2864] = {.lex_state = 230},
  [2865] = {.lex_state = 187},
  [2866] = {.lex_state = 209},
  [2867] = {.lex_state = 209},
  [2868] = {.lex_state = 183},
  [2869] = {.lex_state = 187},
  [2870] = {.lex_state = 183},
  [2871] = {.lex_state = 209},
  [2872] = {.lex_state = 209},
  [2873] = {.lex_state = 209},
  [2874] = {.lex_state = 228},
  [2875] = {.lex_state = 228},
  [2876] = {.lex_state = 230},
  [2877] = {.lex_state = 228},
  [2878] = {.lex_state = 228},
  [2879] = {.lex_state = 187},
  [2880] = {.lex_state = 230},
  [2881] = {.lex_state = 228},
  [2882] = {.lex_state = 228},
  [2883] = {.lex_state = 209},
  [2884] = {.lex_state = 209},
  [2885] = {.lex_state = 212},
  [2886] = {.lex_state = 230},
  [2887] = {.lex_state = 230},
  [2888] = {.lex_state = 216},
  [2889] = {.lex_state = 230},
  [2890] = {.lex_state = 228},
  [2891] = {.lex_state = 209},
  [2892] = {.lex_state = 228},
  [2893] = {.lex_state = 228},
  [2894] = {.lex_state = 230},
  [2895] = {.lex_state = 228},
  [2896] = {.lex_state = 216},
  [2897] = {.lex_state = 212},
  [2898] = {.lex_state = 216},
  [2899] = {.lex_state = 216},
  [2900] = {.lex_state = 216},
  [2901] = {.lex_state = 230},
  [2902] = {.lex_state = 209},
  [2903] = {.lex_state = 216},
  [2904] = {.lex_state = 212},
  [2905] = {.lex_state = 230},
  [2906] = {.lex_state = 187},
  [2907] = {.lex_state = 230},
  [2908] = {.lex_state = 210},
  [2909] = {.lex_state = 209},
  [2910] = {.lex_state = 241},
  [2911] = {.lex_state = 230},
  [2912] = {.lex_state = 210},
  [2913] = {.lex_state = 241},
  [2914] = {.lex_state = 230},
  [2915] = {.lex_state = 228},
  [2916] = {.lex_state = 210},
  [2917] = {.lex_state = 187},
  [2918] = {.lex_state = 187},
  [2919] = {.lex_state = 209},
  [2920] = {.lex_state = 209},
  [2921] = {.lex_state = 216},
  [2922] = {.lex_state = 216},
  [2923] = {.lex_state = 228},
  [2924] = {.lex_state = 216},
  [2925] = {.lex_state = 230},
  [2926] = {.lex_state = 209},
  [2927] = {.lex_state = 176},
  [2928] = {.lex_state = 217},
  [2929] = {.lex_state = 228},
  [2930] = {.lex_state = 209},
  [2931] = {.lex_state = 216},
  [2932] = {.lex_state = 210},
  [2933] = {.lex_state = 209},
  [2934] = {.lex_state = 230},
  [2935] = {.lex_state = 230},
  [2936] = {.lex_state = 230},
  [2937] = {.lex_state = 228},
  [2938] = {.lex_state = 216},
  [2939] = {.lex_state = 216},
  [2940] = {.lex_state = 216},
  [2941] = {.lex_state = 230},
  [2942] = {.lex_state = 216},
  [2943] = {.lex_state = 230},
  [2944] = {.lex_state = 230},
  [2945] = {.lex_state = 176},
  [2946] = {.lex_state = 230},
  [2947] = {.lex_state = 216},
  [2948] = {.lex_state = 217},
  [2949] = {.lex_state = 209},
  [2950] = {.lex_state = 209},
  [2951] = {.lex_state = 230},
  [2952] = {.lex_state = 241},
  [2953] = {.lex_state = 230},
  [2954] = {.lex_state = 197},
  [2955] = {.lex_state = 209},
  [2956] = {.lex_state = 197},
  [2957] = {.lex_state = 230},
  [2958] = {.lex_state = 197},
  [2959] = {.lex_state = 230},
  [2960] = {.lex_state = 230},
  [2961] = {.lex_state = 217},
  [2962] = {.lex_state = 230},
  [2963] = {.lex_state = 230},
  [2964] = {.lex_state = 209},
  [2965] = {.lex_state = 230},
  [2966] = {.lex_state = 197},
  [2967] = {.lex_state = 197},
  [2968] = {.lex_state = 209},
  [2969] = {.lex_state = 209},
  [2970] = {.lex_state = 241},
  [2971] = {.lex_state = 230},
  [2972] = {.lex_state = 230},
  [2973] = {.lex_state = 216},
  [2974] = {.lex_state = 230},
  [2975] = {.lex_state = 209},
  [2976] = {.lex_state = 216},
  [2977] = {.lex_state = 230},
  [2978] = {.lex_state = 241},
  [2979] = {.lex_state = 183},
  [2980] = {.lex_state = 230},
  [2981] = {.lex_state = 230},
  [2982] = {.lex_state = 209},
  [2983] = {.lex_state = 230},
  [2984] = {.lex_state = 230},
  [2985] = {.lex_state = 241},
  [2986] = {.lex_state = 197},
  [2987] = {.lex_state = 197},
  [2988] = {.lex_state = 209},
  [2989] = {.lex_state = 230},
  [2990] = {.lex_state = 183},
  [2991] = {.lex_state = 230},
  [2992] = {.lex_state = 230},
  [2993] = {.lex_state = 209},
  [2994] = {.lex_state = 230},
  [2995] = {.lex_state = 183},
  [2996] = {.lex_state = 209},
  [2997] = {.lex_state = 230},
  [2998] = {.lex_state = 230},
  [2999] = {.lex_state = 230},
  [3000] = {.lex_state = 197},
  [3001] = {.lex_state = 230},
  [3002] = {.lex_state = 216},
  [3003] = {.lex_state = 230},
  [3004] = {.lex_state = 183},
  [3005] = {.lex_state = 197},
  [3006] = {.lex_state = 230},
  [3007] = {.lex_state = 197},
  [3008] = {.lex_state = 230},
  [3009] = {.lex_state = 230},
  [3010] = {.lex_state = 230},
  [3011] = {.lex_state = 230},
  [3012] = {.lex_state = 230},
  [3013] = {.lex_state = 197},
  [3014] = {.lex_state = 230},
  [3015] = {.lex_state = 197},
  [3016] = {.lex_state = 197},
  [3017] = {.lex_state = 197},
  [3018] = {.lex_state = 197},
  [3019] = {.lex_state = 209},
  [3020] = {.lex_state = 209},
  [3021] = {.lex_state = 197},
  [3022] = {.lex_state = 230},
  [3023] = {.lex_state = 216},
  [3024] = {.lex_state = 230},
  [3025] = {.lex_state = 197},
  [3026] = {.lex_state = 209},
  [3027] = {.lex_state = 176},
  [3028] = {.lex_state = 209},
  [3029] = {.lex_state = 176},
  [3030] = {.lex_state = 209},
  [3031] = {.lex_state = 209},
  [3032] = {.lex_state = 176},
  [3033] = {.lex_state = 176},
  [3034] = {.lex_state = 210},
  [3035] = {.lex_state = 196},
  [3036] = {.lex_state = 209},
  [3037] = {.lex_state = 176},
  [3038] = {.lex_state = 209},
  [3039] = {.lex_state = 209},
  [3040] = {.lex_state = 209},
  [3041] = {.lex_state = 176},
  [3042] = {.lex_state = 209},
  [3043] = {.lex_state = 209},
  [3044] = {.lex_state = 209},
  [3045] = {.lex_state = 176},
  [3046] = {.lex_state = 227},
  [3047] = {.lex_state = 176},
  [3048] = {.lex_state = 216},
  [3049] = {.lex_state = 209},
  [3050] = {.lex_state = 227},
  [3051] = {.lex_state = 209},
  [3052] = {.lex_state = 209},
  [3053] = {.lex_state = 209},
  [3054] = {.lex_state = 209},
  [3055] = {.lex_state = 209},
  [3056] = {.lex_state = 198},
  [3057] = {.lex_state = 227},
  [3058] = {.lex_state = 176},
  [3059] = {.lex_state = 201},
  [3060] = {.lex_state = 176},
  [3061] = {.lex_state = 201},
  [3062] = {.lex_state = 176},
  [3063] = {.lex_state = 198},
  [3064] = {.lex_state = 198},
  [3065] = {.lex_state = 198},
  [3066] = {.lex_state = 209},
  [3067] = {.lex_state = 209},
  [3068] = {.lex_state = 209},
  [3069] = {.lex_state = 176},
  [3070] = {.lex_state = 209},
  [3071] = {.lex_state = 209},
  [3072] = {.lex_state = 198},
  [3073] = {.lex_state = 209},
  [3074] = {.lex_state = 176},
  [3075] = {.lex_state = 176},
  [3076] = {.lex_state = 198},
  [3077] = {.lex_state = 176},
  [3078] = {.lex_state = 198},
  [3079] = {.lex_state = 209},
  [3080] = {.lex_state = 210},
  [3081] = {.lex_state = 201},
  [3082] = {.lex_state = 227},
  [3083] = {.lex_state = 209},
  [3084] = {.lex_state = 176},
  [3085] = {.lex_state = 216},
  [3086] = {.lex_state = 176},
  [3087] = {.lex_state = 176},
  [3088] = {.lex_state = 176},
  [3089] = {.lex_state = 176},
  [3090] = {.lex_state = 216},
  [3091] = {.lex_state = 194},
  [3092] = {.lex_state = 194},
  [3093] = {.lex_state = 201},
  [3094] = {.lex_state = 197},
  [3095] = {.lex_state = 216},
  [3096] = {.lex_state = 216},
  [3097] = {.lex_state = 209},
  [3098] = {.lex_state = 216},
  [3099] = {.lex_state = 197},
  [3100] = {.lex_state = 241},
  [3101] = {.lex_state = 241},
  [3102] = {.lex_state = 210},
  [3103] = {.lex_state = 216},
  [3104] = {.lex_state = 209},
  [3105] = {.lex_state = 216},
  [3106] = {.lex_state = 197},
  [3107] = {.lex_state = 209},
  [3108] = {.lex_state = 209},
  [3109] = {.lex_state = 197},
  [3110] = {.lex_state = 197},
  [3111] = {.lex_state = 197},
  [3112] = {.lex_state = 209},
  [3113] = {.lex_state = 197},
  [3114] = {.lex_state = 197},
  [3115] = {.lex_state = 197},
  [3116] = {.lex_state = 197},
  [3117] = {.lex_state = 197},
  [3118] = {.lex_state = 216},
  [3119] = {.lex_state = 197},
  [3120] = {.lex_state = 201},
  [3121] = {.lex_state = 209},
  [3122] = {.lex_state = 242},
  [3123] = {.lex_state = 197},
  [3124] = {.lex_state = 242},
  [3125] = {.lex_state = 209},
  [3126] = {.lex_state = 197},
  [3127] = {.lex_state = 194},
  [3128] = {.lex_state = 194},
  [3129] = {.lex_state = 197},
  [3130] = {.lex_state = 194},
  [3131] = {.lex_state = 197},
  [3132] = {.lex_state = 216},
  [3133] = {.lex_state = 209},
  [3134] = {.lex_state = 216},
  [3135] = {.lex_state = 216},
  [3136] = {.lex_state = 209},
  [3137] = {.lex_state = 194},
  [3138] = {.lex_state = 209},
  [3139] = {.lex_state = 197},
  [3140] = {.lex_state = 209},
  [3141] = {.lex_state = 209},
  [3142] = {.lex_state = 209},
  [3143] = {.lex_state = 216},
  [3144] = {.lex_state = 209},
  [3145] = {.lex_state = 209},
  [3146] = {.lex_state = 201},
  [3147] = {.lex_state = 209},
  [3148] = {.lex_state = 196},
  [3149] = {.lex_state = 216},
  [3150] = {.lex_state = 197},
  [3151] = {.lex_state = 209},
  [3152] = {.lex_state = 209},
  [3153] = {.lex_state = 209},
  [3154] = {.lex_state = 170},
  [3155] = {.lex_state = 183},
  [3156] = {.lex_state = 219},
  [3157] = {.lex_state = 241},
  [3158] = {.lex_state = 209},
  [3159] = {.lex_state = 219},
  [3160] = {.lex_state = 209},
  [3161] = {.lex_state = 209},
  [3162] = {.lex_state = 209},
  [3163] = {.lex_state = 209},
  [3164] = {.lex_state = 241},
  [3165] = {.lex_state = 183},
  [3166] = {.lex_state = 241},
  [3167] = {.lex_state = 241},
  [3168] = {.lex_state = 209},
  [3169] = {.lex_state = 170},
  [3170] = {.lex_state = 209},
  [3171] = {.lex_state = 209},
  [3172] = {.lex_state = 209},
  [3173] = {.lex_state = 209},
  [3174] = {.lex_state = 216},
  [3175] = {.lex_state = 209},
  [3176] = {.lex_state = 209},
  [3177] = {.lex_state = 209},
  [3178] = {.lex_state = 241},
  [3179] = {.lex_state = 209},
  [3180] = {.lex_state = 209},
  [3181] = {.lex_state = 241},
  [3182] = {.lex_state = 241},
  [3183] = {.lex_state = 241},
  [3184] = {.lex_state = 209},
  [3185] = {.lex_state = 219},
  [3186] = {.lex_state = 209},
  [3187] = {.lex_state = 209},
  [3188] = {.lex_state = 241},
  [3189] = {.lex_state = 170},
  [3190] = {.lex_state = 241},
  [3191] = {.lex_state = 216},
  [3192] = {.lex_state = 170},
  [3193] = {.lex_state = 241},
  [3194] = {.lex_state = 219},
  [3195] = {.lex_state = 228},
  [3196] = {.lex_state = 241},
  [3197] = {.lex_state = 209},
  [3198] = {.lex_state = 209},
  [3199] = {.lex_state = 209},
  [3200] = {.lex_state = 209},
  [3201] = {.lex_state = 194},
  [3202] = {.lex_state = 216},
  [3203] = {.lex_state = 241},
  [3204] = {.lex_state = 241},
  [3205] = {.lex_state = 209},
  [3206] = {.lex_state = 209},
  [3207] = {.lex_state = 241},
  [3208] = {.lex_state = 209},
  [3209] = {.lex_state = 209},
  [3210] = {.lex_state = 209},
  [3211] = {.lex_state = 194},
  [3212] = {.lex_state = 209},
  [3213] = {.lex_state = 216},
  [3214] = {.lex_state = 216},
  [3215] = {.lex_state = 241},
  [3216] = {.lex_state = 209},
  [3217] = {.lex_state = 216},
  [3218] = {.lex_state = 209},
  [3219] = {.lex_state = 241},
  [3220] = {.lex_state = 241},
  [3221] = {.lex_state = 170},
  [3222] = {.lex_state = 241},
  [3223] = {.lex_state = 216},
  [3224] = {.lex_state = 209},
  [3225] = {.lex_state = 209},
  [3226] = {.lex_state = 209},
  [3227] = {.lex_state = 216},
  [3228] = {.lex_state = 170},
  [3229] = {.lex_state = 209},
  [3230] = {.lex_state = 194},
  [3231] = {.lex_state = 216},
  [3232] = {.lex_state = 209},
  [3233] = {.lex_state = 209},
  [3234] = {.lex_state = 241},
  [3235] = {.lex_state = 209},
  [3236] = {.lex_state = 219},
  [3237] = {.lex_state = 183},
  [3238] = {.lex_state = 197},
  [3239] = {.lex_state = 216},
  [3240] = {.lex_state = 194},
  [3241] = {.lex_state = 219},
  [3242] = {.lex_state = 209},
  [3243] = {.lex_state = 209},
  [3244] = {.lex_state = 209},
  [3245] = {.lex_state = 194},
  [3246] = {.lex_state = 209},
  [3247] = {.lex_state = 216},
  [3248] = {.lex_state = 216},
  [3249] = {.lex_state = 209},
  [3250] = {.lex_state = 204},
  [3251] = {.lex_state = 197},
  [3252] = {.lex_state = 216},
  [3253] = {.lex_state = 216},
  [3254] = {.lex_state = 197},
  [3255] = {.lex_state = 197},
  [3256] = {.lex_state = 197},
  [3257] = {.lex_state = 209},
  [3258] = {.lex_state = 216},
  [3259] = {.lex_state = 216},
  [3260] = {.lex_state = 209},
  [3261] = {.lex_state = 216},
  [3262] = {.lex_state = 209},
  [3263] = {.lex_state = 216},
  [3264] = {.lex_state = 216},
  [3265] = {.lex_state = 216},
  [3266] = {.lex_state = 216},
  [3267] = {.lex_state = 197},
  [3268] = {.lex_state = 209},
  [3269] = {.lex_state = 197},
  [3270] = {.lex_state = 209},
  [3271] = {.lex_state = 197},
  [3272] = {.lex_state = 209},
  [3273] = {.lex_state = 197},
  [3274] = {.lex_state = 197},
  [3275] = {.lex_state = 209},
  [3276] = {.lex_state = 209},
  [3277] = {.lex_state = 209},
  [3278] = {.lex_state = 209},
  [3279] = {.lex_state = 216},
  [3280] = {.lex_state = 209},
  [3281] = {.lex_state = 216},
  [3282] = {.lex_state = 209},
  [3283] = {.lex_state = 216},
  [3284] = {.lex_state = 209},
  [3285] = {.lex_state = 209},
  [3286] = {.lex_state = 197},
  [3287] = {.lex_state = 176},
  [3288] = {.lex_state = 176},
  [3289] = {.lex_state = 218},
  [3290] = {.lex_state = 209},
  [3291] = {.lex_state = 197},
  [3292] = {.lex_state = 216},
  [3293] = {.lex_state = 197},
  [3294] = {.lex_state = 216},
  [3295] = {.lex_state = 197},
  [3296] = {.lex_state = 209},
  [3297] = {.lex_state = 216},
  [3298] = {.lex_state = 216},
  [3299] = {.lex_state = 242},
  [3300] = {.lex_state = 209},
  [3301] = {.lex_state = 216},
  [3302] = {.lex_state = 209},
  [3303] = {.lex_state = 216},
  [3304] = {.lex_state = 216},
  [3305] = {.lex_state = 176},
  [3306] = {.lex_state = 209},
  [3307] = {.lex_state = 209},
  [3308] = {.lex_state = 209},
  [3309] = {.lex_state = 216},
  [3310] = {.lex_state = 216},
  [3311] = {.lex_state = 176},
  [3312] = {.lex_state = 197},
  [3313] = {.lex_state = 216},
  [3314] = {.lex_state = 216},
  [3315] = {.lex_state = 176},
  [3316] = {.lex_state = 209},
  [3317] = {.lex_state = 216},
  [3318] = {.lex_state = 197},
  [3319] = {.lex_state = 197},
  [3320] = {.lex_state = 209},
  [3321] = {.lex_state = 216},
  [3322] = {.lex_state = 196},
  [3323] = {.lex_state = 216},
  [3324] = {.lex_state = 216},
  [3325] = {.lex_state = 183},
  [3326] = {.lex_state = 209},
  [3327] = {.lex_state = 209},
  [3328] = {.lex_state = 216},
  [3329] = {.lex_state = 216},
  [3330] = {.lex_state = 216},
  [3331] = {.lex_state = 176},
  [3332] = {.lex_state = 216},
  [3333] = {.lex_state = 209},
  [3334] = {.lex_state = 209},
  [3335] = {.lex_state = 209},
  [3336] = {.lex_state = 209},
  [3337] = {.lex_state = 196},
  [3338] = {.lex_state = 209},
  [3339] = {.lex_state = 216},
  [3340] = {.lex_state = 209},
  [3341] = {.lex_state = 216},
  [3342] = {.lex_state = 216},
  [3343] = {.lex_state = 219},
  [3344] = {.lex_state = 209},
  [3345] = {.lex_state = 211},
  [3346] = {.lex_state = 242},
  [3347] = {.lex_state = 216},
  [3348] = {.lex_state = 209},
  [3349] = {.lex_state = 209},
  [3350] = {.lex_state = 209},
  [3351] = {.lex_state = 209},
  [3352] = {.lex_state = 194},
  [3353] = {.lex_state = 194},
  [3354] = {.lex_state = 242},
  [3355] = {.lex_state = 196},
  [3356] = {.lex_state = 216},
  [3357] = {.lex_state = 216},
  [3358] = {.lex_state = 216},
  [3359] = {.lex_state = 201},
  [3360] = {.lex_state = 201},
  [3361] = {.lex_state = 183},
  [3362] = {.lex_state = 206},
  [3363] = {.lex_state = 242},
  [3364] = {.lex_state = 216},
  [3365] = {.lex_state = 194},
  [3366] = {.lex_state = 194},
  [3367] = {.lex_state = 197},
  [3368] = {.lex_state = 216},
  [3369] = {.lex_state = 216},
  [3370] = {.lex_state = 216},
  [3371] = {.lex_state = 216},
  [3372] = {.lex_state = 216},
  [3373] = {.lex_state = 209},
  [3374] = {.lex_state = 209},
  [3375] = {.lex_state = 216},
  [3376] = {.lex_state = 216},
  [3377] = {.lex_state = 216},
  [3378] = {.lex_state = 216},
  [3379] = {.lex_state = 216},
  [3380] = {.lex_state = 209},
  [3381] = {.lex_state = 216},
  [3382] = {.lex_state = 216},
  [3383] = {.lex_state = 194},
  [3384] = {.lex_state = 216},
  [3385] = {.lex_state = 216},
  [3386] = {.lex_state = 216},
  [3387] = {.lex_state = 209},
  [3388] = {.lex_state = 194},
  [3389] = {.lex_state = 194},
  [3390] = {.lex_state = 196},
  [3391] = {.lex_state = 196},
  [3392] = {.lex_state = 197},
  [3393] = {.lex_state = 194},
  [3394] = {.lex_state = 216},
  [3395] = {.lex_state = 194},
  [3396] = {.lex_state = 194},
  [3397] = {.lex_state = 216},
  [3398] = {.lex_state = 213},
  [3399] = {.lex_state = 242},
  [3400] = {.lex_state = 216},
  [3401] = {.lex_state = 194},
  [3402] = {.lex_state = 215},
  [3403] = {.lex_state = 194},
  [3404] = {.lex_state = 194},
  [3405] = {.lex_state = 216},
  [3406] = {.lex_state = 213},
  [3407] = {.lex_state = 201},
  [3408] = {.lex_state = 216},
  [3409] = {.lex_state = 183},
  [3410] = {.lex_state = 209},
  [3411] = {.lex_state = 196},
  [3412] = {.lex_state = 216},
  [3413] = {.lex_state = 216},
  [3414] = {.lex_state = 209},
  [3415] = {.lex_state = 194},
  [3416] = {.lex_state = 209},
  [3417] = {.lex_state = 209},
  [3418] = {.lex_state = 194},
  [3419] = {.lex_state = 194},
  [3420] = {.lex_state = 209},
  [3421] = {.lex_state = 209},
  [3422] = {.lex_state = 200},
  [3423] = {.lex_state = 200},
  [3424] = {.lex_state = 209},
  [3425] = {.lex_state = 194},
  [3426] = {.lex_state = 194},
  [3427] = {.lex_state = 209},
  [3428] = {.lex_state = 242},
  [3429] = {.lex_state = 194},
  [3430] = {.lex_state = 209},
  [3431] = {.lex_state = 209},
  [3432] = {.lex_state = 200},
  [3433] = {.lex_state = 200},
  [3434] = {.lex_state = 200},
  [3435] = {.lex_state = 200},
  [3436] = {.lex_state = 200},
  [3437] = {.lex_state = 194},
  [3438] = {.lex_state = 200},
  [3439] = {.lex_state = 200},
  [3440] = {.lex_state = 209},
  [3441] = {.lex_state = 194},
  [3442] = {.lex_state = 209},
  [3443] = {.lex_state = 194},
  [3444] = {.lex_state = 194},
  [3445] = {.lex_state = 209},
  [3446] = {.lex_state = 200},
  [3447] = {.lex_state = 209},
  [3448] = {.lex_state = 194},
  [3449] = {.lex_state = 209},
  [3450] = {.lex_state = 200},
  [3451] = {.lex_state = 200},
  [3452] = {.lex_state = 200},
  [3453] = {.lex_state = 200},
  [3454] = {.lex_state = 196},
  [3455] = {.lex_state = 200},
  [3456] = {.lex_state = 183},
  [3457] = {.lex_state = 209},
  [3458] = {.lex_state = 200},
  [3459] = {.lex_state = 200},
  [3460] = {.lex_state = 200},
  [3461] = {.lex_state = 200},
  [3462] = {.lex_state = 200},
  [3463] = {.lex_state = 216},
  [3464] = {.lex_state = 200},
  [3465] = {.lex_state = 200},
  [3466] = {.lex_state = 200},
  [3467] = {.lex_state = 196},
  [3468] = {.lex_state = 213},
  [3469] = {.lex_state = 209},
  [3470] = {.lex_state = 200},
  [3471] = {.lex_state = 194},
  [3472] = {.lex_state = 176},
  [3473] = {.lex_state = 209},
  [3474] = {.lex_state = 197},
  [3475] = {.lex_state = 194},
  [3476] = {.lex_state = 204},
  [3477] = {.lex_state = 216},
  [3478] = {.lex_state = 194},
  [3479] = {.lex_state = 194},
  [3480] = {.lex_state = 209},
  [3481] = {.lex_state = 209},
  [3482] = {.lex_state = 209},
  [3483] = {.lex_state = 209},
  [3484] = {.lex_state = 209},
  [3485] = {.lex_state = 209},
  [3486] = {.lex_state = 209},
  [3487] = {.lex_state = 209},
  [3488] = {.lex_state = 209},
  [3489] = {.lex_state = 183},
  [3490] = {.lex_state = 219},
  [3491] = {.lex_state = 209},
  [3492] = {.lex_state = 219},
  [3493] = {.lex_state = 209},
  [3494] = {.lex_state = 209},
  [3495] = {.lex_state = 209},
  [3496] = {.lex_state = 223},
  [3497] = {.lex_state = 209},
  [3498] = {.lex_state = 193},
  [3499] = {.lex_state = 209},
  [3500] = {.lex_state = 209},
  [3501] = {.lex_state = 209},
  [3502] = {.lex_state = 206},
  [3503] = {.lex_state = 206},
  [3504] = {.lex_state = 209},
  [3505] = {.lex_state = 225},
  [3506] = {.lex_state = 209},
  [3507] = {.lex_state = 209},
  [3508] = {.lex_state = 209},
  [3509] = {.lex_state = 197},
  [3510] = {.lex_state = 209},
  [3511] = {.lex_state = 183},
  [3512] = {.lex_state = 206},
  [3513] = {.lex_state = 204},
  [3514] = {.lex_state = 209},
  [3515] = {.lex_state = 209},
  [3516] = {.lex_state = 209},
  [3517] = {.lex_state = 209},
  [3518] = {.lex_state = 209},
  [3519] = {.lex_state = 221},
  [3520] = {.lex_state = 209},
  [3521] = {.lex_state = 209},
  [3522] = {.lex_state = 209},
  [3523] = {.lex_state = 209},
  [3524] = {.lex_state = 206},
  [3525] = {.lex_state = 225},
  [3526] = {.lex_state = 209},
  [3527] = {.lex_state = 209},
  [3528] = {.lex_state = 204},
  [3529] = {.lex_state = 209},
  [3530] = {.lex_state = 209},
  [3531] = {.lex_state = 219},
  [3532] = {.lex_state = 209},
  [3533] = {.lex_state = 219},
  [3534] = {.lex_state = 209},
  [3535] = {.lex_state = 206},
  [3536] = {.lex_state = 209},
  [3537] = {.lex_state = 209},
  [3538] = {.lex_state = 219},
  [3539] = {.lex_state = 209},
  [3540] = {.lex_state = 219},
  [3541] = {.lex_state = 209},
  [3542] = {.lex_state = 209},
  [3543] = {.lex_state = 219},
  [3544] = {.lex_state = 209},
  [3545] = {.lex_state = 205},
  [3546] = {.lex_state = 219},
  [3547] = {.lex_state = 219},
  [3548] = {.lex_state = 219},
  [3549] = {.lex_state = 219},
  [3550] = {.lex_state = 209},
  [3551] = {.lex_state = 219},
  [3552] = {.lex_state = 183},
  [3553] = {.lex_state = 209},
  [3554] = {.lex_state = 209},
  [3555] = {.lex_state = 204},
  [3556] = {.lex_state = 209},
  [3557] = {.lex_state = 209},
  [3558] = {.lex_state = 209},
  [3559] = {.lex_state = 209},
  [3560] = {.lex_state = 209},
  [3561] = {.lex_state = 206},
  [3562] = {.lex_state = 209},
  [3563] = {.lex_state = 209},
  [3564] = {.lex_state = 209},
  [3565] = {.lex_state = 219},
  [3566] = {.lex_state = 209},
  [3567] = {.lex_state = 209},
  [3568] = {.lex_state = 209},
  [3569] = {.lex_state = 209},
  [3570] = {.lex_state = 209},
  [3571] = {.lex_state = 216},
  [3572] = {.lex_state = 209},
  [3573] = {.lex_state = 209},
  [3574] = {.lex_state = 209},
  [3575] = {.lex_state = 216},
  [3576] = {.lex_state = 206},
  [3577] = {.lex_state = 206},
  [3578] = {.lex_state = 206},
  [3579] = {.lex_state = 209},
  [3580] = {.lex_state = 209},
  [3581] = {.lex_state = 209},
  [3582] = {.lex_state = 209},
  [3583] = {.lex_state = 209},
  [3584] = {.lex_state = 209},
  [3585] = {.lex_state = 197},
  [3586] = {.lex_state = 216},
  [3587] = {.lex_state = 209},
  [3588] = {.lex_state = 209},
  [3589] = {.lex_state = 209},
  [3590] = {.lex_state = 209},
  [3591] = {.lex_state = 209},
  [3592] = {.lex_state = 219},
  [3593] = {.lex_state = 209},
  [3594] = {.lex_state = 206},
  [3595] = {.lex_state = 193},
  [3596] = {.lex_state = 209},
  [3597] = {.lex_state = 209},
  [3598] = {.lex_state = 209},
  [3599] = {.lex_state = 209},
  [3600] = {.lex_state = 209},
  [3601] = {.lex_state = 209},
  [3602] = {.lex_state = 221},
  [3603] = {.lex_state = 209},
  [3604] = {.lex_state = 209},
  [3605] = {.lex_state = 209},
  [3606] = {.lex_state = 206},
  [3607] = {.lex_state = 209},
  [3608] = {.lex_state = 209},
  [3609] = {.lex_state = 209},
  [3610] = {.lex_state = 221},
  [3611] = {.lex_state = 209},
  [3612] = {.lex_state = 209},
  [3613] = {.lex_state = 209},
  [3614] = {.lex_state = 205},
  [3615] = {.lex_state = 209},
  [3616] = {.lex_state = 209},
  [3617] = {.lex_state = 209},
  [3618] = {.lex_state = 209},
  [3619] = {.lex_state = 209},
  [3620] = {.lex_state = 209},
  [3621] = {.lex_state = 209},
  [3622] = {.lex_state = 209},
  [3623] = {.lex_state = 209},
  [3624] = {.lex_state = 209},
  [3625] = {.lex_state = 209},
  [3626] = {.lex_state = 206},
  [3627] = {.lex_state = 209},
  [3628] = {.lex_state = 209},
  [3629] = {.lex_state = 209},
  [3630] = {.lex_state = 193},
  [3631] = {.lex_state = 219},
  [3632] = {.lex_state = 219},
  [3633] = {.lex_state = 209},
  [3634] = {.lex_state = 238},
  [3635] = {.lex_state = 209},
  [3636] = {.lex_state = 209},
  [3637] = {.lex_state = 209},
  [3638] = {.lex_state = 209},
  [3639] = {.lex_state = 209},
  [3640] = {.lex_state = 209},
  [3641] = {.lex_state = 209},
  [3642] = {.lex_state = 209},
  [3643] = {.lex_state = 216},
  [3644] = {.lex_state = 238},
  [3645] = {.lex_state = 209},
  [3646] = {.lex_state = 209},
  [3647] = {.lex_state = 206},
  [3648] = {.lex_state = 209},
  [3649] = {.lex_state = 183},
  [3650] = {.lex_state = 209},
  [3651] = {.lex_state = 209},
  [3652] = {.lex_state = 209},
  [3653] = {.lex_state = 209},
  [3654] = {.lex_state = 206},
  [3655] = {.lex_state = 206},
  [3656] = {.lex_state = 206},
  [3657] = {.lex_state = 206},
  [3658] = {.lex_state = 209},
  [3659] = {.lex_state = 209},
  [3660] = {.lex_state = 216},
  [3661] = {.lex_state = 216},
  [3662] = {.lex_state = 209},
  [3663] = {.lex_state = 216},
  [3664] = {.lex_state = 200},
  [3665] = {.lex_state = 216},
  [3666] = {.lex_state = 216},
  [3667] = {.lex_state = 216},
  [3668] = {.lex_state = 209},
  [3669] = {.lex_state = 206},
  [3670] = {.lex_state = 216},
  [3671] = {.lex_state = 209},
  [3672] = {.lex_state = 216},
  [3673] = {.lex_state = 209},
  [3674] = {.lex_state = 200},
  [3675] = {.lex_state = 206},
  [3676] = {.lex_state = 206},
  [3677] = {.lex_state = 200},
  [3678] = {.lex_state = 200},
  [3679] = {.lex_state = 242},
  [3680] = {.lex_state = 209},
  [3681] = {.lex_state = 216},
  [3682] = {.lex_state = 216},
  [3683] = {.lex_state = 216},
  [3684] = {.lex_state = 216},
  [3685] = {.lex_state = 216},
  [3686] = {.lex_state = 209},
  [3687] = {.lex_state = 242},
  [3688] = {.lex_state = 216},
  [3689] = {.lex_state = 216},
  [3690] = {.lex_state = 200},
  [3691] = {.lex_state = 216},
  [3692] = {.lex_state = 216},
  [3693] = {.lex_state = 216},
  [3694] = {.lex_state = 196},
  [3695] = {.lex_state = 183},
  [3696] = {.lex_state = 206},
  [3697] = {.lex_state = 216},
  [3698] = {.lex_state = 183},
  [3699] = {.lex_state = 216},
  [3700] = {.lex_state = 216},
  [3701] = {.lex_state = 209},
  [3702] = {.lex_state = 209},
  [3703] = {.lex_state = 216},
  [3704] = {.lex_state = 200},
  [3705] = {.lex_state = 216},
  [3706] = {.lex_state = 216},
  [3707] = {.lex_state = 216},
  [3708] = {.lex_state = 238},
  [3709] = {.lex_state = 209},
  [3710] = {.lex_state = 216},
  [3711] = {.lex_state = 216},
  [3712] = {.lex_state = 216},
  [3713] = {.lex_state = 216},
  [3714] = {.lex_state = 204},
  [3715] = {.lex_state = 242},
  [3716] = {.lex_state = 216},
  [3717] = {.lex_state = 206},
  [3718] = {.lex_state = 216},
  [3719] = {.lex_state = 216},
  [3720] = {.lex_state = 216},
  [3721] = {.lex_state = 206},
  [3722] = {.lex_state = 216},
  [3723] = {.lex_state = 216},
  [3724] = {.lex_state = 216},
  [3725] = {.lex_state = 209},
  [3726] = {.lex_state = 216},
  [3727] = {.lex_state = 216},
  [3728] = {.lex_state = 206},
  [3729] = {.lex_state = 216},
  [3730] = {.lex_state = 200},
  [3731] = {.lex_state = 216},
  [3732] = {.lex_state = 216},
  [3733] = {.lex_state = 216},
  [3734] = {.lex_state = 216},
  [3735] = {.lex_state = 216},
  [3736] = {.lex_state = 216},
  [3737] = {.lex_state = 216},
  [3738] = {.lex_state = 216},
  [3739] = {.lex_state = 209},
  [3740] = {.lex_state = 216},
  [3741] = {.lex_state = 216},
  [3742] = {.lex_state = 200},
  [3743] = {.lex_state = 216},
  [3744] = {.lex_state = 216},
  [3745] = {.lex_state = 242},
  [3746] = {.lex_state = 216},
  [3747] = {.lex_state = 216},
  [3748] = {.lex_state = 216},
  [3749] = {.lex_state = 216},
  [3750] = {.lex_state = 216},
  [3751] = {.lex_state = 216},
  [3752] = {.lex_state = 216},
  [3753] = {.lex_state = 216},
  [3754] = {.lex_state = 216},
  [3755] = {.lex_state = 216},
  [3756] = {.lex_state = 242},
  [3757] = {.lex_state = 216},
  [3758] = {.lex_state = 209},
  [3759] = {.lex_state = 209},
  [3760] = {.lex_state = 206},
  [3761] = {.lex_state = 197},
  [3762] = {.lex_state = 209},
  [3763] = {.lex_state = 216},
  [3764] = {.lex_state = 216},
  [3765] = {.lex_state = 209},
  [3766] = {.lex_state = 216},
  [3767] = {.lex_state = 204},
  [3768] = {.lex_state = 209},
  [3769] = {.lex_state = 216},
  [3770] = {.lex_state = 216},
  [3771] = {.lex_state = 209},
  [3772] = {.lex_state = 216},
  [3773] = {.lex_state = 216},
  [3774] = {.lex_state = 209},
  [3775] = {.lex_state = 209},
  [3776] = {.lex_state = 216},
  [3777] = {.lex_state = 216},
  [3778] = {.lex_state = 209},
  [3779] = {.lex_state = 216},
  [3780] = {.lex_state = 209},
  [3781] = {.lex_state = 216},
  [3782] = {.lex_state = 216},
  [3783] = {.lex_state = 209},
  [3784] = {.lex_state = 216},
  [3785] = {.lex_state = 209},
  [3786] = {.lex_state = 216},
  [3787] = {.lex_state = 216},
  [3788] = {.lex_state = 216},
  [3789] = {.lex_state = 209},
  [3790] = {.lex_state = 216},
  [3791] = {.lex_state = 242},
  [3792] = {.lex_state = 216},
  [3793] = {.lex_state = 216},
  [3794] = {.lex_state = 238},
  [3795] = {.lex_state = 197},
  [3796] = {.lex_state = 216},
  [3797] = {.lex_state = 216},
  [3798] = {.lex_state = 216},
  [3799] = {.lex_state = 209},
  [3800] = {.lex_state = 204},
  [3801] = {.lex_state = 204},
  [3802] = {.lex_state = 213},
  [3803] = {.lex_state = 206},
  [3804] = {.lex_state = 213},
  [3805] = {.lex_state = 204},
  [3806] = {.lex_state = 204},
  [3807] = {.lex_state = 193},
  [3808] = {.lex_state = 204},
  [3809] = {.lex_state = 213},
  [3810] = {.lex_state = 206},
  [3811] = {.lex_state = 204},
  [3812] = {.lex_state = 193},
  [3813] = {.lex_state = 206},
  [3814] = {.lex_state = 204},
  [3815] = {.lex_state = 204},
  [3816] = {.lex_state = 204},
  [3817] = {.lex_state = 204},
  [3818] = {.lex_state = 239},
  [3819] = {.lex_state = 206},
  [3820] = {.lex_state = 204},
  [3821] = {.lex_state = 204},
  [3822] = {.lex_state = 242},
  [3823] = {.lex_state = 242},
  [3824] = {.lex_state = 197},
  [3825] = {.lex_state = 204},
  [3826] = {.lex_state = 209},
  [3827] = {.lex_state = 183},
  [3828] = {.lex_state = 183},
  [3829] = {.lex_state = 183},
  [3830] = {.lex_state = 183},
  [3831] = {.lex_state = 209},
  [3832] = {.lex_state = 209},
  [3833] = {.lex_state = 239},
  [3834] = {.lex_state = 209},
  [3835] = {.lex_state = 239},
  [3836] = {.lex_state = 206},
  [3837] = {.lex_state = 239},
  [3838] = {.lex_state = 239},
  [3839] = {.lex_state = 239},
  [3840] = {.lex_state = 239},
  [3841] = {.lex_state = 209},
  [3842] = {.lex_state = 209},
  [3843] = {.lex_state = 209},
  [3844] = {.lex_state = 239},
  [3845] = {.lex_state = 209},
  [3846] = {.lex_state = 239},
  [3847] = {.lex_state = 239},
  [3848] = {.lex_state = 206},
  [3849] = {.lex_state = 209},
  [3850] = {.lex_state = 209},
  [3851] = {.lex_state = 239},
  [3852] = {.lex_state = 209},
  [3853] = {.lex_state = 239},
  [3854] = {.lex_state = 239},
  [3855] = {.lex_state = 209},
  [3856] = {.lex_state = 239},
  [3857] = {.lex_state = 183},
  [3858] = {.lex_state = 183},
  [3859] = {.lex_state = 239},
  [3860] = {.lex_state = 209},
  [3861] = {.lex_state = 183},
  [3862] = {.lex_state = 193},
  [3863] = {.lex_state = 206},
  [3864] = {.lex_state = 209},
  [3865] = {.lex_state = 193},
  [3866] = {.lex_state = 239},
  [3867] = {.lex_state = 239},
  [3868] = {.lex_state = 239},
  [3869] = {.lex_state = 209},
  [3870] = {.lex_state = 206},
  [3871] = {.lex_state = 204},
  [3872] = {.lex_state = 209},
  [3873] = {.lex_state = 209},
  [3874] = {.lex_state = 206},
  [3875] = {.lex_state = 209},
  [3876] = {.lex_state = 209},
  [3877] = {.lex_state = 206},
  [3878] = {.lex_state = 193},
  [3879] = {.lex_state = 206},
  [3880] = {.lex_state = 239},
  [3881] = {.lex_state = 209},
  [3882] = {.lex_state = 239},
  [3883] = {.lex_state = 209},
  [3884] = {.lex_state = 239},
  [3885] = {.lex_state = 239},
  [3886] = {.lex_state = 239},
  [3887] = {.lex_state = 239},
  [3888] = {.lex_state = 239},
  [3889] = {.lex_state = 239},
  [3890] = {.lex_state = 209},
  [3891] = {.lex_state = 225},
  [3892] = {.lex_state = 239},
  [3893] = {.lex_state = 209},
  [3894] = {.lex_state = 239},
  [3895] = {.lex_state = 209},
  [3896] = {.lex_state = 209},
  [3897] = {.lex_state = 239},
  [3898] = {.lex_state = 239},
  [3899] = {.lex_state = 209},
  [3900] = {.lex_state = 209},
  [3901] = {.lex_state = 209},
  [3902] = {.lex_state = 206},
  [3903] = {.lex_state = 239},
  [3904] = {.lex_state = 239},
  [3905] = {.lex_state = 206},
  [3906] = {.lex_state = 209},
  [3907] = {.lex_state = 239},
  [3908] = {.lex_state = 225},
  [3909] = {.lex_state = 239},
  [3910] = {.lex_state = 209},
  [3911] = {.lex_state = 239},
  [3912] = {.lex_state = 239},
  [3913] = {.lex_state = 204},
  [3914] = {.lex_state = 239},
  [3915] = {.lex_state = 209},
  [3916] = {.lex_state = 239},
  [3917] = {.lex_state = 239},
  [3918] = {.lex_state = 209},
  [3919] = {.lex_state = 239},
  [3920] = {.lex_state = 239},
  [3921] = {.lex_state = 239},
  [3922] = {.lex_state = 239},
  [3923] = {.lex_state = 209},
  [3924] = {.lex_state = 239},
  [3925] = {.lex_state = 193},
  [3926] = {.lex_state = 239},
  [3927] = {.lex_state = 239},
  [3928] = {.lex_state = 209},
  [3929] = {.lex_state = 239},
  [3930] = {.lex_state = 206},
  [3931] = {.lex_state = 206},
  [3932] = {.lex_state = 209},
  [3933] = {.lex_state = 209},
  [3934] = {.lex_state = 209},
  [3935] = {.lex_state = 209},
  [3936] = {.lex_state = 239},
  [3937] = {.lex_state = 239},
  [3938] = {.lex_state = 206},
  [3939] = {.lex_state = 209},
  [3940] = {.lex_state = 206},
  [3941] = {.lex_state = 239},
  [3942] = {.lex_state = 239},
  [3943] = {.lex_state = 239},
  [3944] = {.lex_state = 209},
  [3945] = {.lex_state = 209},
  [3946] = {.lex_state = 209},
  [3947] = {.lex_state = 239},
  [3948] = {.lex_state = 209},
  [3949] = {.lex_state = 239},
  [3950] = {.lex_state = 209},
  [3951] = {.lex_state = 209},
  [3952] = {.lex_state = 239},
  [3953] = {.lex_state = 209},
  [3954] = {.lex_state = 239},
  [3955] = {.lex_state = 183},
  [3956] = {.lex_state = 239},
  [3957] = {.lex_state = 209},
  [3958] = {.lex_state = 239},
  [3959] = {.lex_state = 206},
  [3960] = {.lex_state = 209},
  [3961] = {.lex_state = 209},
  [3962] = {.lex_state = 209},
  [3963] = {.lex_state = 209},
  [3964] = {.lex_state = 206},
  [3965] = {.lex_state = 209},
  [3966] = {.lex_state = 239},
  [3967] = {.lex_state = 209},
  [3968] = {.lex_state = 209},
  [3969] = {.lex_state = 239},
  [3970] = {.lex_state = 183},
  [3971] = {.lex_state = 239},
  [3972] = {.lex_state = 239},
  [3973] = {.lex_state = 239},
  [3974] = {.lex_state = 239},
  [3975] = {.lex_state = 239},
  [3976] = {.lex_state = 209},
  [3977] = {.lex_state = 239},
  [3978] = {.lex_state = 239},
  [3979] = {.lex_state = 209},
  [3980] = {.lex_state = 209},
  [3981] = {.lex_state = 209},
  [3982] = {.lex_state = 206},
  [3983] = {.lex_state = 239},
  [3984] = {.lex_state = 206},
  [3985] = {.lex_state = 206},
  [3986] = {.lex_state = 206},
  [3987] = {.lex_state = 239},
  [3988] = {.lex_state = 239},
  [3989] = {.lex_state = 206},
  [3990] = {.lex_state = 239},
  [3991] = {.lex_state = 239},
  [3992] = {.lex_state = 206},
  [3993] = {.lex_state = 206},
  [3994] = {.lex_state = 206},
  [3995] = {.lex_state = 242},
  [3996] = {.lex_state = 242},
  [3997] = {.lex_state = 239},
  [3998] = {.lex_state = 206},
  [3999] = {.lex_state = 206},
  [4000] = {.lex_state = 239},
  [4001] = {.lex_state = 206},
  [4002] = {.lex_state = 206},
  [4003] = {.lex_state = 206},
  [4004] = {.lex_state = 239},
  [4005] = {.lex_state = 206},
  [4006] = {.lex_state = 239},
  [4007] = {.lex_state = 206},
  [4008] = {.lex_state = 206},
  [4009] = {.lex_state = 206},
  [4010] = {.lex_state = 239},
  [4011] = {.lex_state = 239},
  [4012] = {.lex_state = 206},
  [4013] = {.lex_state = 245},
  [4014] = {.lex_state = 193},
  [4015] = {.lex_state = 193},
  [4016] = {.lex_state = 206},
  [4017] = {.lex_state = 206},
  [4018] = {.lex_state = 206},
  [4019] = {.lex_state = 206},
  [4020] = {.lex_state = 228},
  [4021] = {.lex_state = 206},
  [4022] = {.lex_state = 206},
  [4023] = {.lex_state = 206},
  [4024] = {.lex_state = 206},
  [4025] = {.lex_state = 206},
  [4026] = {.lex_state = 239},
  [4027] = {.lex_state = 193},
  [4028] = {.lex_state = 206},
  [4029] = {.lex_state = 206},
  [4030] = {.lex_state = 239},
  [4031] = {.lex_state = 206},
  [4032] = {.lex_state = 206},
  [4033] = {.lex_state = 206},
  [4034] = {.lex_state = 206},
  [4035] = {.lex_state = 239},
  [4036] = {.lex_state = 206},
  [4037] = {.lex_state = 193},
  [4038] = {.lex_state = 206},
  [4039] = {.lex_state = 239},
  [4040] = {.lex_state = 206},
  [4041] = {.lex_state = 241},
  [4042] = {.lex_state = 206},
  [4043] = {.lex_state = 206},
  [4044] = {.lex_state = 206},
  [4045] = {.lex_state = 206},
  [4046] = {.lex_state = 241},
  [4047] = {.lex_state = 241},
  [4048] = {.lex_state = 206},
  [4049] = {.lex_state = 243},
  [4050] = {.lex_state = 241},
  [4051] = {.lex_state = 241},
  [4052] = {.lex_state = 206},
  [4053] = {.lex_state = 243},
  [4054] = {.lex_state = 241},
  [4055] = {.lex_state = 241},
  [4056] = {.lex_state = 241},
  [4057] = {.lex_state = 241},
  [4058] = {.lex_state = 206},
  [4059] = {.lex_state = 206},
  [4060] = {.lex_state = 206},
  [4061] = {.lex_state = 206},
  [4062] = {.lex_state = 241},
  [4063] = {.lex_state = 241},
  [4064] = {.lex_state = 241},
  [4065] = {.lex_state = 206},
  [4066] = {.lex_state = 241},
  [4067] = {.lex_state = 241},
  [4068] = {.lex_state = 206},
  [4069] = {.lex_state = 241},
  [4070] = {.lex_state = 206},
  [4071] = {.lex_state = 228},
  [4072] = {.lex_state = 206},
  [4073] = {.lex_state = 206},
  [4074] = {.lex_state = 241},
  [4075] = {.lex_state = 206},
  [4076] = {.lex_state = 206},
  [4077] = {.lex_state = 206},
  [4078] = {.lex_state = 206},
  [4079] = {.lex_state = 206},
  [4080] = {.lex_state = 242},
  [4081] = {.lex_state = 204},
  [4082] = {.lex_state = 241},
  [4083] = {.lex_state = 206},
  [4084] = {.lex_state = 204},
  [4085] = {.lex_state = 206},
  [4086] = {.lex_state = 228},
  [4087] = {.lex_state = 206},
  [4088] = {.lex_state = 242},
  [4089] = {.lex_state = 206},
  [4090] = {.lex_state = 241},
  [4091] = {.lex_state = 241},
  [4092] = {.lex_state = 228},
  [4093] = {.lex_state = 241},
  [4094] = {.lex_state = 206},
  [4095] = {.lex_state = 206},
  [4096] = {.lex_state = 241},
  [4097] = {.lex_state = 241},
  [4098] = {.lex_state = 239},
  [4099] = {.lex_state = 239},
  [4100] = {.lex_state = 239},
  [4101] = {.lex_state = 239},
  [4102] = {.lex_state = 206},
  [4103] = {.lex_state = 206},
  [4104] = {.lex_state = 206},
  [4105] = {.lex_state = 239},
  [4106] = {.lex_state = 206},
  [4107] = {.lex_state = 206},
  [4108] = {.lex_state = 206},
  [4109] = {.lex_state = 206},
  [4110] = {.lex_state = 239},
  [4111] = {.lex_state = 239},
  [4112] = {.lex_state = 206},
  [4113] = {.lex_state = 206},
  [4114] = {.lex_state = 206},
  [4115] = {.lex_state = 206},
  [4116] = {.lex_state = 206},
  [4117] = {.lex_state = 206},
  [4118] = {.lex_state = 206},
  [4119] = {.lex_state = 206},
  [4120] = {.lex_state = 206},
  [4121] = {.lex_state = 239},
  [4122] = {.lex_state = 239},
  [4123] = {.lex_state = 245},
  [4124] = {.lex_state = 245},
  [4125] = {.lex_state = 230},
  [4126] = {.lex_state = 241},
  [4127] = {.lex_state = 239},
  [4128] = {.lex_state = 230},
  [4129] = {.lex_state = 239},
  [4130] = {.lex_state = 239},
  [4131] = {.lex_state = 206},
  [4132] = {.lex_state = 239},
  [4133] = {.lex_state = 239},
  [4134] = {.lex_state = 206},
  [4135] = {.lex_state = 206},
  [4136] = {.lex_state = 239},
  [4137] = {.lex_state = 239},
  [4138] = {.lex_state = 239},
  [4139] = {.lex_state = 239},
  [4140] = {.lex_state = 239},
  [4141] = {.lex_state = 241},
  [4142] = {.lex_state = 241},
  [4143] = {.lex_state = 242},
  [4144] = {.lex_state = 206},
  [4145] = {.lex_state = 206},
  [4146] = {.lex_state = 239},
  [4147] = {.lex_state = 206},
  [4148] = {.lex_state = 206},
  [4149] = {.lex_state = 206},
  [4150] = {.lex_state = 206},
  [4151] = {.lex_state = 230},
  [4152] = {.lex_state = 239},
  [4153] = {.lex_state = 206},
  [4154] = {.lex_state = 206},
  [4155] = {.lex_state = 239},
  [4156] = {.lex_state = 206},
  [4157] = {.lex_state = 239},
  [4158] = {.lex_state = 206},
  [4159] = {.lex_state = 206},
  [4160] = {.lex_state = 239},
  [4161] = {.lex_state = 206},
  [4162] = {.lex_state = 206},
  [4163] = {.lex_state = 206},
  [4164] = {.lex_state = 206},
  [4165] = {.lex_state = 242},
  [4166] = {.lex_state = 206},
  [4167] = {.lex_state = 230},
  [4168] = {.lex_state = 206},
  [4169] = {.lex_state = 239},
  [4170] = {.lex_state = 206},
  [4171] = {.lex_state = 206},
  [4172] = {.lex_state = 239},
  [4173] = {.lex_state = 239},
  [4174] = {.lex_state = 239},
  [4175] = {.lex_state = 206},
  [4176] = {.lex_state = 206},
  [4177] = {.lex_state = 225},
  [4178] = {.lex_state = 206},
  [4179] = {.lex_state = 206},
  [4180] = {.lex_state = 206},
  [4181] = {.lex_state = 206},
  [4182] = {.lex_state = 238},
  [4183] = {.lex_state = 230},
  [4184] = {.lex_state = 225},
  [4185] = {.lex_state = 230},
  [4186] = {.lex_state = 244},
  [4187] = {.lex_state = 206},
  [4188] = {.lex_state = 206},
  [4189] = {.lex_state = 206},
  [4190] = {.lex_state = 206},
  [4191] = {.lex_state = 206},
  [4192] = {.lex_state = 206},
  [4193] = {.lex_state = 206},
  [4194] = {.lex_state = 206},
  [4195] = {.lex_state = 242},
  [4196] = {.lex_state = 206},
  [4197] = {.lex_state = 206},
  [4198] = {.lex_state = 206},
  [4199] = {.lex_state = 206},
  [4200] = {.lex_state = 230},
  [4201] = {.lex_state = 206},
  [4202] = {.lex_state = 244},
  [4203] = {.lex_state = 241},
  [4204] = {.lex_state = 230},
  [4205] = {.lex_state = 241},
  [4206] = {.lex_state = 206},
  [4207] = {.lex_state = 206},
  [4208] = {.lex_state = 206},
  [4209] = {.lex_state = 207},
  [4210] = {.lex_state = 225},
  [4211] = {.lex_state = 225},
  [4212] = {.lex_state = 225},
  [4213] = {.lex_state = 206},
  [4214] = {.lex_state = 225},
  [4215] = {.lex_state = 241},
  [4216] = {.lex_state = 206},
  [4217] = {.lex_state = 225},
  [4218] = {.lex_state = 206},
  [4219] = {.lex_state = 242},
  [4220] = {.lex_state = 238},
  [4221] = {.lex_state = 242},
  [4222] = {.lex_state = 238},
  [4223] = {.lex_state = 242},
  [4224] = {.lex_state = 207},
  [4225] = {.lex_state = 225},
  [4226] = {.lex_state = 241},
  [4227] = {.lex_state = 225},
  [4228] = {.lex_state = 207},
  [4229] = {.lex_state = 242},
  [4230] = {.lex_state = 242},
  [4231] = {.lex_state = 242},
  [4232] = {.lex_state = 206},
  [4233] = {.lex_state = 225},
  [4234] = {.lex_state = 241},
  [4235] = {.lex_state = 206},
  [4236] = {.lex_state = 245},
  [4237] = {.lex_state = 207},
  [4238] = {.lex_state = 243},
  [4239] = {.lex_state = 242},
  [4240] = {.lex_state = 207},
  [4241] = {.lex_state = 206},
  [4242] = {.lex_state = 242},
  [4243] = {.lex_state = 243},
  [4244] = {.lex_state = 241},
  [4245] = {.lex_state = 242},
  [4246] = {.lex_state = 206},
  [4247] = {.lex_state = 245},
  [4248] = {.lex_state = 206},
  [4249] = {.lex_state = 241},
  [4250] = {.lex_state = 207},
  [4251] = {.lex_state = 206},
  [4252] = {.lex_state = 245},
  [4253] = {.lex_state = 206},
  [4254] = {.lex_state = 242},
  [4255] = {.lex_state = 206},
  [4256] = {.lex_state = 241},
  [4257] = {.lex_state = 241},
  [4258] = {.lex_state = 241},
  [4259] = {.lex_state = 206},
  [4260] = {.lex_state = 206},
  [4261] = {.lex_state = 241},
  [4262] = {.lex_state = 206},
  [4263] = {.lex_state = 206},
  [4264] = {.lex_state = 241},
  [4265] = {.lex_state = 230},
  [4266] = {.lex_state = 206},
  [4267] = {.lex_state = 206},
  [4268] = {.lex_state = 230},
  [4269] = {.lex_state = 206},
  [4270] = {.lex_state = 241},
  [4271] = {.lex_state = 206},
  [4272] = {.lex_state = 246},
  [4273] = {.lex_state = 230},
  [4274] = {.lex_state = 230},
  [4275] = {.lex_state = 230},
  [4276] = {.lex_state = 206},
  [4277] = {.lex_state = 230},
  [4278] = {.lex_state = 230},
  [4279] = {.lex_state = 206},
  [4280] = {.lex_state = 230},
  [4281] = {.lex_state = 230},
  [4282] = {.lex_state = 230},
  [4283] = {.lex_state = 241},
  [4284] = {.lex_state = 206},
  [4285] = {.lex_state = 238},
  [4286] = {.lex_state = 241},
  [4287] = {.lex_state = 206},
  [4288] = {.lex_state = 230},
  [4289] = {.lex_state = 206},
  [4290] = {.lex_state = 241},
  [4291] = {.lex_state = 246},
  [4292] = {.lex_state = 230},
  [4293] = {.lex_state = 241},
  [4294] = {.lex_state = 242},
  [4295] = {.lex_state = 206},
  [4296] = {.lex_state = 206},
  [4297] = {.lex_state = 246},
  [4298] = {.lex_state = 238},
  [4299] = {.lex_state = 238},
  [4300] = {.lex_state = 230},
  [4301] = {.lex_state = 230},
  [4302] = {.lex_state = 230},
  [4303] = {.lex_state = 206},
  [4304] = {.lex_state = 230},
  [4305] = {.lex_state = 230},
  [4306] = {.lex_state = 206},
  [4307] = {.lex_state = 206},
  [4308] = {.lex_state = 206},
  [4309] = {.lex_state = 242},
  [4310] = {.lex_state = 238},
  [4311] = {.lex_state = 242},
  [4312] = {.lex_state = 242},
  [4313] = {.lex_state = 230},
  [4314] = {.lex_state = 206},
  [4315] = {.lex_state = 206},
  [4316] = {.lex_state = 230},
  [4317] = {.lex_state = 206},
  [4318] = {.lex_state = 206},
  [4319] = {.lex_state = 206},
  [4320] = {.lex_state = 242},
  [4321] = {.lex_state = 230},
  [4322] = {.lex_state = 206},
  [4323] = {.lex_state = 230},
  [4324] = {.lex_state = 242},
  [4325] = {.lex_state = 230},
  [4326] = {.lex_state = 242},
  [4327] = {.lex_state = 230},
  [4328] = {.lex_state = 206},
  [4329] = {.lex_state = 206},
  [4330] = {.lex_state = 206},
  [4331] = {.lex_state = 206},
  [4332] = {.lex_state = 230},
  [4333] = {.lex_state = 230},
  [4334] = {.lex_state = 206},
  [4335] = {.lex_state = 230},
  [4336] = {.lex_state = 242},
  [4337] = {.lex_state = 206},
  [4338] = {.lex_state = 230},
  [4339] = {.lex_state = 206},
  [4340] = {.lex_state = 230},
  [4341] = {.lex_state = 206},
  [4342] = {.lex_state = 230},
  [4343] = {.lex_state = 206},
  [4344] = {.lex_state = 242},
  [4345] = {.lex_state = 206},
  [4346] = {.lex_state = 206},
  [4347] = {.lex_state = 242},
  [4348] = {.lex_state = 230},
  [4349] = {.lex_state = 206},
  [4350] = {.lex_state = 206},
  [4351] = {.lex_state = 206},
  [4352] = {.lex_state = 206},
  [4353] = {.lex_state = 230},
  [4354] = {.lex_state = 242},
  [4355] = {.lex_state = 206},
  [4356] = {.lex_state = 230},
  [4357] = {.lex_state = 206},
  [4358] = {.lex_state = 241},
  [4359] = {.lex_state = 224},
  [4360] = {.lex_state = 206},
  [4361] = {.lex_state = 206},
  [4362] = {.lex_state = 206},
  [4363] = {.lex_state = 206},
  [4364] = {.lex_state = 206},
  [4365] = {.lex_state = 242},
  [4366] = {.lex_state = 206},
  [4367] = {.lex_state = 206},
  [4368] = {.lex_state = 241},
  [4369] = {.lex_state = 206},
  [4370] = {.lex_state = 206},
  [4371] = {.lex_state = 206},
  [4372] = {.lex_state = 230},
  [4373] = {.lex_state = 242},
  [4374] = {.lex_state = 206},
  [4375] = {.lex_state = 206},
  [4376] = {.lex_state = 230},
  [4377] = {.lex_state = 206},
  [4378] = {.lex_state = 206},
  [4379] = {.lex_state = 206},
  [4380] = {.lex_state = 206},
  [4381] = {.lex_state = 206},
  [4382] = {.lex_state = 206},
  [4383] = {.lex_state = 206},
  [4384] = {.lex_state = 206},
  [4385] = {.lex_state = 206},
  [4386] = {.lex_state = 242},
  [4387] = {.lex_state = 206},
  [4388] = {.lex_state = 230},
  [4389] = {.lex_state = 206},
  [4390] = {.lex_state = 206},
  [4391] = {.lex_state = 230},
  [4392] = {.lex_state = 206},
  [4393] = {.lex_state = 206},
  [4394] = {.lex_state = 242},
  [4395] = {.lex_state = 206},
  [4396] = {.lex_state = 206},
  [4397] = {.lex_state = 230},
  [4398] = {.lex_state = 206},
  [4399] = {.lex_state = 206},
  [4400] = {.lex_state = 206},
  [4401] = {.lex_state = 206},
  [4402] = {.lex_state = 206},
  [4403] = {.lex_state = 206},
  [4404] = {.lex_state = 206},
  [4405] = {.lex_state = 206},
  [4406] = {.lex_state = 206},
  [4407] = {.lex_state = 206},
  [4408] = {.lex_state = 230},
  [4409] = {.lex_state = 230},
  [4410] = {.lex_state = 206},
  [4411] = {.lex_state = 206},
  [4412] = {.lex_state = 206},
  [4413] = {.lex_state = 241},
  [4414] = {.lex_state = 241},
  [4415] = {.lex_state = 206},
  [4416] = {.lex_state = 238},
  [4417] = {.lex_state = 230},
  [4418] = {.lex_state = 206},
  [4419] = {.lex_state = 230},
  [4420] = {.lex_state = 206},
  [4421] = {.lex_state = 206},
  [4422] = {.lex_state = 230},
  [4423] = {.lex_state = 230},
  [4424] = {.lex_state = 230},
  [4425] = {.lex_state = 230},
  [4426] = {.lex_state = 242},
  [4427] = {.lex_state = 206},
  [4428] = {.lex_state = 206},
  [4429] = {.lex_state = 206},
  [4430] = {.lex_state = 206},
  [4431] = {.lex_state = 206},
  [4432] = {.lex_state = 206},
  [4433] = {.lex_state = 206},
  [4434] = {.lex_state = 206},
  [4435] = {.lex_state = 206},
  [4436] = {.lex_state = 206},
  [4437] = {.lex_state = 206},
  [4438] = {.lex_state = 206},
  [4439] = {.lex_state = 206},
  [4440] = {.lex_state = 206},
  [4441] = {.lex_state = 206},
  [4442] = {.lex_state = 206},
  [4443] = {.lex_state = 206},
  [4444] = {.lex_state = 206},
  [4445] = {.lex_state = 206},
  [4446] = {.lex_state = 206},
  [4447] = {.lex_state = 206},
  [4448] = {.lex_state = 206},
  [4449] = {.lex_state = 206},
  [4450] = {.lex_state = 206},
  [4451] = {.lex_state = 206},
  [4452] = {.lex_state = 241},
  [4453] = {.lex_state = 206},
  [4454] = {.lex_state = 206},
  [4455] = {.lex_state = 206},
  [4456] = {.lex_state = 241},
  [4457] = {.lex_state = 206},
  [4458] = {.lex_state = 206},
  [4459] = {.lex_state = 206},
  [4460] = {.lex_state = 206},
  [4461] = {.lex_state = 206},
  [4462] = {.lex_state = 206},
  [4463] = {.lex_state = 206},
  [4464] = {.lex_state = 206},
  [4465] = {.lex_state = 238},
  [4466] = {.lex_state = 206},
  [4467] = {.lex_state = 228},
  [4468] = {.lex_state = 206},
  [4469] = {.lex_state = 206},
  [4470] = {.lex_state = 206},
  [4471] = {.lex_state = 206},
  [4472] = {.lex_state = 241},
  [4473] = {.lex_state = 206},
  [4474] = {.lex_state = 206},
  [4475] = {.lex_state = 206},
  [4476] = {.lex_state = 206},
  [4477] = {.lex_state = 206},
  [4478] = {.lex_state = 206},
  [4479] = {.lex_state = 238},
  [4480] = {.lex_state = 206},
  [4481] = {.lex_state = 206},
  [4482] = {.lex_state = 206},
  [4483] = {.lex_state = 225},
  [4484] = {.lex_state = 206},
  [4485] = {.lex_state = 206},
  [4486] = {.lex_state = 206},
  [4487] = {.lex_state = 206},
  [4488] = {.lex_state = 206},
  [4489] = {.lex_state = 207},
  [4490] = {.lex_state = 206},
  [4491] = {.lex_state = 206},
  [4492] = {.lex_state = 206},
  [4493] = {.lex_state = 206},
  [4494] = {.lex_state = 206},
  [4495] = {.lex_state = 206},
  [4496] = {.lex_state = 243},
  [4497] = {.lex_state = 243},
  [4498] = {.lex_state = 243},
  [4499] = {.lex_state = 225},
  [4500] = {.lex_state = 230},
  [4501] = {.lex_state = 206},
  [4502] = {.lex_state = 206},
  [4503] = {.lex_state = 243},
  [4504] = {.lex_state = 243},
  [4505] = {.lex_state = 206},
  [4506] = {.lex_state = 206},
  [4507] = {.lex_state = 206},
  [4508] = {.lex_state = 206},
  [4509] = {.lex_state = 230},
  [4510] = {.lex_state = 243},
  [4511] = {.lex_state = 206},
  [4512] = {.lex_state = 206},
  [4513] = {.lex_state = 230},
  [4514] = {.lex_state = 206},
  [4515] = {.lex_state = 243},
  [4516] = {.lex_state = 206},
  [4517] = {.lex_state = 206},
  [4518] = {.lex_state = 230},
  [4519] = {.lex_state = 206},
  [4520] = {.lex_state = 225},
  [4521] = {.lex_state = 207},
  [4522] = {.lex_state = 206},
  [4523] = {.lex_state = 207},
  [4524] = {.lex_state = 206},
  [4525] = {.lex_state = 206},
  [4526] = {.lex_state = 230},
  [4527] = {.lex_state = 206},
  [4528] = {.lex_state = 206},
  [4529] = {.lex_state = 230},
  [4530] = {.lex_state = 206},
  [4531] = {.lex_state = 206},
  [4532] = {.lex_state = 206},
  [4533] = {.lex_state = 206},
  [4534] = {.lex_state = 206},
  [4535] = {.lex_state = 230},
  [4536] = {.lex_state = 243},
  [4537] = {.lex_state = 242},
  [4538] = {.lex_state = 243},
  [4539] = {.lex_state = 206},
  [4540] = {.lex_state = 241},
  [4541] = {.lex_state = 206},
  [4542] = {.lex_state = 206},
  [4543] = {.lex_state = 238},
  [4544] = {.lex_state = 243},
  [4545] = {.lex_state = 206},
  [4546] = {.lex_state = 206},
  [4547] = {.lex_state = 230},
  [4548] = {.lex_state = 206},
  [4549] = {.lex_state = 241},
  [4550] = {.lex_state = 230},
  [4551] = {.lex_state = 206},
  [4552] = {.lex_state = 206},
  [4553] = {.lex_state = 206},
  [4554] = {.lex_state = 230},
  [4555] = {.lex_state = 230},
  [4556] = {.lex_state = 230},
  [4557] = {.lex_state = 230},
  [4558] = {.lex_state = 230},
  [4559] = {.lex_state = 206},
  [4560] = {.lex_state = 206},
  [4561] = {.lex_state = 206},
  [4562] = {.lex_state = 206},
  [4563] = {.lex_state = 206},
  [4564] = {.lex_state = 206},
  [4565] = {.lex_state = 230},
  [4566] = {.lex_state = 230},
  [4567] = {.lex_state = 230},
  [4568] = {.lex_state = 206},
  [4569] = {.lex_state = 230},
  [4570] = {.lex_state = 230},
  [4571] = {.lex_state = 230},
  [4572] = {.lex_state = 230},
  [4573] = {.lex_state = 230},
  [4574] = {.lex_state = 230},
  [4575] = {.lex_state = 230},
  [4576] = {.lex_state = 230},
  [4577] = {.lex_state = 243},
  [4578] = {.lex_state = 206},
  [4579] = {.lex_state = 242},
  [4580] = {.lex_state = 230},
  [4581] = {.lex_state = 230},
  [4582] = {.lex_state = 230},
  [4583] = {.lex_state = 206},
  [4584] = {.lex_state = 206},
  [4585] = {.lex_state = 206},
  [4586] = {.lex_state = 206},
  [4587] = {.lex_state = 206},
  [4588] = {.lex_state = 243},
  [4589] = {.lex_state = 206},
  [4590] = {.lex_state = 206},
  [4591] = {.lex_state = 206},
  [4592] = {.lex_state = 206},
  [4593] = {.lex_state = 206},
  [4594] = {.lex_state = 206},
  [4595] = {.lex_state = 241},
  [4596] = {.lex_state = 206},
  [4597] = {.lex_state = 206},
  [4598] = {.lex_state = 242},
  [4599] = {.lex_state = 206},
  [4600] = {.lex_state = 242},
  [4601] = {.lex_state = 206},
  [4602] = {.lex_state = 206},
  [4603] = {.lex_state = 206},
  [4604] = {.lex_state = 241},
  [4605] = {.lex_state = 206},
  [4606] = {.lex_state = 241},
  [4607] = {.lex_state = 241},
  [4608] = {.lex_state = 206},
  [4609] = {.lex_state = 206},
  [4610] = {.lex_state = 206},
  [4611] = {.lex_state = 206},
  [4612] = {.lex_state = 206},
  [4613] = {.lex_state = 206},
  [4614] = {.lex_state = 206},
  [4615] = {.lex_state = 206},
  [4616] = {.lex_state = 206},
  [4617] = {.lex_state = 206},
  [4618] = {.lex_state = 206},
  [4619] = {.lex_state = 206},
  [4620] = {.lex_state = 241},
  [4621] = {.lex_state = 206},
  [4622] = {.lex_state = 206},
  [4623] = {.lex_state = 206},
  [4624] = {.lex_state = 206},
  [4625] = {.lex_state = 242},
  [4626] = {.lex_state = 241},
  [4627] = {.lex_state = 206},
  [4628] = {.lex_state = 206},
  [4629] = {.lex_state = 206},
  [4630] = {.lex_state = 206},
  [4631] = {.lex_state = 206},
  [4632] = {.lex_state = 206},
  [4633] = {.lex_state = 241},
  [4634] = {.lex_state = 206},
  [4635] = {.lex_state = 206},
  [4636] = {.lex_state = 206},
  [4637] = {.lex_state = 206},
  [4638] = {.lex_state = 206},
  [4639] = {.lex_state = 241},
  [4640] = {.lex_state = 206},
  [4641] = {.lex_state = 206},
  [4642] = {.lex_state = 206},
  [4643] = {.lex_state = 206},
  [4644] = {.lex_state = 241},
  [4645] = {.lex_state = 206},
  [4646] = {.lex_state = 206},
  [4647] = {.lex_state = 206},
  [4648] = {.lex_state = 206},
  [4649] = {.lex_state = 206},
  [4650] = {.lex_state = 206},
  [4651] = {.lex_state = 206},
  [4652] = {.lex_state = 206},
  [4653] = {.lex_state = 206},
  [4654] = {.lex_state = 206},
  [4655] = {.lex_state = 206},
  [4656] = {.lex_state = 239},
  [4657] = {.lex_state = 206},
  [4658] = {.lex_state = 206},
  [4659] = {.lex_state = 206},
  [4660] = {.lex_state = 206},
  [4661] = {.lex_state = 206},
  [4662] = {.lex_state = 231},
  [4663] = {.lex_state = 206},
  [4664] = {.lex_state = 241},
  [4665] = {.lex_state = 241},
  [4666] = {.lex_state = 241},
  [4667] = {.lex_state = 206},
  [4668] = {.lex_state = 241},
  [4669] = {.lex_state = 241},
  [4670] = {.lex_state = 242},
  [4671] = {.lex_state = 241},
  [4672] = {.lex_state = 206},
  [4673] = {.lex_state = 206},
  [4674] = {.lex_state = 206},
  [4675] = {.lex_state = 241},
  [4676] = {.lex_state = 241},
  [4677] = {.lex_state = 206},
  [4678] = {.lex_state = 239},
  [4679] = {.lex_state = 242},
  [4680] = {.lex_state = 206},
  [4681] = {.lex_state = 241},
  [4682] = {.lex_state = 241},
  [4683] = {.lex_state = 241},
  [4684] = {.lex_state = 241},
  [4685] = {.lex_state = 241},
  [4686] = {.lex_state = 206},
  [4687] = {.lex_state = 206},
  [4688] = {.lex_state = 206},
  [4689] = {.lex_state = 206},
  [4690] = {.lex_state = 206},
  [4691] = {.lex_state = 242},
  [4692] = {.lex_state = 206},
  [4693] = {.lex_state = 241},
  [4694] = {.lex_state = 241},
  [4695] = {.lex_state = 231},
  [4696] = {.lex_state = 231},
  [4697] = {.lex_state = 206},
  [4698] = {.lex_state = 206},
  [4699] = {.lex_state = 206},
  [4700] = {.lex_state = 206},
  [4701] = {.lex_state = 206},
  [4702] = {.lex_state = 206},
  [4703] = {.lex_state = 242},
  [4704] = {.lex_state = 206},
  [4705] = {.lex_state = 206},
  [4706] = {.lex_state = 206},
  [4707] = {.lex_state = 206},
  [4708] = {.lex_state = 206},
  [4709] = {.lex_state = 206},
  [4710] = {.lex_state = 241},
  [4711] = {.lex_state = 206},
  [4712] = {.lex_state = 206},
  [4713] = {.lex_state = 206},
  [4714] = {.lex_state = 206},
  [4715] = {.lex_state = 206},
  [4716] = {.lex_state = 206},
  [4717] = {.lex_state = 206},
  [4718] = {.lex_state = 230},
  [4719] = {.lex_state = 241},
  [4720] = {.lex_state = 242},
  [4721] = {.lex_state = 242},
  [4722] = {.lex_state = 243},
  [4723] = {.lex_state = 241},
  [4724] = {.lex_state = 206},
  [4725] = {.lex_state = 241},
  [4726] = {.lex_state = 206},
  [4727] = {.lex_state = 206},
  [4728] = {.lex_state = 206},
  [4729] = {.lex_state = 206},
  [4730] = {.lex_state = 241},
  [4731] = {.lex_state = 206},
  [4732] = {.lex_state = 239},
  [4733] = {.lex_state = 241},
  [4734] = {.lex_state = 206},
  [4735] = {.lex_state = 241},
  [4736] = {.lex_state = 241},
  [4737] = {.lex_state = 230},
  [4738] = {.lex_state = 241},
  [4739] = {.lex_state = 230},
  [4740] = {.lex_state = 230},
  [4741] = {.lex_state = 230},
  [4742] = {.lex_state = 230},
  [4743] = {.lex_state = 241},
  [4744] = {.lex_state = 206},
  [4745] = {.lex_state = 239},
  [4746] = {.lex_state = 230},
  [4747] = {.lex_state = 239},
  [4748] = {.lex_state = 230},
  [4749] = {.lex_state = 230},
  [4750] = {.lex_state = 205},
  [4751] = {.lex_state = 241},
  [4752] = {.lex_state = 241},
  [4753] = {.lex_state = 241},
  [4754] = {.lex_state = 230},
  [4755] = {.lex_state = 241},
  [4756] = {.lex_state = 239},
  [4757] = {.lex_state = 230},
  [4758] = {.lex_state = 241},
  [4759] = {.lex_state = 230},
  [4760] = {.lex_state = 230},
  [4761] = {.lex_state = 206},
  [4762] = {.lex_state = 230},
  [4763] = {.lex_state = 230},
  [4764] = {.lex_state = 230},
  [4765] = {.lex_state = 241},
  [4766] = {.lex_state = 241},
  [4767] = {.lex_state = 241},
  [4768] = {.lex_state = 241},
  [4769] = {.lex_state = 241},
  [4770] = {.lex_state = 206},
  [4771] = {.lex_state = 239},
  [4772] = {.lex_state = 230},
  [4773] = {.lex_state = 230},
  [4774] = {.lex_state = 230},
  [4775] = {.lex_state = 230},
  [4776] = {.lex_state = 230},
  [4777] = {.lex_state = 241},
  [4778] = {.lex_state = 225},
  [4779] = {.lex_state = 206},
  [4780] = {.lex_state = 241},
  [4781] = {.lex_state = 241},
  [4782] = {.lex_state = 241},
  [4783] = {.lex_state = 241},
  [4784] = {.lex_state = 239},
  [4785] = {.lex_state = 241},
  [4786] = {.lex_state = 239},
  [4787] = {.lex_state = 241},
  [4788] = {.lex_state = 239},
  [4789] = {.lex_state = 230},
  [4790] = {.lex_state = 230},
  [4791] = {.lex_state = 207},
  [4792] = {.lex_state = 230},
  [4793] = {.lex_state = 239},
  [4794] = {.lex_state = 230},
  [4795] = {.lex_state = 242},
  [4796] = {.lex_state = 230},
  [4797] = {.lex_state = 230},
  [4798] = {.lex_state = 230},
  [4799] = {.lex_state = 230},
  [4800] = {.lex_state = 239},
  [4801] = {.lex_state = 230},
  [4802] = {.lex_state = 230},
  [4803] = {.lex_state = 239},
  [4804] = {.lex_state = 241},
  [4805] = {.lex_state = 241},
  [4806] = {.lex_state = 239},
  [4807] = {.lex_state = 230},
  [4808] = {.lex_state = 230},
  [4809] = {.lex_state = 241},
  [4810] = {.lex_state = 241},
  [4811] = {.lex_state = 241},
  [4812] = {.lex_state = 230},
  [4813] = {.lex_state = 241},
  [4814] = {.lex_state = 241},
  [4815] = {.lex_state = 243},
  [4816] = {.lex_state = 230},
  [4817] = {.lex_state = 239},
  [4818] = {.lex_state = 230},
  [4819] = {.lex_state = 239},
  [4820] = {.lex_state = 230},
  [4821] = {.lex_state = 230},
  [4822] = {.lex_state = 239},
  [4823] = {.lex_state = 230},
  [4824] = {.lex_state = 241},
  [4825] = {.lex_state = 241},
  [4826] = {.lex_state = 242},
  [4827] = {.lex_state = 239},
  [4828] = {.lex_state = 230},
  [4829] = {.lex_state = 243},
  [4830] = {.lex_state = 230},
  [4831] = {.lex_state = 239},
  [4832] = {.lex_state = 239},
  [4833] = {.lex_state = 239},
  [4834] = {.lex_state = 241},
  [4835] = {.lex_state = 239},
  [4836] = {.lex_state = 239},
  [4837] = {.lex_state = 230},
  [4838] = {.lex_state = 230},
  [4839] = {.lex_state = 241},
  [4840] = {.lex_state = 230},
  [4841] = {.lex_state = 230},
  [4842] = {.lex_state = 243},
  [4843] = {.lex_state = 243},
  [4844] = {.lex_state = 238},
  [4845] = {.lex_state = 242},
  [4846] = {.lex_state = 206},
  [4847] = {.lex_state = 242},
  [4848] = {.lex_state = 242},
  [4849] = {.lex_state = 238},
  [4850] = {.lex_state = 238},
  [4851] = {.lex_state = 242},
  [4852] = {.lex_state = 225},
  [4853] = {.lex_state = 225},
  [4854] = {.lex_state = 242},
  [4855] = {.lex_state = 242},
  [4856] = {.lex_state = 242},
  [4857] = {.lex_state = 238},
  [4858] = {.lex_state = 242},
  [4859] = {.lex_state = 238},
  [4860] = {.lex_state = 242},
  [4861] = {.lex_state = 238},
  [4862] = {.lex_state = 242},
  [4863] = {.lex_state = 225},
  [4864] = {.lex_state = 242},
  [4865] = {.lex_state = 242},
  [4866] = {.lex_state = 242},
  [4867] = {.lex_state = 242},
  [4868] = {.lex_state = 242},
  [4869] = {.lex_state = 238},
  [4870] = {.lex_state = 242},
  [4871] = {.lex_state = 225},
  [4872] = {.lex_state = 243},
  [4873] = {.lex_state = 243},
  [4874] = {.lex_state = 225},
  [4875] = {.lex_state = 242},
  [4876] = {.lex_state = 242},
  [4877] = {.lex_state = 243},
  [4878] = {.lex_state = 242},
  [4879] = {.lex_state = 242},
  [4880] = {.lex_state = 242},
  [4881] = {.lex_state = 242},
  [4882] = {.lex_state = 242},
  [4883] = {.lex_state = 242},
  [4884] = {.lex_state = 242},
  [4885] = {.lex_state = 242},
  [4886] = {.lex_state = 242},
  [4887] = {.lex_state = 242},
  [4888] = {.lex_state = 242},
  [4889] = {.lex_state = 243},
  [4890] = {.lex_state = 242},
  [4891] = {.lex_state = 243},
  [4892] = {.lex_state = 242},
  [4893] = {.lex_state = 242},
  [4894] = {.lex_state = 242},
  [4895] = {.lex_state = 206},
  [4896] = {.lex_state = 242},
  [4897] = {.lex_state = 242},
  [4898] = {.lex_state = 242},
  [4899] = {.lex_state = 243},
  [4900] = {.lex_state = 242},
  [4901] = {.lex_state = 241},
  [4902] = {.lex_state = 243},
  [4903] = {.lex_state = 242},
  [4904] = {.lex_state = 242},
  [4905] = {.lex_state = 243},
  [4906] = {.lex_state = 242},
  [4907] = {.lex_state = 243},
  [4908] = {.lex_state = 238},
  [4909] = {.lex_state = 242},
  [4910] = {.lex_state = 206},
  [4911] = {.lex_state = 242},
  [4912] = {.lex_state = 242},
  [4913] = {.lex_state = 243},
  [4914] = {.lex_state = 242},
  [4915] = {.lex_state = 242},
  [4916] = {.lex_state = 241},
  [4917] = {.lex_state = 242},
  [4918] = {.lex_state = 243},
  [4919] = {.lex_state = 242},
  [4920] = {.lex_state = 242},
  [4921] = {.lex_state = 242},
  [4922] = {.lex_state = 242},
  [4923] = {.lex_state = 225},
  [4924] = {.lex_state = 242},
  [4925] = {.lex_state = 242},
  [4926] = {.lex_state = 243},
  [4927] = {.lex_state = 242},
  [4928] = {.lex_state = 225},
  [4929] = {.lex_state = 242},
  [4930] = {.lex_state = 242},
  [4931] = {.lex_state = 242},
  [4932] = {.lex_state = 242},
  [4933] = {.lex_state = 242},
  [4934] = {.lex_state = 242},
  [4935] = {.lex_state = 225},
  [4936] = {.lex_state = 242},
  [4937] = {.lex_state = 241},
  [4938] = {.lex_state = 242},
  [4939] = {.lex_state = 242},
  [4940] = {.lex_state = 225},
  [4941] = {.lex_state = 242},
  [4942] = {.lex_state = 243},
  [4943] = {.lex_state = 243},
  [4944] = {.lex_state = 225},
  [4945] = {.lex_state = 242},
  [4946] = {.lex_state = 242},
  [4947] = {.lex_state = 239},
  [4948] = {.lex_state = 238},
  [4949] = {.lex_state = 241},
  [4950] = {.lex_state = 241},
  [4951] = {.lex_state = 243},
  [4952] = {.lex_state = 241},
  [4953] = {.lex_state = 239},
  [4954] = {.lex_state = 238},
  [4955] = {.lex_state = 241},
  [4956] = {.lex_state = 241},
  [4957] = {.lex_state = 230},
  [4958] = {.lex_state = 243},
  [4959] = {.lex_state = 243},
  [4960] = {.lex_state = 243},
  [4961] = {.lex_state = 205},
  [4962] = {.lex_state = 241},
  [4963] = {.lex_state = 241},
  [4964] = {.lex_state = 241},
  [4965] = {.lex_state = 238},
  [4966] = {.lex_state = 206},
  [4967] = {.lex_state = 243},
  [4968] = {.lex_state = 225},
  [4969] = {.lex_state = 238},
  [4970] = {.lex_state = 206},
  [4971] = {.lex_state = 230},
  [4972] = {.lex_state = 241},
  [4973] = {.lex_state = 205},
  [4974] = {.lex_state = 243},
  [4975] = {.lex_state = 241},
  [4976] = {.lex_state = 225},
  [4977] = {.lex_state = 243},
  [4978] = {.lex_state = 241},
  [4979] = {.lex_state = 243},
  [4980] = {.lex_state = 243},
  [4981] = {.lex_state = 243},
  [4982] = {.lex_state = 238},
  [4983] = {.lex_state = 243},
  [4984] = {.lex_state = 239},
  [4985] = {.lex_state = 239},
  [4986] = {.lex_state = 243},
  [4987] = {.lex_state = 242},
  [4988] = {.lex_state = 239},
  [4989] = {.lex_state = 243},
  [4990] = {.lex_state = 243},
  [4991] = {.lex_state = 243},
  [4992] = {.lex_state = 242},
  [4993] = {.lex_state = 243},
  [4994] = {.lex_state = 243},
  [4995] = {.lex_state = 239},
  [4996] = {.lex_state = 243},
  [4997] = {.lex_state = 239},
  [4998] = {.lex_state = 243},
  [4999] = {.lex_state = 243},
  [5000] = {.lex_state = 243},
  [5001] = {.lex_state = 242},
  [5002] = {.lex_state = 243},
  [5003] = {.lex_state = 239},
  [5004] = {.lex_state = 239},
  [5005] = {.lex_state = 239},
  [5006] = {.lex_state = 243},
  [5007] = {.lex_state = 243},
  [5008] = {.lex_state = 239},
  [5009] = {.lex_state = 239},
  [5010] = {.lex_state = 242},
  [5011] = {.lex_state = 242},
  [5012] = {.lex_state = 238},
  [5013] = {.lex_state = 243},
  [5014] = {.lex_state = 243},
  [5015] = {.lex_state = 243},
  [5016] = {.lex_state = 239},
  [5017] = {.lex_state = 239},
  [5018] = {.lex_state = 243},
  [5019] = {.lex_state = 243},
  [5020] = {.lex_state = 243},
  [5021] = {.lex_state = 241},
  [5022] = {.lex_state = 239},
  [5023] = {.lex_state = 238},
  [5024] = {.lex_state = 239},
  [5025] = {.lex_state = 243},
  [5026] = {.lex_state = 243},
  [5027] = {.lex_state = 243},
  [5028] = {.lex_state = 239},
  [5029] = {.lex_state = 242},
  [5030] = {.lex_state = 239},
  [5031] = {.lex_state = 242},
  [5032] = {.lex_state = 243},
  [5033] = {.lex_state = 243},
  [5034] = {.lex_state = 239},
  [5035] = {.lex_state = 243},
  [5036] = {.lex_state = 243},
  [5037] = {.lex_state = 243},
  [5038] = {.lex_state = 239},
  [5039] = {.lex_state = 243},
  [5040] = {.lex_state = 238},
  [5041] = {.lex_state = 242},
  [5042] = {.lex_state = 243},
  [5043] = {.lex_state = 242},
  [5044] = {.lex_state = 242},
  [5045] = {.lex_state = 243},
  [5046] = {.lex_state = 243},
  [5047] = {.lex_state = 242},
  [5048] = {.lex_state = 239},
  [5049] = {.lex_state = 206},
  [5050] = {.lex_state = 239},
  [5051] = {.lex_state = 239},
  [5052] = {.lex_state = 239},
  [5053] = {.lex_state = 206},
  [5054] = {.lex_state = 242},
  [5055] = {.lex_state = 242},
  [5056] = {.lex_state = 206},
  [5057] = {.lex_state = 242},
  [5058] = {.lex_state = 242},
  [5059] = {.lex_state = 242},
  [5060] = {.lex_state = 206},
  [5061] = {.lex_state = 242},
  [5062] = {.lex_state = 242},
  [5063] = {.lex_state = 239},
  [5064] = {.lex_state = 196},
  [5065] = {.lex_state = 196},
  [5066] = {.lex_state = 238},
  [5067] = {.lex_state = 239},
  [5068] = {.lex_state = 241},
  [5069] = {.lex_state = 239},
  [5070] = {.lex_state = 238},
  [5071] = {.lex_state = 239},
  [5072] = {.lex_state = 239},
  [5073] = {.lex_state = 238},
  [5074] = {.lex_state = 241},
  [5075] = {.lex_state = 239},
  [5076] = {.lex_state = 238},
  [5077] = {.lex_state = 238},
  [5078] = {.lex_state = 238},
  [5079] = {.lex_state = 239},
  [5080] = {.lex_state = 239},
  [5081] = {.lex_state = 225},
  [5082] = {.lex_state = 239},
  [5083] = {.lex_state = 239},
  [5084] = {.lex_state = 238},
  [5085] = {.lex_state = 239},
  [5086] = {.lex_state = 238},
  [5087] = {.lex_state = 239},
  [5088] = {.lex_state = 196},
  [5089] = {.lex_state = 196},
  [5090] = {.lex_state = 241},
  [5091] = {.lex_state = 196},
  [5092] = {.lex_state = 239},
  [5093] = {.lex_state = 196},
  [5094] = {.lex_state = 239},
  [5095] = {.lex_state = 238},
  [5096] = {.lex_state = 196},
  [5097] = {.lex_state = 196},
  [5098] = {.lex_state = 239},
  [5099] = {.lex_state = 238},
  [5100] = {.lex_state = 196},
  [5101] = {.lex_state = 196},
  [5102] = {.lex_state = 196},
  [5103] = {.lex_state = 196},
  [5104] = {.lex_state = 238},
  [5105] = {.lex_state = 196},
  [5106] = {.lex_state = 239},
  [5107] = {.lex_state = 196},
  [5108] = {.lex_state = 239},
  [5109] = {.lex_state = 196},
  [5110] = {.lex_state = 196},
  [5111] = {.lex_state = 239},
  [5112] = {.lex_state = 196},
  [5113] = {.lex_state = 196},
  [5114] = {.lex_state = 196},
  [5115] = {.lex_state = 196},
  [5116] = {.lex_state = 196},
  [5117] = {.lex_state = 196},
  [5118] = {.lex_state = 239},
  [5119] = {.lex_state = 238},
  [5120] = {.lex_state = 196},
  [5121] = {.lex_state = 196},
  [5122] = {.lex_state = 239},
  [5123] = {.lex_state = 238},
  [5124] = {.lex_state = 238},
  [5125] = {.lex_state = 196},
  [5126] = {.lex_state = 196},
  [5127] = {.lex_state = 239},
  [5128] = {.lex_state = 238},
  [5129] = {.lex_state = 196},
  [5130] = {.lex_state = 239},
  [5131] = {.lex_state = 239},
  [5132] = {.lex_state = 196},
  [5133] = {.lex_state = 196},
  [5134] = {.lex_state = 239},
  [5135] = {.lex_state = 241},
  [5136] = {.lex_state = 239},
  [5137] = {.lex_state = 196},
  [5138] = {.lex_state = 239},
  [5139] = {.lex_state = 196},
  [5140] = {.lex_state = 196},
  [5141] = {.lex_state = 238},
  [5142] = {.lex_state = 239},
  [5143] = {.lex_state = 239},
  [5144] = {.lex_state = 196},
  [5145] = {.lex_state = 196},
  [5146] = {.lex_state = 239},
  [5147] = {.lex_state = 239},
  [5148] = {.lex_state = 239},
  [5149] = {.lex_state = 239},
  [5150] = {.lex_state = 239},
  [5151] = {.lex_state = 196},
  [5152] = {.lex_state = 196},
  [5153] = {.lex_state = 196},
  [5154] = {.lex_state = 196},
  [5155] = {.lex_state = 196},
  [5156] = {.lex_state = 241},
  [5157] = {.lex_state = 196},
  [5158] = {.lex_state = 196},
  [5159] = {.lex_state = 241},
  [5160] = {.lex_state = 196},
  [5161] = {.lex_state = 196},
  [5162] = {.lex_state = 239},
  [5163] = {.lex_state = 196},
  [5164] = {.lex_state = 196},
  [5165] = {.lex_state = 196},
  [5166] = {.lex_state = 196},
  [5167] = {.lex_state = 196},
  [5168] = {.lex_state = 239},
  [5169] = {.lex_state = 196},
  [5170] = {.lex_state = 196},
  [5171] = {.lex_state = 196},
  [5172] = {.lex_state = 239},
  [5173] = {.lex_state = 239},
  [5174] = {.lex_state = 196},
  [5175] = {.lex_state = 196},
  [5176] = {.lex_state = 196},
  [5177] = {.lex_state = 239},
  [5178] = {.lex_state = 241},
  [5179] = {.lex_state = 196},
  [5180] = {.lex_state = 239},
  [5181] = {.lex_state = 241},
  [5182] = {.lex_state = 196},
  [5183] = {.lex_state = 196},
  [5184] = {.lex_state = 239},
  [5185] = {.lex_state = 196},
  [5186] = {.lex_state = 196},
  [5187] = {.lex_state = 196},
  [5188] = {.lex_state = 241},
  [5189] = {.lex_state = 196},
  [5190] = {.lex_state = 196},
  [5191] = {.lex_state = 225},
  [5192] = {.lex_state = 196},
  [5193] = {.lex_state = 196},
  [5194] = {.lex_state = 196},
  [5195] = {.lex_state = 196},
  [5196] = {.lex_state = 196},
  [5197] = {.lex_state = 196},
  [5198] = {.lex_state = 196},
  [5199] = {.lex_state = 196},
  [5200] = {.lex_state = 243},
  [5201] = {.lex_state = 196},
  [5202] = {.lex_state = 196},
  [5203] = {.lex_state = 196},
  [5204] = {.lex_state = 196},
  [5205] = {.lex_state = 239},
  [5206] = {.lex_state = 239},
  [5207] = {.lex_state = 241},
  [5208] = {.lex_state = 196},
  [5209] = {.lex_state = 239},
  [5210] = {.lex_state = 196},
  [5211] = {.lex_state = 196},
  [5212] = {.lex_state = 196},
  [5213] = {.lex_state = 241},
  [5214] = {.lex_state = 196},
  [5215] = {.lex_state = 239},
  [5216] = {.lex_state = 239},
  [5217] = {.lex_state = 239},
  [5218] = {.lex_state = 239},
  [5219] = {.lex_state = 239},
  [5220] = {.lex_state = 239},
  [5221] = {.lex_state = 239},
  [5222] = {.lex_state = 239},
  [5223] = {.lex_state = 241},
  [5224] = {.lex_state = 242},
  [5225] = {.lex_state = 241},
  [5226] = {.lex_state = 196},
  [5227] = {.lex_state = 242},
  [5228] = {.lex_state = 241},
  [5229] = {.lex_state = 196},
  [5230] = {.lex_state = 241},
  [5231] = {.lex_state = 241},
  [5232] = {.lex_state = 239},
  [5233] = {.lex_state = 239},
  [5234] = {.lex_state = 196},
  [5235] = {.lex_state = 241},
  [5236] = {.lex_state = 242},
  [5237] = {.lex_state = 241},
  [5238] = {.lex_state = 196},
  [5239] = {.lex_state = 241},
  [5240] = {.lex_state = 196},
  [5241] = {.lex_state = 239},
  [5242] = {.lex_state = 241},
  [5243] = {.lex_state = 196},
  [5244] = {.lex_state = 241},
  [5245] = {.lex_state = 242},
  [5246] = {.lex_state = 241},
  [5247] = {.lex_state = 238},
  [5248] = {.lex_state = 242},
  [5249] = {.lex_state = 238},
  [5250] = {.lex_state = 242},
  [5251] = {.lex_state = 241},
  [5252] = {.lex_state = 241},
  [5253] = {.lex_state = 242},
  [5254] = {.lex_state = 241},
  [5255] = {.lex_state = 241},
  [5256] = {.lex_state = 241},
  [5257] = {.lex_state = 241},
  [5258] = {.lex_state = 196},
  [5259] = {.lex_state = 238},
  [5260] = {.lex_state = 242},
  [5261] = {.lex_state = 241},
  [5262] = {.lex_state = 196},
  [5263] = {.lex_state = 241},
  [5264] = {.lex_state = 196},
  [5265] = {.lex_state = 241},
  [5266] = {.lex_state = 196},
  [5267] = {.lex_state = 241},
  [5268] = {.lex_state = 241},
  [5269] = {.lex_state = 238},
  [5270] = {.lex_state = 242},
  [5271] = {.lex_state = 239},
  [5272] = {.lex_state = 242},
  [5273] = {.lex_state = 196},
  [5274] = {.lex_state = 242},
  [5275] = {.lex_state = 239},
  [5276] = {.lex_state = 196},
  [5277] = {.lex_state = 239},
  [5278] = {.lex_state = 241},
  [5279] = {.lex_state = 239},
  [5280] = {.lex_state = 241},
  [5281] = {.lex_state = 241},
  [5282] = {.lex_state = 242},
  [5283] = {.lex_state = 241},
  [5284] = {.lex_state = 241},
  [5285] = {.lex_state = 196},
  [5286] = {.lex_state = 241},
  [5287] = {.lex_state = 196},
  [5288] = {.lex_state = 241},
  [5289] = {.lex_state = 241},
  [5290] = {.lex_state = 241},
  [5291] = {.lex_state = 241},
  [5292] = {.lex_state = 241},
  [5293] = {.lex_state = 239},
  [5294] = {.lex_state = 242},
  [5295] = {.lex_state = 239},
  [5296] = {.lex_state = 241},
  [5297] = {.lex_state = 241},
  [5298] = {.lex_state = 196},
  [5299] = {.lex_state = 241},
  [5300] = {.lex_state = 196},
  [5301] = {.lex_state = 196},
  [5302] = {.lex_state = 196},
  [5303] = {.lex_state = 241},
  [5304] = {.lex_state = 241},
  [5305] = {.lex_state = 239},
  [5306] = {.lex_state = 241},
  [5307] = {.lex_state = 242},
  [5308] = {.lex_state = 239},
  [5309] = {.lex_state = 241},
  [5310] = {.lex_state = 239},
  [5311] = {.lex_state = 239},
  [5312] = {.lex_state = 239},
  [5313] = {.lex_state = 242},
  [5314] = {.lex_state = 242},
  [5315] = {.lex_state = 242},
  [5316] = {.lex_state = 242},
  [5317] = {.lex_state = 241},
  [5318] = {.lex_state = 242},
  [5319] = {.lex_state = 196},
  [5320] = {.lex_state = 196},
  [5321] = {.lex_state = 243},
  [5322] = {.lex_state = 196},
  [5323] = {.lex_state = 243},
  [5324] = {.lex_state = 196},
  [5325] = {.lex_state = 242},
  [5326] = {.lex_state = 242},
  [5327] = {.lex_state = 239},
  [5328] = {.lex_state = 239},
  [5329] = {.lex_state = 242},
  [5330] = {.lex_state = 242},
  [5331] = {.lex_state = 242},
  [5332] = {.lex_state = 242},
  [5333] = {.lex_state = 238},
  [5334] = {.lex_state = 242},
  [5335] = {.lex_state = 242},
  [5336] = {.lex_state = 242},
  [5337] = {.lex_state = 239},
  [5338] = {.lex_state = 242},
  [5339] = {.lex_state = 241},
  [5340] = {.lex_state = 242},
  [5341] = {.lex_state = 242},
  [5342] = {.lex_state = 239},
  [5343] = {.lex_state = 242},
  [5344] = {.lex_state = 196},
  [5345] = {.lex_state = 238},
  [5346] = {.lex_state = 238},
  [5347] = {.lex_state = 251},
  [5348] = {.lex_state = 196},
  [5349] = {.lex_state = 238},
  [5350] = {.lex_state = 196},
  [5351] = {.lex_state = 196},
  [5352] = {.lex_state = 196},
  [5353] = {.lex_state = 242},
  [5354] = {.lex_state = 238},
  [5355] = {.lex_state = 251},
  [5356] = {.lex_state = 238},
  [5357] = {.lex_state = 196},
  [5358] = {.lex_state = 251},
  [5359] = {.lex_state = 251},
  [5360] = {.lex_state = 251},
  [5361] = {.lex_state = 238},
  [5362] = {.lex_state = 251},
  [5363] = {.lex_state = 251},
  [5364] = {.lex_state = 242},
  [5365] = {.lex_state = 242},
  [5366] = {.lex_state = 225},
  [5367] = {.lex_state = 242},
  [5368] = {.lex_state = 238},
  [5369] = {.lex_state = 242},
  [5370] = {.lex_state = 242},
  [5371] = {.lex_state = 238},
  [5372] = {.lex_state = 242},
  [5373] = {.lex_state = 238},
  [5374] = {.lex_state = 238},
  [5375] = {.lex_state = 242},
  [5376] = {.lex_state = 242},
  [5377] = {.lex_state = 242},
  [5378] = {.lex_state = 242},
  [5379] = {.lex_state = 238},
  [5380] = {.lex_state = 242},
  [5381] = {.lex_state = 242},
  [5382] = {.lex_state = 238},
  [5383] = {.lex_state = 242},
  [5384] = {.lex_state = 242},
  [5385] = {.lex_state = 242},
  [5386] = {.lex_state = 242},
  [5387] = {.lex_state = 251},
  [5388] = {.lex_state = 251},
  [5389] = {.lex_state = 196},
  [5390] = {.lex_state = 251},
  [5391] = {.lex_state = 251},
  [5392] = {.lex_state = 251},
  [5393] = {.lex_state = 196},
  [5394] = {.lex_state = 251},
  [5395] = {.lex_state = 251},
  [5396] = {.lex_state = 251},
  [5397] = {.lex_state = 251},
  [5398] = {.lex_state = 251},
  [5399] = {.lex_state = 251},
  [5400] = {.lex_state = 251},
  [5401] = {.lex_state = 251},
  [5402] = {.lex_state = 251},
  [5403] = {.lex_state = 251},
  [5404] = {.lex_state = 251},
  [5405] = {.lex_state = 251},
  [5406] = {.lex_state = 251},
  [5407] = {.lex_state = 251},
  [5408] = {.lex_state = 251},
  [5409] = {.lex_state = 225},
  [5410] = {.lex_state = 251},
  [5411] = {.lex_state = 251},
  [5412] = {.lex_state = 251},
  [5413] = {.lex_state = 225},
  [5414] = {.lex_state = 196},
  [5415] = {.lex_state = 225},
  [5416] = {.lex_state = 251},
  [5417] = {.lex_state = 251},
  [5418] = {.lex_state = 251},
  [5419] = {.lex_state = 196},
  [5420] = {.lex_state = 242},
  [5421] = {.lex_state = 196},
  [5422] = {.lex_state = 251},
  [5423] = {.lex_state = 251},
  [5424] = {.lex_state = 196},
  [5425] = {.lex_state = 195},
  [5426] = {.lex_state = 251},
  [5427] = {.lex_state = 251},
  [5428] = {.lex_state = 251},
  [5429] = {.lex_state = 251},
  [5430] = {.lex_state = 251},
  [5431] = {.lex_state = 251},
  [5432] = {.lex_state = 251},
  [5433] = {.lex_state = 225},
  [5434] = {.lex_state = 196},
  [5435] = {.lex_state = 196},
  [5436] = {.lex_state = 196},
  [5437] = {.lex_state = 196},
  [5438] = {.lex_state = 196},
  [5439] = {.lex_state = 196},
  [5440] = {.lex_state = 196},
  [5441] = {.lex_state = 99},
  [5442] = {.lex_state = 196},
  [5443] = {.lex_state = 242},
  [5444] = {.lex_state = 196},
  [5445] = {.lex_state = 196},
  [5446] = {.lex_state = 196},
  [5447] = {.lex_state = 196},
  [5448] = {.lex_state = 196},
  [5449] = {.lex_state = 196},
  [5450] = {.lex_state = 196},
  [5451] = {.lex_state = 196},
  [5452] = {.lex_state = 196},
  [5453] = {.lex_state = 196},
  [5454] = {.lex_state = 196},
  [5455] = {.lex_state = 196},
  [5456] = {.lex_state = 196},
  [5457] = {.lex_state = 196},
  [5458] = {.lex_state = 196},
  [5459] = {.lex_state = 196},
  [5460] = {.lex_state = 196},
  [5461] = {.lex_state = 196},
  [5462] = {.lex_state = 196},
  [5463] = {.lex_state = 196},
  [5464] = {.lex_state = 196},
  [5465] = {.lex_state = 196},
  [5466] = {.lex_state = 196},
  [5467] = {.lex_state = 196},
  [5468] = {.lex_state = 196},
  [5469] = {.lex_state = 178},
  [5470] = {.lex_state = 196},
  [5471] = {.lex_state = 196},
  [5472] = {.lex_state = 196},
  [5473] = {.lex_state = 196},
  [5474] = {.lex_state = 196},
  [5475] = {.lex_state = 196},
  [5476] = {.lex_state = 196},
  [5477] = {.lex_state = 196},
  [5478] = {.lex_state = 178},
  [5479] = {.lex_state = 196},
  [5480] = {.lex_state = 196},
  [5481] = {.lex_state = 196},
  [5482] = {.lex_state = 196},
  [5483] = {.lex_state = 196},
  [5484] = {.lex_state = 196},
  [5485] = {.lex_state = 196},
  [5486] = {.lex_state = 195},
  [5487] = {.lex_state = 195},
  [5488] = {.lex_state = 196},
  [5489] = {.lex_state = 196},
  [5490] = {.lex_state = 196},
  [5491] = {.lex_state = 196},
  [5492] = {.lex_state = 196},
  [5493] = {.lex_state = 196},
  [5494] = {.lex_state = 196},
  [5495] = {.lex_state = 196},
  [5496] = {.lex_state = 196},
  [5497] = {.lex_state = 196},
  [5498] = {.lex_state = 196},
  [5499] = {.lex_state = 196},
  [5500] = {.lex_state = 196},
  [5501] = {.lex_state = 196},
  [5502] = {.lex_state = 196},
  [5503] = {.lex_state = 243},
  [5504] = {.lex_state = 196},
  [5505] = {.lex_state = 178},
  [5506] = {.lex_state = 195},
  [5507] = {.lex_state = 196},
  [5508] = {.lex_state = 196},
  [5509] = {.lex_state = 196},
  [5510] = {.lex_state = 196},
  [5511] = {.lex_state = 196},
  [5512] = {.lex_state = 196},
  [5513] = {.lex_state = 196},
  [5514] = {.lex_state = 196},
  [5515] = {.lex_state = 196},
  [5516] = {.lex_state = 196},
  [5517] = {.lex_state = 196},
  [5518] = {.lex_state = 196},
  [5519] = {.lex_state = 196},
  [5520] = {.lex_state = 196},
  [5521] = {.lex_state = 196},
  [5522] = {.lex_state = 196},
  [5523] = {.lex_state = 196},
  [5524] = {.lex_state = 196},
  [5525] = {.lex_state = 196},
  [5526] = {.lex_state = 196},
  [5527] = {.lex_state = 196},
  [5528] = {.lex_state = 196},
  [5529] = {.lex_state = 196},
  [5530] = {.lex_state = 196},
  [5531] = {.lex_state = 196},
  [5532] = {.lex_state = 196},
  [5533] = {.lex_state = 178},
  [5534] = {.lex_state = 239},
  [5535] = {.lex_state = 178},
  [5536] = {.lex_state = 178},
  [5537] = {.lex_state = 195},
  [5538] = {.lex_state = 178},
  [5539] = {.lex_state = 242},
  [5540] = {.lex_state = 195},
  [5541] = {.lex_state = 225},
  [5542] = {.lex_state = 225},
  [5543] = {.lex_state = 195},
  [5544] = {.lex_state = 178},
  [5545] = {.lex_state = 239},
  [5546] = {.lex_state = 178},
  [5547] = {.lex_state = 178},
  [5548] = {.lex_state = 242},
  [5549] = {.lex_state = 239},
  [5550] = {.lex_state = 195},
  [5551] = {.lex_state = 242},
  [5552] = {.lex_state = 242},
  [5553] = {.lex_state = 178},
  [5554] = {.lex_state = 241},
  [5555] = {.lex_state = 178},
  [5556] = {.lex_state = 242},
  [5557] = {.lex_state = 195},
  [5558] = {.lex_state = 178},
  [5559] = {.lex_state = 178},
  [5560] = {.lex_state = 225},
  [5561] = {.lex_state = 242},
  [5562] = {.lex_state = 242},
  [5563] = {.lex_state = 239},
  [5564] = {.lex_state = 178},
  [5565] = {.lex_state = 239},
  [5566] = {.lex_state = 178},
  [5567] = {.lex_state = 195},
  [5568] = {.lex_state = 178},
  [5569] = {.lex_state = 239},
  [5570] = {.lex_state = 242},
  [5571] = {.lex_state = 225},
  [5572] = {.lex_state = 178},
  [5573] = {.lex_state = 178},
  [5574] = {.lex_state = 225},
  [5575] = {.lex_state = 242},
  [5576] = {.lex_state = 239},
  [5577] = {.lex_state = 239},
  [5578] = {.lex_state = 225},
  [5579] = {.lex_state = 178},
  [5580] = {.lex_state = 239},
  [5581] = {.lex_state = 239},
  [5582] = {.lex_state = 178},
  [5583] = {.lex_state = 178},
  [5584] = {.lex_state = 178},
  [5585] = {.lex_state = 195},
  [5586] = {.lex_state = 195},
  [5587] = {.lex_state = 238},
  [5588] = {.lex_state = 178},
  [5589] = {.lex_state = 239},
  [5590] = {.lex_state = 238},
  [5591] = {.lex_state = 195},
  [5592] = {.lex_state = 195},
  [5593] = {.lex_state = 178},
  [5594] = {.lex_state = 225},
  [5595] = {.lex_state = 178},
  [5596] = {.lex_state = 241},
  [5597] = {.lex_state = 239},
  [5598] = {.lex_state = 178},
  [5599] = {.lex_state = 195},
  [5600] = {.lex_state = 239},
  [5601] = {.lex_state = 195},
  [5602] = {.lex_state = 225},
  [5603] = {.lex_state = 239},
  [5604] = {.lex_state = 178},
  [5605] = {.lex_state = 225},
  [5606] = {.lex_state = 178},
  [5607] = {.lex_state = 225},
  [5608] = {.lex_state = 178},
  [5609] = {.lex_state = 178},
  [5610] = {.lex_state = 239},
  [5611] = {.lex_state = 195},
  [5612] = {.lex_state = 178},
  [5613] = {.lex_state = 178},
  [5614] = {.lex_state = 195},
  [5615] = {.lex_state = 195},
  [5616] = {.lex_state = 239},
  [5617] = {.lex_state = 195},
  [5618] = {.lex_state = 195},
  [5619] = {.lex_state = 178},
  [5620] = {.lex_state = 195},
  [5621] = {.lex_state = 239},
  [5622] = {.lex_state = 178},
  [5623] = {.lex_state = 225},
  [5624] = {.lex_state = 225},
  [5625] = {.lex_state = 225},
  [5626] = {.lex_state = 225},
  [5627] = {.lex_state = 195},
  [5628] = {.lex_state = 225},
  [5629] = {.lex_state = 195},
  [5630] = {.lex_state = 239},
  [5631] = {.lex_state = 178},
  [5632] = {.lex_state = 178},
  [5633] = {.lex_state = 178},
  [5634] = {.lex_state = 178},
  [5635] = {.lex_state = 242},
  [5636] = {.lex_state = 225},
  [5637] = {.lex_state = 178},
  [5638] = {.lex_state = 178},
  [5639] = {.lex_state = 225},
  [5640] = {.lex_state = 178},
  [5641] = {.lex_state = 242},
  [5642] = {.lex_state = 239},
  [5643] = {.lex_state = 242},
  [5644] = {.lex_state = 225},
  [5645] = {.lex_state = 242},
  [5646] = {.lex_state = 196},
  [5647] = {.lex_state = 242},
  [5648] = {.lex_state = 242},
  [5649] = {.lex_state = 242},
  [5650] = {.lex_state = 239},
  [5651] = {.lex_state = 242},
  [5652] = {.lex_state = 242},
  [5653] = {.lex_state = 196},
  [5654] = {.lex_state = 242},
  [5655] = {.lex_state = 99},
  [5656] = {.lex_state = 99},
  [5657] = {.lex_state = 242},
  [5658] = {.lex_state = 99},
  [5659] = {.lex_state = 196},
  [5660] = {.lex_state = 241},
  [5661] = {.lex_state = 242},
  [5662] = {.lex_state = 196},
  [5663] = {.lex_state = 99},
  [5664] = {.lex_state = 242},
  [5665] = {.lex_state = 242},
  [5666] = {.lex_state = 99},
  [5667] = {.lex_state = 99},
  [5668] = {.lex_state = 239},
  [5669] = {.lex_state = 239},
  [5670] = {.lex_state = 99},
  [5671] = {.lex_state = 99},
  [5672] = {.lex_state = 99},
  [5673] = {.lex_state = 242},
  [5674] = {.lex_state = 99},
  [5675] = {.lex_state = 242},
  [5676] = {.lex_state = 242},
  [5677] = {.lex_state = 195},
  [5678] = {.lex_state = 225},
  [5679] = {.lex_state = 195},
  [5680] = {.lex_state = 99},
  [5681] = {.lex_state = 99},
  [5682] = {.lex_state = 99},
  [5683] = {.lex_state = 239},
  [5684] = {.lex_state = 99},
  [5685] = {.lex_state = 99},
  [5686] = {.lex_state = 99},
  [5687] = {.lex_state = 242},
  [5688] = {.lex_state = 239},
  [5689] = {.lex_state = 242},
  [5690] = {.lex_state = 239},
  [5691] = {.lex_state = 99},
  [5692] = {.lex_state = 242},
  [5693] = {.lex_state = 196},
  [5694] = {.lex_state = 99},
  [5695] = {.lex_state = 239},
  [5696] = {.lex_state = 242},
  [5697] = {.lex_state = 239},
  [5698] = {.lex_state = 242},
  [5699] = {.lex_state = 99},
  [5700] = {.lex_state = 242},
  [5701] = {.lex_state = 99},
  [5702] = {.lex_state = 242},
  [5703] = {.lex_state = 99},
  [5704] = {.lex_state = 99},
  [5705] = {.lex_state = 242},
  [5706] = {.lex_state = 99},
  [5707] = {.lex_state = 230},
  [5708] = {.lex_state = 242},
  [5709] = {.lex_state = 242},
  [5710] = {.lex_state = 99},
  [5711] = {.lex_state = 242},
  [5712] = {.lex_state = 99},
  [5713] = {.lex_state = 99},
  [5714] = {.lex_state = 206},
  [5715] = {.lex_state = 99},
  [5716] = {.lex_state = 99},
  [5717] = {.lex_state = 242},
  [5718] = {.lex_state = 225},
  [5719] = {.lex_state = 242},
  [5720] = {.lex_state = 242},
  [5721] = {.lex_state = 242},
  [5722] = {.lex_state = 242},
  [5723] = {.lex_state = 242},
  [5724] = {.lex_state = 196},
  [5725] = {.lex_state = 99},
  [5726] = {.lex_state = 242},
  [5727] = {.lex_state = 242},
  [5728] = {.lex_state = 239},
  [5729] = {.lex_state = 239},
  [5730] = {.lex_state = 225},
  [5731] = {.lex_state = 242},
  [5732] = {.lex_state = 225},
  [5733] = {.lex_state = 239},
  [5734] = {.lex_state = 99},
  [5735] = {.lex_state = 242},
  [5736] = {.lex_state = 242},
  [5737] = {.lex_state = 99},
  [5738] = {.lex_state = 99},
  [5739] = {.lex_state = 242},
  [5740] = {.lex_state = 242},
  [5741] = {.lex_state = 225},
  [5742] = {.lex_state = 242},
  [5743] = {.lex_state = 99},
  [5744] = {.lex_state = 242},
  [5745] = {.lex_state = 242},
  [5746] = {.lex_state = 242},
  [5747] = {.lex_state = 242},
  [5748] = {.lex_state = 242},
  [5749] = {.lex_state = 196},
  [5750] = {.lex_state = 242},
  [5751] = {.lex_state = 242},
  [5752] = {.lex_state = 196},
  [5753] = {.lex_state = 242},
  [5754] = {.lex_state = 242},
  [5755] = {.lex_state = 242},
  [5756] = {.lex_state = 196},
  [5757] = {.lex_state = 225},
  [5758] = {.lex_state = 242},
  [5759] = {.lex_state = 242},
  [5760] = {.lex_state = 242},
  [5761] = {.lex_state = 196},
  [5762] = {.lex_state = 243},
  [5763] = {.lex_state = 196},
  [5764] = {.lex_state = 175},
  [5765] = {.lex_state = 175},
  [5766] = {.lex_state = 243},
  [5767] = {.lex_state = 225},
  [5768] = {.lex_state = 243},
  [5769] = {.lex_state = 241},
  [5770] = {.lex_state = 243},
  [5771] = {.lex_state = 243},
  [5772] = {.lex_state = 242},
  [5773] = {.lex_state = 243},
  [5774] = {.lex_state = 243},
  [5775] = {.lex_state = 243},
  [5776] = {.lex_state = 241},
  [5777] = {.lex_state = 241},
  [5778] = {.lex_state = 243},
  [5779] = {.lex_state = 243},
  [5780] = {.lex_state = 243},
  [5781] = {.lex_state = 243},
  [5782] = {.lex_state = 243},
  [5783] = {.lex_state = 243},
  [5784] = {.lex_state = 243},
  [5785] = {.lex_state = 196},
  [5786] = {.lex_state = 243},
  [5787] = {.lex_state = 243},
  [5788] = {.lex_state = 234},
  [5789] = {.lex_state = 196},
  [5790] = {.lex_state = 242},
  [5791] = {.lex_state = 241},
  [5792] = {.lex_state = 242},
  [5793] = {.lex_state = 241},
  [5794] = {.lex_state = 234},
  [5795] = {.lex_state = 238},
  [5796] = {.lex_state = 242},
  [5797] = {.lex_state = 243},
  [5798] = {.lex_state = 242},
  [5799] = {.lex_state = 243},
  [5800] = {.lex_state = 175},
  [5801] = {.lex_state = 196},
  [5802] = {.lex_state = 243},
  [5803] = {.lex_state = 242},
  [5804] = {.lex_state = 196},
  [5805] = {.lex_state = 241},
  [5806] = {.lex_state = 243},
  [5807] = {.lex_state = 241},
  [5808] = {.lex_state = 243},
  [5809] = {.lex_state = 243},
  [5810] = {.lex_state = 243},
  [5811] = {.lex_state = 175},
  [5812] = {.lex_state = 175},
  [5813] = {.lex_state = 175},
  [5814] = {.lex_state = 241},
  [5815] = {.lex_state = 225},
  [5816] = {.lex_state = 243},
  [5817] = {.lex_state = 225},
  [5818] = {.lex_state = 243},
  [5819] = {.lex_state = 238},
  [5820] = {.lex_state = 196},
  [5821] = {.lex_state = 241},
  [5822] = {.lex_state = 175},
  [5823] = {.lex_state = 175},
  [5824] = {.lex_state = 241},
  [5825] = {.lex_state = 175},
  [5826] = {.lex_state = 243},
  [5827] = {.lex_state = 242},
  [5828] = {.lex_state = 243},
  [5829] = {.lex_state = 234},
  [5830] = {.lex_state = 242},
  [5831] = {.lex_state = 225},
  [5832] = {.lex_state = 241},
  [5833] = {.lex_state = 243},
  [5834] = {.lex_state = 234},
  [5835] = {.lex_state = 242},
  [5836] = {.lex_state = 238},
  [5837] = {.lex_state = 242},
  [5838] = {.lex_state = 175},
  [5839] = {.lex_state = 243},
  [5840] = {.lex_state = 175},
  [5841] = {.lex_state = 239},
  [5842] = {.lex_state = 239},
  [5843] = {.lex_state = 239},
  [5844] = {.lex_state = 239},
  [5845] = {.lex_state = 239},
  [5846] = {.lex_state = 243},
  [5847] = {.lex_state = 243},
  [5848] = {.lex_state = 239},
  [5849] = {.lex_state = 206},
  [5850] = {.lex_state = 239},
  [5851] = {.lex_state = 239},
  [5852] = {.lex_state = 242},
  [5853] = {.lex_state = 243},
  [5854] = {.lex_state = 239},
  [5855] = {.lex_state = 196},
  [5856] = {.lex_state = 239},
  [5857] = {.lex_state = 239},
  [5858] = {.lex_state = 242},
  [5859] = {.lex_state = 242},
  [5860] = {.lex_state = 239},
  [5861] = {.lex_state = 239},
  [5862] = {.lex_state = 243},
  [5863] = {.lex_state = 239},
  [5864] = {.lex_state = 239},
  [5865] = {.lex_state = 239},
  [5866] = {.lex_state = 243},
  [5867] = {.lex_state = 243},
  [5868] = {.lex_state = 243},
  [5869] = {.lex_state = 242},
  [5870] = {.lex_state = 242},
  [5871] = {.lex_state = 242},
  [5872] = {.lex_state = 196},
  [5873] = {.lex_state = 243},
  [5874] = {.lex_state = 175},
  [5875] = {.lex_state = 239},
  [5876] = {.lex_state = 206},
  [5877] = {.lex_state = 242},
  [5878] = {.lex_state = 242},
  [5879] = {.lex_state = 239},
  [5880] = {.lex_state = 239},
  [5881] = {.lex_state = 242},
  [5882] = {.lex_state = 242},
  [5883] = {.lex_state = 243},
  [5884] = {.lex_state = 242},
  [5885] = {.lex_state = 242},
  [5886] = {.lex_state = 242},
  [5887] = {.lex_state = 175},
  [5888] = {.lex_state = 197},
  [5889] = {.lex_state = 241},
  [5890] = {.lex_state = 241},
  [5891] = {.lex_state = 242},
  [5892] = {.lex_state = 242},
  [5893] = {.lex_state = 242},
  [5894] = {.lex_state = 196},
  [5895] = {.lex_state = 242},
  [5896] = {.lex_state = 242},
  [5897] = {.lex_state = 196},
  [5898] = {.lex_state = 242},
  [5899] = {.lex_state = 242},
  [5900] = {.lex_state = 242},
  [5901] = {.lex_state = 242},
  [5902] = {.lex_state = 196},
  [5903] = {.lex_state = 242},
  [5904] = {.lex_state = 242},
  [5905] = {.lex_state = 242},
  [5906] = {.lex_state = 197},
  [5907] = {.lex_state = 242},
  [5908] = {.lex_state = 188},
  [5909] = {.lex_state = 242},
  [5910] = {.lex_state = 188},
  [5911] = {.lex_state = 188},
  [5912] = {.lex_state = 175},
  [5913] = {.lex_state = 188},
  [5914] = {.lex_state = 197},
  [5915] = {.lex_state = 242},
  [5916] = {.lex_state = 242},
  [5917] = {.lex_state = 242},
  [5918] = {.lex_state = 242},
  [5919] = {.lex_state = 181},
  [5920] = {.lex_state = 242},
  [5921] = {.lex_state = 175},
  [5922] = {.lex_state = 188},
  [5923] = {.lex_state = 197},
  [5924] = {.lex_state = 242},
  [5925] = {.lex_state = 175},
  [5926] = {.lex_state = 197},
  [5927] = {.lex_state = 242},
  [5928] = {.lex_state = 175},
  [5929] = {.lex_state = 241},
  [5930] = {.lex_state = 196},
  [5931] = {.lex_state = 242},
  [5932] = {.lex_state = 242},
  [5933] = {.lex_state = 242},
  [5934] = {.lex_state = 242},
  [5935] = {.lex_state = 188},
  [5936] = {.lex_state = 242},
  [5937] = {.lex_state = 188},
  [5938] = {.lex_state = 188},
  [5939] = {.lex_state = 242},
  [5940] = {.lex_state = 188},
  [5941] = {.lex_state = 242},
  [5942] = {.lex_state = 197},
  [5943] = {.lex_state = 196},
  [5944] = {.lex_state = 242},
  [5945] = {.lex_state = 175},
  [5946] = {.lex_state = 242},
  [5947] = {.lex_state = 242},
  [5948] = {.lex_state = 241},
  [5949] = {.lex_state = 242},
  [5950] = {.lex_state = 241},
  [5951] = {.lex_state = 242},
  [5952] = {.lex_state = 242},
  [5953] = {.lex_state = 242},
  [5954] = {.lex_state = 242},
  [5955] = {.lex_state = 242},
  [5956] = {.lex_state = 242},
  [5957] = {.lex_state = 242},
  [5958] = {.lex_state = 242},
  [5959] = {.lex_state = 242},
  [5960] = {.lex_state = 175},
  [5961] = {.lex_state = 241},
  [5962] = {.lex_state = 188},
  [5963] = {.lex_state = 188},
  [5964] = {.lex_state = 241},
  [5965] = {.lex_state = 175},
  [5966] = {.lex_state = 188},
  [5967] = {.lex_state = 242},
  [5968] = {.lex_state = 197},
  [5969] = {.lex_state = 196},
  [5970] = {.lex_state = 242},
  [5971] = {.lex_state = 242},
  [5972] = {.lex_state = 196},
  [5973] = {.lex_state = 242},
  [5974] = {.lex_state = 196},
  [5975] = {.lex_state = 175},
  [5976] = {.lex_state = 242},
  [5977] = {.lex_state = 197},
  [5978] = {.lex_state = 188},
  [5979] = {.lex_state = 175},
  [5980] = {.lex_state = 241},
  [5981] = {.lex_state = 188},
  [5982] = {.lex_state = 242},
  [5983] = {.lex_state = 242},
  [5984] = {.lex_state = 188},
  [5985] = {.lex_state = 242},
  [5986] = {.lex_state = 242},
  [5987] = {.lex_state = 242},
  [5988] = {.lex_state = 242},
  [5989] = {.lex_state = 205},
  [5990] = {.lex_state = 216},
  [5991] = {.lex_state = 196},
  [5992] = {.lex_state = 200},
  [5993] = {.lex_state = 196},
  [5994] = {.lex_state = 234},
  [5995] = {.lex_state = 242},
  [5996] = {.lex_state = 188},
  [5997] = {.lex_state = 196},
  [5998] = {.lex_state = 200},
  [5999] = {.lex_state = 196},
  [6000] = {.lex_state = 200},
  [6001] = {.lex_state = 242},
  [6002] = {.lex_state = 243},
  [6003] = {.lex_state = 196},
  [6004] = {.lex_state = 242},
  [6005] = {.lex_state = 242},
  [6006] = {.lex_state = 200},
  [6007] = {.lex_state = 196},
  [6008] = {.lex_state = 234},
  [6009] = {.lex_state = 196},
  [6010] = {.lex_state = 188},
  [6011] = {.lex_state = 242},
  [6012] = {.lex_state = 243},
  [6013] = {.lex_state = 242},
  [6014] = {.lex_state = 242},
  [6015] = {.lex_state = 200},
  [6016] = {.lex_state = 200},
  [6017] = {.lex_state = 242},
  [6018] = {.lex_state = 242},
  [6019] = {.lex_state = 200},
  [6020] = {.lex_state = 188},
  [6021] = {.lex_state = 243},
  [6022] = {.lex_state = 196},
  [6023] = {.lex_state = 243},
  [6024] = {.lex_state = 238},
  [6025] = {.lex_state = 242},
  [6026] = {.lex_state = 196},
  [6027] = {.lex_state = 243},
  [6028] = {.lex_state = 200},
  [6029] = {.lex_state = 242},
  [6030] = {.lex_state = 196},
  [6031] = {.lex_state = 200},
  [6032] = {.lex_state = 200},
  [6033] = {.lex_state = 243},
  [6034] = {.lex_state = 216},
  [6035] = {.lex_state = 188},
  [6036] = {.lex_state = 242},
  [6037] = {.lex_state = 216},
  [6038] = {.lex_state = 188},
  [6039] = {.lex_state = 200},
  [6040] = {.lex_state = 242},
  [6041] = {.lex_state = 188},
  [6042] = {.lex_state = 196},
  [6043] = {.lex_state = 230},
  [6044] = {.lex_state = 230},
  [6045] = {.lex_state = 196},
  [6046] = {.lex_state = 243},
  [6047] = {.lex_state = 230},
  [6048] = {.lex_state = 242},
  [6049] = {.lex_state = 196},
  [6050] = {.lex_state = 230},
  [6051] = {.lex_state = 243},
  [6052] = {.lex_state = 243},
  [6053] = {.lex_state = 196},
  [6054] = {.lex_state = 234},
  [6055] = {.lex_state = 196},
  [6056] = {.lex_state = 242},
  [6057] = {.lex_state = 196},
  [6058] = {.lex_state = 242},
  [6059] = {.lex_state = 196},
  [6060] = {.lex_state = 196},
  [6061] = {.lex_state = 196},
  [6062] = {.lex_state = 242},
  [6063] = {.lex_state = 230},
  [6064] = {.lex_state = 230},
  [6065] = {.lex_state = 230},
  [6066] = {.lex_state = 200},
  [6067] = {.lex_state = 230},
  [6068] = {.lex_state = 243},
  [6069] = {.lex_state = 242},
  [6070] = {.lex_state = 196},
  [6071] = {.lex_state = 243},
  [6072] = {.lex_state = 243},
  [6073] = {.lex_state = 200},
  [6074] = {.lex_state = 243},
  [6075] = {.lex_state = 216},
  [6076] = {.lex_state = 243},
  [6077] = {.lex_state = 242},
  [6078] = {.lex_state = 196},
  [6079] = {.lex_state = 216},
  [6080] = {.lex_state = 196},
  [6081] = {.lex_state = 216},
  [6082] = {.lex_state = 196},
  [6083] = {.lex_state = 234},
  [6084] = {.lex_state = 242},
  [6085] = {.lex_state = 250},
  [6086] = {.lex_state = 243},
  [6087] = {.lex_state = 200},
  [6088] = {.lex_state = 242},
  [6089] = {.lex_state = 200},
  [6090] = {.lex_state = 200},
  [6091] = {.lex_state = 196},
  [6092] = {.lex_state = 200},
  [6093] = {.lex_state = 243},
  [6094] = {.lex_state = 200},
  [6095] = {.lex_state = 216},
  [6096] = {.lex_state = 216},
  [6097] = {.lex_state = 243},
  [6098] = {.lex_state = 238},
  [6099] = {.lex_state = 243},
  [6100] = {.lex_state = 243},
  [6101] = {.lex_state = 188},
  [6102] = {.lex_state = 242},
  [6103] = {.lex_state = 242},
  [6104] = {.lex_state = 243},
  [6105] = {.lex_state = 242},
  [6106] = {.lex_state = 242},
  [6107] = {.lex_state = 243},
  [6108] = {.lex_state = 0},
  [6109] = {.lex_state = 230},
  [6110] = {.lex_state = 194},
  [6111] = {.lex_state = 242},
  [6112] = {.lex_state = 242},
  [6113] = {.lex_state = 242},
  [6114] = {.lex_state = 196},
  [6115] = {.lex_state = 242},
  [6116] = {.lex_state = 194},
  [6117] = {.lex_state = 230},
  [6118] = {.lex_state = 242},
  [6119] = {.lex_state = 175},
  [6120] = {.lex_state = 194},
  [6121] = {.lex_state = 242},
  [6122] = {.lex_state = 242},
  [6123] = {.lex_state = 196},
  [6124] = {.lex_state = 230},
  [6125] = {.lex_state = 194},
  [6126] = {.lex_state = 194},
  [6127] = {.lex_state = 194},
  [6128] = {.lex_state = 230},
  [6129] = {.lex_state = 0},
  [6130] = {.lex_state = 194},
  [6131] = {.lex_state = 196},
  [6132] = {.lex_state = 196},
  [6133] = {.lex_state = 196},
  [6134] = {.lex_state = 242},
  [6135] = {.lex_state = 196},
  [6136] = {.lex_state = 194},
  [6137] = {.lex_state = 242},
  [6138] = {.lex_state = 242},
  [6139] = {.lex_state = 242},
  [6140] = {.lex_state = 194},
  [6141] = {.lex_state = 230},
  [6142] = {.lex_state = 196},
  [6143] = {.lex_state = 0},
  [6144] = {.lex_state = 230},
  [6145] = {.lex_state = 0},
  [6146] = {.lex_state = 196},
  [6147] = {.lex_state = 0},
  [6148] = {.lex_state = 194},
  [6149] = {.lex_state = 196},
  [6150] = {.lex_state = 242},
  [6151] = {.lex_state = 0},
  [6152] = {.lex_state = 196},
  [6153] = {.lex_state = 194},
  [6154] = {.lex_state = 196},
  [6155] = {.lex_state = 242},
  [6156] = {.lex_state = 0},
  [6157] = {.lex_state = 175},
  [6158] = {.lex_state = 175},
  [6159] = {.lex_state = 242},
  [6160] = {.lex_state = 194},
  [6161] = {.lex_state = 242},
  [6162] = {.lex_state = 242},
  [6163] = {.lex_state = 194},
  [6164] = {.lex_state = 242},
  [6165] = {.lex_state = 230},
  [6166] = {.lex_state = 194},
  [6167] = {.lex_state = 242},
  [6168] = {.lex_state = 230},
  [6169] = {.lex_state = 230},
  [6170] = {.lex_state = 230},
  [6171] = {.lex_state = 196},
  [6172] = {.lex_state = 230},
  [6173] = {.lex_state = 242},
  [6174] = {.lex_state = 196},
  [6175] = {.lex_state = 194},
  [6176] = {.lex_state = 230},
  [6177] = {.lex_state = 242},
  [6178] = {.lex_state = 196},
  [6179] = {.lex_state = 194},
  [6180] = {.lex_state = 196},
  [6181] = {.lex_state = 194},
  [6182] = {.lex_state = 194},
  [6183] = {.lex_state = 194},
  [6184] = {.lex_state = 194},
  [6185] = {.lex_state = 242},
  [6186] = {.lex_state = 196},
  [6187] = {.lex_state = 196},
  [6188] = {.lex_state = 196},
  [6189] = {.lex_state = 238},
  [6190] = {.lex_state = 196},
  [6191] = {.lex_state = 243},
  [6192] = {.lex_state = 196},
  [6193] = {.lex_state = 196},
  [6194] = {.lex_state = 196},
  [6195] = {.lex_state = 196},
  [6196] = {.lex_state = 196},
  [6197] = {.lex_state = 243},
  [6198] = {.lex_state = 196},
  [6199] = {.lex_state = 196},
  [6200] = {.lex_state = 196},
  [6201] = {.lex_state = 243},
  [6202] = {.lex_state = 242},
  [6203] = {.lex_state = 238},
  [6204] = {.lex_state = 243},
  [6205] = {.lex_state = 238},
  [6206] = {.lex_state = 196},
  [6207] = {.lex_state = 196},
  [6208] = {.lex_state = 242},
  [6209] = {.lex_state = 196},
  [6210] = {.lex_state = 238},
  [6211] = {.lex_state = 243},
  [6212] = {.lex_state = 242},
  [6213] = {.lex_state = 196},
  [6214] = {.lex_state = 242},
  [6215] = {.lex_state = 241},
  [6216] = {.lex_state = 242},
  [6217] = {.lex_state = 243},
  [6218] = {.lex_state = 196},
  [6219] = {.lex_state = 196},
  [6220] = {.lex_state = 0},
  [6221] = {.lex_state = 196},
  [6222] = {.lex_state = 196},
  [6223] = {.lex_state = 196},
  [6224] = {.lex_state = 196},
  [6225] = {.lex_state = 243},
  [6226] = {.lex_state = 242},
  [6227] = {.lex_state = 243},
  [6228] = {.lex_state = 196},
  [6229] = {.lex_state = 196},
  [6230] = {.lex_state = 196},
  [6231] = {.lex_state = 196},
  [6232] = {.lex_state = 242},
  [6233] = {.lex_state = 242},
  [6234] = {.lex_state = 242},
  [6235] = {.lex_state = 196},
  [6236] = {.lex_state = 196},
  [6237] = {.lex_state = 196},
  [6238] = {.lex_state = 196},
  [6239] = {.lex_state = 238},
  [6240] = {.lex_state = 242},
  [6241] = {.lex_state = 194},
  [6242] = {.lex_state = 196},
  [6243] = {.lex_state = 196},
  [6244] = {.lex_state = 242},
  [6245] = {.lex_state = 196},
  [6246] = {.lex_state = 197},
  [6247] = {.lex_state = 196},
  [6248] = {.lex_state = 196},
  [6249] = {.lex_state = 196},
  [6250] = {.lex_state = 196},
  [6251] = {.lex_state = 242},
  [6252] = {.lex_state = 196},
  [6253] = {.lex_state = 196},
  [6254] = {.lex_state = 196},
  [6255] = {.lex_state = 196},
  [6256] = {.lex_state = 196},
  [6257] = {.lex_state = 241},
  [6258] = {.lex_state = 196},
  [6259] = {.lex_state = 241},
  [6260] = {.lex_state = 196},
  [6261] = {.lex_state = 241},
  [6262] = {.lex_state = 196},
  [6263] = {.lex_state = 242},
  [6264] = {.lex_state = 196},
  [6265] = {.lex_state = 196},
  [6266] = {.lex_state = 242},
  [6267] = {.lex_state = 242},
  [6268] = {.lex_state = 196},
  [6269] = {.lex_state = 196},
  [6270] = {.lex_state = 242},
  [6271] = {.lex_state = 196},
  [6272] = {.lex_state = 242},
  [6273] = {.lex_state = 242},
  [6274] = {.lex_state = 196},
  [6275] = {.lex_state = 196},
  [6276] = {.lex_state = 196},
  [6277] = {.lex_state = 196},
  [6278] = {.lex_state = 242},
  [6279] = {.lex_state = 242},
  [6280] = {.lex_state = 196},
  [6281] = {.lex_state = 242},
  [6282] = {.lex_state = 196},
  [6283] = {.lex_state = 242},
  [6284] = {.lex_state = 196},
  [6285] = {.lex_state = 196},
  [6286] = {.lex_state = 242},
  [6287] = {.lex_state = 242},
  [6288] = {.lex_state = 196},
  [6289] = {.lex_state = 242},
  [6290] = {.lex_state = 197},
  [6291] = {.lex_state = 196},
  [6292] = {.lex_state = 197},
  [6293] = {.lex_state = 196},
  [6294] = {.lex_state = 196},
  [6295] = {.lex_state = 196},
  [6296] = {.lex_state = 196},
  [6297] = {.lex_state = 241},
  [6298] = {.lex_state = 242},
  [6299] = {.lex_state = 196},
  [6300] = {.lex_state = 196},
  [6301] = {.lex_state = 196},
  [6302] = {.lex_state = 242},
  [6303] = {.lex_state = 196},
  [6304] = {.lex_state = 196},
  [6305] = {.lex_state = 196},
  [6306] = {.lex_state = 196},
  [6307] = {.lex_state = 242},
  [6308] = {.lex_state = 242},
  [6309] = {.lex_state = 242},
  [6310] = {.lex_state = 196},
  [6311] = {.lex_state = 196},
  [6312] = {.lex_state = 242},
  [6313] = {.lex_state = 197},
  [6314] = {.lex_state = 196},
  [6315] = {.lex_state = 196},
  [6316] = {.lex_state = 242},
  [6317] = {.lex_state = 196},
  [6318] = {.lex_state = 196},
  [6319] = {.lex_state = 196},
  [6320] = {.lex_state = 196},
  [6321] = {.lex_state = 241},
  [6322] = {.lex_state = 242},
  [6323] = {.lex_state = 196},
  [6324] = {.lex_state = 196},
  [6325] = {.lex_state = 196},
  [6326] = {.lex_state = 241},
  [6327] = {.lex_state = 196},
  [6328] = {.lex_state = 196},
  [6329] = {.lex_state = 196},
  [6330] = {.lex_state = 196},
  [6331] = {.lex_state = 196},
  [6332] = {.lex_state = 196},
  [6333] = {.lex_state = 196},
  [6334] = {.lex_state = 196},
  [6335] = {.lex_state = 242},
  [6336] = {.lex_state = 196},
  [6337] = {.lex_state = 196},
  [6338] = {.lex_state = 196},
  [6339] = {.lex_state = 196},
  [6340] = {.lex_state = 196},
  [6341] = {.lex_state = 196},
  [6342] = {.lex_state = 197},
  [6343] = {.lex_state = 196},
  [6344] = {.lex_state = 196},
  [6345] = {.lex_state = 196},
  [6346] = {.lex_state = 196},
  [6347] = {.lex_state = 196},
  [6348] = {.lex_state = 196},
  [6349] = {.lex_state = 196},
  [6350] = {.lex_state = 242},
  [6351] = {.lex_state = 242},
  [6352] = {.lex_state = 242},
  [6353] = {.lex_state = 196},
  [6354] = {.lex_state = 196},
  [6355] = {.lex_state = 196},
  [6356] = {.lex_state = 242},
  [6357] = {.lex_state = 242},
  [6358] = {.lex_state = 196},
  [6359] = {.lex_state = 242},
  [6360] = {.lex_state = 242},
  [6361] = {.lex_state = 196},
  [6362] = {.lex_state = 242},
  [6363] = {.lex_state = 238},
  [6364] = {.lex_state = 242},
  [6365] = {.lex_state = 242},
  [6366] = {.lex_state = 196},
  [6367] = {.lex_state = 196},
  [6368] = {.lex_state = 241},
  [6369] = {.lex_state = 242},
  [6370] = {.lex_state = 242},
  [6371] = {.lex_state = 196},
  [6372] = {.lex_state = 241},
  [6373] = {.lex_state = 196},
  [6374] = {.lex_state = 196},
  [6375] = {.lex_state = 196},
  [6376] = {.lex_state = 197},
  [6377] = {.lex_state = 196},
  [6378] = {.lex_state = 197},
  [6379] = {.lex_state = 196},
  [6380] = {.lex_state = 196},
  [6381] = {.lex_state = 197},
  [6382] = {.lex_state = 230},
  [6383] = {.lex_state = 225},
  [6384] = {.lex_state = 225},
  [6385] = {.lex_state = 225},
  [6386] = {.lex_state = 225},
  [6387] = {.lex_state = 225},
  [6388] = {.lex_state = 225},
  [6389] = {.lex_state = 200},
  [6390] = {.lex_state = 242},
  [6391] = {.lex_state = 242},
  [6392] = {.lex_state = 196},
  [6393] = {.lex_state = 225},
  [6394] = {.lex_state = 181},
  [6395] = {.lex_state = 230},
  [6396] = {.lex_state = 242},
  [6397] = {.lex_state = 230},
  [6398] = {.lex_state = 196},
  [6399] = {.lex_state = 216},
  [6400] = {.lex_state = 242},
  [6401] = {.lex_state = 216},
  [6402] = {.lex_state = 225},
  [6403] = {.lex_state = 216},
  [6404] = {.lex_state = 242},
  [6405] = {.lex_state = 242},
  [6406] = {.lex_state = 216},
  [6407] = {.lex_state = 200},
  [6408] = {.lex_state = 200},
  [6409] = {.lex_state = 242},
  [6410] = {.lex_state = 216},
  [6411] = {.lex_state = 200},
  [6412] = {.lex_state = 216},
  [6413] = {.lex_state = 200},
  [6414] = {.lex_state = 200},
  [6415] = {.lex_state = 216},
  [6416] = {.lex_state = 216},
  [6417] = {.lex_state = 230},
  [6418] = {.lex_state = 230},
  [6419] = {.lex_state = 200},
  [6420] = {.lex_state = 230},
  [6421] = {.lex_state = 225},
  [6422] = {.lex_state = 230},
  [6423] = {.lex_state = 225},
  [6424] = {.lex_state = 200},
  [6425] = {.lex_state = 196},
  [6426] = {.lex_state = 225},
  [6427] = {.lex_state = 337},
  [6428] = {.lex_state = 196},
  [6429] = {.lex_state = 225},
  [6430] = {.lex_state = 225},
  [6431] = {.lex_state = 196},
  [6432] = {.lex_state = 238},
  [6433] = {.lex_state = 242},
  [6434] = {.lex_state = 242},
  [6435] = {.lex_state = 196},
  [6436] = {.lex_state = 242},
  [6437] = {.lex_state = 230},
  [6438] = {.lex_state = 181},
  [6439] = {.lex_state = 337},
  [6440] = {.lex_state = 235},
  [6441] = {.lex_state = 196},
  [6442] = {.lex_state = 175},
  [6443] = {.lex_state = 243},
  [6444] = {.lex_state = 337},
  [6445] = {.lex_state = 243},
  [6446] = {.lex_state = 196},
  [6447] = {.lex_state = 242},
  [6448] = {.lex_state = 243},
  [6449] = {.lex_state = 196},
  [6450] = {.lex_state = 235},
  [6451] = {.lex_state = 196},
  [6452] = {.lex_state = 196},
  [6453] = {.lex_state = 196},
  [6454] = {.lex_state = 196},
  [6455] = {.lex_state = 196},
  [6456] = {.lex_state = 196},
  [6457] = {.lex_state = 196},
  [6458] = {.lex_state = 196},
  [6459] = {.lex_state = 196},
  [6460] = {.lex_state = 196},
  [6461] = {.lex_state = 196},
  [6462] = {.lex_state = 196},
  [6463] = {.lex_state = 241},
  [6464] = {.lex_state = 196},
  [6465] = {.lex_state = 242},
  [6466] = {.lex_state = 235},
  [6467] = {.lex_state = 196},
  [6468] = {.lex_state = 196},
  [6469] = {.lex_state = 243},
  [6470] = {.lex_state = 196},
  [6471] = {.lex_state = 196},
  [6472] = {.lex_state = 196},
  [6473] = {.lex_state = 196},
  [6474] = {.lex_state = 196},
  [6475] = {.lex_state = 196},
  [6476] = {.lex_state = 196},
  [6477] = {.lex_state = 337},
  [6478] = {.lex_state = 337},
  [6479] = {.lex_state = 196},
  [6480] = {.lex_state = 196},
  [6481] = {.lex_state = 196},
  [6482] = {.lex_state = 196},
  [6483] = {.lex_state = 337},
  [6484] = {.lex_state = 196},
  [6485] = {.lex_state = 196},
  [6486] = {.lex_state = 196},
  [6487] = {.lex_state = 196},
  [6488] = {.lex_state = 196},
  [6489] = {.lex_state = 196},
  [6490] = {.lex_state = 196},
  [6491] = {.lex_state = 196},
  [6492] = {.lex_state = 196},
  [6493] = {.lex_state = 337},
  [6494] = {.lex_state = 235},
  [6495] = {.lex_state = 196},
  [6496] = {.lex_state = 337},
  [6497] = {.lex_state = 196},
  [6498] = {.lex_state = 196},
  [6499] = {.lex_state = 196},
  [6500] = {.lex_state = 196},
  [6501] = {.lex_state = 196},
  [6502] = {.lex_state = 196},
  [6503] = {.lex_state = 196},
  [6504] = {.lex_state = 196},
  [6505] = {.lex_state = 196},
  [6506] = {.lex_state = 196},
  [6507] = {.lex_state = 337},
  [6508] = {.lex_state = 337},
  [6509] = {.lex_state = 337},
  [6510] = {.lex_state = 337},
  [6511] = {.lex_state = 337},
  [6512] = {.lex_state = 337},
  [6513] = {.lex_state = 241},
  [6514] = {.lex_state = 242},
  [6515] = {.lex_state = 337},
  [6516] = {.lex_state = 337},
  [6517] = {.lex_state = 181},
  [6518] = {.lex_state = 175},
  [6519] = {.lex_state = 337},
  [6520] = {.lex_state = 337},
  [6521] = {.lex_state = 241},
  [6522] = {.lex_state = 337},
  [6523] = {.lex_state = 225},
  [6524] = {.lex_state = 337},
  [6525] = {.lex_state = 238},
  [6526] = {.lex_state = 337},
  [6527] = {.lex_state = 337},
  [6528] = {.lex_state = 337},
  [6529] = {.lex_state = 337},
  [6530] = {.lex_state = 242},
  [6531] = {.lex_state = 175},
  [6532] = {.lex_state = 196},
  [6533] = {.lex_state = 242},
  [6534] = {.lex_state = 337},
  [6535] = {.lex_state = 242},
  [6536] = {.lex_state = 337},
  [6537] = {.lex_state = 337},
  [6538] = {.lex_state = 337},
  [6539] = {.lex_state = 241},
  [6540] = {.lex_state = 337},
  [6541] = {.lex_state = 191},
  [6542] = {.lex_state = 337},
  [6543] = {.lex_state = 225},
  [6544] = {.lex_state = 238},
  [6545] = {.lex_state = 196},
  [6546] = {.lex_state = 241},
  [6547] = {.lex_state = 241},
  [6548] = {.lex_state = 242},
  [6549] = {.lex_state = 337},
  [6550] = {.lex_state = 242},
  [6551] = {.lex_state = 337},
  [6552] = {.lex_state = 337},
  [6553] = {.lex_state = 337},
  [6554] = {.lex_state = 242},
  [6555] = {.lex_state = 238},
  [6556] = {.lex_state = 337},
  [6557] = {.lex_state = 337},
  [6558] = {.lex_state = 337},
  [6559] = {.lex_state = 196},
  [6560] = {.lex_state = 175},
  [6561] = {.lex_state = 337},
  [6562] = {.lex_state = 175},
  [6563] = {.lex_state = 175},
  [6564] = {.lex_state = 175},
  [6565] = {.lex_state = 175},
  [6566] = {.lex_state = 337},
  [6567] = {.lex_state = 196},
  [6568] = {.lex_state = 337},
  [6569] = {.lex_state = 196},
  [6570] = {.lex_state = 196},
  [6571] = {.lex_state = 181},
  [6572] = {.lex_state = 196},
  [6573] = {.lex_state = 191},
  [6574] = {.lex_state = 181},
  [6575] = {.lex_state = 175},
  [6576] = {.lex_state = 191},
  [6577] = {.lex_state = 175},
  [6578] = {.lex_state = 175},
  [6579] = {.lex_state = 241},
  [6580] = {.lex_state = 337},
  [6581] = {.lex_state = 337},
  [6582] = {.lex_state = 196},
  [6583] = {.lex_state = 175},
  [6584] = {.lex_state = 242},
  [6585] = {.lex_state = 242},
  [6586] = {.lex_state = 337},
  [6587] = {.lex_state = 196},
  [6588] = {.lex_state = 175},
  [6589] = {.lex_state = 242},
  [6590] = {.lex_state = 175},
  [6591] = {.lex_state = 337},
  [6592] = {.lex_state = 175},
  [6593] = {.lex_state = 175},
  [6594] = {.lex_state = 181},
  [6595] = {.lex_state = 337},
  [6596] = {.lex_state = 242},
  [6597] = {.lex_state = 175},
  [6598] = {.lex_state = 191},
  [6599] = {.lex_state = 175},
  [6600] = {.lex_state = 191},
  [6601] = {.lex_state = 181},
  [6602] = {.lex_state = 175},
  [6603] = {.lex_state = 175},
  [6604] = {.lex_state = 175},
  [6605] = {.lex_state = 337},
  [6606] = {.lex_state = 238},
  [6607] = {.lex_state = 241},
  [6608] = {.lex_state = 175},
  [6609] = {.lex_state = 196},
  [6610] = {.lex_state = 337},
  [6611] = {.lex_state = 175},
  [6612] = {.lex_state = 175},
  [6613] = {.lex_state = 175},
  [6614] = {.lex_state = 337},
  [6615] = {.lex_state = 175},
  [6616] = {.lex_state = 196},
  [6617] = {.lex_state = 242},
  [6618] = {.lex_state = 241},
  [6619] = {.lex_state = 194},
  [6620] = {.lex_state = 337},
  [6621] = {.lex_state = 238},
  [6622] = {.lex_state = 196},
  [6623] = {.lex_state = 337},
  [6624] = {.lex_state = 196},
  [6625] = {.lex_state = 196},
  [6626] = {.lex_state = 238},
  [6627] = {.lex_state = 196},
  [6628] = {.lex_state = 238},
  [6629] = {.lex_state = 238},
  [6630] = {.lex_state = 194},
  [6631] = {.lex_state = 238},
  [6632] = {.lex_state = 196},
  [6633] = {.lex_state = 196},
  [6634] = {.lex_state = 194},
  [6635] = {.lex_state = 238},
  [6636] = {.lex_state = 238},
  [6637] = {.lex_state = 194},
  [6638] = {.lex_state = 196},
  [6639] = {.lex_state = 243},
  [6640] = {.lex_state = 337},
  [6641] = {.lex_state = 238},
  [6642] = {.lex_state = 194},
  [6643] = {.lex_state = 196},
  [6644] = {.lex_state = 194},
  [6645] = {.lex_state = 243},
  [6646] = {.lex_state = 196},
  [6647] = {.lex_state = 337},
  [6648] = {.lex_state = 196},
  [6649] = {.lex_state = 196},
  [6650] = {.lex_state = 337},
  [6651] = {.lex_state = 196},
  [6652] = {.lex_state = 196},
  [6653] = {.lex_state = 238},
  [6654] = {.lex_state = 194},
  [6655] = {.lex_state = 196},
  [6656] = {.lex_state = 238},
  [6657] = {.lex_state = 242},
  [6658] = {.lex_state = 0},
  [6659] = {.lex_state = 194},
  [6660] = {.lex_state = 238},
  [6661] = {.lex_state = 196},
  [6662] = {.lex_state = 194},
  [6663] = {.lex_state = 196},
  [6664] = {.lex_state = 238},
  [6665] = {.lex_state = 194},
  [6666] = {.lex_state = 194},
  [6667] = {.lex_state = 0},
  [6668] = {.lex_state = 238},
  [6669] = {.lex_state = 196},
  [6670] = {.lex_state = 196},
  [6671] = {.lex_state = 238},
  [6672] = {.lex_state = 196},
  [6673] = {.lex_state = 196},
  [6674] = {.lex_state = 196},
  [6675] = {.lex_state = 196},
  [6676] = {.lex_state = 196},
  [6677] = {.lex_state = 196},
  [6678] = {.lex_state = 196},
  [6679] = {.lex_state = 181},
  [6680] = {.lex_state = 196},
  [6681] = {.lex_state = 196},
  [6682] = {.lex_state = 175},
  [6683] = {.lex_state = 175},
  [6684] = {.lex_state = 238},
  [6685] = {.lex_state = 175},
  [6686] = {.lex_state = 181},
  [6687] = {.lex_state = 181},
  [6688] = {.lex_state = 196},
  [6689] = {.lex_state = 196},
  [6690] = {.lex_state = 196},
  [6691] = {.lex_state = 196},
  [6692] = {.lex_state = 196},
  [6693] = {.lex_state = 196},
  [6694] = {.lex_state = 181},
  [6695] = {.lex_state = 196},
  [6696] = {.lex_state = 337},
  [6697] = {.lex_state = 196},
  [6698] = {.lex_state = 175},
  [6699] = {.lex_state = 196},
  [6700] = {.lex_state = 196},
  [6701] = {.lex_state = 196},
  [6702] = {.lex_state = 196},
  [6703] = {.lex_state = 196},
  [6704] = {.lex_state = 196},
  [6705] = {.lex_state = 196},
  [6706] = {.lex_state = 196},
  [6707] = {.lex_state = 196},
  [6708] = {.lex_state = 196},
  [6709] = {.lex_state = 196},
  [6710] = {.lex_state = 196},
  [6711] = {.lex_state = 196},
  [6712] = {.lex_state = 196},
  [6713] = {.lex_state = 196},
  [6714] = {.lex_state = 196},
  [6715] = {.lex_state = 238},
  [6716] = {.lex_state = 196},
  [6717] = {.lex_state = 196},
  [6718] = {.lex_state = 238},
  [6719] = {.lex_state = 196},
  [6720] = {.lex_state = 337},
  [6721] = {.lex_state = 196},
  [6722] = {.lex_state = 337},
  [6723] = {.lex_state = 337},
  [6724] = {.lex_state = 196},
  [6725] = {.lex_state = 196},
  [6726] = {.lex_state = 238},
  [6727] = {.lex_state = 175},
  [6728] = {.lex_state = 181},
  [6729] = {.lex_state = 0},
  [6730] = {.lex_state = 175},
  [6731] = {.lex_state = 108},
  [6732] = {.lex_state = 337},
  [6733] = {.lex_state = 0},
  [6734] = {.lex_state = 196},
  [6735] = {.lex_state = 196},
  [6736] = {.lex_state = 175},
  [6737] = {.lex_state = 110},
  [6738] = {.lex_state = 110},
  [6739] = {.lex_state = 181},
  [6740] = {.lex_state = 111},
  [6741] = {.lex_state = 181},
  [6742] = {.lex_state = 337},
  [6743] = {.lex_state = 337},
  [6744] = {.lex_state = 110},
  [6745] = {.lex_state = 110},
  [6746] = {.lex_state = 337},
  [6747] = {.lex_state = 238},
  [6748] = {.lex_state = 337},
  [6749] = {.lex_state = 0},
  [6750] = {.lex_state = 0},
  [6751] = {.lex_state = 110},
  [6752] = {.lex_state = 196},
  [6753] = {.lex_state = 196},
  [6754] = {.lex_state = 110},
  [6755] = {.lex_state = 196},
  [6756] = {.lex_state = 181},
  [6757] = {.lex_state = 337},
  [6758] = {.lex_state = 0},
  [6759] = {.lex_state = 337},
  [6760] = {.lex_state = 337},
  [6761] = {.lex_state = 181},
  [6762] = {.lex_state = 337},
  [6763] = {.lex_state = 175},
  [6764] = {.lex_state = 337},
  [6765] = {.lex_state = 110},
  [6766] = {.lex_state = 181},
  [6767] = {.lex_state = 110},
  [6768] = {.lex_state = 196},
  [6769] = {.lex_state = 0},
  [6770] = {.lex_state = 181},
  [6771] = {.lex_state = 181},
  [6772] = {.lex_state = 110},
  [6773] = {.lex_state = 337},
  [6774] = {.lex_state = 110},
  [6775] = {.lex_state = 337},
  [6776] = {.lex_state = 0},
  [6777] = {.lex_state = 337},
  [6778] = {.lex_state = 0},
  [6779] = {.lex_state = 110},
  [6780] = {.lex_state = 0},
  [6781] = {.lex_state = 337},
  [6782] = {.lex_state = 196},
  [6783] = {.lex_state = 181},
  [6784] = {.lex_state = 110},
  [6785] = {.lex_state = 337},
  [6786] = {.lex_state = 110},
  [6787] = {.lex_state = 108},
  [6788] = {.lex_state = 0},
  [6789] = {.lex_state = 196},
  [6790] = {.lex_state = 238},
  [6791] = {.lex_state = 181},
  [6792] = {.lex_state = 110},
  [6793] = {.lex_state = 175},
  [6794] = {.lex_state = 175},
  [6795] = {.lex_state = 196},
  [6796] = {.lex_state = 181},
  [6797] = {.lex_state = 181},
  [6798] = {.lex_state = 110},
  [6799] = {.lex_state = 181},
  [6800] = {.lex_state = 337},
  [6801] = {.lex_state = 108},
  [6802] = {.lex_state = 0},
  [6803] = {.lex_state = 337},
  [6804] = {.lex_state = 337},
  [6805] = {.lex_state = 337},
  [6806] = {.lex_state = 110},
  [6807] = {.lex_state = 181},
  [6808] = {.lex_state = 181},
  [6809] = {.lex_state = 337},
  [6810] = {.lex_state = 110},
  [6811] = {.lex_state = 181},
  [6812] = {.lex_state = 337},
  [6813] = {.lex_state = 110},
  [6814] = {.lex_state = 181},
  [6815] = {.lex_state = 0},
  [6816] = {.lex_state = 111},
  [6817] = {.lex_state = 111},
  [6818] = {.lex_state = 0},
  [6819] = {.lex_state = 181},
  [6820] = {.lex_state = 181},
  [6821] = {.lex_state = 181},
  [6822] = {.lex_state = 110},
  [6823] = {.lex_state = 108},
  [6824] = {.lex_state = 0},
  [6825] = {.lex_state = 238},
  [6826] = {.lex_state = 196},
  [6827] = {.lex_state = 196},
  [6828] = {.lex_state = 175},
  [6829] = {.lex_state = 110},
  [6830] = {.lex_state = 181},
  [6831] = {.lex_state = 110},
  [6832] = {.lex_state = 181},
  [6833] = {.lex_state = 337},
  [6834] = {.lex_state = 181},
  [6835] = {.lex_state = 181},
  [6836] = {.lex_state = 238},
  [6837] = {.lex_state = 108},
  [6838] = {.lex_state = 110},
  [6839] = {.lex_state = 181},
  [6840] = {.lex_state = 0},
  [6841] = {.lex_state = 196},
  [6842] = {.lex_state = 181},
  [6843] = {.lex_state = 196},
  [6844] = {.lex_state = 337},
  [6845] = {.lex_state = 181},
  [6846] = {.lex_state = 110},
  [6847] = {.lex_state = 337},
  [6848] = {.lex_state = 108},
  [6849] = {.lex_state = 196},
  [6850] = {.lex_state = 196},
  [6851] = {.lex_state = 196},
  [6852] = {.lex_state = 238},
  [6853] = {.lex_state = 175},
  [6854] = {.lex_state = 0},
  [6855] = {.lex_state = 196},
  [6856] = {.lex_state = 337},
  [6857] = {.lex_state = 110},
  [6858] = {.lex_state = 196},
  [6859] = {.lex_state = 108},
  [6860] = {.lex_state = 110},
  [6861] = {.lex_state = 196},
  [6862] = {.lex_state = 181},
  [6863] = {.lex_state = 196},
  [6864] = {.lex_state = 181},
  [6865] = {.lex_state = 175},
  [6866] = {.lex_state = 337},
  [6867] = {.lex_state = 111},
  [6868] = {.lex_state = 337},
  [6869] = {.lex_state = 175},
  [6870] = {.lex_state = 196},
  [6871] = {.lex_state = 238},
  [6872] = {.lex_state = 111},
  [6873] = {.lex_state = 238},
  [6874] = {.lex_state = 0},
  [6875] = {.lex_state = 181},
  [6876] = {.lex_state = 175},
  [6877] = {.lex_state = 181},
  [6878] = {.lex_state = 196},
  [6879] = {.lex_state = 337},
  [6880] = {.lex_state = 181},
  [6881] = {.lex_state = 0},
  [6882] = {.lex_state = 0},
  [6883] = {.lex_state = 181},
  [6884] = {.lex_state = 175},
  [6885] = {.lex_state = 337},
  [6886] = {.lex_state = 337},
  [6887] = {.lex_state = 175},
  [6888] = {.lex_state = 196},
  [6889] = {.lex_state = 108},
  [6890] = {.lex_state = 181},
  [6891] = {.lex_state = 110},
  [6892] = {.lex_state = 108},
  [6893] = {.lex_state = 196},
  [6894] = {.lex_state = 196},
  [6895] = {.lex_state = 110},
  [6896] = {.lex_state = 175},
  [6897] = {.lex_state = 181},
  [6898] = {.lex_state = 337},
  [6899] = {.lex_state = 175},
  [6900] = {.lex_state = 111},
  [6901] = {.lex_state = 175},
  [6902] = {.lex_state = 337},
  [6903] = {.lex_state = 0},
  [6904] = {.lex_state = 238},
  [6905] = {.lex_state = 175},
  [6906] = {.lex_state = 196},
  [6907] = {.lex_state = 337},
  [6908] = {.lex_state = 337},
  [6909] = {.lex_state = 337},
  [6910] = {.lex_state = 196},
  [6911] = {.lex_state = 175},
  [6912] = {.lex_state = 196},
  [6913] = {.lex_state = 196},
  [6914] = {.lex_state = 0},
  [6915] = {.lex_state = 110},
  [6916] = {.lex_state = 337},
  [6917] = {.lex_state = 238},
  [6918] = {.lex_state = 110},
  [6919] = {.lex_state = 108},
  [6920] = {.lex_state = 196},
  [6921] = {.lex_state = 337},
  [6922] = {.lex_state = 0},
  [6923] = {.lex_state = 175},
  [6924] = {.lex_state = 196},
  [6925] = {.lex_state = 175},
  [6926] = {.lex_state = 181},
  [6927] = {.lex_state = 337},
  [6928] = {.lex_state = 181},
  [6929] = {.lex_state = 175},
  [6930] = {.lex_state = 196},
  [6931] = {.lex_state = 196},
  [6932] = {.lex_state = 181},
  [6933] = {.lex_state = 196},
  [6934] = {.lex_state = 181},
  [6935] = {.lex_state = 175},
  [6936] = {.lex_state = 175},
  [6937] = {.lex_state = 110},
  [6938] = {.lex_state = 196},
  [6939] = {.lex_state = 181},
  [6940] = {.lex_state = 196},
  [6941] = {.lex_state = 0},
  [6942] = {.lex_state = 238},
  [6943] = {.lex_state = 0},
  [6944] = {.lex_state = 196},
  [6945] = {.lex_state = 181},
  [6946] = {.lex_state = 108},
  [6947] = {.lex_state = 181},
  [6948] = {.lex_state = 181},
  [6949] = {.lex_state = 196},
  [6950] = {.lex_state = 0},
  [6951] = {.lex_state = 175},
  [6952] = {.lex_state = 337},
  [6953] = {.lex_state = 110},
  [6954] = {.lex_state = 110},
  [6955] = {.lex_state = 111},
  [6956] = {.lex_state = 108},
  [6957] = {.lex_state = 196},
  [6958] = {.lex_state = 181},
  [6959] = {.lex_state = 110},
  [6960] = {.lex_state = 181},
  [6961] = {.lex_state = 337},
  [6962] = {.lex_state = 110},
  [6963] = {.lex_state = 181},
  [6964] = {.lex_state = 337},
  [6965] = {.lex_state = 181},
  [6966] = {.lex_state = 181},
  [6967] = {.lex_state = 175},
  [6968] = {.lex_state = 181},
  [6969] = {.lex_state = 110},
  [6970] = {.lex_state = 337},
  [6971] = {.lex_state = 196},
  [6972] = {.lex_state = 110},
  [6973] = {.lex_state = 110},
  [6974] = {.lex_state = 337},
  [6975] = {.lex_state = 181},
  [6976] = {.lex_state = 196},
  [6977] = {.lex_state = 196},
  [6978] = {.lex_state = 175},
  [6979] = {.lex_state = 337},
  [6980] = {.lex_state = 181},
  [6981] = {.lex_state = 181},
  [6982] = {.lex_state = 181},
  [6983] = {.lex_state = 175},
  [6984] = {.lex_state = 196},
  [6985] = {.lex_state = 181},
  [6986] = {.lex_state = 181},
  [6987] = {.lex_state = 196},
  [6988] = {.lex_state = 196},
  [6989] = {.lex_state = 181},
  [6990] = {.lex_state = 196},
  [6991] = {.lex_state = 181},
  [6992] = {.lex_state = 181},
  [6993] = {.lex_state = 181},
  [6994] = {.lex_state = 108},
  [6995] = {.lex_state = 110},
  [6996] = {.lex_state = 181},
  [6997] = {.lex_state = 175},
  [6998] = {.lex_state = 337},
  [6999] = {.lex_state = 181},
  [7000] = {.lex_state = 0},
  [7001] = {.lex_state = 337},
  [7002] = {.lex_state = 175},
  [7003] = {.lex_state = 196},
  [7004] = {.lex_state = 175},
  [7005] = {.lex_state = 175},
  [7006] = {.lex_state = 181},
  [7007] = {.lex_state = 196},
  [7008] = {.lex_state = 196},
  [7009] = {.lex_state = 196},
  [7010] = {.lex_state = 337},
  [7011] = {.lex_state = 110},
  [7012] = {.lex_state = 181},
  [7013] = {.lex_state = 181},
  [7014] = {.lex_state = 0},
  [7015] = {.lex_state = 181},
  [7016] = {.lex_state = 337},
  [7017] = {.lex_state = 181},
  [7018] = {.lex_state = 181},
  [7019] = {.lex_state = 0},
  [7020] = {.lex_state = 0},
  [7021] = {.lex_state = 196},
  [7022] = {.lex_state = 0},
  [7023] = {.lex_state = 181},
  [7024] = {.lex_state = 0},
  [7025] = {.lex_state = 196},
  [7026] = {.lex_state = 0},
  [7027] = {.lex_state = 181},
  [7028] = {.lex_state = 0},
  [7029] = {.lex_state = 196},
  [7030] = {.lex_state = 0},
  [7031] = {.lex_state = 0},
  [7032] = {.lex_state = 0},
  [7033] = {.lex_state = 337},
  [7034] = {.lex_state = 0},
  [7035] = {.lex_state = 239},
  [7036] = {.lex_state = 0},
  [7037] = {.lex_state = 0},
  [7038] = {.lex_state = 196},
  [7039] = {.lex_state = 0},
  [7040] = {.lex_state = 0},
  [7041] = {.lex_state = 0},
  [7042] = {.lex_state = 196},
  [7043] = {.lex_state = 196},
  [7044] = {.lex_state = 0},
  [7045] = {.lex_state = 0},
  [7046] = {.lex_state = 0},
  [7047] = {.lex_state = 0},
  [7048] = {.lex_state = 0},
  [7049] = {.lex_state = 0},
  [7050] = {.lex_state = 181},
  [7051] = {.lex_state = 181},
  [7052] = {.lex_state = 181},
  [7053] = {.lex_state = 0},
  [7054] = {.lex_state = 0},
  [7055] = {.lex_state = 0},
  [7056] = {.lex_state = 0},
  [7057] = {.lex_state = 108},
  [7058] = {.lex_state = 0},
  [7059] = {.lex_state = 181},
  [7060] = {.lex_state = 337},
  [7061] = {.lex_state = 0},
  [7062] = {.lex_state = 337},
  [7063] = {.lex_state = 181},
  [7064] = {.lex_state = 0},
  [7065] = {.lex_state = 181},
  [7066] = {.lex_state = 0},
  [7067] = {.lex_state = 0},
  [7068] = {.lex_state = 0},
  [7069] = {.lex_state = 0},
  [7070] = {.lex_state = 0},
  [7071] = {.lex_state = 196},
  [7072] = {.lex_state = 0},
  [7073] = {.lex_state = 108},
  [7074] = {.lex_state = 175},
  [7075] = {.lex_state = 0},
  [7076] = {.lex_state = 196},
  [7077] = {.lex_state = 181},
  [7078] = {.lex_state = 196},
  [7079] = {.lex_state = 196},
  [7080] = {.lex_state = 0},
  [7081] = {.lex_state = 0},
  [7082] = {.lex_state = 0},
  [7083] = {.lex_state = 0},
  [7084] = {.lex_state = 0},
  [7085] = {.lex_state = 0},
  [7086] = {.lex_state = 0},
  [7087] = {.lex_state = 181},
  [7088] = {.lex_state = 181},
  [7089] = {.lex_state = 0},
  [7090] = {.lex_state = 0},
  [7091] = {.lex_state = 0},
  [7092] = {.lex_state = 0},
  [7093] = {.lex_state = 181},
  [7094] = {.lex_state = 0},
  [7095] = {.lex_state = 0},
  [7096] = {.lex_state = 0},
  [7097] = {.lex_state = 181},
  [7098] = {.lex_state = 0},
  [7099] = {.lex_state = 196},
  [7100] = {.lex_state = 181},
  [7101] = {.lex_state = 181},
  [7102] = {.lex_state = 108},
  [7103] = {.lex_state = 181},
  [7104] = {.lex_state = 181},
  [7105] = {.lex_state = 181},
  [7106] = {.lex_state = 181},
  [7107] = {.lex_state = 337},
  [7108] = {.lex_state = 0},
  [7109] = {.lex_state = 0},
  [7110] = {.lex_state = 196},
  [7111] = {.lex_state = 0},
  [7112] = {.lex_state = 181},
  [7113] = {.lex_state = 181},
  [7114] = {.lex_state = 0},
  [7115] = {.lex_state = 0},
  [7116] = {.lex_state = 0},
  [7117] = {.lex_state = 0},
  [7118] = {.lex_state = 337},
  [7119] = {.lex_state = 0},
  [7120] = {.lex_state = 0},
  [7121] = {.lex_state = 337},
  [7122] = {.lex_state = 0},
  [7123] = {.lex_state = 0},
  [7124] = {.lex_state = 196},
  [7125] = {.lex_state = 0},
  [7126] = {.lex_state = 181},
  [7127] = {.lex_state = 0},
  [7128] = {.lex_state = 0},
  [7129] = {.lex_state = 0},
  [7130] = {.lex_state = 0},
  [7131] = {.lex_state = 0},
  [7132] = {.lex_state = 0},
  [7133] = {.lex_state = 196},
  [7134] = {.lex_state = 0},
  [7135] = {.lex_state = 181},
  [7136] = {.lex_state = 0},
  [7137] = {.lex_state = 196},
  [7138] = {.lex_state = 0},
  [7139] = {.lex_state = 196},
  [7140] = {.lex_state = 0},
  [7141] = {.lex_state = 0},
  [7142] = {.lex_state = 0},
  [7143] = {.lex_state = 181},
  [7144] = {.lex_state = 181},
  [7145] = {.lex_state = 196},
  [7146] = {.lex_state = 0},
  [7147] = {.lex_state = 0},
  [7148] = {.lex_state = 196},
  [7149] = {.lex_state = 0},
  [7150] = {.lex_state = 108},
  [7151] = {.lex_state = 238},
  [7152] = {.lex_state = 0},
  [7153] = {.lex_state = 0},
  [7154] = {.lex_state = 0},
  [7155] = {.lex_state = 196},
  [7156] = {.lex_state = 113},
  [7157] = {.lex_state = 196},
  [7158] = {.lex_state = 196},
  [7159] = {.lex_state = 0},
  [7160] = {.lex_state = 0},
  [7161] = {.lex_state = 0},
  [7162] = {.lex_state = 181},
  [7163] = {.lex_state = 0},
  [7164] = {.lex_state = 196},
  [7165] = {.lex_state = 0},
  [7166] = {.lex_state = 0},
  [7167] = {.lex_state = 337},
  [7168] = {.lex_state = 0},
  [7169] = {.lex_state = 0},
  [7170] = {.lex_state = 181},
  [7171] = {.lex_state = 337},
  [7172] = {.lex_state = 0},
  [7173] = {.lex_state = 0},
  [7174] = {.lex_state = 196},
  [7175] = {.lex_state = 0},
  [7176] = {.lex_state = 181},
  [7177] = {.lex_state = 0},
  [7178] = {.lex_state = 0},
  [7179] = {.lex_state = 113},
  [7180] = {.lex_state = 0},
  [7181] = {.lex_state = 0},
  [7182] = {.lex_state = 0},
  [7183] = {.lex_state = 0},
  [7184] = {.lex_state = 0},
  [7185] = {.lex_state = 0},
  [7186] = {.lex_state = 0},
  [7187] = {.lex_state = 0},
  [7188] = {.lex_state = 113},
  [7189] = {.lex_state = 0},
  [7190] = {.lex_state = 0},
  [7191] = {.lex_state = 0},
  [7192] = {.lex_state = 337},
  [7193] = {.lex_state = 337},
  [7194] = {.lex_state = 0},
  [7195] = {.lex_state = 196},
  [7196] = {.lex_state = 196},
  [7197] = {.lex_state = 337},
  [7198] = {.lex_state = 181},
  [7199] = {.lex_state = 0},
  [7200] = {.lex_state = 196},
  [7201] = {.lex_state = 337},
  [7202] = {.lex_state = 0},
  [7203] = {.lex_state = 0},
  [7204] = {.lex_state = 181},
  [7205] = {.lex_state = 0},
  [7206] = {.lex_state = 196},
  [7207] = {.lex_state = 196},
  [7208] = {.lex_state = 0},
  [7209] = {.lex_state = 181},
  [7210] = {.lex_state = 175},
  [7211] = {.lex_state = 196},
  [7212] = {.lex_state = 0},
  [7213] = {.lex_state = 0},
  [7214] = {.lex_state = 0},
  [7215] = {.lex_state = 0},
  [7216] = {.lex_state = 0},
  [7217] = {.lex_state = 0},
  [7218] = {.lex_state = 0},
  [7219] = {.lex_state = 0},
  [7220] = {.lex_state = 0},
  [7221] = {.lex_state = 196},
  [7222] = {.lex_state = 0},
  [7223] = {.lex_state = 196},
  [7224] = {.lex_state = 0},
  [7225] = {.lex_state = 196},
  [7226] = {.lex_state = 181},
  [7227] = {.lex_state = 181},
  [7228] = {.lex_state = 337},
  [7229] = {.lex_state = 0},
  [7230] = {.lex_state = 181},
  [7231] = {.lex_state = 337},
  [7232] = {.lex_state = 181},
  [7233] = {.lex_state = 196},
  [7234] = {.lex_state = 181},
  [7235] = {.lex_state = 113},
  [7236] = {.lex_state = 0},
  [7237] = {.lex_state = 0},
  [7238] = {.lex_state = 0},
  [7239] = {.lex_state = 0},
  [7240] = {.lex_state = 0},
  [7241] = {.lex_state = 0},
  [7242] = {.lex_state = 0},
  [7243] = {.lex_state = 0},
  [7244] = {.lex_state = 0},
  [7245] = {.lex_state = 0},
  [7246] = {.lex_state = 108},
  [7247] = {.lex_state = 0},
  [7248] = {.lex_state = 0},
  [7249] = {.lex_state = 196},
  [7250] = {.lex_state = 196},
  [7251] = {.lex_state = 196},
  [7252] = {.lex_state = 0},
  [7253] = {.lex_state = 181},
  [7254] = {.lex_state = 0},
  [7255] = {.lex_state = 196},
  [7256] = {.lex_state = 196},
  [7257] = {.lex_state = 181},
  [7258] = {.lex_state = 196},
  [7259] = {.lex_state = 181},
  [7260] = {.lex_state = 181},
  [7261] = {.lex_state = 0},
  [7262] = {.lex_state = 181},
  [7263] = {.lex_state = 0},
  [7264] = {.lex_state = 0},
  [7265] = {.lex_state = 0},
  [7266] = {.lex_state = 0},
  [7267] = {.lex_state = 0},
  [7268] = {.lex_state = 337},
  [7269] = {.lex_state = 196},
  [7270] = {.lex_state = 0},
  [7271] = {.lex_state = 0},
  [7272] = {.lex_state = 0},
  [7273] = {.lex_state = 0},
  [7274] = {.lex_state = 196},
  [7275] = {.lex_state = 0},
  [7276] = {.lex_state = 0},
  [7277] = {.lex_state = 196},
  [7278] = {.lex_state = 0},
  [7279] = {.lex_state = 0},
  [7280] = {.lex_state = 196},
  [7281] = {.lex_state = 0},
  [7282] = {.lex_state = 196},
  [7283] = {.lex_state = 0},
  [7284] = {.lex_state = 181},
  [7285] = {.lex_state = 0},
  [7286] = {.lex_state = 0},
  [7287] = {.lex_state = 0},
  [7288] = {.lex_state = 0},
  [7289] = {.lex_state = 196},
  [7290] = {.lex_state = 0},
  [7291] = {.lex_state = 0},
  [7292] = {.lex_state = 181},
  [7293] = {.lex_state = 181},
  [7294] = {.lex_state = 196},
  [7295] = {.lex_state = 0},
  [7296] = {.lex_state = 0},
  [7297] = {.lex_state = 0},
  [7298] = {.lex_state = 0},
  [7299] = {.lex_state = 0},
  [7300] = {.lex_state = 181},
  [7301] = {.lex_state = 196},
  [7302] = {.lex_state = 0},
  [7303] = {.lex_state = 0},
  [7304] = {.lex_state = 0},
  [7305] = {.lex_state = 181},
  [7306] = {.lex_state = 0},
  [7307] = {.lex_state = 0},
  [7308] = {.lex_state = 0},
  [7309] = {.lex_state = 0},
  [7310] = {.lex_state = 181},
  [7311] = {.lex_state = 0},
  [7312] = {.lex_state = 0},
  [7313] = {.lex_state = 0},
  [7314] = {.lex_state = 0},
  [7315] = {.lex_state = 181},
  [7316] = {.lex_state = 0},
  [7317] = {.lex_state = 181},
  [7318] = {.lex_state = 108},
  [7319] = {.lex_state = 0},
  [7320] = {.lex_state = 181},
  [7321] = {.lex_state = 196},
  [7322] = {.lex_state = 196},
  [7323] = {.lex_state = 0},
  [7324] = {.lex_state = 181},
  [7325] = {.lex_state = 0},
  [7326] = {.lex_state = 0},
  [7327] = {.lex_state = 0},
  [7328] = {.lex_state = 0},
  [7329] = {.lex_state = 0},
  [7330] = {.lex_state = 0},
  [7331] = {.lex_state = 196},
  [7332] = {.lex_state = 0},
  [7333] = {.lex_state = 0},
  [7334] = {.lex_state = 181},
  [7335] = {.lex_state = 0},
  [7336] = {.lex_state = 108},
  [7337] = {.lex_state = 181},
  [7338] = {.lex_state = 0},
  [7339] = {.lex_state = 196},
  [7340] = {.lex_state = 0},
  [7341] = {.lex_state = 0},
  [7342] = {.lex_state = 196},
  [7343] = {.lex_state = 0},
  [7344] = {.lex_state = 0},
  [7345] = {.lex_state = 0},
  [7346] = {.lex_state = 0},
  [7347] = {.lex_state = 196},
  [7348] = {.lex_state = 0},
  [7349] = {.lex_state = 0},
  [7350] = {.lex_state = 0},
  [7351] = {.lex_state = 0},
  [7352] = {.lex_state = 0},
  [7353] = {.lex_state = 0},
  [7354] = {.lex_state = 0},
  [7355] = {.lex_state = 196},
  [7356] = {.lex_state = 0},
  [7357] = {.lex_state = 0},
  [7358] = {.lex_state = 181},
  [7359] = {.lex_state = 0},
  [7360] = {.lex_state = 0},
  [7361] = {.lex_state = 0},
  [7362] = {.lex_state = 0},
  [7363] = {.lex_state = 181},
  [7364] = {.lex_state = 108},
  [7365] = {.lex_state = 0},
  [7366] = {.lex_state = 196},
  [7367] = {.lex_state = 196},
  [7368] = {.lex_state = 108},
  [7369] = {.lex_state = 0},
  [7370] = {.lex_state = 0},
  [7371] = {.lex_state = 0},
  [7372] = {.lex_state = 0},
  [7373] = {.lex_state = 0},
  [7374] = {.lex_state = 0},
  [7375] = {.lex_state = 337},
  [7376] = {.lex_state = 0},
  [7377] = {.lex_state = 196},
  [7378] = {.lex_state = 108},
  [7379] = {.lex_state = 0},
  [7380] = {.lex_state = 0},
  [7381] = {.lex_state = 0},
  [7382] = {.lex_state = 0},
  [7383] = {.lex_state = 0},
  [7384] = {.lex_state = 337},
  [7385] = {.lex_state = 0},
  [7386] = {.lex_state = 181},
  [7387] = {.lex_state = 196},
  [7388] = {.lex_state = 0},
  [7389] = {.lex_state = 0},
  [7390] = {.lex_state = 0},
  [7391] = {.lex_state = 0},
  [7392] = {.lex_state = 196},
  [7393] = {.lex_state = 0},
  [7394] = {.lex_state = 337},
  [7395] = {.lex_state = 0},
  [7396] = {.lex_state = 0},
  [7397] = {.lex_state = 0},
  [7398] = {.lex_state = 0},
  [7399] = {.lex_state = 0},
  [7400] = {.lex_state = 196},
  [7401] = {.lex_state = 196},
  [7402] = {.lex_state = 0},
  [7403] = {.lex_state = 0},
  [7404] = {.lex_state = 175},
  [7405] = {.lex_state = 0},
  [7406] = {.lex_state = 0},
  [7407] = {.lex_state = 0},
  [7408] = {.lex_state = 0},
  [7409] = {.lex_state = 0},
  [7410] = {.lex_state = 196},
  [7411] = {.lex_state = 196},
  [7412] = {.lex_state = 108},
  [7413] = {.lex_state = 0},
  [7414] = {.lex_state = 0},
  [7415] = {.lex_state = 0},
  [7416] = {.lex_state = 196},
  [7417] = {.lex_state = 0},
  [7418] = {.lex_state = 196},
  [7419] = {.lex_state = 0},
  [7420] = {.lex_state = 181},
  [7421] = {.lex_state = 108},
  [7422] = {.lex_state = 181},
  [7423] = {.lex_state = 181},
  [7424] = {.lex_state = 0},
  [7425] = {.lex_state = 181},
  [7426] = {.lex_state = 196},
  [7427] = {.lex_state = 0},
  [7428] = {.lex_state = 196},
  [7429] = {.lex_state = 196},
  [7430] = {.lex_state = 0},
  [7431] = {.lex_state = 0},
  [7432] = {.lex_state = 0},
  [7433] = {.lex_state = 0},
  [7434] = {.lex_state = 0},
  [7435] = {.lex_state = 0},
  [7436] = {.lex_state = 196},
  [7437] = {.lex_state = 181},
  [7438] = {.lex_state = 337},
  [7439] = {.lex_state = 0},
  [7440] = {.lex_state = 0},
  [7441] = {.lex_state = 196},
  [7442] = {.lex_state = 112},
  [7443] = {.lex_state = 0},
  [7444] = {.lex_state = 196},
  [7445] = {.lex_state = 337},
  [7446] = {.lex_state = 196},
  [7447] = {.lex_state = 196},
  [7448] = {.lex_state = 196},
  [7449] = {.lex_state = 0},
  [7450] = {.lex_state = 337},
  [7451] = {.lex_state = 337},
  [7452] = {.lex_state = 196},
  [7453] = {.lex_state = 337},
  [7454] = {.lex_state = 196},
  [7455] = {.lex_state = 196},
  [7456] = {.lex_state = 337},
  [7457] = {.lex_state = 337, .external_lex_state = 2},
  [7458] = {.lex_state = 196},
  [7459] = {.lex_state = 0},
  [7460] = {.lex_state = 337},
  [7461] = {.lex_state = 337, .external_lex_state = 2},
  [7462] = {.lex_state = 0},
  [7463] = {.lex_state = 337, .external_lex_state = 2},
  [7464] = {.lex_state = 337, .external_lex_state = 2},
  [7465] = {.lex_state = 337},
  [7466] = {.lex_state = 337},
  [7467] = {.lex_state = 337, .external_lex_state = 2},
  [7468] = {.lex_state = 337, .external_lex_state = 2},
  [7469] = {.lex_state = 337, .external_lex_state = 2},
  [7470] = {.lex_state = 337},
  [7471] = {.lex_state = 112},
  [7472] = {.lex_state = 337, .external_lex_state = 2},
  [7473] = {.lex_state = 337, .external_lex_state = 2},
  [7474] = {.lex_state = 337},
  [7475] = {.lex_state = 337, .external_lex_state = 2},
  [7476] = {.lex_state = 196},
  [7477] = {.lex_state = 196},
  [7478] = {.lex_state = 337, .external_lex_state = 2},
  [7479] = {.lex_state = 196},
  [7480] = {.lex_state = 337},
  [7481] = {.lex_state = 337, .external_lex_state = 2},
  [7482] = {.lex_state = 196},
  [7483] = {.lex_state = 337},
  [7484] = {.lex_state = 196},
  [7485] = {.lex_state = 196},
  [7486] = {.lex_state = 337, .external_lex_state = 2},
  [7487] = {.lex_state = 337},
  [7488] = {.lex_state = 196},
  [7489] = {.lex_state = 112},
  [7490] = {.lex_state = 337},
  [7491] = {.lex_state = 337},
  [7492] = {.lex_state = 337, .external_lex_state = 2},
  [7493] = {.lex_state = 196},
  [7494] = {.lex_state = 337},
  [7495] = {.lex_state = 337, .external_lex_state = 2},
  [7496] = {.lex_state = 0},
  [7497] = {.lex_state = 337},
  [7498] = {.lex_state = 337},
  [7499] = {.lex_state = 0},
  [7500] = {.lex_state = 196},
  [7501] = {.lex_state = 337, .external_lex_state = 2},
  [7502] = {.lex_state = 0},
  [7503] = {.lex_state = 0},
  [7504] = {.lex_state = 196},
  [7505] = {.lex_state = 196},
  [7506] = {.lex_state = 337},
  [7507] = {.lex_state = 196},
  [7508] = {.lex_state = 196},
  [7509] = {.lex_state = 0},
  [7510] = {.lex_state = 0},
  [7511] = {.lex_state = 196},
  [7512] = {.lex_state = 337},
  [7513] = {.lex_state = 0},
  [7514] = {.lex_state = 337},
  [7515] = {.lex_state = 0},
  [7516] = {.lex_state = 0},
  [7517] = {.lex_state = 0},
  [7518] = {.lex_state = 0},
  [7519] = {.lex_state = 0},
  [7520] = {.lex_state = 0},
  [7521] = {.lex_state = 337},
  [7522] = {.lex_state = 0},
  [7523] = {.lex_state = 0},
  [7524] = {.lex_state = 0},
  [7525] = {.lex_state = 0},
  [7526] = {.lex_state = 0},
  [7527] = {.lex_state = 337, .external_lex_state = 2},
  [7528] = {.lex_state = 0},
  [7529] = {.lex_state = 0},
  [7530] = {.lex_state = 0},
  [7531] = {.lex_state = 0},
  [7532] = {.lex_state = 196},
  [7533] = {.lex_state = 337},
  [7534] = {.lex_state = 112},
  [7535] = {.lex_state = 0},
  [7536] = {.lex_state = 337},
  [7537] = {.lex_state = 0},
  [7538] = {.lex_state = 337},
  [7539] = {.lex_state = 196},
  [7540] = {.lex_state = 0},
  [7541] = {.lex_state = 0},
  [7542] = {.lex_state = 0},
  [7543] = {.lex_state = 0},
  [7544] = {.lex_state = 0},
  [7545] = {.lex_state = 0},
  [7546] = {.lex_state = 0},
  [7547] = {.lex_state = 0},
  [7548] = {.lex_state = 0},
  [7549] = {.lex_state = 337},
  [7550] = {.lex_state = 0},
  [7551] = {.lex_state = 0},
  [7552] = {.lex_state = 337},
  [7553] = {.lex_state = 0},
  [7554] = {.lex_state = 0},
  [7555] = {.lex_state = 337},
  [7556] = {.lex_state = 337},
  [7557] = {.lex_state = 0},
  [7558] = {.lex_state = 0},
  [7559] = {.lex_state = 0},
  [7560] = {.lex_state = 0},
  [7561] = {.lex_state = 0},
  [7562] = {.lex_state = 0},
  [7563] = {.lex_state = 337},
  [7564] = {.lex_state = 0},
  [7565] = {.lex_state = 0},
  [7566] = {.lex_state = 337},
  [7567] = {.lex_state = 0},
  [7568] = {.lex_state = 196},
  [7569] = {.lex_state = 0},
  [7570] = {.lex_state = 0},
  [7571] = {.lex_state = 0},
  [7572] = {.lex_state = 0},
  [7573] = {.lex_state = 337},
  [7574] = {.lex_state = 0},
  [7575] = {.lex_state = 0},
  [7576] = {.lex_state = 0},
  [7577] = {.lex_state = 0},
  [7578] = {.lex_state = 0},
  [7579] = {.lex_state = 0},
  [7580] = {.lex_state = 0},
  [7581] = {.lex_state = 0},
  [7582] = {.lex_state = 0},
  [7583] = {.lex_state = 196},
  [7584] = {.lex_state = 0},
  [7585] = {.lex_state = 0},
  [7586] = {.lex_state = 0},
  [7587] = {.lex_state = 0},
  [7588] = {.lex_state = 112},
  [7589] = {.lex_state = 112},
  [7590] = {.lex_state = 0},
  [7591] = {.lex_state = 337},
  [7592] = {.lex_state = 0},
  [7593] = {.lex_state = 196},
  [7594] = {.lex_state = 0},
  [7595] = {.lex_state = 0},
  [7596] = {.lex_state = 0},
  [7597] = {.lex_state = 0},
  [7598] = {.lex_state = 0},
  [7599] = {.lex_state = 0},
  [7600] = {.lex_state = 0},
  [7601] = {.lex_state = 0},
  [7602] = {.lex_state = 0},
  [7603] = {.lex_state = 0},
  [7604] = {.lex_state = 337},
  [7605] = {.lex_state = 0},
  [7606] = {.lex_state = 0},
  [7607] = {.lex_state = 0},
  [7608] = {.lex_state = 0},
  [7609] = {.lex_state = 0},
  [7610] = {.lex_state = 0},
  [7611] = {.lex_state = 0},
  [7612] = {.lex_state = 0},
  [7613] = {.lex_state = 0},
  [7614] = {.lex_state = 0},
  [7615] = {.lex_state = 337},
  [7616] = {.lex_state = 0},
  [7617] = {.lex_state = 0},
  [7618] = {.lex_state = 0},
  [7619] = {.lex_state = 0},
  [7620] = {.lex_state = 112},
  [7621] = {.lex_state = 0},
  [7622] = {.lex_state = 0},
  [7623] = {.lex_state = 337},
  [7624] = {.lex_state = 337},
  [7625] = {.lex_state = 0},
  [7626] = {.lex_state = 0},
  [7627] = {.lex_state = 0},
  [7628] = {.lex_state = 196},
  [7629] = {.lex_state = 0},
  [7630] = {.lex_state = 0},
  [7631] = {.lex_state = 0},
  [7632] = {.lex_state = 0},
  [7633] = {.lex_state = 337},
  [7634] = {.lex_state = 337},
  [7635] = {.lex_state = 0},
  [7636] = {.lex_state = 337},
  [7637] = {.lex_state = 0},
  [7638] = {.lex_state = 0},
  [7639] = {.lex_state = 112},
  [7640] = {.lex_state = 337},
  [7641] = {.lex_state = 0},
  [7642] = {.lex_state = 0},
  [7643] = {.lex_state = 0},
  [7644] = {.lex_state = 0},
  [7645] = {.lex_state = 0},
  [7646] = {.lex_state = 0},
  [7647] = {.lex_state = 337},
  [7648] = {.lex_state = 112},
  [7649] = {.lex_state = 337},
  [7650] = {.lex_state = 0},
  [7651] = {.lex_state = 196},
  [7652] = {.lex_state = 0},
  [7653] = {.lex_state = 0},
  [7654] = {.lex_state = 0},
  [7655] = {.lex_state = 0},
  [7656] = {.lex_state = 0},
  [7657] = {.lex_state = 337},
  [7658] = {.lex_state = 0},
  [7659] = {.lex_state = 337},
  [7660] = {.lex_state = 112},
  [7661] = {.lex_state = 0},
  [7662] = {.lex_state = 0},
  [7663] = {.lex_state = 0},
  [7664] = {.lex_state = 0},
  [7665] = {.lex_state = 337},
  [7666] = {.lex_state = 0},
  [7667] = {.lex_state = 0},
  [7668] = {.lex_state = 0},
  [7669] = {.lex_state = 0},
  [7670] = {.lex_state = 0},
  [7671] = {.lex_state = 337},
  [7672] = {.lex_state = 337},
  [7673] = {.lex_state = 0},
  [7674] = {.lex_state = 0},
  [7675] = {.lex_state = 196},
  [7676] = {.lex_state = 0},
  [7677] = {.lex_state = 0},
  [7678] = {.lex_state = 337},
  [7679] = {.lex_state = 0},
  [7680] = {.lex_state = 0},
  [7681] = {.lex_state = 0},
  [7682] = {.lex_state = 0},
  [7683] = {.lex_state = 196},
  [7684] = {.lex_state = 0},
  [7685] = {.lex_state = 0},
  [7686] = {.lex_state = 0},
  [7687] = {.lex_state = 196},
  [7688] = {.lex_state = 0},
  [7689] = {.lex_state = 0},
  [7690] = {.lex_state = 337},
  [7691] = {.lex_state = 0},
  [7692] = {.lex_state = 337},
  [7693] = {.lex_state = 337},
  [7694] = {.lex_state = 0},
  [7695] = {.lex_state = 0},
  [7696] = {.lex_state = 0},
  [7697] = {.lex_state = 0},
  [7698] = {.lex_state = 0},
  [7699] = {.lex_state = 0},
  [7700] = {.lex_state = 0},
  [7701] = {.lex_state = 0},
  [7702] = {.lex_state = 0},
  [7703] = {.lex_state = 0},
  [7704] = {.lex_state = 337},
  [7705] = {.lex_state = 0},
  [7706] = {.lex_state = 0},
  [7707] = {.lex_state = 0},
  [7708] = {.lex_state = 337},
  [7709] = {.lex_state = 112},
  [7710] = {.lex_state = 196},
  [7711] = {.lex_state = 196},
  [7712] = {.lex_state = 0},
  [7713] = {.lex_state = 337},
  [7714] = {.lex_state = 0},
  [7715] = {.lex_state = 0},
  [7716] = {.lex_state = 0},
  [7717] = {.lex_state = 196},
  [7718] = {.lex_state = 0},
  [7719] = {.lex_state = 196},
  [7720] = {.lex_state = 337},
  [7721] = {.lex_state = 0},
  [7722] = {.lex_state = 0},
  [7723] = {.lex_state = 0},
  [7724] = {.lex_state = 0},
  [7725] = {.lex_state = 337},
  [7726] = {.lex_state = 0},
  [7727] = {.lex_state = 112},
  [7728] = {.lex_state = 0},
  [7729] = {.lex_state = 0},
  [7730] = {.lex_state = 0},
  [7731] = {.lex_state = 337},
  [7732] = {.lex_state = 0},
  [7733] = {.lex_state = 337},
  [7734] = {.lex_state = 0},
  [7735] = {.lex_state = 337},
  [7736] = {.lex_state = 0},
  [7737] = {.lex_state = 0},
  [7738] = {.lex_state = 112},
  [7739] = {.lex_state = 112},
  [7740] = {.lex_state = 337},
  [7741] = {.lex_state = 0},
  [7742] = {.lex_state = 0},
  [7743] = {.lex_state = 196},
  [7744] = {.lex_state = 196},
  [7745] = {.lex_state = 0},
  [7746] = {.lex_state = 0},
  [7747] = {.lex_state = 0},
  [7748] = {.lex_state = 112},
  [7749] = {.lex_state = 0},
  [7750] = {.lex_state = 337},
  [7751] = {.lex_state = 0},
  [7752] = {.lex_state = 0},
  [7753] = {.lex_state = 0},
  [7754] = {.lex_state = 337},
  [7755] = {.lex_state = 0},
  [7756] = {.lex_state = 196},
  [7757] = {.lex_state = 337},
  [7758] = {.lex_state = 337},
  [7759] = {.lex_state = 0},
  [7760] = {.lex_state = 0},
  [7761] = {.lex_state = 196},
  [7762] = {.lex_state = 337},
  [7763] = {.lex_state = 0},
  [7764] = {.lex_state = 0},
  [7765] = {.lex_state = 337},
  [7766] = {.lex_state = 0},
  [7767] = {.lex_state = 196},
  [7768] = {.lex_state = 0},
  [7769] = {.lex_state = 0},
  [7770] = {.lex_state = 337},
  [7771] = {.lex_state = 0},
  [7772] = {.lex_state = 337},
  [7773] = {.lex_state = 0},
  [7774] = {.lex_state = 0},
  [7775] = {.lex_state = 0},
  [7776] = {.lex_state = 0},
  [7777] = {.lex_state = 337},
  [7778] = {.lex_state = 337},
  [7779] = {.lex_state = 0},
  [7780] = {.lex_state = 0},
  [7781] = {.lex_state = 337},
  [7782] = {.lex_state = 0},
  [7783] = {.lex_state = 196},
  [7784] = {.lex_state = 0},
  [7785] = {.lex_state = 0},
  [7786] = {.lex_state = 0},
  [7787] = {.lex_state = 0},
  [7788] = {.lex_state = 337},
  [7789] = {.lex_state = 0},
  [7790] = {.lex_state = 0},
  [7791] = {.lex_state = 337},
  [7792] = {.lex_state = 0},
  [7793] = {.lex_state = 0},
  [7794] = {.lex_state = 0},
  [7795] = {.lex_state = 337},
  [7796] = {.lex_state = 196},
  [7797] = {.lex_state = 0},
  [7798] = {.lex_state = 0},
  [7799] = {.lex_state = 0},
  [7800] = {.lex_state = 0},
  [7801] = {.lex_state = 196},
  [7802] = {.lex_state = 0},
  [7803] = {.lex_state = 0},
  [7804] = {.lex_state = 337},
  [7805] = {.lex_state = 0},
  [7806] = {.lex_state = 0},
  [7807] = {.lex_state = 337},
  [7808] = {.lex_state = 196},
  [7809] = {.lex_state = 0},
  [7810] = {.lex_state = 0},
  [7811] = {.lex_state = 0},
  [7812] = {.lex_state = 337},
  [7813] = {.lex_state = 337},
  [7814] = {.lex_state = 196},
  [7815] = {.lex_state = 112},
  [7816] = {.lex_state = 0},
  [7817] = {.lex_state = 0},
  [7818] = {.lex_state = 0},
  [7819] = {.lex_state = 0},
  [7820] = {.lex_state = 0},
  [7821] = {.lex_state = 196},
  [7822] = {.lex_state = 0},
  [7823] = {.lex_state = 0},
  [7824] = {.lex_state = 337},
  [7825] = {.lex_state = 337},
  [7826] = {.lex_state = 0},
  [7827] = {.lex_state = 337},
  [7828] = {.lex_state = 337},
  [7829] = {.lex_state = 112},
  [7830] = {.lex_state = 0},
  [7831] = {.lex_state = 0},
  [7832] = {.lex_state = 0},
  [7833] = {.lex_state = 0},
  [7834] = {.lex_state = 0},
  [7835] = {.lex_state = 0},
  [7836] = {.lex_state = 337},
  [7837] = {.lex_state = 196},
  [7838] = {.lex_state = 0},
  [7839] = {.lex_state = 0},
  [7840] = {.lex_state = 196},
  [7841] = {.lex_state = 0},
  [7842] = {.lex_state = 0},
  [7843] = {.lex_state = 181},
  [7844] = {.lex_state = 0},
  [7845] = {.lex_state = 113},
  [7846] = {.lex_state = 0},
  [7847] = {.lex_state = 0},
  [7848] = {.lex_state = 0},
  [7849] = {.lex_state = 0},
  [7850] = {.lex_state = 0},
  [7851] = {.lex_state = 0},
  [7852] = {.lex_state = 0},
  [7853] = {.lex_state = 0},
  [7854] = {.lex_state = 196},
  [7855] = {.lex_state = 0},
  [7856] = {.lex_state = 0},
  [7857] = {.lex_state = 0},
  [7858] = {.lex_state = 196},
  [7859] = {.lex_state = 0},
  [7860] = {.lex_state = 196},
  [7861] = {.lex_state = 0},
  [7862] = {.lex_state = 0},
  [7863] = {.lex_state = 0},
  [7864] = {.lex_state = 0},
  [7865] = {.lex_state = 196},
  [7866] = {.lex_state = 113},
  [7867] = {.lex_state = 0},
  [7868] = {.lex_state = 196},
  [7869] = {.lex_state = 0, .external_lex_state = 2},
  [7870] = {.lex_state = 0},
  [7871] = {.lex_state = 0},
  [7872] = {.lex_state = 0},
  [7873] = {.lex_state = 0},
  [7874] = {.lex_state = 0},
  [7875] = {.lex_state = 0},
  [7876] = {.lex_state = 0},
  [7877] = {.lex_state = 181},
  [7878] = {.lex_state = 0},
  [7879] = {.lex_state = 196},
  [7880] = {.lex_state = 0},
  [7881] = {.lex_state = 0},
  [7882] = {.lex_state = 0},
  [7883] = {.lex_state = 0},
  [7884] = {.lex_state = 0},
  [7885] = {.lex_state = 0},
  [7886] = {.lex_state = 0},
  [7887] = {.lex_state = 0},
  [7888] = {.lex_state = 196},
  [7889] = {.lex_state = 196},
  [7890] = {.lex_state = 0},
  [7891] = {.lex_state = 196},
  [7892] = {.lex_state = 0},
  [7893] = {.lex_state = 0},
  [7894] = {.lex_state = 0},
  [7895] = {.lex_state = 0},
  [7896] = {.lex_state = 0},
  [7897] = {.lex_state = 0},
  [7898] = {.lex_state = 196},
  [7899] = {.lex_state = 0},
  [7900] = {.lex_state = 0},
  [7901] = {.lex_state = 181},
  [7902] = {.lex_state = 0},
  [7903] = {.lex_state = 0},
  [7904] = {.lex_state = 0},
  [7905] = {.lex_state = 337},
  [7906] = {.lex_state = 337},
  [7907] = {.lex_state = 0},
  [7908] = {.lex_state = 0},
  [7909] = {.lex_state = 0},
  [7910] = {.lex_state = 0},
  [7911] = {.lex_state = 0},
  [7912] = {.lex_state = 0},
  [7913] = {.lex_state = 0},
  [7914] = {.lex_state = 0},
  [7915] = {.lex_state = 0},
  [7916] = {.lex_state = 196},
  [7917] = {.lex_state = 181},
  [7918] = {.lex_state = 113},
  [7919] = {.lex_state = 196},
  [7920] = {.lex_state = 0},
  [7921] = {.lex_state = 173},
  [7922] = {.lex_state = 0},
  [7923] = {.lex_state = 0},
  [7924] = {.lex_state = 0},
  [7925] = {.lex_state = 0},
  [7926] = {.lex_state = 337},
  [7927] = {.lex_state = 196},
  [7928] = {.lex_state = 0},
  [7929] = {.lex_state = 0},
  [7930] = {.lex_state = 0},
  [7931] = {.lex_state = 0},
  [7932] = {.lex_state = 0},
  [7933] = {.lex_state = 0},
  [7934] = {.lex_state = 0},
  [7935] = {.lex_state = 337},
  [7936] = {.lex_state = 0},
  [7937] = {.lex_state = 0},
  [7938] = {.lex_state = 0},
  [7939] = {.lex_state = 196},
  [7940] = {.lex_state = 113},
  [7941] = {.lex_state = 0},
  [7942] = {.lex_state = 0},
  [7943] = {.lex_state = 0},
  [7944] = {.lex_state = 0},
  [7945] = {.lex_state = 0},
  [7946] = {.lex_state = 0},
  [7947] = {.lex_state = 196},
  [7948] = {.lex_state = 0},
  [7949] = {.lex_state = 0},
  [7950] = {.lex_state = 0},
  [7951] = {.lex_state = 0},
  [7952] = {.lex_state = 173},
  [7953] = {.lex_state = 173},
  [7954] = {.lex_state = 113},
  [7955] = {.lex_state = 0},
  [7956] = {.lex_state = 196},
  [7957] = {.lex_state = 181},
  [7958] = {.lex_state = 196},
  [7959] = {.lex_state = 0},
  [7960] = {.lex_state = 196},
  [7961] = {.lex_state = 196},
  [7962] = {.lex_state = 196},
  [7963] = {.lex_state = 0},
  [7964] = {.lex_state = 0},
  [7965] = {.lex_state = 0},
  [7966] = {.lex_state = 0},
  [7967] = {.lex_state = 0, .external_lex_state = 2},
  [7968] = {.lex_state = 196},
  [7969] = {.lex_state = 196},
  [7970] = {.lex_state = 0},
  [7971] = {.lex_state = 0},
  [7972] = {.lex_state = 0},
  [7973] = {.lex_state = 0},
  [7974] = {.lex_state = 196},
  [7975] = {.lex_state = 0},
  [7976] = {.lex_state = 0},
  [7977] = {.lex_state = 0},
  [7978] = {.lex_state = 0},
  [7979] = {.lex_state = 0},
  [7980] = {.lex_state = 337},
  [7981] = {.lex_state = 0},
  [7982] = {.lex_state = 0},
  [7983] = {.lex_state = 0},
  [7984] = {.lex_state = 0},
  [7985] = {.lex_state = 0},
  [7986] = {.lex_state = 337},
  [7987] = {.lex_state = 0},
  [7988] = {.lex_state = 0},
  [7989] = {.lex_state = 0},
  [7990] = {.lex_state = 113},
  [7991] = {.lex_state = 0},
  [7992] = {.lex_state = 0},
  [7993] = {.lex_state = 0},
  [7994] = {.lex_state = 173},
  [7995] = {.lex_state = 0},
  [7996] = {.lex_state = 337},
  [7997] = {.lex_state = 0},
  [7998] = {.lex_state = 337},
  [7999] = {.lex_state = 0},
  [8000] = {.lex_state = 196},
  [8001] = {.lex_state = 0},
  [8002] = {.lex_state = 0},
  [8003] = {.lex_state = 0},
  [8004] = {.lex_state = 196},
  [8005] = {.lex_state = 196},
  [8006] = {.lex_state = 0},
  [8007] = {.lex_state = 196},
  [8008] = {.lex_state = 0},
  [8009] = {.lex_state = 0},
  [8010] = {.lex_state = 0},
  [8011] = {.lex_state = 0},
  [8012] = {.lex_state = 0},
  [8013] = {.lex_state = 0},
  [8014] = {.lex_state = 0},
  [8015] = {.lex_state = 0},
  [8016] = {.lex_state = 0},
  [8017] = {.lex_state = 0},
  [8018] = {.lex_state = 337},
  [8019] = {.lex_state = 0},
  [8020] = {.lex_state = 196},
  [8021] = {.lex_state = 0},
  [8022] = {.lex_state = 196},
  [8023] = {.lex_state = 0},
  [8024] = {.lex_state = 0},
  [8025] = {.lex_state = 0},
  [8026] = {.lex_state = 0},
  [8027] = {.lex_state = 0},
  [8028] = {.lex_state = 0, .external_lex_state = 2},
  [8029] = {.lex_state = 0},
  [8030] = {.lex_state = 196},
  [8031] = {.lex_state = 0},
  [8032] = {.lex_state = 0},
  [8033] = {.lex_state = 0},
  [8034] = {.lex_state = 113},
  [8035] = {.lex_state = 113},
  [8036] = {.lex_state = 113},
  [8037] = {.lex_state = 0},
  [8038] = {.lex_state = 0},
  [8039] = {.lex_state = 0},
  [8040] = {.lex_state = 0},
  [8041] = {.lex_state = 0},
  [8042] = {.lex_state = 173},
  [8043] = {.lex_state = 0},
  [8044] = {.lex_state = 0},
  [8045] = {.lex_state = 173},
  [8046] = {.lex_state = 181},
  [8047] = {.lex_state = 0},
  [8048] = {.lex_state = 337},
  [8049] = {.lex_state = 0},
  [8050] = {.lex_state = 0},
  [8051] = {.lex_state = 196},
  [8052] = {.lex_state = 181},
  [8053] = {.lex_state = 113},
  [8054] = {.lex_state = 0},
  [8055] = {.lex_state = 196},
  [8056] = {.lex_state = 0},
  [8057] = {.lex_state = 0},
  [8058] = {.lex_state = 173},
  [8059] = {.lex_state = 0},
  [8060] = {.lex_state = 196},
  [8061] = {.lex_state = 0},
  [8062] = {.lex_state = 0},
  [8063] = {.lex_state = 0},
  [8064] = {.lex_state = 0},
  [8065] = {.lex_state = 0},
  [8066] = {.lex_state = 0},
  [8067] = {.lex_state = 0},
  [8068] = {.lex_state = 0},
  [8069] = {.lex_state = 0},
  [8070] = {.lex_state = 0},
  [8071] = {.lex_state = 173},
  [8072] = {.lex_state = 0},
  [8073] = {.lex_state = 0},
  [8074] = {.lex_state = 0},
  [8075] = {.lex_state = 0},
  [8076] = {.lex_state = 0},
  [8077] = {.lex_state = 0},
  [8078] = {.lex_state = 0},
  [8079] = {.lex_state = 0, .external_lex_state = 2},
  [8080] = {.lex_state = 0},
  [8081] = {.lex_state = 196},
  [8082] = {.lex_state = 0},
  [8083] = {.lex_state = 0},
  [8084] = {.lex_state = 0},
  [8085] = {.lex_state = 173},
  [8086] = {.lex_state = 173},
  [8087] = {.lex_state = 113},
  [8088] = {.lex_state = 0},
  [8089] = {.lex_state = 0},
  [8090] = {.lex_state = 0},
  [8091] = {.lex_state = 0},
  [8092] = {.lex_state = 196},
  [8093] = {.lex_state = 173},
  [8094] = {.lex_state = 173},
  [8095] = {.lex_state = 173},
  [8096] = {.lex_state = 337},
  [8097] = {.lex_state = 0},
  [8098] = {.lex_state = 0},
  [8099] = {.lex_state = 113},
  [8100] = {.lex_state = 0},
  [8101] = {.lex_state = 173},
  [8102] = {.lex_state = 0},
  [8103] = {.lex_state = 0},
  [8104] = {.lex_state = 0},
  [8105] = {.lex_state = 196},
  [8106] = {.lex_state = 0},
  [8107] = {.lex_state = 0},
  [8108] = {.lex_state = 0},
  [8109] = {.lex_state = 0},
  [8110] = {.lex_state = 0},
  [8111] = {.lex_state = 0},
  [8112] = {.lex_state = 0},
  [8113] = {.lex_state = 0},
  [8114] = {.lex_state = 113},
  [8115] = {.lex_state = 0},
  [8116] = {.lex_state = 196},
  [8117] = {.lex_state = 0},
  [8118] = {.lex_state = 0},
  [8119] = {.lex_state = 0},
  [8120] = {.lex_state = 0},
  [8121] = {.lex_state = 0, .external_lex_state = 2},
  [8122] = {.lex_state = 0},
  [8123] = {.lex_state = 0},
  [8124] = {.lex_state = 0},
  [8125] = {.lex_state = 0},
  [8126] = {.lex_state = 0},
  [8127] = {.lex_state = 0},
  [8128] = {.lex_state = 337},
  [8129] = {.lex_state = 0},
  [8130] = {.lex_state = 0},
  [8131] = {.lex_state = 113},
  [8132] = {.lex_state = 0},
  [8133] = {.lex_state = 0},
  [8134] = {.lex_state = 113},
  [8135] = {.lex_state = 196},
  [8136] = {.lex_state = 0, .external_lex_state = 2},
  [8137] = {.lex_state = 181},
  [8138] = {.lex_state = 113},
  [8139] = {.lex_state = 0},
  [8140] = {.lex_state = 0},
  [8141] = {.lex_state = 337},
  [8142] = {.lex_state = 196},
  [8143] = {.lex_state = 173},
  [8144] = {.lex_state = 0},
  [8145] = {.lex_state = 173},
  [8146] = {.lex_state = 173},
  [8147] = {.lex_state = 0, .external_lex_state = 2},
  [8148] = {.lex_state = 113},
  [8149] = {.lex_state = 0},
  [8150] = {.lex_state = 337},
  [8151] = {.lex_state = 337},
  [8152] = {.lex_state = 0},
  [8153] = {.lex_state = 0, .external_lex_state = 2},
  [8154] = {.lex_state = 0},
  [8155] = {.lex_state = 0},
  [8156] = {.lex_state = 0, .external_lex_state = 2},
  [8157] = {.lex_state = 0},
  [8158] = {.lex_state = 0},
  [8159] = {.lex_state = 0, .external_lex_state = 2},
  [8160] = {.lex_state = 0},
  [8161] = {.lex_state = 0, .external_lex_state = 2},
  [8162] = {.lex_state = 0},
  [8163] = {.lex_state = 0, .external_lex_state = 2},
  [8164] = {.lex_state = 0},
  [8165] = {.lex_state = 0, .external_lex_state = 2},
  [8166] = {.lex_state = 0},
  [8167] = {.lex_state = 0, .external_lex_state = 2},
  [8168] = {.lex_state = 0},
  [8169] = {.lex_state = 0, .external_lex_state = 2},
  [8170] = {.lex_state = 181},
  [8171] = {.lex_state = 0},
  [8172] = {.lex_state = 196},
  [8173] = {.lex_state = 337},
  [8174] = {.lex_state = 0},
  [8175] = {.lex_state = 337},
  [8176] = {.lex_state = 337},
  [8177] = {.lex_state = 337},
  [8178] = {.lex_state = 0},
  [8179] = {.lex_state = 337},
  [8180] = {.lex_state = 337},
  [8181] = {.lex_state = 0},
  [8182] = {.lex_state = 337},
  [8183] = {.lex_state = 0},
  [8184] = {.lex_state = 0},
  [8185] = {.lex_state = 0},
  [8186] = {.lex_state = 0},
  [8187] = {.lex_state = 0},
  [8188] = {.lex_state = 0},
  [8189] = {.lex_state = 0},
  [8190] = {.lex_state = 0},
  [8191] = {.lex_state = 0},
  [8192] = {.lex_state = 171},
  [8193] = {.lex_state = 0},
  [8194] = {.lex_state = 0},
  [8195] = {.lex_state = 0},
  [8196] = {.lex_state = 196},
  [8197] = {.lex_state = 0},
  [8198] = {.lex_state = 337},
  [8199] = {.lex_state = 337},
  [8200] = {.lex_state = 0},
  [8201] = {.lex_state = 0},
  [8202] = {.lex_state = 181},
  [8203] = {.lex_state = 181},
  [8204] = {.lex_state = 337},
  [8205] = {.lex_state = 0, .external_lex_state = 3},
  [8206] = {.lex_state = 0},
  [8207] = {.lex_state = 0},
  [8208] = {.lex_state = 0},
  [8209] = {.lex_state = 337},
  [8210] = {.lex_state = 337},
  [8211] = {.lex_state = 0},
  [8212] = {.lex_state = 0},
  [8213] = {.lex_state = 0},
  [8214] = {.lex_state = 337},
  [8215] = {.lex_state = 0},
  [8216] = {.lex_state = 0},
  [8217] = {.lex_state = 0},
  [8218] = {.lex_state = 173},
  [8219] = {.lex_state = 0},
  [8220] = {.lex_state = 113},
  [8221] = {.lex_state = 196},
  [8222] = {.lex_state = 0},
  [8223] = {.lex_state = 0},
  [8224] = {.lex_state = 0},
  [8225] = {.lex_state = 337},
  [8226] = {.lex_state = 0},
  [8227] = {.lex_state = 196},
  [8228] = {.lex_state = 181},
  [8229] = {.lex_state = 196},
  [8230] = {.lex_state = 0},
  [8231] = {.lex_state = 196},
  [8232] = {.lex_state = 0, .external_lex_state = 2},
  [8233] = {.lex_state = 0},
  [8234] = {.lex_state = 196},
  [8235] = {.lex_state = 0},
  [8236] = {.lex_state = 0},
  [8237] = {.lex_state = 196},
  [8238] = {.lex_state = 196},
  [8239] = {.lex_state = 0},
  [8240] = {.lex_state = 0},
  [8241] = {.lex_state = 0},
  [8242] = {.lex_state = 0},
  [8243] = {.lex_state = 196},
  [8244] = {.lex_state = 0},
  [8245] = {.lex_state = 0},
  [8246] = {.lex_state = 181},
  [8247] = {.lex_state = 0},
  [8248] = {.lex_state = 196},
  [8249] = {.lex_state = 0},
  [8250] = {.lex_state = 0},
  [8251] = {.lex_state = 0},
  [8252] = {.lex_state = 0},
  [8253] = {.lex_state = 196},
  [8254] = {.lex_state = 196},
  [8255] = {.lex_state = 181},
  [8256] = {.lex_state = 0},
  [8257] = {.lex_state = 0},
  [8258] = {.lex_state = 0},
  [8259] = {.lex_state = 0},
  [8260] = {.lex_state = 0, .external_lex_state = 3},
  [8261] = {.lex_state = 0},
  [8262] = {.lex_state = 0},
  [8263] = {.lex_state = 0},
  [8264] = {.lex_state = 337},
  [8265] = {.lex_state = 0},
  [8266] = {.lex_state = 113},
  [8267] = {.lex_state = 113},
  [8268] = {.lex_state = 0},
  [8269] = {.lex_state = 113},
  [8270] = {.lex_state = 0},
  [8271] = {.lex_state = 0},
  [8272] = {.lex_state = 0, .external_lex_state = 2},
  [8273] = {.lex_state = 181},
  [8274] = {.lex_state = 196},
  [8275] = {.lex_state = 0},
  [8276] = {.lex_state = 0},
  [8277] = {.lex_state = 173},
  [8278] = {.lex_state = 173},
  [8279] = {.lex_state = 171},
  [8280] = {.lex_state = 173},
  [8281] = {.lex_state = 173},
  [8282] = {.lex_state = 0},
  [8283] = {.lex_state = 196},
  [8284] = {.lex_state = 173},
  [8285] = {.lex_state = 0},
  [8286] = {.lex_state = 0},
  [8287] = {.lex_state = 173},
  [8288] = {.lex_state = 0},
  [8289] = {.lex_state = 196},
  [8290] = {.lex_state = 173},
  [8291] = {.lex_state = 173},
  [8292] = {.lex_state = 0},
  [8293] = {.lex_state = 337},
  [8294] = {.lex_state = 0},
  [8295] = {.lex_state = 0},
  [8296] = {.lex_state = 0},
  [8297] = {.lex_state = 0},
  [8298] = {.lex_state = 0},
  [8299] = {.lex_state = 0},
  [8300] = {.lex_state = 0},
  [8301] = {.lex_state = 0},
  [8302] = {.lex_state = 196},
  [8303] = {.lex_state = 0},
  [8304] = {.lex_state = 0},
  [8305] = {.lex_state = 0},
  [8306] = {.lex_state = 0},
  [8307] = {.lex_state = 196},
  [8308] = {.lex_state = 0},
  [8309] = {.lex_state = 0},
  [8310] = {.lex_state = 0},
  [8311] = {.lex_state = 0},
  [8312] = {.lex_state = 0},
  [8313] = {.lex_state = 0},
  [8314] = {.lex_state = 0},
  [8315] = {.lex_state = 173},
  [8316] = {.lex_state = 0},
  [8317] = {.lex_state = 0},
  [8318] = {.lex_state = 0},
  [8319] = {.lex_state = 0},
  [8320] = {.lex_state = 0},
  [8321] = {.lex_state = 196},
  [8322] = {.lex_state = 196},
  [8323] = {.lex_state = 173},
  [8324] = {.lex_state = 337},
  [8325] = {.lex_state = 173},
  [8326] = {.lex_state = 0},
  [8327] = {.lex_state = 0},
  [8328] = {.lex_state = 0},
  [8329] = {.lex_state = 0},
  [8330] = {.lex_state = 0},
  [8331] = {.lex_state = 0},
  [8332] = {.lex_state = 0},
  [8333] = {.lex_state = 173},
  [8334] = {.lex_state = 0},
  [8335] = {.lex_state = 0},
  [8336] = {.lex_state = 0},
  [8337] = {.lex_state = 0},
  [8338] = {.lex_state = 0},
  [8339] = {.lex_state = 0, .external_lex_state = 3},
  [8340] = {.lex_state = 0},
  [8341] = {.lex_state = 173},
  [8342] = {.lex_state = 0},
  [8343] = {.lex_state = 0},
  [8344] = {.lex_state = 173},
  [8345] = {.lex_state = 196},
  [8346] = {.lex_state = 337},
  [8347] = {.lex_state = 0},
  [8348] = {.lex_state = 0},
  [8349] = {.lex_state = 0},
  [8350] = {.lex_state = 337},
  [8351] = {.lex_state = 0},
  [8352] = {.lex_state = 0},
  [8353] = {.lex_state = 0},
  [8354] = {.lex_state = 0},
  [8355] = {.lex_state = 0},
  [8356] = {.lex_state = 0},
  [8357] = {.lex_state = 0},
  [8358] = {.lex_state = 173},
  [8359] = {.lex_state = 0},
  [8360] = {.lex_state = 0},
  [8361] = {.lex_state = 173},
  [8362] = {.lex_state = 0},
  [8363] = {.lex_state = 173},
  [8364] = {.lex_state = 337},
  [8365] = {.lex_state = 0},
  [8366] = {.lex_state = 0},
  [8367] = {.lex_state = 337},
  [8368] = {.lex_state = 173},
  [8369] = {.lex_state = 0},
  [8370] = {.lex_state = 0},
  [8371] = {.lex_state = 0},
  [8372] = {.lex_state = 196},
  [8373] = {.lex_state = 0},
  [8374] = {.lex_state = 337},
  [8375] = {.lex_state = 337},
  [8376] = {.lex_state = 337},
  [8377] = {.lex_state = 337},
  [8378] = {.lex_state = 337},
  [8379] = {.lex_state = 181},
  [8380] = {.lex_state = 337},
  [8381] = {.lex_state = 0},
  [8382] = {.lex_state = 0},
  [8383] = {.lex_state = 0},
  [8384] = {.lex_state = 173},
  [8385] = {.lex_state = 173},
  [8386] = {.lex_state = 196},
  [8387] = {.lex_state = 174},
  [8388] = {.lex_state = 337},
  [8389] = {.lex_state = 0},
  [8390] = {.lex_state = 113},
  [8391] = {.lex_state = 195},
  [8392] = {.lex_state = 337},
  [8393] = {.lex_state = 0, .external_lex_state = 3},
  [8394] = {.lex_state = 337},
  [8395] = {.lex_state = 337},
  [8396] = {.lex_state = 196},
  [8397] = {.lex_state = 0},
  [8398] = {.lex_state = 0},
  [8399] = {.lex_state = 0},
  [8400] = {.lex_state = 181},
  [8401] = {.lex_state = 173},
  [8402] = {.lex_state = 196},
  [8403] = {.lex_state = 0},
  [8404] = {.lex_state = 0},
  [8405] = {.lex_state = 181},
  [8406] = {.lex_state = 0},
  [8407] = {.lex_state = 0},
  [8408] = {.lex_state = 0},
  [8409] = {.lex_state = 337},
  [8410] = {.lex_state = 337},
  [8411] = {.lex_state = 337},
  [8412] = {.lex_state = 173},
  [8413] = {.lex_state = 337},
  [8414] = {.lex_state = 0},
  [8415] = {.lex_state = 0},
  [8416] = {.lex_state = 196},
  [8417] = {.lex_state = 181},
  [8418] = {.lex_state = 337},
  [8419] = {.lex_state = 0},
  [8420] = {.lex_state = 0},
  [8421] = {.lex_state = 337},
  [8422] = {.lex_state = 0, .external_lex_state = 3},
  [8423] = {.lex_state = 0},
  [8424] = {.lex_state = 0},
  [8425] = {.lex_state = 0},
  [8426] = {.lex_state = 0},
  [8427] = {.lex_state = 0},
  [8428] = {.lex_state = 0},
  [8429] = {.lex_state = 0},
  [8430] = {.lex_state = 181},
  [8431] = {.lex_state = 0},
  [8432] = {.lex_state = 0},
  [8433] = {.lex_state = 337},
  [8434] = {.lex_state = 337},
  [8435] = {.lex_state = 337},
  [8436] = {.lex_state = 0},
  [8437] = {.lex_state = 337},
  [8438] = {.lex_state = 0},
  [8439] = {.lex_state = 0},
  [8440] = {.lex_state = 196},
  [8441] = {.lex_state = 337},
  [8442] = {.lex_state = 0},
  [8443] = {.lex_state = 0},
  [8444] = {.lex_state = 337},
  [8445] = {.lex_state = 0, .external_lex_state = 3},
  [8446] = {.lex_state = 0},
  [8447] = {.lex_state = 0},
  [8448] = {.lex_state = 337},
  [8449] = {.lex_state = 0},
  [8450] = {.lex_state = 0},
  [8451] = {.lex_state = 0},
  [8452] = {.lex_state = 181},
  [8453] = {.lex_state = 0},
  [8454] = {.lex_state = 337},
  [8455] = {.lex_state = 337},
  [8456] = {.lex_state = 337},
  [8457] = {.lex_state = 195},
  [8458] = {.lex_state = 337},
  [8459] = {.lex_state = 196},
  [8460] = {.lex_state = 0},
  [8461] = {.lex_state = 337},
  [8462] = {.lex_state = 0},
  [8463] = {.lex_state = 171},
  [8464] = {.lex_state = 337},
  [8465] = {.lex_state = 0, .external_lex_state = 3},
  [8466] = {.lex_state = 337},
  [8467] = {.lex_state = 0},
  [8468] = {.lex_state = 0},
  [8469] = {.lex_state = 0},
  [8470] = {.lex_state = 0},
  [8471] = {.lex_state = 0},
  [8472] = {.lex_state = 181},
  [8473] = {.lex_state = 173},
  [8474] = {.lex_state = 337},
  [8475] = {.lex_state = 0},
  [8476] = {.lex_state = 337},
  [8477] = {.lex_state = 0},
  [8478] = {.lex_state = 173},
  [8479] = {.lex_state = 0},
  [8480] = {.lex_state = 113},
  [8481] = {.lex_state = 337},
  [8482] = {.lex_state = 0, .external_lex_state = 3},
  [8483] = {.lex_state = 337},
  [8484] = {.lex_state = 0},
  [8485] = {.lex_state = 0},
  [8486] = {.lex_state = 173},
  [8487] = {.lex_state = 0},
  [8488] = {.lex_state = 0},
  [8489] = {.lex_state = 337},
  [8490] = {.lex_state = 337},
  [8491] = {.lex_state = 0},
  [8492] = {.lex_state = 0, .external_lex_state = 3},
  [8493] = {.lex_state = 0},
  [8494] = {.lex_state = 0},
  [8495] = {.lex_state = 0},
  [8496] = {.lex_state = 337},
  [8497] = {.lex_state = 337},
  [8498] = {.lex_state = 337},
  [8499] = {.lex_state = 173},
  [8500] = {.lex_state = 0, .external_lex_state = 3},
  [8501] = {.lex_state = 173},
  [8502] = {.lex_state = 0},
  [8503] = {.lex_state = 337},
  [8504] = {.lex_state = 337},
  [8505] = {.lex_state = 0, .external_lex_state = 3},
  [8506] = {.lex_state = 0},
  [8507] = {.lex_state = 0, .external_lex_state = 3},
  [8508] = {.lex_state = 0},
  [8509] = {.lex_state = 0, .external_lex_state = 3},
  [8510] = {.lex_state = 0},
  [8511] = {.lex_state = 0, .external_lex_state = 3},
  [8512] = {.lex_state = 0},
  [8513] = {.lex_state = 0, .external_lex_state = 3},
  [8514] = {.lex_state = 0},
  [8515] = {.lex_state = 0, .external_lex_state = 3},
  [8516] = {.lex_state = 0},
  [8517] = {.lex_state = 0, .external_lex_state = 3},
  [8518] = {.lex_state = 0},
  [8519] = {.lex_state = 0, .external_lex_state = 3},
  [8520] = {.lex_state = 0},
  [8521] = {.lex_state = 196},
  [8522] = {.lex_state = 196},
  [8523] = {.lex_state = 337},
  [8524] = {.lex_state = 337},
  [8525] = {.lex_state = 196},
  [8526] = {.lex_state = 0},
  [8527] = {.lex_state = 0},
  [8528] = {.lex_state = 173},
  [8529] = {.lex_state = 0},
  [8530] = {.lex_state = 196},
  [8531] = {.lex_state = 173},
  [8532] = {.lex_state = 196},
  [8533] = {.lex_state = 0},
  [8534] = {.lex_state = 0},
  [8535] = {.lex_state = 337},
  [8536] = {.lex_state = 173},
  [8537] = {.lex_state = 173},
  [8538] = {.lex_state = 0},
  [8539] = {.lex_state = 337},
  [8540] = {.lex_state = 0},
  [8541] = {.lex_state = 0},
  [8542] = {.lex_state = 196},
  [8543] = {.lex_state = 196},
  [8544] = {.lex_state = 0, .external_lex_state = 3},
  [8545] = {.lex_state = 0},
  [8546] = {.lex_state = 0},
  [8547] = {.lex_state = 0},
  [8548] = {.lex_state = 0},
  [8549] = {.lex_state = 0},
  [8550] = {.lex_state = 0},
  [8551] = {.lex_state = 0},
  [8552] = {.lex_state = 0},
  [8553] = {.lex_state = 0},
  [8554] = {.lex_state = 0},
  [8555] = {.lex_state = 0},
  [8556] = {.lex_state = 0},
  [8557] = {.lex_state = 337},
  [8558] = {.lex_state = 0},
  [8559] = {.lex_state = 113},
  [8560] = {.lex_state = 0},
  [8561] = {.lex_state = 0},
  [8562] = {.lex_state = 196},
  [8563] = {.lex_state = 337},
  [8564] = {.lex_state = 196},
  [8565] = {.lex_state = 0},
  [8566] = {.lex_state = 0},
  [8567] = {.lex_state = 0},
  [8568] = {.lex_state = 0},
  [8569] = {.lex_state = 113},
  [8570] = {.lex_state = 0},
  [8571] = {.lex_state = 0},
  [8572] = {.lex_state = 0},
  [8573] = {.lex_state = 0},
  [8574] = {.lex_state = 0},
  [8575] = {.lex_state = 181},
  [8576] = {.lex_state = 113},
  [8577] = {.lex_state = 113},
  [8578] = {.lex_state = 0},
  [8579] = {.lex_state = 113},
  [8580] = {.lex_state = 173},
  [8581] = {.lex_state = 173},
  [8582] = {.lex_state = 337},
  [8583] = {.lex_state = 239},
  [8584] = {.lex_state = 0},
  [8585] = {.lex_state = 0},
  [8586] = {.lex_state = 173},
  [8587] = {.lex_state = 0},
  [8588] = {.lex_state = 196},
  [8589] = {.lex_state = 337},
  [8590] = {.lex_state = 181},
  [8591] = {.lex_state = 196},
  [8592] = {.lex_state = 195},
  [8593] = {.lex_state = 337},
  [8594] = {.lex_state = 0},
  [8595] = {.lex_state = 337},
  [8596] = {.lex_state = 0},
  [8597] = {.lex_state = 337},
  [8598] = {.lex_state = 181},
  [8599] = {.lex_state = 196},
  [8600] = {.lex_state = 0},
  [8601] = {.lex_state = 337},
  [8602] = {.lex_state = 337},
  [8603] = {.lex_state = 0},
  [8604] = {.lex_state = 181},
  [8605] = {.lex_state = 337},
  [8606] = {.lex_state = 196},
  [8607] = {.lex_state = 337},
  [8608] = {.lex_state = 337},
  [8609] = {.lex_state = 196},
  [8610] = {.lex_state = 0},
  [8611] = {.lex_state = 0},
  [8612] = {.lex_state = 0},
  [8613] = {.lex_state = 337},
  [8614] = {.lex_state = 196},
  [8615] = {.lex_state = 0, .external_lex_state = 3},
  [8616] = {.lex_state = 337},
  [8617] = {.lex_state = 0},
  [8618] = {.lex_state = 181},
  [8619] = {.lex_state = 337},
  [8620] = {.lex_state = 337},
  [8621] = {.lex_state = 196},
  [8622] = {.lex_state = 196},
  [8623] = {.lex_state = 173},
  [8624] = {.lex_state = 337},
  [8625] = {.lex_state = 196},
  [8626] = {.lex_state = 0, .external_lex_state = 3},
  [8627] = {.lex_state = 0},
  [8628] = {.lex_state = 113},
  [8629] = {.lex_state = 181},
  [8630] = {.lex_state = 337},
  [8631] = {.lex_state = 196},
  [8632] = {.lex_state = 0},
  [8633] = {.lex_state = 0},
  [8634] = {.lex_state = 196},
  [8635] = {.lex_state = 0, .external_lex_state = 3},
  [8636] = {.lex_state = 0},
  [8637] = {.lex_state = 337},
  [8638] = {.lex_state = 337},
  [8639] = {.lex_state = 196},
  [8640] = {.lex_state = 173},
  [8641] = {.lex_state = 196},
  [8642] = {.lex_state = 196},
  [8643] = {.lex_state = 0, .external_lex_state = 3},
  [8644] = {.lex_state = 337},
  [8645] = {.lex_state = 0},
  [8646] = {.lex_state = 337},
  [8647] = {.lex_state = 196},
  [8648] = {.lex_state = 0},
  [8649] = {.lex_state = 196},
  [8650] = {.lex_state = 0, .external_lex_state = 3},
  [8651] = {.lex_state = 0},
  [8652] = {.lex_state = 113},
  [8653] = {.lex_state = 196},
  [8654] = {.lex_state = 0, .external_lex_state = 3},
  [8655] = {.lex_state = 337},
  [8656] = {.lex_state = 337},
  [8657] = {.lex_state = 0, .external_lex_state = 3},
  [8658] = {.lex_state = 0},
  [8659] = {.lex_state = 0, .external_lex_state = 3},
  [8660] = {.lex_state = 0},
  [8661] = {.lex_state = 0, .external_lex_state = 3},
  [8662] = {.lex_state = 0},
  [8663] = {.lex_state = 0, .external_lex_state = 3},
  [8664] = {.lex_state = 0},
  [8665] = {.lex_state = 0, .external_lex_state = 3},
  [8666] = {.lex_state = 113},
  [8667] = {.lex_state = 0, .external_lex_state = 3},
  [8668] = {.lex_state = 0},
  [8669] = {.lex_state = 0, .external_lex_state = 3},
  [8670] = {.lex_state = 0},
  [8671] = {.lex_state = 0, .external_lex_state = 3},
  [8672] = {.lex_state = 0},
  [8673] = {.lex_state = 0, .external_lex_state = 3},
  [8674] = {.lex_state = 337},
  [8675] = {.lex_state = 337},
  [8676] = {.lex_state = 196},
  [8677] = {.lex_state = 337},
  [8678] = {.lex_state = 337},
  [8679] = {.lex_state = 196},
  [8680] = {.lex_state = 337},
  [8681] = {.lex_state = 337},
  [8682] = {.lex_state = 196},
  [8683] = {.lex_state = 337},
  [8684] = {.lex_state = 337},
  [8685] = {.lex_state = 196},
  [8686] = {.lex_state = 337},
  [8687] = {.lex_state = 337},
  [8688] = {.lex_state = 196},
  [8689] = {.lex_state = 337},
  [8690] = {.lex_state = 337},
  [8691] = {.lex_state = 337},
  [8692] = {.lex_state = 337},
  [8693] = {.lex_state = 337},
  [8694] = {.lex_state = 337},
  [8695] = {.lex_state = 337},
  [8696] = {.lex_state = 337},
  [8697] = {.lex_state = 337},
  [8698] = {.lex_state = 337},
  [8699] = {.lex_state = 337},
  [8700] = {.lex_state = 0},
  [8701] = {.lex_state = 181},
  [8702] = {.lex_state = 196},
  [8703] = {.lex_state = 337},
  [8704] = {.lex_state = 196},
  [8705] = {.lex_state = 337},
  [8706] = {.lex_state = 337},
  [8707] = {.lex_state = 337},
  [8708] = {.lex_state = 337},
  [8709] = {.lex_state = 337},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [aux_sym_preproc_include_token1] = ACTIONS(1),
    [aux_sym_preproc_def_token1] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [aux_sym_preproc_if_token1] = ACTIONS(1),
    [aux_sym_preproc_if_token2] = ACTIONS(1),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1),
    [aux_sym_preproc_else_token1] = ACTIONS(1),
    [aux_sym_preproc_elif_token1] = ACTIONS(1),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1),
    [sym_preproc_directive] = ACTIONS(1),
    [anon_sym_LPAREN2] = ACTIONS(1),
    [anon_sym_defined] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_LT_LT] = ACTIONS(1),
    [anon_sym_GT_GT] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym___extension__] = ACTIONS(1),
    [anon_sym_typedef] = ACTIONS(1),
    [anon_sym_in] = ACTIONS(1),
    [anon_sym_out] = ACTIONS(1),
    [anon_sym_inout] = ACTIONS(1),
    [anon_sym_extern] = ACTIONS(1),
    [anon_sym___attribute__] = ACTIONS(1),
    [anon_sym_COLON_COLON] = ACTIONS(1),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1),
    [anon_sym___declspec] = ACTIONS(1),
    [anon_sym___based] = ACTIONS(1),
    [anon_sym___cdecl] = ACTIONS(1),
    [anon_sym___clrcall] = ACTIONS(1),
    [anon_sym___stdcall] = ACTIONS(1),
    [anon_sym___fastcall] = ACTIONS(1),
    [anon_sym___thiscall] = ACTIONS(1),
    [anon_sym___vectorcall] = ACTIONS(1),
    [sym_ms_restrict_modifier] = ACTIONS(1),
    [sym_ms_unsigned_ptr_modifier] = ACTIONS(1),
    [sym_ms_signed_ptr_modifier] = ACTIONS(1),
    [anon_sym__unaligned] = ACTIONS(1),
    [anon_sym___unaligned] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_signed] = ACTIONS(1),
    [anon_sym_unsigned] = ACTIONS(1),
    [anon_sym_long] = ACTIONS(1),
    [anon_sym_short] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_static] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_register] = ACTIONS(1),
    [anon_sym_inline] = ACTIONS(1),
    [anon_sym___inline] = ACTIONS(1),
    [anon_sym___inline__] = ACTIONS(1),
    [anon_sym___forceinline] = ACTIONS(1),
    [anon_sym_thread_local] = ACTIONS(1),
    [anon_sym___thread] = ACTIONS(1),
    [anon_sym_const] = ACTIONS(1),
    [anon_sym_constexpr] = ACTIONS(1),
    [anon_sym_volatile] = ACTIONS(1),
    [anon_sym_restrict] = ACTIONS(1),
    [anon_sym___restrict__] = ACTIONS(1),
    [anon_sym__Atomic] = ACTIONS(1),
    [anon_sym__Noreturn] = ACTIONS(1),
    [anon_sym_noreturn] = ACTIONS(1),
    [anon_sym_mutable] = ACTIONS(1),
    [anon_sym_constinit] = ACTIONS(1),
    [anon_sym_consteval] = ACTIONS(1),
    [anon_sym_alignas] = ACTIONS(1),
    [anon_sym__Alignas] = ACTIONS(1),
    [sym_primitive_type] = ACTIONS(1),
    [anon_sym_enum] = ACTIONS(1),
    [anon_sym_class] = ACTIONS(1),
    [anon_sym_struct] = ACTIONS(1),
    [anon_sym_union] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_switch] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_default] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_do] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_return] = ACTIONS(1),
    [anon_sym_break] = ACTIONS(1),
    [anon_sym_continue] = ACTIONS(1),
    [anon_sym_goto] = ACTIONS(1),
    [anon_sym___try] = ACTIONS(1),
    [anon_sym___except] = ACTIONS(1),
    [anon_sym___finally] = ACTIONS(1),
    [anon_sym___leave] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_STAR_EQ] = ACTIONS(1),
    [anon_sym_SLASH_EQ] = ACTIONS(1),
    [anon_sym_PERCENT_EQ] = ACTIONS(1),
    [anon_sym_PLUS_EQ] = ACTIONS(1),
    [anon_sym_DASH_EQ] = ACTIONS(1),
    [anon_sym_LT_LT_EQ] = ACTIONS(1),
    [anon_sym_GT_GT_EQ] = ACTIONS(1),
    [anon_sym_AMP_EQ] = ACTIONS(1),
    [anon_sym_CARET_EQ] = ACTIONS(1),
    [anon_sym_PIPE_EQ] = ACTIONS(1),
    [anon_sym_and_eq] = ACTIONS(1),
    [anon_sym_or_eq] = ACTIONS(1),
    [anon_sym_xor_eq] = ACTIONS(1),
    [anon_sym_not] = ACTIONS(1),
    [anon_sym_compl] = ACTIONS(1),
    [anon_sym_LT_EQ_GT] = ACTIONS(1),
    [anon_sym_or] = ACTIONS(1),
    [anon_sym_and] = ACTIONS(1),
    [anon_sym_bitor] = ACTIONS(1),
    [anon_sym_xor] = ACTIONS(1),
    [anon_sym_bitand] = ACTIONS(1),
    [anon_sym_not_eq] = ACTIONS(1),
    [anon_sym_DASH_DASH] = ACTIONS(1),
    [anon_sym_PLUS_PLUS] = ACTIONS(1),
    [anon_sym_sizeof] = ACTIONS(1),
    [anon_sym___alignof__] = ACTIONS(1),
    [anon_sym___alignof] = ACTIONS(1),
    [anon_sym__alignof] = ACTIONS(1),
    [anon_sym_alignof] = ACTIONS(1),
    [anon_sym__Alignof] = ACTIONS(1),
    [anon_sym_offsetof] = ACTIONS(1),
    [anon_sym__Generic] = ACTIONS(1),
    [anon_sym_asm] = ACTIONS(1),
    [anon_sym___asm__] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_DOT_STAR] = ACTIONS(1),
    [anon_sym_DASH_GT] = ACTIONS(1),
    [sym_number_literal] = ACTIONS(1),
    [anon_sym_L_SQUOTE] = ACTIONS(1),
    [anon_sym_u_SQUOTE] = ACTIONS(1),
    [anon_sym_U_SQUOTE] = ACTIONS(1),
    [anon_sym_u8_SQUOTE] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [anon_sym_L_DQUOTE] = ACTIONS(1),
    [anon_sym_u_DQUOTE] = ACTIONS(1),
    [anon_sym_U_DQUOTE] = ACTIONS(1),
    [anon_sym_u8_DQUOTE] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [sym_true] = ACTIONS(1),
    [sym_false] = ACTIONS(1),
    [anon_sym_NULL] = ACTIONS(1),
    [anon_sym_nullptr] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1),
    [anon_sym_decltype] = ACTIONS(1),
    [anon_sym_final] = ACTIONS(1),
    [anon_sym_override] = ACTIONS(1),
    [sym_virtual] = ACTIONS(1),
    [anon_sym_explicit] = ACTIONS(1),
    [anon_sym_typename] = ACTIONS(1),
    [anon_sym_template] = ACTIONS(1),
    [anon_sym_GT2] = ACTIONS(1),
    [anon_sym_operator] = ACTIONS(1),
    [anon_sym_try] = ACTIONS(1),
    [anon_sym_delete] = ACTIONS(1),
    [anon_sym_0] = ACTIONS(1),
    [anon_sym_friend] = ACTIONS(1),
    [anon_sym_public] = ACTIONS(1),
    [anon_sym_private] = ACTIONS(1),
    [anon_sym_protected] = ACTIONS(1),
    [anon_sym_noexcept] = ACTIONS(1),
    [anon_sym_throw] = ACTIONS(1),
    [anon_sym_namespace] = ACTIONS(1),
    [anon_sym_using] = ACTIONS(1),
    [anon_sym_static_assert] = ACTIONS(1),
    [anon_sym_concept] = ACTIONS(1),
    [anon_sym_co_return] = ACTIONS(1),
    [anon_sym_co_yield] = ACTIONS(1),
    [anon_sym_catch] = ACTIONS(1),
    [anon_sym_R_DQUOTE] = ACTIONS(1),
    [anon_sym_LR_DQUOTE] = ACTIONS(1),
    [anon_sym_uR_DQUOTE] = ACTIONS(1),
    [anon_sym_UR_DQUOTE] = ACTIONS(1),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1),
    [anon_sym_co_await] = ACTIONS(1),
    [anon_sym_new] = ACTIONS(1),
    [anon_sym_requires] = ACTIONS(1),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1),
    [anon_sym_LBRACK_RBRACK] = ACTIONS(1),
    [sym_this] = ACTIONS(1),
    [anon_sym_discard] = ACTIONS(1),
    [anon_sym_precise] = ACTIONS(1),
    [anon_sym_shared] = ACTIONS(1),
    [anon_sym_groupshared] = ACTIONS(1),
    [anon_sym_uniform] = ACTIONS(1),
    [anon_sym_row_major] = ACTIONS(1),
    [anon_sym_column_major] = ACTIONS(1),
    [anon_sym_globallycoherent] = ACTIONS(1),
    [anon_sym_centroid] = ACTIONS(1),
    [anon_sym_noperspective] = ACTIONS(1),
    [anon_sym_nointerpolation] = ACTIONS(1),
    [anon_sym_sample] = ACTIONS(1),
    [anon_sym_linear] = ACTIONS(1),
    [anon_sym_snorm] = ACTIONS(1),
    [anon_sym_unorm] = ACTIONS(1),
    [anon_sym_point] = ACTIONS(1),
    [anon_sym_line] = ACTIONS(1),
    [anon_sym_triangleadj] = ACTIONS(1),
    [anon_sym_lineadj] = ACTIONS(1),
    [anon_sym_triangle] = ACTIONS(1),
    [anon_sym_cbuffer] = ACTIONS(1),
    [sym_raw_string_delimiter] = ACTIONS(1),
    [sym_raw_string_content] = ACTIONS(1),
  },
  [1] = {
    [sym_translation_unit] = STATE(8584),
    [sym__top_level_item] = STATE(80),
    [sym_preproc_include] = STATE(80),
    [sym_preproc_def] = STATE(80),
    [sym_preproc_function_def] = STATE(80),
    [sym_preproc_call] = STATE(80),
    [sym_preproc_if] = STATE(80),
    [sym_preproc_ifdef] = STATE(80),
    [sym_function_definition] = STATE(80),
    [sym_declaration] = STATE(80),
    [sym_type_definition] = STATE(80),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4633),
    [sym_linkage_specification] = STATE(80),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1945),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6115),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(80),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2257),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(757),
    [sym__top_level_statement] = STATE(80),
    [sym_labeled_statement] = STATE(80),
    [sym__top_level_expression_statement] = STATE(80),
    [sym_if_statement] = STATE(80),
    [sym_switch_statement] = STATE(80),
    [sym_case_statement] = STATE(80),
    [sym_while_statement] = STATE(80),
    [sym_do_statement] = STATE(80),
    [sym_for_statement] = STATE(80),
    [sym_return_statement] = STATE(80),
    [sym_break_statement] = STATE(80),
    [sym_continue_statement] = STATE(80),
    [sym_goto_statement] = STATE(80),
    [sym_expression] = STATE(4779),
    [sym__string] = STATE(4846),
    [sym_conditional_expression] = STATE(4846),
    [sym_assignment_expression] = STATE(4846),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4846),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4846),
    [sym_cast_expression] = STATE(4846),
    [sym_sizeof_expression] = STATE(4846),
    [sym_alignof_expression] = STATE(4846),
    [sym_offsetof_expression] = STATE(4846),
    [sym_generic_expression] = STATE(4846),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4846),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4846),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4791),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4846),
    [sym__empty_declaration] = STATE(80),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1833),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(80),
    [sym_template_instantiation] = STATE(80),
    [sym_operator_cast] = STATE(6631),
    [sym__constructor_specifiers] = STATE(1833),
    [sym_operator_cast_definition] = STATE(80),
    [sym_operator_cast_declaration] = STATE(80),
    [sym_constructor_or_destructor_definition] = STATE(80),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4778),
    [sym_namespace_definition] = STATE(80),
    [sym_namespace_alias_definition] = STATE(80),
    [sym_using_declaration] = STATE(80),
    [sym_alias_declaration] = STATE(80),
    [sym_static_assert_declaration] = STATE(80),
    [sym_concept_definition] = STATE(80),
    [sym_for_range_loop] = STATE(80),
    [sym_co_return_statement] = STATE(80),
    [sym_co_yield_statement] = STATE(80),
    [sym_throw_statement] = STATE(80),
    [sym_try_statement] = STATE(80),
    [sym_raw_string_literal] = STATE(3861),
    [sym_co_await_expression] = STATE(4846),
    [sym_new_expression] = STATE(4846),
    [sym_delete_expression] = STATE(4846),
    [sym_requires_clause] = STATE(4846),
    [sym_requires_expression] = STATE(4846),
    [sym_lambda_expression] = STATE(4846),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4846),
    [sym_parameter_pack_expansion] = STATE(4846),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6631),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3824),
    [sym_qualifiers] = STATE(2369),
    [sym_hlsl_attribute] = STATE(1206),
    [aux_sym_translation_unit_repeat1] = STATE(80),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(840),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1833),
    [ts_builtin_sym_end] = ACTIONS(5),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_preproc_include_token1] = ACTIONS(9),
    [aux_sym_preproc_def_token1] = ACTIONS(11),
    [aux_sym_preproc_if_token1] = ACTIONS(13),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(15),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(15),
    [sym_preproc_directive] = ACTIONS(17),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym___extension__] = ACTIONS(33),
    [anon_sym_typedef] = ACTIONS(35),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(39),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(81),
    [anon_sym_default] = ACTIONS(83),
    [anon_sym_while] = ACTIONS(85),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(111),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(117),
    [sym_false] = ACTIONS(117),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(129),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_namespace] = ACTIONS(139),
    [anon_sym_using] = ACTIONS(141),
    [anon_sym_static_assert] = ACTIONS(143),
    [anon_sym_concept] = ACTIONS(145),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(117),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [2] = {
    [sym__block_item] = STATE(56),
    [sym_preproc_include] = STATE(56),
    [sym_preproc_def] = STATE(56),
    [sym_preproc_function_def] = STATE(56),
    [sym_preproc_call] = STATE(56),
    [sym_preproc_if] = STATE(56),
    [sym_preproc_ifdef] = STATE(56),
    [sym_function_definition] = STATE(56),
    [sym_declaration] = STATE(56),
    [sym_type_definition] = STATE(56),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(56),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(56),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4296),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7085),
    [sym_initializer_pair] = STATE(7085),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(56),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(56),
    [sym_template_instantiation] = STATE(56),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(56),
    [sym_operator_cast_declaration] = STATE(56),
    [sym_constructor_or_destructor_definition] = STATE(56),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(56),
    [sym_namespace_alias_definition] = STATE(56),
    [sym_using_declaration] = STATE(56),
    [sym_alias_declaration] = STATE(56),
    [sym_static_assert_declaration] = STATE(56),
    [sym_concept_definition] = STATE(56),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(56),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(161),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [anon_sym_COMMA] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_RBRACE] = ACTIONS(185),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(187),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [3] = {
    [sym__block_item] = STATE(58),
    [sym_preproc_include] = STATE(58),
    [sym_preproc_def] = STATE(58),
    [sym_preproc_function_def] = STATE(58),
    [sym_preproc_call] = STATE(58),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_ifdef] = STATE(58),
    [sym_function_definition] = STATE(58),
    [sym_declaration] = STATE(58),
    [sym_type_definition] = STATE(58),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(58),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(58),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4296),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7085),
    [sym_initializer_pair] = STATE(7085),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(58),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(58),
    [sym_template_instantiation] = STATE(58),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(58),
    [sym_operator_cast_declaration] = STATE(58),
    [sym_constructor_or_destructor_definition] = STATE(58),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(58),
    [sym_namespace_alias_definition] = STATE(58),
    [sym_using_declaration] = STATE(58),
    [sym_alias_declaration] = STATE(58),
    [sym_static_assert_declaration] = STATE(58),
    [sym_concept_definition] = STATE(58),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(58),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(161),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [anon_sym_COMMA] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_RBRACE] = ACTIONS(245),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(187),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [4] = {
    [sym__block_item] = STATE(39),
    [sym_preproc_include] = STATE(39),
    [sym_preproc_def] = STATE(39),
    [sym_preproc_function_def] = STATE(39),
    [sym_preproc_call] = STATE(39),
    [sym_preproc_if] = STATE(39),
    [sym_preproc_ifdef] = STATE(39),
    [sym_function_definition] = STATE(39),
    [sym_declaration] = STATE(39),
    [sym_type_definition] = STATE(39),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(39),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(39),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4296),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7085),
    [sym_initializer_pair] = STATE(7085),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(39),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(39),
    [sym_template_instantiation] = STATE(39),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(39),
    [sym_operator_cast_declaration] = STATE(39),
    [sym_constructor_or_destructor_definition] = STATE(39),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(39),
    [sym_namespace_alias_definition] = STATE(39),
    [sym_using_declaration] = STATE(39),
    [sym_alias_declaration] = STATE(39),
    [sym_static_assert_declaration] = STATE(39),
    [sym_concept_definition] = STATE(39),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(39),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(161),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [anon_sym_COMMA] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_RBRACE] = ACTIONS(247),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(187),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [5] = {
    [sym__block_item] = STATE(68),
    [sym_preproc_include] = STATE(68),
    [sym_preproc_def] = STATE(68),
    [sym_preproc_function_def] = STATE(68),
    [sym_preproc_call] = STATE(68),
    [sym_preproc_if] = STATE(68),
    [sym_preproc_ifdef] = STATE(68),
    [sym_function_definition] = STATE(68),
    [sym_declaration] = STATE(68),
    [sym_type_definition] = STATE(68),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(68),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(68),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4296),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7085),
    [sym_initializer_pair] = STATE(7085),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(68),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(68),
    [sym_template_instantiation] = STATE(68),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(68),
    [sym_operator_cast_declaration] = STATE(68),
    [sym_constructor_or_destructor_definition] = STATE(68),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(68),
    [sym_namespace_alias_definition] = STATE(68),
    [sym_using_declaration] = STATE(68),
    [sym_alias_declaration] = STATE(68),
    [sym_static_assert_declaration] = STATE(68),
    [sym_concept_definition] = STATE(68),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(68),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(161),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [anon_sym_COMMA] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_RBRACE] = ACTIONS(249),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(187),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [6] = {
    [sym__block_item] = STATE(56),
    [sym_preproc_include] = STATE(56),
    [sym_preproc_def] = STATE(56),
    [sym_preproc_function_def] = STATE(56),
    [sym_preproc_call] = STATE(56),
    [sym_preproc_if] = STATE(56),
    [sym_preproc_ifdef] = STATE(56),
    [sym_function_definition] = STATE(56),
    [sym_declaration] = STATE(56),
    [sym_type_definition] = STATE(56),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(56),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(56),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4296),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7085),
    [sym_initializer_pair] = STATE(7085),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(56),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(56),
    [sym_template_instantiation] = STATE(56),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(56),
    [sym_operator_cast_declaration] = STATE(56),
    [sym_constructor_or_destructor_definition] = STATE(56),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(56),
    [sym_namespace_alias_definition] = STATE(56),
    [sym_using_declaration] = STATE(56),
    [sym_alias_declaration] = STATE(56),
    [sym_static_assert_declaration] = STATE(56),
    [sym_concept_definition] = STATE(56),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(56),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(161),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [anon_sym_COMMA] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_RBRACE] = ACTIONS(251),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(187),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [7] = {
    [sym__block_item] = STATE(75),
    [sym_preproc_include] = STATE(75),
    [sym_preproc_def] = STATE(75),
    [sym_preproc_function_def] = STATE(75),
    [sym_preproc_call] = STATE(75),
    [sym_preproc_if] = STATE(75),
    [sym_preproc_ifdef] = STATE(75),
    [sym_function_definition] = STATE(75),
    [sym_declaration] = STATE(75),
    [sym_type_definition] = STATE(75),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(75),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(75),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4296),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7085),
    [sym_initializer_pair] = STATE(7085),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(75),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(75),
    [sym_template_instantiation] = STATE(75),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(75),
    [sym_operator_cast_declaration] = STATE(75),
    [sym_constructor_or_destructor_definition] = STATE(75),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(75),
    [sym_namespace_alias_definition] = STATE(75),
    [sym_using_declaration] = STATE(75),
    [sym_alias_declaration] = STATE(75),
    [sym_static_assert_declaration] = STATE(75),
    [sym_concept_definition] = STATE(75),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(75),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(161),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [anon_sym_COMMA] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_RBRACE] = ACTIONS(253),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(187),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [8] = {
    [sym__block_item] = STATE(75),
    [sym_preproc_include] = STATE(75),
    [sym_preproc_def] = STATE(75),
    [sym_preproc_function_def] = STATE(75),
    [sym_preproc_call] = STATE(75),
    [sym_preproc_if] = STATE(75),
    [sym_preproc_ifdef] = STATE(75),
    [sym_function_definition] = STATE(75),
    [sym_declaration] = STATE(75),
    [sym_type_definition] = STATE(75),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(75),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(75),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4296),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7085),
    [sym_initializer_pair] = STATE(7085),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(75),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(75),
    [sym_template_instantiation] = STATE(75),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(75),
    [sym_operator_cast_declaration] = STATE(75),
    [sym_constructor_or_destructor_definition] = STATE(75),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(75),
    [sym_namespace_alias_definition] = STATE(75),
    [sym_using_declaration] = STATE(75),
    [sym_alias_declaration] = STATE(75),
    [sym_static_assert_declaration] = STATE(75),
    [sym_concept_definition] = STATE(75),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(75),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(161),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [anon_sym_COMMA] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_RBRACE] = ACTIONS(255),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(187),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [9] = {
    [sym__block_item] = STATE(39),
    [sym_preproc_include] = STATE(39),
    [sym_preproc_def] = STATE(39),
    [sym_preproc_function_def] = STATE(39),
    [sym_preproc_call] = STATE(39),
    [sym_preproc_if] = STATE(39),
    [sym_preproc_ifdef] = STATE(39),
    [sym_function_definition] = STATE(39),
    [sym_declaration] = STATE(39),
    [sym_type_definition] = STATE(39),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(39),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(39),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4296),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7085),
    [sym_initializer_pair] = STATE(7085),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(39),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(39),
    [sym_template_instantiation] = STATE(39),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(39),
    [sym_operator_cast_declaration] = STATE(39),
    [sym_constructor_or_destructor_definition] = STATE(39),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(39),
    [sym_namespace_alias_definition] = STATE(39),
    [sym_using_declaration] = STATE(39),
    [sym_alias_declaration] = STATE(39),
    [sym_static_assert_declaration] = STATE(39),
    [sym_concept_definition] = STATE(39),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(39),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(161),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [anon_sym_COMMA] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_RBRACE] = ACTIONS(257),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(187),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [10] = {
    [sym__block_item] = STATE(50),
    [sym_preproc_include] = STATE(50),
    [sym_preproc_def] = STATE(50),
    [sym_preproc_function_def] = STATE(50),
    [sym_preproc_call] = STATE(50),
    [sym_preproc_if] = STATE(50),
    [sym_preproc_ifdef] = STATE(50),
    [sym_function_definition] = STATE(50),
    [sym_declaration] = STATE(50),
    [sym_type_definition] = STATE(50),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(50),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(50),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4296),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7085),
    [sym_initializer_pair] = STATE(7085),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(50),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(50),
    [sym_template_instantiation] = STATE(50),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(50),
    [sym_operator_cast_declaration] = STATE(50),
    [sym_constructor_or_destructor_definition] = STATE(50),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(50),
    [sym_namespace_alias_definition] = STATE(50),
    [sym_using_declaration] = STATE(50),
    [sym_alias_declaration] = STATE(50),
    [sym_static_assert_declaration] = STATE(50),
    [sym_concept_definition] = STATE(50),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(50),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(161),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [anon_sym_COMMA] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_RBRACE] = ACTIONS(259),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(187),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [11] = {
    [sym__block_item] = STATE(46),
    [sym_preproc_include] = STATE(46),
    [sym_preproc_def] = STATE(46),
    [sym_preproc_function_def] = STATE(46),
    [sym_preproc_call] = STATE(46),
    [sym_preproc_if] = STATE(46),
    [sym_preproc_ifdef] = STATE(46),
    [sym_function_definition] = STATE(46),
    [sym_declaration] = STATE(46),
    [sym_type_definition] = STATE(46),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(46),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(46),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4296),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7085),
    [sym_initializer_pair] = STATE(7085),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(46),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(46),
    [sym_template_instantiation] = STATE(46),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(46),
    [sym_operator_cast_declaration] = STATE(46),
    [sym_constructor_or_destructor_definition] = STATE(46),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(46),
    [sym_namespace_alias_definition] = STATE(46),
    [sym_using_declaration] = STATE(46),
    [sym_alias_declaration] = STATE(46),
    [sym_static_assert_declaration] = STATE(46),
    [sym_concept_definition] = STATE(46),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(46),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(161),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [anon_sym_COMMA] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_RBRACE] = ACTIONS(261),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(187),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [12] = {
    [sym__block_item] = STATE(50),
    [sym_preproc_include] = STATE(50),
    [sym_preproc_def] = STATE(50),
    [sym_preproc_function_def] = STATE(50),
    [sym_preproc_call] = STATE(50),
    [sym_preproc_if] = STATE(50),
    [sym_preproc_ifdef] = STATE(50),
    [sym_function_definition] = STATE(50),
    [sym_declaration] = STATE(50),
    [sym_type_definition] = STATE(50),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(50),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(50),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4296),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7085),
    [sym_initializer_pair] = STATE(7085),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(50),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(50),
    [sym_template_instantiation] = STATE(50),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(50),
    [sym_operator_cast_declaration] = STATE(50),
    [sym_constructor_or_destructor_definition] = STATE(50),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(50),
    [sym_namespace_alias_definition] = STATE(50),
    [sym_using_declaration] = STATE(50),
    [sym_alias_declaration] = STATE(50),
    [sym_static_assert_declaration] = STATE(50),
    [sym_concept_definition] = STATE(50),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(50),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(161),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [anon_sym_COMMA] = ACTIONS(167),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_RBRACE] = ACTIONS(263),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(187),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [13] = {
    [sym__block_item] = STATE(18),
    [sym_preproc_include] = STATE(18),
    [sym_preproc_def] = STATE(18),
    [sym_preproc_function_def] = STATE(18),
    [sym_preproc_call] = STATE(18),
    [sym_preproc_if] = STATE(18),
    [sym_preproc_ifdef] = STATE(18),
    [sym_preproc_else] = STATE(8385),
    [sym_preproc_elif] = STATE(8385),
    [sym_preproc_elifdef] = STATE(8385),
    [sym_function_definition] = STATE(18),
    [sym_declaration] = STATE(18),
    [sym_type_definition] = STATE(18),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_linkage_specification] = STATE(18),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1943),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6185),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(178),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2258),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(273),
    [sym_statement] = STATE(18),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(18),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1823),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(18),
    [sym_template_instantiation] = STATE(18),
    [sym_operator_cast] = STATE(6628),
    [sym__constructor_specifiers] = STATE(1823),
    [sym_operator_cast_definition] = STATE(18),
    [sym_operator_cast_declaration] = STATE(18),
    [sym_constructor_or_destructor_definition] = STATE(18),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(18),
    [sym_namespace_alias_definition] = STATE(18),
    [sym_using_declaration] = STATE(18),
    [sym_alias_declaration] = STATE(18),
    [sym_static_assert_declaration] = STATE(18),
    [sym_concept_definition] = STATE(18),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6628),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(1214),
    [aux_sym_preproc_if_repeat1] = STATE(18),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1823),
    [sym_identifier] = ACTIONS(265),
    [aux_sym_preproc_include_token1] = ACTIONS(267),
    [aux_sym_preproc_def_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token1] = ACTIONS(271),
    [aux_sym_preproc_if_token2] = ACTIONS(273),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(275),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(275),
    [aux_sym_preproc_else_token1] = ACTIONS(277),
    [aux_sym_preproc_elif_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(281),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(281),
    [sym_preproc_directive] = ACTIONS(283),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym___extension__] = ACTIONS(287),
    [anon_sym_typedef] = ACTIONS(289),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(291),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(295),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(323),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_namespace] = ACTIONS(329),
    [anon_sym_using] = ACTIONS(331),
    [anon_sym_static_assert] = ACTIONS(333),
    [anon_sym_concept] = ACTIONS(335),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [14] = {
    [sym__block_item] = STATE(33),
    [sym_preproc_include] = STATE(33),
    [sym_preproc_def] = STATE(33),
    [sym_preproc_function_def] = STATE(33),
    [sym_preproc_call] = STATE(33),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_ifdef] = STATE(33),
    [sym_preproc_else] = STATE(8042),
    [sym_preproc_elif] = STATE(8042),
    [sym_preproc_elifdef] = STATE(8042),
    [sym_function_definition] = STATE(33),
    [sym_declaration] = STATE(33),
    [sym_type_definition] = STATE(33),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_linkage_specification] = STATE(33),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1943),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6185),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(178),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2258),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(273),
    [sym_statement] = STATE(33),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(33),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1823),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(33),
    [sym_template_instantiation] = STATE(33),
    [sym_operator_cast] = STATE(6628),
    [sym__constructor_specifiers] = STATE(1823),
    [sym_operator_cast_definition] = STATE(33),
    [sym_operator_cast_declaration] = STATE(33),
    [sym_constructor_or_destructor_definition] = STATE(33),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(33),
    [sym_namespace_alias_definition] = STATE(33),
    [sym_using_declaration] = STATE(33),
    [sym_alias_declaration] = STATE(33),
    [sym_static_assert_declaration] = STATE(33),
    [sym_concept_definition] = STATE(33),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6628),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(1214),
    [aux_sym_preproc_if_repeat1] = STATE(33),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1823),
    [sym_identifier] = ACTIONS(265),
    [aux_sym_preproc_include_token1] = ACTIONS(267),
    [aux_sym_preproc_def_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token1] = ACTIONS(271),
    [aux_sym_preproc_if_token2] = ACTIONS(345),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(275),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(275),
    [aux_sym_preproc_else_token1] = ACTIONS(277),
    [aux_sym_preproc_elif_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(281),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(281),
    [sym_preproc_directive] = ACTIONS(283),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym___extension__] = ACTIONS(287),
    [anon_sym_typedef] = ACTIONS(289),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(291),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(295),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(323),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_namespace] = ACTIONS(329),
    [anon_sym_using] = ACTIONS(331),
    [anon_sym_static_assert] = ACTIONS(333),
    [anon_sym_concept] = ACTIONS(335),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [15] = {
    [sym__block_item] = STATE(20),
    [sym_preproc_include] = STATE(20),
    [sym_preproc_def] = STATE(20),
    [sym_preproc_function_def] = STATE(20),
    [sym_preproc_call] = STATE(20),
    [sym_preproc_if] = STATE(20),
    [sym_preproc_ifdef] = STATE(20),
    [sym_preproc_else] = STATE(8045),
    [sym_preproc_elif] = STATE(8045),
    [sym_preproc_elifdef] = STATE(8045),
    [sym_function_definition] = STATE(20),
    [sym_declaration] = STATE(20),
    [sym_type_definition] = STATE(20),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_linkage_specification] = STATE(20),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1943),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6185),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(178),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2258),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(273),
    [sym_statement] = STATE(20),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(20),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1823),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(20),
    [sym_template_instantiation] = STATE(20),
    [sym_operator_cast] = STATE(6628),
    [sym__constructor_specifiers] = STATE(1823),
    [sym_operator_cast_definition] = STATE(20),
    [sym_operator_cast_declaration] = STATE(20),
    [sym_constructor_or_destructor_definition] = STATE(20),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(20),
    [sym_namespace_alias_definition] = STATE(20),
    [sym_using_declaration] = STATE(20),
    [sym_alias_declaration] = STATE(20),
    [sym_static_assert_declaration] = STATE(20),
    [sym_concept_definition] = STATE(20),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6628),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(1214),
    [aux_sym_preproc_if_repeat1] = STATE(20),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1823),
    [sym_identifier] = ACTIONS(265),
    [aux_sym_preproc_include_token1] = ACTIONS(267),
    [aux_sym_preproc_def_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token1] = ACTIONS(271),
    [aux_sym_preproc_if_token2] = ACTIONS(347),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(275),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(275),
    [aux_sym_preproc_else_token1] = ACTIONS(277),
    [aux_sym_preproc_elif_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(281),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(281),
    [sym_preproc_directive] = ACTIONS(283),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym___extension__] = ACTIONS(287),
    [anon_sym_typedef] = ACTIONS(289),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(291),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(295),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(323),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_namespace] = ACTIONS(329),
    [anon_sym_using] = ACTIONS(331),
    [anon_sym_static_assert] = ACTIONS(333),
    [anon_sym_concept] = ACTIONS(335),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [16] = {
    [sym__block_item] = STATE(33),
    [sym_preproc_include] = STATE(33),
    [sym_preproc_def] = STATE(33),
    [sym_preproc_function_def] = STATE(33),
    [sym_preproc_call] = STATE(33),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_ifdef] = STATE(33),
    [sym_preproc_else] = STATE(8101),
    [sym_preproc_elif] = STATE(8101),
    [sym_preproc_elifdef] = STATE(8101),
    [sym_function_definition] = STATE(33),
    [sym_declaration] = STATE(33),
    [sym_type_definition] = STATE(33),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_linkage_specification] = STATE(33),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1943),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6185),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(178),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2258),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(273),
    [sym_statement] = STATE(33),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(33),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1823),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(33),
    [sym_template_instantiation] = STATE(33),
    [sym_operator_cast] = STATE(6628),
    [sym__constructor_specifiers] = STATE(1823),
    [sym_operator_cast_definition] = STATE(33),
    [sym_operator_cast_declaration] = STATE(33),
    [sym_constructor_or_destructor_definition] = STATE(33),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(33),
    [sym_namespace_alias_definition] = STATE(33),
    [sym_using_declaration] = STATE(33),
    [sym_alias_declaration] = STATE(33),
    [sym_static_assert_declaration] = STATE(33),
    [sym_concept_definition] = STATE(33),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6628),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(1214),
    [aux_sym_preproc_if_repeat1] = STATE(33),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1823),
    [sym_identifier] = ACTIONS(265),
    [aux_sym_preproc_include_token1] = ACTIONS(267),
    [aux_sym_preproc_def_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token1] = ACTIONS(271),
    [aux_sym_preproc_if_token2] = ACTIONS(349),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(275),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(275),
    [aux_sym_preproc_else_token1] = ACTIONS(277),
    [aux_sym_preproc_elif_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(281),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(281),
    [sym_preproc_directive] = ACTIONS(283),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym___extension__] = ACTIONS(287),
    [anon_sym_typedef] = ACTIONS(289),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(291),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(295),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(323),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_namespace] = ACTIONS(329),
    [anon_sym_using] = ACTIONS(331),
    [anon_sym_static_assert] = ACTIONS(333),
    [anon_sym_concept] = ACTIONS(335),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [17] = {
    [sym__block_item] = STATE(28),
    [sym_preproc_include] = STATE(28),
    [sym_preproc_def] = STATE(28),
    [sym_preproc_function_def] = STATE(28),
    [sym_preproc_call] = STATE(28),
    [sym_preproc_if] = STATE(28),
    [sym_preproc_ifdef] = STATE(28),
    [sym_preproc_else] = STATE(8058),
    [sym_preproc_elif] = STATE(8058),
    [sym_preproc_elifdef] = STATE(8058),
    [sym_function_definition] = STATE(28),
    [sym_declaration] = STATE(28),
    [sym_type_definition] = STATE(28),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_linkage_specification] = STATE(28),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1943),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6185),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(178),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2258),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(273),
    [sym_statement] = STATE(28),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(28),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1823),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(28),
    [sym_template_instantiation] = STATE(28),
    [sym_operator_cast] = STATE(6628),
    [sym__constructor_specifiers] = STATE(1823),
    [sym_operator_cast_definition] = STATE(28),
    [sym_operator_cast_declaration] = STATE(28),
    [sym_constructor_or_destructor_definition] = STATE(28),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(28),
    [sym_namespace_alias_definition] = STATE(28),
    [sym_using_declaration] = STATE(28),
    [sym_alias_declaration] = STATE(28),
    [sym_static_assert_declaration] = STATE(28),
    [sym_concept_definition] = STATE(28),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6628),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(1214),
    [aux_sym_preproc_if_repeat1] = STATE(28),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1823),
    [sym_identifier] = ACTIONS(265),
    [aux_sym_preproc_include_token1] = ACTIONS(267),
    [aux_sym_preproc_def_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token1] = ACTIONS(271),
    [aux_sym_preproc_if_token2] = ACTIONS(351),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(275),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(275),
    [aux_sym_preproc_else_token1] = ACTIONS(277),
    [aux_sym_preproc_elif_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(281),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(281),
    [sym_preproc_directive] = ACTIONS(283),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym___extension__] = ACTIONS(287),
    [anon_sym_typedef] = ACTIONS(289),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(291),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(295),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(323),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_namespace] = ACTIONS(329),
    [anon_sym_using] = ACTIONS(331),
    [anon_sym_static_assert] = ACTIONS(333),
    [anon_sym_concept] = ACTIONS(335),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [18] = {
    [sym__block_item] = STATE(33),
    [sym_preproc_include] = STATE(33),
    [sym_preproc_def] = STATE(33),
    [sym_preproc_function_def] = STATE(33),
    [sym_preproc_call] = STATE(33),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_ifdef] = STATE(33),
    [sym_preproc_else] = STATE(8341),
    [sym_preproc_elif] = STATE(8341),
    [sym_preproc_elifdef] = STATE(8341),
    [sym_function_definition] = STATE(33),
    [sym_declaration] = STATE(33),
    [sym_type_definition] = STATE(33),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_linkage_specification] = STATE(33),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1943),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6185),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(178),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2258),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(273),
    [sym_statement] = STATE(33),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(33),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1823),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(33),
    [sym_template_instantiation] = STATE(33),
    [sym_operator_cast] = STATE(6628),
    [sym__constructor_specifiers] = STATE(1823),
    [sym_operator_cast_definition] = STATE(33),
    [sym_operator_cast_declaration] = STATE(33),
    [sym_constructor_or_destructor_definition] = STATE(33),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(33),
    [sym_namespace_alias_definition] = STATE(33),
    [sym_using_declaration] = STATE(33),
    [sym_alias_declaration] = STATE(33),
    [sym_static_assert_declaration] = STATE(33),
    [sym_concept_definition] = STATE(33),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6628),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(1214),
    [aux_sym_preproc_if_repeat1] = STATE(33),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1823),
    [sym_identifier] = ACTIONS(265),
    [aux_sym_preproc_include_token1] = ACTIONS(267),
    [aux_sym_preproc_def_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token1] = ACTIONS(271),
    [aux_sym_preproc_if_token2] = ACTIONS(353),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(275),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(275),
    [aux_sym_preproc_else_token1] = ACTIONS(277),
    [aux_sym_preproc_elif_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(281),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(281),
    [sym_preproc_directive] = ACTIONS(283),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym___extension__] = ACTIONS(287),
    [anon_sym_typedef] = ACTIONS(289),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(291),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(295),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(323),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_namespace] = ACTIONS(329),
    [anon_sym_using] = ACTIONS(331),
    [anon_sym_static_assert] = ACTIONS(333),
    [anon_sym_concept] = ACTIONS(335),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [19] = {
    [sym__block_item] = STATE(33),
    [sym_preproc_include] = STATE(33),
    [sym_preproc_def] = STATE(33),
    [sym_preproc_function_def] = STATE(33),
    [sym_preproc_call] = STATE(33),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_ifdef] = STATE(33),
    [sym_preproc_else] = STATE(8344),
    [sym_preproc_elif] = STATE(8344),
    [sym_preproc_elifdef] = STATE(8344),
    [sym_function_definition] = STATE(33),
    [sym_declaration] = STATE(33),
    [sym_type_definition] = STATE(33),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_linkage_specification] = STATE(33),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1943),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6185),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(178),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2258),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(273),
    [sym_statement] = STATE(33),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(33),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1823),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(33),
    [sym_template_instantiation] = STATE(33),
    [sym_operator_cast] = STATE(6628),
    [sym__constructor_specifiers] = STATE(1823),
    [sym_operator_cast_definition] = STATE(33),
    [sym_operator_cast_declaration] = STATE(33),
    [sym_constructor_or_destructor_definition] = STATE(33),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(33),
    [sym_namespace_alias_definition] = STATE(33),
    [sym_using_declaration] = STATE(33),
    [sym_alias_declaration] = STATE(33),
    [sym_static_assert_declaration] = STATE(33),
    [sym_concept_definition] = STATE(33),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6628),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(1214),
    [aux_sym_preproc_if_repeat1] = STATE(33),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1823),
    [sym_identifier] = ACTIONS(265),
    [aux_sym_preproc_include_token1] = ACTIONS(267),
    [aux_sym_preproc_def_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token1] = ACTIONS(271),
    [aux_sym_preproc_if_token2] = ACTIONS(355),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(275),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(275),
    [aux_sym_preproc_else_token1] = ACTIONS(277),
    [aux_sym_preproc_elif_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(281),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(281),
    [sym_preproc_directive] = ACTIONS(283),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym___extension__] = ACTIONS(287),
    [anon_sym_typedef] = ACTIONS(289),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(291),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(295),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(323),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_namespace] = ACTIONS(329),
    [anon_sym_using] = ACTIONS(331),
    [anon_sym_static_assert] = ACTIONS(333),
    [anon_sym_concept] = ACTIONS(335),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [20] = {
    [sym__block_item] = STATE(33),
    [sym_preproc_include] = STATE(33),
    [sym_preproc_def] = STATE(33),
    [sym_preproc_function_def] = STATE(33),
    [sym_preproc_call] = STATE(33),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_ifdef] = STATE(33),
    [sym_preproc_else] = STATE(8278),
    [sym_preproc_elif] = STATE(8278),
    [sym_preproc_elifdef] = STATE(8278),
    [sym_function_definition] = STATE(33),
    [sym_declaration] = STATE(33),
    [sym_type_definition] = STATE(33),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_linkage_specification] = STATE(33),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1943),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6185),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(178),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2258),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(273),
    [sym_statement] = STATE(33),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(33),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1823),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(33),
    [sym_template_instantiation] = STATE(33),
    [sym_operator_cast] = STATE(6628),
    [sym__constructor_specifiers] = STATE(1823),
    [sym_operator_cast_definition] = STATE(33),
    [sym_operator_cast_declaration] = STATE(33),
    [sym_constructor_or_destructor_definition] = STATE(33),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(33),
    [sym_namespace_alias_definition] = STATE(33),
    [sym_using_declaration] = STATE(33),
    [sym_alias_declaration] = STATE(33),
    [sym_static_assert_declaration] = STATE(33),
    [sym_concept_definition] = STATE(33),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6628),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(1214),
    [aux_sym_preproc_if_repeat1] = STATE(33),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1823),
    [sym_identifier] = ACTIONS(265),
    [aux_sym_preproc_include_token1] = ACTIONS(267),
    [aux_sym_preproc_def_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token1] = ACTIONS(271),
    [aux_sym_preproc_if_token2] = ACTIONS(357),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(275),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(275),
    [aux_sym_preproc_else_token1] = ACTIONS(277),
    [aux_sym_preproc_elif_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(281),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(281),
    [sym_preproc_directive] = ACTIONS(283),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym___extension__] = ACTIONS(287),
    [anon_sym_typedef] = ACTIONS(289),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(291),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(295),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(323),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_namespace] = ACTIONS(329),
    [anon_sym_using] = ACTIONS(331),
    [anon_sym_static_assert] = ACTIONS(333),
    [anon_sym_concept] = ACTIONS(335),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [21] = {
    [sym__block_item] = STATE(16),
    [sym_preproc_include] = STATE(16),
    [sym_preproc_def] = STATE(16),
    [sym_preproc_function_def] = STATE(16),
    [sym_preproc_call] = STATE(16),
    [sym_preproc_if] = STATE(16),
    [sym_preproc_ifdef] = STATE(16),
    [sym_preproc_else] = STATE(8146),
    [sym_preproc_elif] = STATE(8146),
    [sym_preproc_elifdef] = STATE(8146),
    [sym_function_definition] = STATE(16),
    [sym_declaration] = STATE(16),
    [sym_type_definition] = STATE(16),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_linkage_specification] = STATE(16),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1943),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6185),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(178),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2258),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(273),
    [sym_statement] = STATE(16),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(16),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1823),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(16),
    [sym_template_instantiation] = STATE(16),
    [sym_operator_cast] = STATE(6628),
    [sym__constructor_specifiers] = STATE(1823),
    [sym_operator_cast_definition] = STATE(16),
    [sym_operator_cast_declaration] = STATE(16),
    [sym_constructor_or_destructor_definition] = STATE(16),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(16),
    [sym_namespace_alias_definition] = STATE(16),
    [sym_using_declaration] = STATE(16),
    [sym_alias_declaration] = STATE(16),
    [sym_static_assert_declaration] = STATE(16),
    [sym_concept_definition] = STATE(16),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6628),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(1214),
    [aux_sym_preproc_if_repeat1] = STATE(16),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1823),
    [sym_identifier] = ACTIONS(265),
    [aux_sym_preproc_include_token1] = ACTIONS(267),
    [aux_sym_preproc_def_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token1] = ACTIONS(271),
    [aux_sym_preproc_if_token2] = ACTIONS(359),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(275),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(275),
    [aux_sym_preproc_else_token1] = ACTIONS(277),
    [aux_sym_preproc_elif_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(281),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(281),
    [sym_preproc_directive] = ACTIONS(283),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym___extension__] = ACTIONS(287),
    [anon_sym_typedef] = ACTIONS(289),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(291),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(295),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(323),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_namespace] = ACTIONS(329),
    [anon_sym_using] = ACTIONS(331),
    [anon_sym_static_assert] = ACTIONS(333),
    [anon_sym_concept] = ACTIONS(335),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [22] = {
    [sym__block_item] = STATE(24),
    [sym_preproc_include] = STATE(24),
    [sym_preproc_def] = STATE(24),
    [sym_preproc_function_def] = STATE(24),
    [sym_preproc_call] = STATE(24),
    [sym_preproc_if] = STATE(24),
    [sym_preproc_ifdef] = STATE(24),
    [sym_preproc_else] = STATE(8218),
    [sym_preproc_elif] = STATE(8218),
    [sym_preproc_elifdef] = STATE(8218),
    [sym_function_definition] = STATE(24),
    [sym_declaration] = STATE(24),
    [sym_type_definition] = STATE(24),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_linkage_specification] = STATE(24),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1943),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6185),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(178),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2258),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(273),
    [sym_statement] = STATE(24),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(24),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1823),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(24),
    [sym_template_instantiation] = STATE(24),
    [sym_operator_cast] = STATE(6628),
    [sym__constructor_specifiers] = STATE(1823),
    [sym_operator_cast_definition] = STATE(24),
    [sym_operator_cast_declaration] = STATE(24),
    [sym_constructor_or_destructor_definition] = STATE(24),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(24),
    [sym_namespace_alias_definition] = STATE(24),
    [sym_using_declaration] = STATE(24),
    [sym_alias_declaration] = STATE(24),
    [sym_static_assert_declaration] = STATE(24),
    [sym_concept_definition] = STATE(24),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6628),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(1214),
    [aux_sym_preproc_if_repeat1] = STATE(24),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1823),
    [sym_identifier] = ACTIONS(265),
    [aux_sym_preproc_include_token1] = ACTIONS(267),
    [aux_sym_preproc_def_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token1] = ACTIONS(271),
    [aux_sym_preproc_if_token2] = ACTIONS(361),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(275),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(275),
    [aux_sym_preproc_else_token1] = ACTIONS(277),
    [aux_sym_preproc_elif_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(281),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(281),
    [sym_preproc_directive] = ACTIONS(283),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym___extension__] = ACTIONS(287),
    [anon_sym_typedef] = ACTIONS(289),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(291),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(295),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(323),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_namespace] = ACTIONS(329),
    [anon_sym_using] = ACTIONS(331),
    [anon_sym_static_assert] = ACTIONS(333),
    [anon_sym_concept] = ACTIONS(335),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [23] = {
    [sym__block_item] = STATE(14),
    [sym_preproc_include] = STATE(14),
    [sym_preproc_def] = STATE(14),
    [sym_preproc_function_def] = STATE(14),
    [sym_preproc_call] = STATE(14),
    [sym_preproc_if] = STATE(14),
    [sym_preproc_ifdef] = STATE(14),
    [sym_preproc_else] = STATE(8640),
    [sym_preproc_elif] = STATE(8640),
    [sym_preproc_elifdef] = STATE(8640),
    [sym_function_definition] = STATE(14),
    [sym_declaration] = STATE(14),
    [sym_type_definition] = STATE(14),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_linkage_specification] = STATE(14),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1943),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6185),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(178),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2258),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(273),
    [sym_statement] = STATE(14),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(14),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1823),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(14),
    [sym_template_instantiation] = STATE(14),
    [sym_operator_cast] = STATE(6628),
    [sym__constructor_specifiers] = STATE(1823),
    [sym_operator_cast_definition] = STATE(14),
    [sym_operator_cast_declaration] = STATE(14),
    [sym_constructor_or_destructor_definition] = STATE(14),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(14),
    [sym_namespace_alias_definition] = STATE(14),
    [sym_using_declaration] = STATE(14),
    [sym_alias_declaration] = STATE(14),
    [sym_static_assert_declaration] = STATE(14),
    [sym_concept_definition] = STATE(14),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6628),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(1214),
    [aux_sym_preproc_if_repeat1] = STATE(14),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1823),
    [sym_identifier] = ACTIONS(265),
    [aux_sym_preproc_include_token1] = ACTIONS(267),
    [aux_sym_preproc_def_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token1] = ACTIONS(271),
    [aux_sym_preproc_if_token2] = ACTIONS(363),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(275),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(275),
    [aux_sym_preproc_else_token1] = ACTIONS(277),
    [aux_sym_preproc_elif_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(281),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(281),
    [sym_preproc_directive] = ACTIONS(283),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym___extension__] = ACTIONS(287),
    [anon_sym_typedef] = ACTIONS(289),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(291),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(295),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(323),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_namespace] = ACTIONS(329),
    [anon_sym_using] = ACTIONS(331),
    [anon_sym_static_assert] = ACTIONS(333),
    [anon_sym_concept] = ACTIONS(335),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [24] = {
    [sym__block_item] = STATE(33),
    [sym_preproc_include] = STATE(33),
    [sym_preproc_def] = STATE(33),
    [sym_preproc_function_def] = STATE(33),
    [sym_preproc_call] = STATE(33),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_ifdef] = STATE(33),
    [sym_preproc_else] = STATE(8143),
    [sym_preproc_elif] = STATE(8143),
    [sym_preproc_elifdef] = STATE(8143),
    [sym_function_definition] = STATE(33),
    [sym_declaration] = STATE(33),
    [sym_type_definition] = STATE(33),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_linkage_specification] = STATE(33),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1943),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6185),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(178),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2258),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(273),
    [sym_statement] = STATE(33),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(33),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1823),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(33),
    [sym_template_instantiation] = STATE(33),
    [sym_operator_cast] = STATE(6628),
    [sym__constructor_specifiers] = STATE(1823),
    [sym_operator_cast_definition] = STATE(33),
    [sym_operator_cast_declaration] = STATE(33),
    [sym_constructor_or_destructor_definition] = STATE(33),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(33),
    [sym_namespace_alias_definition] = STATE(33),
    [sym_using_declaration] = STATE(33),
    [sym_alias_declaration] = STATE(33),
    [sym_static_assert_declaration] = STATE(33),
    [sym_concept_definition] = STATE(33),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6628),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(1214),
    [aux_sym_preproc_if_repeat1] = STATE(33),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1823),
    [sym_identifier] = ACTIONS(265),
    [aux_sym_preproc_include_token1] = ACTIONS(267),
    [aux_sym_preproc_def_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token1] = ACTIONS(271),
    [aux_sym_preproc_if_token2] = ACTIONS(365),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(275),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(275),
    [aux_sym_preproc_else_token1] = ACTIONS(277),
    [aux_sym_preproc_elif_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(281),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(281),
    [sym_preproc_directive] = ACTIONS(283),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym___extension__] = ACTIONS(287),
    [anon_sym_typedef] = ACTIONS(289),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(291),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(295),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(323),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_namespace] = ACTIONS(329),
    [anon_sym_using] = ACTIONS(331),
    [anon_sym_static_assert] = ACTIONS(333),
    [anon_sym_concept] = ACTIONS(335),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [25] = {
    [sym__block_item] = STATE(19),
    [sym_preproc_include] = STATE(19),
    [sym_preproc_def] = STATE(19),
    [sym_preproc_function_def] = STATE(19),
    [sym_preproc_call] = STATE(19),
    [sym_preproc_if] = STATE(19),
    [sym_preproc_ifdef] = STATE(19),
    [sym_preproc_else] = STATE(8277),
    [sym_preproc_elif] = STATE(8277),
    [sym_preproc_elifdef] = STATE(8277),
    [sym_function_definition] = STATE(19),
    [sym_declaration] = STATE(19),
    [sym_type_definition] = STATE(19),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_linkage_specification] = STATE(19),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1943),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6185),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(178),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2258),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(273),
    [sym_statement] = STATE(19),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(19),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1823),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(19),
    [sym_template_instantiation] = STATE(19),
    [sym_operator_cast] = STATE(6628),
    [sym__constructor_specifiers] = STATE(1823),
    [sym_operator_cast_definition] = STATE(19),
    [sym_operator_cast_declaration] = STATE(19),
    [sym_constructor_or_destructor_definition] = STATE(19),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(19),
    [sym_namespace_alias_definition] = STATE(19),
    [sym_using_declaration] = STATE(19),
    [sym_alias_declaration] = STATE(19),
    [sym_static_assert_declaration] = STATE(19),
    [sym_concept_definition] = STATE(19),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6628),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(1214),
    [aux_sym_preproc_if_repeat1] = STATE(19),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1823),
    [sym_identifier] = ACTIONS(265),
    [aux_sym_preproc_include_token1] = ACTIONS(267),
    [aux_sym_preproc_def_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token1] = ACTIONS(271),
    [aux_sym_preproc_if_token2] = ACTIONS(367),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(275),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(275),
    [aux_sym_preproc_else_token1] = ACTIONS(277),
    [aux_sym_preproc_elif_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(281),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(281),
    [sym_preproc_directive] = ACTIONS(283),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym___extension__] = ACTIONS(287),
    [anon_sym_typedef] = ACTIONS(289),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(291),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(295),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(323),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_namespace] = ACTIONS(329),
    [anon_sym_using] = ACTIONS(331),
    [anon_sym_static_assert] = ACTIONS(333),
    [anon_sym_concept] = ACTIONS(335),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [26] = {
    [sym__block_item] = STATE(33),
    [sym_preproc_include] = STATE(33),
    [sym_preproc_def] = STATE(33),
    [sym_preproc_function_def] = STATE(33),
    [sym_preproc_call] = STATE(33),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_ifdef] = STATE(33),
    [sym_preproc_else] = STATE(8384),
    [sym_preproc_elif] = STATE(8384),
    [sym_preproc_elifdef] = STATE(8384),
    [sym_function_definition] = STATE(33),
    [sym_declaration] = STATE(33),
    [sym_type_definition] = STATE(33),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_linkage_specification] = STATE(33),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1943),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6185),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(178),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2258),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(273),
    [sym_statement] = STATE(33),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(33),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1823),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(33),
    [sym_template_instantiation] = STATE(33),
    [sym_operator_cast] = STATE(6628),
    [sym__constructor_specifiers] = STATE(1823),
    [sym_operator_cast_definition] = STATE(33),
    [sym_operator_cast_declaration] = STATE(33),
    [sym_constructor_or_destructor_definition] = STATE(33),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(33),
    [sym_namespace_alias_definition] = STATE(33),
    [sym_using_declaration] = STATE(33),
    [sym_alias_declaration] = STATE(33),
    [sym_static_assert_declaration] = STATE(33),
    [sym_concept_definition] = STATE(33),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6628),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(1214),
    [aux_sym_preproc_if_repeat1] = STATE(33),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1823),
    [sym_identifier] = ACTIONS(265),
    [aux_sym_preproc_include_token1] = ACTIONS(267),
    [aux_sym_preproc_def_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token1] = ACTIONS(271),
    [aux_sym_preproc_if_token2] = ACTIONS(369),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(275),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(275),
    [aux_sym_preproc_else_token1] = ACTIONS(277),
    [aux_sym_preproc_elif_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(281),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(281),
    [sym_preproc_directive] = ACTIONS(283),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym___extension__] = ACTIONS(287),
    [anon_sym_typedef] = ACTIONS(289),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(291),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(295),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(323),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_namespace] = ACTIONS(329),
    [anon_sym_using] = ACTIONS(331),
    [anon_sym_static_assert] = ACTIONS(333),
    [anon_sym_concept] = ACTIONS(335),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [27] = {
    [sym__block_item] = STATE(33),
    [sym_preproc_include] = STATE(33),
    [sym_preproc_def] = STATE(33),
    [sym_preproc_function_def] = STATE(33),
    [sym_preproc_call] = STATE(33),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_ifdef] = STATE(33),
    [sym_preproc_else] = STATE(7952),
    [sym_preproc_elif] = STATE(7952),
    [sym_preproc_elifdef] = STATE(7952),
    [sym_function_definition] = STATE(33),
    [sym_declaration] = STATE(33),
    [sym_type_definition] = STATE(33),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_linkage_specification] = STATE(33),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1943),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6185),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(178),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2258),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(273),
    [sym_statement] = STATE(33),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(33),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1823),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(33),
    [sym_template_instantiation] = STATE(33),
    [sym_operator_cast] = STATE(6628),
    [sym__constructor_specifiers] = STATE(1823),
    [sym_operator_cast_definition] = STATE(33),
    [sym_operator_cast_declaration] = STATE(33),
    [sym_constructor_or_destructor_definition] = STATE(33),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(33),
    [sym_namespace_alias_definition] = STATE(33),
    [sym_using_declaration] = STATE(33),
    [sym_alias_declaration] = STATE(33),
    [sym_static_assert_declaration] = STATE(33),
    [sym_concept_definition] = STATE(33),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6628),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(1214),
    [aux_sym_preproc_if_repeat1] = STATE(33),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1823),
    [sym_identifier] = ACTIONS(265),
    [aux_sym_preproc_include_token1] = ACTIONS(267),
    [aux_sym_preproc_def_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token1] = ACTIONS(271),
    [aux_sym_preproc_if_token2] = ACTIONS(371),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(275),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(275),
    [aux_sym_preproc_else_token1] = ACTIONS(277),
    [aux_sym_preproc_elif_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(281),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(281),
    [sym_preproc_directive] = ACTIONS(283),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym___extension__] = ACTIONS(287),
    [anon_sym_typedef] = ACTIONS(289),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(291),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(295),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(323),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_namespace] = ACTIONS(329),
    [anon_sym_using] = ACTIONS(331),
    [anon_sym_static_assert] = ACTIONS(333),
    [anon_sym_concept] = ACTIONS(335),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [28] = {
    [sym__block_item] = STATE(33),
    [sym_preproc_include] = STATE(33),
    [sym_preproc_def] = STATE(33),
    [sym_preproc_function_def] = STATE(33),
    [sym_preproc_call] = STATE(33),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_ifdef] = STATE(33),
    [sym_preproc_else] = STATE(8623),
    [sym_preproc_elif] = STATE(8623),
    [sym_preproc_elifdef] = STATE(8623),
    [sym_function_definition] = STATE(33),
    [sym_declaration] = STATE(33),
    [sym_type_definition] = STATE(33),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_linkage_specification] = STATE(33),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1943),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6185),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(178),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2258),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(273),
    [sym_statement] = STATE(33),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(33),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1823),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(33),
    [sym_template_instantiation] = STATE(33),
    [sym_operator_cast] = STATE(6628),
    [sym__constructor_specifiers] = STATE(1823),
    [sym_operator_cast_definition] = STATE(33),
    [sym_operator_cast_declaration] = STATE(33),
    [sym_constructor_or_destructor_definition] = STATE(33),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(33),
    [sym_namespace_alias_definition] = STATE(33),
    [sym_using_declaration] = STATE(33),
    [sym_alias_declaration] = STATE(33),
    [sym_static_assert_declaration] = STATE(33),
    [sym_concept_definition] = STATE(33),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6628),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(1214),
    [aux_sym_preproc_if_repeat1] = STATE(33),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1823),
    [sym_identifier] = ACTIONS(265),
    [aux_sym_preproc_include_token1] = ACTIONS(267),
    [aux_sym_preproc_def_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token1] = ACTIONS(271),
    [aux_sym_preproc_if_token2] = ACTIONS(373),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(275),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(275),
    [aux_sym_preproc_else_token1] = ACTIONS(277),
    [aux_sym_preproc_elif_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(281),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(281),
    [sym_preproc_directive] = ACTIONS(283),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym___extension__] = ACTIONS(287),
    [anon_sym_typedef] = ACTIONS(289),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(291),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(295),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(323),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_namespace] = ACTIONS(329),
    [anon_sym_using] = ACTIONS(331),
    [anon_sym_static_assert] = ACTIONS(333),
    [anon_sym_concept] = ACTIONS(335),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [29] = {
    [sym__block_item] = STATE(32),
    [sym_preproc_include] = STATE(32),
    [sym_preproc_def] = STATE(32),
    [sym_preproc_function_def] = STATE(32),
    [sym_preproc_call] = STATE(32),
    [sym_preproc_if] = STATE(32),
    [sym_preproc_ifdef] = STATE(32),
    [sym_preproc_else] = STATE(7953),
    [sym_preproc_elif] = STATE(7953),
    [sym_preproc_elifdef] = STATE(7953),
    [sym_function_definition] = STATE(32),
    [sym_declaration] = STATE(32),
    [sym_type_definition] = STATE(32),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_linkage_specification] = STATE(32),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1943),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6185),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(178),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2258),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(273),
    [sym_statement] = STATE(32),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(32),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1823),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(32),
    [sym_template_instantiation] = STATE(32),
    [sym_operator_cast] = STATE(6628),
    [sym__constructor_specifiers] = STATE(1823),
    [sym_operator_cast_definition] = STATE(32),
    [sym_operator_cast_declaration] = STATE(32),
    [sym_constructor_or_destructor_definition] = STATE(32),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(32),
    [sym_namespace_alias_definition] = STATE(32),
    [sym_using_declaration] = STATE(32),
    [sym_alias_declaration] = STATE(32),
    [sym_static_assert_declaration] = STATE(32),
    [sym_concept_definition] = STATE(32),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6628),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(1214),
    [aux_sym_preproc_if_repeat1] = STATE(32),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1823),
    [sym_identifier] = ACTIONS(265),
    [aux_sym_preproc_include_token1] = ACTIONS(267),
    [aux_sym_preproc_def_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token1] = ACTIONS(271),
    [aux_sym_preproc_if_token2] = ACTIONS(375),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(275),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(275),
    [aux_sym_preproc_else_token1] = ACTIONS(277),
    [aux_sym_preproc_elif_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(281),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(281),
    [sym_preproc_directive] = ACTIONS(283),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym___extension__] = ACTIONS(287),
    [anon_sym_typedef] = ACTIONS(289),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(291),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(295),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(323),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_namespace] = ACTIONS(329),
    [anon_sym_using] = ACTIONS(331),
    [anon_sym_static_assert] = ACTIONS(333),
    [anon_sym_concept] = ACTIONS(335),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [30] = {
    [sym__block_item] = STATE(26),
    [sym_preproc_include] = STATE(26),
    [sym_preproc_def] = STATE(26),
    [sym_preproc_function_def] = STATE(26),
    [sym_preproc_call] = STATE(26),
    [sym_preproc_if] = STATE(26),
    [sym_preproc_ifdef] = STATE(26),
    [sym_preproc_else] = STATE(8478),
    [sym_preproc_elif] = STATE(8478),
    [sym_preproc_elifdef] = STATE(8478),
    [sym_function_definition] = STATE(26),
    [sym_declaration] = STATE(26),
    [sym_type_definition] = STATE(26),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_linkage_specification] = STATE(26),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1943),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6185),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(178),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2258),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(273),
    [sym_statement] = STATE(26),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(26),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1823),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(26),
    [sym_template_instantiation] = STATE(26),
    [sym_operator_cast] = STATE(6628),
    [sym__constructor_specifiers] = STATE(1823),
    [sym_operator_cast_definition] = STATE(26),
    [sym_operator_cast_declaration] = STATE(26),
    [sym_constructor_or_destructor_definition] = STATE(26),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(26),
    [sym_namespace_alias_definition] = STATE(26),
    [sym_using_declaration] = STATE(26),
    [sym_alias_declaration] = STATE(26),
    [sym_static_assert_declaration] = STATE(26),
    [sym_concept_definition] = STATE(26),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6628),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(1214),
    [aux_sym_preproc_if_repeat1] = STATE(26),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1823),
    [sym_identifier] = ACTIONS(265),
    [aux_sym_preproc_include_token1] = ACTIONS(267),
    [aux_sym_preproc_def_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token1] = ACTIONS(271),
    [aux_sym_preproc_if_token2] = ACTIONS(377),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(275),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(275),
    [aux_sym_preproc_else_token1] = ACTIONS(277),
    [aux_sym_preproc_elif_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(281),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(281),
    [sym_preproc_directive] = ACTIONS(283),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym___extension__] = ACTIONS(287),
    [anon_sym_typedef] = ACTIONS(289),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(291),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(295),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(323),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_namespace] = ACTIONS(329),
    [anon_sym_using] = ACTIONS(331),
    [anon_sym_static_assert] = ACTIONS(333),
    [anon_sym_concept] = ACTIONS(335),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [31] = {
    [sym__block_item] = STATE(27),
    [sym_preproc_include] = STATE(27),
    [sym_preproc_def] = STATE(27),
    [sym_preproc_function_def] = STATE(27),
    [sym_preproc_call] = STATE(27),
    [sym_preproc_if] = STATE(27),
    [sym_preproc_ifdef] = STATE(27),
    [sym_preproc_else] = STATE(7994),
    [sym_preproc_elif] = STATE(7994),
    [sym_preproc_elifdef] = STATE(7994),
    [sym_function_definition] = STATE(27),
    [sym_declaration] = STATE(27),
    [sym_type_definition] = STATE(27),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_linkage_specification] = STATE(27),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1943),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6185),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(178),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2258),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(273),
    [sym_statement] = STATE(27),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(27),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1823),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(27),
    [sym_template_instantiation] = STATE(27),
    [sym_operator_cast] = STATE(6628),
    [sym__constructor_specifiers] = STATE(1823),
    [sym_operator_cast_definition] = STATE(27),
    [sym_operator_cast_declaration] = STATE(27),
    [sym_constructor_or_destructor_definition] = STATE(27),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(27),
    [sym_namespace_alias_definition] = STATE(27),
    [sym_using_declaration] = STATE(27),
    [sym_alias_declaration] = STATE(27),
    [sym_static_assert_declaration] = STATE(27),
    [sym_concept_definition] = STATE(27),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6628),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(1214),
    [aux_sym_preproc_if_repeat1] = STATE(27),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1823),
    [sym_identifier] = ACTIONS(265),
    [aux_sym_preproc_include_token1] = ACTIONS(267),
    [aux_sym_preproc_def_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token1] = ACTIONS(271),
    [aux_sym_preproc_if_token2] = ACTIONS(379),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(275),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(275),
    [aux_sym_preproc_else_token1] = ACTIONS(277),
    [aux_sym_preproc_elif_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(281),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(281),
    [sym_preproc_directive] = ACTIONS(283),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym___extension__] = ACTIONS(287),
    [anon_sym_typedef] = ACTIONS(289),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(291),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(295),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(323),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_namespace] = ACTIONS(329),
    [anon_sym_using] = ACTIONS(331),
    [anon_sym_static_assert] = ACTIONS(333),
    [anon_sym_concept] = ACTIONS(335),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [32] = {
    [sym__block_item] = STATE(33),
    [sym_preproc_include] = STATE(33),
    [sym_preproc_def] = STATE(33),
    [sym_preproc_function_def] = STATE(33),
    [sym_preproc_call] = STATE(33),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_ifdef] = STATE(33),
    [sym_preproc_else] = STATE(7921),
    [sym_preproc_elif] = STATE(7921),
    [sym_preproc_elifdef] = STATE(7921),
    [sym_function_definition] = STATE(33),
    [sym_declaration] = STATE(33),
    [sym_type_definition] = STATE(33),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_linkage_specification] = STATE(33),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1943),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6185),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(178),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2258),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(273),
    [sym_statement] = STATE(33),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(33),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1823),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(33),
    [sym_template_instantiation] = STATE(33),
    [sym_operator_cast] = STATE(6628),
    [sym__constructor_specifiers] = STATE(1823),
    [sym_operator_cast_definition] = STATE(33),
    [sym_operator_cast_declaration] = STATE(33),
    [sym_constructor_or_destructor_definition] = STATE(33),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(33),
    [sym_namespace_alias_definition] = STATE(33),
    [sym_using_declaration] = STATE(33),
    [sym_alias_declaration] = STATE(33),
    [sym_static_assert_declaration] = STATE(33),
    [sym_concept_definition] = STATE(33),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6628),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(1214),
    [aux_sym_preproc_if_repeat1] = STATE(33),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1823),
    [sym_identifier] = ACTIONS(265),
    [aux_sym_preproc_include_token1] = ACTIONS(267),
    [aux_sym_preproc_def_token1] = ACTIONS(269),
    [aux_sym_preproc_if_token1] = ACTIONS(271),
    [aux_sym_preproc_if_token2] = ACTIONS(381),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(275),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(275),
    [aux_sym_preproc_else_token1] = ACTIONS(277),
    [aux_sym_preproc_elif_token1] = ACTIONS(279),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(281),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(281),
    [sym_preproc_directive] = ACTIONS(283),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym___extension__] = ACTIONS(287),
    [anon_sym_typedef] = ACTIONS(289),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(291),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(295),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(323),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_namespace] = ACTIONS(329),
    [anon_sym_using] = ACTIONS(331),
    [anon_sym_static_assert] = ACTIONS(333),
    [anon_sym_concept] = ACTIONS(335),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [33] = {
    [sym__block_item] = STATE(33),
    [sym_preproc_include] = STATE(33),
    [sym_preproc_def] = STATE(33),
    [sym_preproc_function_def] = STATE(33),
    [sym_preproc_call] = STATE(33),
    [sym_preproc_if] = STATE(33),
    [sym_preproc_ifdef] = STATE(33),
    [sym_function_definition] = STATE(33),
    [sym_declaration] = STATE(33),
    [sym_type_definition] = STATE(33),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_linkage_specification] = STATE(33),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1943),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6185),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(178),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2258),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(273),
    [sym_statement] = STATE(33),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(33),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1823),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(33),
    [sym_template_instantiation] = STATE(33),
    [sym_operator_cast] = STATE(6628),
    [sym__constructor_specifiers] = STATE(1823),
    [sym_operator_cast_definition] = STATE(33),
    [sym_operator_cast_declaration] = STATE(33),
    [sym_constructor_or_destructor_definition] = STATE(33),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(33),
    [sym_namespace_alias_definition] = STATE(33),
    [sym_using_declaration] = STATE(33),
    [sym_alias_declaration] = STATE(33),
    [sym_static_assert_declaration] = STATE(33),
    [sym_concept_definition] = STATE(33),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6628),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(1214),
    [aux_sym_preproc_if_repeat1] = STATE(33),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1823),
    [sym_identifier] = ACTIONS(383),
    [aux_sym_preproc_include_token1] = ACTIONS(386),
    [aux_sym_preproc_def_token1] = ACTIONS(389),
    [aux_sym_preproc_if_token1] = ACTIONS(392),
    [aux_sym_preproc_if_token2] = ACTIONS(395),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(397),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(397),
    [aux_sym_preproc_else_token1] = ACTIONS(395),
    [aux_sym_preproc_elif_token1] = ACTIONS(395),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(395),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(395),
    [sym_preproc_directive] = ACTIONS(400),
    [anon_sym_LPAREN2] = ACTIONS(403),
    [anon_sym_BANG] = ACTIONS(406),
    [anon_sym_TILDE] = ACTIONS(409),
    [anon_sym_DASH] = ACTIONS(412),
    [anon_sym_PLUS] = ACTIONS(412),
    [anon_sym_STAR] = ACTIONS(415),
    [anon_sym_AMP_AMP] = ACTIONS(418),
    [anon_sym_AMP] = ACTIONS(421),
    [anon_sym_SEMI] = ACTIONS(424),
    [anon_sym___extension__] = ACTIONS(427),
    [anon_sym_typedef] = ACTIONS(430),
    [anon_sym_in] = ACTIONS(433),
    [anon_sym_out] = ACTIONS(433),
    [anon_sym_inout] = ACTIONS(433),
    [anon_sym_extern] = ACTIONS(436),
    [anon_sym___attribute__] = ACTIONS(439),
    [anon_sym_COLON_COLON] = ACTIONS(442),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(445),
    [anon_sym___declspec] = ACTIONS(448),
    [anon_sym___based] = ACTIONS(451),
    [anon_sym___cdecl] = ACTIONS(454),
    [anon_sym___clrcall] = ACTIONS(454),
    [anon_sym___stdcall] = ACTIONS(454),
    [anon_sym___fastcall] = ACTIONS(454),
    [anon_sym___thiscall] = ACTIONS(454),
    [anon_sym___vectorcall] = ACTIONS(454),
    [anon_sym_LBRACE] = ACTIONS(457),
    [anon_sym_signed] = ACTIONS(460),
    [anon_sym_unsigned] = ACTIONS(460),
    [anon_sym_long] = ACTIONS(460),
    [anon_sym_short] = ACTIONS(460),
    [anon_sym_LBRACK] = ACTIONS(463),
    [anon_sym_static] = ACTIONS(466),
    [anon_sym_register] = ACTIONS(466),
    [anon_sym_inline] = ACTIONS(469),
    [anon_sym___inline] = ACTIONS(466),
    [anon_sym___inline__] = ACTIONS(466),
    [anon_sym___forceinline] = ACTIONS(466),
    [anon_sym_thread_local] = ACTIONS(466),
    [anon_sym___thread] = ACTIONS(466),
    [anon_sym_const] = ACTIONS(472),
    [anon_sym_constexpr] = ACTIONS(472),
    [anon_sym_volatile] = ACTIONS(472),
    [anon_sym_restrict] = ACTIONS(472),
    [anon_sym___restrict__] = ACTIONS(472),
    [anon_sym__Atomic] = ACTIONS(472),
    [anon_sym__Noreturn] = ACTIONS(472),
    [anon_sym_noreturn] = ACTIONS(472),
    [anon_sym_mutable] = ACTIONS(472),
    [anon_sym_constinit] = ACTIONS(472),
    [anon_sym_consteval] = ACTIONS(472),
    [anon_sym_alignas] = ACTIONS(475),
    [anon_sym__Alignas] = ACTIONS(475),
    [sym_primitive_type] = ACTIONS(478),
    [anon_sym_enum] = ACTIONS(481),
    [anon_sym_class] = ACTIONS(484),
    [anon_sym_struct] = ACTIONS(487),
    [anon_sym_union] = ACTIONS(490),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_switch] = ACTIONS(496),
    [anon_sym_case] = ACTIONS(499),
    [anon_sym_default] = ACTIONS(502),
    [anon_sym_while] = ACTIONS(505),
    [anon_sym_do] = ACTIONS(508),
    [anon_sym_for] = ACTIONS(511),
    [anon_sym_return] = ACTIONS(514),
    [anon_sym_break] = ACTIONS(517),
    [anon_sym_continue] = ACTIONS(520),
    [anon_sym_goto] = ACTIONS(523),
    [anon_sym___try] = ACTIONS(526),
    [anon_sym___leave] = ACTIONS(529),
    [anon_sym_not] = ACTIONS(412),
    [anon_sym_compl] = ACTIONS(412),
    [anon_sym_DASH_DASH] = ACTIONS(532),
    [anon_sym_PLUS_PLUS] = ACTIONS(532),
    [anon_sym_sizeof] = ACTIONS(535),
    [anon_sym___alignof__] = ACTIONS(538),
    [anon_sym___alignof] = ACTIONS(538),
    [anon_sym__alignof] = ACTIONS(538),
    [anon_sym_alignof] = ACTIONS(538),
    [anon_sym__Alignof] = ACTIONS(538),
    [anon_sym_offsetof] = ACTIONS(541),
    [anon_sym__Generic] = ACTIONS(544),
    [anon_sym_asm] = ACTIONS(547),
    [anon_sym___asm__] = ACTIONS(547),
    [sym_number_literal] = ACTIONS(550),
    [anon_sym_L_SQUOTE] = ACTIONS(553),
    [anon_sym_u_SQUOTE] = ACTIONS(553),
    [anon_sym_U_SQUOTE] = ACTIONS(553),
    [anon_sym_u8_SQUOTE] = ACTIONS(553),
    [anon_sym_SQUOTE] = ACTIONS(553),
    [anon_sym_L_DQUOTE] = ACTIONS(556),
    [anon_sym_u_DQUOTE] = ACTIONS(556),
    [anon_sym_U_DQUOTE] = ACTIONS(556),
    [anon_sym_u8_DQUOTE] = ACTIONS(556),
    [anon_sym_DQUOTE] = ACTIONS(556),
    [sym_true] = ACTIONS(559),
    [sym_false] = ACTIONS(559),
    [anon_sym_NULL] = ACTIONS(562),
    [anon_sym_nullptr] = ACTIONS(562),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(565),
    [anon_sym_decltype] = ACTIONS(568),
    [sym_virtual] = ACTIONS(433),
    [anon_sym_explicit] = ACTIONS(571),
    [anon_sym_typename] = ACTIONS(574),
    [anon_sym_template] = ACTIONS(577),
    [anon_sym_operator] = ACTIONS(580),
    [anon_sym_try] = ACTIONS(583),
    [anon_sym_delete] = ACTIONS(586),
    [anon_sym_throw] = ACTIONS(589),
    [anon_sym_namespace] = ACTIONS(592),
    [anon_sym_using] = ACTIONS(595),
    [anon_sym_static_assert] = ACTIONS(598),
    [anon_sym_concept] = ACTIONS(601),
    [anon_sym_co_return] = ACTIONS(604),
    [anon_sym_co_yield] = ACTIONS(607),
    [anon_sym_R_DQUOTE] = ACTIONS(610),
    [anon_sym_LR_DQUOTE] = ACTIONS(610),
    [anon_sym_uR_DQUOTE] = ACTIONS(610),
    [anon_sym_UR_DQUOTE] = ACTIONS(610),
    [anon_sym_u8R_DQUOTE] = ACTIONS(610),
    [anon_sym_co_await] = ACTIONS(613),
    [anon_sym_new] = ACTIONS(616),
    [anon_sym_requires] = ACTIONS(619),
    [sym_this] = ACTIONS(559),
    [anon_sym_discard] = ACTIONS(622),
    [anon_sym_precise] = ACTIONS(625),
    [anon_sym_shared] = ACTIONS(625),
    [anon_sym_groupshared] = ACTIONS(625),
    [anon_sym_uniform] = ACTIONS(625),
    [anon_sym_row_major] = ACTIONS(625),
    [anon_sym_column_major] = ACTIONS(625),
    [anon_sym_globallycoherent] = ACTIONS(625),
    [anon_sym_centroid] = ACTIONS(625),
    [anon_sym_noperspective] = ACTIONS(625),
    [anon_sym_nointerpolation] = ACTIONS(625),
    [anon_sym_sample] = ACTIONS(625),
    [anon_sym_linear] = ACTIONS(625),
    [anon_sym_snorm] = ACTIONS(625),
    [anon_sym_unorm] = ACTIONS(625),
    [anon_sym_point] = ACTIONS(625),
    [anon_sym_line] = ACTIONS(625),
    [anon_sym_triangleadj] = ACTIONS(625),
    [anon_sym_lineadj] = ACTIONS(625),
    [anon_sym_triangle] = ACTIONS(625),
    [anon_sym_cbuffer] = ACTIONS(628),
  },
  [34] = {
    [sym__block_item] = STATE(45),
    [sym_preproc_include] = STATE(45),
    [sym_preproc_def] = STATE(45),
    [sym_preproc_function_def] = STATE(45),
    [sym_preproc_call] = STATE(45),
    [sym_preproc_if] = STATE(45),
    [sym_preproc_ifdef] = STATE(45),
    [sym_function_definition] = STATE(45),
    [sym_declaration] = STATE(45),
    [sym_type_definition] = STATE(45),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(45),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(45),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(45),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(45),
    [sym_template_instantiation] = STATE(45),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(45),
    [sym_operator_cast_declaration] = STATE(45),
    [sym_constructor_or_destructor_definition] = STATE(45),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(45),
    [sym_namespace_alias_definition] = STATE(45),
    [sym_using_declaration] = STATE(45),
    [sym_alias_declaration] = STATE(45),
    [sym_static_assert_declaration] = STATE(45),
    [sym_concept_definition] = STATE(45),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(45),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(635),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [35] = {
    [sym__block_item] = STATE(42),
    [sym_preproc_include] = STATE(42),
    [sym_preproc_def] = STATE(42),
    [sym_preproc_function_def] = STATE(42),
    [sym_preproc_call] = STATE(42),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_ifdef] = STATE(42),
    [sym_function_definition] = STATE(42),
    [sym_declaration] = STATE(42),
    [sym_type_definition] = STATE(42),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(42),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(42),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(42),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(42),
    [sym_template_instantiation] = STATE(42),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(42),
    [sym_operator_cast_declaration] = STATE(42),
    [sym_constructor_or_destructor_definition] = STATE(42),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(42),
    [sym_namespace_alias_definition] = STATE(42),
    [sym_using_declaration] = STATE(42),
    [sym_alias_declaration] = STATE(42),
    [sym_static_assert_declaration] = STATE(42),
    [sym_concept_definition] = STATE(42),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(42),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(637),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [36] = {
    [sym__block_item] = STATE(39),
    [sym_preproc_include] = STATE(39),
    [sym_preproc_def] = STATE(39),
    [sym_preproc_function_def] = STATE(39),
    [sym_preproc_call] = STATE(39),
    [sym_preproc_if] = STATE(39),
    [sym_preproc_ifdef] = STATE(39),
    [sym_function_definition] = STATE(39),
    [sym_declaration] = STATE(39),
    [sym_type_definition] = STATE(39),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(39),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(39),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(39),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(39),
    [sym_template_instantiation] = STATE(39),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(39),
    [sym_operator_cast_declaration] = STATE(39),
    [sym_constructor_or_destructor_definition] = STATE(39),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(39),
    [sym_namespace_alias_definition] = STATE(39),
    [sym_using_declaration] = STATE(39),
    [sym_alias_declaration] = STATE(39),
    [sym_static_assert_declaration] = STATE(39),
    [sym_concept_definition] = STATE(39),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(39),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(639),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [37] = {
    [sym__block_item] = STATE(68),
    [sym_preproc_include] = STATE(68),
    [sym_preproc_def] = STATE(68),
    [sym_preproc_function_def] = STATE(68),
    [sym_preproc_call] = STATE(68),
    [sym_preproc_if] = STATE(68),
    [sym_preproc_ifdef] = STATE(68),
    [sym_function_definition] = STATE(68),
    [sym_declaration] = STATE(68),
    [sym_type_definition] = STATE(68),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(68),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(68),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(68),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(68),
    [sym_template_instantiation] = STATE(68),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(68),
    [sym_operator_cast_declaration] = STATE(68),
    [sym_constructor_or_destructor_definition] = STATE(68),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(68),
    [sym_namespace_alias_definition] = STATE(68),
    [sym_using_declaration] = STATE(68),
    [sym_alias_declaration] = STATE(68),
    [sym_static_assert_declaration] = STATE(68),
    [sym_concept_definition] = STATE(68),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(68),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(641),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [38] = {
    [sym__block_item] = STATE(42),
    [sym_preproc_include] = STATE(42),
    [sym_preproc_def] = STATE(42),
    [sym_preproc_function_def] = STATE(42),
    [sym_preproc_call] = STATE(42),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_ifdef] = STATE(42),
    [sym_function_definition] = STATE(42),
    [sym_declaration] = STATE(42),
    [sym_type_definition] = STATE(42),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(42),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(42),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(42),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(42),
    [sym_template_instantiation] = STATE(42),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(42),
    [sym_operator_cast_declaration] = STATE(42),
    [sym_constructor_or_destructor_definition] = STATE(42),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(42),
    [sym_namespace_alias_definition] = STATE(42),
    [sym_using_declaration] = STATE(42),
    [sym_alias_declaration] = STATE(42),
    [sym_static_assert_declaration] = STATE(42),
    [sym_concept_definition] = STATE(42),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(42),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(643),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [39] = {
    [sym__block_item] = STATE(42),
    [sym_preproc_include] = STATE(42),
    [sym_preproc_def] = STATE(42),
    [sym_preproc_function_def] = STATE(42),
    [sym_preproc_call] = STATE(42),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_ifdef] = STATE(42),
    [sym_function_definition] = STATE(42),
    [sym_declaration] = STATE(42),
    [sym_type_definition] = STATE(42),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(42),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(42),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(42),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(42),
    [sym_template_instantiation] = STATE(42),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(42),
    [sym_operator_cast_declaration] = STATE(42),
    [sym_constructor_or_destructor_definition] = STATE(42),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(42),
    [sym_namespace_alias_definition] = STATE(42),
    [sym_using_declaration] = STATE(42),
    [sym_alias_declaration] = STATE(42),
    [sym_static_assert_declaration] = STATE(42),
    [sym_concept_definition] = STATE(42),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(42),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(645),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [40] = {
    [sym__block_item] = STATE(44),
    [sym_preproc_include] = STATE(44),
    [sym_preproc_def] = STATE(44),
    [sym_preproc_function_def] = STATE(44),
    [sym_preproc_call] = STATE(44),
    [sym_preproc_if] = STATE(44),
    [sym_preproc_ifdef] = STATE(44),
    [sym_function_definition] = STATE(44),
    [sym_declaration] = STATE(44),
    [sym_type_definition] = STATE(44),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(44),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(44),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(44),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(44),
    [sym_template_instantiation] = STATE(44),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(44),
    [sym_operator_cast_declaration] = STATE(44),
    [sym_constructor_or_destructor_definition] = STATE(44),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(44),
    [sym_namespace_alias_definition] = STATE(44),
    [sym_using_declaration] = STATE(44),
    [sym_alias_declaration] = STATE(44),
    [sym_static_assert_declaration] = STATE(44),
    [sym_concept_definition] = STATE(44),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(44),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(647),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [41] = {
    [sym__block_item] = STATE(38),
    [sym_preproc_include] = STATE(38),
    [sym_preproc_def] = STATE(38),
    [sym_preproc_function_def] = STATE(38),
    [sym_preproc_call] = STATE(38),
    [sym_preproc_if] = STATE(38),
    [sym_preproc_ifdef] = STATE(38),
    [sym_function_definition] = STATE(38),
    [sym_declaration] = STATE(38),
    [sym_type_definition] = STATE(38),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(38),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(38),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(38),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(38),
    [sym_template_instantiation] = STATE(38),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(38),
    [sym_operator_cast_declaration] = STATE(38),
    [sym_constructor_or_destructor_definition] = STATE(38),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(38),
    [sym_namespace_alias_definition] = STATE(38),
    [sym_using_declaration] = STATE(38),
    [sym_alias_declaration] = STATE(38),
    [sym_static_assert_declaration] = STATE(38),
    [sym_concept_definition] = STATE(38),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(38),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(649),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [42] = {
    [sym__block_item] = STATE(42),
    [sym_preproc_include] = STATE(42),
    [sym_preproc_def] = STATE(42),
    [sym_preproc_function_def] = STATE(42),
    [sym_preproc_call] = STATE(42),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_ifdef] = STATE(42),
    [sym_function_definition] = STATE(42),
    [sym_declaration] = STATE(42),
    [sym_type_definition] = STATE(42),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(42),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(42),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(42),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(42),
    [sym_template_instantiation] = STATE(42),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(42),
    [sym_operator_cast_declaration] = STATE(42),
    [sym_constructor_or_destructor_definition] = STATE(42),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(42),
    [sym_namespace_alias_definition] = STATE(42),
    [sym_using_declaration] = STATE(42),
    [sym_alias_declaration] = STATE(42),
    [sym_static_assert_declaration] = STATE(42),
    [sym_concept_definition] = STATE(42),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(42),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(651),
    [aux_sym_preproc_include_token1] = ACTIONS(654),
    [aux_sym_preproc_def_token1] = ACTIONS(657),
    [aux_sym_preproc_if_token1] = ACTIONS(660),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(663),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(663),
    [sym_preproc_directive] = ACTIONS(666),
    [anon_sym_LPAREN2] = ACTIONS(403),
    [anon_sym_BANG] = ACTIONS(406),
    [anon_sym_TILDE] = ACTIONS(409),
    [anon_sym_DASH] = ACTIONS(412),
    [anon_sym_PLUS] = ACTIONS(412),
    [anon_sym_STAR] = ACTIONS(415),
    [anon_sym_AMP_AMP] = ACTIONS(418),
    [anon_sym_AMP] = ACTIONS(421),
    [anon_sym_SEMI] = ACTIONS(669),
    [anon_sym___extension__] = ACTIONS(672),
    [anon_sym_typedef] = ACTIONS(675),
    [anon_sym_in] = ACTIONS(433),
    [anon_sym_out] = ACTIONS(433),
    [anon_sym_inout] = ACTIONS(433),
    [anon_sym_extern] = ACTIONS(678),
    [anon_sym___attribute__] = ACTIONS(439),
    [anon_sym_COLON_COLON] = ACTIONS(442),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(445),
    [anon_sym___declspec] = ACTIONS(448),
    [anon_sym___based] = ACTIONS(451),
    [anon_sym___cdecl] = ACTIONS(454),
    [anon_sym___clrcall] = ACTIONS(454),
    [anon_sym___stdcall] = ACTIONS(454),
    [anon_sym___fastcall] = ACTIONS(454),
    [anon_sym___thiscall] = ACTIONS(454),
    [anon_sym___vectorcall] = ACTIONS(454),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(684),
    [anon_sym_signed] = ACTIONS(460),
    [anon_sym_unsigned] = ACTIONS(460),
    [anon_sym_long] = ACTIONS(460),
    [anon_sym_short] = ACTIONS(460),
    [anon_sym_LBRACK] = ACTIONS(463),
    [anon_sym_static] = ACTIONS(466),
    [anon_sym_register] = ACTIONS(466),
    [anon_sym_inline] = ACTIONS(686),
    [anon_sym___inline] = ACTIONS(466),
    [anon_sym___inline__] = ACTIONS(466),
    [anon_sym___forceinline] = ACTIONS(466),
    [anon_sym_thread_local] = ACTIONS(466),
    [anon_sym___thread] = ACTIONS(466),
    [anon_sym_const] = ACTIONS(472),
    [anon_sym_constexpr] = ACTIONS(472),
    [anon_sym_volatile] = ACTIONS(472),
    [anon_sym_restrict] = ACTIONS(472),
    [anon_sym___restrict__] = ACTIONS(472),
    [anon_sym__Atomic] = ACTIONS(472),
    [anon_sym__Noreturn] = ACTIONS(472),
    [anon_sym_noreturn] = ACTIONS(472),
    [anon_sym_mutable] = ACTIONS(472),
    [anon_sym_constinit] = ACTIONS(472),
    [anon_sym_consteval] = ACTIONS(472),
    [anon_sym_alignas] = ACTIONS(475),
    [anon_sym__Alignas] = ACTIONS(475),
    [sym_primitive_type] = ACTIONS(478),
    [anon_sym_enum] = ACTIONS(481),
    [anon_sym_class] = ACTIONS(484),
    [anon_sym_struct] = ACTIONS(487),
    [anon_sym_union] = ACTIONS(490),
    [anon_sym_if] = ACTIONS(689),
    [anon_sym_switch] = ACTIONS(692),
    [anon_sym_case] = ACTIONS(695),
    [anon_sym_default] = ACTIONS(698),
    [anon_sym_while] = ACTIONS(701),
    [anon_sym_do] = ACTIONS(704),
    [anon_sym_for] = ACTIONS(707),
    [anon_sym_return] = ACTIONS(710),
    [anon_sym_break] = ACTIONS(713),
    [anon_sym_continue] = ACTIONS(716),
    [anon_sym_goto] = ACTIONS(719),
    [anon_sym___try] = ACTIONS(722),
    [anon_sym___leave] = ACTIONS(725),
    [anon_sym_not] = ACTIONS(412),
    [anon_sym_compl] = ACTIONS(412),
    [anon_sym_DASH_DASH] = ACTIONS(532),
    [anon_sym_PLUS_PLUS] = ACTIONS(532),
    [anon_sym_sizeof] = ACTIONS(535),
    [anon_sym___alignof__] = ACTIONS(538),
    [anon_sym___alignof] = ACTIONS(538),
    [anon_sym__alignof] = ACTIONS(538),
    [anon_sym_alignof] = ACTIONS(538),
    [anon_sym__Alignof] = ACTIONS(538),
    [anon_sym_offsetof] = ACTIONS(541),
    [anon_sym__Generic] = ACTIONS(544),
    [anon_sym_asm] = ACTIONS(547),
    [anon_sym___asm__] = ACTIONS(547),
    [sym_number_literal] = ACTIONS(550),
    [anon_sym_L_SQUOTE] = ACTIONS(553),
    [anon_sym_u_SQUOTE] = ACTIONS(553),
    [anon_sym_U_SQUOTE] = ACTIONS(553),
    [anon_sym_u8_SQUOTE] = ACTIONS(553),
    [anon_sym_SQUOTE] = ACTIONS(553),
    [anon_sym_L_DQUOTE] = ACTIONS(556),
    [anon_sym_u_DQUOTE] = ACTIONS(556),
    [anon_sym_U_DQUOTE] = ACTIONS(556),
    [anon_sym_u8_DQUOTE] = ACTIONS(556),
    [anon_sym_DQUOTE] = ACTIONS(556),
    [sym_true] = ACTIONS(559),
    [sym_false] = ACTIONS(559),
    [anon_sym_NULL] = ACTIONS(562),
    [anon_sym_nullptr] = ACTIONS(562),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(565),
    [anon_sym_decltype] = ACTIONS(568),
    [sym_virtual] = ACTIONS(433),
    [anon_sym_explicit] = ACTIONS(571),
    [anon_sym_typename] = ACTIONS(574),
    [anon_sym_template] = ACTIONS(728),
    [anon_sym_operator] = ACTIONS(580),
    [anon_sym_try] = ACTIONS(731),
    [anon_sym_delete] = ACTIONS(586),
    [anon_sym_throw] = ACTIONS(734),
    [anon_sym_namespace] = ACTIONS(737),
    [anon_sym_using] = ACTIONS(740),
    [anon_sym_static_assert] = ACTIONS(743),
    [anon_sym_concept] = ACTIONS(746),
    [anon_sym_co_return] = ACTIONS(749),
    [anon_sym_co_yield] = ACTIONS(752),
    [anon_sym_R_DQUOTE] = ACTIONS(610),
    [anon_sym_LR_DQUOTE] = ACTIONS(610),
    [anon_sym_uR_DQUOTE] = ACTIONS(610),
    [anon_sym_UR_DQUOTE] = ACTIONS(610),
    [anon_sym_u8R_DQUOTE] = ACTIONS(610),
    [anon_sym_co_await] = ACTIONS(613),
    [anon_sym_new] = ACTIONS(616),
    [anon_sym_requires] = ACTIONS(619),
    [sym_this] = ACTIONS(559),
    [anon_sym_discard] = ACTIONS(755),
    [anon_sym_precise] = ACTIONS(625),
    [anon_sym_shared] = ACTIONS(625),
    [anon_sym_groupshared] = ACTIONS(625),
    [anon_sym_uniform] = ACTIONS(625),
    [anon_sym_row_major] = ACTIONS(625),
    [anon_sym_column_major] = ACTIONS(625),
    [anon_sym_globallycoherent] = ACTIONS(625),
    [anon_sym_centroid] = ACTIONS(625),
    [anon_sym_noperspective] = ACTIONS(625),
    [anon_sym_nointerpolation] = ACTIONS(625),
    [anon_sym_sample] = ACTIONS(625),
    [anon_sym_linear] = ACTIONS(625),
    [anon_sym_snorm] = ACTIONS(625),
    [anon_sym_unorm] = ACTIONS(625),
    [anon_sym_point] = ACTIONS(625),
    [anon_sym_line] = ACTIONS(625),
    [anon_sym_triangleadj] = ACTIONS(625),
    [anon_sym_lineadj] = ACTIONS(625),
    [anon_sym_triangle] = ACTIONS(625),
    [anon_sym_cbuffer] = ACTIONS(758),
  },
  [43] = {
    [sym__block_item] = STATE(46),
    [sym_preproc_include] = STATE(46),
    [sym_preproc_def] = STATE(46),
    [sym_preproc_function_def] = STATE(46),
    [sym_preproc_call] = STATE(46),
    [sym_preproc_if] = STATE(46),
    [sym_preproc_ifdef] = STATE(46),
    [sym_function_definition] = STATE(46),
    [sym_declaration] = STATE(46),
    [sym_type_definition] = STATE(46),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(46),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(46),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(46),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(46),
    [sym_template_instantiation] = STATE(46),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(46),
    [sym_operator_cast_declaration] = STATE(46),
    [sym_constructor_or_destructor_definition] = STATE(46),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(46),
    [sym_namespace_alias_definition] = STATE(46),
    [sym_using_declaration] = STATE(46),
    [sym_alias_declaration] = STATE(46),
    [sym_static_assert_declaration] = STATE(46),
    [sym_concept_definition] = STATE(46),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(46),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(761),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [44] = {
    [sym__block_item] = STATE(42),
    [sym_preproc_include] = STATE(42),
    [sym_preproc_def] = STATE(42),
    [sym_preproc_function_def] = STATE(42),
    [sym_preproc_call] = STATE(42),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_ifdef] = STATE(42),
    [sym_function_definition] = STATE(42),
    [sym_declaration] = STATE(42),
    [sym_type_definition] = STATE(42),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(42),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(42),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(42),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(42),
    [sym_template_instantiation] = STATE(42),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(42),
    [sym_operator_cast_declaration] = STATE(42),
    [sym_constructor_or_destructor_definition] = STATE(42),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(42),
    [sym_namespace_alias_definition] = STATE(42),
    [sym_using_declaration] = STATE(42),
    [sym_alias_declaration] = STATE(42),
    [sym_static_assert_declaration] = STATE(42),
    [sym_concept_definition] = STATE(42),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(42),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(763),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [45] = {
    [sym__block_item] = STATE(42),
    [sym_preproc_include] = STATE(42),
    [sym_preproc_def] = STATE(42),
    [sym_preproc_function_def] = STATE(42),
    [sym_preproc_call] = STATE(42),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_ifdef] = STATE(42),
    [sym_function_definition] = STATE(42),
    [sym_declaration] = STATE(42),
    [sym_type_definition] = STATE(42),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(42),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(42),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(42),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(42),
    [sym_template_instantiation] = STATE(42),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(42),
    [sym_operator_cast_declaration] = STATE(42),
    [sym_constructor_or_destructor_definition] = STATE(42),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(42),
    [sym_namespace_alias_definition] = STATE(42),
    [sym_using_declaration] = STATE(42),
    [sym_alias_declaration] = STATE(42),
    [sym_static_assert_declaration] = STATE(42),
    [sym_concept_definition] = STATE(42),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(42),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(765),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [46] = {
    [sym__block_item] = STATE(42),
    [sym_preproc_include] = STATE(42),
    [sym_preproc_def] = STATE(42),
    [sym_preproc_function_def] = STATE(42),
    [sym_preproc_call] = STATE(42),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_ifdef] = STATE(42),
    [sym_function_definition] = STATE(42),
    [sym_declaration] = STATE(42),
    [sym_type_definition] = STATE(42),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(42),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(42),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(42),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(42),
    [sym_template_instantiation] = STATE(42),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(42),
    [sym_operator_cast_declaration] = STATE(42),
    [sym_constructor_or_destructor_definition] = STATE(42),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(42),
    [sym_namespace_alias_definition] = STATE(42),
    [sym_using_declaration] = STATE(42),
    [sym_alias_declaration] = STATE(42),
    [sym_static_assert_declaration] = STATE(42),
    [sym_concept_definition] = STATE(42),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(42),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(767),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [47] = {
    [sym__block_item] = STATE(42),
    [sym_preproc_include] = STATE(42),
    [sym_preproc_def] = STATE(42),
    [sym_preproc_function_def] = STATE(42),
    [sym_preproc_call] = STATE(42),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_ifdef] = STATE(42),
    [sym_function_definition] = STATE(42),
    [sym_declaration] = STATE(42),
    [sym_type_definition] = STATE(42),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(42),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(42),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(42),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(42),
    [sym_template_instantiation] = STATE(42),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(42),
    [sym_operator_cast_declaration] = STATE(42),
    [sym_constructor_or_destructor_definition] = STATE(42),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(42),
    [sym_namespace_alias_definition] = STATE(42),
    [sym_using_declaration] = STATE(42),
    [sym_alias_declaration] = STATE(42),
    [sym_static_assert_declaration] = STATE(42),
    [sym_concept_definition] = STATE(42),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(42),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(769),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [48] = {
    [sym__block_item] = STATE(79),
    [sym_preproc_include] = STATE(79),
    [sym_preproc_def] = STATE(79),
    [sym_preproc_function_def] = STATE(79),
    [sym_preproc_call] = STATE(79),
    [sym_preproc_if] = STATE(79),
    [sym_preproc_ifdef] = STATE(79),
    [sym_function_definition] = STATE(79),
    [sym_declaration] = STATE(79),
    [sym_type_definition] = STATE(79),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4694),
    [sym_linkage_specification] = STATE(79),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1965),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6159),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(468),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2254),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(548),
    [sym_statement] = STATE(79),
    [sym_labeled_statement] = STATE(468),
    [sym_expression_statement] = STATE(468),
    [sym_if_statement] = STATE(468),
    [sym_switch_statement] = STATE(468),
    [sym_case_statement] = STATE(468),
    [sym_while_statement] = STATE(468),
    [sym_do_statement] = STATE(468),
    [sym_for_statement] = STATE(468),
    [sym_return_statement] = STATE(468),
    [sym_break_statement] = STATE(468),
    [sym_continue_statement] = STATE(468),
    [sym_goto_statement] = STATE(468),
    [sym_seh_try_statement] = STATE(468),
    [sym_seh_leave_statement] = STATE(468),
    [sym_expression] = STATE(4453),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7849),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(79),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1828),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(79),
    [sym_template_instantiation] = STATE(79),
    [sym_operator_cast] = STATE(6668),
    [sym__constructor_specifiers] = STATE(1828),
    [sym_operator_cast_definition] = STATE(79),
    [sym_operator_cast_declaration] = STATE(79),
    [sym_constructor_or_destructor_definition] = STATE(79),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(79),
    [sym_namespace_alias_definition] = STATE(79),
    [sym_using_declaration] = STATE(79),
    [sym_alias_declaration] = STATE(79),
    [sym_static_assert_declaration] = STATE(79),
    [sym_concept_definition] = STATE(79),
    [sym_for_range_loop] = STATE(468),
    [sym_co_return_statement] = STATE(468),
    [sym_co_yield_statement] = STATE(468),
    [sym_throw_statement] = STATE(468),
    [sym_try_statement] = STATE(468),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6668),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(468),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(468),
    [sym_hlsl_attribute] = STATE(1220),
    [aux_sym_preproc_if_repeat1] = STATE(79),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(827),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(771),
    [aux_sym_preproc_include_token1] = ACTIONS(773),
    [aux_sym_preproc_def_token1] = ACTIONS(775),
    [aux_sym_preproc_if_token1] = ACTIONS(777),
    [aux_sym_preproc_if_token2] = ACTIONS(779),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(781),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(781),
    [sym_preproc_directive] = ACTIONS(783),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(785),
    [anon_sym___extension__] = ACTIONS(787),
    [anon_sym_typedef] = ACTIONS(789),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(791),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(793),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(795),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(797),
    [anon_sym_switch] = ACTIONS(799),
    [anon_sym_case] = ACTIONS(801),
    [anon_sym_default] = ACTIONS(803),
    [anon_sym_while] = ACTIONS(805),
    [anon_sym_do] = ACTIONS(807),
    [anon_sym_for] = ACTIONS(809),
    [anon_sym_return] = ACTIONS(811),
    [anon_sym_break] = ACTIONS(813),
    [anon_sym_continue] = ACTIONS(815),
    [anon_sym_goto] = ACTIONS(817),
    [anon_sym___try] = ACTIONS(819),
    [anon_sym___leave] = ACTIONS(821),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(823),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(825),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(827),
    [anon_sym_namespace] = ACTIONS(829),
    [anon_sym_using] = ACTIONS(831),
    [anon_sym_static_assert] = ACTIONS(833),
    [anon_sym_concept] = ACTIONS(835),
    [anon_sym_co_return] = ACTIONS(837),
    [anon_sym_co_yield] = ACTIONS(839),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(841),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(843),
  },
  [49] = {
    [sym__block_item] = STATE(50),
    [sym_preproc_include] = STATE(50),
    [sym_preproc_def] = STATE(50),
    [sym_preproc_function_def] = STATE(50),
    [sym_preproc_call] = STATE(50),
    [sym_preproc_if] = STATE(50),
    [sym_preproc_ifdef] = STATE(50),
    [sym_function_definition] = STATE(50),
    [sym_declaration] = STATE(50),
    [sym_type_definition] = STATE(50),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(50),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(50),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(50),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(50),
    [sym_template_instantiation] = STATE(50),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(50),
    [sym_operator_cast_declaration] = STATE(50),
    [sym_constructor_or_destructor_definition] = STATE(50),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(50),
    [sym_namespace_alias_definition] = STATE(50),
    [sym_using_declaration] = STATE(50),
    [sym_alias_declaration] = STATE(50),
    [sym_static_assert_declaration] = STATE(50),
    [sym_concept_definition] = STATE(50),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(50),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(845),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [50] = {
    [sym__block_item] = STATE(42),
    [sym_preproc_include] = STATE(42),
    [sym_preproc_def] = STATE(42),
    [sym_preproc_function_def] = STATE(42),
    [sym_preproc_call] = STATE(42),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_ifdef] = STATE(42),
    [sym_function_definition] = STATE(42),
    [sym_declaration] = STATE(42),
    [sym_type_definition] = STATE(42),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(42),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(42),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(42),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(42),
    [sym_template_instantiation] = STATE(42),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(42),
    [sym_operator_cast_declaration] = STATE(42),
    [sym_constructor_or_destructor_definition] = STATE(42),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(42),
    [sym_namespace_alias_definition] = STATE(42),
    [sym_using_declaration] = STATE(42),
    [sym_alias_declaration] = STATE(42),
    [sym_static_assert_declaration] = STATE(42),
    [sym_concept_definition] = STATE(42),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(42),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(847),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [51] = {
    [sym__block_item] = STATE(35),
    [sym_preproc_include] = STATE(35),
    [sym_preproc_def] = STATE(35),
    [sym_preproc_function_def] = STATE(35),
    [sym_preproc_call] = STATE(35),
    [sym_preproc_if] = STATE(35),
    [sym_preproc_ifdef] = STATE(35),
    [sym_function_definition] = STATE(35),
    [sym_declaration] = STATE(35),
    [sym_type_definition] = STATE(35),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(35),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(35),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(35),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(35),
    [sym_template_instantiation] = STATE(35),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(35),
    [sym_operator_cast_declaration] = STATE(35),
    [sym_constructor_or_destructor_definition] = STATE(35),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(35),
    [sym_namespace_alias_definition] = STATE(35),
    [sym_using_declaration] = STATE(35),
    [sym_alias_declaration] = STATE(35),
    [sym_static_assert_declaration] = STATE(35),
    [sym_concept_definition] = STATE(35),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(35),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(849),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [52] = {
    [sym__block_item] = STATE(58),
    [sym_preproc_include] = STATE(58),
    [sym_preproc_def] = STATE(58),
    [sym_preproc_function_def] = STATE(58),
    [sym_preproc_call] = STATE(58),
    [sym_preproc_if] = STATE(58),
    [sym_preproc_ifdef] = STATE(58),
    [sym_function_definition] = STATE(58),
    [sym_declaration] = STATE(58),
    [sym_type_definition] = STATE(58),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(58),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(58),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(58),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(58),
    [sym_template_instantiation] = STATE(58),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(58),
    [sym_operator_cast_declaration] = STATE(58),
    [sym_constructor_or_destructor_definition] = STATE(58),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(58),
    [sym_namespace_alias_definition] = STATE(58),
    [sym_using_declaration] = STATE(58),
    [sym_alias_declaration] = STATE(58),
    [sym_static_assert_declaration] = STATE(58),
    [sym_concept_definition] = STATE(58),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(58),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(851),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [53] = {
    [sym__block_item] = STATE(77),
    [sym_preproc_include] = STATE(77),
    [sym_preproc_def] = STATE(77),
    [sym_preproc_function_def] = STATE(77),
    [sym_preproc_call] = STATE(77),
    [sym_preproc_if] = STATE(77),
    [sym_preproc_ifdef] = STATE(77),
    [sym_function_definition] = STATE(77),
    [sym_declaration] = STATE(77),
    [sym_type_definition] = STATE(77),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(77),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(77),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(77),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(77),
    [sym_template_instantiation] = STATE(77),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(77),
    [sym_operator_cast_declaration] = STATE(77),
    [sym_constructor_or_destructor_definition] = STATE(77),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(77),
    [sym_namespace_alias_definition] = STATE(77),
    [sym_using_declaration] = STATE(77),
    [sym_alias_declaration] = STATE(77),
    [sym_static_assert_declaration] = STATE(77),
    [sym_concept_definition] = STATE(77),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(77),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(853),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [54] = {
    [sym__block_item] = STATE(61),
    [sym_preproc_include] = STATE(61),
    [sym_preproc_def] = STATE(61),
    [sym_preproc_function_def] = STATE(61),
    [sym_preproc_call] = STATE(61),
    [sym_preproc_if] = STATE(61),
    [sym_preproc_ifdef] = STATE(61),
    [sym_function_definition] = STATE(61),
    [sym_declaration] = STATE(61),
    [sym_type_definition] = STATE(61),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(61),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(61),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(61),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(61),
    [sym_template_instantiation] = STATE(61),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(61),
    [sym_operator_cast_declaration] = STATE(61),
    [sym_constructor_or_destructor_definition] = STATE(61),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(61),
    [sym_namespace_alias_definition] = STATE(61),
    [sym_using_declaration] = STATE(61),
    [sym_alias_declaration] = STATE(61),
    [sym_static_assert_declaration] = STATE(61),
    [sym_concept_definition] = STATE(61),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(61),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(855),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [55] = {
    [sym__block_item] = STATE(55),
    [sym_preproc_include] = STATE(55),
    [sym_preproc_def] = STATE(55),
    [sym_preproc_function_def] = STATE(55),
    [sym_preproc_call] = STATE(55),
    [sym_preproc_if] = STATE(55),
    [sym_preproc_ifdef] = STATE(55),
    [sym_function_definition] = STATE(55),
    [sym_declaration] = STATE(55),
    [sym_type_definition] = STATE(55),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4694),
    [sym_linkage_specification] = STATE(55),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1965),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6159),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(468),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2254),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(548),
    [sym_statement] = STATE(55),
    [sym_labeled_statement] = STATE(468),
    [sym_expression_statement] = STATE(468),
    [sym_if_statement] = STATE(468),
    [sym_switch_statement] = STATE(468),
    [sym_case_statement] = STATE(468),
    [sym_while_statement] = STATE(468),
    [sym_do_statement] = STATE(468),
    [sym_for_statement] = STATE(468),
    [sym_return_statement] = STATE(468),
    [sym_break_statement] = STATE(468),
    [sym_continue_statement] = STATE(468),
    [sym_goto_statement] = STATE(468),
    [sym_seh_try_statement] = STATE(468),
    [sym_seh_leave_statement] = STATE(468),
    [sym_expression] = STATE(4453),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7849),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(55),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1828),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(55),
    [sym_template_instantiation] = STATE(55),
    [sym_operator_cast] = STATE(6668),
    [sym__constructor_specifiers] = STATE(1828),
    [sym_operator_cast_definition] = STATE(55),
    [sym_operator_cast_declaration] = STATE(55),
    [sym_constructor_or_destructor_definition] = STATE(55),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(55),
    [sym_namespace_alias_definition] = STATE(55),
    [sym_using_declaration] = STATE(55),
    [sym_alias_declaration] = STATE(55),
    [sym_static_assert_declaration] = STATE(55),
    [sym_concept_definition] = STATE(55),
    [sym_for_range_loop] = STATE(468),
    [sym_co_return_statement] = STATE(468),
    [sym_co_yield_statement] = STATE(468),
    [sym_throw_statement] = STATE(468),
    [sym_try_statement] = STATE(468),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6668),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(468),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(468),
    [sym_hlsl_attribute] = STATE(1220),
    [aux_sym_preproc_if_repeat1] = STATE(55),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(827),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(857),
    [aux_sym_preproc_include_token1] = ACTIONS(860),
    [aux_sym_preproc_def_token1] = ACTIONS(863),
    [aux_sym_preproc_if_token1] = ACTIONS(866),
    [aux_sym_preproc_if_token2] = ACTIONS(395),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(869),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(869),
    [sym_preproc_directive] = ACTIONS(872),
    [anon_sym_LPAREN2] = ACTIONS(403),
    [anon_sym_BANG] = ACTIONS(406),
    [anon_sym_TILDE] = ACTIONS(409),
    [anon_sym_DASH] = ACTIONS(412),
    [anon_sym_PLUS] = ACTIONS(412),
    [anon_sym_STAR] = ACTIONS(415),
    [anon_sym_AMP_AMP] = ACTIONS(418),
    [anon_sym_AMP] = ACTIONS(421),
    [anon_sym_SEMI] = ACTIONS(875),
    [anon_sym___extension__] = ACTIONS(878),
    [anon_sym_typedef] = ACTIONS(881),
    [anon_sym_in] = ACTIONS(433),
    [anon_sym_out] = ACTIONS(433),
    [anon_sym_inout] = ACTIONS(433),
    [anon_sym_extern] = ACTIONS(884),
    [anon_sym___attribute__] = ACTIONS(439),
    [anon_sym_COLON_COLON] = ACTIONS(442),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(445),
    [anon_sym___declspec] = ACTIONS(448),
    [anon_sym___based] = ACTIONS(451),
    [anon_sym___cdecl] = ACTIONS(454),
    [anon_sym___clrcall] = ACTIONS(454),
    [anon_sym___stdcall] = ACTIONS(454),
    [anon_sym___fastcall] = ACTIONS(454),
    [anon_sym___thiscall] = ACTIONS(454),
    [anon_sym___vectorcall] = ACTIONS(454),
    [anon_sym_LBRACE] = ACTIONS(887),
    [anon_sym_signed] = ACTIONS(460),
    [anon_sym_unsigned] = ACTIONS(460),
    [anon_sym_long] = ACTIONS(460),
    [anon_sym_short] = ACTIONS(460),
    [anon_sym_LBRACK] = ACTIONS(463),
    [anon_sym_static] = ACTIONS(466),
    [anon_sym_register] = ACTIONS(466),
    [anon_sym_inline] = ACTIONS(890),
    [anon_sym___inline] = ACTIONS(466),
    [anon_sym___inline__] = ACTIONS(466),
    [anon_sym___forceinline] = ACTIONS(466),
    [anon_sym_thread_local] = ACTIONS(466),
    [anon_sym___thread] = ACTIONS(466),
    [anon_sym_const] = ACTIONS(472),
    [anon_sym_constexpr] = ACTIONS(472),
    [anon_sym_volatile] = ACTIONS(472),
    [anon_sym_restrict] = ACTIONS(472),
    [anon_sym___restrict__] = ACTIONS(472),
    [anon_sym__Atomic] = ACTIONS(472),
    [anon_sym__Noreturn] = ACTIONS(472),
    [anon_sym_noreturn] = ACTIONS(472),
    [anon_sym_mutable] = ACTIONS(472),
    [anon_sym_constinit] = ACTIONS(472),
    [anon_sym_consteval] = ACTIONS(472),
    [anon_sym_alignas] = ACTIONS(475),
    [anon_sym__Alignas] = ACTIONS(475),
    [sym_primitive_type] = ACTIONS(478),
    [anon_sym_enum] = ACTIONS(481),
    [anon_sym_class] = ACTIONS(484),
    [anon_sym_struct] = ACTIONS(487),
    [anon_sym_union] = ACTIONS(490),
    [anon_sym_if] = ACTIONS(893),
    [anon_sym_switch] = ACTIONS(896),
    [anon_sym_case] = ACTIONS(899),
    [anon_sym_default] = ACTIONS(902),
    [anon_sym_while] = ACTIONS(905),
    [anon_sym_do] = ACTIONS(908),
    [anon_sym_for] = ACTIONS(911),
    [anon_sym_return] = ACTIONS(914),
    [anon_sym_break] = ACTIONS(917),
    [anon_sym_continue] = ACTIONS(920),
    [anon_sym_goto] = ACTIONS(923),
    [anon_sym___try] = ACTIONS(926),
    [anon_sym___leave] = ACTIONS(929),
    [anon_sym_not] = ACTIONS(412),
    [anon_sym_compl] = ACTIONS(412),
    [anon_sym_DASH_DASH] = ACTIONS(532),
    [anon_sym_PLUS_PLUS] = ACTIONS(532),
    [anon_sym_sizeof] = ACTIONS(535),
    [anon_sym___alignof__] = ACTIONS(538),
    [anon_sym___alignof] = ACTIONS(538),
    [anon_sym__alignof] = ACTIONS(538),
    [anon_sym_alignof] = ACTIONS(538),
    [anon_sym__Alignof] = ACTIONS(538),
    [anon_sym_offsetof] = ACTIONS(541),
    [anon_sym__Generic] = ACTIONS(544),
    [anon_sym_asm] = ACTIONS(547),
    [anon_sym___asm__] = ACTIONS(547),
    [sym_number_literal] = ACTIONS(550),
    [anon_sym_L_SQUOTE] = ACTIONS(553),
    [anon_sym_u_SQUOTE] = ACTIONS(553),
    [anon_sym_U_SQUOTE] = ACTIONS(553),
    [anon_sym_u8_SQUOTE] = ACTIONS(553),
    [anon_sym_SQUOTE] = ACTIONS(553),
    [anon_sym_L_DQUOTE] = ACTIONS(556),
    [anon_sym_u_DQUOTE] = ACTIONS(556),
    [anon_sym_U_DQUOTE] = ACTIONS(556),
    [anon_sym_u8_DQUOTE] = ACTIONS(556),
    [anon_sym_DQUOTE] = ACTIONS(556),
    [sym_true] = ACTIONS(559),
    [sym_false] = ACTIONS(559),
    [anon_sym_NULL] = ACTIONS(562),
    [anon_sym_nullptr] = ACTIONS(562),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(565),
    [anon_sym_decltype] = ACTIONS(568),
    [sym_virtual] = ACTIONS(433),
    [anon_sym_explicit] = ACTIONS(571),
    [anon_sym_typename] = ACTIONS(574),
    [anon_sym_template] = ACTIONS(932),
    [anon_sym_operator] = ACTIONS(580),
    [anon_sym_try] = ACTIONS(935),
    [anon_sym_delete] = ACTIONS(586),
    [anon_sym_throw] = ACTIONS(938),
    [anon_sym_namespace] = ACTIONS(941),
    [anon_sym_using] = ACTIONS(944),
    [anon_sym_static_assert] = ACTIONS(947),
    [anon_sym_concept] = ACTIONS(950),
    [anon_sym_co_return] = ACTIONS(953),
    [anon_sym_co_yield] = ACTIONS(956),
    [anon_sym_R_DQUOTE] = ACTIONS(610),
    [anon_sym_LR_DQUOTE] = ACTIONS(610),
    [anon_sym_uR_DQUOTE] = ACTIONS(610),
    [anon_sym_UR_DQUOTE] = ACTIONS(610),
    [anon_sym_u8R_DQUOTE] = ACTIONS(610),
    [anon_sym_co_await] = ACTIONS(613),
    [anon_sym_new] = ACTIONS(616),
    [anon_sym_requires] = ACTIONS(619),
    [sym_this] = ACTIONS(559),
    [anon_sym_discard] = ACTIONS(959),
    [anon_sym_precise] = ACTIONS(625),
    [anon_sym_shared] = ACTIONS(625),
    [anon_sym_groupshared] = ACTIONS(625),
    [anon_sym_uniform] = ACTIONS(625),
    [anon_sym_row_major] = ACTIONS(625),
    [anon_sym_column_major] = ACTIONS(625),
    [anon_sym_globallycoherent] = ACTIONS(625),
    [anon_sym_centroid] = ACTIONS(625),
    [anon_sym_noperspective] = ACTIONS(625),
    [anon_sym_nointerpolation] = ACTIONS(625),
    [anon_sym_sample] = ACTIONS(625),
    [anon_sym_linear] = ACTIONS(625),
    [anon_sym_snorm] = ACTIONS(625),
    [anon_sym_unorm] = ACTIONS(625),
    [anon_sym_point] = ACTIONS(625),
    [anon_sym_line] = ACTIONS(625),
    [anon_sym_triangleadj] = ACTIONS(625),
    [anon_sym_lineadj] = ACTIONS(625),
    [anon_sym_triangle] = ACTIONS(625),
    [anon_sym_cbuffer] = ACTIONS(962),
  },
  [56] = {
    [sym__block_item] = STATE(42),
    [sym_preproc_include] = STATE(42),
    [sym_preproc_def] = STATE(42),
    [sym_preproc_function_def] = STATE(42),
    [sym_preproc_call] = STATE(42),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_ifdef] = STATE(42),
    [sym_function_definition] = STATE(42),
    [sym_declaration] = STATE(42),
    [sym_type_definition] = STATE(42),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(42),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(42),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(42),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(42),
    [sym_template_instantiation] = STATE(42),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(42),
    [sym_operator_cast_declaration] = STATE(42),
    [sym_constructor_or_destructor_definition] = STATE(42),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(42),
    [sym_namespace_alias_definition] = STATE(42),
    [sym_using_declaration] = STATE(42),
    [sym_alias_declaration] = STATE(42),
    [sym_static_assert_declaration] = STATE(42),
    [sym_concept_definition] = STATE(42),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(42),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(965),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [57] = {
    [sym__block_item] = STATE(56),
    [sym_preproc_include] = STATE(56),
    [sym_preproc_def] = STATE(56),
    [sym_preproc_function_def] = STATE(56),
    [sym_preproc_call] = STATE(56),
    [sym_preproc_if] = STATE(56),
    [sym_preproc_ifdef] = STATE(56),
    [sym_function_definition] = STATE(56),
    [sym_declaration] = STATE(56),
    [sym_type_definition] = STATE(56),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(56),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(56),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(56),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(56),
    [sym_template_instantiation] = STATE(56),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(56),
    [sym_operator_cast_declaration] = STATE(56),
    [sym_constructor_or_destructor_definition] = STATE(56),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(56),
    [sym_namespace_alias_definition] = STATE(56),
    [sym_using_declaration] = STATE(56),
    [sym_alias_declaration] = STATE(56),
    [sym_static_assert_declaration] = STATE(56),
    [sym_concept_definition] = STATE(56),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(56),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(967),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [58] = {
    [sym__block_item] = STATE(42),
    [sym_preproc_include] = STATE(42),
    [sym_preproc_def] = STATE(42),
    [sym_preproc_function_def] = STATE(42),
    [sym_preproc_call] = STATE(42),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_ifdef] = STATE(42),
    [sym_function_definition] = STATE(42),
    [sym_declaration] = STATE(42),
    [sym_type_definition] = STATE(42),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(42),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(42),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(42),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(42),
    [sym_template_instantiation] = STATE(42),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(42),
    [sym_operator_cast_declaration] = STATE(42),
    [sym_constructor_or_destructor_definition] = STATE(42),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(42),
    [sym_namespace_alias_definition] = STATE(42),
    [sym_using_declaration] = STATE(42),
    [sym_alias_declaration] = STATE(42),
    [sym_static_assert_declaration] = STATE(42),
    [sym_concept_definition] = STATE(42),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(42),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(969),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [59] = {
    [sym__block_item] = STATE(62),
    [sym_preproc_include] = STATE(62),
    [sym_preproc_def] = STATE(62),
    [sym_preproc_function_def] = STATE(62),
    [sym_preproc_call] = STATE(62),
    [sym_preproc_if] = STATE(62),
    [sym_preproc_ifdef] = STATE(62),
    [sym_function_definition] = STATE(62),
    [sym_declaration] = STATE(62),
    [sym_type_definition] = STATE(62),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(62),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(62),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(62),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(62),
    [sym_template_instantiation] = STATE(62),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(62),
    [sym_operator_cast_declaration] = STATE(62),
    [sym_constructor_or_destructor_definition] = STATE(62),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(62),
    [sym_namespace_alias_definition] = STATE(62),
    [sym_using_declaration] = STATE(62),
    [sym_alias_declaration] = STATE(62),
    [sym_static_assert_declaration] = STATE(62),
    [sym_concept_definition] = STATE(62),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(62),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(971),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [60] = {
    [sym__block_item] = STATE(78),
    [sym_preproc_include] = STATE(78),
    [sym_preproc_def] = STATE(78),
    [sym_preproc_function_def] = STATE(78),
    [sym_preproc_call] = STATE(78),
    [sym_preproc_if] = STATE(78),
    [sym_preproc_ifdef] = STATE(78),
    [sym_function_definition] = STATE(78),
    [sym_declaration] = STATE(78),
    [sym_type_definition] = STATE(78),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(78),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(78),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(78),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(78),
    [sym_template_instantiation] = STATE(78),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(78),
    [sym_operator_cast_declaration] = STATE(78),
    [sym_constructor_or_destructor_definition] = STATE(78),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(78),
    [sym_namespace_alias_definition] = STATE(78),
    [sym_using_declaration] = STATE(78),
    [sym_alias_declaration] = STATE(78),
    [sym_static_assert_declaration] = STATE(78),
    [sym_concept_definition] = STATE(78),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(78),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(973),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [61] = {
    [sym__block_item] = STATE(42),
    [sym_preproc_include] = STATE(42),
    [sym_preproc_def] = STATE(42),
    [sym_preproc_function_def] = STATE(42),
    [sym_preproc_call] = STATE(42),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_ifdef] = STATE(42),
    [sym_function_definition] = STATE(42),
    [sym_declaration] = STATE(42),
    [sym_type_definition] = STATE(42),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(42),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(42),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(42),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(42),
    [sym_template_instantiation] = STATE(42),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(42),
    [sym_operator_cast_declaration] = STATE(42),
    [sym_constructor_or_destructor_definition] = STATE(42),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(42),
    [sym_namespace_alias_definition] = STATE(42),
    [sym_using_declaration] = STATE(42),
    [sym_alias_declaration] = STATE(42),
    [sym_static_assert_declaration] = STATE(42),
    [sym_concept_definition] = STATE(42),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(42),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(975),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [62] = {
    [sym__block_item] = STATE(42),
    [sym_preproc_include] = STATE(42),
    [sym_preproc_def] = STATE(42),
    [sym_preproc_function_def] = STATE(42),
    [sym_preproc_call] = STATE(42),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_ifdef] = STATE(42),
    [sym_function_definition] = STATE(42),
    [sym_declaration] = STATE(42),
    [sym_type_definition] = STATE(42),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(42),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(42),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(42),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(42),
    [sym_template_instantiation] = STATE(42),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(42),
    [sym_operator_cast_declaration] = STATE(42),
    [sym_constructor_or_destructor_definition] = STATE(42),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(42),
    [sym_namespace_alias_definition] = STATE(42),
    [sym_using_declaration] = STATE(42),
    [sym_alias_declaration] = STATE(42),
    [sym_static_assert_declaration] = STATE(42),
    [sym_concept_definition] = STATE(42),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(42),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(977),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [63] = {
    [sym__block_item] = STATE(42),
    [sym_preproc_include] = STATE(42),
    [sym_preproc_def] = STATE(42),
    [sym_preproc_function_def] = STATE(42),
    [sym_preproc_call] = STATE(42),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_ifdef] = STATE(42),
    [sym_function_definition] = STATE(42),
    [sym_declaration] = STATE(42),
    [sym_type_definition] = STATE(42),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(42),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(42),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(42),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(42),
    [sym_template_instantiation] = STATE(42),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(42),
    [sym_operator_cast_declaration] = STATE(42),
    [sym_constructor_or_destructor_definition] = STATE(42),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(42),
    [sym_namespace_alias_definition] = STATE(42),
    [sym_using_declaration] = STATE(42),
    [sym_alias_declaration] = STATE(42),
    [sym_static_assert_declaration] = STATE(42),
    [sym_concept_definition] = STATE(42),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(42),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(979),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [64] = {
    [sym__block_item] = STATE(63),
    [sym_preproc_include] = STATE(63),
    [sym_preproc_def] = STATE(63),
    [sym_preproc_function_def] = STATE(63),
    [sym_preproc_call] = STATE(63),
    [sym_preproc_if] = STATE(63),
    [sym_preproc_ifdef] = STATE(63),
    [sym_function_definition] = STATE(63),
    [sym_declaration] = STATE(63),
    [sym_type_definition] = STATE(63),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(63),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(63),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(63),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(63),
    [sym_template_instantiation] = STATE(63),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(63),
    [sym_operator_cast_declaration] = STATE(63),
    [sym_constructor_or_destructor_definition] = STATE(63),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(63),
    [sym_namespace_alias_definition] = STATE(63),
    [sym_using_declaration] = STATE(63),
    [sym_alias_declaration] = STATE(63),
    [sym_static_assert_declaration] = STATE(63),
    [sym_concept_definition] = STATE(63),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(63),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(981),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [65] = {
    [sym__block_item] = STATE(75),
    [sym_preproc_include] = STATE(75),
    [sym_preproc_def] = STATE(75),
    [sym_preproc_function_def] = STATE(75),
    [sym_preproc_call] = STATE(75),
    [sym_preproc_if] = STATE(75),
    [sym_preproc_ifdef] = STATE(75),
    [sym_function_definition] = STATE(75),
    [sym_declaration] = STATE(75),
    [sym_type_definition] = STATE(75),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(75),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(75),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(75),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(75),
    [sym_template_instantiation] = STATE(75),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(75),
    [sym_operator_cast_declaration] = STATE(75),
    [sym_constructor_or_destructor_definition] = STATE(75),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(75),
    [sym_namespace_alias_definition] = STATE(75),
    [sym_using_declaration] = STATE(75),
    [sym_alias_declaration] = STATE(75),
    [sym_static_assert_declaration] = STATE(75),
    [sym_concept_definition] = STATE(75),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(75),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(983),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [66] = {
    [sym__block_item] = STATE(42),
    [sym_preproc_include] = STATE(42),
    [sym_preproc_def] = STATE(42),
    [sym_preproc_function_def] = STATE(42),
    [sym_preproc_call] = STATE(42),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_ifdef] = STATE(42),
    [sym_function_definition] = STATE(42),
    [sym_declaration] = STATE(42),
    [sym_type_definition] = STATE(42),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(42),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(42),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(42),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(42),
    [sym_template_instantiation] = STATE(42),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(42),
    [sym_operator_cast_declaration] = STATE(42),
    [sym_constructor_or_destructor_definition] = STATE(42),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(42),
    [sym_namespace_alias_definition] = STATE(42),
    [sym_using_declaration] = STATE(42),
    [sym_alias_declaration] = STATE(42),
    [sym_static_assert_declaration] = STATE(42),
    [sym_concept_definition] = STATE(42),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(42),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(985),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [67] = {
    [sym__block_item] = STATE(69),
    [sym_preproc_include] = STATE(69),
    [sym_preproc_def] = STATE(69),
    [sym_preproc_function_def] = STATE(69),
    [sym_preproc_call] = STATE(69),
    [sym_preproc_if] = STATE(69),
    [sym_preproc_ifdef] = STATE(69),
    [sym_function_definition] = STATE(69),
    [sym_declaration] = STATE(69),
    [sym_type_definition] = STATE(69),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(69),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(69),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(69),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(69),
    [sym_template_instantiation] = STATE(69),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(69),
    [sym_operator_cast_declaration] = STATE(69),
    [sym_constructor_or_destructor_definition] = STATE(69),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(69),
    [sym_namespace_alias_definition] = STATE(69),
    [sym_using_declaration] = STATE(69),
    [sym_alias_declaration] = STATE(69),
    [sym_static_assert_declaration] = STATE(69),
    [sym_concept_definition] = STATE(69),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(69),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(987),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [68] = {
    [sym__block_item] = STATE(42),
    [sym_preproc_include] = STATE(42),
    [sym_preproc_def] = STATE(42),
    [sym_preproc_function_def] = STATE(42),
    [sym_preproc_call] = STATE(42),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_ifdef] = STATE(42),
    [sym_function_definition] = STATE(42),
    [sym_declaration] = STATE(42),
    [sym_type_definition] = STATE(42),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(42),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(42),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(42),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(42),
    [sym_template_instantiation] = STATE(42),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(42),
    [sym_operator_cast_declaration] = STATE(42),
    [sym_constructor_or_destructor_definition] = STATE(42),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(42),
    [sym_namespace_alias_definition] = STATE(42),
    [sym_using_declaration] = STATE(42),
    [sym_alias_declaration] = STATE(42),
    [sym_static_assert_declaration] = STATE(42),
    [sym_concept_definition] = STATE(42),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(42),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(989),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [69] = {
    [sym__block_item] = STATE(42),
    [sym_preproc_include] = STATE(42),
    [sym_preproc_def] = STATE(42),
    [sym_preproc_function_def] = STATE(42),
    [sym_preproc_call] = STATE(42),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_ifdef] = STATE(42),
    [sym_function_definition] = STATE(42),
    [sym_declaration] = STATE(42),
    [sym_type_definition] = STATE(42),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(42),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(42),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(42),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(42),
    [sym_template_instantiation] = STATE(42),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(42),
    [sym_operator_cast_declaration] = STATE(42),
    [sym_constructor_or_destructor_definition] = STATE(42),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(42),
    [sym_namespace_alias_definition] = STATE(42),
    [sym_using_declaration] = STATE(42),
    [sym_alias_declaration] = STATE(42),
    [sym_static_assert_declaration] = STATE(42),
    [sym_concept_definition] = STATE(42),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(42),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(991),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [70] = {
    [sym__block_item] = STATE(47),
    [sym_preproc_include] = STATE(47),
    [sym_preproc_def] = STATE(47),
    [sym_preproc_function_def] = STATE(47),
    [sym_preproc_call] = STATE(47),
    [sym_preproc_if] = STATE(47),
    [sym_preproc_ifdef] = STATE(47),
    [sym_function_definition] = STATE(47),
    [sym_declaration] = STATE(47),
    [sym_type_definition] = STATE(47),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(47),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(47),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(47),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(47),
    [sym_template_instantiation] = STATE(47),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(47),
    [sym_operator_cast_declaration] = STATE(47),
    [sym_constructor_or_destructor_definition] = STATE(47),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(47),
    [sym_namespace_alias_definition] = STATE(47),
    [sym_using_declaration] = STATE(47),
    [sym_alias_declaration] = STATE(47),
    [sym_static_assert_declaration] = STATE(47),
    [sym_concept_definition] = STATE(47),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(47),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(993),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [71] = {
    [sym__block_item] = STATE(72),
    [sym_preproc_include] = STATE(72),
    [sym_preproc_def] = STATE(72),
    [sym_preproc_function_def] = STATE(72),
    [sym_preproc_call] = STATE(72),
    [sym_preproc_if] = STATE(72),
    [sym_preproc_ifdef] = STATE(72),
    [sym_function_definition] = STATE(72),
    [sym_declaration] = STATE(72),
    [sym_type_definition] = STATE(72),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(72),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(72),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(72),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(72),
    [sym_template_instantiation] = STATE(72),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(72),
    [sym_operator_cast_declaration] = STATE(72),
    [sym_constructor_or_destructor_definition] = STATE(72),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(72),
    [sym_namespace_alias_definition] = STATE(72),
    [sym_using_declaration] = STATE(72),
    [sym_alias_declaration] = STATE(72),
    [sym_static_assert_declaration] = STATE(72),
    [sym_concept_definition] = STATE(72),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(72),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(995),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [72] = {
    [sym__block_item] = STATE(42),
    [sym_preproc_include] = STATE(42),
    [sym_preproc_def] = STATE(42),
    [sym_preproc_function_def] = STATE(42),
    [sym_preproc_call] = STATE(42),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_ifdef] = STATE(42),
    [sym_function_definition] = STATE(42),
    [sym_declaration] = STATE(42),
    [sym_type_definition] = STATE(42),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(42),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(42),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(42),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(42),
    [sym_template_instantiation] = STATE(42),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(42),
    [sym_operator_cast_declaration] = STATE(42),
    [sym_constructor_or_destructor_definition] = STATE(42),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(42),
    [sym_namespace_alias_definition] = STATE(42),
    [sym_using_declaration] = STATE(42),
    [sym_alias_declaration] = STATE(42),
    [sym_static_assert_declaration] = STATE(42),
    [sym_concept_definition] = STATE(42),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(42),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(997),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [73] = {
    [sym__block_item] = STATE(66),
    [sym_preproc_include] = STATE(66),
    [sym_preproc_def] = STATE(66),
    [sym_preproc_function_def] = STATE(66),
    [sym_preproc_call] = STATE(66),
    [sym_preproc_if] = STATE(66),
    [sym_preproc_ifdef] = STATE(66),
    [sym_function_definition] = STATE(66),
    [sym_declaration] = STATE(66),
    [sym_type_definition] = STATE(66),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(66),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(66),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(66),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(66),
    [sym_template_instantiation] = STATE(66),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(66),
    [sym_operator_cast_declaration] = STATE(66),
    [sym_constructor_or_destructor_definition] = STATE(66),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(66),
    [sym_namespace_alias_definition] = STATE(66),
    [sym_using_declaration] = STATE(66),
    [sym_alias_declaration] = STATE(66),
    [sym_static_assert_declaration] = STATE(66),
    [sym_concept_definition] = STATE(66),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(66),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(999),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [74] = {
    [sym__block_item] = STATE(76),
    [sym_preproc_include] = STATE(76),
    [sym_preproc_def] = STATE(76),
    [sym_preproc_function_def] = STATE(76),
    [sym_preproc_call] = STATE(76),
    [sym_preproc_if] = STATE(76),
    [sym_preproc_ifdef] = STATE(76),
    [sym_function_definition] = STATE(76),
    [sym_declaration] = STATE(76),
    [sym_type_definition] = STATE(76),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(76),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(76),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(76),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(76),
    [sym_template_instantiation] = STATE(76),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(76),
    [sym_operator_cast_declaration] = STATE(76),
    [sym_constructor_or_destructor_definition] = STATE(76),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(76),
    [sym_namespace_alias_definition] = STATE(76),
    [sym_using_declaration] = STATE(76),
    [sym_alias_declaration] = STATE(76),
    [sym_static_assert_declaration] = STATE(76),
    [sym_concept_definition] = STATE(76),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(76),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(1001),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [75] = {
    [sym__block_item] = STATE(42),
    [sym_preproc_include] = STATE(42),
    [sym_preproc_def] = STATE(42),
    [sym_preproc_function_def] = STATE(42),
    [sym_preproc_call] = STATE(42),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_ifdef] = STATE(42),
    [sym_function_definition] = STATE(42),
    [sym_declaration] = STATE(42),
    [sym_type_definition] = STATE(42),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(42),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(42),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(42),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(42),
    [sym_template_instantiation] = STATE(42),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(42),
    [sym_operator_cast_declaration] = STATE(42),
    [sym_constructor_or_destructor_definition] = STATE(42),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(42),
    [sym_namespace_alias_definition] = STATE(42),
    [sym_using_declaration] = STATE(42),
    [sym_alias_declaration] = STATE(42),
    [sym_static_assert_declaration] = STATE(42),
    [sym_concept_definition] = STATE(42),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(42),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(1003),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [76] = {
    [sym__block_item] = STATE(42),
    [sym_preproc_include] = STATE(42),
    [sym_preproc_def] = STATE(42),
    [sym_preproc_function_def] = STATE(42),
    [sym_preproc_call] = STATE(42),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_ifdef] = STATE(42),
    [sym_function_definition] = STATE(42),
    [sym_declaration] = STATE(42),
    [sym_type_definition] = STATE(42),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(42),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(42),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(42),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(42),
    [sym_template_instantiation] = STATE(42),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(42),
    [sym_operator_cast_declaration] = STATE(42),
    [sym_constructor_or_destructor_definition] = STATE(42),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(42),
    [sym_namespace_alias_definition] = STATE(42),
    [sym_using_declaration] = STATE(42),
    [sym_alias_declaration] = STATE(42),
    [sym_static_assert_declaration] = STATE(42),
    [sym_concept_definition] = STATE(42),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(42),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(1005),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [77] = {
    [sym__block_item] = STATE(42),
    [sym_preproc_include] = STATE(42),
    [sym_preproc_def] = STATE(42),
    [sym_preproc_function_def] = STATE(42),
    [sym_preproc_call] = STATE(42),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_ifdef] = STATE(42),
    [sym_function_definition] = STATE(42),
    [sym_declaration] = STATE(42),
    [sym_type_definition] = STATE(42),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(42),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(42),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(42),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(42),
    [sym_template_instantiation] = STATE(42),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(42),
    [sym_operator_cast_declaration] = STATE(42),
    [sym_constructor_or_destructor_definition] = STATE(42),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(42),
    [sym_namespace_alias_definition] = STATE(42),
    [sym_using_declaration] = STATE(42),
    [sym_alias_declaration] = STATE(42),
    [sym_static_assert_declaration] = STATE(42),
    [sym_concept_definition] = STATE(42),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(42),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(1007),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [78] = {
    [sym__block_item] = STATE(42),
    [sym_preproc_include] = STATE(42),
    [sym_preproc_def] = STATE(42),
    [sym_preproc_function_def] = STATE(42),
    [sym_preproc_call] = STATE(42),
    [sym_preproc_if] = STATE(42),
    [sym_preproc_ifdef] = STATE(42),
    [sym_function_definition] = STATE(42),
    [sym_declaration] = STATE(42),
    [sym_type_definition] = STATE(42),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_linkage_specification] = STATE(42),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6173),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(484),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(599),
    [sym_statement] = STATE(42),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(42),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1824),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(42),
    [sym_template_instantiation] = STATE(42),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1824),
    [sym_operator_cast_definition] = STATE(42),
    [sym_operator_cast_declaration] = STATE(42),
    [sym_constructor_or_destructor_definition] = STATE(42),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(42),
    [sym_namespace_alias_definition] = STATE(42),
    [sym_using_declaration] = STATE(42),
    [sym_alias_declaration] = STATE(42),
    [sym_static_assert_declaration] = STATE(42),
    [sym_concept_definition] = STATE(42),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(1203),
    [aux_sym_preproc_if_repeat1] = STATE(42),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1824),
    [sym_identifier] = ACTIONS(631),
    [aux_sym_preproc_include_token1] = ACTIONS(163),
    [aux_sym_preproc_def_token1] = ACTIONS(165),
    [aux_sym_preproc_if_token1] = ACTIONS(169),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(171),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(171),
    [sym_preproc_directive] = ACTIONS(173),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(181),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(1009),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(189),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(223),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(229),
    [anon_sym_using] = ACTIONS(231),
    [anon_sym_static_assert] = ACTIONS(233),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [79] = {
    [sym__block_item] = STATE(55),
    [sym_preproc_include] = STATE(55),
    [sym_preproc_def] = STATE(55),
    [sym_preproc_function_def] = STATE(55),
    [sym_preproc_call] = STATE(55),
    [sym_preproc_if] = STATE(55),
    [sym_preproc_ifdef] = STATE(55),
    [sym_function_definition] = STATE(55),
    [sym_declaration] = STATE(55),
    [sym_type_definition] = STATE(55),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4694),
    [sym_linkage_specification] = STATE(55),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1965),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6159),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(468),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2254),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(548),
    [sym_statement] = STATE(55),
    [sym_labeled_statement] = STATE(468),
    [sym_expression_statement] = STATE(468),
    [sym_if_statement] = STATE(468),
    [sym_switch_statement] = STATE(468),
    [sym_case_statement] = STATE(468),
    [sym_while_statement] = STATE(468),
    [sym_do_statement] = STATE(468),
    [sym_for_statement] = STATE(468),
    [sym_return_statement] = STATE(468),
    [sym_break_statement] = STATE(468),
    [sym_continue_statement] = STATE(468),
    [sym_goto_statement] = STATE(468),
    [sym_seh_try_statement] = STATE(468),
    [sym_seh_leave_statement] = STATE(468),
    [sym_expression] = STATE(4453),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7849),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym__empty_declaration] = STATE(55),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1828),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(55),
    [sym_template_instantiation] = STATE(55),
    [sym_operator_cast] = STATE(6668),
    [sym__constructor_specifiers] = STATE(1828),
    [sym_operator_cast_definition] = STATE(55),
    [sym_operator_cast_declaration] = STATE(55),
    [sym_constructor_or_destructor_definition] = STATE(55),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4499),
    [sym_namespace_definition] = STATE(55),
    [sym_namespace_alias_definition] = STATE(55),
    [sym_using_declaration] = STATE(55),
    [sym_alias_declaration] = STATE(55),
    [sym_static_assert_declaration] = STATE(55),
    [sym_concept_definition] = STATE(55),
    [sym_for_range_loop] = STATE(468),
    [sym_co_return_statement] = STATE(468),
    [sym_co_yield_statement] = STATE(468),
    [sym_throw_statement] = STATE(468),
    [sym_try_statement] = STATE(468),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3355),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6668),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(468),
    [sym_qualifiers] = STATE(2369),
    [sym_cbuffer_specifier] = STATE(468),
    [sym_hlsl_attribute] = STATE(1220),
    [aux_sym_preproc_if_repeat1] = STATE(55),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(827),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1828),
    [sym_identifier] = ACTIONS(771),
    [aux_sym_preproc_include_token1] = ACTIONS(773),
    [aux_sym_preproc_def_token1] = ACTIONS(775),
    [aux_sym_preproc_if_token1] = ACTIONS(777),
    [aux_sym_preproc_if_token2] = ACTIONS(1011),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(781),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(781),
    [sym_preproc_directive] = ACTIONS(783),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_SEMI] = ACTIONS(785),
    [anon_sym___extension__] = ACTIONS(787),
    [anon_sym_typedef] = ACTIONS(789),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(791),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(793),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(795),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(797),
    [anon_sym_switch] = ACTIONS(799),
    [anon_sym_case] = ACTIONS(801),
    [anon_sym_default] = ACTIONS(803),
    [anon_sym_while] = ACTIONS(805),
    [anon_sym_do] = ACTIONS(807),
    [anon_sym_for] = ACTIONS(809),
    [anon_sym_return] = ACTIONS(811),
    [anon_sym_break] = ACTIONS(813),
    [anon_sym_continue] = ACTIONS(815),
    [anon_sym_goto] = ACTIONS(817),
    [anon_sym___try] = ACTIONS(819),
    [anon_sym___leave] = ACTIONS(821),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(823),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(825),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(827),
    [anon_sym_namespace] = ACTIONS(829),
    [anon_sym_using] = ACTIONS(831),
    [anon_sym_static_assert] = ACTIONS(833),
    [anon_sym_concept] = ACTIONS(835),
    [anon_sym_co_return] = ACTIONS(837),
    [anon_sym_co_yield] = ACTIONS(839),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(841),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(843),
  },
  [80] = {
    [sym__top_level_item] = STATE(81),
    [sym_preproc_include] = STATE(81),
    [sym_preproc_def] = STATE(81),
    [sym_preproc_function_def] = STATE(81),
    [sym_preproc_call] = STATE(81),
    [sym_preproc_if] = STATE(81),
    [sym_preproc_ifdef] = STATE(81),
    [sym_function_definition] = STATE(81),
    [sym_declaration] = STATE(81),
    [sym_type_definition] = STATE(81),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4633),
    [sym_linkage_specification] = STATE(81),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1945),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6115),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(81),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2257),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(757),
    [sym__top_level_statement] = STATE(81),
    [sym_labeled_statement] = STATE(81),
    [sym__top_level_expression_statement] = STATE(81),
    [sym_if_statement] = STATE(81),
    [sym_switch_statement] = STATE(81),
    [sym_case_statement] = STATE(81),
    [sym_while_statement] = STATE(81),
    [sym_do_statement] = STATE(81),
    [sym_for_statement] = STATE(81),
    [sym_return_statement] = STATE(81),
    [sym_break_statement] = STATE(81),
    [sym_continue_statement] = STATE(81),
    [sym_goto_statement] = STATE(81),
    [sym_expression] = STATE(4779),
    [sym__string] = STATE(4846),
    [sym_conditional_expression] = STATE(4846),
    [sym_assignment_expression] = STATE(4846),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4846),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4846),
    [sym_cast_expression] = STATE(4846),
    [sym_sizeof_expression] = STATE(4846),
    [sym_alignof_expression] = STATE(4846),
    [sym_offsetof_expression] = STATE(4846),
    [sym_generic_expression] = STATE(4846),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4846),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4846),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4791),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4846),
    [sym__empty_declaration] = STATE(81),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1833),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(81),
    [sym_template_instantiation] = STATE(81),
    [sym_operator_cast] = STATE(6631),
    [sym__constructor_specifiers] = STATE(1833),
    [sym_operator_cast_definition] = STATE(81),
    [sym_operator_cast_declaration] = STATE(81),
    [sym_constructor_or_destructor_definition] = STATE(81),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4778),
    [sym_namespace_definition] = STATE(81),
    [sym_namespace_alias_definition] = STATE(81),
    [sym_using_declaration] = STATE(81),
    [sym_alias_declaration] = STATE(81),
    [sym_static_assert_declaration] = STATE(81),
    [sym_concept_definition] = STATE(81),
    [sym_for_range_loop] = STATE(81),
    [sym_co_return_statement] = STATE(81),
    [sym_co_yield_statement] = STATE(81),
    [sym_throw_statement] = STATE(81),
    [sym_try_statement] = STATE(81),
    [sym_raw_string_literal] = STATE(3861),
    [sym_co_await_expression] = STATE(4846),
    [sym_new_expression] = STATE(4846),
    [sym_delete_expression] = STATE(4846),
    [sym_requires_clause] = STATE(4846),
    [sym_requires_expression] = STATE(4846),
    [sym_lambda_expression] = STATE(4846),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4846),
    [sym_parameter_pack_expansion] = STATE(4846),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6631),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3824),
    [sym_qualifiers] = STATE(2369),
    [sym_hlsl_attribute] = STATE(1206),
    [aux_sym_translation_unit_repeat1] = STATE(81),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(840),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1833),
    [ts_builtin_sym_end] = ACTIONS(1013),
    [sym_identifier] = ACTIONS(7),
    [aux_sym_preproc_include_token1] = ACTIONS(9),
    [aux_sym_preproc_def_token1] = ACTIONS(11),
    [aux_sym_preproc_if_token1] = ACTIONS(13),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(15),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(15),
    [sym_preproc_directive] = ACTIONS(17),
    [anon_sym_LPAREN2] = ACTIONS(19),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym___extension__] = ACTIONS(33),
    [anon_sym_typedef] = ACTIONS(35),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(39),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(45),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(57),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(61),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(81),
    [anon_sym_default] = ACTIONS(83),
    [anon_sym_while] = ACTIONS(85),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(111),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(117),
    [sym_false] = ACTIONS(117),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(129),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_namespace] = ACTIONS(139),
    [anon_sym_using] = ACTIONS(141),
    [anon_sym_static_assert] = ACTIONS(143),
    [anon_sym_concept] = ACTIONS(145),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(117),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [81] = {
    [sym__top_level_item] = STATE(81),
    [sym_preproc_include] = STATE(81),
    [sym_preproc_def] = STATE(81),
    [sym_preproc_function_def] = STATE(81),
    [sym_preproc_call] = STATE(81),
    [sym_preproc_if] = STATE(81),
    [sym_preproc_ifdef] = STATE(81),
    [sym_function_definition] = STATE(81),
    [sym_declaration] = STATE(81),
    [sym_type_definition] = STATE(81),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4633),
    [sym_linkage_specification] = STATE(81),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(946),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1945),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6115),
    [sym_array_declarator] = STATE(6270),
    [sym_compound_statement] = STATE(81),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2257),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(757),
    [sym__top_level_statement] = STATE(81),
    [sym_labeled_statement] = STATE(81),
    [sym__top_level_expression_statement] = STATE(81),
    [sym_if_statement] = STATE(81),
    [sym_switch_statement] = STATE(81),
    [sym_case_statement] = STATE(81),
    [sym_while_statement] = STATE(81),
    [sym_do_statement] = STATE(81),
    [sym_for_statement] = STATE(81),
    [sym_return_statement] = STATE(81),
    [sym_break_statement] = STATE(81),
    [sym_continue_statement] = STATE(81),
    [sym_goto_statement] = STATE(81),
    [sym_expression] = STATE(4779),
    [sym__string] = STATE(4846),
    [sym_conditional_expression] = STATE(4846),
    [sym_assignment_expression] = STATE(4846),
    [sym_pointer_expression] = STATE(3824),
    [sym_unary_expression] = STATE(4846),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4846),
    [sym_cast_expression] = STATE(4846),
    [sym_sizeof_expression] = STATE(4846),
    [sym_alignof_expression] = STATE(4846),
    [sym_offsetof_expression] = STATE(4846),
    [sym_generic_expression] = STATE(4846),
    [sym_subscript_expression] = STATE(3824),
    [sym_call_expression] = STATE(3824),
    [sym_gnu_asm_expression] = STATE(4846),
    [sym_field_expression] = STATE(3824),
    [sym_compound_literal_expression] = STATE(4846),
    [sym_parenthesized_expression] = STATE(3824),
    [sym_char_literal] = STATE(4791),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4846),
    [sym__empty_declaration] = STATE(81),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_explicit_function_specifier] = STATE(1833),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(81),
    [sym_template_instantiation] = STATE(81),
    [sym_operator_cast] = STATE(6631),
    [sym__constructor_specifiers] = STATE(1833),
    [sym_operator_cast_definition] = STATE(81),
    [sym_operator_cast_declaration] = STATE(81),
    [sym_constructor_or_destructor_definition] = STATE(81),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4778),
    [sym_namespace_definition] = STATE(81),
    [sym_namespace_alias_definition] = STATE(81),
    [sym_using_declaration] = STATE(81),
    [sym_alias_declaration] = STATE(81),
    [sym_static_assert_declaration] = STATE(81),
    [sym_concept_definition] = STATE(81),
    [sym_for_range_loop] = STATE(81),
    [sym_co_return_statement] = STATE(81),
    [sym_co_yield_statement] = STATE(81),
    [sym_throw_statement] = STATE(81),
    [sym_try_statement] = STATE(81),
    [sym_raw_string_literal] = STATE(3861),
    [sym_co_await_expression] = STATE(4846),
    [sym_new_expression] = STATE(4846),
    [sym_delete_expression] = STATE(4846),
    [sym_requires_clause] = STATE(4846),
    [sym_requires_expression] = STATE(4846),
    [sym_lambda_expression] = STATE(4846),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4846),
    [sym_parameter_pack_expansion] = STATE(4846),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5413),
    [sym_qualified_identifier] = STATE(3694),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_qualified_operator_cast_identifier] = STATE(6631),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3824),
    [sym_qualifiers] = STATE(2369),
    [sym_hlsl_attribute] = STATE(1206),
    [aux_sym_translation_unit_repeat1] = STATE(81),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(840),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1833),
    [ts_builtin_sym_end] = ACTIONS(1015),
    [sym_identifier] = ACTIONS(1017),
    [aux_sym_preproc_include_token1] = ACTIONS(1020),
    [aux_sym_preproc_def_token1] = ACTIONS(1023),
    [aux_sym_preproc_if_token1] = ACTIONS(1026),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1029),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1029),
    [sym_preproc_directive] = ACTIONS(1032),
    [anon_sym_LPAREN2] = ACTIONS(1035),
    [anon_sym_BANG] = ACTIONS(1038),
    [anon_sym_TILDE] = ACTIONS(1041),
    [anon_sym_DASH] = ACTIONS(1044),
    [anon_sym_PLUS] = ACTIONS(1044),
    [anon_sym_STAR] = ACTIONS(1047),
    [anon_sym_AMP_AMP] = ACTIONS(1050),
    [anon_sym_AMP] = ACTIONS(1053),
    [anon_sym___extension__] = ACTIONS(1056),
    [anon_sym_typedef] = ACTIONS(1059),
    [anon_sym_in] = ACTIONS(1062),
    [anon_sym_out] = ACTIONS(1062),
    [anon_sym_inout] = ACTIONS(1062),
    [anon_sym_extern] = ACTIONS(1065),
    [anon_sym___attribute__] = ACTIONS(1068),
    [anon_sym_COLON_COLON] = ACTIONS(1071),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1074),
    [anon_sym___declspec] = ACTIONS(1077),
    [anon_sym___based] = ACTIONS(1080),
    [anon_sym___cdecl] = ACTIONS(1083),
    [anon_sym___clrcall] = ACTIONS(1083),
    [anon_sym___stdcall] = ACTIONS(1083),
    [anon_sym___fastcall] = ACTIONS(1083),
    [anon_sym___thiscall] = ACTIONS(1083),
    [anon_sym___vectorcall] = ACTIONS(1083),
    [anon_sym_LBRACE] = ACTIONS(1086),
    [anon_sym_signed] = ACTIONS(1089),
    [anon_sym_unsigned] = ACTIONS(1089),
    [anon_sym_long] = ACTIONS(1089),
    [anon_sym_short] = ACTIONS(1089),
    [anon_sym_LBRACK] = ACTIONS(1092),
    [anon_sym_static] = ACTIONS(1095),
    [anon_sym_register] = ACTIONS(1095),
    [anon_sym_inline] = ACTIONS(1098),
    [anon_sym___inline] = ACTIONS(1095),
    [anon_sym___inline__] = ACTIONS(1095),
    [anon_sym___forceinline] = ACTIONS(1095),
    [anon_sym_thread_local] = ACTIONS(1095),
    [anon_sym___thread] = ACTIONS(1095),
    [anon_sym_const] = ACTIONS(1101),
    [anon_sym_constexpr] = ACTIONS(1101),
    [anon_sym_volatile] = ACTIONS(1101),
    [anon_sym_restrict] = ACTIONS(1101),
    [anon_sym___restrict__] = ACTIONS(1101),
    [anon_sym__Atomic] = ACTIONS(1101),
    [anon_sym__Noreturn] = ACTIONS(1101),
    [anon_sym_noreturn] = ACTIONS(1101),
    [anon_sym_mutable] = ACTIONS(1101),
    [anon_sym_constinit] = ACTIONS(1101),
    [anon_sym_consteval] = ACTIONS(1101),
    [anon_sym_alignas] = ACTIONS(1104),
    [anon_sym__Alignas] = ACTIONS(1104),
    [sym_primitive_type] = ACTIONS(1107),
    [anon_sym_enum] = ACTIONS(1110),
    [anon_sym_class] = ACTIONS(1113),
    [anon_sym_struct] = ACTIONS(1116),
    [anon_sym_union] = ACTIONS(1119),
    [anon_sym_if] = ACTIONS(1122),
    [anon_sym_switch] = ACTIONS(1125),
    [anon_sym_case] = ACTIONS(1128),
    [anon_sym_default] = ACTIONS(1131),
    [anon_sym_while] = ACTIONS(1134),
    [anon_sym_do] = ACTIONS(1137),
    [anon_sym_for] = ACTIONS(1140),
    [anon_sym_return] = ACTIONS(1143),
    [anon_sym_break] = ACTIONS(1146),
    [anon_sym_continue] = ACTIONS(1149),
    [anon_sym_goto] = ACTIONS(1152),
    [anon_sym_not] = ACTIONS(1044),
    [anon_sym_compl] = ACTIONS(1044),
    [anon_sym_DASH_DASH] = ACTIONS(1155),
    [anon_sym_PLUS_PLUS] = ACTIONS(1155),
    [anon_sym_sizeof] = ACTIONS(1158),
    [anon_sym___alignof__] = ACTIONS(1161),
    [anon_sym___alignof] = ACTIONS(1161),
    [anon_sym__alignof] = ACTIONS(1161),
    [anon_sym_alignof] = ACTIONS(1161),
    [anon_sym__Alignof] = ACTIONS(1161),
    [anon_sym_offsetof] = ACTIONS(1164),
    [anon_sym__Generic] = ACTIONS(1167),
    [anon_sym_asm] = ACTIONS(1170),
    [anon_sym___asm__] = ACTIONS(1170),
    [sym_number_literal] = ACTIONS(1173),
    [anon_sym_L_SQUOTE] = ACTIONS(1176),
    [anon_sym_u_SQUOTE] = ACTIONS(1176),
    [anon_sym_U_SQUOTE] = ACTIONS(1176),
    [anon_sym_u8_SQUOTE] = ACTIONS(1176),
    [anon_sym_SQUOTE] = ACTIONS(1176),
    [anon_sym_L_DQUOTE] = ACTIONS(1179),
    [anon_sym_u_DQUOTE] = ACTIONS(1179),
    [anon_sym_U_DQUOTE] = ACTIONS(1179),
    [anon_sym_u8_DQUOTE] = ACTIONS(1179),
    [anon_sym_DQUOTE] = ACTIONS(1179),
    [sym_true] = ACTIONS(1182),
    [sym_false] = ACTIONS(1182),
    [anon_sym_NULL] = ACTIONS(1185),
    [anon_sym_nullptr] = ACTIONS(1185),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1188),
    [anon_sym_decltype] = ACTIONS(1191),
    [sym_virtual] = ACTIONS(1062),
    [anon_sym_explicit] = ACTIONS(1194),
    [anon_sym_typename] = ACTIONS(1197),
    [anon_sym_template] = ACTIONS(1200),
    [anon_sym_operator] = ACTIONS(1203),
    [anon_sym_try] = ACTIONS(1206),
    [anon_sym_delete] = ACTIONS(1209),
    [anon_sym_throw] = ACTIONS(1212),
    [anon_sym_namespace] = ACTIONS(1215),
    [anon_sym_using] = ACTIONS(1218),
    [anon_sym_static_assert] = ACTIONS(1221),
    [anon_sym_concept] = ACTIONS(1224),
    [anon_sym_co_return] = ACTIONS(1227),
    [anon_sym_co_yield] = ACTIONS(1230),
    [anon_sym_R_DQUOTE] = ACTIONS(1233),
    [anon_sym_LR_DQUOTE] = ACTIONS(1233),
    [anon_sym_uR_DQUOTE] = ACTIONS(1233),
    [anon_sym_UR_DQUOTE] = ACTIONS(1233),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1233),
    [anon_sym_co_await] = ACTIONS(1236),
    [anon_sym_new] = ACTIONS(1239),
    [anon_sym_requires] = ACTIONS(1242),
    [sym_this] = ACTIONS(1182),
    [anon_sym_precise] = ACTIONS(1245),
    [anon_sym_shared] = ACTIONS(1245),
    [anon_sym_groupshared] = ACTIONS(1245),
    [anon_sym_uniform] = ACTIONS(1245),
    [anon_sym_row_major] = ACTIONS(1245),
    [anon_sym_column_major] = ACTIONS(1245),
    [anon_sym_globallycoherent] = ACTIONS(1245),
    [anon_sym_centroid] = ACTIONS(1245),
    [anon_sym_noperspective] = ACTIONS(1245),
    [anon_sym_nointerpolation] = ACTIONS(1245),
    [anon_sym_sample] = ACTIONS(1245),
    [anon_sym_linear] = ACTIONS(1245),
    [anon_sym_snorm] = ACTIONS(1245),
    [anon_sym_unorm] = ACTIONS(1245),
    [anon_sym_point] = ACTIONS(1245),
    [anon_sym_line] = ACTIONS(1245),
    [anon_sym_triangleadj] = ACTIONS(1245),
    [anon_sym_lineadj] = ACTIONS(1245),
    [anon_sym_triangle] = ACTIONS(1245),
  },
  [82] = {
    [sym_declaration] = STATE(84),
    [sym_type_definition] = STATE(84),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5213),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(84),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(84),
    [sym_labeled_statement] = STATE(84),
    [sym_expression_statement] = STATE(84),
    [sym_if_statement] = STATE(84),
    [sym_switch_statement] = STATE(84),
    [sym_while_statement] = STATE(84),
    [sym_do_statement] = STATE(84),
    [sym_for_statement] = STATE(84),
    [sym_return_statement] = STATE(84),
    [sym_break_statement] = STATE(84),
    [sym_continue_statement] = STATE(84),
    [sym_goto_statement] = STATE(84),
    [sym_seh_try_statement] = STATE(84),
    [sym_seh_leave_statement] = STATE(84),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(84),
    [sym_co_return_statement] = STATE(84),
    [sym_co_yield_statement] = STATE(84),
    [sym_throw_statement] = STATE(84),
    [sym_try_statement] = STATE(84),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(84),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(84),
    [sym_hlsl_attribute] = STATE(7801),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(84),
    [sym_identifier] = ACTIONS(1248),
    [aux_sym_preproc_include_token1] = ACTIONS(1250),
    [aux_sym_preproc_def_token1] = ACTIONS(1250),
    [aux_sym_preproc_if_token1] = ACTIONS(1250),
    [aux_sym_preproc_if_token2] = ACTIONS(1250),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1250),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1250),
    [aux_sym_preproc_else_token1] = ACTIONS(1250),
    [aux_sym_preproc_elif_token1] = ACTIONS(1250),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1250),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1250),
    [sym_preproc_directive] = ACTIONS(1250),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP_AMP] = ACTIONS(1256),
    [anon_sym_AMP] = ACTIONS(1258),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym___extension__] = ACTIONS(287),
    [anon_sym_typedef] = ACTIONS(289),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(1250),
    [anon_sym___cdecl] = ACTIONS(1250),
    [anon_sym___clrcall] = ACTIONS(1250),
    [anon_sym___stdcall] = ACTIONS(1250),
    [anon_sym___fastcall] = ACTIONS(1250),
    [anon_sym___thiscall] = ACTIONS(1250),
    [anon_sym___vectorcall] = ACTIONS(1250),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_else] = ACTIONS(1250),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(1250),
    [anon_sym_default] = ACTIONS(1250),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_explicit] = ACTIONS(1250),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(1250),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_namespace] = ACTIONS(1250),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_static_assert] = ACTIONS(1250),
    [anon_sym_concept] = ACTIONS(1250),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [83] = {
    [sym_declaration] = STATE(86),
    [sym_type_definition] = STATE(86),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5213),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(86),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(86),
    [sym_labeled_statement] = STATE(86),
    [sym_expression_statement] = STATE(86),
    [sym_if_statement] = STATE(86),
    [sym_switch_statement] = STATE(86),
    [sym_while_statement] = STATE(86),
    [sym_do_statement] = STATE(86),
    [sym_for_statement] = STATE(86),
    [sym_return_statement] = STATE(86),
    [sym_break_statement] = STATE(86),
    [sym_continue_statement] = STATE(86),
    [sym_goto_statement] = STATE(86),
    [sym_seh_try_statement] = STATE(86),
    [sym_seh_leave_statement] = STATE(86),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(86),
    [sym_co_return_statement] = STATE(86),
    [sym_co_yield_statement] = STATE(86),
    [sym_throw_statement] = STATE(86),
    [sym_try_statement] = STATE(86),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(86),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(86),
    [sym_hlsl_attribute] = STATE(7801),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(86),
    [sym_identifier] = ACTIONS(1248),
    [aux_sym_preproc_include_token1] = ACTIONS(1268),
    [aux_sym_preproc_def_token1] = ACTIONS(1268),
    [aux_sym_preproc_if_token1] = ACTIONS(1268),
    [aux_sym_preproc_if_token2] = ACTIONS(1268),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1268),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1268),
    [aux_sym_preproc_else_token1] = ACTIONS(1268),
    [aux_sym_preproc_elif_token1] = ACTIONS(1268),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1268),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1268),
    [sym_preproc_directive] = ACTIONS(1268),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP_AMP] = ACTIONS(1270),
    [anon_sym_AMP] = ACTIONS(1258),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym___extension__] = ACTIONS(287),
    [anon_sym_typedef] = ACTIONS(289),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(1268),
    [anon_sym___cdecl] = ACTIONS(1268),
    [anon_sym___clrcall] = ACTIONS(1268),
    [anon_sym___stdcall] = ACTIONS(1268),
    [anon_sym___fastcall] = ACTIONS(1268),
    [anon_sym___thiscall] = ACTIONS(1268),
    [anon_sym___vectorcall] = ACTIONS(1268),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_else] = ACTIONS(1268),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(1268),
    [anon_sym_default] = ACTIONS(1268),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_explicit] = ACTIONS(1268),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(1268),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_namespace] = ACTIONS(1268),
    [anon_sym_using] = ACTIONS(1268),
    [anon_sym_static_assert] = ACTIONS(1268),
    [anon_sym_concept] = ACTIONS(1268),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [84] = {
    [sym_declaration] = STATE(84),
    [sym_type_definition] = STATE(84),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5213),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(84),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(84),
    [sym_labeled_statement] = STATE(84),
    [sym_expression_statement] = STATE(84),
    [sym_if_statement] = STATE(84),
    [sym_switch_statement] = STATE(84),
    [sym_while_statement] = STATE(84),
    [sym_do_statement] = STATE(84),
    [sym_for_statement] = STATE(84),
    [sym_return_statement] = STATE(84),
    [sym_break_statement] = STATE(84),
    [sym_continue_statement] = STATE(84),
    [sym_goto_statement] = STATE(84),
    [sym_seh_try_statement] = STATE(84),
    [sym_seh_leave_statement] = STATE(84),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(84),
    [sym_co_return_statement] = STATE(84),
    [sym_co_yield_statement] = STATE(84),
    [sym_throw_statement] = STATE(84),
    [sym_try_statement] = STATE(84),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(84),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(84),
    [sym_hlsl_attribute] = STATE(7801),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(84),
    [sym_identifier] = ACTIONS(1272),
    [aux_sym_preproc_include_token1] = ACTIONS(1275),
    [aux_sym_preproc_def_token1] = ACTIONS(1275),
    [aux_sym_preproc_if_token1] = ACTIONS(1275),
    [aux_sym_preproc_if_token2] = ACTIONS(1275),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1275),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1275),
    [aux_sym_preproc_else_token1] = ACTIONS(1275),
    [aux_sym_preproc_elif_token1] = ACTIONS(1275),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1275),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1275),
    [sym_preproc_directive] = ACTIONS(1275),
    [anon_sym_LPAREN2] = ACTIONS(1277),
    [anon_sym_BANG] = ACTIONS(1280),
    [anon_sym_TILDE] = ACTIONS(1280),
    [anon_sym_DASH] = ACTIONS(1283),
    [anon_sym_PLUS] = ACTIONS(1283),
    [anon_sym_STAR] = ACTIONS(1286),
    [anon_sym_AMP_AMP] = ACTIONS(1289),
    [anon_sym_AMP] = ACTIONS(1291),
    [anon_sym_SEMI] = ACTIONS(1294),
    [anon_sym___extension__] = ACTIONS(1297),
    [anon_sym_typedef] = ACTIONS(1300),
    [anon_sym_in] = ACTIONS(1303),
    [anon_sym_out] = ACTIONS(1303),
    [anon_sym_inout] = ACTIONS(1303),
    [anon_sym_extern] = ACTIONS(1306),
    [anon_sym___attribute__] = ACTIONS(1309),
    [anon_sym_COLON_COLON] = ACTIONS(1312),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1315),
    [anon_sym___declspec] = ACTIONS(1318),
    [anon_sym___based] = ACTIONS(1275),
    [anon_sym___cdecl] = ACTIONS(1275),
    [anon_sym___clrcall] = ACTIONS(1275),
    [anon_sym___stdcall] = ACTIONS(1275),
    [anon_sym___fastcall] = ACTIONS(1275),
    [anon_sym___thiscall] = ACTIONS(1275),
    [anon_sym___vectorcall] = ACTIONS(1275),
    [anon_sym_LBRACE] = ACTIONS(1321),
    [anon_sym_signed] = ACTIONS(1324),
    [anon_sym_unsigned] = ACTIONS(1324),
    [anon_sym_long] = ACTIONS(1324),
    [anon_sym_short] = ACTIONS(1324),
    [anon_sym_LBRACK] = ACTIONS(1327),
    [anon_sym_static] = ACTIONS(1306),
    [anon_sym_register] = ACTIONS(1306),
    [anon_sym_inline] = ACTIONS(1306),
    [anon_sym___inline] = ACTIONS(1306),
    [anon_sym___inline__] = ACTIONS(1306),
    [anon_sym___forceinline] = ACTIONS(1306),
    [anon_sym_thread_local] = ACTIONS(1306),
    [anon_sym___thread] = ACTIONS(1306),
    [anon_sym_const] = ACTIONS(1330),
    [anon_sym_constexpr] = ACTIONS(1330),
    [anon_sym_volatile] = ACTIONS(1330),
    [anon_sym_restrict] = ACTIONS(1330),
    [anon_sym___restrict__] = ACTIONS(1330),
    [anon_sym__Atomic] = ACTIONS(1330),
    [anon_sym__Noreturn] = ACTIONS(1330),
    [anon_sym_noreturn] = ACTIONS(1330),
    [anon_sym_mutable] = ACTIONS(1330),
    [anon_sym_constinit] = ACTIONS(1330),
    [anon_sym_consteval] = ACTIONS(1330),
    [anon_sym_alignas] = ACTIONS(1333),
    [anon_sym__Alignas] = ACTIONS(1333),
    [sym_primitive_type] = ACTIONS(1336),
    [anon_sym_enum] = ACTIONS(1339),
    [anon_sym_class] = ACTIONS(1342),
    [anon_sym_struct] = ACTIONS(1345),
    [anon_sym_union] = ACTIONS(1348),
    [anon_sym_if] = ACTIONS(1351),
    [anon_sym_else] = ACTIONS(1275),
    [anon_sym_switch] = ACTIONS(1354),
    [anon_sym_case] = ACTIONS(1275),
    [anon_sym_default] = ACTIONS(1275),
    [anon_sym_while] = ACTIONS(1357),
    [anon_sym_do] = ACTIONS(1360),
    [anon_sym_for] = ACTIONS(1363),
    [anon_sym_return] = ACTIONS(1366),
    [anon_sym_break] = ACTIONS(1369),
    [anon_sym_continue] = ACTIONS(1372),
    [anon_sym_goto] = ACTIONS(1375),
    [anon_sym___try] = ACTIONS(1378),
    [anon_sym___leave] = ACTIONS(1381),
    [anon_sym_not] = ACTIONS(1283),
    [anon_sym_compl] = ACTIONS(1283),
    [anon_sym_DASH_DASH] = ACTIONS(1384),
    [anon_sym_PLUS_PLUS] = ACTIONS(1384),
    [anon_sym_sizeof] = ACTIONS(1387),
    [anon_sym___alignof__] = ACTIONS(1390),
    [anon_sym___alignof] = ACTIONS(1390),
    [anon_sym__alignof] = ACTIONS(1390),
    [anon_sym_alignof] = ACTIONS(1390),
    [anon_sym__Alignof] = ACTIONS(1390),
    [anon_sym_offsetof] = ACTIONS(1393),
    [anon_sym__Generic] = ACTIONS(1396),
    [anon_sym_asm] = ACTIONS(1399),
    [anon_sym___asm__] = ACTIONS(1399),
    [sym_number_literal] = ACTIONS(1402),
    [anon_sym_L_SQUOTE] = ACTIONS(1405),
    [anon_sym_u_SQUOTE] = ACTIONS(1405),
    [anon_sym_U_SQUOTE] = ACTIONS(1405),
    [anon_sym_u8_SQUOTE] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1405),
    [anon_sym_L_DQUOTE] = ACTIONS(1408),
    [anon_sym_u_DQUOTE] = ACTIONS(1408),
    [anon_sym_U_DQUOTE] = ACTIONS(1408),
    [anon_sym_u8_DQUOTE] = ACTIONS(1408),
    [anon_sym_DQUOTE] = ACTIONS(1408),
    [sym_true] = ACTIONS(1411),
    [sym_false] = ACTIONS(1411),
    [anon_sym_NULL] = ACTIONS(1414),
    [anon_sym_nullptr] = ACTIONS(1414),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1417),
    [anon_sym_decltype] = ACTIONS(1420),
    [sym_virtual] = ACTIONS(1303),
    [anon_sym_explicit] = ACTIONS(1275),
    [anon_sym_typename] = ACTIONS(1423),
    [anon_sym_template] = ACTIONS(1426),
    [anon_sym_operator] = ACTIONS(1275),
    [anon_sym_try] = ACTIONS(1429),
    [anon_sym_delete] = ACTIONS(1432),
    [anon_sym_throw] = ACTIONS(1435),
    [anon_sym_namespace] = ACTIONS(1275),
    [anon_sym_using] = ACTIONS(1275),
    [anon_sym_static_assert] = ACTIONS(1275),
    [anon_sym_concept] = ACTIONS(1275),
    [anon_sym_co_return] = ACTIONS(1438),
    [anon_sym_co_yield] = ACTIONS(1441),
    [anon_sym_R_DQUOTE] = ACTIONS(1444),
    [anon_sym_LR_DQUOTE] = ACTIONS(1444),
    [anon_sym_uR_DQUOTE] = ACTIONS(1444),
    [anon_sym_UR_DQUOTE] = ACTIONS(1444),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1444),
    [anon_sym_co_await] = ACTIONS(1447),
    [anon_sym_new] = ACTIONS(1450),
    [anon_sym_requires] = ACTIONS(1453),
    [sym_this] = ACTIONS(1411),
    [anon_sym_discard] = ACTIONS(1456),
    [anon_sym_precise] = ACTIONS(1459),
    [anon_sym_shared] = ACTIONS(1459),
    [anon_sym_groupshared] = ACTIONS(1459),
    [anon_sym_uniform] = ACTIONS(1459),
    [anon_sym_row_major] = ACTIONS(1459),
    [anon_sym_column_major] = ACTIONS(1459),
    [anon_sym_globallycoherent] = ACTIONS(1459),
    [anon_sym_centroid] = ACTIONS(1459),
    [anon_sym_noperspective] = ACTIONS(1459),
    [anon_sym_nointerpolation] = ACTIONS(1459),
    [anon_sym_sample] = ACTIONS(1459),
    [anon_sym_linear] = ACTIONS(1459),
    [anon_sym_snorm] = ACTIONS(1459),
    [anon_sym_unorm] = ACTIONS(1459),
    [anon_sym_point] = ACTIONS(1459),
    [anon_sym_line] = ACTIONS(1459),
    [anon_sym_triangleadj] = ACTIONS(1459),
    [anon_sym_lineadj] = ACTIONS(1459),
    [anon_sym_triangle] = ACTIONS(1459),
    [anon_sym_cbuffer] = ACTIONS(1462),
  },
  [85] = {
    [sym_declaration] = STATE(82),
    [sym_type_definition] = STATE(82),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5213),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(82),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(82),
    [sym_labeled_statement] = STATE(82),
    [sym_expression_statement] = STATE(82),
    [sym_if_statement] = STATE(82),
    [sym_switch_statement] = STATE(82),
    [sym_while_statement] = STATE(82),
    [sym_do_statement] = STATE(82),
    [sym_for_statement] = STATE(82),
    [sym_return_statement] = STATE(82),
    [sym_break_statement] = STATE(82),
    [sym_continue_statement] = STATE(82),
    [sym_goto_statement] = STATE(82),
    [sym_seh_try_statement] = STATE(82),
    [sym_seh_leave_statement] = STATE(82),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(82),
    [sym_co_return_statement] = STATE(82),
    [sym_co_yield_statement] = STATE(82),
    [sym_throw_statement] = STATE(82),
    [sym_try_statement] = STATE(82),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(82),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(82),
    [sym_hlsl_attribute] = STATE(7801),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(82),
    [sym_identifier] = ACTIONS(1248),
    [aux_sym_preproc_include_token1] = ACTIONS(1465),
    [aux_sym_preproc_def_token1] = ACTIONS(1465),
    [aux_sym_preproc_if_token1] = ACTIONS(1465),
    [aux_sym_preproc_if_token2] = ACTIONS(1465),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1465),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1465),
    [aux_sym_preproc_else_token1] = ACTIONS(1465),
    [aux_sym_preproc_elif_token1] = ACTIONS(1465),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1465),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1465),
    [sym_preproc_directive] = ACTIONS(1465),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP_AMP] = ACTIONS(1467),
    [anon_sym_AMP] = ACTIONS(1258),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym___extension__] = ACTIONS(287),
    [anon_sym_typedef] = ACTIONS(289),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(1465),
    [anon_sym___cdecl] = ACTIONS(1465),
    [anon_sym___clrcall] = ACTIONS(1465),
    [anon_sym___stdcall] = ACTIONS(1465),
    [anon_sym___fastcall] = ACTIONS(1465),
    [anon_sym___thiscall] = ACTIONS(1465),
    [anon_sym___vectorcall] = ACTIONS(1465),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_else] = ACTIONS(1465),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(1465),
    [anon_sym_default] = ACTIONS(1465),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_explicit] = ACTIONS(1465),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(1465),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_namespace] = ACTIONS(1465),
    [anon_sym_using] = ACTIONS(1465),
    [anon_sym_static_assert] = ACTIONS(1465),
    [anon_sym_concept] = ACTIONS(1465),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [86] = {
    [sym_declaration] = STATE(84),
    [sym_type_definition] = STATE(84),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5213),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(84),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(84),
    [sym_labeled_statement] = STATE(84),
    [sym_expression_statement] = STATE(84),
    [sym_if_statement] = STATE(84),
    [sym_switch_statement] = STATE(84),
    [sym_while_statement] = STATE(84),
    [sym_do_statement] = STATE(84),
    [sym_for_statement] = STATE(84),
    [sym_return_statement] = STATE(84),
    [sym_break_statement] = STATE(84),
    [sym_continue_statement] = STATE(84),
    [sym_goto_statement] = STATE(84),
    [sym_seh_try_statement] = STATE(84),
    [sym_seh_leave_statement] = STATE(84),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(84),
    [sym_co_return_statement] = STATE(84),
    [sym_co_yield_statement] = STATE(84),
    [sym_throw_statement] = STATE(84),
    [sym_try_statement] = STATE(84),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(84),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(84),
    [sym_hlsl_attribute] = STATE(7801),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(84),
    [sym_identifier] = ACTIONS(1248),
    [aux_sym_preproc_include_token1] = ACTIONS(1469),
    [aux_sym_preproc_def_token1] = ACTIONS(1469),
    [aux_sym_preproc_if_token1] = ACTIONS(1469),
    [aux_sym_preproc_if_token2] = ACTIONS(1469),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1469),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1469),
    [aux_sym_preproc_else_token1] = ACTIONS(1469),
    [aux_sym_preproc_elif_token1] = ACTIONS(1469),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1469),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1469),
    [sym_preproc_directive] = ACTIONS(1469),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP_AMP] = ACTIONS(1471),
    [anon_sym_AMP] = ACTIONS(1258),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym___extension__] = ACTIONS(287),
    [anon_sym_typedef] = ACTIONS(289),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(1469),
    [anon_sym___cdecl] = ACTIONS(1469),
    [anon_sym___clrcall] = ACTIONS(1469),
    [anon_sym___stdcall] = ACTIONS(1469),
    [anon_sym___fastcall] = ACTIONS(1469),
    [anon_sym___thiscall] = ACTIONS(1469),
    [anon_sym___vectorcall] = ACTIONS(1469),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_else] = ACTIONS(1469),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(1469),
    [anon_sym_default] = ACTIONS(1469),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_explicit] = ACTIONS(1469),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(1469),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_namespace] = ACTIONS(1469),
    [anon_sym_using] = ACTIONS(1469),
    [anon_sym_static_assert] = ACTIONS(1469),
    [anon_sym_concept] = ACTIONS(1469),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [87] = {
    [sym_declaration] = STATE(99),
    [sym_type_definition] = STATE(99),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5159),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(99),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(99),
    [sym_labeled_statement] = STATE(99),
    [sym_expression_statement] = STATE(99),
    [sym_if_statement] = STATE(99),
    [sym_switch_statement] = STATE(99),
    [sym_while_statement] = STATE(99),
    [sym_do_statement] = STATE(99),
    [sym_for_statement] = STATE(99),
    [sym_return_statement] = STATE(99),
    [sym_break_statement] = STATE(99),
    [sym_continue_statement] = STATE(99),
    [sym_goto_statement] = STATE(99),
    [sym_seh_try_statement] = STATE(99),
    [sym_seh_leave_statement] = STATE(99),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(99),
    [sym_co_return_statement] = STATE(99),
    [sym_co_yield_statement] = STATE(99),
    [sym_throw_statement] = STATE(99),
    [sym_try_statement] = STATE(99),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(99),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(99),
    [sym_hlsl_attribute] = STATE(7796),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(99),
    [sym_identifier] = ACTIONS(1473),
    [aux_sym_preproc_include_token1] = ACTIONS(1268),
    [aux_sym_preproc_def_token1] = ACTIONS(1268),
    [aux_sym_preproc_if_token1] = ACTIONS(1268),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1268),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1268),
    [sym_preproc_directive] = ACTIONS(1268),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP_AMP] = ACTIONS(1270),
    [anon_sym_AMP] = ACTIONS(1258),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(1268),
    [anon_sym___cdecl] = ACTIONS(1268),
    [anon_sym___clrcall] = ACTIONS(1268),
    [anon_sym___stdcall] = ACTIONS(1268),
    [anon_sym___fastcall] = ACTIONS(1268),
    [anon_sym___thiscall] = ACTIONS(1268),
    [anon_sym___vectorcall] = ACTIONS(1268),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(1270),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_else] = ACTIONS(1268),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(1268),
    [anon_sym_default] = ACTIONS(1268),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_explicit] = ACTIONS(1268),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(1268),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(1268),
    [anon_sym_using] = ACTIONS(1268),
    [anon_sym_static_assert] = ACTIONS(1268),
    [anon_sym_concept] = ACTIONS(1268),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [88] = {
    [sym_declaration] = STATE(101),
    [sym_type_definition] = STATE(101),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5181),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(101),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(101),
    [sym_labeled_statement] = STATE(101),
    [sym_expression_statement] = STATE(101),
    [sym_if_statement] = STATE(101),
    [sym_switch_statement] = STATE(101),
    [sym_while_statement] = STATE(101),
    [sym_do_statement] = STATE(101),
    [sym_for_statement] = STATE(101),
    [sym_return_statement] = STATE(101),
    [sym_break_statement] = STATE(101),
    [sym_continue_statement] = STATE(101),
    [sym_goto_statement] = STATE(101),
    [sym_seh_try_statement] = STATE(101),
    [sym_seh_leave_statement] = STATE(101),
    [sym_expression] = STATE(4525),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8558),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(101),
    [sym_co_return_statement] = STATE(101),
    [sym_co_yield_statement] = STATE(101),
    [sym_throw_statement] = STATE(101),
    [sym_try_statement] = STATE(101),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(101),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(101),
    [sym_hlsl_attribute] = STATE(7458),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(840),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(101),
    [ts_builtin_sym_end] = ACTIONS(1256),
    [sym_identifier] = ACTIONS(1475),
    [aux_sym_preproc_include_token1] = ACTIONS(1250),
    [aux_sym_preproc_def_token1] = ACTIONS(1250),
    [aux_sym_preproc_if_token1] = ACTIONS(1250),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1250),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1250),
    [sym_preproc_directive] = ACTIONS(1250),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP_AMP] = ACTIONS(1256),
    [anon_sym_AMP] = ACTIONS(1258),
    [anon_sym_SEMI] = ACTIONS(1477),
    [anon_sym___extension__] = ACTIONS(33),
    [anon_sym_typedef] = ACTIONS(35),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(1250),
    [anon_sym___cdecl] = ACTIONS(1250),
    [anon_sym___clrcall] = ACTIONS(1250),
    [anon_sym___stdcall] = ACTIONS(1250),
    [anon_sym___fastcall] = ACTIONS(1250),
    [anon_sym___thiscall] = ACTIONS(1250),
    [anon_sym___vectorcall] = ACTIONS(1250),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_else] = ACTIONS(1250),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(1250),
    [anon_sym_default] = ACTIONS(1250),
    [anon_sym_while] = ACTIONS(85),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(1479),
    [anon_sym___leave] = ACTIONS(1481),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_explicit] = ACTIONS(1250),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(1250),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_namespace] = ACTIONS(1250),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_static_assert] = ACTIONS(1250),
    [anon_sym_concept] = ACTIONS(1250),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1483),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(1485),
  },
  [89] = {
    [sym_declaration] = STATE(92),
    [sym_type_definition] = STATE(92),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5090),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(92),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(92),
    [sym_labeled_statement] = STATE(92),
    [sym_expression_statement] = STATE(92),
    [sym_if_statement] = STATE(92),
    [sym_switch_statement] = STATE(92),
    [sym_while_statement] = STATE(92),
    [sym_do_statement] = STATE(92),
    [sym_for_statement] = STATE(92),
    [sym_return_statement] = STATE(92),
    [sym_break_statement] = STATE(92),
    [sym_continue_statement] = STATE(92),
    [sym_goto_statement] = STATE(92),
    [sym_seh_try_statement] = STATE(92),
    [sym_seh_leave_statement] = STATE(92),
    [sym_expression] = STATE(4453),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7849),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(92),
    [sym_co_return_statement] = STATE(92),
    [sym_co_yield_statement] = STATE(92),
    [sym_throw_statement] = STATE(92),
    [sym_try_statement] = STATE(92),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(92),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(92),
    [sym_hlsl_attribute] = STATE(7711),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(827),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(92),
    [sym_identifier] = ACTIONS(1487),
    [aux_sym_preproc_include_token1] = ACTIONS(1250),
    [aux_sym_preproc_def_token1] = ACTIONS(1250),
    [aux_sym_preproc_if_token1] = ACTIONS(1250),
    [aux_sym_preproc_if_token2] = ACTIONS(1250),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1250),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1250),
    [sym_preproc_directive] = ACTIONS(1250),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP_AMP] = ACTIONS(1256),
    [anon_sym_AMP] = ACTIONS(1258),
    [anon_sym_SEMI] = ACTIONS(785),
    [anon_sym___extension__] = ACTIONS(787),
    [anon_sym_typedef] = ACTIONS(789),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(1250),
    [anon_sym___cdecl] = ACTIONS(1250),
    [anon_sym___clrcall] = ACTIONS(1250),
    [anon_sym___stdcall] = ACTIONS(1250),
    [anon_sym___fastcall] = ACTIONS(1250),
    [anon_sym___thiscall] = ACTIONS(1250),
    [anon_sym___vectorcall] = ACTIONS(1250),
    [anon_sym_LBRACE] = ACTIONS(793),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(797),
    [anon_sym_else] = ACTIONS(1250),
    [anon_sym_switch] = ACTIONS(799),
    [anon_sym_case] = ACTIONS(1250),
    [anon_sym_default] = ACTIONS(1250),
    [anon_sym_while] = ACTIONS(805),
    [anon_sym_do] = ACTIONS(807),
    [anon_sym_for] = ACTIONS(809),
    [anon_sym_return] = ACTIONS(811),
    [anon_sym_break] = ACTIONS(813),
    [anon_sym_continue] = ACTIONS(815),
    [anon_sym_goto] = ACTIONS(817),
    [anon_sym___try] = ACTIONS(819),
    [anon_sym___leave] = ACTIONS(821),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_explicit] = ACTIONS(1250),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(1250),
    [anon_sym_try] = ACTIONS(825),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(827),
    [anon_sym_namespace] = ACTIONS(1250),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_static_assert] = ACTIONS(1250),
    [anon_sym_concept] = ACTIONS(1250),
    [anon_sym_co_return] = ACTIONS(837),
    [anon_sym_co_yield] = ACTIONS(839),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(841),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(843),
  },
  [90] = {
    [sym_declaration] = STATE(91),
    [sym_type_definition] = STATE(91),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5159),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(91),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(91),
    [sym_labeled_statement] = STATE(91),
    [sym_expression_statement] = STATE(91),
    [sym_if_statement] = STATE(91),
    [sym_switch_statement] = STATE(91),
    [sym_while_statement] = STATE(91),
    [sym_do_statement] = STATE(91),
    [sym_for_statement] = STATE(91),
    [sym_return_statement] = STATE(91),
    [sym_break_statement] = STATE(91),
    [sym_continue_statement] = STATE(91),
    [sym_goto_statement] = STATE(91),
    [sym_seh_try_statement] = STATE(91),
    [sym_seh_leave_statement] = STATE(91),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(91),
    [sym_co_return_statement] = STATE(91),
    [sym_co_yield_statement] = STATE(91),
    [sym_throw_statement] = STATE(91),
    [sym_try_statement] = STATE(91),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(91),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(91),
    [sym_hlsl_attribute] = STATE(7796),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(91),
    [sym_identifier] = ACTIONS(1473),
    [aux_sym_preproc_include_token1] = ACTIONS(1250),
    [aux_sym_preproc_def_token1] = ACTIONS(1250),
    [aux_sym_preproc_if_token1] = ACTIONS(1250),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1250),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1250),
    [sym_preproc_directive] = ACTIONS(1250),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP_AMP] = ACTIONS(1256),
    [anon_sym_AMP] = ACTIONS(1258),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(1250),
    [anon_sym___cdecl] = ACTIONS(1250),
    [anon_sym___clrcall] = ACTIONS(1250),
    [anon_sym___stdcall] = ACTIONS(1250),
    [anon_sym___fastcall] = ACTIONS(1250),
    [anon_sym___thiscall] = ACTIONS(1250),
    [anon_sym___vectorcall] = ACTIONS(1250),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(1256),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_else] = ACTIONS(1250),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(1250),
    [anon_sym_default] = ACTIONS(1250),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_explicit] = ACTIONS(1250),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(1250),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(1250),
    [anon_sym_using] = ACTIONS(1250),
    [anon_sym_static_assert] = ACTIONS(1250),
    [anon_sym_concept] = ACTIONS(1250),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [91] = {
    [sym_declaration] = STATE(91),
    [sym_type_definition] = STATE(91),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5159),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(91),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(91),
    [sym_labeled_statement] = STATE(91),
    [sym_expression_statement] = STATE(91),
    [sym_if_statement] = STATE(91),
    [sym_switch_statement] = STATE(91),
    [sym_while_statement] = STATE(91),
    [sym_do_statement] = STATE(91),
    [sym_for_statement] = STATE(91),
    [sym_return_statement] = STATE(91),
    [sym_break_statement] = STATE(91),
    [sym_continue_statement] = STATE(91),
    [sym_goto_statement] = STATE(91),
    [sym_seh_try_statement] = STATE(91),
    [sym_seh_leave_statement] = STATE(91),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(91),
    [sym_co_return_statement] = STATE(91),
    [sym_co_yield_statement] = STATE(91),
    [sym_throw_statement] = STATE(91),
    [sym_try_statement] = STATE(91),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(91),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(91),
    [sym_hlsl_attribute] = STATE(7796),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(91),
    [sym_identifier] = ACTIONS(1489),
    [aux_sym_preproc_include_token1] = ACTIONS(1275),
    [aux_sym_preproc_def_token1] = ACTIONS(1275),
    [aux_sym_preproc_if_token1] = ACTIONS(1275),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1275),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1275),
    [sym_preproc_directive] = ACTIONS(1275),
    [anon_sym_LPAREN2] = ACTIONS(1277),
    [anon_sym_BANG] = ACTIONS(1280),
    [anon_sym_TILDE] = ACTIONS(1280),
    [anon_sym_DASH] = ACTIONS(1283),
    [anon_sym_PLUS] = ACTIONS(1283),
    [anon_sym_STAR] = ACTIONS(1286),
    [anon_sym_AMP_AMP] = ACTIONS(1289),
    [anon_sym_AMP] = ACTIONS(1291),
    [anon_sym_SEMI] = ACTIONS(1492),
    [anon_sym___extension__] = ACTIONS(1495),
    [anon_sym_typedef] = ACTIONS(1498),
    [anon_sym_in] = ACTIONS(1303),
    [anon_sym_out] = ACTIONS(1303),
    [anon_sym_inout] = ACTIONS(1303),
    [anon_sym_extern] = ACTIONS(1306),
    [anon_sym___attribute__] = ACTIONS(1309),
    [anon_sym_COLON_COLON] = ACTIONS(1312),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1315),
    [anon_sym___declspec] = ACTIONS(1318),
    [anon_sym___based] = ACTIONS(1275),
    [anon_sym___cdecl] = ACTIONS(1275),
    [anon_sym___clrcall] = ACTIONS(1275),
    [anon_sym___stdcall] = ACTIONS(1275),
    [anon_sym___fastcall] = ACTIONS(1275),
    [anon_sym___thiscall] = ACTIONS(1275),
    [anon_sym___vectorcall] = ACTIONS(1275),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(1289),
    [anon_sym_signed] = ACTIONS(1324),
    [anon_sym_unsigned] = ACTIONS(1324),
    [anon_sym_long] = ACTIONS(1324),
    [anon_sym_short] = ACTIONS(1324),
    [anon_sym_LBRACK] = ACTIONS(1327),
    [anon_sym_static] = ACTIONS(1306),
    [anon_sym_register] = ACTIONS(1306),
    [anon_sym_inline] = ACTIONS(1306),
    [anon_sym___inline] = ACTIONS(1306),
    [anon_sym___inline__] = ACTIONS(1306),
    [anon_sym___forceinline] = ACTIONS(1306),
    [anon_sym_thread_local] = ACTIONS(1306),
    [anon_sym___thread] = ACTIONS(1306),
    [anon_sym_const] = ACTIONS(1330),
    [anon_sym_constexpr] = ACTIONS(1330),
    [anon_sym_volatile] = ACTIONS(1330),
    [anon_sym_restrict] = ACTIONS(1330),
    [anon_sym___restrict__] = ACTIONS(1330),
    [anon_sym__Atomic] = ACTIONS(1330),
    [anon_sym__Noreturn] = ACTIONS(1330),
    [anon_sym_noreturn] = ACTIONS(1330),
    [anon_sym_mutable] = ACTIONS(1330),
    [anon_sym_constinit] = ACTIONS(1330),
    [anon_sym_consteval] = ACTIONS(1330),
    [anon_sym_alignas] = ACTIONS(1333),
    [anon_sym__Alignas] = ACTIONS(1333),
    [sym_primitive_type] = ACTIONS(1336),
    [anon_sym_enum] = ACTIONS(1339),
    [anon_sym_class] = ACTIONS(1342),
    [anon_sym_struct] = ACTIONS(1345),
    [anon_sym_union] = ACTIONS(1348),
    [anon_sym_if] = ACTIONS(1504),
    [anon_sym_else] = ACTIONS(1275),
    [anon_sym_switch] = ACTIONS(1507),
    [anon_sym_case] = ACTIONS(1275),
    [anon_sym_default] = ACTIONS(1275),
    [anon_sym_while] = ACTIONS(1510),
    [anon_sym_do] = ACTIONS(1513),
    [anon_sym_for] = ACTIONS(1516),
    [anon_sym_return] = ACTIONS(1519),
    [anon_sym_break] = ACTIONS(1522),
    [anon_sym_continue] = ACTIONS(1525),
    [anon_sym_goto] = ACTIONS(1528),
    [anon_sym___try] = ACTIONS(1531),
    [anon_sym___leave] = ACTIONS(1534),
    [anon_sym_not] = ACTIONS(1283),
    [anon_sym_compl] = ACTIONS(1283),
    [anon_sym_DASH_DASH] = ACTIONS(1384),
    [anon_sym_PLUS_PLUS] = ACTIONS(1384),
    [anon_sym_sizeof] = ACTIONS(1387),
    [anon_sym___alignof__] = ACTIONS(1390),
    [anon_sym___alignof] = ACTIONS(1390),
    [anon_sym__alignof] = ACTIONS(1390),
    [anon_sym_alignof] = ACTIONS(1390),
    [anon_sym__Alignof] = ACTIONS(1390),
    [anon_sym_offsetof] = ACTIONS(1393),
    [anon_sym__Generic] = ACTIONS(1396),
    [anon_sym_asm] = ACTIONS(1399),
    [anon_sym___asm__] = ACTIONS(1399),
    [sym_number_literal] = ACTIONS(1402),
    [anon_sym_L_SQUOTE] = ACTIONS(1405),
    [anon_sym_u_SQUOTE] = ACTIONS(1405),
    [anon_sym_U_SQUOTE] = ACTIONS(1405),
    [anon_sym_u8_SQUOTE] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1405),
    [anon_sym_L_DQUOTE] = ACTIONS(1408),
    [anon_sym_u_DQUOTE] = ACTIONS(1408),
    [anon_sym_U_DQUOTE] = ACTIONS(1408),
    [anon_sym_u8_DQUOTE] = ACTIONS(1408),
    [anon_sym_DQUOTE] = ACTIONS(1408),
    [sym_true] = ACTIONS(1411),
    [sym_false] = ACTIONS(1411),
    [anon_sym_NULL] = ACTIONS(1414),
    [anon_sym_nullptr] = ACTIONS(1414),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1417),
    [anon_sym_decltype] = ACTIONS(1420),
    [sym_virtual] = ACTIONS(1303),
    [anon_sym_explicit] = ACTIONS(1275),
    [anon_sym_typename] = ACTIONS(1423),
    [anon_sym_template] = ACTIONS(1426),
    [anon_sym_operator] = ACTIONS(1275),
    [anon_sym_try] = ACTIONS(1537),
    [anon_sym_delete] = ACTIONS(1432),
    [anon_sym_throw] = ACTIONS(1540),
    [anon_sym_namespace] = ACTIONS(1275),
    [anon_sym_using] = ACTIONS(1275),
    [anon_sym_static_assert] = ACTIONS(1275),
    [anon_sym_concept] = ACTIONS(1275),
    [anon_sym_co_return] = ACTIONS(1543),
    [anon_sym_co_yield] = ACTIONS(1546),
    [anon_sym_R_DQUOTE] = ACTIONS(1444),
    [anon_sym_LR_DQUOTE] = ACTIONS(1444),
    [anon_sym_uR_DQUOTE] = ACTIONS(1444),
    [anon_sym_UR_DQUOTE] = ACTIONS(1444),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1444),
    [anon_sym_co_await] = ACTIONS(1447),
    [anon_sym_new] = ACTIONS(1450),
    [anon_sym_requires] = ACTIONS(1453),
    [sym_this] = ACTIONS(1411),
    [anon_sym_discard] = ACTIONS(1549),
    [anon_sym_precise] = ACTIONS(1459),
    [anon_sym_shared] = ACTIONS(1459),
    [anon_sym_groupshared] = ACTIONS(1459),
    [anon_sym_uniform] = ACTIONS(1459),
    [anon_sym_row_major] = ACTIONS(1459),
    [anon_sym_column_major] = ACTIONS(1459),
    [anon_sym_globallycoherent] = ACTIONS(1459),
    [anon_sym_centroid] = ACTIONS(1459),
    [anon_sym_noperspective] = ACTIONS(1459),
    [anon_sym_nointerpolation] = ACTIONS(1459),
    [anon_sym_sample] = ACTIONS(1459),
    [anon_sym_linear] = ACTIONS(1459),
    [anon_sym_snorm] = ACTIONS(1459),
    [anon_sym_unorm] = ACTIONS(1459),
    [anon_sym_point] = ACTIONS(1459),
    [anon_sym_line] = ACTIONS(1459),
    [anon_sym_triangleadj] = ACTIONS(1459),
    [anon_sym_lineadj] = ACTIONS(1459),
    [anon_sym_triangle] = ACTIONS(1459),
    [anon_sym_cbuffer] = ACTIONS(1552),
  },
  [92] = {
    [sym_declaration] = STATE(92),
    [sym_type_definition] = STATE(92),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5090),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(92),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(92),
    [sym_labeled_statement] = STATE(92),
    [sym_expression_statement] = STATE(92),
    [sym_if_statement] = STATE(92),
    [sym_switch_statement] = STATE(92),
    [sym_while_statement] = STATE(92),
    [sym_do_statement] = STATE(92),
    [sym_for_statement] = STATE(92),
    [sym_return_statement] = STATE(92),
    [sym_break_statement] = STATE(92),
    [sym_continue_statement] = STATE(92),
    [sym_goto_statement] = STATE(92),
    [sym_seh_try_statement] = STATE(92),
    [sym_seh_leave_statement] = STATE(92),
    [sym_expression] = STATE(4453),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7849),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(92),
    [sym_co_return_statement] = STATE(92),
    [sym_co_yield_statement] = STATE(92),
    [sym_throw_statement] = STATE(92),
    [sym_try_statement] = STATE(92),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(92),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(92),
    [sym_hlsl_attribute] = STATE(7711),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(827),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(92),
    [sym_identifier] = ACTIONS(1555),
    [aux_sym_preproc_include_token1] = ACTIONS(1275),
    [aux_sym_preproc_def_token1] = ACTIONS(1275),
    [aux_sym_preproc_if_token1] = ACTIONS(1275),
    [aux_sym_preproc_if_token2] = ACTIONS(1275),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1275),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1275),
    [sym_preproc_directive] = ACTIONS(1275),
    [anon_sym_LPAREN2] = ACTIONS(1277),
    [anon_sym_BANG] = ACTIONS(1280),
    [anon_sym_TILDE] = ACTIONS(1280),
    [anon_sym_DASH] = ACTIONS(1283),
    [anon_sym_PLUS] = ACTIONS(1283),
    [anon_sym_STAR] = ACTIONS(1286),
    [anon_sym_AMP_AMP] = ACTIONS(1289),
    [anon_sym_AMP] = ACTIONS(1291),
    [anon_sym_SEMI] = ACTIONS(1558),
    [anon_sym___extension__] = ACTIONS(1561),
    [anon_sym_typedef] = ACTIONS(1564),
    [anon_sym_in] = ACTIONS(1303),
    [anon_sym_out] = ACTIONS(1303),
    [anon_sym_inout] = ACTIONS(1303),
    [anon_sym_extern] = ACTIONS(1306),
    [anon_sym___attribute__] = ACTIONS(1309),
    [anon_sym_COLON_COLON] = ACTIONS(1312),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1315),
    [anon_sym___declspec] = ACTIONS(1318),
    [anon_sym___based] = ACTIONS(1275),
    [anon_sym___cdecl] = ACTIONS(1275),
    [anon_sym___clrcall] = ACTIONS(1275),
    [anon_sym___stdcall] = ACTIONS(1275),
    [anon_sym___fastcall] = ACTIONS(1275),
    [anon_sym___thiscall] = ACTIONS(1275),
    [anon_sym___vectorcall] = ACTIONS(1275),
    [anon_sym_LBRACE] = ACTIONS(1567),
    [anon_sym_signed] = ACTIONS(1324),
    [anon_sym_unsigned] = ACTIONS(1324),
    [anon_sym_long] = ACTIONS(1324),
    [anon_sym_short] = ACTIONS(1324),
    [anon_sym_LBRACK] = ACTIONS(1327),
    [anon_sym_static] = ACTIONS(1306),
    [anon_sym_register] = ACTIONS(1306),
    [anon_sym_inline] = ACTIONS(1306),
    [anon_sym___inline] = ACTIONS(1306),
    [anon_sym___inline__] = ACTIONS(1306),
    [anon_sym___forceinline] = ACTIONS(1306),
    [anon_sym_thread_local] = ACTIONS(1306),
    [anon_sym___thread] = ACTIONS(1306),
    [anon_sym_const] = ACTIONS(1330),
    [anon_sym_constexpr] = ACTIONS(1330),
    [anon_sym_volatile] = ACTIONS(1330),
    [anon_sym_restrict] = ACTIONS(1330),
    [anon_sym___restrict__] = ACTIONS(1330),
    [anon_sym__Atomic] = ACTIONS(1330),
    [anon_sym__Noreturn] = ACTIONS(1330),
    [anon_sym_noreturn] = ACTIONS(1330),
    [anon_sym_mutable] = ACTIONS(1330),
    [anon_sym_constinit] = ACTIONS(1330),
    [anon_sym_consteval] = ACTIONS(1330),
    [anon_sym_alignas] = ACTIONS(1333),
    [anon_sym__Alignas] = ACTIONS(1333),
    [sym_primitive_type] = ACTIONS(1336),
    [anon_sym_enum] = ACTIONS(1339),
    [anon_sym_class] = ACTIONS(1342),
    [anon_sym_struct] = ACTIONS(1345),
    [anon_sym_union] = ACTIONS(1348),
    [anon_sym_if] = ACTIONS(1570),
    [anon_sym_else] = ACTIONS(1275),
    [anon_sym_switch] = ACTIONS(1573),
    [anon_sym_case] = ACTIONS(1275),
    [anon_sym_default] = ACTIONS(1275),
    [anon_sym_while] = ACTIONS(1576),
    [anon_sym_do] = ACTIONS(1579),
    [anon_sym_for] = ACTIONS(1582),
    [anon_sym_return] = ACTIONS(1585),
    [anon_sym_break] = ACTIONS(1588),
    [anon_sym_continue] = ACTIONS(1591),
    [anon_sym_goto] = ACTIONS(1594),
    [anon_sym___try] = ACTIONS(1597),
    [anon_sym___leave] = ACTIONS(1600),
    [anon_sym_not] = ACTIONS(1283),
    [anon_sym_compl] = ACTIONS(1283),
    [anon_sym_DASH_DASH] = ACTIONS(1384),
    [anon_sym_PLUS_PLUS] = ACTIONS(1384),
    [anon_sym_sizeof] = ACTIONS(1387),
    [anon_sym___alignof__] = ACTIONS(1390),
    [anon_sym___alignof] = ACTIONS(1390),
    [anon_sym__alignof] = ACTIONS(1390),
    [anon_sym_alignof] = ACTIONS(1390),
    [anon_sym__Alignof] = ACTIONS(1390),
    [anon_sym_offsetof] = ACTIONS(1393),
    [anon_sym__Generic] = ACTIONS(1396),
    [anon_sym_asm] = ACTIONS(1399),
    [anon_sym___asm__] = ACTIONS(1399),
    [sym_number_literal] = ACTIONS(1402),
    [anon_sym_L_SQUOTE] = ACTIONS(1405),
    [anon_sym_u_SQUOTE] = ACTIONS(1405),
    [anon_sym_U_SQUOTE] = ACTIONS(1405),
    [anon_sym_u8_SQUOTE] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1405),
    [anon_sym_L_DQUOTE] = ACTIONS(1408),
    [anon_sym_u_DQUOTE] = ACTIONS(1408),
    [anon_sym_U_DQUOTE] = ACTIONS(1408),
    [anon_sym_u8_DQUOTE] = ACTIONS(1408),
    [anon_sym_DQUOTE] = ACTIONS(1408),
    [sym_true] = ACTIONS(1411),
    [sym_false] = ACTIONS(1411),
    [anon_sym_NULL] = ACTIONS(1414),
    [anon_sym_nullptr] = ACTIONS(1414),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1417),
    [anon_sym_decltype] = ACTIONS(1420),
    [sym_virtual] = ACTIONS(1303),
    [anon_sym_explicit] = ACTIONS(1275),
    [anon_sym_typename] = ACTIONS(1423),
    [anon_sym_template] = ACTIONS(1426),
    [anon_sym_operator] = ACTIONS(1275),
    [anon_sym_try] = ACTIONS(1603),
    [anon_sym_delete] = ACTIONS(1432),
    [anon_sym_throw] = ACTIONS(1606),
    [anon_sym_namespace] = ACTIONS(1275),
    [anon_sym_using] = ACTIONS(1275),
    [anon_sym_static_assert] = ACTIONS(1275),
    [anon_sym_concept] = ACTIONS(1275),
    [anon_sym_co_return] = ACTIONS(1609),
    [anon_sym_co_yield] = ACTIONS(1612),
    [anon_sym_R_DQUOTE] = ACTIONS(1444),
    [anon_sym_LR_DQUOTE] = ACTIONS(1444),
    [anon_sym_uR_DQUOTE] = ACTIONS(1444),
    [anon_sym_UR_DQUOTE] = ACTIONS(1444),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1444),
    [anon_sym_co_await] = ACTIONS(1447),
    [anon_sym_new] = ACTIONS(1450),
    [anon_sym_requires] = ACTIONS(1453),
    [sym_this] = ACTIONS(1411),
    [anon_sym_discard] = ACTIONS(1615),
    [anon_sym_precise] = ACTIONS(1459),
    [anon_sym_shared] = ACTIONS(1459),
    [anon_sym_groupshared] = ACTIONS(1459),
    [anon_sym_uniform] = ACTIONS(1459),
    [anon_sym_row_major] = ACTIONS(1459),
    [anon_sym_column_major] = ACTIONS(1459),
    [anon_sym_globallycoherent] = ACTIONS(1459),
    [anon_sym_centroid] = ACTIONS(1459),
    [anon_sym_noperspective] = ACTIONS(1459),
    [anon_sym_nointerpolation] = ACTIONS(1459),
    [anon_sym_sample] = ACTIONS(1459),
    [anon_sym_linear] = ACTIONS(1459),
    [anon_sym_snorm] = ACTIONS(1459),
    [anon_sym_unorm] = ACTIONS(1459),
    [anon_sym_point] = ACTIONS(1459),
    [anon_sym_line] = ACTIONS(1459),
    [anon_sym_triangleadj] = ACTIONS(1459),
    [anon_sym_lineadj] = ACTIONS(1459),
    [anon_sym_triangle] = ACTIONS(1459),
    [anon_sym_cbuffer] = ACTIONS(1618),
  },
  [93] = {
    [sym_declaration] = STATE(100),
    [sym_type_definition] = STATE(100),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5181),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(100),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(100),
    [sym_labeled_statement] = STATE(100),
    [sym_expression_statement] = STATE(100),
    [sym_if_statement] = STATE(100),
    [sym_switch_statement] = STATE(100),
    [sym_while_statement] = STATE(100),
    [sym_do_statement] = STATE(100),
    [sym_for_statement] = STATE(100),
    [sym_return_statement] = STATE(100),
    [sym_break_statement] = STATE(100),
    [sym_continue_statement] = STATE(100),
    [sym_goto_statement] = STATE(100),
    [sym_seh_try_statement] = STATE(100),
    [sym_seh_leave_statement] = STATE(100),
    [sym_expression] = STATE(4525),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8558),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(100),
    [sym_co_return_statement] = STATE(100),
    [sym_co_yield_statement] = STATE(100),
    [sym_throw_statement] = STATE(100),
    [sym_try_statement] = STATE(100),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(100),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(100),
    [sym_hlsl_attribute] = STATE(7458),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(840),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(100),
    [ts_builtin_sym_end] = ACTIONS(1270),
    [sym_identifier] = ACTIONS(1475),
    [aux_sym_preproc_include_token1] = ACTIONS(1268),
    [aux_sym_preproc_def_token1] = ACTIONS(1268),
    [aux_sym_preproc_if_token1] = ACTIONS(1268),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1268),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1268),
    [sym_preproc_directive] = ACTIONS(1268),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP_AMP] = ACTIONS(1270),
    [anon_sym_AMP] = ACTIONS(1258),
    [anon_sym_SEMI] = ACTIONS(1477),
    [anon_sym___extension__] = ACTIONS(33),
    [anon_sym_typedef] = ACTIONS(35),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(1268),
    [anon_sym___cdecl] = ACTIONS(1268),
    [anon_sym___clrcall] = ACTIONS(1268),
    [anon_sym___stdcall] = ACTIONS(1268),
    [anon_sym___fastcall] = ACTIONS(1268),
    [anon_sym___thiscall] = ACTIONS(1268),
    [anon_sym___vectorcall] = ACTIONS(1268),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_else] = ACTIONS(1268),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(1268),
    [anon_sym_default] = ACTIONS(1268),
    [anon_sym_while] = ACTIONS(85),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(1479),
    [anon_sym___leave] = ACTIONS(1481),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_explicit] = ACTIONS(1268),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(1268),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_namespace] = ACTIONS(1268),
    [anon_sym_using] = ACTIONS(1268),
    [anon_sym_static_assert] = ACTIONS(1268),
    [anon_sym_concept] = ACTIONS(1268),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1483),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(1485),
  },
  [94] = {
    [sym_declaration] = STATE(90),
    [sym_type_definition] = STATE(90),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5159),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(90),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(90),
    [sym_labeled_statement] = STATE(90),
    [sym_expression_statement] = STATE(90),
    [sym_if_statement] = STATE(90),
    [sym_switch_statement] = STATE(90),
    [sym_while_statement] = STATE(90),
    [sym_do_statement] = STATE(90),
    [sym_for_statement] = STATE(90),
    [sym_return_statement] = STATE(90),
    [sym_break_statement] = STATE(90),
    [sym_continue_statement] = STATE(90),
    [sym_goto_statement] = STATE(90),
    [sym_seh_try_statement] = STATE(90),
    [sym_seh_leave_statement] = STATE(90),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(90),
    [sym_co_return_statement] = STATE(90),
    [sym_co_yield_statement] = STATE(90),
    [sym_throw_statement] = STATE(90),
    [sym_try_statement] = STATE(90),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(90),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(90),
    [sym_hlsl_attribute] = STATE(7796),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(90),
    [sym_identifier] = ACTIONS(1473),
    [aux_sym_preproc_include_token1] = ACTIONS(1465),
    [aux_sym_preproc_def_token1] = ACTIONS(1465),
    [aux_sym_preproc_if_token1] = ACTIONS(1465),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1465),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1465),
    [sym_preproc_directive] = ACTIONS(1465),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP_AMP] = ACTIONS(1467),
    [anon_sym_AMP] = ACTIONS(1258),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(1465),
    [anon_sym___cdecl] = ACTIONS(1465),
    [anon_sym___clrcall] = ACTIONS(1465),
    [anon_sym___stdcall] = ACTIONS(1465),
    [anon_sym___fastcall] = ACTIONS(1465),
    [anon_sym___thiscall] = ACTIONS(1465),
    [anon_sym___vectorcall] = ACTIONS(1465),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(1467),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_else] = ACTIONS(1465),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(1465),
    [anon_sym_default] = ACTIONS(1465),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_explicit] = ACTIONS(1465),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(1465),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(1465),
    [anon_sym_using] = ACTIONS(1465),
    [anon_sym_static_assert] = ACTIONS(1465),
    [anon_sym_concept] = ACTIONS(1465),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [95] = {
    [sym_declaration] = STATE(97),
    [sym_type_definition] = STATE(97),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5090),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(97),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(97),
    [sym_labeled_statement] = STATE(97),
    [sym_expression_statement] = STATE(97),
    [sym_if_statement] = STATE(97),
    [sym_switch_statement] = STATE(97),
    [sym_while_statement] = STATE(97),
    [sym_do_statement] = STATE(97),
    [sym_for_statement] = STATE(97),
    [sym_return_statement] = STATE(97),
    [sym_break_statement] = STATE(97),
    [sym_continue_statement] = STATE(97),
    [sym_goto_statement] = STATE(97),
    [sym_seh_try_statement] = STATE(97),
    [sym_seh_leave_statement] = STATE(97),
    [sym_expression] = STATE(4453),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7849),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(97),
    [sym_co_return_statement] = STATE(97),
    [sym_co_yield_statement] = STATE(97),
    [sym_throw_statement] = STATE(97),
    [sym_try_statement] = STATE(97),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(97),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(97),
    [sym_hlsl_attribute] = STATE(7711),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(827),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(97),
    [sym_identifier] = ACTIONS(1487),
    [aux_sym_preproc_include_token1] = ACTIONS(1268),
    [aux_sym_preproc_def_token1] = ACTIONS(1268),
    [aux_sym_preproc_if_token1] = ACTIONS(1268),
    [aux_sym_preproc_if_token2] = ACTIONS(1268),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1268),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1268),
    [sym_preproc_directive] = ACTIONS(1268),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP_AMP] = ACTIONS(1270),
    [anon_sym_AMP] = ACTIONS(1258),
    [anon_sym_SEMI] = ACTIONS(785),
    [anon_sym___extension__] = ACTIONS(787),
    [anon_sym_typedef] = ACTIONS(789),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(1268),
    [anon_sym___cdecl] = ACTIONS(1268),
    [anon_sym___clrcall] = ACTIONS(1268),
    [anon_sym___stdcall] = ACTIONS(1268),
    [anon_sym___fastcall] = ACTIONS(1268),
    [anon_sym___thiscall] = ACTIONS(1268),
    [anon_sym___vectorcall] = ACTIONS(1268),
    [anon_sym_LBRACE] = ACTIONS(793),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(797),
    [anon_sym_else] = ACTIONS(1268),
    [anon_sym_switch] = ACTIONS(799),
    [anon_sym_case] = ACTIONS(1268),
    [anon_sym_default] = ACTIONS(1268),
    [anon_sym_while] = ACTIONS(805),
    [anon_sym_do] = ACTIONS(807),
    [anon_sym_for] = ACTIONS(809),
    [anon_sym_return] = ACTIONS(811),
    [anon_sym_break] = ACTIONS(813),
    [anon_sym_continue] = ACTIONS(815),
    [anon_sym_goto] = ACTIONS(817),
    [anon_sym___try] = ACTIONS(819),
    [anon_sym___leave] = ACTIONS(821),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_explicit] = ACTIONS(1268),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(1268),
    [anon_sym_try] = ACTIONS(825),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(827),
    [anon_sym_namespace] = ACTIONS(1268),
    [anon_sym_using] = ACTIONS(1268),
    [anon_sym_static_assert] = ACTIONS(1268),
    [anon_sym_concept] = ACTIONS(1268),
    [anon_sym_co_return] = ACTIONS(837),
    [anon_sym_co_yield] = ACTIONS(839),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(841),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(843),
  },
  [96] = {
    [sym_declaration] = STATE(88),
    [sym_type_definition] = STATE(88),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5181),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(88),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(88),
    [sym_labeled_statement] = STATE(88),
    [sym_expression_statement] = STATE(88),
    [sym_if_statement] = STATE(88),
    [sym_switch_statement] = STATE(88),
    [sym_while_statement] = STATE(88),
    [sym_do_statement] = STATE(88),
    [sym_for_statement] = STATE(88),
    [sym_return_statement] = STATE(88),
    [sym_break_statement] = STATE(88),
    [sym_continue_statement] = STATE(88),
    [sym_goto_statement] = STATE(88),
    [sym_seh_try_statement] = STATE(88),
    [sym_seh_leave_statement] = STATE(88),
    [sym_expression] = STATE(4525),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8558),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(88),
    [sym_co_return_statement] = STATE(88),
    [sym_co_yield_statement] = STATE(88),
    [sym_throw_statement] = STATE(88),
    [sym_try_statement] = STATE(88),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(88),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(88),
    [sym_hlsl_attribute] = STATE(7458),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(840),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(88),
    [ts_builtin_sym_end] = ACTIONS(1467),
    [sym_identifier] = ACTIONS(1475),
    [aux_sym_preproc_include_token1] = ACTIONS(1465),
    [aux_sym_preproc_def_token1] = ACTIONS(1465),
    [aux_sym_preproc_if_token1] = ACTIONS(1465),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1465),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1465),
    [sym_preproc_directive] = ACTIONS(1465),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP_AMP] = ACTIONS(1467),
    [anon_sym_AMP] = ACTIONS(1258),
    [anon_sym_SEMI] = ACTIONS(1477),
    [anon_sym___extension__] = ACTIONS(33),
    [anon_sym_typedef] = ACTIONS(35),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(1465),
    [anon_sym___cdecl] = ACTIONS(1465),
    [anon_sym___clrcall] = ACTIONS(1465),
    [anon_sym___stdcall] = ACTIONS(1465),
    [anon_sym___fastcall] = ACTIONS(1465),
    [anon_sym___thiscall] = ACTIONS(1465),
    [anon_sym___vectorcall] = ACTIONS(1465),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_else] = ACTIONS(1465),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(1465),
    [anon_sym_default] = ACTIONS(1465),
    [anon_sym_while] = ACTIONS(85),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(1479),
    [anon_sym___leave] = ACTIONS(1481),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_explicit] = ACTIONS(1465),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(1465),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_namespace] = ACTIONS(1465),
    [anon_sym_using] = ACTIONS(1465),
    [anon_sym_static_assert] = ACTIONS(1465),
    [anon_sym_concept] = ACTIONS(1465),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1483),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(1485),
  },
  [97] = {
    [sym_declaration] = STATE(92),
    [sym_type_definition] = STATE(92),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5090),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(92),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(92),
    [sym_labeled_statement] = STATE(92),
    [sym_expression_statement] = STATE(92),
    [sym_if_statement] = STATE(92),
    [sym_switch_statement] = STATE(92),
    [sym_while_statement] = STATE(92),
    [sym_do_statement] = STATE(92),
    [sym_for_statement] = STATE(92),
    [sym_return_statement] = STATE(92),
    [sym_break_statement] = STATE(92),
    [sym_continue_statement] = STATE(92),
    [sym_goto_statement] = STATE(92),
    [sym_seh_try_statement] = STATE(92),
    [sym_seh_leave_statement] = STATE(92),
    [sym_expression] = STATE(4453),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7849),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(92),
    [sym_co_return_statement] = STATE(92),
    [sym_co_yield_statement] = STATE(92),
    [sym_throw_statement] = STATE(92),
    [sym_try_statement] = STATE(92),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(92),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(92),
    [sym_hlsl_attribute] = STATE(7711),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(827),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(92),
    [sym_identifier] = ACTIONS(1487),
    [aux_sym_preproc_include_token1] = ACTIONS(1469),
    [aux_sym_preproc_def_token1] = ACTIONS(1469),
    [aux_sym_preproc_if_token1] = ACTIONS(1469),
    [aux_sym_preproc_if_token2] = ACTIONS(1469),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1469),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1469),
    [sym_preproc_directive] = ACTIONS(1469),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP_AMP] = ACTIONS(1471),
    [anon_sym_AMP] = ACTIONS(1258),
    [anon_sym_SEMI] = ACTIONS(785),
    [anon_sym___extension__] = ACTIONS(787),
    [anon_sym_typedef] = ACTIONS(789),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(1469),
    [anon_sym___cdecl] = ACTIONS(1469),
    [anon_sym___clrcall] = ACTIONS(1469),
    [anon_sym___stdcall] = ACTIONS(1469),
    [anon_sym___fastcall] = ACTIONS(1469),
    [anon_sym___thiscall] = ACTIONS(1469),
    [anon_sym___vectorcall] = ACTIONS(1469),
    [anon_sym_LBRACE] = ACTIONS(793),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(797),
    [anon_sym_else] = ACTIONS(1469),
    [anon_sym_switch] = ACTIONS(799),
    [anon_sym_case] = ACTIONS(1469),
    [anon_sym_default] = ACTIONS(1469),
    [anon_sym_while] = ACTIONS(805),
    [anon_sym_do] = ACTIONS(807),
    [anon_sym_for] = ACTIONS(809),
    [anon_sym_return] = ACTIONS(811),
    [anon_sym_break] = ACTIONS(813),
    [anon_sym_continue] = ACTIONS(815),
    [anon_sym_goto] = ACTIONS(817),
    [anon_sym___try] = ACTIONS(819),
    [anon_sym___leave] = ACTIONS(821),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_explicit] = ACTIONS(1469),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(1469),
    [anon_sym_try] = ACTIONS(825),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(827),
    [anon_sym_namespace] = ACTIONS(1469),
    [anon_sym_using] = ACTIONS(1469),
    [anon_sym_static_assert] = ACTIONS(1469),
    [anon_sym_concept] = ACTIONS(1469),
    [anon_sym_co_return] = ACTIONS(837),
    [anon_sym_co_yield] = ACTIONS(839),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(841),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(843),
  },
  [98] = {
    [sym_declaration] = STATE(89),
    [sym_type_definition] = STATE(89),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5090),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(89),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(89),
    [sym_labeled_statement] = STATE(89),
    [sym_expression_statement] = STATE(89),
    [sym_if_statement] = STATE(89),
    [sym_switch_statement] = STATE(89),
    [sym_while_statement] = STATE(89),
    [sym_do_statement] = STATE(89),
    [sym_for_statement] = STATE(89),
    [sym_return_statement] = STATE(89),
    [sym_break_statement] = STATE(89),
    [sym_continue_statement] = STATE(89),
    [sym_goto_statement] = STATE(89),
    [sym_seh_try_statement] = STATE(89),
    [sym_seh_leave_statement] = STATE(89),
    [sym_expression] = STATE(4453),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7849),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(89),
    [sym_co_return_statement] = STATE(89),
    [sym_co_yield_statement] = STATE(89),
    [sym_throw_statement] = STATE(89),
    [sym_try_statement] = STATE(89),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(89),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(89),
    [sym_hlsl_attribute] = STATE(7711),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(827),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(89),
    [sym_identifier] = ACTIONS(1487),
    [aux_sym_preproc_include_token1] = ACTIONS(1465),
    [aux_sym_preproc_def_token1] = ACTIONS(1465),
    [aux_sym_preproc_if_token1] = ACTIONS(1465),
    [aux_sym_preproc_if_token2] = ACTIONS(1465),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1465),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1465),
    [sym_preproc_directive] = ACTIONS(1465),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP_AMP] = ACTIONS(1467),
    [anon_sym_AMP] = ACTIONS(1258),
    [anon_sym_SEMI] = ACTIONS(785),
    [anon_sym___extension__] = ACTIONS(787),
    [anon_sym_typedef] = ACTIONS(789),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(1465),
    [anon_sym___cdecl] = ACTIONS(1465),
    [anon_sym___clrcall] = ACTIONS(1465),
    [anon_sym___stdcall] = ACTIONS(1465),
    [anon_sym___fastcall] = ACTIONS(1465),
    [anon_sym___thiscall] = ACTIONS(1465),
    [anon_sym___vectorcall] = ACTIONS(1465),
    [anon_sym_LBRACE] = ACTIONS(793),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(797),
    [anon_sym_else] = ACTIONS(1465),
    [anon_sym_switch] = ACTIONS(799),
    [anon_sym_case] = ACTIONS(1465),
    [anon_sym_default] = ACTIONS(1465),
    [anon_sym_while] = ACTIONS(805),
    [anon_sym_do] = ACTIONS(807),
    [anon_sym_for] = ACTIONS(809),
    [anon_sym_return] = ACTIONS(811),
    [anon_sym_break] = ACTIONS(813),
    [anon_sym_continue] = ACTIONS(815),
    [anon_sym_goto] = ACTIONS(817),
    [anon_sym___try] = ACTIONS(819),
    [anon_sym___leave] = ACTIONS(821),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_explicit] = ACTIONS(1465),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(1465),
    [anon_sym_try] = ACTIONS(825),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(827),
    [anon_sym_namespace] = ACTIONS(1465),
    [anon_sym_using] = ACTIONS(1465),
    [anon_sym_static_assert] = ACTIONS(1465),
    [anon_sym_concept] = ACTIONS(1465),
    [anon_sym_co_return] = ACTIONS(837),
    [anon_sym_co_yield] = ACTIONS(839),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(841),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(843),
  },
  [99] = {
    [sym_declaration] = STATE(91),
    [sym_type_definition] = STATE(91),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5159),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(91),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(91),
    [sym_labeled_statement] = STATE(91),
    [sym_expression_statement] = STATE(91),
    [sym_if_statement] = STATE(91),
    [sym_switch_statement] = STATE(91),
    [sym_while_statement] = STATE(91),
    [sym_do_statement] = STATE(91),
    [sym_for_statement] = STATE(91),
    [sym_return_statement] = STATE(91),
    [sym_break_statement] = STATE(91),
    [sym_continue_statement] = STATE(91),
    [sym_goto_statement] = STATE(91),
    [sym_seh_try_statement] = STATE(91),
    [sym_seh_leave_statement] = STATE(91),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(91),
    [sym_co_return_statement] = STATE(91),
    [sym_co_yield_statement] = STATE(91),
    [sym_throw_statement] = STATE(91),
    [sym_try_statement] = STATE(91),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(91),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(91),
    [sym_hlsl_attribute] = STATE(7796),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(91),
    [sym_identifier] = ACTIONS(1473),
    [aux_sym_preproc_include_token1] = ACTIONS(1469),
    [aux_sym_preproc_def_token1] = ACTIONS(1469),
    [aux_sym_preproc_if_token1] = ACTIONS(1469),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1469),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1469),
    [sym_preproc_directive] = ACTIONS(1469),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP_AMP] = ACTIONS(1471),
    [anon_sym_AMP] = ACTIONS(1258),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym___extension__] = ACTIONS(177),
    [anon_sym_typedef] = ACTIONS(179),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(1469),
    [anon_sym___cdecl] = ACTIONS(1469),
    [anon_sym___clrcall] = ACTIONS(1469),
    [anon_sym___stdcall] = ACTIONS(1469),
    [anon_sym___fastcall] = ACTIONS(1469),
    [anon_sym___thiscall] = ACTIONS(1469),
    [anon_sym___vectorcall] = ACTIONS(1469),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_RBRACE] = ACTIONS(1471),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_else] = ACTIONS(1469),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(1469),
    [anon_sym_default] = ACTIONS(1469),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_explicit] = ACTIONS(1469),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(1469),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_namespace] = ACTIONS(1469),
    [anon_sym_using] = ACTIONS(1469),
    [anon_sym_static_assert] = ACTIONS(1469),
    [anon_sym_concept] = ACTIONS(1469),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [100] = {
    [sym_declaration] = STATE(101),
    [sym_type_definition] = STATE(101),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5181),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(101),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(101),
    [sym_labeled_statement] = STATE(101),
    [sym_expression_statement] = STATE(101),
    [sym_if_statement] = STATE(101),
    [sym_switch_statement] = STATE(101),
    [sym_while_statement] = STATE(101),
    [sym_do_statement] = STATE(101),
    [sym_for_statement] = STATE(101),
    [sym_return_statement] = STATE(101),
    [sym_break_statement] = STATE(101),
    [sym_continue_statement] = STATE(101),
    [sym_goto_statement] = STATE(101),
    [sym_seh_try_statement] = STATE(101),
    [sym_seh_leave_statement] = STATE(101),
    [sym_expression] = STATE(4525),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8558),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(101),
    [sym_co_return_statement] = STATE(101),
    [sym_co_yield_statement] = STATE(101),
    [sym_throw_statement] = STATE(101),
    [sym_try_statement] = STATE(101),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(101),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(101),
    [sym_hlsl_attribute] = STATE(7458),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(840),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(101),
    [ts_builtin_sym_end] = ACTIONS(1471),
    [sym_identifier] = ACTIONS(1475),
    [aux_sym_preproc_include_token1] = ACTIONS(1469),
    [aux_sym_preproc_def_token1] = ACTIONS(1469),
    [aux_sym_preproc_if_token1] = ACTIONS(1469),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1469),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1469),
    [sym_preproc_directive] = ACTIONS(1469),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP_AMP] = ACTIONS(1471),
    [anon_sym_AMP] = ACTIONS(1258),
    [anon_sym_SEMI] = ACTIONS(1477),
    [anon_sym___extension__] = ACTIONS(33),
    [anon_sym_typedef] = ACTIONS(35),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(1469),
    [anon_sym___cdecl] = ACTIONS(1469),
    [anon_sym___clrcall] = ACTIONS(1469),
    [anon_sym___stdcall] = ACTIONS(1469),
    [anon_sym___fastcall] = ACTIONS(1469),
    [anon_sym___thiscall] = ACTIONS(1469),
    [anon_sym___vectorcall] = ACTIONS(1469),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_else] = ACTIONS(1469),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(1469),
    [anon_sym_default] = ACTIONS(1469),
    [anon_sym_while] = ACTIONS(85),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(1479),
    [anon_sym___leave] = ACTIONS(1481),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_explicit] = ACTIONS(1469),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(1469),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_namespace] = ACTIONS(1469),
    [anon_sym_using] = ACTIONS(1469),
    [anon_sym_static_assert] = ACTIONS(1469),
    [anon_sym_concept] = ACTIONS(1469),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1483),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(1485),
  },
  [101] = {
    [sym_declaration] = STATE(101),
    [sym_type_definition] = STATE(101),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5181),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(101),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(101),
    [sym_labeled_statement] = STATE(101),
    [sym_expression_statement] = STATE(101),
    [sym_if_statement] = STATE(101),
    [sym_switch_statement] = STATE(101),
    [sym_while_statement] = STATE(101),
    [sym_do_statement] = STATE(101),
    [sym_for_statement] = STATE(101),
    [sym_return_statement] = STATE(101),
    [sym_break_statement] = STATE(101),
    [sym_continue_statement] = STATE(101),
    [sym_goto_statement] = STATE(101),
    [sym_seh_try_statement] = STATE(101),
    [sym_seh_leave_statement] = STATE(101),
    [sym_expression] = STATE(4525),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8558),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(101),
    [sym_co_return_statement] = STATE(101),
    [sym_co_yield_statement] = STATE(101),
    [sym_throw_statement] = STATE(101),
    [sym_try_statement] = STATE(101),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(101),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(101),
    [sym_hlsl_attribute] = STATE(7458),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(840),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(101),
    [ts_builtin_sym_end] = ACTIONS(1289),
    [sym_identifier] = ACTIONS(1621),
    [aux_sym_preproc_include_token1] = ACTIONS(1275),
    [aux_sym_preproc_def_token1] = ACTIONS(1275),
    [aux_sym_preproc_if_token1] = ACTIONS(1275),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1275),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1275),
    [sym_preproc_directive] = ACTIONS(1275),
    [anon_sym_LPAREN2] = ACTIONS(1277),
    [anon_sym_BANG] = ACTIONS(1280),
    [anon_sym_TILDE] = ACTIONS(1280),
    [anon_sym_DASH] = ACTIONS(1283),
    [anon_sym_PLUS] = ACTIONS(1283),
    [anon_sym_STAR] = ACTIONS(1286),
    [anon_sym_AMP_AMP] = ACTIONS(1289),
    [anon_sym_AMP] = ACTIONS(1291),
    [anon_sym_SEMI] = ACTIONS(1624),
    [anon_sym___extension__] = ACTIONS(1627),
    [anon_sym_typedef] = ACTIONS(1630),
    [anon_sym_in] = ACTIONS(1303),
    [anon_sym_out] = ACTIONS(1303),
    [anon_sym_inout] = ACTIONS(1303),
    [anon_sym_extern] = ACTIONS(1306),
    [anon_sym___attribute__] = ACTIONS(1309),
    [anon_sym_COLON_COLON] = ACTIONS(1312),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1315),
    [anon_sym___declspec] = ACTIONS(1318),
    [anon_sym___based] = ACTIONS(1275),
    [anon_sym___cdecl] = ACTIONS(1275),
    [anon_sym___clrcall] = ACTIONS(1275),
    [anon_sym___stdcall] = ACTIONS(1275),
    [anon_sym___fastcall] = ACTIONS(1275),
    [anon_sym___thiscall] = ACTIONS(1275),
    [anon_sym___vectorcall] = ACTIONS(1275),
    [anon_sym_LBRACE] = ACTIONS(1633),
    [anon_sym_signed] = ACTIONS(1324),
    [anon_sym_unsigned] = ACTIONS(1324),
    [anon_sym_long] = ACTIONS(1324),
    [anon_sym_short] = ACTIONS(1324),
    [anon_sym_LBRACK] = ACTIONS(1327),
    [anon_sym_static] = ACTIONS(1306),
    [anon_sym_register] = ACTIONS(1306),
    [anon_sym_inline] = ACTIONS(1306),
    [anon_sym___inline] = ACTIONS(1306),
    [anon_sym___inline__] = ACTIONS(1306),
    [anon_sym___forceinline] = ACTIONS(1306),
    [anon_sym_thread_local] = ACTIONS(1306),
    [anon_sym___thread] = ACTIONS(1306),
    [anon_sym_const] = ACTIONS(1330),
    [anon_sym_constexpr] = ACTIONS(1330),
    [anon_sym_volatile] = ACTIONS(1330),
    [anon_sym_restrict] = ACTIONS(1330),
    [anon_sym___restrict__] = ACTIONS(1330),
    [anon_sym__Atomic] = ACTIONS(1330),
    [anon_sym__Noreturn] = ACTIONS(1330),
    [anon_sym_noreturn] = ACTIONS(1330),
    [anon_sym_mutable] = ACTIONS(1330),
    [anon_sym_constinit] = ACTIONS(1330),
    [anon_sym_consteval] = ACTIONS(1330),
    [anon_sym_alignas] = ACTIONS(1333),
    [anon_sym__Alignas] = ACTIONS(1333),
    [sym_primitive_type] = ACTIONS(1336),
    [anon_sym_enum] = ACTIONS(1339),
    [anon_sym_class] = ACTIONS(1342),
    [anon_sym_struct] = ACTIONS(1345),
    [anon_sym_union] = ACTIONS(1348),
    [anon_sym_if] = ACTIONS(1636),
    [anon_sym_else] = ACTIONS(1275),
    [anon_sym_switch] = ACTIONS(1639),
    [anon_sym_case] = ACTIONS(1275),
    [anon_sym_default] = ACTIONS(1275),
    [anon_sym_while] = ACTIONS(1642),
    [anon_sym_do] = ACTIONS(1645),
    [anon_sym_for] = ACTIONS(1648),
    [anon_sym_return] = ACTIONS(1651),
    [anon_sym_break] = ACTIONS(1654),
    [anon_sym_continue] = ACTIONS(1657),
    [anon_sym_goto] = ACTIONS(1660),
    [anon_sym___try] = ACTIONS(1663),
    [anon_sym___leave] = ACTIONS(1666),
    [anon_sym_not] = ACTIONS(1283),
    [anon_sym_compl] = ACTIONS(1283),
    [anon_sym_DASH_DASH] = ACTIONS(1384),
    [anon_sym_PLUS_PLUS] = ACTIONS(1384),
    [anon_sym_sizeof] = ACTIONS(1387),
    [anon_sym___alignof__] = ACTIONS(1390),
    [anon_sym___alignof] = ACTIONS(1390),
    [anon_sym__alignof] = ACTIONS(1390),
    [anon_sym_alignof] = ACTIONS(1390),
    [anon_sym__Alignof] = ACTIONS(1390),
    [anon_sym_offsetof] = ACTIONS(1393),
    [anon_sym__Generic] = ACTIONS(1396),
    [anon_sym_asm] = ACTIONS(1399),
    [anon_sym___asm__] = ACTIONS(1399),
    [sym_number_literal] = ACTIONS(1402),
    [anon_sym_L_SQUOTE] = ACTIONS(1405),
    [anon_sym_u_SQUOTE] = ACTIONS(1405),
    [anon_sym_U_SQUOTE] = ACTIONS(1405),
    [anon_sym_u8_SQUOTE] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1405),
    [anon_sym_L_DQUOTE] = ACTIONS(1408),
    [anon_sym_u_DQUOTE] = ACTIONS(1408),
    [anon_sym_U_DQUOTE] = ACTIONS(1408),
    [anon_sym_u8_DQUOTE] = ACTIONS(1408),
    [anon_sym_DQUOTE] = ACTIONS(1408),
    [sym_true] = ACTIONS(1411),
    [sym_false] = ACTIONS(1411),
    [anon_sym_NULL] = ACTIONS(1414),
    [anon_sym_nullptr] = ACTIONS(1414),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1417),
    [anon_sym_decltype] = ACTIONS(1420),
    [sym_virtual] = ACTIONS(1303),
    [anon_sym_explicit] = ACTIONS(1275),
    [anon_sym_typename] = ACTIONS(1423),
    [anon_sym_template] = ACTIONS(1426),
    [anon_sym_operator] = ACTIONS(1275),
    [anon_sym_try] = ACTIONS(1669),
    [anon_sym_delete] = ACTIONS(1432),
    [anon_sym_throw] = ACTIONS(1672),
    [anon_sym_namespace] = ACTIONS(1275),
    [anon_sym_using] = ACTIONS(1275),
    [anon_sym_static_assert] = ACTIONS(1275),
    [anon_sym_concept] = ACTIONS(1275),
    [anon_sym_co_return] = ACTIONS(1675),
    [anon_sym_co_yield] = ACTIONS(1678),
    [anon_sym_R_DQUOTE] = ACTIONS(1444),
    [anon_sym_LR_DQUOTE] = ACTIONS(1444),
    [anon_sym_uR_DQUOTE] = ACTIONS(1444),
    [anon_sym_UR_DQUOTE] = ACTIONS(1444),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1444),
    [anon_sym_co_await] = ACTIONS(1447),
    [anon_sym_new] = ACTIONS(1450),
    [anon_sym_requires] = ACTIONS(1453),
    [sym_this] = ACTIONS(1411),
    [anon_sym_discard] = ACTIONS(1681),
    [anon_sym_precise] = ACTIONS(1459),
    [anon_sym_shared] = ACTIONS(1459),
    [anon_sym_groupshared] = ACTIONS(1459),
    [anon_sym_uniform] = ACTIONS(1459),
    [anon_sym_row_major] = ACTIONS(1459),
    [anon_sym_column_major] = ACTIONS(1459),
    [anon_sym_globallycoherent] = ACTIONS(1459),
    [anon_sym_centroid] = ACTIONS(1459),
    [anon_sym_noperspective] = ACTIONS(1459),
    [anon_sym_nointerpolation] = ACTIONS(1459),
    [anon_sym_sample] = ACTIONS(1459),
    [anon_sym_linear] = ACTIONS(1459),
    [anon_sym_snorm] = ACTIONS(1459),
    [anon_sym_unorm] = ACTIONS(1459),
    [anon_sym_point] = ACTIONS(1459),
    [anon_sym_line] = ACTIONS(1459),
    [anon_sym_triangleadj] = ACTIONS(1459),
    [anon_sym_lineadj] = ACTIONS(1459),
    [anon_sym_triangle] = ACTIONS(1459),
    [anon_sym_cbuffer] = ACTIONS(1684),
  },
  [102] = {
    [sym_declaration] = STATE(104),
    [sym_type_definition] = STATE(104),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5068),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(104),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(104),
    [sym_labeled_statement] = STATE(104),
    [sym_expression_statement] = STATE(104),
    [sym_if_statement] = STATE(104),
    [sym_switch_statement] = STATE(104),
    [sym_while_statement] = STATE(104),
    [sym_do_statement] = STATE(104),
    [sym_for_statement] = STATE(104),
    [sym_return_statement] = STATE(104),
    [sym_break_statement] = STATE(104),
    [sym_continue_statement] = STATE(104),
    [sym_goto_statement] = STATE(104),
    [sym_seh_try_statement] = STATE(104),
    [sym_seh_leave_statement] = STATE(104),
    [sym_expression] = STATE(4514),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8003),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(104),
    [sym_co_return_statement] = STATE(104),
    [sym_co_yield_statement] = STATE(104),
    [sym_throw_statement] = STATE(104),
    [sym_try_statement] = STATE(104),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(104),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(104),
    [sym_hlsl_attribute] = STATE(7744),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(875),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(104),
    [sym_identifier] = ACTIONS(1687),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym___extension__] = ACTIONS(1691),
    [anon_sym_typedef] = ACTIONS(1693),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_LBRACE] = ACTIONS(1695),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(1697),
    [anon_sym_else] = ACTIONS(1469),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1701),
    [anon_sym_do] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1705),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1709),
    [anon_sym_continue] = ACTIONS(1711),
    [anon_sym_goto] = ACTIONS(1713),
    [anon_sym___try] = ACTIONS(1715),
    [anon_sym___leave] = ACTIONS(1717),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1719),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(1721),
    [anon_sym_co_return] = ACTIONS(1723),
    [anon_sym_co_yield] = ACTIONS(1725),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1727),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(1729),
  },
  [103] = {
    [sym_declaration] = STATE(105),
    [sym_type_definition] = STATE(105),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5068),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(105),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(105),
    [sym_labeled_statement] = STATE(105),
    [sym_expression_statement] = STATE(105),
    [sym_if_statement] = STATE(105),
    [sym_switch_statement] = STATE(105),
    [sym_while_statement] = STATE(105),
    [sym_do_statement] = STATE(105),
    [sym_for_statement] = STATE(105),
    [sym_return_statement] = STATE(105),
    [sym_break_statement] = STATE(105),
    [sym_continue_statement] = STATE(105),
    [sym_goto_statement] = STATE(105),
    [sym_seh_try_statement] = STATE(105),
    [sym_seh_leave_statement] = STATE(105),
    [sym_expression] = STATE(4514),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8003),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(105),
    [sym_co_return_statement] = STATE(105),
    [sym_co_yield_statement] = STATE(105),
    [sym_throw_statement] = STATE(105),
    [sym_try_statement] = STATE(105),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(105),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(105),
    [sym_hlsl_attribute] = STATE(7744),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(875),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(105),
    [sym_identifier] = ACTIONS(1687),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym___extension__] = ACTIONS(1691),
    [anon_sym_typedef] = ACTIONS(1693),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_LBRACE] = ACTIONS(1695),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(1697),
    [anon_sym_else] = ACTIONS(1465),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1701),
    [anon_sym_do] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1705),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1709),
    [anon_sym_continue] = ACTIONS(1711),
    [anon_sym_goto] = ACTIONS(1713),
    [anon_sym___try] = ACTIONS(1715),
    [anon_sym___leave] = ACTIONS(1717),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1719),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(1721),
    [anon_sym_co_return] = ACTIONS(1723),
    [anon_sym_co_yield] = ACTIONS(1725),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1727),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(1729),
  },
  [104] = {
    [sym_declaration] = STATE(104),
    [sym_type_definition] = STATE(104),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5068),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(104),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(104),
    [sym_labeled_statement] = STATE(104),
    [sym_expression_statement] = STATE(104),
    [sym_if_statement] = STATE(104),
    [sym_switch_statement] = STATE(104),
    [sym_while_statement] = STATE(104),
    [sym_do_statement] = STATE(104),
    [sym_for_statement] = STATE(104),
    [sym_return_statement] = STATE(104),
    [sym_break_statement] = STATE(104),
    [sym_continue_statement] = STATE(104),
    [sym_goto_statement] = STATE(104),
    [sym_seh_try_statement] = STATE(104),
    [sym_seh_leave_statement] = STATE(104),
    [sym_expression] = STATE(4514),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8003),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(104),
    [sym_co_return_statement] = STATE(104),
    [sym_co_yield_statement] = STATE(104),
    [sym_throw_statement] = STATE(104),
    [sym_try_statement] = STATE(104),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(104),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(104),
    [sym_hlsl_attribute] = STATE(7744),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(875),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(104),
    [sym_identifier] = ACTIONS(1731),
    [anon_sym_LPAREN2] = ACTIONS(1277),
    [anon_sym_BANG] = ACTIONS(1280),
    [anon_sym_TILDE] = ACTIONS(1280),
    [anon_sym_DASH] = ACTIONS(1283),
    [anon_sym_PLUS] = ACTIONS(1283),
    [anon_sym_STAR] = ACTIONS(1286),
    [anon_sym_AMP] = ACTIONS(1286),
    [anon_sym_SEMI] = ACTIONS(1734),
    [anon_sym___extension__] = ACTIONS(1737),
    [anon_sym_typedef] = ACTIONS(1740),
    [anon_sym_in] = ACTIONS(1303),
    [anon_sym_out] = ACTIONS(1303),
    [anon_sym_inout] = ACTIONS(1303),
    [anon_sym_extern] = ACTIONS(1306),
    [anon_sym___attribute__] = ACTIONS(1309),
    [anon_sym_COLON_COLON] = ACTIONS(1312),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1315),
    [anon_sym___declspec] = ACTIONS(1318),
    [anon_sym_LBRACE] = ACTIONS(1743),
    [anon_sym_signed] = ACTIONS(1324),
    [anon_sym_unsigned] = ACTIONS(1324),
    [anon_sym_long] = ACTIONS(1324),
    [anon_sym_short] = ACTIONS(1324),
    [anon_sym_LBRACK] = ACTIONS(1327),
    [anon_sym_static] = ACTIONS(1306),
    [anon_sym_register] = ACTIONS(1306),
    [anon_sym_inline] = ACTIONS(1306),
    [anon_sym___inline] = ACTIONS(1306),
    [anon_sym___inline__] = ACTIONS(1306),
    [anon_sym___forceinline] = ACTIONS(1306),
    [anon_sym_thread_local] = ACTIONS(1306),
    [anon_sym___thread] = ACTIONS(1306),
    [anon_sym_const] = ACTIONS(1330),
    [anon_sym_constexpr] = ACTIONS(1330),
    [anon_sym_volatile] = ACTIONS(1330),
    [anon_sym_restrict] = ACTIONS(1330),
    [anon_sym___restrict__] = ACTIONS(1330),
    [anon_sym__Atomic] = ACTIONS(1330),
    [anon_sym__Noreturn] = ACTIONS(1330),
    [anon_sym_noreturn] = ACTIONS(1330),
    [anon_sym_mutable] = ACTIONS(1330),
    [anon_sym_constinit] = ACTIONS(1330),
    [anon_sym_consteval] = ACTIONS(1330),
    [anon_sym_alignas] = ACTIONS(1333),
    [anon_sym__Alignas] = ACTIONS(1333),
    [sym_primitive_type] = ACTIONS(1336),
    [anon_sym_enum] = ACTIONS(1339),
    [anon_sym_class] = ACTIONS(1342),
    [anon_sym_struct] = ACTIONS(1345),
    [anon_sym_union] = ACTIONS(1348),
    [anon_sym_if] = ACTIONS(1746),
    [anon_sym_else] = ACTIONS(1275),
    [anon_sym_switch] = ACTIONS(1749),
    [anon_sym_while] = ACTIONS(1752),
    [anon_sym_do] = ACTIONS(1755),
    [anon_sym_for] = ACTIONS(1758),
    [anon_sym_return] = ACTIONS(1761),
    [anon_sym_break] = ACTIONS(1764),
    [anon_sym_continue] = ACTIONS(1767),
    [anon_sym_goto] = ACTIONS(1770),
    [anon_sym___try] = ACTIONS(1773),
    [anon_sym___leave] = ACTIONS(1776),
    [anon_sym_not] = ACTIONS(1283),
    [anon_sym_compl] = ACTIONS(1283),
    [anon_sym_DASH_DASH] = ACTIONS(1384),
    [anon_sym_PLUS_PLUS] = ACTIONS(1384),
    [anon_sym_sizeof] = ACTIONS(1387),
    [anon_sym___alignof__] = ACTIONS(1390),
    [anon_sym___alignof] = ACTIONS(1390),
    [anon_sym__alignof] = ACTIONS(1390),
    [anon_sym_alignof] = ACTIONS(1390),
    [anon_sym__Alignof] = ACTIONS(1390),
    [anon_sym_offsetof] = ACTIONS(1393),
    [anon_sym__Generic] = ACTIONS(1396),
    [anon_sym_asm] = ACTIONS(1399),
    [anon_sym___asm__] = ACTIONS(1399),
    [sym_number_literal] = ACTIONS(1402),
    [anon_sym_L_SQUOTE] = ACTIONS(1405),
    [anon_sym_u_SQUOTE] = ACTIONS(1405),
    [anon_sym_U_SQUOTE] = ACTIONS(1405),
    [anon_sym_u8_SQUOTE] = ACTIONS(1405),
    [anon_sym_SQUOTE] = ACTIONS(1405),
    [anon_sym_L_DQUOTE] = ACTIONS(1408),
    [anon_sym_u_DQUOTE] = ACTIONS(1408),
    [anon_sym_U_DQUOTE] = ACTIONS(1408),
    [anon_sym_u8_DQUOTE] = ACTIONS(1408),
    [anon_sym_DQUOTE] = ACTIONS(1408),
    [sym_true] = ACTIONS(1411),
    [sym_false] = ACTIONS(1411),
    [anon_sym_NULL] = ACTIONS(1414),
    [anon_sym_nullptr] = ACTIONS(1414),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1417),
    [anon_sym_decltype] = ACTIONS(1420),
    [sym_virtual] = ACTIONS(1303),
    [anon_sym_typename] = ACTIONS(1423),
    [anon_sym_template] = ACTIONS(1426),
    [anon_sym_try] = ACTIONS(1779),
    [anon_sym_delete] = ACTIONS(1432),
    [anon_sym_throw] = ACTIONS(1782),
    [anon_sym_co_return] = ACTIONS(1785),
    [anon_sym_co_yield] = ACTIONS(1788),
    [anon_sym_R_DQUOTE] = ACTIONS(1444),
    [anon_sym_LR_DQUOTE] = ACTIONS(1444),
    [anon_sym_uR_DQUOTE] = ACTIONS(1444),
    [anon_sym_UR_DQUOTE] = ACTIONS(1444),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1444),
    [anon_sym_co_await] = ACTIONS(1447),
    [anon_sym_new] = ACTIONS(1450),
    [anon_sym_requires] = ACTIONS(1453),
    [sym_this] = ACTIONS(1411),
    [anon_sym_discard] = ACTIONS(1791),
    [anon_sym_precise] = ACTIONS(1459),
    [anon_sym_shared] = ACTIONS(1459),
    [anon_sym_groupshared] = ACTIONS(1459),
    [anon_sym_uniform] = ACTIONS(1459),
    [anon_sym_row_major] = ACTIONS(1459),
    [anon_sym_column_major] = ACTIONS(1459),
    [anon_sym_globallycoherent] = ACTIONS(1459),
    [anon_sym_centroid] = ACTIONS(1459),
    [anon_sym_noperspective] = ACTIONS(1459),
    [anon_sym_nointerpolation] = ACTIONS(1459),
    [anon_sym_sample] = ACTIONS(1459),
    [anon_sym_linear] = ACTIONS(1459),
    [anon_sym_snorm] = ACTIONS(1459),
    [anon_sym_unorm] = ACTIONS(1459),
    [anon_sym_point] = ACTIONS(1459),
    [anon_sym_line] = ACTIONS(1459),
    [anon_sym_triangleadj] = ACTIONS(1459),
    [anon_sym_lineadj] = ACTIONS(1459),
    [anon_sym_triangle] = ACTIONS(1459),
    [anon_sym_cbuffer] = ACTIONS(1794),
  },
  [105] = {
    [sym_declaration] = STATE(104),
    [sym_type_definition] = STATE(104),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5068),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(104),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(104),
    [sym_labeled_statement] = STATE(104),
    [sym_expression_statement] = STATE(104),
    [sym_if_statement] = STATE(104),
    [sym_switch_statement] = STATE(104),
    [sym_while_statement] = STATE(104),
    [sym_do_statement] = STATE(104),
    [sym_for_statement] = STATE(104),
    [sym_return_statement] = STATE(104),
    [sym_break_statement] = STATE(104),
    [sym_continue_statement] = STATE(104),
    [sym_goto_statement] = STATE(104),
    [sym_seh_try_statement] = STATE(104),
    [sym_seh_leave_statement] = STATE(104),
    [sym_expression] = STATE(4514),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8003),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(104),
    [sym_co_return_statement] = STATE(104),
    [sym_co_yield_statement] = STATE(104),
    [sym_throw_statement] = STATE(104),
    [sym_try_statement] = STATE(104),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(104),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(104),
    [sym_hlsl_attribute] = STATE(7744),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(875),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(104),
    [sym_identifier] = ACTIONS(1687),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym___extension__] = ACTIONS(1691),
    [anon_sym_typedef] = ACTIONS(1693),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_LBRACE] = ACTIONS(1695),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(1697),
    [anon_sym_else] = ACTIONS(1250),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1701),
    [anon_sym_do] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1705),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1709),
    [anon_sym_continue] = ACTIONS(1711),
    [anon_sym_goto] = ACTIONS(1713),
    [anon_sym___try] = ACTIONS(1715),
    [anon_sym___leave] = ACTIONS(1717),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1719),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(1721),
    [anon_sym_co_return] = ACTIONS(1723),
    [anon_sym_co_yield] = ACTIONS(1725),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1727),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(1729),
  },
  [106] = {
    [sym_declaration] = STATE(102),
    [sym_type_definition] = STATE(102),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5068),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1028),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_compound_statement] = STATE(102),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_attributed_statement] = STATE(102),
    [sym_labeled_statement] = STATE(102),
    [sym_expression_statement] = STATE(102),
    [sym_if_statement] = STATE(102),
    [sym_switch_statement] = STATE(102),
    [sym_while_statement] = STATE(102),
    [sym_do_statement] = STATE(102),
    [sym_for_statement] = STATE(102),
    [sym_return_statement] = STATE(102),
    [sym_break_statement] = STATE(102),
    [sym_continue_statement] = STATE(102),
    [sym_goto_statement] = STATE(102),
    [sym_seh_try_statement] = STATE(102),
    [sym_seh_leave_statement] = STATE(102),
    [sym_expression] = STATE(4514),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8003),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(102),
    [sym_co_return_statement] = STATE(102),
    [sym_co_yield_statement] = STATE(102),
    [sym_throw_statement] = STATE(102),
    [sym_try_statement] = STATE(102),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(102),
    [sym_qualifiers] = STATE(1979),
    [sym_cbuffer_specifier] = STATE(102),
    [sym_hlsl_attribute] = STATE(7744),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_attributed_declarator_repeat1] = STATE(875),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_case_statement_repeat1] = STATE(102),
    [sym_identifier] = ACTIONS(1687),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym___extension__] = ACTIONS(1691),
    [anon_sym_typedef] = ACTIONS(1693),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_LBRACE] = ACTIONS(1695),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(1697),
    [anon_sym_else] = ACTIONS(1268),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1701),
    [anon_sym_do] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1705),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1709),
    [anon_sym_continue] = ACTIONS(1711),
    [anon_sym_goto] = ACTIONS(1713),
    [anon_sym___try] = ACTIONS(1715),
    [anon_sym___leave] = ACTIONS(1717),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1719),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(1721),
    [anon_sym_co_return] = ACTIONS(1723),
    [anon_sym_co_yield] = ACTIONS(1725),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1727),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
    [anon_sym_cbuffer] = ACTIONS(1729),
  },
  [107] = {
    [sym_declaration] = STATE(538),
    [sym_type_definition] = STATE(2632),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5178),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_expression_statement] = STATE(2632),
    [sym__for_statement_body] = STATE(7937),
    [sym_expression] = STATE(4493),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7951),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_alias_declaration] = STATE(2632),
    [sym__for_range_loop_body] = STATE(7938),
    [sym_init_statement] = STATE(1942),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(1797),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1799),
    [anon_sym___extension__] = ACTIONS(1801),
    [anon_sym_typedef] = ACTIONS(1803),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_using] = ACTIONS(1809),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [108] = {
    [sym_declaration] = STATE(538),
    [sym_type_definition] = STATE(2632),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5178),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_expression_statement] = STATE(2632),
    [sym__for_statement_body] = STATE(8428),
    [sym_expression] = STATE(4493),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7951),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_alias_declaration] = STATE(2632),
    [sym__for_range_loop_body] = STATE(8427),
    [sym_init_statement] = STATE(1942),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(1797),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1799),
    [anon_sym___extension__] = ACTIONS(1801),
    [anon_sym_typedef] = ACTIONS(1803),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_using] = ACTIONS(1809),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [109] = {
    [sym_declaration] = STATE(538),
    [sym_type_definition] = STATE(2632),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5178),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_expression_statement] = STATE(2632),
    [sym__for_statement_body] = STATE(8194),
    [sym_expression] = STATE(4493),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7951),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_alias_declaration] = STATE(2632),
    [sym__for_range_loop_body] = STATE(8107),
    [sym_init_statement] = STATE(1942),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(1797),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1799),
    [anon_sym___extension__] = ACTIONS(1801),
    [anon_sym_typedef] = ACTIONS(1803),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_using] = ACTIONS(1809),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [110] = {
    [sym_declaration] = STATE(538),
    [sym_type_definition] = STATE(2632),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5178),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_expression_statement] = STATE(2632),
    [sym__for_statement_body] = STATE(7841),
    [sym_expression] = STATE(4493),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7951),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_alias_declaration] = STATE(2632),
    [sym__for_range_loop_body] = STATE(7847),
    [sym_init_statement] = STATE(1942),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(1797),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1799),
    [anon_sym___extension__] = ACTIONS(1801),
    [anon_sym_typedef] = ACTIONS(1803),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_using] = ACTIONS(1809),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [111] = {
    [sym_declaration] = STATE(538),
    [sym_type_definition] = STATE(2632),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5178),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_expression_statement] = STATE(2632),
    [sym__for_statement_body] = STATE(7944),
    [sym_expression] = STATE(4493),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7951),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_alias_declaration] = STATE(2632),
    [sym__for_range_loop_body] = STATE(7955),
    [sym_init_statement] = STATE(1942),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(1797),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1799),
    [anon_sym___extension__] = ACTIONS(1801),
    [anon_sym_typedef] = ACTIONS(1803),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_using] = ACTIONS(1809),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [112] = {
    [sym_declaration] = STATE(538),
    [sym_type_definition] = STATE(2632),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5178),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_expression_statement] = STATE(2632),
    [sym__for_statement_body] = STATE(8547),
    [sym_expression] = STATE(4493),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7951),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_alias_declaration] = STATE(2632),
    [sym__for_range_loop_body] = STATE(8545),
    [sym_init_statement] = STATE(1942),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(1797),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1799),
    [anon_sym___extension__] = ACTIONS(1801),
    [anon_sym_typedef] = ACTIONS(1803),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_using] = ACTIONS(1809),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [113] = {
    [sym_declaration] = STATE(1115),
    [sym_type_definition] = STATE(1115),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5188),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_expression_statement] = STATE(1115),
    [sym_expression] = STATE(4383),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7787),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_alias_declaration] = STATE(1115),
    [sym_init_statement] = STATE(127),
    [sym_condition_declaration] = STATE(7930),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(1797),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym___extension__] = ACTIONS(1691),
    [anon_sym_typedef] = ACTIONS(1693),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_using] = ACTIONS(1811),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [114] = {
    [sym__declaration_modifiers] = STATE(1984),
    [sym__declaration_specifiers] = STATE(4097),
    [sym_attribute_specifier] = STATE(1984),
    [sym_attribute_declaration] = STATE(1984),
    [sym_ms_declspec_modifier] = STATE(1984),
    [sym_storage_class_specifier] = STATE(1984),
    [sym_type_qualifier] = STATE(1984),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_parameter_declaration] = STATE(7092),
    [sym_expression] = STATE(3430),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7818),
    [sym_dependent_type] = STATE(2277),
    [sym_optional_parameter_declaration] = STATE(7092),
    [sym_variadic_parameter_declaration] = STATE(7092),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym__unary_left_fold] = STATE(8570),
    [sym__unary_right_fold] = STATE(8567),
    [sym__binary_fold] = STATE(8566),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5639),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3537),
    [sym_qualifiers] = STATE(1984),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1984),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(1813),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_RPAREN] = ACTIONS(1817),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1827),
    [anon_sym_out] = ACTIONS(1827),
    [anon_sym_inout] = ACTIONS(1827),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(1831),
    [anon_sym_enum] = ACTIONS(1833),
    [anon_sym_class] = ACTIONS(1835),
    [anon_sym_struct] = ACTIONS(1837),
    [anon_sym_union] = ACTIONS(1839),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1827),
    [anon_sym_typename] = ACTIONS(1863),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [115] = {
    [sym__declaration_modifiers] = STATE(1984),
    [sym__declaration_specifiers] = STATE(4097),
    [sym_attribute_specifier] = STATE(1984),
    [sym_attribute_declaration] = STATE(1984),
    [sym_ms_declspec_modifier] = STATE(1984),
    [sym_storage_class_specifier] = STATE(1984),
    [sym_type_qualifier] = STATE(1984),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_parameter_declaration] = STATE(7092),
    [sym_expression] = STATE(3373),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7818),
    [sym_dependent_type] = STATE(2277),
    [sym_optional_parameter_declaration] = STATE(7092),
    [sym_variadic_parameter_declaration] = STATE(7092),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym__unary_left_fold] = STATE(8551),
    [sym__unary_right_fold] = STATE(8550),
    [sym__binary_fold] = STATE(8549),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5639),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3537),
    [sym_qualifiers] = STATE(1984),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1984),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(1813),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_RPAREN] = ACTIONS(1817),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1827),
    [anon_sym_out] = ACTIONS(1827),
    [anon_sym_inout] = ACTIONS(1827),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(1831),
    [anon_sym_enum] = ACTIONS(1833),
    [anon_sym_class] = ACTIONS(1835),
    [anon_sym_struct] = ACTIONS(1837),
    [anon_sym_union] = ACTIONS(1839),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1827),
    [anon_sym_typename] = ACTIONS(1863),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [116] = {
    [sym__declaration_modifiers] = STATE(1984),
    [sym__declaration_specifiers] = STATE(4097),
    [sym_attribute_specifier] = STATE(1984),
    [sym_attribute_declaration] = STATE(1984),
    [sym_ms_declspec_modifier] = STATE(1984),
    [sym_storage_class_specifier] = STATE(1984),
    [sym_type_qualifier] = STATE(1984),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_parameter_declaration] = STATE(7092),
    [sym_expression] = STATE(3414),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7818),
    [sym_dependent_type] = STATE(2277),
    [sym_optional_parameter_declaration] = STATE(7092),
    [sym_variadic_parameter_declaration] = STATE(7092),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym__unary_left_fold] = STATE(7995),
    [sym__unary_right_fold] = STATE(7997),
    [sym__binary_fold] = STATE(7999),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5639),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3537),
    [sym_qualifiers] = STATE(1984),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1984),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(1813),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_RPAREN] = ACTIONS(1817),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1827),
    [anon_sym_out] = ACTIONS(1827),
    [anon_sym_inout] = ACTIONS(1827),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(1831),
    [anon_sym_enum] = ACTIONS(1833),
    [anon_sym_class] = ACTIONS(1835),
    [anon_sym_struct] = ACTIONS(1837),
    [anon_sym_union] = ACTIONS(1839),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1827),
    [anon_sym_typename] = ACTIONS(1863),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [117] = {
    [sym__declaration_modifiers] = STATE(1984),
    [sym__declaration_specifiers] = STATE(4097),
    [sym_attribute_specifier] = STATE(1984),
    [sym_attribute_declaration] = STATE(1984),
    [sym_ms_declspec_modifier] = STATE(1984),
    [sym_storage_class_specifier] = STATE(1984),
    [sym_type_qualifier] = STATE(1984),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_parameter_declaration] = STATE(7092),
    [sym_expression] = STATE(3447),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7818),
    [sym_dependent_type] = STATE(2277),
    [sym_optional_parameter_declaration] = STATE(7092),
    [sym_variadic_parameter_declaration] = STATE(7092),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym__unary_left_fold] = STATE(8027),
    [sym__unary_right_fold] = STATE(8025),
    [sym__binary_fold] = STATE(8021),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5639),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3537),
    [sym_qualifiers] = STATE(1984),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1984),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(1813),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_RPAREN] = ACTIONS(1817),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1827),
    [anon_sym_out] = ACTIONS(1827),
    [anon_sym_inout] = ACTIONS(1827),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(1831),
    [anon_sym_enum] = ACTIONS(1833),
    [anon_sym_class] = ACTIONS(1835),
    [anon_sym_struct] = ACTIONS(1837),
    [anon_sym_union] = ACTIONS(1839),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1827),
    [anon_sym_typename] = ACTIONS(1863),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [118] = {
    [sym__declaration_modifiers] = STATE(1984),
    [sym__declaration_specifiers] = STATE(4097),
    [sym_attribute_specifier] = STATE(1984),
    [sym_attribute_declaration] = STATE(1984),
    [sym_ms_declspec_modifier] = STATE(1984),
    [sym_storage_class_specifier] = STATE(1984),
    [sym_type_qualifier] = STATE(1984),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_parameter_declaration] = STATE(7092),
    [sym_expression] = STATE(3374),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7818),
    [sym_dependent_type] = STATE(2277),
    [sym_optional_parameter_declaration] = STATE(7092),
    [sym_variadic_parameter_declaration] = STATE(7092),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym__unary_left_fold] = STATE(8259),
    [sym__unary_right_fold] = STATE(8258),
    [sym__binary_fold] = STATE(8257),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5639),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3537),
    [sym_qualifiers] = STATE(1984),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1984),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(1813),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_RPAREN] = ACTIONS(1817),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1827),
    [anon_sym_out] = ACTIONS(1827),
    [anon_sym_inout] = ACTIONS(1827),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(1831),
    [anon_sym_enum] = ACTIONS(1833),
    [anon_sym_class] = ACTIONS(1835),
    [anon_sym_struct] = ACTIONS(1837),
    [anon_sym_union] = ACTIONS(1839),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1827),
    [anon_sym_typename] = ACTIONS(1863),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [119] = {
    [sym__declaration_modifiers] = STATE(1984),
    [sym__declaration_specifiers] = STATE(4097),
    [sym_attribute_specifier] = STATE(1984),
    [sym_attribute_declaration] = STATE(1984),
    [sym_ms_declspec_modifier] = STATE(1984),
    [sym_storage_class_specifier] = STATE(1984),
    [sym_type_qualifier] = STATE(1984),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_parameter_declaration] = STATE(7092),
    [sym_expression] = STATE(3421),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7818),
    [sym_dependent_type] = STATE(2277),
    [sym_optional_parameter_declaration] = STATE(7092),
    [sym_variadic_parameter_declaration] = STATE(7092),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym__unary_left_fold] = STATE(7861),
    [sym__unary_right_fold] = STATE(7859),
    [sym__binary_fold] = STATE(7857),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5639),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3537),
    [sym_qualifiers] = STATE(1984),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1984),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(1813),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_RPAREN] = ACTIONS(1817),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1827),
    [anon_sym_out] = ACTIONS(1827),
    [anon_sym_inout] = ACTIONS(1827),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(1831),
    [anon_sym_enum] = ACTIONS(1833),
    [anon_sym_class] = ACTIONS(1835),
    [anon_sym_struct] = ACTIONS(1837),
    [anon_sym_union] = ACTIONS(1839),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1827),
    [anon_sym_typename] = ACTIONS(1863),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [120] = {
    [sym__declaration_modifiers] = STATE(1984),
    [sym__declaration_specifiers] = STATE(4097),
    [sym_attribute_specifier] = STATE(1984),
    [sym_attribute_declaration] = STATE(1984),
    [sym_ms_declspec_modifier] = STATE(1984),
    [sym_compound_statement] = STATE(7066),
    [sym_storage_class_specifier] = STATE(1984),
    [sym_type_qualifier] = STATE(1984),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_parameter_declaration] = STATE(7178),
    [sym_expression] = STATE(4366),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7066),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_optional_parameter_declaration] = STATE(7178),
    [sym_variadic_parameter_declaration] = STATE(7178),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5607),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_qualifiers] = STATE(1984),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1984),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(1875),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1877),
    [anon_sym_RPAREN] = ACTIONS(1879),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(1881),
    [anon_sym_in] = ACTIONS(1827),
    [anon_sym_out] = ACTIONS(1827),
    [anon_sym_inout] = ACTIONS(1827),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_LBRACE] = ACTIONS(1883),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(1833),
    [anon_sym_class] = ACTIONS(1835),
    [anon_sym_struct] = ACTIONS(1837),
    [anon_sym_union] = ACTIONS(1839),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1827),
    [anon_sym_typename] = ACTIONS(1863),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [121] = {
    [sym_declaration] = STATE(1358),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5135),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__for_statement_body] = STATE(7864),
    [sym_expression] = STATE(4446),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(1797),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1885),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [122] = {
    [sym_declaration] = STATE(1358),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5135),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__for_statement_body] = STATE(8013),
    [sym_expression] = STATE(4446),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(1797),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1885),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [123] = {
    [sym_declaration] = STATE(1358),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5135),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__for_statement_body] = STATE(8297),
    [sym_expression] = STATE(4446),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(1797),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1885),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [124] = {
    [sym_declaration] = STATE(1358),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5135),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__for_statement_body] = STATE(8342),
    [sym_expression] = STATE(4446),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(1797),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1885),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [125] = {
    [sym_declaration] = STATE(1358),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5135),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__for_statement_body] = STATE(8103),
    [sym_expression] = STATE(4446),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(1797),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1885),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [126] = {
    [sym_declaration] = STATE(1358),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5135),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__for_statement_body] = STATE(7963),
    [sym_expression] = STATE(4446),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(1797),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1885),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [127] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5303),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_expression] = STATE(4506),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7985),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2336),
    [sym_template_function] = STATE(4019),
    [sym_condition_declaration] = STATE(7985),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5578),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(2330),
    [sym_user_defined_literal] = STATE(3392),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(1797),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(67),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [128] = {
    [sym_identifier] = ACTIONS(1887),
    [aux_sym_preproc_include_token1] = ACTIONS(1887),
    [aux_sym_preproc_def_token1] = ACTIONS(1887),
    [anon_sym_COMMA] = ACTIONS(1889),
    [anon_sym_RPAREN] = ACTIONS(1889),
    [aux_sym_preproc_if_token1] = ACTIONS(1887),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1887),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1887),
    [sym_preproc_directive] = ACTIONS(1887),
    [anon_sym_LPAREN2] = ACTIONS(1889),
    [anon_sym_BANG] = ACTIONS(1889),
    [anon_sym_TILDE] = ACTIONS(1889),
    [anon_sym_DASH] = ACTIONS(1887),
    [anon_sym_PLUS] = ACTIONS(1887),
    [anon_sym_STAR] = ACTIONS(1889),
    [anon_sym_PIPE_PIPE] = ACTIONS(1889),
    [anon_sym_AMP_AMP] = ACTIONS(1889),
    [anon_sym_AMP] = ACTIONS(1887),
    [anon_sym_COLON] = ACTIONS(1887),
    [anon_sym_SEMI] = ACTIONS(1889),
    [anon_sym___extension__] = ACTIONS(1887),
    [anon_sym_typedef] = ACTIONS(1887),
    [anon_sym_in] = ACTIONS(1887),
    [anon_sym_out] = ACTIONS(1887),
    [anon_sym_inout] = ACTIONS(1887),
    [anon_sym_extern] = ACTIONS(1887),
    [anon_sym___attribute__] = ACTIONS(1887),
    [anon_sym_COLON_COLON] = ACTIONS(1889),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1889),
    [anon_sym___declspec] = ACTIONS(1887),
    [anon_sym___based] = ACTIONS(1887),
    [anon_sym___cdecl] = ACTIONS(1887),
    [anon_sym___clrcall] = ACTIONS(1887),
    [anon_sym___stdcall] = ACTIONS(1887),
    [anon_sym___fastcall] = ACTIONS(1887),
    [anon_sym___thiscall] = ACTIONS(1887),
    [anon_sym___vectorcall] = ACTIONS(1887),
    [anon_sym_LBRACE] = ACTIONS(1889),
    [anon_sym_RBRACE] = ACTIONS(1889),
    [anon_sym_signed] = ACTIONS(1887),
    [anon_sym_unsigned] = ACTIONS(1887),
    [anon_sym_long] = ACTIONS(1887),
    [anon_sym_short] = ACTIONS(1887),
    [anon_sym_LBRACK] = ACTIONS(1887),
    [anon_sym_static] = ACTIONS(1887),
    [anon_sym_EQ] = ACTIONS(1889),
    [anon_sym_register] = ACTIONS(1887),
    [anon_sym_inline] = ACTIONS(1887),
    [anon_sym___inline] = ACTIONS(1887),
    [anon_sym___inline__] = ACTIONS(1887),
    [anon_sym___forceinline] = ACTIONS(1887),
    [anon_sym_thread_local] = ACTIONS(1887),
    [anon_sym___thread] = ACTIONS(1887),
    [anon_sym_const] = ACTIONS(1887),
    [anon_sym_constexpr] = ACTIONS(1887),
    [anon_sym_volatile] = ACTIONS(1887),
    [anon_sym_restrict] = ACTIONS(1887),
    [anon_sym___restrict__] = ACTIONS(1887),
    [anon_sym__Atomic] = ACTIONS(1887),
    [anon_sym__Noreturn] = ACTIONS(1887),
    [anon_sym_noreturn] = ACTIONS(1887),
    [anon_sym_mutable] = ACTIONS(1887),
    [anon_sym_constinit] = ACTIONS(1887),
    [anon_sym_consteval] = ACTIONS(1887),
    [anon_sym_alignas] = ACTIONS(1887),
    [anon_sym__Alignas] = ACTIONS(1887),
    [sym_primitive_type] = ACTIONS(1887),
    [anon_sym_enum] = ACTIONS(1887),
    [anon_sym_class] = ACTIONS(1887),
    [anon_sym_struct] = ACTIONS(1887),
    [anon_sym_union] = ACTIONS(1887),
    [anon_sym_if] = ACTIONS(1887),
    [anon_sym_else] = ACTIONS(1887),
    [anon_sym_switch] = ACTIONS(1887),
    [anon_sym_case] = ACTIONS(1887),
    [anon_sym_default] = ACTIONS(1887),
    [anon_sym_while] = ACTIONS(1887),
    [anon_sym_do] = ACTIONS(1887),
    [anon_sym_for] = ACTIONS(1887),
    [anon_sym_return] = ACTIONS(1887),
    [anon_sym_break] = ACTIONS(1887),
    [anon_sym_continue] = ACTIONS(1887),
    [anon_sym_goto] = ACTIONS(1887),
    [anon_sym___try] = ACTIONS(1887),
    [anon_sym___leave] = ACTIONS(1887),
    [anon_sym_not] = ACTIONS(1887),
    [anon_sym_compl] = ACTIONS(1887),
    [anon_sym_or] = ACTIONS(1887),
    [anon_sym_and] = ACTIONS(1887),
    [anon_sym_DASH_DASH] = ACTIONS(1889),
    [anon_sym_PLUS_PLUS] = ACTIONS(1889),
    [anon_sym_sizeof] = ACTIONS(1887),
    [anon_sym___alignof__] = ACTIONS(1887),
    [anon_sym___alignof] = ACTIONS(1887),
    [anon_sym__alignof] = ACTIONS(1887),
    [anon_sym_alignof] = ACTIONS(1887),
    [anon_sym__Alignof] = ACTIONS(1887),
    [anon_sym_offsetof] = ACTIONS(1887),
    [anon_sym__Generic] = ACTIONS(1887),
    [anon_sym_asm] = ACTIONS(1887),
    [anon_sym___asm__] = ACTIONS(1887),
    [sym_number_literal] = ACTIONS(1889),
    [anon_sym_L_SQUOTE] = ACTIONS(1889),
    [anon_sym_u_SQUOTE] = ACTIONS(1889),
    [anon_sym_U_SQUOTE] = ACTIONS(1889),
    [anon_sym_u8_SQUOTE] = ACTIONS(1889),
    [anon_sym_SQUOTE] = ACTIONS(1889),
    [anon_sym_L_DQUOTE] = ACTIONS(1889),
    [anon_sym_u_DQUOTE] = ACTIONS(1889),
    [anon_sym_U_DQUOTE] = ACTIONS(1889),
    [anon_sym_u8_DQUOTE] = ACTIONS(1889),
    [anon_sym_DQUOTE] = ACTIONS(1889),
    [sym_true] = ACTIONS(1887),
    [sym_false] = ACTIONS(1887),
    [anon_sym_NULL] = ACTIONS(1887),
    [anon_sym_nullptr] = ACTIONS(1887),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1887),
    [anon_sym_decltype] = ACTIONS(1887),
    [anon_sym_final] = ACTIONS(1887),
    [anon_sym_override] = ACTIONS(1887),
    [sym_virtual] = ACTIONS(1887),
    [anon_sym_explicit] = ACTIONS(1887),
    [anon_sym_typename] = ACTIONS(1887),
    [anon_sym_template] = ACTIONS(1887),
    [anon_sym_GT2] = ACTIONS(1889),
    [anon_sym_operator] = ACTIONS(1887),
    [anon_sym_try] = ACTIONS(1887),
    [anon_sym_delete] = ACTIONS(1887),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_namespace] = ACTIONS(1887),
    [anon_sym_using] = ACTIONS(1887),
    [anon_sym_static_assert] = ACTIONS(1887),
    [anon_sym_concept] = ACTIONS(1887),
    [anon_sym_co_return] = ACTIONS(1887),
    [anon_sym_co_yield] = ACTIONS(1887),
    [anon_sym_R_DQUOTE] = ACTIONS(1889),
    [anon_sym_LR_DQUOTE] = ACTIONS(1889),
    [anon_sym_uR_DQUOTE] = ACTIONS(1889),
    [anon_sym_UR_DQUOTE] = ACTIONS(1889),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1889),
    [anon_sym_co_await] = ACTIONS(1887),
    [anon_sym_new] = ACTIONS(1887),
    [anon_sym_requires] = ACTIONS(1887),
    [sym_this] = ACTIONS(1887),
    [anon_sym_discard] = ACTIONS(1887),
    [anon_sym_precise] = ACTIONS(1887),
    [anon_sym_shared] = ACTIONS(1887),
    [anon_sym_groupshared] = ACTIONS(1887),
    [anon_sym_uniform] = ACTIONS(1887),
    [anon_sym_row_major] = ACTIONS(1887),
    [anon_sym_column_major] = ACTIONS(1887),
    [anon_sym_globallycoherent] = ACTIONS(1887),
    [anon_sym_centroid] = ACTIONS(1887),
    [anon_sym_noperspective] = ACTIONS(1887),
    [anon_sym_nointerpolation] = ACTIONS(1887),
    [anon_sym_sample] = ACTIONS(1887),
    [anon_sym_linear] = ACTIONS(1887),
    [anon_sym_snorm] = ACTIONS(1887),
    [anon_sym_unorm] = ACTIONS(1887),
    [anon_sym_point] = ACTIONS(1887),
    [anon_sym_line] = ACTIONS(1887),
    [anon_sym_triangleadj] = ACTIONS(1887),
    [anon_sym_lineadj] = ACTIONS(1887),
    [anon_sym_triangle] = ACTIONS(1887),
    [anon_sym_cbuffer] = ACTIONS(1887),
  },
  [129] = {
    [sym_identifier] = ACTIONS(1891),
    [aux_sym_preproc_include_token1] = ACTIONS(1891),
    [aux_sym_preproc_def_token1] = ACTIONS(1891),
    [anon_sym_COMMA] = ACTIONS(1893),
    [anon_sym_RPAREN] = ACTIONS(1893),
    [aux_sym_preproc_if_token1] = ACTIONS(1891),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1891),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1891),
    [sym_preproc_directive] = ACTIONS(1891),
    [anon_sym_LPAREN2] = ACTIONS(1893),
    [anon_sym_BANG] = ACTIONS(1893),
    [anon_sym_TILDE] = ACTIONS(1893),
    [anon_sym_DASH] = ACTIONS(1891),
    [anon_sym_PLUS] = ACTIONS(1891),
    [anon_sym_STAR] = ACTIONS(1893),
    [anon_sym_PIPE_PIPE] = ACTIONS(1893),
    [anon_sym_AMP_AMP] = ACTIONS(1893),
    [anon_sym_AMP] = ACTIONS(1891),
    [anon_sym_COLON] = ACTIONS(1891),
    [anon_sym_SEMI] = ACTIONS(1893),
    [anon_sym___extension__] = ACTIONS(1891),
    [anon_sym_typedef] = ACTIONS(1891),
    [anon_sym_in] = ACTIONS(1891),
    [anon_sym_out] = ACTIONS(1891),
    [anon_sym_inout] = ACTIONS(1891),
    [anon_sym_extern] = ACTIONS(1891),
    [anon_sym___attribute__] = ACTIONS(1891),
    [anon_sym_COLON_COLON] = ACTIONS(1893),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1893),
    [anon_sym___declspec] = ACTIONS(1891),
    [anon_sym___based] = ACTIONS(1891),
    [anon_sym___cdecl] = ACTIONS(1891),
    [anon_sym___clrcall] = ACTIONS(1891),
    [anon_sym___stdcall] = ACTIONS(1891),
    [anon_sym___fastcall] = ACTIONS(1891),
    [anon_sym___thiscall] = ACTIONS(1891),
    [anon_sym___vectorcall] = ACTIONS(1891),
    [anon_sym_LBRACE] = ACTIONS(1893),
    [anon_sym_RBRACE] = ACTIONS(1893),
    [anon_sym_signed] = ACTIONS(1891),
    [anon_sym_unsigned] = ACTIONS(1891),
    [anon_sym_long] = ACTIONS(1891),
    [anon_sym_short] = ACTIONS(1891),
    [anon_sym_LBRACK] = ACTIONS(1891),
    [anon_sym_static] = ACTIONS(1891),
    [anon_sym_EQ] = ACTIONS(1893),
    [anon_sym_register] = ACTIONS(1891),
    [anon_sym_inline] = ACTIONS(1891),
    [anon_sym___inline] = ACTIONS(1891),
    [anon_sym___inline__] = ACTIONS(1891),
    [anon_sym___forceinline] = ACTIONS(1891),
    [anon_sym_thread_local] = ACTIONS(1891),
    [anon_sym___thread] = ACTIONS(1891),
    [anon_sym_const] = ACTIONS(1891),
    [anon_sym_constexpr] = ACTIONS(1891),
    [anon_sym_volatile] = ACTIONS(1891),
    [anon_sym_restrict] = ACTIONS(1891),
    [anon_sym___restrict__] = ACTIONS(1891),
    [anon_sym__Atomic] = ACTIONS(1891),
    [anon_sym__Noreturn] = ACTIONS(1891),
    [anon_sym_noreturn] = ACTIONS(1891),
    [anon_sym_mutable] = ACTIONS(1891),
    [anon_sym_constinit] = ACTIONS(1891),
    [anon_sym_consteval] = ACTIONS(1891),
    [anon_sym_alignas] = ACTIONS(1891),
    [anon_sym__Alignas] = ACTIONS(1891),
    [sym_primitive_type] = ACTIONS(1891),
    [anon_sym_enum] = ACTIONS(1891),
    [anon_sym_class] = ACTIONS(1891),
    [anon_sym_struct] = ACTIONS(1891),
    [anon_sym_union] = ACTIONS(1891),
    [anon_sym_if] = ACTIONS(1891),
    [anon_sym_else] = ACTIONS(1891),
    [anon_sym_switch] = ACTIONS(1891),
    [anon_sym_case] = ACTIONS(1891),
    [anon_sym_default] = ACTIONS(1891),
    [anon_sym_while] = ACTIONS(1891),
    [anon_sym_do] = ACTIONS(1891),
    [anon_sym_for] = ACTIONS(1891),
    [anon_sym_return] = ACTIONS(1891),
    [anon_sym_break] = ACTIONS(1891),
    [anon_sym_continue] = ACTIONS(1891),
    [anon_sym_goto] = ACTIONS(1891),
    [anon_sym___try] = ACTIONS(1891),
    [anon_sym___leave] = ACTIONS(1891),
    [anon_sym_not] = ACTIONS(1891),
    [anon_sym_compl] = ACTIONS(1891),
    [anon_sym_or] = ACTIONS(1891),
    [anon_sym_and] = ACTIONS(1891),
    [anon_sym_DASH_DASH] = ACTIONS(1893),
    [anon_sym_PLUS_PLUS] = ACTIONS(1893),
    [anon_sym_sizeof] = ACTIONS(1891),
    [anon_sym___alignof__] = ACTIONS(1891),
    [anon_sym___alignof] = ACTIONS(1891),
    [anon_sym__alignof] = ACTIONS(1891),
    [anon_sym_alignof] = ACTIONS(1891),
    [anon_sym__Alignof] = ACTIONS(1891),
    [anon_sym_offsetof] = ACTIONS(1891),
    [anon_sym__Generic] = ACTIONS(1891),
    [anon_sym_asm] = ACTIONS(1891),
    [anon_sym___asm__] = ACTIONS(1891),
    [sym_number_literal] = ACTIONS(1893),
    [anon_sym_L_SQUOTE] = ACTIONS(1893),
    [anon_sym_u_SQUOTE] = ACTIONS(1893),
    [anon_sym_U_SQUOTE] = ACTIONS(1893),
    [anon_sym_u8_SQUOTE] = ACTIONS(1893),
    [anon_sym_SQUOTE] = ACTIONS(1893),
    [anon_sym_L_DQUOTE] = ACTIONS(1893),
    [anon_sym_u_DQUOTE] = ACTIONS(1893),
    [anon_sym_U_DQUOTE] = ACTIONS(1893),
    [anon_sym_u8_DQUOTE] = ACTIONS(1893),
    [anon_sym_DQUOTE] = ACTIONS(1893),
    [sym_true] = ACTIONS(1891),
    [sym_false] = ACTIONS(1891),
    [anon_sym_NULL] = ACTIONS(1891),
    [anon_sym_nullptr] = ACTIONS(1891),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1891),
    [anon_sym_decltype] = ACTIONS(1891),
    [anon_sym_final] = ACTIONS(1891),
    [anon_sym_override] = ACTIONS(1891),
    [sym_virtual] = ACTIONS(1891),
    [anon_sym_explicit] = ACTIONS(1891),
    [anon_sym_typename] = ACTIONS(1891),
    [anon_sym_template] = ACTIONS(1891),
    [anon_sym_GT2] = ACTIONS(1893),
    [anon_sym_operator] = ACTIONS(1891),
    [anon_sym_try] = ACTIONS(1891),
    [anon_sym_delete] = ACTIONS(1891),
    [anon_sym_throw] = ACTIONS(1891),
    [anon_sym_namespace] = ACTIONS(1891),
    [anon_sym_using] = ACTIONS(1891),
    [anon_sym_static_assert] = ACTIONS(1891),
    [anon_sym_concept] = ACTIONS(1891),
    [anon_sym_co_return] = ACTIONS(1891),
    [anon_sym_co_yield] = ACTIONS(1891),
    [anon_sym_R_DQUOTE] = ACTIONS(1893),
    [anon_sym_LR_DQUOTE] = ACTIONS(1893),
    [anon_sym_uR_DQUOTE] = ACTIONS(1893),
    [anon_sym_UR_DQUOTE] = ACTIONS(1893),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1893),
    [anon_sym_co_await] = ACTIONS(1891),
    [anon_sym_new] = ACTIONS(1891),
    [anon_sym_requires] = ACTIONS(1891),
    [sym_this] = ACTIONS(1891),
    [anon_sym_discard] = ACTIONS(1891),
    [anon_sym_precise] = ACTIONS(1891),
    [anon_sym_shared] = ACTIONS(1891),
    [anon_sym_groupshared] = ACTIONS(1891),
    [anon_sym_uniform] = ACTIONS(1891),
    [anon_sym_row_major] = ACTIONS(1891),
    [anon_sym_column_major] = ACTIONS(1891),
    [anon_sym_globallycoherent] = ACTIONS(1891),
    [anon_sym_centroid] = ACTIONS(1891),
    [anon_sym_noperspective] = ACTIONS(1891),
    [anon_sym_nointerpolation] = ACTIONS(1891),
    [anon_sym_sample] = ACTIONS(1891),
    [anon_sym_linear] = ACTIONS(1891),
    [anon_sym_snorm] = ACTIONS(1891),
    [anon_sym_unorm] = ACTIONS(1891),
    [anon_sym_point] = ACTIONS(1891),
    [anon_sym_line] = ACTIONS(1891),
    [anon_sym_triangleadj] = ACTIONS(1891),
    [anon_sym_lineadj] = ACTIONS(1891),
    [anon_sym_triangle] = ACTIONS(1891),
    [anon_sym_cbuffer] = ACTIONS(1891),
  },
  [130] = {
    [sym_identifier] = ACTIONS(1895),
    [aux_sym_preproc_include_token1] = ACTIONS(1895),
    [aux_sym_preproc_def_token1] = ACTIONS(1895),
    [anon_sym_COMMA] = ACTIONS(1897),
    [anon_sym_RPAREN] = ACTIONS(1897),
    [aux_sym_preproc_if_token1] = ACTIONS(1895),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1895),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1895),
    [sym_preproc_directive] = ACTIONS(1895),
    [anon_sym_LPAREN2] = ACTIONS(1897),
    [anon_sym_BANG] = ACTIONS(1897),
    [anon_sym_TILDE] = ACTIONS(1897),
    [anon_sym_DASH] = ACTIONS(1895),
    [anon_sym_PLUS] = ACTIONS(1895),
    [anon_sym_STAR] = ACTIONS(1897),
    [anon_sym_PIPE_PIPE] = ACTIONS(1897),
    [anon_sym_AMP_AMP] = ACTIONS(1897),
    [anon_sym_AMP] = ACTIONS(1895),
    [anon_sym_COLON] = ACTIONS(1895),
    [anon_sym_SEMI] = ACTIONS(1897),
    [anon_sym___extension__] = ACTIONS(1895),
    [anon_sym_typedef] = ACTIONS(1895),
    [anon_sym_in] = ACTIONS(1895),
    [anon_sym_out] = ACTIONS(1895),
    [anon_sym_inout] = ACTIONS(1895),
    [anon_sym_extern] = ACTIONS(1895),
    [anon_sym___attribute__] = ACTIONS(1895),
    [anon_sym_COLON_COLON] = ACTIONS(1897),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1897),
    [anon_sym___declspec] = ACTIONS(1895),
    [anon_sym___based] = ACTIONS(1895),
    [anon_sym___cdecl] = ACTIONS(1895),
    [anon_sym___clrcall] = ACTIONS(1895),
    [anon_sym___stdcall] = ACTIONS(1895),
    [anon_sym___fastcall] = ACTIONS(1895),
    [anon_sym___thiscall] = ACTIONS(1895),
    [anon_sym___vectorcall] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1897),
    [anon_sym_RBRACE] = ACTIONS(1897),
    [anon_sym_signed] = ACTIONS(1895),
    [anon_sym_unsigned] = ACTIONS(1895),
    [anon_sym_long] = ACTIONS(1895),
    [anon_sym_short] = ACTIONS(1895),
    [anon_sym_LBRACK] = ACTIONS(1895),
    [anon_sym_static] = ACTIONS(1895),
    [anon_sym_EQ] = ACTIONS(1897),
    [anon_sym_register] = ACTIONS(1895),
    [anon_sym_inline] = ACTIONS(1895),
    [anon_sym___inline] = ACTIONS(1895),
    [anon_sym___inline__] = ACTIONS(1895),
    [anon_sym___forceinline] = ACTIONS(1895),
    [anon_sym_thread_local] = ACTIONS(1895),
    [anon_sym___thread] = ACTIONS(1895),
    [anon_sym_const] = ACTIONS(1895),
    [anon_sym_constexpr] = ACTIONS(1895),
    [anon_sym_volatile] = ACTIONS(1895),
    [anon_sym_restrict] = ACTIONS(1895),
    [anon_sym___restrict__] = ACTIONS(1895),
    [anon_sym__Atomic] = ACTIONS(1895),
    [anon_sym__Noreturn] = ACTIONS(1895),
    [anon_sym_noreturn] = ACTIONS(1895),
    [anon_sym_mutable] = ACTIONS(1895),
    [anon_sym_constinit] = ACTIONS(1895),
    [anon_sym_consteval] = ACTIONS(1895),
    [anon_sym_alignas] = ACTIONS(1895),
    [anon_sym__Alignas] = ACTIONS(1895),
    [sym_primitive_type] = ACTIONS(1895),
    [anon_sym_enum] = ACTIONS(1895),
    [anon_sym_class] = ACTIONS(1895),
    [anon_sym_struct] = ACTIONS(1895),
    [anon_sym_union] = ACTIONS(1895),
    [anon_sym_if] = ACTIONS(1895),
    [anon_sym_else] = ACTIONS(1895),
    [anon_sym_switch] = ACTIONS(1895),
    [anon_sym_case] = ACTIONS(1895),
    [anon_sym_default] = ACTIONS(1895),
    [anon_sym_while] = ACTIONS(1895),
    [anon_sym_do] = ACTIONS(1895),
    [anon_sym_for] = ACTIONS(1895),
    [anon_sym_return] = ACTIONS(1895),
    [anon_sym_break] = ACTIONS(1895),
    [anon_sym_continue] = ACTIONS(1895),
    [anon_sym_goto] = ACTIONS(1895),
    [anon_sym___try] = ACTIONS(1895),
    [anon_sym___leave] = ACTIONS(1895),
    [anon_sym_not] = ACTIONS(1895),
    [anon_sym_compl] = ACTIONS(1895),
    [anon_sym_or] = ACTIONS(1895),
    [anon_sym_and] = ACTIONS(1895),
    [anon_sym_DASH_DASH] = ACTIONS(1897),
    [anon_sym_PLUS_PLUS] = ACTIONS(1897),
    [anon_sym_sizeof] = ACTIONS(1895),
    [anon_sym___alignof__] = ACTIONS(1895),
    [anon_sym___alignof] = ACTIONS(1895),
    [anon_sym__alignof] = ACTIONS(1895),
    [anon_sym_alignof] = ACTIONS(1895),
    [anon_sym__Alignof] = ACTIONS(1895),
    [anon_sym_offsetof] = ACTIONS(1895),
    [anon_sym__Generic] = ACTIONS(1895),
    [anon_sym_asm] = ACTIONS(1895),
    [anon_sym___asm__] = ACTIONS(1895),
    [sym_number_literal] = ACTIONS(1897),
    [anon_sym_L_SQUOTE] = ACTIONS(1897),
    [anon_sym_u_SQUOTE] = ACTIONS(1897),
    [anon_sym_U_SQUOTE] = ACTIONS(1897),
    [anon_sym_u8_SQUOTE] = ACTIONS(1897),
    [anon_sym_SQUOTE] = ACTIONS(1897),
    [anon_sym_L_DQUOTE] = ACTIONS(1897),
    [anon_sym_u_DQUOTE] = ACTIONS(1897),
    [anon_sym_U_DQUOTE] = ACTIONS(1897),
    [anon_sym_u8_DQUOTE] = ACTIONS(1897),
    [anon_sym_DQUOTE] = ACTIONS(1897),
    [sym_true] = ACTIONS(1895),
    [sym_false] = ACTIONS(1895),
    [anon_sym_NULL] = ACTIONS(1895),
    [anon_sym_nullptr] = ACTIONS(1895),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1895),
    [anon_sym_decltype] = ACTIONS(1895),
    [anon_sym_final] = ACTIONS(1895),
    [anon_sym_override] = ACTIONS(1895),
    [sym_virtual] = ACTIONS(1895),
    [anon_sym_explicit] = ACTIONS(1895),
    [anon_sym_typename] = ACTIONS(1895),
    [anon_sym_template] = ACTIONS(1895),
    [anon_sym_GT2] = ACTIONS(1897),
    [anon_sym_operator] = ACTIONS(1895),
    [anon_sym_try] = ACTIONS(1895),
    [anon_sym_delete] = ACTIONS(1895),
    [anon_sym_throw] = ACTIONS(1895),
    [anon_sym_namespace] = ACTIONS(1895),
    [anon_sym_using] = ACTIONS(1895),
    [anon_sym_static_assert] = ACTIONS(1895),
    [anon_sym_concept] = ACTIONS(1895),
    [anon_sym_co_return] = ACTIONS(1895),
    [anon_sym_co_yield] = ACTIONS(1895),
    [anon_sym_R_DQUOTE] = ACTIONS(1897),
    [anon_sym_LR_DQUOTE] = ACTIONS(1897),
    [anon_sym_uR_DQUOTE] = ACTIONS(1897),
    [anon_sym_UR_DQUOTE] = ACTIONS(1897),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1897),
    [anon_sym_co_await] = ACTIONS(1895),
    [anon_sym_new] = ACTIONS(1895),
    [anon_sym_requires] = ACTIONS(1895),
    [sym_this] = ACTIONS(1895),
    [anon_sym_discard] = ACTIONS(1895),
    [anon_sym_precise] = ACTIONS(1895),
    [anon_sym_shared] = ACTIONS(1895),
    [anon_sym_groupshared] = ACTIONS(1895),
    [anon_sym_uniform] = ACTIONS(1895),
    [anon_sym_row_major] = ACTIONS(1895),
    [anon_sym_column_major] = ACTIONS(1895),
    [anon_sym_globallycoherent] = ACTIONS(1895),
    [anon_sym_centroid] = ACTIONS(1895),
    [anon_sym_noperspective] = ACTIONS(1895),
    [anon_sym_nointerpolation] = ACTIONS(1895),
    [anon_sym_sample] = ACTIONS(1895),
    [anon_sym_linear] = ACTIONS(1895),
    [anon_sym_snorm] = ACTIONS(1895),
    [anon_sym_unorm] = ACTIONS(1895),
    [anon_sym_point] = ACTIONS(1895),
    [anon_sym_line] = ACTIONS(1895),
    [anon_sym_triangleadj] = ACTIONS(1895),
    [anon_sym_lineadj] = ACTIONS(1895),
    [anon_sym_triangle] = ACTIONS(1895),
    [anon_sym_cbuffer] = ACTIONS(1895),
  },
  [131] = {
    [sym_identifier] = ACTIONS(1899),
    [aux_sym_preproc_include_token1] = ACTIONS(1899),
    [aux_sym_preproc_def_token1] = ACTIONS(1899),
    [anon_sym_COMMA] = ACTIONS(1901),
    [anon_sym_RPAREN] = ACTIONS(1901),
    [aux_sym_preproc_if_token1] = ACTIONS(1899),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1899),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1899),
    [sym_preproc_directive] = ACTIONS(1899),
    [anon_sym_LPAREN2] = ACTIONS(1901),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1901),
    [anon_sym_PIPE_PIPE] = ACTIONS(1901),
    [anon_sym_AMP_AMP] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1899),
    [anon_sym_COLON] = ACTIONS(1899),
    [anon_sym_SEMI] = ACTIONS(1901),
    [anon_sym___extension__] = ACTIONS(1899),
    [anon_sym_typedef] = ACTIONS(1899),
    [anon_sym_in] = ACTIONS(1899),
    [anon_sym_out] = ACTIONS(1899),
    [anon_sym_inout] = ACTIONS(1899),
    [anon_sym_extern] = ACTIONS(1899),
    [anon_sym___attribute__] = ACTIONS(1899),
    [anon_sym_COLON_COLON] = ACTIONS(1901),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1901),
    [anon_sym___declspec] = ACTIONS(1899),
    [anon_sym___based] = ACTIONS(1899),
    [anon_sym___cdecl] = ACTIONS(1899),
    [anon_sym___clrcall] = ACTIONS(1899),
    [anon_sym___stdcall] = ACTIONS(1899),
    [anon_sym___fastcall] = ACTIONS(1899),
    [anon_sym___thiscall] = ACTIONS(1899),
    [anon_sym___vectorcall] = ACTIONS(1899),
    [anon_sym_LBRACE] = ACTIONS(1901),
    [anon_sym_RBRACE] = ACTIONS(1901),
    [anon_sym_signed] = ACTIONS(1899),
    [anon_sym_unsigned] = ACTIONS(1899),
    [anon_sym_long] = ACTIONS(1899),
    [anon_sym_short] = ACTIONS(1899),
    [anon_sym_LBRACK] = ACTIONS(1899),
    [anon_sym_static] = ACTIONS(1899),
    [anon_sym_EQ] = ACTIONS(1901),
    [anon_sym_register] = ACTIONS(1899),
    [anon_sym_inline] = ACTIONS(1899),
    [anon_sym___inline] = ACTIONS(1899),
    [anon_sym___inline__] = ACTIONS(1899),
    [anon_sym___forceinline] = ACTIONS(1899),
    [anon_sym_thread_local] = ACTIONS(1899),
    [anon_sym___thread] = ACTIONS(1899),
    [anon_sym_const] = ACTIONS(1899),
    [anon_sym_constexpr] = ACTIONS(1899),
    [anon_sym_volatile] = ACTIONS(1899),
    [anon_sym_restrict] = ACTIONS(1899),
    [anon_sym___restrict__] = ACTIONS(1899),
    [anon_sym__Atomic] = ACTIONS(1899),
    [anon_sym__Noreturn] = ACTIONS(1899),
    [anon_sym_noreturn] = ACTIONS(1899),
    [anon_sym_mutable] = ACTIONS(1899),
    [anon_sym_constinit] = ACTIONS(1899),
    [anon_sym_consteval] = ACTIONS(1899),
    [anon_sym_alignas] = ACTIONS(1899),
    [anon_sym__Alignas] = ACTIONS(1899),
    [sym_primitive_type] = ACTIONS(1899),
    [anon_sym_enum] = ACTIONS(1899),
    [anon_sym_class] = ACTIONS(1899),
    [anon_sym_struct] = ACTIONS(1899),
    [anon_sym_union] = ACTIONS(1899),
    [anon_sym_if] = ACTIONS(1899),
    [anon_sym_else] = ACTIONS(1899),
    [anon_sym_switch] = ACTIONS(1899),
    [anon_sym_case] = ACTIONS(1899),
    [anon_sym_default] = ACTIONS(1899),
    [anon_sym_while] = ACTIONS(1899),
    [anon_sym_do] = ACTIONS(1899),
    [anon_sym_for] = ACTIONS(1899),
    [anon_sym_return] = ACTIONS(1899),
    [anon_sym_break] = ACTIONS(1899),
    [anon_sym_continue] = ACTIONS(1899),
    [anon_sym_goto] = ACTIONS(1899),
    [anon_sym___try] = ACTIONS(1899),
    [anon_sym___leave] = ACTIONS(1899),
    [anon_sym_not] = ACTIONS(1899),
    [anon_sym_compl] = ACTIONS(1899),
    [anon_sym_or] = ACTIONS(1899),
    [anon_sym_and] = ACTIONS(1899),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_sizeof] = ACTIONS(1899),
    [anon_sym___alignof__] = ACTIONS(1899),
    [anon_sym___alignof] = ACTIONS(1899),
    [anon_sym__alignof] = ACTIONS(1899),
    [anon_sym_alignof] = ACTIONS(1899),
    [anon_sym__Alignof] = ACTIONS(1899),
    [anon_sym_offsetof] = ACTIONS(1899),
    [anon_sym__Generic] = ACTIONS(1899),
    [anon_sym_asm] = ACTIONS(1899),
    [anon_sym___asm__] = ACTIONS(1899),
    [sym_number_literal] = ACTIONS(1901),
    [anon_sym_L_SQUOTE] = ACTIONS(1901),
    [anon_sym_u_SQUOTE] = ACTIONS(1901),
    [anon_sym_U_SQUOTE] = ACTIONS(1901),
    [anon_sym_u8_SQUOTE] = ACTIONS(1901),
    [anon_sym_SQUOTE] = ACTIONS(1901),
    [anon_sym_L_DQUOTE] = ACTIONS(1901),
    [anon_sym_u_DQUOTE] = ACTIONS(1901),
    [anon_sym_U_DQUOTE] = ACTIONS(1901),
    [anon_sym_u8_DQUOTE] = ACTIONS(1901),
    [anon_sym_DQUOTE] = ACTIONS(1901),
    [sym_true] = ACTIONS(1899),
    [sym_false] = ACTIONS(1899),
    [anon_sym_NULL] = ACTIONS(1899),
    [anon_sym_nullptr] = ACTIONS(1899),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1899),
    [anon_sym_decltype] = ACTIONS(1899),
    [anon_sym_final] = ACTIONS(1899),
    [anon_sym_override] = ACTIONS(1899),
    [sym_virtual] = ACTIONS(1899),
    [anon_sym_explicit] = ACTIONS(1899),
    [anon_sym_typename] = ACTIONS(1899),
    [anon_sym_template] = ACTIONS(1899),
    [anon_sym_GT2] = ACTIONS(1901),
    [anon_sym_operator] = ACTIONS(1899),
    [anon_sym_try] = ACTIONS(1899),
    [anon_sym_delete] = ACTIONS(1899),
    [anon_sym_throw] = ACTIONS(1899),
    [anon_sym_namespace] = ACTIONS(1899),
    [anon_sym_using] = ACTIONS(1899),
    [anon_sym_static_assert] = ACTIONS(1899),
    [anon_sym_concept] = ACTIONS(1899),
    [anon_sym_co_return] = ACTIONS(1899),
    [anon_sym_co_yield] = ACTIONS(1899),
    [anon_sym_R_DQUOTE] = ACTIONS(1901),
    [anon_sym_LR_DQUOTE] = ACTIONS(1901),
    [anon_sym_uR_DQUOTE] = ACTIONS(1901),
    [anon_sym_UR_DQUOTE] = ACTIONS(1901),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1901),
    [anon_sym_co_await] = ACTIONS(1899),
    [anon_sym_new] = ACTIONS(1899),
    [anon_sym_requires] = ACTIONS(1899),
    [sym_this] = ACTIONS(1899),
    [anon_sym_discard] = ACTIONS(1899),
    [anon_sym_precise] = ACTIONS(1899),
    [anon_sym_shared] = ACTIONS(1899),
    [anon_sym_groupshared] = ACTIONS(1899),
    [anon_sym_uniform] = ACTIONS(1899),
    [anon_sym_row_major] = ACTIONS(1899),
    [anon_sym_column_major] = ACTIONS(1899),
    [anon_sym_globallycoherent] = ACTIONS(1899),
    [anon_sym_centroid] = ACTIONS(1899),
    [anon_sym_noperspective] = ACTIONS(1899),
    [anon_sym_nointerpolation] = ACTIONS(1899),
    [anon_sym_sample] = ACTIONS(1899),
    [anon_sym_linear] = ACTIONS(1899),
    [anon_sym_snorm] = ACTIONS(1899),
    [anon_sym_unorm] = ACTIONS(1899),
    [anon_sym_point] = ACTIONS(1899),
    [anon_sym_line] = ACTIONS(1899),
    [anon_sym_triangleadj] = ACTIONS(1899),
    [anon_sym_lineadj] = ACTIONS(1899),
    [anon_sym_triangle] = ACTIONS(1899),
    [anon_sym_cbuffer] = ACTIONS(1899),
  },
  [132] = {
    [sym_identifier] = ACTIONS(1903),
    [aux_sym_preproc_include_token1] = ACTIONS(1903),
    [aux_sym_preproc_def_token1] = ACTIONS(1903),
    [anon_sym_COMMA] = ACTIONS(1905),
    [anon_sym_RPAREN] = ACTIONS(1905),
    [aux_sym_preproc_if_token1] = ACTIONS(1903),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1903),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1903),
    [sym_preproc_directive] = ACTIONS(1903),
    [anon_sym_LPAREN2] = ACTIONS(1905),
    [anon_sym_BANG] = ACTIONS(1905),
    [anon_sym_TILDE] = ACTIONS(1905),
    [anon_sym_DASH] = ACTIONS(1903),
    [anon_sym_PLUS] = ACTIONS(1903),
    [anon_sym_STAR] = ACTIONS(1905),
    [anon_sym_PIPE_PIPE] = ACTIONS(1905),
    [anon_sym_AMP_AMP] = ACTIONS(1905),
    [anon_sym_AMP] = ACTIONS(1903),
    [anon_sym_COLON] = ACTIONS(1903),
    [anon_sym_SEMI] = ACTIONS(1905),
    [anon_sym___extension__] = ACTIONS(1903),
    [anon_sym_typedef] = ACTIONS(1903),
    [anon_sym_in] = ACTIONS(1903),
    [anon_sym_out] = ACTIONS(1903),
    [anon_sym_inout] = ACTIONS(1903),
    [anon_sym_extern] = ACTIONS(1903),
    [anon_sym___attribute__] = ACTIONS(1903),
    [anon_sym_COLON_COLON] = ACTIONS(1905),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1905),
    [anon_sym___declspec] = ACTIONS(1903),
    [anon_sym___based] = ACTIONS(1903),
    [anon_sym___cdecl] = ACTIONS(1903),
    [anon_sym___clrcall] = ACTIONS(1903),
    [anon_sym___stdcall] = ACTIONS(1903),
    [anon_sym___fastcall] = ACTIONS(1903),
    [anon_sym___thiscall] = ACTIONS(1903),
    [anon_sym___vectorcall] = ACTIONS(1903),
    [anon_sym_LBRACE] = ACTIONS(1905),
    [anon_sym_RBRACE] = ACTIONS(1905),
    [anon_sym_signed] = ACTIONS(1903),
    [anon_sym_unsigned] = ACTIONS(1903),
    [anon_sym_long] = ACTIONS(1903),
    [anon_sym_short] = ACTIONS(1903),
    [anon_sym_LBRACK] = ACTIONS(1903),
    [anon_sym_static] = ACTIONS(1903),
    [anon_sym_EQ] = ACTIONS(1905),
    [anon_sym_register] = ACTIONS(1903),
    [anon_sym_inline] = ACTIONS(1903),
    [anon_sym___inline] = ACTIONS(1903),
    [anon_sym___inline__] = ACTIONS(1903),
    [anon_sym___forceinline] = ACTIONS(1903),
    [anon_sym_thread_local] = ACTIONS(1903),
    [anon_sym___thread] = ACTIONS(1903),
    [anon_sym_const] = ACTIONS(1903),
    [anon_sym_constexpr] = ACTIONS(1903),
    [anon_sym_volatile] = ACTIONS(1903),
    [anon_sym_restrict] = ACTIONS(1903),
    [anon_sym___restrict__] = ACTIONS(1903),
    [anon_sym__Atomic] = ACTIONS(1903),
    [anon_sym__Noreturn] = ACTIONS(1903),
    [anon_sym_noreturn] = ACTIONS(1903),
    [anon_sym_mutable] = ACTIONS(1903),
    [anon_sym_constinit] = ACTIONS(1903),
    [anon_sym_consteval] = ACTIONS(1903),
    [anon_sym_alignas] = ACTIONS(1903),
    [anon_sym__Alignas] = ACTIONS(1903),
    [sym_primitive_type] = ACTIONS(1903),
    [anon_sym_enum] = ACTIONS(1903),
    [anon_sym_class] = ACTIONS(1903),
    [anon_sym_struct] = ACTIONS(1903),
    [anon_sym_union] = ACTIONS(1903),
    [anon_sym_if] = ACTIONS(1903),
    [anon_sym_else] = ACTIONS(1903),
    [anon_sym_switch] = ACTIONS(1903),
    [anon_sym_case] = ACTIONS(1903),
    [anon_sym_default] = ACTIONS(1903),
    [anon_sym_while] = ACTIONS(1903),
    [anon_sym_do] = ACTIONS(1903),
    [anon_sym_for] = ACTIONS(1903),
    [anon_sym_return] = ACTIONS(1903),
    [anon_sym_break] = ACTIONS(1903),
    [anon_sym_continue] = ACTIONS(1903),
    [anon_sym_goto] = ACTIONS(1903),
    [anon_sym___try] = ACTIONS(1903),
    [anon_sym___leave] = ACTIONS(1903),
    [anon_sym_not] = ACTIONS(1903),
    [anon_sym_compl] = ACTIONS(1903),
    [anon_sym_or] = ACTIONS(1903),
    [anon_sym_and] = ACTIONS(1903),
    [anon_sym_DASH_DASH] = ACTIONS(1905),
    [anon_sym_PLUS_PLUS] = ACTIONS(1905),
    [anon_sym_sizeof] = ACTIONS(1903),
    [anon_sym___alignof__] = ACTIONS(1903),
    [anon_sym___alignof] = ACTIONS(1903),
    [anon_sym__alignof] = ACTIONS(1903),
    [anon_sym_alignof] = ACTIONS(1903),
    [anon_sym__Alignof] = ACTIONS(1903),
    [anon_sym_offsetof] = ACTIONS(1903),
    [anon_sym__Generic] = ACTIONS(1903),
    [anon_sym_asm] = ACTIONS(1903),
    [anon_sym___asm__] = ACTIONS(1903),
    [sym_number_literal] = ACTIONS(1905),
    [anon_sym_L_SQUOTE] = ACTIONS(1905),
    [anon_sym_u_SQUOTE] = ACTIONS(1905),
    [anon_sym_U_SQUOTE] = ACTIONS(1905),
    [anon_sym_u8_SQUOTE] = ACTIONS(1905),
    [anon_sym_SQUOTE] = ACTIONS(1905),
    [anon_sym_L_DQUOTE] = ACTIONS(1905),
    [anon_sym_u_DQUOTE] = ACTIONS(1905),
    [anon_sym_U_DQUOTE] = ACTIONS(1905),
    [anon_sym_u8_DQUOTE] = ACTIONS(1905),
    [anon_sym_DQUOTE] = ACTIONS(1905),
    [sym_true] = ACTIONS(1903),
    [sym_false] = ACTIONS(1903),
    [anon_sym_NULL] = ACTIONS(1903),
    [anon_sym_nullptr] = ACTIONS(1903),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1903),
    [anon_sym_decltype] = ACTIONS(1903),
    [anon_sym_final] = ACTIONS(1903),
    [anon_sym_override] = ACTIONS(1903),
    [sym_virtual] = ACTIONS(1903),
    [anon_sym_explicit] = ACTIONS(1903),
    [anon_sym_typename] = ACTIONS(1903),
    [anon_sym_template] = ACTIONS(1903),
    [anon_sym_GT2] = ACTIONS(1905),
    [anon_sym_operator] = ACTIONS(1903),
    [anon_sym_try] = ACTIONS(1903),
    [anon_sym_delete] = ACTIONS(1903),
    [anon_sym_throw] = ACTIONS(1903),
    [anon_sym_namespace] = ACTIONS(1903),
    [anon_sym_using] = ACTIONS(1903),
    [anon_sym_static_assert] = ACTIONS(1903),
    [anon_sym_concept] = ACTIONS(1903),
    [anon_sym_co_return] = ACTIONS(1903),
    [anon_sym_co_yield] = ACTIONS(1903),
    [anon_sym_R_DQUOTE] = ACTIONS(1905),
    [anon_sym_LR_DQUOTE] = ACTIONS(1905),
    [anon_sym_uR_DQUOTE] = ACTIONS(1905),
    [anon_sym_UR_DQUOTE] = ACTIONS(1905),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1905),
    [anon_sym_co_await] = ACTIONS(1903),
    [anon_sym_new] = ACTIONS(1903),
    [anon_sym_requires] = ACTIONS(1903),
    [sym_this] = ACTIONS(1903),
    [anon_sym_discard] = ACTIONS(1903),
    [anon_sym_precise] = ACTIONS(1903),
    [anon_sym_shared] = ACTIONS(1903),
    [anon_sym_groupshared] = ACTIONS(1903),
    [anon_sym_uniform] = ACTIONS(1903),
    [anon_sym_row_major] = ACTIONS(1903),
    [anon_sym_column_major] = ACTIONS(1903),
    [anon_sym_globallycoherent] = ACTIONS(1903),
    [anon_sym_centroid] = ACTIONS(1903),
    [anon_sym_noperspective] = ACTIONS(1903),
    [anon_sym_nointerpolation] = ACTIONS(1903),
    [anon_sym_sample] = ACTIONS(1903),
    [anon_sym_linear] = ACTIONS(1903),
    [anon_sym_snorm] = ACTIONS(1903),
    [anon_sym_unorm] = ACTIONS(1903),
    [anon_sym_point] = ACTIONS(1903),
    [anon_sym_line] = ACTIONS(1903),
    [anon_sym_triangleadj] = ACTIONS(1903),
    [anon_sym_lineadj] = ACTIONS(1903),
    [anon_sym_triangle] = ACTIONS(1903),
    [anon_sym_cbuffer] = ACTIONS(1903),
  },
  [133] = {
    [sym_field_declaration_list] = STATE(198),
    [sym_virtual_specifier] = STATE(7012),
    [sym_base_class_clause] = STATE(7794),
    [sym_identifier] = ACTIONS(1907),
    [aux_sym_preproc_include_token1] = ACTIONS(1907),
    [aux_sym_preproc_def_token1] = ACTIONS(1907),
    [aux_sym_preproc_if_token1] = ACTIONS(1907),
    [aux_sym_preproc_if_token2] = ACTIONS(1907),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1907),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1907),
    [aux_sym_preproc_else_token1] = ACTIONS(1907),
    [aux_sym_preproc_elif_token1] = ACTIONS(1907),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1907),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1907),
    [sym_preproc_directive] = ACTIONS(1907),
    [anon_sym_LPAREN2] = ACTIONS(1909),
    [anon_sym_BANG] = ACTIONS(1909),
    [anon_sym_TILDE] = ACTIONS(1909),
    [anon_sym_DASH] = ACTIONS(1907),
    [anon_sym_PLUS] = ACTIONS(1907),
    [anon_sym_STAR] = ACTIONS(1909),
    [anon_sym_AMP_AMP] = ACTIONS(1909),
    [anon_sym_AMP] = ACTIONS(1907),
    [anon_sym_COLON] = ACTIONS(1911),
    [anon_sym_SEMI] = ACTIONS(1909),
    [anon_sym___extension__] = ACTIONS(1907),
    [anon_sym_typedef] = ACTIONS(1907),
    [anon_sym_in] = ACTIONS(1907),
    [anon_sym_out] = ACTIONS(1907),
    [anon_sym_inout] = ACTIONS(1907),
    [anon_sym_extern] = ACTIONS(1907),
    [anon_sym___attribute__] = ACTIONS(1907),
    [anon_sym_COLON_COLON] = ACTIONS(1909),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1909),
    [anon_sym___declspec] = ACTIONS(1907),
    [anon_sym___based] = ACTIONS(1907),
    [anon_sym___cdecl] = ACTIONS(1907),
    [anon_sym___clrcall] = ACTIONS(1907),
    [anon_sym___stdcall] = ACTIONS(1907),
    [anon_sym___fastcall] = ACTIONS(1907),
    [anon_sym___thiscall] = ACTIONS(1907),
    [anon_sym___vectorcall] = ACTIONS(1907),
    [anon_sym_LBRACE] = ACTIONS(1913),
    [anon_sym_signed] = ACTIONS(1907),
    [anon_sym_unsigned] = ACTIONS(1907),
    [anon_sym_long] = ACTIONS(1907),
    [anon_sym_short] = ACTIONS(1907),
    [anon_sym_LBRACK] = ACTIONS(1907),
    [anon_sym_static] = ACTIONS(1907),
    [anon_sym_register] = ACTIONS(1907),
    [anon_sym_inline] = ACTIONS(1907),
    [anon_sym___inline] = ACTIONS(1907),
    [anon_sym___inline__] = ACTIONS(1907),
    [anon_sym___forceinline] = ACTIONS(1907),
    [anon_sym_thread_local] = ACTIONS(1907),
    [anon_sym___thread] = ACTIONS(1907),
    [anon_sym_const] = ACTIONS(1907),
    [anon_sym_constexpr] = ACTIONS(1907),
    [anon_sym_volatile] = ACTIONS(1907),
    [anon_sym_restrict] = ACTIONS(1907),
    [anon_sym___restrict__] = ACTIONS(1907),
    [anon_sym__Atomic] = ACTIONS(1907),
    [anon_sym__Noreturn] = ACTIONS(1907),
    [anon_sym_noreturn] = ACTIONS(1907),
    [anon_sym_mutable] = ACTIONS(1907),
    [anon_sym_constinit] = ACTIONS(1907),
    [anon_sym_consteval] = ACTIONS(1907),
    [anon_sym_alignas] = ACTIONS(1907),
    [anon_sym__Alignas] = ACTIONS(1907),
    [sym_primitive_type] = ACTIONS(1907),
    [anon_sym_enum] = ACTIONS(1907),
    [anon_sym_class] = ACTIONS(1907),
    [anon_sym_struct] = ACTIONS(1907),
    [anon_sym_union] = ACTIONS(1907),
    [anon_sym_if] = ACTIONS(1907),
    [anon_sym_else] = ACTIONS(1907),
    [anon_sym_switch] = ACTIONS(1907),
    [anon_sym_case] = ACTIONS(1907),
    [anon_sym_default] = ACTIONS(1907),
    [anon_sym_while] = ACTIONS(1907),
    [anon_sym_do] = ACTIONS(1907),
    [anon_sym_for] = ACTIONS(1907),
    [anon_sym_return] = ACTIONS(1907),
    [anon_sym_break] = ACTIONS(1907),
    [anon_sym_continue] = ACTIONS(1907),
    [anon_sym_goto] = ACTIONS(1907),
    [anon_sym___try] = ACTIONS(1907),
    [anon_sym___leave] = ACTIONS(1907),
    [anon_sym_not] = ACTIONS(1907),
    [anon_sym_compl] = ACTIONS(1907),
    [anon_sym_DASH_DASH] = ACTIONS(1909),
    [anon_sym_PLUS_PLUS] = ACTIONS(1909),
    [anon_sym_sizeof] = ACTIONS(1907),
    [anon_sym___alignof__] = ACTIONS(1907),
    [anon_sym___alignof] = ACTIONS(1907),
    [anon_sym__alignof] = ACTIONS(1907),
    [anon_sym_alignof] = ACTIONS(1907),
    [anon_sym__Alignof] = ACTIONS(1907),
    [anon_sym_offsetof] = ACTIONS(1907),
    [anon_sym__Generic] = ACTIONS(1907),
    [anon_sym_asm] = ACTIONS(1907),
    [anon_sym___asm__] = ACTIONS(1907),
    [sym_number_literal] = ACTIONS(1909),
    [anon_sym_L_SQUOTE] = ACTIONS(1909),
    [anon_sym_u_SQUOTE] = ACTIONS(1909),
    [anon_sym_U_SQUOTE] = ACTIONS(1909),
    [anon_sym_u8_SQUOTE] = ACTIONS(1909),
    [anon_sym_SQUOTE] = ACTIONS(1909),
    [anon_sym_L_DQUOTE] = ACTIONS(1909),
    [anon_sym_u_DQUOTE] = ACTIONS(1909),
    [anon_sym_U_DQUOTE] = ACTIONS(1909),
    [anon_sym_u8_DQUOTE] = ACTIONS(1909),
    [anon_sym_DQUOTE] = ACTIONS(1909),
    [sym_true] = ACTIONS(1907),
    [sym_false] = ACTIONS(1907),
    [anon_sym_NULL] = ACTIONS(1907),
    [anon_sym_nullptr] = ACTIONS(1907),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1907),
    [anon_sym_decltype] = ACTIONS(1907),
    [anon_sym_final] = ACTIONS(1915),
    [anon_sym_override] = ACTIONS(1915),
    [sym_virtual] = ACTIONS(1907),
    [anon_sym_explicit] = ACTIONS(1907),
    [anon_sym_typename] = ACTIONS(1907),
    [anon_sym_template] = ACTIONS(1907),
    [anon_sym_operator] = ACTIONS(1907),
    [anon_sym_try] = ACTIONS(1907),
    [anon_sym_delete] = ACTIONS(1907),
    [anon_sym_throw] = ACTIONS(1907),
    [anon_sym_namespace] = ACTIONS(1907),
    [anon_sym_using] = ACTIONS(1907),
    [anon_sym_static_assert] = ACTIONS(1907),
    [anon_sym_concept] = ACTIONS(1907),
    [anon_sym_co_return] = ACTIONS(1907),
    [anon_sym_co_yield] = ACTIONS(1907),
    [anon_sym_R_DQUOTE] = ACTIONS(1909),
    [anon_sym_LR_DQUOTE] = ACTIONS(1909),
    [anon_sym_uR_DQUOTE] = ACTIONS(1909),
    [anon_sym_UR_DQUOTE] = ACTIONS(1909),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1909),
    [anon_sym_co_await] = ACTIONS(1907),
    [anon_sym_new] = ACTIONS(1907),
    [anon_sym_requires] = ACTIONS(1907),
    [sym_this] = ACTIONS(1907),
    [anon_sym_discard] = ACTIONS(1907),
    [anon_sym_precise] = ACTIONS(1907),
    [anon_sym_shared] = ACTIONS(1907),
    [anon_sym_groupshared] = ACTIONS(1907),
    [anon_sym_uniform] = ACTIONS(1907),
    [anon_sym_row_major] = ACTIONS(1907),
    [anon_sym_column_major] = ACTIONS(1907),
    [anon_sym_globallycoherent] = ACTIONS(1907),
    [anon_sym_centroid] = ACTIONS(1907),
    [anon_sym_noperspective] = ACTIONS(1907),
    [anon_sym_nointerpolation] = ACTIONS(1907),
    [anon_sym_sample] = ACTIONS(1907),
    [anon_sym_linear] = ACTIONS(1907),
    [anon_sym_snorm] = ACTIONS(1907),
    [anon_sym_unorm] = ACTIONS(1907),
    [anon_sym_point] = ACTIONS(1907),
    [anon_sym_line] = ACTIONS(1907),
    [anon_sym_triangleadj] = ACTIONS(1907),
    [anon_sym_lineadj] = ACTIONS(1907),
    [anon_sym_triangle] = ACTIONS(1907),
    [anon_sym_cbuffer] = ACTIONS(1907),
  },
  [134] = {
    [sym_identifier] = ACTIONS(1917),
    [aux_sym_preproc_include_token1] = ACTIONS(1917),
    [aux_sym_preproc_def_token1] = ACTIONS(1917),
    [anon_sym_COMMA] = ACTIONS(1919),
    [anon_sym_RPAREN] = ACTIONS(1919),
    [aux_sym_preproc_if_token1] = ACTIONS(1917),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1917),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1917),
    [sym_preproc_directive] = ACTIONS(1917),
    [anon_sym_LPAREN2] = ACTIONS(1919),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1919),
    [anon_sym_PIPE_PIPE] = ACTIONS(1919),
    [anon_sym_AMP_AMP] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1917),
    [anon_sym_COLON] = ACTIONS(1917),
    [anon_sym_SEMI] = ACTIONS(1919),
    [anon_sym___extension__] = ACTIONS(1917),
    [anon_sym_typedef] = ACTIONS(1917),
    [anon_sym_in] = ACTIONS(1917),
    [anon_sym_out] = ACTIONS(1917),
    [anon_sym_inout] = ACTIONS(1917),
    [anon_sym_extern] = ACTIONS(1917),
    [anon_sym___attribute__] = ACTIONS(1917),
    [anon_sym_COLON_COLON] = ACTIONS(1919),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1919),
    [anon_sym___declspec] = ACTIONS(1917),
    [anon_sym___based] = ACTIONS(1917),
    [anon_sym___cdecl] = ACTIONS(1917),
    [anon_sym___clrcall] = ACTIONS(1917),
    [anon_sym___stdcall] = ACTIONS(1917),
    [anon_sym___fastcall] = ACTIONS(1917),
    [anon_sym___thiscall] = ACTIONS(1917),
    [anon_sym___vectorcall] = ACTIONS(1917),
    [anon_sym_LBRACE] = ACTIONS(1919),
    [anon_sym_RBRACE] = ACTIONS(1919),
    [anon_sym_signed] = ACTIONS(1917),
    [anon_sym_unsigned] = ACTIONS(1917),
    [anon_sym_long] = ACTIONS(1917),
    [anon_sym_short] = ACTIONS(1917),
    [anon_sym_LBRACK] = ACTIONS(1917),
    [anon_sym_static] = ACTIONS(1917),
    [anon_sym_EQ] = ACTIONS(1919),
    [anon_sym_register] = ACTIONS(1917),
    [anon_sym_inline] = ACTIONS(1917),
    [anon_sym___inline] = ACTIONS(1917),
    [anon_sym___inline__] = ACTIONS(1917),
    [anon_sym___forceinline] = ACTIONS(1917),
    [anon_sym_thread_local] = ACTIONS(1917),
    [anon_sym___thread] = ACTIONS(1917),
    [anon_sym_const] = ACTIONS(1917),
    [anon_sym_constexpr] = ACTIONS(1917),
    [anon_sym_volatile] = ACTIONS(1917),
    [anon_sym_restrict] = ACTIONS(1917),
    [anon_sym___restrict__] = ACTIONS(1917),
    [anon_sym__Atomic] = ACTIONS(1917),
    [anon_sym__Noreturn] = ACTIONS(1917),
    [anon_sym_noreturn] = ACTIONS(1917),
    [anon_sym_mutable] = ACTIONS(1917),
    [anon_sym_constinit] = ACTIONS(1917),
    [anon_sym_consteval] = ACTIONS(1917),
    [anon_sym_alignas] = ACTIONS(1917),
    [anon_sym__Alignas] = ACTIONS(1917),
    [sym_primitive_type] = ACTIONS(1917),
    [anon_sym_enum] = ACTIONS(1917),
    [anon_sym_class] = ACTIONS(1917),
    [anon_sym_struct] = ACTIONS(1917),
    [anon_sym_union] = ACTIONS(1917),
    [anon_sym_if] = ACTIONS(1917),
    [anon_sym_else] = ACTIONS(1917),
    [anon_sym_switch] = ACTIONS(1917),
    [anon_sym_case] = ACTIONS(1917),
    [anon_sym_default] = ACTIONS(1917),
    [anon_sym_while] = ACTIONS(1917),
    [anon_sym_do] = ACTIONS(1917),
    [anon_sym_for] = ACTIONS(1917),
    [anon_sym_return] = ACTIONS(1917),
    [anon_sym_break] = ACTIONS(1917),
    [anon_sym_continue] = ACTIONS(1917),
    [anon_sym_goto] = ACTIONS(1917),
    [anon_sym___try] = ACTIONS(1917),
    [anon_sym___leave] = ACTIONS(1917),
    [anon_sym_not] = ACTIONS(1917),
    [anon_sym_compl] = ACTIONS(1917),
    [anon_sym_or] = ACTIONS(1917),
    [anon_sym_and] = ACTIONS(1917),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_sizeof] = ACTIONS(1917),
    [anon_sym___alignof__] = ACTIONS(1917),
    [anon_sym___alignof] = ACTIONS(1917),
    [anon_sym__alignof] = ACTIONS(1917),
    [anon_sym_alignof] = ACTIONS(1917),
    [anon_sym__Alignof] = ACTIONS(1917),
    [anon_sym_offsetof] = ACTIONS(1917),
    [anon_sym__Generic] = ACTIONS(1917),
    [anon_sym_asm] = ACTIONS(1917),
    [anon_sym___asm__] = ACTIONS(1917),
    [sym_number_literal] = ACTIONS(1919),
    [anon_sym_L_SQUOTE] = ACTIONS(1919),
    [anon_sym_u_SQUOTE] = ACTIONS(1919),
    [anon_sym_U_SQUOTE] = ACTIONS(1919),
    [anon_sym_u8_SQUOTE] = ACTIONS(1919),
    [anon_sym_SQUOTE] = ACTIONS(1919),
    [anon_sym_L_DQUOTE] = ACTIONS(1919),
    [anon_sym_u_DQUOTE] = ACTIONS(1919),
    [anon_sym_U_DQUOTE] = ACTIONS(1919),
    [anon_sym_u8_DQUOTE] = ACTIONS(1919),
    [anon_sym_DQUOTE] = ACTIONS(1919),
    [sym_true] = ACTIONS(1917),
    [sym_false] = ACTIONS(1917),
    [anon_sym_NULL] = ACTIONS(1917),
    [anon_sym_nullptr] = ACTIONS(1917),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1917),
    [anon_sym_decltype] = ACTIONS(1917),
    [anon_sym_final] = ACTIONS(1917),
    [anon_sym_override] = ACTIONS(1917),
    [sym_virtual] = ACTIONS(1917),
    [anon_sym_explicit] = ACTIONS(1917),
    [anon_sym_typename] = ACTIONS(1917),
    [anon_sym_template] = ACTIONS(1917),
    [anon_sym_GT2] = ACTIONS(1919),
    [anon_sym_operator] = ACTIONS(1917),
    [anon_sym_try] = ACTIONS(1917),
    [anon_sym_delete] = ACTIONS(1917),
    [anon_sym_throw] = ACTIONS(1917),
    [anon_sym_namespace] = ACTIONS(1917),
    [anon_sym_using] = ACTIONS(1917),
    [anon_sym_static_assert] = ACTIONS(1917),
    [anon_sym_concept] = ACTIONS(1917),
    [anon_sym_co_return] = ACTIONS(1917),
    [anon_sym_co_yield] = ACTIONS(1917),
    [anon_sym_R_DQUOTE] = ACTIONS(1919),
    [anon_sym_LR_DQUOTE] = ACTIONS(1919),
    [anon_sym_uR_DQUOTE] = ACTIONS(1919),
    [anon_sym_UR_DQUOTE] = ACTIONS(1919),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1919),
    [anon_sym_co_await] = ACTIONS(1917),
    [anon_sym_new] = ACTIONS(1917),
    [anon_sym_requires] = ACTIONS(1917),
    [sym_this] = ACTIONS(1917),
    [anon_sym_discard] = ACTIONS(1917),
    [anon_sym_precise] = ACTIONS(1917),
    [anon_sym_shared] = ACTIONS(1917),
    [anon_sym_groupshared] = ACTIONS(1917),
    [anon_sym_uniform] = ACTIONS(1917),
    [anon_sym_row_major] = ACTIONS(1917),
    [anon_sym_column_major] = ACTIONS(1917),
    [anon_sym_globallycoherent] = ACTIONS(1917),
    [anon_sym_centroid] = ACTIONS(1917),
    [anon_sym_noperspective] = ACTIONS(1917),
    [anon_sym_nointerpolation] = ACTIONS(1917),
    [anon_sym_sample] = ACTIONS(1917),
    [anon_sym_linear] = ACTIONS(1917),
    [anon_sym_snorm] = ACTIONS(1917),
    [anon_sym_unorm] = ACTIONS(1917),
    [anon_sym_point] = ACTIONS(1917),
    [anon_sym_line] = ACTIONS(1917),
    [anon_sym_triangleadj] = ACTIONS(1917),
    [anon_sym_lineadj] = ACTIONS(1917),
    [anon_sym_triangle] = ACTIONS(1917),
    [anon_sym_cbuffer] = ACTIONS(1917),
  },
  [135] = {
    [sym_field_declaration_list] = STATE(229),
    [sym_virtual_specifier] = STATE(6982),
    [sym_base_class_clause] = STATE(7773),
    [sym_identifier] = ACTIONS(1921),
    [aux_sym_preproc_include_token1] = ACTIONS(1921),
    [aux_sym_preproc_def_token1] = ACTIONS(1921),
    [aux_sym_preproc_if_token1] = ACTIONS(1921),
    [aux_sym_preproc_if_token2] = ACTIONS(1921),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1921),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1921),
    [aux_sym_preproc_else_token1] = ACTIONS(1921),
    [aux_sym_preproc_elif_token1] = ACTIONS(1921),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1921),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1921),
    [sym_preproc_directive] = ACTIONS(1921),
    [anon_sym_LPAREN2] = ACTIONS(1923),
    [anon_sym_BANG] = ACTIONS(1923),
    [anon_sym_TILDE] = ACTIONS(1923),
    [anon_sym_DASH] = ACTIONS(1921),
    [anon_sym_PLUS] = ACTIONS(1921),
    [anon_sym_STAR] = ACTIONS(1923),
    [anon_sym_AMP_AMP] = ACTIONS(1923),
    [anon_sym_AMP] = ACTIONS(1921),
    [anon_sym_COLON] = ACTIONS(1911),
    [anon_sym_SEMI] = ACTIONS(1923),
    [anon_sym___extension__] = ACTIONS(1921),
    [anon_sym_typedef] = ACTIONS(1921),
    [anon_sym_in] = ACTIONS(1921),
    [anon_sym_out] = ACTIONS(1921),
    [anon_sym_inout] = ACTIONS(1921),
    [anon_sym_extern] = ACTIONS(1921),
    [anon_sym___attribute__] = ACTIONS(1921),
    [anon_sym_COLON_COLON] = ACTIONS(1923),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1923),
    [anon_sym___declspec] = ACTIONS(1921),
    [anon_sym___based] = ACTIONS(1921),
    [anon_sym___cdecl] = ACTIONS(1921),
    [anon_sym___clrcall] = ACTIONS(1921),
    [anon_sym___stdcall] = ACTIONS(1921),
    [anon_sym___fastcall] = ACTIONS(1921),
    [anon_sym___thiscall] = ACTIONS(1921),
    [anon_sym___vectorcall] = ACTIONS(1921),
    [anon_sym_LBRACE] = ACTIONS(1913),
    [anon_sym_signed] = ACTIONS(1921),
    [anon_sym_unsigned] = ACTIONS(1921),
    [anon_sym_long] = ACTIONS(1921),
    [anon_sym_short] = ACTIONS(1921),
    [anon_sym_LBRACK] = ACTIONS(1921),
    [anon_sym_static] = ACTIONS(1921),
    [anon_sym_register] = ACTIONS(1921),
    [anon_sym_inline] = ACTIONS(1921),
    [anon_sym___inline] = ACTIONS(1921),
    [anon_sym___inline__] = ACTIONS(1921),
    [anon_sym___forceinline] = ACTIONS(1921),
    [anon_sym_thread_local] = ACTIONS(1921),
    [anon_sym___thread] = ACTIONS(1921),
    [anon_sym_const] = ACTIONS(1921),
    [anon_sym_constexpr] = ACTIONS(1921),
    [anon_sym_volatile] = ACTIONS(1921),
    [anon_sym_restrict] = ACTIONS(1921),
    [anon_sym___restrict__] = ACTIONS(1921),
    [anon_sym__Atomic] = ACTIONS(1921),
    [anon_sym__Noreturn] = ACTIONS(1921),
    [anon_sym_noreturn] = ACTIONS(1921),
    [anon_sym_mutable] = ACTIONS(1921),
    [anon_sym_constinit] = ACTIONS(1921),
    [anon_sym_consteval] = ACTIONS(1921),
    [anon_sym_alignas] = ACTIONS(1921),
    [anon_sym__Alignas] = ACTIONS(1921),
    [sym_primitive_type] = ACTIONS(1921),
    [anon_sym_enum] = ACTIONS(1921),
    [anon_sym_class] = ACTIONS(1921),
    [anon_sym_struct] = ACTIONS(1921),
    [anon_sym_union] = ACTIONS(1921),
    [anon_sym_if] = ACTIONS(1921),
    [anon_sym_else] = ACTIONS(1921),
    [anon_sym_switch] = ACTIONS(1921),
    [anon_sym_case] = ACTIONS(1921),
    [anon_sym_default] = ACTIONS(1921),
    [anon_sym_while] = ACTIONS(1921),
    [anon_sym_do] = ACTIONS(1921),
    [anon_sym_for] = ACTIONS(1921),
    [anon_sym_return] = ACTIONS(1921),
    [anon_sym_break] = ACTIONS(1921),
    [anon_sym_continue] = ACTIONS(1921),
    [anon_sym_goto] = ACTIONS(1921),
    [anon_sym___try] = ACTIONS(1921),
    [anon_sym___leave] = ACTIONS(1921),
    [anon_sym_not] = ACTIONS(1921),
    [anon_sym_compl] = ACTIONS(1921),
    [anon_sym_DASH_DASH] = ACTIONS(1923),
    [anon_sym_PLUS_PLUS] = ACTIONS(1923),
    [anon_sym_sizeof] = ACTIONS(1921),
    [anon_sym___alignof__] = ACTIONS(1921),
    [anon_sym___alignof] = ACTIONS(1921),
    [anon_sym__alignof] = ACTIONS(1921),
    [anon_sym_alignof] = ACTIONS(1921),
    [anon_sym__Alignof] = ACTIONS(1921),
    [anon_sym_offsetof] = ACTIONS(1921),
    [anon_sym__Generic] = ACTIONS(1921),
    [anon_sym_asm] = ACTIONS(1921),
    [anon_sym___asm__] = ACTIONS(1921),
    [sym_number_literal] = ACTIONS(1923),
    [anon_sym_L_SQUOTE] = ACTIONS(1923),
    [anon_sym_u_SQUOTE] = ACTIONS(1923),
    [anon_sym_U_SQUOTE] = ACTIONS(1923),
    [anon_sym_u8_SQUOTE] = ACTIONS(1923),
    [anon_sym_SQUOTE] = ACTIONS(1923),
    [anon_sym_L_DQUOTE] = ACTIONS(1923),
    [anon_sym_u_DQUOTE] = ACTIONS(1923),
    [anon_sym_U_DQUOTE] = ACTIONS(1923),
    [anon_sym_u8_DQUOTE] = ACTIONS(1923),
    [anon_sym_DQUOTE] = ACTIONS(1923),
    [sym_true] = ACTIONS(1921),
    [sym_false] = ACTIONS(1921),
    [anon_sym_NULL] = ACTIONS(1921),
    [anon_sym_nullptr] = ACTIONS(1921),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1921),
    [anon_sym_decltype] = ACTIONS(1921),
    [anon_sym_final] = ACTIONS(1915),
    [anon_sym_override] = ACTIONS(1915),
    [sym_virtual] = ACTIONS(1921),
    [anon_sym_explicit] = ACTIONS(1921),
    [anon_sym_typename] = ACTIONS(1921),
    [anon_sym_template] = ACTIONS(1921),
    [anon_sym_operator] = ACTIONS(1921),
    [anon_sym_try] = ACTIONS(1921),
    [anon_sym_delete] = ACTIONS(1921),
    [anon_sym_throw] = ACTIONS(1921),
    [anon_sym_namespace] = ACTIONS(1921),
    [anon_sym_using] = ACTIONS(1921),
    [anon_sym_static_assert] = ACTIONS(1921),
    [anon_sym_concept] = ACTIONS(1921),
    [anon_sym_co_return] = ACTIONS(1921),
    [anon_sym_co_yield] = ACTIONS(1921),
    [anon_sym_R_DQUOTE] = ACTIONS(1923),
    [anon_sym_LR_DQUOTE] = ACTIONS(1923),
    [anon_sym_uR_DQUOTE] = ACTIONS(1923),
    [anon_sym_UR_DQUOTE] = ACTIONS(1923),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1923),
    [anon_sym_co_await] = ACTIONS(1921),
    [anon_sym_new] = ACTIONS(1921),
    [anon_sym_requires] = ACTIONS(1921),
    [sym_this] = ACTIONS(1921),
    [anon_sym_discard] = ACTIONS(1921),
    [anon_sym_precise] = ACTIONS(1921),
    [anon_sym_shared] = ACTIONS(1921),
    [anon_sym_groupshared] = ACTIONS(1921),
    [anon_sym_uniform] = ACTIONS(1921),
    [anon_sym_row_major] = ACTIONS(1921),
    [anon_sym_column_major] = ACTIONS(1921),
    [anon_sym_globallycoherent] = ACTIONS(1921),
    [anon_sym_centroid] = ACTIONS(1921),
    [anon_sym_noperspective] = ACTIONS(1921),
    [anon_sym_nointerpolation] = ACTIONS(1921),
    [anon_sym_sample] = ACTIONS(1921),
    [anon_sym_linear] = ACTIONS(1921),
    [anon_sym_snorm] = ACTIONS(1921),
    [anon_sym_unorm] = ACTIONS(1921),
    [anon_sym_point] = ACTIONS(1921),
    [anon_sym_line] = ACTIONS(1921),
    [anon_sym_triangleadj] = ACTIONS(1921),
    [anon_sym_lineadj] = ACTIONS(1921),
    [anon_sym_triangle] = ACTIONS(1921),
    [anon_sym_cbuffer] = ACTIONS(1921),
  },
  [136] = {
    [sym_identifier] = ACTIONS(1925),
    [aux_sym_preproc_include_token1] = ACTIONS(1925),
    [aux_sym_preproc_def_token1] = ACTIONS(1925),
    [anon_sym_COMMA] = ACTIONS(1927),
    [anon_sym_RPAREN] = ACTIONS(1927),
    [aux_sym_preproc_if_token1] = ACTIONS(1925),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1925),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1925),
    [sym_preproc_directive] = ACTIONS(1925),
    [anon_sym_LPAREN2] = ACTIONS(1927),
    [anon_sym_BANG] = ACTIONS(1927),
    [anon_sym_TILDE] = ACTIONS(1927),
    [anon_sym_DASH] = ACTIONS(1925),
    [anon_sym_PLUS] = ACTIONS(1925),
    [anon_sym_STAR] = ACTIONS(1927),
    [anon_sym_PIPE_PIPE] = ACTIONS(1927),
    [anon_sym_AMP_AMP] = ACTIONS(1927),
    [anon_sym_AMP] = ACTIONS(1925),
    [anon_sym_COLON] = ACTIONS(1925),
    [anon_sym_SEMI] = ACTIONS(1927),
    [anon_sym___extension__] = ACTIONS(1925),
    [anon_sym_typedef] = ACTIONS(1925),
    [anon_sym_in] = ACTIONS(1925),
    [anon_sym_out] = ACTIONS(1925),
    [anon_sym_inout] = ACTIONS(1925),
    [anon_sym_extern] = ACTIONS(1925),
    [anon_sym___attribute__] = ACTIONS(1925),
    [anon_sym_COLON_COLON] = ACTIONS(1927),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1927),
    [anon_sym___declspec] = ACTIONS(1925),
    [anon_sym___based] = ACTIONS(1925),
    [anon_sym___cdecl] = ACTIONS(1925),
    [anon_sym___clrcall] = ACTIONS(1925),
    [anon_sym___stdcall] = ACTIONS(1925),
    [anon_sym___fastcall] = ACTIONS(1925),
    [anon_sym___thiscall] = ACTIONS(1925),
    [anon_sym___vectorcall] = ACTIONS(1925),
    [anon_sym_LBRACE] = ACTIONS(1927),
    [anon_sym_RBRACE] = ACTIONS(1927),
    [anon_sym_signed] = ACTIONS(1925),
    [anon_sym_unsigned] = ACTIONS(1925),
    [anon_sym_long] = ACTIONS(1925),
    [anon_sym_short] = ACTIONS(1925),
    [anon_sym_LBRACK] = ACTIONS(1925),
    [anon_sym_static] = ACTIONS(1925),
    [anon_sym_EQ] = ACTIONS(1927),
    [anon_sym_register] = ACTIONS(1925),
    [anon_sym_inline] = ACTIONS(1925),
    [anon_sym___inline] = ACTIONS(1925),
    [anon_sym___inline__] = ACTIONS(1925),
    [anon_sym___forceinline] = ACTIONS(1925),
    [anon_sym_thread_local] = ACTIONS(1925),
    [anon_sym___thread] = ACTIONS(1925),
    [anon_sym_const] = ACTIONS(1925),
    [anon_sym_constexpr] = ACTIONS(1925),
    [anon_sym_volatile] = ACTIONS(1925),
    [anon_sym_restrict] = ACTIONS(1925),
    [anon_sym___restrict__] = ACTIONS(1925),
    [anon_sym__Atomic] = ACTIONS(1925),
    [anon_sym__Noreturn] = ACTIONS(1925),
    [anon_sym_noreturn] = ACTIONS(1925),
    [anon_sym_mutable] = ACTIONS(1925),
    [anon_sym_constinit] = ACTIONS(1925),
    [anon_sym_consteval] = ACTIONS(1925),
    [anon_sym_alignas] = ACTIONS(1925),
    [anon_sym__Alignas] = ACTIONS(1925),
    [sym_primitive_type] = ACTIONS(1925),
    [anon_sym_enum] = ACTIONS(1925),
    [anon_sym_class] = ACTIONS(1925),
    [anon_sym_struct] = ACTIONS(1925),
    [anon_sym_union] = ACTIONS(1925),
    [anon_sym_if] = ACTIONS(1925),
    [anon_sym_else] = ACTIONS(1925),
    [anon_sym_switch] = ACTIONS(1925),
    [anon_sym_case] = ACTIONS(1925),
    [anon_sym_default] = ACTIONS(1925),
    [anon_sym_while] = ACTIONS(1925),
    [anon_sym_do] = ACTIONS(1925),
    [anon_sym_for] = ACTIONS(1925),
    [anon_sym_return] = ACTIONS(1925),
    [anon_sym_break] = ACTIONS(1925),
    [anon_sym_continue] = ACTIONS(1925),
    [anon_sym_goto] = ACTIONS(1925),
    [anon_sym___try] = ACTIONS(1925),
    [anon_sym___leave] = ACTIONS(1925),
    [anon_sym_not] = ACTIONS(1925),
    [anon_sym_compl] = ACTIONS(1925),
    [anon_sym_or] = ACTIONS(1925),
    [anon_sym_and] = ACTIONS(1925),
    [anon_sym_DASH_DASH] = ACTIONS(1927),
    [anon_sym_PLUS_PLUS] = ACTIONS(1927),
    [anon_sym_sizeof] = ACTIONS(1925),
    [anon_sym___alignof__] = ACTIONS(1925),
    [anon_sym___alignof] = ACTIONS(1925),
    [anon_sym__alignof] = ACTIONS(1925),
    [anon_sym_alignof] = ACTIONS(1925),
    [anon_sym__Alignof] = ACTIONS(1925),
    [anon_sym_offsetof] = ACTIONS(1925),
    [anon_sym__Generic] = ACTIONS(1925),
    [anon_sym_asm] = ACTIONS(1925),
    [anon_sym___asm__] = ACTIONS(1925),
    [sym_number_literal] = ACTIONS(1927),
    [anon_sym_L_SQUOTE] = ACTIONS(1927),
    [anon_sym_u_SQUOTE] = ACTIONS(1927),
    [anon_sym_U_SQUOTE] = ACTIONS(1927),
    [anon_sym_u8_SQUOTE] = ACTIONS(1927),
    [anon_sym_SQUOTE] = ACTIONS(1927),
    [anon_sym_L_DQUOTE] = ACTIONS(1927),
    [anon_sym_u_DQUOTE] = ACTIONS(1927),
    [anon_sym_U_DQUOTE] = ACTIONS(1927),
    [anon_sym_u8_DQUOTE] = ACTIONS(1927),
    [anon_sym_DQUOTE] = ACTIONS(1927),
    [sym_true] = ACTIONS(1925),
    [sym_false] = ACTIONS(1925),
    [anon_sym_NULL] = ACTIONS(1925),
    [anon_sym_nullptr] = ACTIONS(1925),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1925),
    [anon_sym_decltype] = ACTIONS(1925),
    [anon_sym_final] = ACTIONS(1925),
    [anon_sym_override] = ACTIONS(1925),
    [sym_virtual] = ACTIONS(1925),
    [anon_sym_explicit] = ACTIONS(1925),
    [anon_sym_typename] = ACTIONS(1925),
    [anon_sym_template] = ACTIONS(1925),
    [anon_sym_GT2] = ACTIONS(1927),
    [anon_sym_operator] = ACTIONS(1925),
    [anon_sym_try] = ACTIONS(1925),
    [anon_sym_delete] = ACTIONS(1925),
    [anon_sym_throw] = ACTIONS(1925),
    [anon_sym_namespace] = ACTIONS(1925),
    [anon_sym_using] = ACTIONS(1925),
    [anon_sym_static_assert] = ACTIONS(1925),
    [anon_sym_concept] = ACTIONS(1925),
    [anon_sym_co_return] = ACTIONS(1925),
    [anon_sym_co_yield] = ACTIONS(1925),
    [anon_sym_R_DQUOTE] = ACTIONS(1927),
    [anon_sym_LR_DQUOTE] = ACTIONS(1927),
    [anon_sym_uR_DQUOTE] = ACTIONS(1927),
    [anon_sym_UR_DQUOTE] = ACTIONS(1927),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1927),
    [anon_sym_co_await] = ACTIONS(1925),
    [anon_sym_new] = ACTIONS(1925),
    [anon_sym_requires] = ACTIONS(1925),
    [sym_this] = ACTIONS(1925),
    [anon_sym_discard] = ACTIONS(1925),
    [anon_sym_precise] = ACTIONS(1925),
    [anon_sym_shared] = ACTIONS(1925),
    [anon_sym_groupshared] = ACTIONS(1925),
    [anon_sym_uniform] = ACTIONS(1925),
    [anon_sym_row_major] = ACTIONS(1925),
    [anon_sym_column_major] = ACTIONS(1925),
    [anon_sym_globallycoherent] = ACTIONS(1925),
    [anon_sym_centroid] = ACTIONS(1925),
    [anon_sym_noperspective] = ACTIONS(1925),
    [anon_sym_nointerpolation] = ACTIONS(1925),
    [anon_sym_sample] = ACTIONS(1925),
    [anon_sym_linear] = ACTIONS(1925),
    [anon_sym_snorm] = ACTIONS(1925),
    [anon_sym_unorm] = ACTIONS(1925),
    [anon_sym_point] = ACTIONS(1925),
    [anon_sym_line] = ACTIONS(1925),
    [anon_sym_triangleadj] = ACTIONS(1925),
    [anon_sym_lineadj] = ACTIONS(1925),
    [anon_sym_triangle] = ACTIONS(1925),
    [anon_sym_cbuffer] = ACTIONS(1925),
  },
  [137] = {
    [ts_builtin_sym_end] = ACTIONS(1929),
    [sym_identifier] = ACTIONS(1931),
    [aux_sym_preproc_include_token1] = ACTIONS(1931),
    [aux_sym_preproc_def_token1] = ACTIONS(1931),
    [anon_sym_COMMA] = ACTIONS(1929),
    [anon_sym_RPAREN] = ACTIONS(1929),
    [aux_sym_preproc_if_token1] = ACTIONS(1931),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1931),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1931),
    [sym_preproc_directive] = ACTIONS(1931),
    [anon_sym_LPAREN2] = ACTIONS(1929),
    [anon_sym_BANG] = ACTIONS(1929),
    [anon_sym_TILDE] = ACTIONS(1929),
    [anon_sym_DASH] = ACTIONS(1931),
    [anon_sym_PLUS] = ACTIONS(1931),
    [anon_sym_STAR] = ACTIONS(1929),
    [anon_sym_PIPE_PIPE] = ACTIONS(1929),
    [anon_sym_AMP_AMP] = ACTIONS(1929),
    [anon_sym_AMP] = ACTIONS(1931),
    [anon_sym_SEMI] = ACTIONS(1929),
    [anon_sym___extension__] = ACTIONS(1931),
    [anon_sym_typedef] = ACTIONS(1931),
    [anon_sym_in] = ACTIONS(1931),
    [anon_sym_out] = ACTIONS(1931),
    [anon_sym_inout] = ACTIONS(1931),
    [anon_sym_extern] = ACTIONS(1931),
    [anon_sym___attribute__] = ACTIONS(1931),
    [anon_sym_COLON_COLON] = ACTIONS(1929),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1929),
    [anon_sym___declspec] = ACTIONS(1931),
    [anon_sym___based] = ACTIONS(1931),
    [anon_sym___cdecl] = ACTIONS(1931),
    [anon_sym___clrcall] = ACTIONS(1931),
    [anon_sym___stdcall] = ACTIONS(1931),
    [anon_sym___fastcall] = ACTIONS(1931),
    [anon_sym___thiscall] = ACTIONS(1931),
    [anon_sym___vectorcall] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1929),
    [anon_sym_signed] = ACTIONS(1931),
    [anon_sym_unsigned] = ACTIONS(1931),
    [anon_sym_long] = ACTIONS(1931),
    [anon_sym_short] = ACTIONS(1931),
    [anon_sym_LBRACK] = ACTIONS(1931),
    [anon_sym_static] = ACTIONS(1931),
    [anon_sym_register] = ACTIONS(1931),
    [anon_sym_inline] = ACTIONS(1931),
    [anon_sym___inline] = ACTIONS(1931),
    [anon_sym___inline__] = ACTIONS(1931),
    [anon_sym___forceinline] = ACTIONS(1931),
    [anon_sym_thread_local] = ACTIONS(1931),
    [anon_sym___thread] = ACTIONS(1931),
    [anon_sym_const] = ACTIONS(1931),
    [anon_sym_constexpr] = ACTIONS(1931),
    [anon_sym_volatile] = ACTIONS(1931),
    [anon_sym_restrict] = ACTIONS(1931),
    [anon_sym___restrict__] = ACTIONS(1931),
    [anon_sym__Atomic] = ACTIONS(1931),
    [anon_sym__Noreturn] = ACTIONS(1931),
    [anon_sym_noreturn] = ACTIONS(1931),
    [anon_sym_mutable] = ACTIONS(1931),
    [anon_sym_constinit] = ACTIONS(1931),
    [anon_sym_consteval] = ACTIONS(1931),
    [anon_sym_alignas] = ACTIONS(1931),
    [anon_sym__Alignas] = ACTIONS(1931),
    [sym_primitive_type] = ACTIONS(1931),
    [anon_sym_enum] = ACTIONS(1931),
    [anon_sym_class] = ACTIONS(1931),
    [anon_sym_struct] = ACTIONS(1931),
    [anon_sym_union] = ACTIONS(1931),
    [anon_sym_if] = ACTIONS(1931),
    [anon_sym_else] = ACTIONS(1931),
    [anon_sym_switch] = ACTIONS(1931),
    [anon_sym_case] = ACTIONS(1931),
    [anon_sym_default] = ACTIONS(1931),
    [anon_sym_while] = ACTIONS(1931),
    [anon_sym_do] = ACTIONS(1931),
    [anon_sym_for] = ACTIONS(1931),
    [anon_sym_return] = ACTIONS(1931),
    [anon_sym_break] = ACTIONS(1931),
    [anon_sym_continue] = ACTIONS(1931),
    [anon_sym_goto] = ACTIONS(1931),
    [anon_sym___try] = ACTIONS(1931),
    [anon_sym___except] = ACTIONS(1931),
    [anon_sym___finally] = ACTIONS(1931),
    [anon_sym___leave] = ACTIONS(1931),
    [anon_sym_not] = ACTIONS(1931),
    [anon_sym_compl] = ACTIONS(1931),
    [anon_sym_or] = ACTIONS(1931),
    [anon_sym_and] = ACTIONS(1931),
    [anon_sym_DASH_DASH] = ACTIONS(1929),
    [anon_sym_PLUS_PLUS] = ACTIONS(1929),
    [anon_sym_sizeof] = ACTIONS(1931),
    [anon_sym___alignof__] = ACTIONS(1931),
    [anon_sym___alignof] = ACTIONS(1931),
    [anon_sym__alignof] = ACTIONS(1931),
    [anon_sym_alignof] = ACTIONS(1931),
    [anon_sym__Alignof] = ACTIONS(1931),
    [anon_sym_offsetof] = ACTIONS(1931),
    [anon_sym__Generic] = ACTIONS(1931),
    [anon_sym_asm] = ACTIONS(1931),
    [anon_sym___asm__] = ACTIONS(1931),
    [sym_number_literal] = ACTIONS(1929),
    [anon_sym_L_SQUOTE] = ACTIONS(1929),
    [anon_sym_u_SQUOTE] = ACTIONS(1929),
    [anon_sym_U_SQUOTE] = ACTIONS(1929),
    [anon_sym_u8_SQUOTE] = ACTIONS(1929),
    [anon_sym_SQUOTE] = ACTIONS(1929),
    [anon_sym_L_DQUOTE] = ACTIONS(1929),
    [anon_sym_u_DQUOTE] = ACTIONS(1929),
    [anon_sym_U_DQUOTE] = ACTIONS(1929),
    [anon_sym_u8_DQUOTE] = ACTIONS(1929),
    [anon_sym_DQUOTE] = ACTIONS(1929),
    [sym_true] = ACTIONS(1931),
    [sym_false] = ACTIONS(1931),
    [anon_sym_NULL] = ACTIONS(1931),
    [anon_sym_nullptr] = ACTIONS(1931),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1931),
    [anon_sym_decltype] = ACTIONS(1931),
    [anon_sym_final] = ACTIONS(1931),
    [anon_sym_override] = ACTIONS(1931),
    [sym_virtual] = ACTIONS(1931),
    [anon_sym_explicit] = ACTIONS(1931),
    [anon_sym_typename] = ACTIONS(1931),
    [anon_sym_template] = ACTIONS(1931),
    [anon_sym_operator] = ACTIONS(1931),
    [anon_sym_try] = ACTIONS(1931),
    [anon_sym_delete] = ACTIONS(1931),
    [anon_sym_throw] = ACTIONS(1931),
    [anon_sym_namespace] = ACTIONS(1931),
    [anon_sym_using] = ACTIONS(1931),
    [anon_sym_static_assert] = ACTIONS(1931),
    [anon_sym_concept] = ACTIONS(1931),
    [anon_sym_co_return] = ACTIONS(1931),
    [anon_sym_co_yield] = ACTIONS(1931),
    [anon_sym_catch] = ACTIONS(1931),
    [anon_sym_R_DQUOTE] = ACTIONS(1929),
    [anon_sym_LR_DQUOTE] = ACTIONS(1929),
    [anon_sym_uR_DQUOTE] = ACTIONS(1929),
    [anon_sym_UR_DQUOTE] = ACTIONS(1929),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1929),
    [anon_sym_co_await] = ACTIONS(1931),
    [anon_sym_new] = ACTIONS(1931),
    [anon_sym_requires] = ACTIONS(1931),
    [sym_this] = ACTIONS(1931),
    [anon_sym_discard] = ACTIONS(1931),
    [anon_sym_precise] = ACTIONS(1931),
    [anon_sym_shared] = ACTIONS(1931),
    [anon_sym_groupshared] = ACTIONS(1931),
    [anon_sym_uniform] = ACTIONS(1931),
    [anon_sym_row_major] = ACTIONS(1931),
    [anon_sym_column_major] = ACTIONS(1931),
    [anon_sym_globallycoherent] = ACTIONS(1931),
    [anon_sym_centroid] = ACTIONS(1931),
    [anon_sym_noperspective] = ACTIONS(1931),
    [anon_sym_nointerpolation] = ACTIONS(1931),
    [anon_sym_sample] = ACTIONS(1931),
    [anon_sym_linear] = ACTIONS(1931),
    [anon_sym_snorm] = ACTIONS(1931),
    [anon_sym_unorm] = ACTIONS(1931),
    [anon_sym_point] = ACTIONS(1931),
    [anon_sym_line] = ACTIONS(1931),
    [anon_sym_triangleadj] = ACTIONS(1931),
    [anon_sym_lineadj] = ACTIONS(1931),
    [anon_sym_triangle] = ACTIONS(1931),
    [anon_sym_cbuffer] = ACTIONS(1931),
  },
  [138] = {
    [sym_template_argument_list] = STATE(146),
    [sym_identifier] = ACTIONS(1933),
    [aux_sym_preproc_include_token1] = ACTIONS(1933),
    [aux_sym_preproc_def_token1] = ACTIONS(1933),
    [aux_sym_preproc_if_token1] = ACTIONS(1933),
    [aux_sym_preproc_if_token2] = ACTIONS(1933),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1933),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1933),
    [aux_sym_preproc_else_token1] = ACTIONS(1933),
    [aux_sym_preproc_elif_token1] = ACTIONS(1933),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1933),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1933),
    [sym_preproc_directive] = ACTIONS(1933),
    [anon_sym_LPAREN2] = ACTIONS(1935),
    [anon_sym_BANG] = ACTIONS(1935),
    [anon_sym_TILDE] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1933),
    [anon_sym_PLUS] = ACTIONS(1933),
    [anon_sym_STAR] = ACTIONS(1935),
    [anon_sym_AMP_AMP] = ACTIONS(1935),
    [anon_sym_AMP] = ACTIONS(1933),
    [anon_sym_LT] = ACTIONS(1937),
    [anon_sym_COLON] = ACTIONS(1933),
    [anon_sym_SEMI] = ACTIONS(1935),
    [anon_sym___extension__] = ACTIONS(1933),
    [anon_sym_typedef] = ACTIONS(1933),
    [anon_sym_in] = ACTIONS(1933),
    [anon_sym_out] = ACTIONS(1933),
    [anon_sym_inout] = ACTIONS(1933),
    [anon_sym_extern] = ACTIONS(1933),
    [anon_sym___attribute__] = ACTIONS(1933),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1935),
    [anon_sym___declspec] = ACTIONS(1933),
    [anon_sym___based] = ACTIONS(1933),
    [anon_sym___cdecl] = ACTIONS(1933),
    [anon_sym___clrcall] = ACTIONS(1933),
    [anon_sym___stdcall] = ACTIONS(1933),
    [anon_sym___fastcall] = ACTIONS(1933),
    [anon_sym___thiscall] = ACTIONS(1933),
    [anon_sym___vectorcall] = ACTIONS(1933),
    [anon_sym_LBRACE] = ACTIONS(1935),
    [anon_sym_signed] = ACTIONS(1933),
    [anon_sym_unsigned] = ACTIONS(1933),
    [anon_sym_long] = ACTIONS(1933),
    [anon_sym_short] = ACTIONS(1933),
    [anon_sym_LBRACK] = ACTIONS(1933),
    [anon_sym_static] = ACTIONS(1933),
    [anon_sym_register] = ACTIONS(1933),
    [anon_sym_inline] = ACTIONS(1933),
    [anon_sym___inline] = ACTIONS(1933),
    [anon_sym___inline__] = ACTIONS(1933),
    [anon_sym___forceinline] = ACTIONS(1933),
    [anon_sym_thread_local] = ACTIONS(1933),
    [anon_sym___thread] = ACTIONS(1933),
    [anon_sym_const] = ACTIONS(1933),
    [anon_sym_constexpr] = ACTIONS(1933),
    [anon_sym_volatile] = ACTIONS(1933),
    [anon_sym_restrict] = ACTIONS(1933),
    [anon_sym___restrict__] = ACTIONS(1933),
    [anon_sym__Atomic] = ACTIONS(1933),
    [anon_sym__Noreturn] = ACTIONS(1933),
    [anon_sym_noreturn] = ACTIONS(1933),
    [anon_sym_mutable] = ACTIONS(1933),
    [anon_sym_constinit] = ACTIONS(1933),
    [anon_sym_consteval] = ACTIONS(1933),
    [anon_sym_alignas] = ACTIONS(1933),
    [anon_sym__Alignas] = ACTIONS(1933),
    [sym_primitive_type] = ACTIONS(1933),
    [anon_sym_enum] = ACTIONS(1933),
    [anon_sym_class] = ACTIONS(1933),
    [anon_sym_struct] = ACTIONS(1933),
    [anon_sym_union] = ACTIONS(1933),
    [anon_sym_if] = ACTIONS(1933),
    [anon_sym_else] = ACTIONS(1933),
    [anon_sym_switch] = ACTIONS(1933),
    [anon_sym_case] = ACTIONS(1933),
    [anon_sym_default] = ACTIONS(1933),
    [anon_sym_while] = ACTIONS(1933),
    [anon_sym_do] = ACTIONS(1933),
    [anon_sym_for] = ACTIONS(1933),
    [anon_sym_return] = ACTIONS(1933),
    [anon_sym_break] = ACTIONS(1933),
    [anon_sym_continue] = ACTIONS(1933),
    [anon_sym_goto] = ACTIONS(1933),
    [anon_sym___try] = ACTIONS(1933),
    [anon_sym___leave] = ACTIONS(1933),
    [anon_sym_not] = ACTIONS(1933),
    [anon_sym_compl] = ACTIONS(1933),
    [anon_sym_DASH_DASH] = ACTIONS(1935),
    [anon_sym_PLUS_PLUS] = ACTIONS(1935),
    [anon_sym_sizeof] = ACTIONS(1933),
    [anon_sym___alignof__] = ACTIONS(1933),
    [anon_sym___alignof] = ACTIONS(1933),
    [anon_sym__alignof] = ACTIONS(1933),
    [anon_sym_alignof] = ACTIONS(1933),
    [anon_sym__Alignof] = ACTIONS(1933),
    [anon_sym_offsetof] = ACTIONS(1933),
    [anon_sym__Generic] = ACTIONS(1933),
    [anon_sym_asm] = ACTIONS(1933),
    [anon_sym___asm__] = ACTIONS(1933),
    [sym_number_literal] = ACTIONS(1935),
    [anon_sym_L_SQUOTE] = ACTIONS(1935),
    [anon_sym_u_SQUOTE] = ACTIONS(1935),
    [anon_sym_U_SQUOTE] = ACTIONS(1935),
    [anon_sym_u8_SQUOTE] = ACTIONS(1935),
    [anon_sym_SQUOTE] = ACTIONS(1935),
    [anon_sym_L_DQUOTE] = ACTIONS(1935),
    [anon_sym_u_DQUOTE] = ACTIONS(1935),
    [anon_sym_U_DQUOTE] = ACTIONS(1935),
    [anon_sym_u8_DQUOTE] = ACTIONS(1935),
    [anon_sym_DQUOTE] = ACTIONS(1935),
    [sym_true] = ACTIONS(1933),
    [sym_false] = ACTIONS(1933),
    [anon_sym_NULL] = ACTIONS(1933),
    [anon_sym_nullptr] = ACTIONS(1933),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1933),
    [anon_sym_decltype] = ACTIONS(1933),
    [anon_sym_final] = ACTIONS(1933),
    [anon_sym_override] = ACTIONS(1933),
    [sym_virtual] = ACTIONS(1933),
    [anon_sym_explicit] = ACTIONS(1933),
    [anon_sym_typename] = ACTIONS(1933),
    [anon_sym_template] = ACTIONS(1933),
    [anon_sym_operator] = ACTIONS(1933),
    [anon_sym_try] = ACTIONS(1933),
    [anon_sym_delete] = ACTIONS(1933),
    [anon_sym_throw] = ACTIONS(1933),
    [anon_sym_namespace] = ACTIONS(1933),
    [anon_sym_using] = ACTIONS(1933),
    [anon_sym_static_assert] = ACTIONS(1933),
    [anon_sym_concept] = ACTIONS(1933),
    [anon_sym_co_return] = ACTIONS(1933),
    [anon_sym_co_yield] = ACTIONS(1933),
    [anon_sym_R_DQUOTE] = ACTIONS(1935),
    [anon_sym_LR_DQUOTE] = ACTIONS(1935),
    [anon_sym_uR_DQUOTE] = ACTIONS(1935),
    [anon_sym_UR_DQUOTE] = ACTIONS(1935),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1935),
    [anon_sym_co_await] = ACTIONS(1933),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_requires] = ACTIONS(1933),
    [sym_this] = ACTIONS(1933),
    [anon_sym_discard] = ACTIONS(1933),
    [anon_sym_precise] = ACTIONS(1933),
    [anon_sym_shared] = ACTIONS(1933),
    [anon_sym_groupshared] = ACTIONS(1933),
    [anon_sym_uniform] = ACTIONS(1933),
    [anon_sym_row_major] = ACTIONS(1933),
    [anon_sym_column_major] = ACTIONS(1933),
    [anon_sym_globallycoherent] = ACTIONS(1933),
    [anon_sym_centroid] = ACTIONS(1933),
    [anon_sym_noperspective] = ACTIONS(1933),
    [anon_sym_nointerpolation] = ACTIONS(1933),
    [anon_sym_sample] = ACTIONS(1933),
    [anon_sym_linear] = ACTIONS(1933),
    [anon_sym_snorm] = ACTIONS(1933),
    [anon_sym_unorm] = ACTIONS(1933),
    [anon_sym_point] = ACTIONS(1933),
    [anon_sym_line] = ACTIONS(1933),
    [anon_sym_triangleadj] = ACTIONS(1933),
    [anon_sym_lineadj] = ACTIONS(1933),
    [anon_sym_triangle] = ACTIONS(1933),
    [anon_sym_cbuffer] = ACTIONS(1933),
  },
  [139] = {
    [sym_template_argument_list] = STATE(146),
    [sym_identifier] = ACTIONS(1941),
    [aux_sym_preproc_include_token1] = ACTIONS(1941),
    [aux_sym_preproc_def_token1] = ACTIONS(1941),
    [aux_sym_preproc_if_token1] = ACTIONS(1941),
    [aux_sym_preproc_if_token2] = ACTIONS(1941),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1941),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1941),
    [aux_sym_preproc_else_token1] = ACTIONS(1941),
    [aux_sym_preproc_elif_token1] = ACTIONS(1941),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1941),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1941),
    [sym_preproc_directive] = ACTIONS(1941),
    [anon_sym_LPAREN2] = ACTIONS(1943),
    [anon_sym_BANG] = ACTIONS(1943),
    [anon_sym_TILDE] = ACTIONS(1943),
    [anon_sym_DASH] = ACTIONS(1941),
    [anon_sym_PLUS] = ACTIONS(1941),
    [anon_sym_STAR] = ACTIONS(1943),
    [anon_sym_AMP_AMP] = ACTIONS(1943),
    [anon_sym_AMP] = ACTIONS(1941),
    [anon_sym_LT] = ACTIONS(1937),
    [anon_sym_COLON] = ACTIONS(1941),
    [anon_sym_SEMI] = ACTIONS(1943),
    [anon_sym___extension__] = ACTIONS(1941),
    [anon_sym_typedef] = ACTIONS(1941),
    [anon_sym_in] = ACTIONS(1941),
    [anon_sym_out] = ACTIONS(1941),
    [anon_sym_inout] = ACTIONS(1941),
    [anon_sym_extern] = ACTIONS(1941),
    [anon_sym___attribute__] = ACTIONS(1941),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1943),
    [anon_sym___declspec] = ACTIONS(1941),
    [anon_sym___based] = ACTIONS(1941),
    [anon_sym___cdecl] = ACTIONS(1941),
    [anon_sym___clrcall] = ACTIONS(1941),
    [anon_sym___stdcall] = ACTIONS(1941),
    [anon_sym___fastcall] = ACTIONS(1941),
    [anon_sym___thiscall] = ACTIONS(1941),
    [anon_sym___vectorcall] = ACTIONS(1941),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_signed] = ACTIONS(1941),
    [anon_sym_unsigned] = ACTIONS(1941),
    [anon_sym_long] = ACTIONS(1941),
    [anon_sym_short] = ACTIONS(1941),
    [anon_sym_LBRACK] = ACTIONS(1941),
    [anon_sym_static] = ACTIONS(1941),
    [anon_sym_register] = ACTIONS(1941),
    [anon_sym_inline] = ACTIONS(1941),
    [anon_sym___inline] = ACTIONS(1941),
    [anon_sym___inline__] = ACTIONS(1941),
    [anon_sym___forceinline] = ACTIONS(1941),
    [anon_sym_thread_local] = ACTIONS(1941),
    [anon_sym___thread] = ACTIONS(1941),
    [anon_sym_const] = ACTIONS(1941),
    [anon_sym_constexpr] = ACTIONS(1941),
    [anon_sym_volatile] = ACTIONS(1941),
    [anon_sym_restrict] = ACTIONS(1941),
    [anon_sym___restrict__] = ACTIONS(1941),
    [anon_sym__Atomic] = ACTIONS(1941),
    [anon_sym__Noreturn] = ACTIONS(1941),
    [anon_sym_noreturn] = ACTIONS(1941),
    [anon_sym_mutable] = ACTIONS(1941),
    [anon_sym_constinit] = ACTIONS(1941),
    [anon_sym_consteval] = ACTIONS(1941),
    [anon_sym_alignas] = ACTIONS(1941),
    [anon_sym__Alignas] = ACTIONS(1941),
    [sym_primitive_type] = ACTIONS(1941),
    [anon_sym_enum] = ACTIONS(1941),
    [anon_sym_class] = ACTIONS(1941),
    [anon_sym_struct] = ACTIONS(1941),
    [anon_sym_union] = ACTIONS(1941),
    [anon_sym_if] = ACTIONS(1941),
    [anon_sym_else] = ACTIONS(1941),
    [anon_sym_switch] = ACTIONS(1941),
    [anon_sym_case] = ACTIONS(1941),
    [anon_sym_default] = ACTIONS(1941),
    [anon_sym_while] = ACTIONS(1941),
    [anon_sym_do] = ACTIONS(1941),
    [anon_sym_for] = ACTIONS(1941),
    [anon_sym_return] = ACTIONS(1941),
    [anon_sym_break] = ACTIONS(1941),
    [anon_sym_continue] = ACTIONS(1941),
    [anon_sym_goto] = ACTIONS(1941),
    [anon_sym___try] = ACTIONS(1941),
    [anon_sym___leave] = ACTIONS(1941),
    [anon_sym_not] = ACTIONS(1941),
    [anon_sym_compl] = ACTIONS(1941),
    [anon_sym_DASH_DASH] = ACTIONS(1943),
    [anon_sym_PLUS_PLUS] = ACTIONS(1943),
    [anon_sym_sizeof] = ACTIONS(1941),
    [anon_sym___alignof__] = ACTIONS(1941),
    [anon_sym___alignof] = ACTIONS(1941),
    [anon_sym__alignof] = ACTIONS(1941),
    [anon_sym_alignof] = ACTIONS(1941),
    [anon_sym__Alignof] = ACTIONS(1941),
    [anon_sym_offsetof] = ACTIONS(1941),
    [anon_sym__Generic] = ACTIONS(1941),
    [anon_sym_asm] = ACTIONS(1941),
    [anon_sym___asm__] = ACTIONS(1941),
    [sym_number_literal] = ACTIONS(1943),
    [anon_sym_L_SQUOTE] = ACTIONS(1943),
    [anon_sym_u_SQUOTE] = ACTIONS(1943),
    [anon_sym_U_SQUOTE] = ACTIONS(1943),
    [anon_sym_u8_SQUOTE] = ACTIONS(1943),
    [anon_sym_SQUOTE] = ACTIONS(1943),
    [anon_sym_L_DQUOTE] = ACTIONS(1943),
    [anon_sym_u_DQUOTE] = ACTIONS(1943),
    [anon_sym_U_DQUOTE] = ACTIONS(1943),
    [anon_sym_u8_DQUOTE] = ACTIONS(1943),
    [anon_sym_DQUOTE] = ACTIONS(1943),
    [sym_true] = ACTIONS(1941),
    [sym_false] = ACTIONS(1941),
    [anon_sym_NULL] = ACTIONS(1941),
    [anon_sym_nullptr] = ACTIONS(1941),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1941),
    [anon_sym_decltype] = ACTIONS(1941),
    [anon_sym_final] = ACTIONS(1941),
    [anon_sym_override] = ACTIONS(1941),
    [sym_virtual] = ACTIONS(1941),
    [anon_sym_explicit] = ACTIONS(1941),
    [anon_sym_typename] = ACTIONS(1941),
    [anon_sym_template] = ACTIONS(1941),
    [anon_sym_operator] = ACTIONS(1941),
    [anon_sym_try] = ACTIONS(1941),
    [anon_sym_delete] = ACTIONS(1941),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_namespace] = ACTIONS(1941),
    [anon_sym_using] = ACTIONS(1941),
    [anon_sym_static_assert] = ACTIONS(1941),
    [anon_sym_concept] = ACTIONS(1941),
    [anon_sym_co_return] = ACTIONS(1941),
    [anon_sym_co_yield] = ACTIONS(1941),
    [anon_sym_R_DQUOTE] = ACTIONS(1943),
    [anon_sym_LR_DQUOTE] = ACTIONS(1943),
    [anon_sym_uR_DQUOTE] = ACTIONS(1943),
    [anon_sym_UR_DQUOTE] = ACTIONS(1943),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1943),
    [anon_sym_co_await] = ACTIONS(1941),
    [anon_sym_new] = ACTIONS(1941),
    [anon_sym_requires] = ACTIONS(1941),
    [sym_this] = ACTIONS(1941),
    [anon_sym_discard] = ACTIONS(1941),
    [anon_sym_precise] = ACTIONS(1941),
    [anon_sym_shared] = ACTIONS(1941),
    [anon_sym_groupshared] = ACTIONS(1941),
    [anon_sym_uniform] = ACTIONS(1941),
    [anon_sym_row_major] = ACTIONS(1941),
    [anon_sym_column_major] = ACTIONS(1941),
    [anon_sym_globallycoherent] = ACTIONS(1941),
    [anon_sym_centroid] = ACTIONS(1941),
    [anon_sym_noperspective] = ACTIONS(1941),
    [anon_sym_nointerpolation] = ACTIONS(1941),
    [anon_sym_sample] = ACTIONS(1941),
    [anon_sym_linear] = ACTIONS(1941),
    [anon_sym_snorm] = ACTIONS(1941),
    [anon_sym_unorm] = ACTIONS(1941),
    [anon_sym_point] = ACTIONS(1941),
    [anon_sym_line] = ACTIONS(1941),
    [anon_sym_triangleadj] = ACTIONS(1941),
    [anon_sym_lineadj] = ACTIONS(1941),
    [anon_sym_triangle] = ACTIONS(1941),
    [anon_sym_cbuffer] = ACTIONS(1941),
  },
  [140] = {
    [ts_builtin_sym_end] = ACTIONS(1945),
    [sym_identifier] = ACTIONS(1947),
    [aux_sym_preproc_include_token1] = ACTIONS(1947),
    [aux_sym_preproc_def_token1] = ACTIONS(1947),
    [anon_sym_RPAREN] = ACTIONS(1945),
    [aux_sym_preproc_if_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1947),
    [sym_preproc_directive] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1945),
    [anon_sym_BANG] = ACTIONS(1945),
    [anon_sym_TILDE] = ACTIONS(1945),
    [anon_sym_DASH] = ACTIONS(1947),
    [anon_sym_PLUS] = ACTIONS(1947),
    [anon_sym_STAR] = ACTIONS(1945),
    [anon_sym_PIPE_PIPE] = ACTIONS(1945),
    [anon_sym_AMP_AMP] = ACTIONS(1945),
    [anon_sym_AMP] = ACTIONS(1947),
    [anon_sym_SEMI] = ACTIONS(1945),
    [anon_sym___extension__] = ACTIONS(1947),
    [anon_sym_typedef] = ACTIONS(1947),
    [anon_sym_in] = ACTIONS(1947),
    [anon_sym_out] = ACTIONS(1947),
    [anon_sym_inout] = ACTIONS(1947),
    [anon_sym_extern] = ACTIONS(1947),
    [anon_sym___attribute__] = ACTIONS(1947),
    [anon_sym_COLON_COLON] = ACTIONS(1945),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1945),
    [anon_sym___declspec] = ACTIONS(1947),
    [anon_sym___based] = ACTIONS(1947),
    [anon_sym___cdecl] = ACTIONS(1947),
    [anon_sym___clrcall] = ACTIONS(1947),
    [anon_sym___stdcall] = ACTIONS(1947),
    [anon_sym___fastcall] = ACTIONS(1947),
    [anon_sym___thiscall] = ACTIONS(1947),
    [anon_sym___vectorcall] = ACTIONS(1947),
    [anon_sym_LBRACE] = ACTIONS(1945),
    [anon_sym_signed] = ACTIONS(1947),
    [anon_sym_unsigned] = ACTIONS(1947),
    [anon_sym_long] = ACTIONS(1947),
    [anon_sym_short] = ACTIONS(1947),
    [anon_sym_LBRACK] = ACTIONS(1947),
    [anon_sym_static] = ACTIONS(1947),
    [anon_sym_register] = ACTIONS(1947),
    [anon_sym_inline] = ACTIONS(1947),
    [anon_sym___inline] = ACTIONS(1947),
    [anon_sym___inline__] = ACTIONS(1947),
    [anon_sym___forceinline] = ACTIONS(1947),
    [anon_sym_thread_local] = ACTIONS(1947),
    [anon_sym___thread] = ACTIONS(1947),
    [anon_sym_const] = ACTIONS(1947),
    [anon_sym_constexpr] = ACTIONS(1947),
    [anon_sym_volatile] = ACTIONS(1947),
    [anon_sym_restrict] = ACTIONS(1947),
    [anon_sym___restrict__] = ACTIONS(1947),
    [anon_sym__Atomic] = ACTIONS(1947),
    [anon_sym__Noreturn] = ACTIONS(1947),
    [anon_sym_noreturn] = ACTIONS(1947),
    [anon_sym_mutable] = ACTIONS(1947),
    [anon_sym_constinit] = ACTIONS(1947),
    [anon_sym_consteval] = ACTIONS(1947),
    [anon_sym_alignas] = ACTIONS(1947),
    [anon_sym__Alignas] = ACTIONS(1947),
    [sym_primitive_type] = ACTIONS(1947),
    [anon_sym_enum] = ACTIONS(1947),
    [anon_sym_class] = ACTIONS(1947),
    [anon_sym_struct] = ACTIONS(1947),
    [anon_sym_union] = ACTIONS(1947),
    [anon_sym_if] = ACTIONS(1947),
    [anon_sym_else] = ACTIONS(1947),
    [anon_sym_switch] = ACTIONS(1947),
    [anon_sym_case] = ACTIONS(1947),
    [anon_sym_default] = ACTIONS(1947),
    [anon_sym_while] = ACTIONS(1947),
    [anon_sym_do] = ACTIONS(1947),
    [anon_sym_for] = ACTIONS(1947),
    [anon_sym_return] = ACTIONS(1947),
    [anon_sym_break] = ACTIONS(1947),
    [anon_sym_continue] = ACTIONS(1947),
    [anon_sym_goto] = ACTIONS(1947),
    [anon_sym___try] = ACTIONS(1947),
    [anon_sym___except] = ACTIONS(1947),
    [anon_sym___finally] = ACTIONS(1947),
    [anon_sym___leave] = ACTIONS(1947),
    [anon_sym_not] = ACTIONS(1947),
    [anon_sym_compl] = ACTIONS(1947),
    [anon_sym_or] = ACTIONS(1947),
    [anon_sym_and] = ACTIONS(1947),
    [anon_sym_DASH_DASH] = ACTIONS(1945),
    [anon_sym_PLUS_PLUS] = ACTIONS(1945),
    [anon_sym_sizeof] = ACTIONS(1947),
    [anon_sym___alignof__] = ACTIONS(1947),
    [anon_sym___alignof] = ACTIONS(1947),
    [anon_sym__alignof] = ACTIONS(1947),
    [anon_sym_alignof] = ACTIONS(1947),
    [anon_sym__Alignof] = ACTIONS(1947),
    [anon_sym_offsetof] = ACTIONS(1947),
    [anon_sym__Generic] = ACTIONS(1947),
    [anon_sym_asm] = ACTIONS(1947),
    [anon_sym___asm__] = ACTIONS(1947),
    [sym_number_literal] = ACTIONS(1945),
    [anon_sym_L_SQUOTE] = ACTIONS(1945),
    [anon_sym_u_SQUOTE] = ACTIONS(1945),
    [anon_sym_U_SQUOTE] = ACTIONS(1945),
    [anon_sym_u8_SQUOTE] = ACTIONS(1945),
    [anon_sym_SQUOTE] = ACTIONS(1945),
    [anon_sym_L_DQUOTE] = ACTIONS(1945),
    [anon_sym_u_DQUOTE] = ACTIONS(1945),
    [anon_sym_U_DQUOTE] = ACTIONS(1945),
    [anon_sym_u8_DQUOTE] = ACTIONS(1945),
    [anon_sym_DQUOTE] = ACTIONS(1945),
    [sym_true] = ACTIONS(1947),
    [sym_false] = ACTIONS(1947),
    [anon_sym_NULL] = ACTIONS(1947),
    [anon_sym_nullptr] = ACTIONS(1947),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1947),
    [anon_sym_decltype] = ACTIONS(1947),
    [anon_sym_final] = ACTIONS(1947),
    [anon_sym_override] = ACTIONS(1947),
    [sym_virtual] = ACTIONS(1947),
    [anon_sym_explicit] = ACTIONS(1947),
    [anon_sym_typename] = ACTIONS(1947),
    [anon_sym_template] = ACTIONS(1947),
    [anon_sym_operator] = ACTIONS(1947),
    [anon_sym_try] = ACTIONS(1947),
    [anon_sym_delete] = ACTIONS(1947),
    [anon_sym_throw] = ACTIONS(1947),
    [anon_sym_namespace] = ACTIONS(1947),
    [anon_sym_using] = ACTIONS(1947),
    [anon_sym_static_assert] = ACTIONS(1947),
    [anon_sym_concept] = ACTIONS(1947),
    [anon_sym_co_return] = ACTIONS(1947),
    [anon_sym_co_yield] = ACTIONS(1947),
    [anon_sym_catch] = ACTIONS(1947),
    [anon_sym_R_DQUOTE] = ACTIONS(1945),
    [anon_sym_LR_DQUOTE] = ACTIONS(1945),
    [anon_sym_uR_DQUOTE] = ACTIONS(1945),
    [anon_sym_UR_DQUOTE] = ACTIONS(1945),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1945),
    [anon_sym_co_await] = ACTIONS(1947),
    [anon_sym_new] = ACTIONS(1947),
    [anon_sym_requires] = ACTIONS(1947),
    [sym_this] = ACTIONS(1947),
    [anon_sym_discard] = ACTIONS(1947),
    [anon_sym_precise] = ACTIONS(1947),
    [anon_sym_shared] = ACTIONS(1947),
    [anon_sym_groupshared] = ACTIONS(1947),
    [anon_sym_uniform] = ACTIONS(1947),
    [anon_sym_row_major] = ACTIONS(1947),
    [anon_sym_column_major] = ACTIONS(1947),
    [anon_sym_globallycoherent] = ACTIONS(1947),
    [anon_sym_centroid] = ACTIONS(1947),
    [anon_sym_noperspective] = ACTIONS(1947),
    [anon_sym_nointerpolation] = ACTIONS(1947),
    [anon_sym_sample] = ACTIONS(1947),
    [anon_sym_linear] = ACTIONS(1947),
    [anon_sym_snorm] = ACTIONS(1947),
    [anon_sym_unorm] = ACTIONS(1947),
    [anon_sym_point] = ACTIONS(1947),
    [anon_sym_line] = ACTIONS(1947),
    [anon_sym_triangleadj] = ACTIONS(1947),
    [anon_sym_lineadj] = ACTIONS(1947),
    [anon_sym_triangle] = ACTIONS(1947),
    [anon_sym_cbuffer] = ACTIONS(1947),
  },
  [141] = {
    [sym_identifier] = ACTIONS(1899),
    [aux_sym_preproc_include_token1] = ACTIONS(1899),
    [aux_sym_preproc_def_token1] = ACTIONS(1899),
    [aux_sym_preproc_if_token1] = ACTIONS(1899),
    [aux_sym_preproc_if_token2] = ACTIONS(1899),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1899),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1899),
    [aux_sym_preproc_else_token1] = ACTIONS(1899),
    [aux_sym_preproc_elif_token1] = ACTIONS(1899),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1899),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1899),
    [sym_preproc_directive] = ACTIONS(1899),
    [anon_sym_LPAREN2] = ACTIONS(1901),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1901),
    [anon_sym_AMP_AMP] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1899),
    [anon_sym_COLON] = ACTIONS(1899),
    [anon_sym_SEMI] = ACTIONS(1901),
    [anon_sym___extension__] = ACTIONS(1899),
    [anon_sym_typedef] = ACTIONS(1899),
    [anon_sym_in] = ACTIONS(1899),
    [anon_sym_out] = ACTIONS(1899),
    [anon_sym_inout] = ACTIONS(1899),
    [anon_sym_extern] = ACTIONS(1899),
    [anon_sym___attribute__] = ACTIONS(1899),
    [anon_sym_COLON_COLON] = ACTIONS(1901),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1901),
    [anon_sym___declspec] = ACTIONS(1899),
    [anon_sym___based] = ACTIONS(1899),
    [anon_sym___cdecl] = ACTIONS(1899),
    [anon_sym___clrcall] = ACTIONS(1899),
    [anon_sym___stdcall] = ACTIONS(1899),
    [anon_sym___fastcall] = ACTIONS(1899),
    [anon_sym___thiscall] = ACTIONS(1899),
    [anon_sym___vectorcall] = ACTIONS(1899),
    [anon_sym_LBRACE] = ACTIONS(1901),
    [anon_sym_signed] = ACTIONS(1899),
    [anon_sym_unsigned] = ACTIONS(1899),
    [anon_sym_long] = ACTIONS(1899),
    [anon_sym_short] = ACTIONS(1899),
    [anon_sym_LBRACK] = ACTIONS(1899),
    [anon_sym_static] = ACTIONS(1899),
    [anon_sym_register] = ACTIONS(1899),
    [anon_sym_inline] = ACTIONS(1899),
    [anon_sym___inline] = ACTIONS(1899),
    [anon_sym___inline__] = ACTIONS(1899),
    [anon_sym___forceinline] = ACTIONS(1899),
    [anon_sym_thread_local] = ACTIONS(1899),
    [anon_sym___thread] = ACTIONS(1899),
    [anon_sym_const] = ACTIONS(1899),
    [anon_sym_constexpr] = ACTIONS(1899),
    [anon_sym_volatile] = ACTIONS(1899),
    [anon_sym_restrict] = ACTIONS(1899),
    [anon_sym___restrict__] = ACTIONS(1899),
    [anon_sym__Atomic] = ACTIONS(1899),
    [anon_sym__Noreturn] = ACTIONS(1899),
    [anon_sym_noreturn] = ACTIONS(1899),
    [anon_sym_mutable] = ACTIONS(1899),
    [anon_sym_constinit] = ACTIONS(1899),
    [anon_sym_consteval] = ACTIONS(1899),
    [anon_sym_alignas] = ACTIONS(1899),
    [anon_sym__Alignas] = ACTIONS(1899),
    [sym_primitive_type] = ACTIONS(1899),
    [anon_sym_enum] = ACTIONS(1899),
    [anon_sym_class] = ACTIONS(1899),
    [anon_sym_struct] = ACTIONS(1899),
    [anon_sym_union] = ACTIONS(1899),
    [anon_sym_if] = ACTIONS(1899),
    [anon_sym_else] = ACTIONS(1899),
    [anon_sym_switch] = ACTIONS(1899),
    [anon_sym_case] = ACTIONS(1899),
    [anon_sym_default] = ACTIONS(1899),
    [anon_sym_while] = ACTIONS(1899),
    [anon_sym_do] = ACTIONS(1899),
    [anon_sym_for] = ACTIONS(1899),
    [anon_sym_return] = ACTIONS(1899),
    [anon_sym_break] = ACTIONS(1899),
    [anon_sym_continue] = ACTIONS(1899),
    [anon_sym_goto] = ACTIONS(1899),
    [anon_sym___try] = ACTIONS(1899),
    [anon_sym___leave] = ACTIONS(1899),
    [anon_sym_not] = ACTIONS(1899),
    [anon_sym_compl] = ACTIONS(1899),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_sizeof] = ACTIONS(1899),
    [anon_sym___alignof__] = ACTIONS(1899),
    [anon_sym___alignof] = ACTIONS(1899),
    [anon_sym__alignof] = ACTIONS(1899),
    [anon_sym_alignof] = ACTIONS(1899),
    [anon_sym__Alignof] = ACTIONS(1899),
    [anon_sym_offsetof] = ACTIONS(1899),
    [anon_sym__Generic] = ACTIONS(1899),
    [anon_sym_asm] = ACTIONS(1899),
    [anon_sym___asm__] = ACTIONS(1899),
    [sym_number_literal] = ACTIONS(1901),
    [anon_sym_L_SQUOTE] = ACTIONS(1901),
    [anon_sym_u_SQUOTE] = ACTIONS(1901),
    [anon_sym_U_SQUOTE] = ACTIONS(1901),
    [anon_sym_u8_SQUOTE] = ACTIONS(1901),
    [anon_sym_SQUOTE] = ACTIONS(1901),
    [anon_sym_L_DQUOTE] = ACTIONS(1901),
    [anon_sym_u_DQUOTE] = ACTIONS(1901),
    [anon_sym_U_DQUOTE] = ACTIONS(1901),
    [anon_sym_u8_DQUOTE] = ACTIONS(1901),
    [anon_sym_DQUOTE] = ACTIONS(1901),
    [sym_true] = ACTIONS(1899),
    [sym_false] = ACTIONS(1899),
    [anon_sym_NULL] = ACTIONS(1899),
    [anon_sym_nullptr] = ACTIONS(1899),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1899),
    [anon_sym_decltype] = ACTIONS(1899),
    [anon_sym_final] = ACTIONS(1899),
    [anon_sym_override] = ACTIONS(1899),
    [sym_virtual] = ACTIONS(1899),
    [anon_sym_explicit] = ACTIONS(1899),
    [anon_sym_typename] = ACTIONS(1899),
    [anon_sym_template] = ACTIONS(1899),
    [anon_sym_operator] = ACTIONS(1899),
    [anon_sym_try] = ACTIONS(1899),
    [anon_sym_delete] = ACTIONS(1899),
    [anon_sym_throw] = ACTIONS(1899),
    [anon_sym_namespace] = ACTIONS(1899),
    [anon_sym_using] = ACTIONS(1899),
    [anon_sym_static_assert] = ACTIONS(1899),
    [anon_sym_concept] = ACTIONS(1899),
    [anon_sym_co_return] = ACTIONS(1899),
    [anon_sym_co_yield] = ACTIONS(1899),
    [anon_sym_R_DQUOTE] = ACTIONS(1901),
    [anon_sym_LR_DQUOTE] = ACTIONS(1901),
    [anon_sym_uR_DQUOTE] = ACTIONS(1901),
    [anon_sym_UR_DQUOTE] = ACTIONS(1901),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1901),
    [anon_sym_co_await] = ACTIONS(1899),
    [anon_sym_new] = ACTIONS(1899),
    [anon_sym_requires] = ACTIONS(1899),
    [sym_this] = ACTIONS(1899),
    [anon_sym_discard] = ACTIONS(1899),
    [anon_sym_precise] = ACTIONS(1899),
    [anon_sym_shared] = ACTIONS(1899),
    [anon_sym_groupshared] = ACTIONS(1899),
    [anon_sym_uniform] = ACTIONS(1899),
    [anon_sym_row_major] = ACTIONS(1899),
    [anon_sym_column_major] = ACTIONS(1899),
    [anon_sym_globallycoherent] = ACTIONS(1899),
    [anon_sym_centroid] = ACTIONS(1899),
    [anon_sym_noperspective] = ACTIONS(1899),
    [anon_sym_nointerpolation] = ACTIONS(1899),
    [anon_sym_sample] = ACTIONS(1899),
    [anon_sym_linear] = ACTIONS(1899),
    [anon_sym_snorm] = ACTIONS(1899),
    [anon_sym_unorm] = ACTIONS(1899),
    [anon_sym_point] = ACTIONS(1899),
    [anon_sym_line] = ACTIONS(1899),
    [anon_sym_triangleadj] = ACTIONS(1899),
    [anon_sym_lineadj] = ACTIONS(1899),
    [anon_sym_triangle] = ACTIONS(1899),
    [anon_sym_cbuffer] = ACTIONS(1899),
  },
  [142] = {
    [sym_identifier] = ACTIONS(1949),
    [aux_sym_preproc_include_token1] = ACTIONS(1949),
    [aux_sym_preproc_def_token1] = ACTIONS(1949),
    [aux_sym_preproc_if_token1] = ACTIONS(1949),
    [aux_sym_preproc_if_token2] = ACTIONS(1949),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1949),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1949),
    [aux_sym_preproc_else_token1] = ACTIONS(1949),
    [aux_sym_preproc_elif_token1] = ACTIONS(1949),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1949),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1949),
    [sym_preproc_directive] = ACTIONS(1949),
    [anon_sym_LPAREN2] = ACTIONS(1951),
    [anon_sym_BANG] = ACTIONS(1951),
    [anon_sym_TILDE] = ACTIONS(1951),
    [anon_sym_DASH] = ACTIONS(1949),
    [anon_sym_PLUS] = ACTIONS(1949),
    [anon_sym_STAR] = ACTIONS(1951),
    [anon_sym_AMP_AMP] = ACTIONS(1951),
    [anon_sym_AMP] = ACTIONS(1949),
    [anon_sym_COLON] = ACTIONS(1949),
    [anon_sym_SEMI] = ACTIONS(1951),
    [anon_sym___extension__] = ACTIONS(1949),
    [anon_sym_typedef] = ACTIONS(1949),
    [anon_sym_in] = ACTIONS(1949),
    [anon_sym_out] = ACTIONS(1949),
    [anon_sym_inout] = ACTIONS(1949),
    [anon_sym_extern] = ACTIONS(1949),
    [anon_sym___attribute__] = ACTIONS(1949),
    [anon_sym_COLON_COLON] = ACTIONS(1951),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1951),
    [anon_sym___declspec] = ACTIONS(1949),
    [anon_sym___based] = ACTIONS(1949),
    [anon_sym___cdecl] = ACTIONS(1949),
    [anon_sym___clrcall] = ACTIONS(1949),
    [anon_sym___stdcall] = ACTIONS(1949),
    [anon_sym___fastcall] = ACTIONS(1949),
    [anon_sym___thiscall] = ACTIONS(1949),
    [anon_sym___vectorcall] = ACTIONS(1949),
    [anon_sym_LBRACE] = ACTIONS(1951),
    [anon_sym_signed] = ACTIONS(1949),
    [anon_sym_unsigned] = ACTIONS(1949),
    [anon_sym_long] = ACTIONS(1949),
    [anon_sym_short] = ACTIONS(1949),
    [anon_sym_LBRACK] = ACTIONS(1949),
    [anon_sym_static] = ACTIONS(1949),
    [anon_sym_register] = ACTIONS(1949),
    [anon_sym_inline] = ACTIONS(1949),
    [anon_sym___inline] = ACTIONS(1949),
    [anon_sym___inline__] = ACTIONS(1949),
    [anon_sym___forceinline] = ACTIONS(1949),
    [anon_sym_thread_local] = ACTIONS(1949),
    [anon_sym___thread] = ACTIONS(1949),
    [anon_sym_const] = ACTIONS(1949),
    [anon_sym_constexpr] = ACTIONS(1949),
    [anon_sym_volatile] = ACTIONS(1949),
    [anon_sym_restrict] = ACTIONS(1949),
    [anon_sym___restrict__] = ACTIONS(1949),
    [anon_sym__Atomic] = ACTIONS(1949),
    [anon_sym__Noreturn] = ACTIONS(1949),
    [anon_sym_noreturn] = ACTIONS(1949),
    [anon_sym_mutable] = ACTIONS(1949),
    [anon_sym_constinit] = ACTIONS(1949),
    [anon_sym_consteval] = ACTIONS(1949),
    [anon_sym_alignas] = ACTIONS(1949),
    [anon_sym__Alignas] = ACTIONS(1949),
    [sym_primitive_type] = ACTIONS(1949),
    [anon_sym_enum] = ACTIONS(1949),
    [anon_sym_class] = ACTIONS(1949),
    [anon_sym_struct] = ACTIONS(1949),
    [anon_sym_union] = ACTIONS(1949),
    [anon_sym_if] = ACTIONS(1949),
    [anon_sym_else] = ACTIONS(1949),
    [anon_sym_switch] = ACTIONS(1949),
    [anon_sym_case] = ACTIONS(1949),
    [anon_sym_default] = ACTIONS(1949),
    [anon_sym_while] = ACTIONS(1949),
    [anon_sym_do] = ACTIONS(1949),
    [anon_sym_for] = ACTIONS(1949),
    [anon_sym_return] = ACTIONS(1949),
    [anon_sym_break] = ACTIONS(1949),
    [anon_sym_continue] = ACTIONS(1949),
    [anon_sym_goto] = ACTIONS(1949),
    [anon_sym___try] = ACTIONS(1949),
    [anon_sym___leave] = ACTIONS(1949),
    [anon_sym_not] = ACTIONS(1949),
    [anon_sym_compl] = ACTIONS(1949),
    [anon_sym_DASH_DASH] = ACTIONS(1951),
    [anon_sym_PLUS_PLUS] = ACTIONS(1951),
    [anon_sym_sizeof] = ACTIONS(1949),
    [anon_sym___alignof__] = ACTIONS(1949),
    [anon_sym___alignof] = ACTIONS(1949),
    [anon_sym__alignof] = ACTIONS(1949),
    [anon_sym_alignof] = ACTIONS(1949),
    [anon_sym__Alignof] = ACTIONS(1949),
    [anon_sym_offsetof] = ACTIONS(1949),
    [anon_sym__Generic] = ACTIONS(1949),
    [anon_sym_asm] = ACTIONS(1949),
    [anon_sym___asm__] = ACTIONS(1949),
    [sym_number_literal] = ACTIONS(1951),
    [anon_sym_L_SQUOTE] = ACTIONS(1951),
    [anon_sym_u_SQUOTE] = ACTIONS(1951),
    [anon_sym_U_SQUOTE] = ACTIONS(1951),
    [anon_sym_u8_SQUOTE] = ACTIONS(1951),
    [anon_sym_SQUOTE] = ACTIONS(1951),
    [anon_sym_L_DQUOTE] = ACTIONS(1951),
    [anon_sym_u_DQUOTE] = ACTIONS(1951),
    [anon_sym_U_DQUOTE] = ACTIONS(1951),
    [anon_sym_u8_DQUOTE] = ACTIONS(1951),
    [anon_sym_DQUOTE] = ACTIONS(1951),
    [sym_true] = ACTIONS(1949),
    [sym_false] = ACTIONS(1949),
    [anon_sym_NULL] = ACTIONS(1949),
    [anon_sym_nullptr] = ACTIONS(1949),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1949),
    [anon_sym_decltype] = ACTIONS(1949),
    [anon_sym_final] = ACTIONS(1949),
    [anon_sym_override] = ACTIONS(1949),
    [sym_virtual] = ACTIONS(1949),
    [anon_sym_explicit] = ACTIONS(1949),
    [anon_sym_typename] = ACTIONS(1949),
    [anon_sym_template] = ACTIONS(1949),
    [anon_sym_operator] = ACTIONS(1949),
    [anon_sym_try] = ACTIONS(1949),
    [anon_sym_delete] = ACTIONS(1949),
    [anon_sym_throw] = ACTIONS(1949),
    [anon_sym_namespace] = ACTIONS(1949),
    [anon_sym_using] = ACTIONS(1949),
    [anon_sym_static_assert] = ACTIONS(1949),
    [anon_sym_concept] = ACTIONS(1949),
    [anon_sym_co_return] = ACTIONS(1949),
    [anon_sym_co_yield] = ACTIONS(1949),
    [anon_sym_R_DQUOTE] = ACTIONS(1951),
    [anon_sym_LR_DQUOTE] = ACTIONS(1951),
    [anon_sym_uR_DQUOTE] = ACTIONS(1951),
    [anon_sym_UR_DQUOTE] = ACTIONS(1951),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1951),
    [anon_sym_co_await] = ACTIONS(1949),
    [anon_sym_new] = ACTIONS(1949),
    [anon_sym_requires] = ACTIONS(1949),
    [sym_this] = ACTIONS(1949),
    [anon_sym_discard] = ACTIONS(1949),
    [anon_sym_precise] = ACTIONS(1949),
    [anon_sym_shared] = ACTIONS(1949),
    [anon_sym_groupshared] = ACTIONS(1949),
    [anon_sym_uniform] = ACTIONS(1949),
    [anon_sym_row_major] = ACTIONS(1949),
    [anon_sym_column_major] = ACTIONS(1949),
    [anon_sym_globallycoherent] = ACTIONS(1949),
    [anon_sym_centroid] = ACTIONS(1949),
    [anon_sym_noperspective] = ACTIONS(1949),
    [anon_sym_nointerpolation] = ACTIONS(1949),
    [anon_sym_sample] = ACTIONS(1949),
    [anon_sym_linear] = ACTIONS(1949),
    [anon_sym_snorm] = ACTIONS(1949),
    [anon_sym_unorm] = ACTIONS(1949),
    [anon_sym_point] = ACTIONS(1949),
    [anon_sym_line] = ACTIONS(1949),
    [anon_sym_triangleadj] = ACTIONS(1949),
    [anon_sym_lineadj] = ACTIONS(1949),
    [anon_sym_triangle] = ACTIONS(1949),
    [anon_sym_cbuffer] = ACTIONS(1949),
  },
  [143] = {
    [sym_identifier] = ACTIONS(1953),
    [aux_sym_preproc_include_token1] = ACTIONS(1953),
    [aux_sym_preproc_def_token1] = ACTIONS(1953),
    [aux_sym_preproc_if_token1] = ACTIONS(1953),
    [aux_sym_preproc_if_token2] = ACTIONS(1953),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1953),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1953),
    [aux_sym_preproc_else_token1] = ACTIONS(1953),
    [aux_sym_preproc_elif_token1] = ACTIONS(1953),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1953),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1953),
    [sym_preproc_directive] = ACTIONS(1953),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_BANG] = ACTIONS(1955),
    [anon_sym_TILDE] = ACTIONS(1955),
    [anon_sym_DASH] = ACTIONS(1953),
    [anon_sym_PLUS] = ACTIONS(1953),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym_COLON] = ACTIONS(1953),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym_typedef] = ACTIONS(1953),
    [anon_sym_in] = ACTIONS(1953),
    [anon_sym_out] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1953),
    [anon_sym_extern] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1955),
    [anon_sym___declspec] = ACTIONS(1953),
    [anon_sym___based] = ACTIONS(1953),
    [anon_sym___cdecl] = ACTIONS(1953),
    [anon_sym___clrcall] = ACTIONS(1953),
    [anon_sym___stdcall] = ACTIONS(1953),
    [anon_sym___fastcall] = ACTIONS(1953),
    [anon_sym___thiscall] = ACTIONS(1953),
    [anon_sym___vectorcall] = ACTIONS(1953),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_signed] = ACTIONS(1953),
    [anon_sym_unsigned] = ACTIONS(1953),
    [anon_sym_long] = ACTIONS(1953),
    [anon_sym_short] = ACTIONS(1953),
    [anon_sym_LBRACK] = ACTIONS(1953),
    [anon_sym_static] = ACTIONS(1953),
    [anon_sym_register] = ACTIONS(1953),
    [anon_sym_inline] = ACTIONS(1953),
    [anon_sym___inline] = ACTIONS(1953),
    [anon_sym___inline__] = ACTIONS(1953),
    [anon_sym___forceinline] = ACTIONS(1953),
    [anon_sym_thread_local] = ACTIONS(1953),
    [anon_sym___thread] = ACTIONS(1953),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [sym_primitive_type] = ACTIONS(1953),
    [anon_sym_enum] = ACTIONS(1953),
    [anon_sym_class] = ACTIONS(1953),
    [anon_sym_struct] = ACTIONS(1953),
    [anon_sym_union] = ACTIONS(1953),
    [anon_sym_if] = ACTIONS(1953),
    [anon_sym_else] = ACTIONS(1953),
    [anon_sym_switch] = ACTIONS(1953),
    [anon_sym_case] = ACTIONS(1953),
    [anon_sym_default] = ACTIONS(1953),
    [anon_sym_while] = ACTIONS(1953),
    [anon_sym_do] = ACTIONS(1953),
    [anon_sym_for] = ACTIONS(1953),
    [anon_sym_return] = ACTIONS(1953),
    [anon_sym_break] = ACTIONS(1953),
    [anon_sym_continue] = ACTIONS(1953),
    [anon_sym_goto] = ACTIONS(1953),
    [anon_sym___try] = ACTIONS(1953),
    [anon_sym___leave] = ACTIONS(1953),
    [anon_sym_not] = ACTIONS(1953),
    [anon_sym_compl] = ACTIONS(1953),
    [anon_sym_DASH_DASH] = ACTIONS(1955),
    [anon_sym_PLUS_PLUS] = ACTIONS(1955),
    [anon_sym_sizeof] = ACTIONS(1953),
    [anon_sym___alignof__] = ACTIONS(1953),
    [anon_sym___alignof] = ACTIONS(1953),
    [anon_sym__alignof] = ACTIONS(1953),
    [anon_sym_alignof] = ACTIONS(1953),
    [anon_sym__Alignof] = ACTIONS(1953),
    [anon_sym_offsetof] = ACTIONS(1953),
    [anon_sym__Generic] = ACTIONS(1953),
    [anon_sym_asm] = ACTIONS(1953),
    [anon_sym___asm__] = ACTIONS(1953),
    [sym_number_literal] = ACTIONS(1955),
    [anon_sym_L_SQUOTE] = ACTIONS(1955),
    [anon_sym_u_SQUOTE] = ACTIONS(1955),
    [anon_sym_U_SQUOTE] = ACTIONS(1955),
    [anon_sym_u8_SQUOTE] = ACTIONS(1955),
    [anon_sym_SQUOTE] = ACTIONS(1955),
    [anon_sym_L_DQUOTE] = ACTIONS(1955),
    [anon_sym_u_DQUOTE] = ACTIONS(1955),
    [anon_sym_U_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8_DQUOTE] = ACTIONS(1955),
    [anon_sym_DQUOTE] = ACTIONS(1955),
    [sym_true] = ACTIONS(1953),
    [sym_false] = ACTIONS(1953),
    [anon_sym_NULL] = ACTIONS(1953),
    [anon_sym_nullptr] = ACTIONS(1953),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
    [sym_virtual] = ACTIONS(1953),
    [anon_sym_explicit] = ACTIONS(1953),
    [anon_sym_typename] = ACTIONS(1953),
    [anon_sym_template] = ACTIONS(1953),
    [anon_sym_operator] = ACTIONS(1953),
    [anon_sym_try] = ACTIONS(1953),
    [anon_sym_delete] = ACTIONS(1953),
    [anon_sym_throw] = ACTIONS(1953),
    [anon_sym_namespace] = ACTIONS(1953),
    [anon_sym_using] = ACTIONS(1953),
    [anon_sym_static_assert] = ACTIONS(1953),
    [anon_sym_concept] = ACTIONS(1953),
    [anon_sym_co_return] = ACTIONS(1953),
    [anon_sym_co_yield] = ACTIONS(1953),
    [anon_sym_R_DQUOTE] = ACTIONS(1955),
    [anon_sym_LR_DQUOTE] = ACTIONS(1955),
    [anon_sym_uR_DQUOTE] = ACTIONS(1955),
    [anon_sym_UR_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1955),
    [anon_sym_co_await] = ACTIONS(1953),
    [anon_sym_new] = ACTIONS(1953),
    [anon_sym_requires] = ACTIONS(1953),
    [sym_this] = ACTIONS(1953),
    [anon_sym_discard] = ACTIONS(1953),
    [anon_sym_precise] = ACTIONS(1953),
    [anon_sym_shared] = ACTIONS(1953),
    [anon_sym_groupshared] = ACTIONS(1953),
    [anon_sym_uniform] = ACTIONS(1953),
    [anon_sym_row_major] = ACTIONS(1953),
    [anon_sym_column_major] = ACTIONS(1953),
    [anon_sym_globallycoherent] = ACTIONS(1953),
    [anon_sym_centroid] = ACTIONS(1953),
    [anon_sym_noperspective] = ACTIONS(1953),
    [anon_sym_nointerpolation] = ACTIONS(1953),
    [anon_sym_sample] = ACTIONS(1953),
    [anon_sym_linear] = ACTIONS(1953),
    [anon_sym_snorm] = ACTIONS(1953),
    [anon_sym_unorm] = ACTIONS(1953),
    [anon_sym_point] = ACTIONS(1953),
    [anon_sym_line] = ACTIONS(1953),
    [anon_sym_triangleadj] = ACTIONS(1953),
    [anon_sym_lineadj] = ACTIONS(1953),
    [anon_sym_triangle] = ACTIONS(1953),
    [anon_sym_cbuffer] = ACTIONS(1953),
  },
  [144] = {
    [sym_identifier] = ACTIONS(1953),
    [aux_sym_preproc_include_token1] = ACTIONS(1953),
    [aux_sym_preproc_def_token1] = ACTIONS(1953),
    [aux_sym_preproc_if_token1] = ACTIONS(1953),
    [aux_sym_preproc_if_token2] = ACTIONS(1953),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1953),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1953),
    [aux_sym_preproc_else_token1] = ACTIONS(1953),
    [aux_sym_preproc_elif_token1] = ACTIONS(1953),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1953),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1953),
    [sym_preproc_directive] = ACTIONS(1953),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_BANG] = ACTIONS(1955),
    [anon_sym_TILDE] = ACTIONS(1955),
    [anon_sym_DASH] = ACTIONS(1953),
    [anon_sym_PLUS] = ACTIONS(1953),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym_COLON] = ACTIONS(1953),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym_typedef] = ACTIONS(1953),
    [anon_sym_in] = ACTIONS(1953),
    [anon_sym_out] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1953),
    [anon_sym_extern] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1955),
    [anon_sym___declspec] = ACTIONS(1953),
    [anon_sym___based] = ACTIONS(1953),
    [anon_sym___cdecl] = ACTIONS(1953),
    [anon_sym___clrcall] = ACTIONS(1953),
    [anon_sym___stdcall] = ACTIONS(1953),
    [anon_sym___fastcall] = ACTIONS(1953),
    [anon_sym___thiscall] = ACTIONS(1953),
    [anon_sym___vectorcall] = ACTIONS(1953),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_signed] = ACTIONS(1953),
    [anon_sym_unsigned] = ACTIONS(1953),
    [anon_sym_long] = ACTIONS(1953),
    [anon_sym_short] = ACTIONS(1953),
    [anon_sym_LBRACK] = ACTIONS(1953),
    [anon_sym_static] = ACTIONS(1953),
    [anon_sym_register] = ACTIONS(1953),
    [anon_sym_inline] = ACTIONS(1953),
    [anon_sym___inline] = ACTIONS(1953),
    [anon_sym___inline__] = ACTIONS(1953),
    [anon_sym___forceinline] = ACTIONS(1953),
    [anon_sym_thread_local] = ACTIONS(1953),
    [anon_sym___thread] = ACTIONS(1953),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [sym_primitive_type] = ACTIONS(1953),
    [anon_sym_enum] = ACTIONS(1953),
    [anon_sym_class] = ACTIONS(1953),
    [anon_sym_struct] = ACTIONS(1953),
    [anon_sym_union] = ACTIONS(1953),
    [anon_sym_if] = ACTIONS(1953),
    [anon_sym_else] = ACTIONS(1953),
    [anon_sym_switch] = ACTIONS(1953),
    [anon_sym_case] = ACTIONS(1953),
    [anon_sym_default] = ACTIONS(1953),
    [anon_sym_while] = ACTIONS(1953),
    [anon_sym_do] = ACTIONS(1953),
    [anon_sym_for] = ACTIONS(1953),
    [anon_sym_return] = ACTIONS(1953),
    [anon_sym_break] = ACTIONS(1953),
    [anon_sym_continue] = ACTIONS(1953),
    [anon_sym_goto] = ACTIONS(1953),
    [anon_sym___try] = ACTIONS(1953),
    [anon_sym___leave] = ACTIONS(1953),
    [anon_sym_not] = ACTIONS(1953),
    [anon_sym_compl] = ACTIONS(1953),
    [anon_sym_DASH_DASH] = ACTIONS(1955),
    [anon_sym_PLUS_PLUS] = ACTIONS(1955),
    [anon_sym_sizeof] = ACTIONS(1953),
    [anon_sym___alignof__] = ACTIONS(1953),
    [anon_sym___alignof] = ACTIONS(1953),
    [anon_sym__alignof] = ACTIONS(1953),
    [anon_sym_alignof] = ACTIONS(1953),
    [anon_sym__Alignof] = ACTIONS(1953),
    [anon_sym_offsetof] = ACTIONS(1953),
    [anon_sym__Generic] = ACTIONS(1953),
    [anon_sym_asm] = ACTIONS(1953),
    [anon_sym___asm__] = ACTIONS(1953),
    [sym_number_literal] = ACTIONS(1955),
    [anon_sym_L_SQUOTE] = ACTIONS(1955),
    [anon_sym_u_SQUOTE] = ACTIONS(1955),
    [anon_sym_U_SQUOTE] = ACTIONS(1955),
    [anon_sym_u8_SQUOTE] = ACTIONS(1955),
    [anon_sym_SQUOTE] = ACTIONS(1955),
    [anon_sym_L_DQUOTE] = ACTIONS(1955),
    [anon_sym_u_DQUOTE] = ACTIONS(1955),
    [anon_sym_U_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8_DQUOTE] = ACTIONS(1955),
    [anon_sym_DQUOTE] = ACTIONS(1955),
    [sym_true] = ACTIONS(1953),
    [sym_false] = ACTIONS(1953),
    [anon_sym_NULL] = ACTIONS(1953),
    [anon_sym_nullptr] = ACTIONS(1953),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
    [sym_virtual] = ACTIONS(1953),
    [anon_sym_explicit] = ACTIONS(1953),
    [anon_sym_typename] = ACTIONS(1953),
    [anon_sym_template] = ACTIONS(1953),
    [anon_sym_operator] = ACTIONS(1953),
    [anon_sym_try] = ACTIONS(1953),
    [anon_sym_delete] = ACTIONS(1953),
    [anon_sym_throw] = ACTIONS(1953),
    [anon_sym_namespace] = ACTIONS(1953),
    [anon_sym_using] = ACTIONS(1953),
    [anon_sym_static_assert] = ACTIONS(1953),
    [anon_sym_concept] = ACTIONS(1953),
    [anon_sym_co_return] = ACTIONS(1953),
    [anon_sym_co_yield] = ACTIONS(1953),
    [anon_sym_R_DQUOTE] = ACTIONS(1955),
    [anon_sym_LR_DQUOTE] = ACTIONS(1955),
    [anon_sym_uR_DQUOTE] = ACTIONS(1955),
    [anon_sym_UR_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1955),
    [anon_sym_co_await] = ACTIONS(1953),
    [anon_sym_new] = ACTIONS(1953),
    [anon_sym_requires] = ACTIONS(1953),
    [sym_this] = ACTIONS(1953),
    [anon_sym_discard] = ACTIONS(1953),
    [anon_sym_precise] = ACTIONS(1953),
    [anon_sym_shared] = ACTIONS(1953),
    [anon_sym_groupshared] = ACTIONS(1953),
    [anon_sym_uniform] = ACTIONS(1953),
    [anon_sym_row_major] = ACTIONS(1953),
    [anon_sym_column_major] = ACTIONS(1953),
    [anon_sym_globallycoherent] = ACTIONS(1953),
    [anon_sym_centroid] = ACTIONS(1953),
    [anon_sym_noperspective] = ACTIONS(1953),
    [anon_sym_nointerpolation] = ACTIONS(1953),
    [anon_sym_sample] = ACTIONS(1953),
    [anon_sym_linear] = ACTIONS(1953),
    [anon_sym_snorm] = ACTIONS(1953),
    [anon_sym_unorm] = ACTIONS(1953),
    [anon_sym_point] = ACTIONS(1953),
    [anon_sym_line] = ACTIONS(1953),
    [anon_sym_triangleadj] = ACTIONS(1953),
    [anon_sym_lineadj] = ACTIONS(1953),
    [anon_sym_triangle] = ACTIONS(1953),
    [anon_sym_cbuffer] = ACTIONS(1953),
  },
  [145] = {
    [sym_identifier] = ACTIONS(1891),
    [aux_sym_preproc_include_token1] = ACTIONS(1891),
    [aux_sym_preproc_def_token1] = ACTIONS(1891),
    [aux_sym_preproc_if_token1] = ACTIONS(1891),
    [aux_sym_preproc_if_token2] = ACTIONS(1891),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1891),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1891),
    [aux_sym_preproc_else_token1] = ACTIONS(1891),
    [aux_sym_preproc_elif_token1] = ACTIONS(1891),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1891),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1891),
    [sym_preproc_directive] = ACTIONS(1891),
    [anon_sym_LPAREN2] = ACTIONS(1893),
    [anon_sym_BANG] = ACTIONS(1893),
    [anon_sym_TILDE] = ACTIONS(1893),
    [anon_sym_DASH] = ACTIONS(1891),
    [anon_sym_PLUS] = ACTIONS(1891),
    [anon_sym_STAR] = ACTIONS(1893),
    [anon_sym_AMP_AMP] = ACTIONS(1893),
    [anon_sym_AMP] = ACTIONS(1891),
    [anon_sym_COLON] = ACTIONS(1891),
    [anon_sym_SEMI] = ACTIONS(1893),
    [anon_sym___extension__] = ACTIONS(1891),
    [anon_sym_typedef] = ACTIONS(1891),
    [anon_sym_in] = ACTIONS(1891),
    [anon_sym_out] = ACTIONS(1891),
    [anon_sym_inout] = ACTIONS(1891),
    [anon_sym_extern] = ACTIONS(1891),
    [anon_sym___attribute__] = ACTIONS(1891),
    [anon_sym_COLON_COLON] = ACTIONS(1893),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1893),
    [anon_sym___declspec] = ACTIONS(1891),
    [anon_sym___based] = ACTIONS(1891),
    [anon_sym___cdecl] = ACTIONS(1891),
    [anon_sym___clrcall] = ACTIONS(1891),
    [anon_sym___stdcall] = ACTIONS(1891),
    [anon_sym___fastcall] = ACTIONS(1891),
    [anon_sym___thiscall] = ACTIONS(1891),
    [anon_sym___vectorcall] = ACTIONS(1891),
    [anon_sym_LBRACE] = ACTIONS(1893),
    [anon_sym_signed] = ACTIONS(1891),
    [anon_sym_unsigned] = ACTIONS(1891),
    [anon_sym_long] = ACTIONS(1891),
    [anon_sym_short] = ACTIONS(1891),
    [anon_sym_LBRACK] = ACTIONS(1891),
    [anon_sym_static] = ACTIONS(1891),
    [anon_sym_register] = ACTIONS(1891),
    [anon_sym_inline] = ACTIONS(1891),
    [anon_sym___inline] = ACTIONS(1891),
    [anon_sym___inline__] = ACTIONS(1891),
    [anon_sym___forceinline] = ACTIONS(1891),
    [anon_sym_thread_local] = ACTIONS(1891),
    [anon_sym___thread] = ACTIONS(1891),
    [anon_sym_const] = ACTIONS(1891),
    [anon_sym_constexpr] = ACTIONS(1891),
    [anon_sym_volatile] = ACTIONS(1891),
    [anon_sym_restrict] = ACTIONS(1891),
    [anon_sym___restrict__] = ACTIONS(1891),
    [anon_sym__Atomic] = ACTIONS(1891),
    [anon_sym__Noreturn] = ACTIONS(1891),
    [anon_sym_noreturn] = ACTIONS(1891),
    [anon_sym_mutable] = ACTIONS(1891),
    [anon_sym_constinit] = ACTIONS(1891),
    [anon_sym_consteval] = ACTIONS(1891),
    [anon_sym_alignas] = ACTIONS(1891),
    [anon_sym__Alignas] = ACTIONS(1891),
    [sym_primitive_type] = ACTIONS(1891),
    [anon_sym_enum] = ACTIONS(1891),
    [anon_sym_class] = ACTIONS(1891),
    [anon_sym_struct] = ACTIONS(1891),
    [anon_sym_union] = ACTIONS(1891),
    [anon_sym_if] = ACTIONS(1891),
    [anon_sym_else] = ACTIONS(1891),
    [anon_sym_switch] = ACTIONS(1891),
    [anon_sym_case] = ACTIONS(1891),
    [anon_sym_default] = ACTIONS(1891),
    [anon_sym_while] = ACTIONS(1891),
    [anon_sym_do] = ACTIONS(1891),
    [anon_sym_for] = ACTIONS(1891),
    [anon_sym_return] = ACTIONS(1891),
    [anon_sym_break] = ACTIONS(1891),
    [anon_sym_continue] = ACTIONS(1891),
    [anon_sym_goto] = ACTIONS(1891),
    [anon_sym___try] = ACTIONS(1891),
    [anon_sym___leave] = ACTIONS(1891),
    [anon_sym_not] = ACTIONS(1891),
    [anon_sym_compl] = ACTIONS(1891),
    [anon_sym_DASH_DASH] = ACTIONS(1893),
    [anon_sym_PLUS_PLUS] = ACTIONS(1893),
    [anon_sym_sizeof] = ACTIONS(1891),
    [anon_sym___alignof__] = ACTIONS(1891),
    [anon_sym___alignof] = ACTIONS(1891),
    [anon_sym__alignof] = ACTIONS(1891),
    [anon_sym_alignof] = ACTIONS(1891),
    [anon_sym__Alignof] = ACTIONS(1891),
    [anon_sym_offsetof] = ACTIONS(1891),
    [anon_sym__Generic] = ACTIONS(1891),
    [anon_sym_asm] = ACTIONS(1891),
    [anon_sym___asm__] = ACTIONS(1891),
    [sym_number_literal] = ACTIONS(1893),
    [anon_sym_L_SQUOTE] = ACTIONS(1893),
    [anon_sym_u_SQUOTE] = ACTIONS(1893),
    [anon_sym_U_SQUOTE] = ACTIONS(1893),
    [anon_sym_u8_SQUOTE] = ACTIONS(1893),
    [anon_sym_SQUOTE] = ACTIONS(1893),
    [anon_sym_L_DQUOTE] = ACTIONS(1893),
    [anon_sym_u_DQUOTE] = ACTIONS(1893),
    [anon_sym_U_DQUOTE] = ACTIONS(1893),
    [anon_sym_u8_DQUOTE] = ACTIONS(1893),
    [anon_sym_DQUOTE] = ACTIONS(1893),
    [sym_true] = ACTIONS(1891),
    [sym_false] = ACTIONS(1891),
    [anon_sym_NULL] = ACTIONS(1891),
    [anon_sym_nullptr] = ACTIONS(1891),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1891),
    [anon_sym_decltype] = ACTIONS(1891),
    [anon_sym_final] = ACTIONS(1891),
    [anon_sym_override] = ACTIONS(1891),
    [sym_virtual] = ACTIONS(1891),
    [anon_sym_explicit] = ACTIONS(1891),
    [anon_sym_typename] = ACTIONS(1891),
    [anon_sym_template] = ACTIONS(1891),
    [anon_sym_operator] = ACTIONS(1891),
    [anon_sym_try] = ACTIONS(1891),
    [anon_sym_delete] = ACTIONS(1891),
    [anon_sym_throw] = ACTIONS(1891),
    [anon_sym_namespace] = ACTIONS(1891),
    [anon_sym_using] = ACTIONS(1891),
    [anon_sym_static_assert] = ACTIONS(1891),
    [anon_sym_concept] = ACTIONS(1891),
    [anon_sym_co_return] = ACTIONS(1891),
    [anon_sym_co_yield] = ACTIONS(1891),
    [anon_sym_R_DQUOTE] = ACTIONS(1893),
    [anon_sym_LR_DQUOTE] = ACTIONS(1893),
    [anon_sym_uR_DQUOTE] = ACTIONS(1893),
    [anon_sym_UR_DQUOTE] = ACTIONS(1893),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1893),
    [anon_sym_co_await] = ACTIONS(1891),
    [anon_sym_new] = ACTIONS(1891),
    [anon_sym_requires] = ACTIONS(1891),
    [sym_this] = ACTIONS(1891),
    [anon_sym_discard] = ACTIONS(1891),
    [anon_sym_precise] = ACTIONS(1891),
    [anon_sym_shared] = ACTIONS(1891),
    [anon_sym_groupshared] = ACTIONS(1891),
    [anon_sym_uniform] = ACTIONS(1891),
    [anon_sym_row_major] = ACTIONS(1891),
    [anon_sym_column_major] = ACTIONS(1891),
    [anon_sym_globallycoherent] = ACTIONS(1891),
    [anon_sym_centroid] = ACTIONS(1891),
    [anon_sym_noperspective] = ACTIONS(1891),
    [anon_sym_nointerpolation] = ACTIONS(1891),
    [anon_sym_sample] = ACTIONS(1891),
    [anon_sym_linear] = ACTIONS(1891),
    [anon_sym_snorm] = ACTIONS(1891),
    [anon_sym_unorm] = ACTIONS(1891),
    [anon_sym_point] = ACTIONS(1891),
    [anon_sym_line] = ACTIONS(1891),
    [anon_sym_triangleadj] = ACTIONS(1891),
    [anon_sym_lineadj] = ACTIONS(1891),
    [anon_sym_triangle] = ACTIONS(1891),
    [anon_sym_cbuffer] = ACTIONS(1891),
  },
  [146] = {
    [sym_identifier] = ACTIONS(1959),
    [aux_sym_preproc_include_token1] = ACTIONS(1959),
    [aux_sym_preproc_def_token1] = ACTIONS(1959),
    [aux_sym_preproc_if_token1] = ACTIONS(1959),
    [aux_sym_preproc_if_token2] = ACTIONS(1959),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1959),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1959),
    [aux_sym_preproc_else_token1] = ACTIONS(1959),
    [aux_sym_preproc_elif_token1] = ACTIONS(1959),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1959),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1959),
    [sym_preproc_directive] = ACTIONS(1959),
    [anon_sym_LPAREN2] = ACTIONS(1961),
    [anon_sym_BANG] = ACTIONS(1961),
    [anon_sym_TILDE] = ACTIONS(1961),
    [anon_sym_DASH] = ACTIONS(1959),
    [anon_sym_PLUS] = ACTIONS(1959),
    [anon_sym_STAR] = ACTIONS(1961),
    [anon_sym_AMP_AMP] = ACTIONS(1961),
    [anon_sym_AMP] = ACTIONS(1959),
    [anon_sym_COLON] = ACTIONS(1959),
    [anon_sym_SEMI] = ACTIONS(1961),
    [anon_sym___extension__] = ACTIONS(1959),
    [anon_sym_typedef] = ACTIONS(1959),
    [anon_sym_in] = ACTIONS(1959),
    [anon_sym_out] = ACTIONS(1959),
    [anon_sym_inout] = ACTIONS(1959),
    [anon_sym_extern] = ACTIONS(1959),
    [anon_sym___attribute__] = ACTIONS(1959),
    [anon_sym_COLON_COLON] = ACTIONS(1961),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1961),
    [anon_sym___declspec] = ACTIONS(1959),
    [anon_sym___based] = ACTIONS(1959),
    [anon_sym___cdecl] = ACTIONS(1959),
    [anon_sym___clrcall] = ACTIONS(1959),
    [anon_sym___stdcall] = ACTIONS(1959),
    [anon_sym___fastcall] = ACTIONS(1959),
    [anon_sym___thiscall] = ACTIONS(1959),
    [anon_sym___vectorcall] = ACTIONS(1959),
    [anon_sym_LBRACE] = ACTIONS(1961),
    [anon_sym_signed] = ACTIONS(1959),
    [anon_sym_unsigned] = ACTIONS(1959),
    [anon_sym_long] = ACTIONS(1959),
    [anon_sym_short] = ACTIONS(1959),
    [anon_sym_LBRACK] = ACTIONS(1959),
    [anon_sym_static] = ACTIONS(1959),
    [anon_sym_register] = ACTIONS(1959),
    [anon_sym_inline] = ACTIONS(1959),
    [anon_sym___inline] = ACTIONS(1959),
    [anon_sym___inline__] = ACTIONS(1959),
    [anon_sym___forceinline] = ACTIONS(1959),
    [anon_sym_thread_local] = ACTIONS(1959),
    [anon_sym___thread] = ACTIONS(1959),
    [anon_sym_const] = ACTIONS(1959),
    [anon_sym_constexpr] = ACTIONS(1959),
    [anon_sym_volatile] = ACTIONS(1959),
    [anon_sym_restrict] = ACTIONS(1959),
    [anon_sym___restrict__] = ACTIONS(1959),
    [anon_sym__Atomic] = ACTIONS(1959),
    [anon_sym__Noreturn] = ACTIONS(1959),
    [anon_sym_noreturn] = ACTIONS(1959),
    [anon_sym_mutable] = ACTIONS(1959),
    [anon_sym_constinit] = ACTIONS(1959),
    [anon_sym_consteval] = ACTIONS(1959),
    [anon_sym_alignas] = ACTIONS(1959),
    [anon_sym__Alignas] = ACTIONS(1959),
    [sym_primitive_type] = ACTIONS(1959),
    [anon_sym_enum] = ACTIONS(1959),
    [anon_sym_class] = ACTIONS(1959),
    [anon_sym_struct] = ACTIONS(1959),
    [anon_sym_union] = ACTIONS(1959),
    [anon_sym_if] = ACTIONS(1959),
    [anon_sym_else] = ACTIONS(1959),
    [anon_sym_switch] = ACTIONS(1959),
    [anon_sym_case] = ACTIONS(1959),
    [anon_sym_default] = ACTIONS(1959),
    [anon_sym_while] = ACTIONS(1959),
    [anon_sym_do] = ACTIONS(1959),
    [anon_sym_for] = ACTIONS(1959),
    [anon_sym_return] = ACTIONS(1959),
    [anon_sym_break] = ACTIONS(1959),
    [anon_sym_continue] = ACTIONS(1959),
    [anon_sym_goto] = ACTIONS(1959),
    [anon_sym___try] = ACTIONS(1959),
    [anon_sym___leave] = ACTIONS(1959),
    [anon_sym_not] = ACTIONS(1959),
    [anon_sym_compl] = ACTIONS(1959),
    [anon_sym_DASH_DASH] = ACTIONS(1961),
    [anon_sym_PLUS_PLUS] = ACTIONS(1961),
    [anon_sym_sizeof] = ACTIONS(1959),
    [anon_sym___alignof__] = ACTIONS(1959),
    [anon_sym___alignof] = ACTIONS(1959),
    [anon_sym__alignof] = ACTIONS(1959),
    [anon_sym_alignof] = ACTIONS(1959),
    [anon_sym__Alignof] = ACTIONS(1959),
    [anon_sym_offsetof] = ACTIONS(1959),
    [anon_sym__Generic] = ACTIONS(1959),
    [anon_sym_asm] = ACTIONS(1959),
    [anon_sym___asm__] = ACTIONS(1959),
    [sym_number_literal] = ACTIONS(1961),
    [anon_sym_L_SQUOTE] = ACTIONS(1961),
    [anon_sym_u_SQUOTE] = ACTIONS(1961),
    [anon_sym_U_SQUOTE] = ACTIONS(1961),
    [anon_sym_u8_SQUOTE] = ACTIONS(1961),
    [anon_sym_SQUOTE] = ACTIONS(1961),
    [anon_sym_L_DQUOTE] = ACTIONS(1961),
    [anon_sym_u_DQUOTE] = ACTIONS(1961),
    [anon_sym_U_DQUOTE] = ACTIONS(1961),
    [anon_sym_u8_DQUOTE] = ACTIONS(1961),
    [anon_sym_DQUOTE] = ACTIONS(1961),
    [sym_true] = ACTIONS(1959),
    [sym_false] = ACTIONS(1959),
    [anon_sym_NULL] = ACTIONS(1959),
    [anon_sym_nullptr] = ACTIONS(1959),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1959),
    [anon_sym_decltype] = ACTIONS(1959),
    [anon_sym_final] = ACTIONS(1959),
    [anon_sym_override] = ACTIONS(1959),
    [sym_virtual] = ACTIONS(1959),
    [anon_sym_explicit] = ACTIONS(1959),
    [anon_sym_typename] = ACTIONS(1959),
    [anon_sym_template] = ACTIONS(1959),
    [anon_sym_operator] = ACTIONS(1959),
    [anon_sym_try] = ACTIONS(1959),
    [anon_sym_delete] = ACTIONS(1959),
    [anon_sym_throw] = ACTIONS(1959),
    [anon_sym_namespace] = ACTIONS(1959),
    [anon_sym_using] = ACTIONS(1959),
    [anon_sym_static_assert] = ACTIONS(1959),
    [anon_sym_concept] = ACTIONS(1959),
    [anon_sym_co_return] = ACTIONS(1959),
    [anon_sym_co_yield] = ACTIONS(1959),
    [anon_sym_R_DQUOTE] = ACTIONS(1961),
    [anon_sym_LR_DQUOTE] = ACTIONS(1961),
    [anon_sym_uR_DQUOTE] = ACTIONS(1961),
    [anon_sym_UR_DQUOTE] = ACTIONS(1961),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1961),
    [anon_sym_co_await] = ACTIONS(1959),
    [anon_sym_new] = ACTIONS(1959),
    [anon_sym_requires] = ACTIONS(1959),
    [sym_this] = ACTIONS(1959),
    [anon_sym_discard] = ACTIONS(1959),
    [anon_sym_precise] = ACTIONS(1959),
    [anon_sym_shared] = ACTIONS(1959),
    [anon_sym_groupshared] = ACTIONS(1959),
    [anon_sym_uniform] = ACTIONS(1959),
    [anon_sym_row_major] = ACTIONS(1959),
    [anon_sym_column_major] = ACTIONS(1959),
    [anon_sym_globallycoherent] = ACTIONS(1959),
    [anon_sym_centroid] = ACTIONS(1959),
    [anon_sym_noperspective] = ACTIONS(1959),
    [anon_sym_nointerpolation] = ACTIONS(1959),
    [anon_sym_sample] = ACTIONS(1959),
    [anon_sym_linear] = ACTIONS(1959),
    [anon_sym_snorm] = ACTIONS(1959),
    [anon_sym_unorm] = ACTIONS(1959),
    [anon_sym_point] = ACTIONS(1959),
    [anon_sym_line] = ACTIONS(1959),
    [anon_sym_triangleadj] = ACTIONS(1959),
    [anon_sym_lineadj] = ACTIONS(1959),
    [anon_sym_triangle] = ACTIONS(1959),
    [anon_sym_cbuffer] = ACTIONS(1959),
  },
  [147] = {
    [sym_catch_clause] = STATE(153),
    [aux_sym_constructor_try_statement_repeat1] = STATE(153),
    [sym_identifier] = ACTIONS(1963),
    [aux_sym_preproc_include_token1] = ACTIONS(1963),
    [aux_sym_preproc_def_token1] = ACTIONS(1963),
    [aux_sym_preproc_if_token1] = ACTIONS(1963),
    [aux_sym_preproc_if_token2] = ACTIONS(1963),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1963),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1963),
    [aux_sym_preproc_else_token1] = ACTIONS(1963),
    [aux_sym_preproc_elif_token1] = ACTIONS(1963),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1963),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1963),
    [sym_preproc_directive] = ACTIONS(1963),
    [anon_sym_LPAREN2] = ACTIONS(1965),
    [anon_sym_BANG] = ACTIONS(1965),
    [anon_sym_TILDE] = ACTIONS(1965),
    [anon_sym_DASH] = ACTIONS(1963),
    [anon_sym_PLUS] = ACTIONS(1963),
    [anon_sym_STAR] = ACTIONS(1965),
    [anon_sym_AMP_AMP] = ACTIONS(1965),
    [anon_sym_AMP] = ACTIONS(1963),
    [anon_sym_SEMI] = ACTIONS(1965),
    [anon_sym___extension__] = ACTIONS(1963),
    [anon_sym_typedef] = ACTIONS(1963),
    [anon_sym_in] = ACTIONS(1963),
    [anon_sym_out] = ACTIONS(1963),
    [anon_sym_inout] = ACTIONS(1963),
    [anon_sym_extern] = ACTIONS(1963),
    [anon_sym___attribute__] = ACTIONS(1963),
    [anon_sym_COLON_COLON] = ACTIONS(1965),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1965),
    [anon_sym___declspec] = ACTIONS(1963),
    [anon_sym___based] = ACTIONS(1963),
    [anon_sym___cdecl] = ACTIONS(1963),
    [anon_sym___clrcall] = ACTIONS(1963),
    [anon_sym___stdcall] = ACTIONS(1963),
    [anon_sym___fastcall] = ACTIONS(1963),
    [anon_sym___thiscall] = ACTIONS(1963),
    [anon_sym___vectorcall] = ACTIONS(1963),
    [anon_sym_LBRACE] = ACTIONS(1965),
    [anon_sym_signed] = ACTIONS(1963),
    [anon_sym_unsigned] = ACTIONS(1963),
    [anon_sym_long] = ACTIONS(1963),
    [anon_sym_short] = ACTIONS(1963),
    [anon_sym_LBRACK] = ACTIONS(1963),
    [anon_sym_static] = ACTIONS(1963),
    [anon_sym_register] = ACTIONS(1963),
    [anon_sym_inline] = ACTIONS(1963),
    [anon_sym___inline] = ACTIONS(1963),
    [anon_sym___inline__] = ACTIONS(1963),
    [anon_sym___forceinline] = ACTIONS(1963),
    [anon_sym_thread_local] = ACTIONS(1963),
    [anon_sym___thread] = ACTIONS(1963),
    [anon_sym_const] = ACTIONS(1963),
    [anon_sym_constexpr] = ACTIONS(1963),
    [anon_sym_volatile] = ACTIONS(1963),
    [anon_sym_restrict] = ACTIONS(1963),
    [anon_sym___restrict__] = ACTIONS(1963),
    [anon_sym__Atomic] = ACTIONS(1963),
    [anon_sym__Noreturn] = ACTIONS(1963),
    [anon_sym_noreturn] = ACTIONS(1963),
    [anon_sym_mutable] = ACTIONS(1963),
    [anon_sym_constinit] = ACTIONS(1963),
    [anon_sym_consteval] = ACTIONS(1963),
    [anon_sym_alignas] = ACTIONS(1963),
    [anon_sym__Alignas] = ACTIONS(1963),
    [sym_primitive_type] = ACTIONS(1963),
    [anon_sym_enum] = ACTIONS(1963),
    [anon_sym_class] = ACTIONS(1963),
    [anon_sym_struct] = ACTIONS(1963),
    [anon_sym_union] = ACTIONS(1963),
    [anon_sym_if] = ACTIONS(1963),
    [anon_sym_else] = ACTIONS(1963),
    [anon_sym_switch] = ACTIONS(1963),
    [anon_sym_case] = ACTIONS(1963),
    [anon_sym_default] = ACTIONS(1963),
    [anon_sym_while] = ACTIONS(1963),
    [anon_sym_do] = ACTIONS(1963),
    [anon_sym_for] = ACTIONS(1963),
    [anon_sym_return] = ACTIONS(1963),
    [anon_sym_break] = ACTIONS(1963),
    [anon_sym_continue] = ACTIONS(1963),
    [anon_sym_goto] = ACTIONS(1963),
    [anon_sym___try] = ACTIONS(1963),
    [anon_sym___leave] = ACTIONS(1963),
    [anon_sym_not] = ACTIONS(1963),
    [anon_sym_compl] = ACTIONS(1963),
    [anon_sym_DASH_DASH] = ACTIONS(1965),
    [anon_sym_PLUS_PLUS] = ACTIONS(1965),
    [anon_sym_sizeof] = ACTIONS(1963),
    [anon_sym___alignof__] = ACTIONS(1963),
    [anon_sym___alignof] = ACTIONS(1963),
    [anon_sym__alignof] = ACTIONS(1963),
    [anon_sym_alignof] = ACTIONS(1963),
    [anon_sym__Alignof] = ACTIONS(1963),
    [anon_sym_offsetof] = ACTIONS(1963),
    [anon_sym__Generic] = ACTIONS(1963),
    [anon_sym_asm] = ACTIONS(1963),
    [anon_sym___asm__] = ACTIONS(1963),
    [sym_number_literal] = ACTIONS(1965),
    [anon_sym_L_SQUOTE] = ACTIONS(1965),
    [anon_sym_u_SQUOTE] = ACTIONS(1965),
    [anon_sym_U_SQUOTE] = ACTIONS(1965),
    [anon_sym_u8_SQUOTE] = ACTIONS(1965),
    [anon_sym_SQUOTE] = ACTIONS(1965),
    [anon_sym_L_DQUOTE] = ACTIONS(1965),
    [anon_sym_u_DQUOTE] = ACTIONS(1965),
    [anon_sym_U_DQUOTE] = ACTIONS(1965),
    [anon_sym_u8_DQUOTE] = ACTIONS(1965),
    [anon_sym_DQUOTE] = ACTIONS(1965),
    [sym_true] = ACTIONS(1963),
    [sym_false] = ACTIONS(1963),
    [anon_sym_NULL] = ACTIONS(1963),
    [anon_sym_nullptr] = ACTIONS(1963),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1963),
    [anon_sym_decltype] = ACTIONS(1963),
    [sym_virtual] = ACTIONS(1963),
    [anon_sym_explicit] = ACTIONS(1963),
    [anon_sym_typename] = ACTIONS(1963),
    [anon_sym_template] = ACTIONS(1963),
    [anon_sym_operator] = ACTIONS(1963),
    [anon_sym_try] = ACTIONS(1963),
    [anon_sym_delete] = ACTIONS(1963),
    [anon_sym_throw] = ACTIONS(1963),
    [anon_sym_namespace] = ACTIONS(1963),
    [anon_sym_using] = ACTIONS(1963),
    [anon_sym_static_assert] = ACTIONS(1963),
    [anon_sym_concept] = ACTIONS(1963),
    [anon_sym_co_return] = ACTIONS(1963),
    [anon_sym_co_yield] = ACTIONS(1963),
    [anon_sym_catch] = ACTIONS(1967),
    [anon_sym_R_DQUOTE] = ACTIONS(1965),
    [anon_sym_LR_DQUOTE] = ACTIONS(1965),
    [anon_sym_uR_DQUOTE] = ACTIONS(1965),
    [anon_sym_UR_DQUOTE] = ACTIONS(1965),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1965),
    [anon_sym_co_await] = ACTIONS(1963),
    [anon_sym_new] = ACTIONS(1963),
    [anon_sym_requires] = ACTIONS(1963),
    [sym_this] = ACTIONS(1963),
    [anon_sym_discard] = ACTIONS(1963),
    [anon_sym_precise] = ACTIONS(1963),
    [anon_sym_shared] = ACTIONS(1963),
    [anon_sym_groupshared] = ACTIONS(1963),
    [anon_sym_uniform] = ACTIONS(1963),
    [anon_sym_row_major] = ACTIONS(1963),
    [anon_sym_column_major] = ACTIONS(1963),
    [anon_sym_globallycoherent] = ACTIONS(1963),
    [anon_sym_centroid] = ACTIONS(1963),
    [anon_sym_noperspective] = ACTIONS(1963),
    [anon_sym_nointerpolation] = ACTIONS(1963),
    [anon_sym_sample] = ACTIONS(1963),
    [anon_sym_linear] = ACTIONS(1963),
    [anon_sym_snorm] = ACTIONS(1963),
    [anon_sym_unorm] = ACTIONS(1963),
    [anon_sym_point] = ACTIONS(1963),
    [anon_sym_line] = ACTIONS(1963),
    [anon_sym_triangleadj] = ACTIONS(1963),
    [anon_sym_lineadj] = ACTIONS(1963),
    [anon_sym_triangle] = ACTIONS(1963),
    [anon_sym_cbuffer] = ACTIONS(1963),
  },
  [148] = {
    [sym_identifier] = ACTIONS(1969),
    [aux_sym_preproc_include_token1] = ACTIONS(1969),
    [aux_sym_preproc_def_token1] = ACTIONS(1969),
    [aux_sym_preproc_if_token1] = ACTIONS(1969),
    [aux_sym_preproc_if_token2] = ACTIONS(1969),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1969),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1969),
    [aux_sym_preproc_else_token1] = ACTIONS(1969),
    [aux_sym_preproc_elif_token1] = ACTIONS(1969),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1969),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1969),
    [sym_preproc_directive] = ACTIONS(1969),
    [anon_sym_LPAREN2] = ACTIONS(1971),
    [anon_sym_BANG] = ACTIONS(1971),
    [anon_sym_TILDE] = ACTIONS(1971),
    [anon_sym_DASH] = ACTIONS(1969),
    [anon_sym_PLUS] = ACTIONS(1969),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_AMP_AMP] = ACTIONS(1971),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_COLON] = ACTIONS(1969),
    [anon_sym_SEMI] = ACTIONS(1971),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym_typedef] = ACTIONS(1969),
    [anon_sym_in] = ACTIONS(1969),
    [anon_sym_out] = ACTIONS(1969),
    [anon_sym_inout] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1971),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym___cdecl] = ACTIONS(1969),
    [anon_sym___clrcall] = ACTIONS(1969),
    [anon_sym___stdcall] = ACTIONS(1969),
    [anon_sym___fastcall] = ACTIONS(1969),
    [anon_sym___thiscall] = ACTIONS(1969),
    [anon_sym___vectorcall] = ACTIONS(1969),
    [anon_sym_LBRACE] = ACTIONS(1971),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1969),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [anon_sym_if] = ACTIONS(1969),
    [anon_sym_else] = ACTIONS(1969),
    [anon_sym_switch] = ACTIONS(1969),
    [anon_sym_case] = ACTIONS(1969),
    [anon_sym_default] = ACTIONS(1969),
    [anon_sym_while] = ACTIONS(1969),
    [anon_sym_do] = ACTIONS(1969),
    [anon_sym_for] = ACTIONS(1969),
    [anon_sym_return] = ACTIONS(1969),
    [anon_sym_break] = ACTIONS(1969),
    [anon_sym_continue] = ACTIONS(1969),
    [anon_sym_goto] = ACTIONS(1969),
    [anon_sym___try] = ACTIONS(1969),
    [anon_sym___leave] = ACTIONS(1969),
    [anon_sym_not] = ACTIONS(1969),
    [anon_sym_compl] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1971),
    [anon_sym_PLUS_PLUS] = ACTIONS(1971),
    [anon_sym_sizeof] = ACTIONS(1969),
    [anon_sym___alignof__] = ACTIONS(1969),
    [anon_sym___alignof] = ACTIONS(1969),
    [anon_sym__alignof] = ACTIONS(1969),
    [anon_sym_alignof] = ACTIONS(1969),
    [anon_sym__Alignof] = ACTIONS(1969),
    [anon_sym_offsetof] = ACTIONS(1969),
    [anon_sym__Generic] = ACTIONS(1969),
    [anon_sym_asm] = ACTIONS(1969),
    [anon_sym___asm__] = ACTIONS(1969),
    [sym_number_literal] = ACTIONS(1971),
    [anon_sym_L_SQUOTE] = ACTIONS(1971),
    [anon_sym_u_SQUOTE] = ACTIONS(1971),
    [anon_sym_U_SQUOTE] = ACTIONS(1971),
    [anon_sym_u8_SQUOTE] = ACTIONS(1971),
    [anon_sym_SQUOTE] = ACTIONS(1971),
    [anon_sym_L_DQUOTE] = ACTIONS(1971),
    [anon_sym_u_DQUOTE] = ACTIONS(1971),
    [anon_sym_U_DQUOTE] = ACTIONS(1971),
    [anon_sym_u8_DQUOTE] = ACTIONS(1971),
    [anon_sym_DQUOTE] = ACTIONS(1971),
    [sym_true] = ACTIONS(1969),
    [sym_false] = ACTIONS(1969),
    [anon_sym_NULL] = ACTIONS(1969),
    [anon_sym_nullptr] = ACTIONS(1969),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_final] = ACTIONS(1969),
    [anon_sym_override] = ACTIONS(1969),
    [sym_virtual] = ACTIONS(1969),
    [anon_sym_explicit] = ACTIONS(1969),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1969),
    [anon_sym_operator] = ACTIONS(1969),
    [anon_sym_try] = ACTIONS(1969),
    [anon_sym_delete] = ACTIONS(1969),
    [anon_sym_throw] = ACTIONS(1969),
    [anon_sym_namespace] = ACTIONS(1969),
    [anon_sym_using] = ACTIONS(1969),
    [anon_sym_static_assert] = ACTIONS(1969),
    [anon_sym_concept] = ACTIONS(1969),
    [anon_sym_co_return] = ACTIONS(1969),
    [anon_sym_co_yield] = ACTIONS(1969),
    [anon_sym_R_DQUOTE] = ACTIONS(1971),
    [anon_sym_LR_DQUOTE] = ACTIONS(1971),
    [anon_sym_uR_DQUOTE] = ACTIONS(1971),
    [anon_sym_UR_DQUOTE] = ACTIONS(1971),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1971),
    [anon_sym_co_await] = ACTIONS(1969),
    [anon_sym_new] = ACTIONS(1969),
    [anon_sym_requires] = ACTIONS(1969),
    [sym_this] = ACTIONS(1969),
    [anon_sym_discard] = ACTIONS(1969),
    [anon_sym_precise] = ACTIONS(1969),
    [anon_sym_shared] = ACTIONS(1969),
    [anon_sym_groupshared] = ACTIONS(1969),
    [anon_sym_uniform] = ACTIONS(1969),
    [anon_sym_row_major] = ACTIONS(1969),
    [anon_sym_column_major] = ACTIONS(1969),
    [anon_sym_globallycoherent] = ACTIONS(1969),
    [anon_sym_centroid] = ACTIONS(1969),
    [anon_sym_noperspective] = ACTIONS(1969),
    [anon_sym_nointerpolation] = ACTIONS(1969),
    [anon_sym_sample] = ACTIONS(1969),
    [anon_sym_linear] = ACTIONS(1969),
    [anon_sym_snorm] = ACTIONS(1969),
    [anon_sym_unorm] = ACTIONS(1969),
    [anon_sym_point] = ACTIONS(1969),
    [anon_sym_line] = ACTIONS(1969),
    [anon_sym_triangleadj] = ACTIONS(1969),
    [anon_sym_lineadj] = ACTIONS(1969),
    [anon_sym_triangle] = ACTIONS(1969),
    [anon_sym_cbuffer] = ACTIONS(1969),
  },
  [149] = {
    [sym_identifier] = ACTIONS(1953),
    [aux_sym_preproc_include_token1] = ACTIONS(1953),
    [aux_sym_preproc_def_token1] = ACTIONS(1953),
    [aux_sym_preproc_if_token1] = ACTIONS(1953),
    [aux_sym_preproc_if_token2] = ACTIONS(1953),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1953),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1953),
    [aux_sym_preproc_else_token1] = ACTIONS(1953),
    [aux_sym_preproc_elif_token1] = ACTIONS(1953),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1953),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1953),
    [sym_preproc_directive] = ACTIONS(1953),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_BANG] = ACTIONS(1955),
    [anon_sym_TILDE] = ACTIONS(1955),
    [anon_sym_DASH] = ACTIONS(1953),
    [anon_sym_PLUS] = ACTIONS(1953),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym_COLON] = ACTIONS(1953),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym_typedef] = ACTIONS(1953),
    [anon_sym_in] = ACTIONS(1953),
    [anon_sym_out] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1953),
    [anon_sym_extern] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1955),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1955),
    [anon_sym___declspec] = ACTIONS(1953),
    [anon_sym___based] = ACTIONS(1953),
    [anon_sym___cdecl] = ACTIONS(1953),
    [anon_sym___clrcall] = ACTIONS(1953),
    [anon_sym___stdcall] = ACTIONS(1953),
    [anon_sym___fastcall] = ACTIONS(1953),
    [anon_sym___thiscall] = ACTIONS(1953),
    [anon_sym___vectorcall] = ACTIONS(1953),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_signed] = ACTIONS(1953),
    [anon_sym_unsigned] = ACTIONS(1953),
    [anon_sym_long] = ACTIONS(1953),
    [anon_sym_short] = ACTIONS(1953),
    [anon_sym_LBRACK] = ACTIONS(1953),
    [anon_sym_static] = ACTIONS(1953),
    [anon_sym_register] = ACTIONS(1953),
    [anon_sym_inline] = ACTIONS(1953),
    [anon_sym___inline] = ACTIONS(1953),
    [anon_sym___inline__] = ACTIONS(1953),
    [anon_sym___forceinline] = ACTIONS(1953),
    [anon_sym_thread_local] = ACTIONS(1953),
    [anon_sym___thread] = ACTIONS(1953),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [sym_primitive_type] = ACTIONS(1953),
    [anon_sym_enum] = ACTIONS(1953),
    [anon_sym_class] = ACTIONS(1953),
    [anon_sym_struct] = ACTIONS(1953),
    [anon_sym_union] = ACTIONS(1953),
    [anon_sym_if] = ACTIONS(1953),
    [anon_sym_else] = ACTIONS(1953),
    [anon_sym_switch] = ACTIONS(1953),
    [anon_sym_case] = ACTIONS(1953),
    [anon_sym_default] = ACTIONS(1953),
    [anon_sym_while] = ACTIONS(1953),
    [anon_sym_do] = ACTIONS(1953),
    [anon_sym_for] = ACTIONS(1953),
    [anon_sym_return] = ACTIONS(1953),
    [anon_sym_break] = ACTIONS(1953),
    [anon_sym_continue] = ACTIONS(1953),
    [anon_sym_goto] = ACTIONS(1953),
    [anon_sym___try] = ACTIONS(1953),
    [anon_sym___leave] = ACTIONS(1953),
    [anon_sym_not] = ACTIONS(1953),
    [anon_sym_compl] = ACTIONS(1953),
    [anon_sym_DASH_DASH] = ACTIONS(1955),
    [anon_sym_PLUS_PLUS] = ACTIONS(1955),
    [anon_sym_sizeof] = ACTIONS(1953),
    [anon_sym___alignof__] = ACTIONS(1953),
    [anon_sym___alignof] = ACTIONS(1953),
    [anon_sym__alignof] = ACTIONS(1953),
    [anon_sym_alignof] = ACTIONS(1953),
    [anon_sym__Alignof] = ACTIONS(1953),
    [anon_sym_offsetof] = ACTIONS(1953),
    [anon_sym__Generic] = ACTIONS(1953),
    [anon_sym_asm] = ACTIONS(1953),
    [anon_sym___asm__] = ACTIONS(1953),
    [sym_number_literal] = ACTIONS(1955),
    [anon_sym_L_SQUOTE] = ACTIONS(1955),
    [anon_sym_u_SQUOTE] = ACTIONS(1955),
    [anon_sym_U_SQUOTE] = ACTIONS(1955),
    [anon_sym_u8_SQUOTE] = ACTIONS(1955),
    [anon_sym_SQUOTE] = ACTIONS(1955),
    [anon_sym_L_DQUOTE] = ACTIONS(1955),
    [anon_sym_u_DQUOTE] = ACTIONS(1955),
    [anon_sym_U_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8_DQUOTE] = ACTIONS(1955),
    [anon_sym_DQUOTE] = ACTIONS(1955),
    [sym_true] = ACTIONS(1953),
    [sym_false] = ACTIONS(1953),
    [anon_sym_NULL] = ACTIONS(1953),
    [anon_sym_nullptr] = ACTIONS(1953),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
    [sym_virtual] = ACTIONS(1953),
    [anon_sym_explicit] = ACTIONS(1953),
    [anon_sym_typename] = ACTIONS(1953),
    [anon_sym_template] = ACTIONS(1953),
    [anon_sym_operator] = ACTIONS(1953),
    [anon_sym_try] = ACTIONS(1953),
    [anon_sym_delete] = ACTIONS(1953),
    [anon_sym_throw] = ACTIONS(1953),
    [anon_sym_namespace] = ACTIONS(1953),
    [anon_sym_using] = ACTIONS(1953),
    [anon_sym_static_assert] = ACTIONS(1953),
    [anon_sym_concept] = ACTIONS(1953),
    [anon_sym_co_return] = ACTIONS(1953),
    [anon_sym_co_yield] = ACTIONS(1953),
    [anon_sym_R_DQUOTE] = ACTIONS(1955),
    [anon_sym_LR_DQUOTE] = ACTIONS(1955),
    [anon_sym_uR_DQUOTE] = ACTIONS(1955),
    [anon_sym_UR_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1955),
    [anon_sym_co_await] = ACTIONS(1953),
    [anon_sym_new] = ACTIONS(1953),
    [anon_sym_requires] = ACTIONS(1953),
    [sym_this] = ACTIONS(1953),
    [anon_sym_discard] = ACTIONS(1953),
    [anon_sym_precise] = ACTIONS(1953),
    [anon_sym_shared] = ACTIONS(1953),
    [anon_sym_groupshared] = ACTIONS(1953),
    [anon_sym_uniform] = ACTIONS(1953),
    [anon_sym_row_major] = ACTIONS(1953),
    [anon_sym_column_major] = ACTIONS(1953),
    [anon_sym_globallycoherent] = ACTIONS(1953),
    [anon_sym_centroid] = ACTIONS(1953),
    [anon_sym_noperspective] = ACTIONS(1953),
    [anon_sym_nointerpolation] = ACTIONS(1953),
    [anon_sym_sample] = ACTIONS(1953),
    [anon_sym_linear] = ACTIONS(1953),
    [anon_sym_snorm] = ACTIONS(1953),
    [anon_sym_unorm] = ACTIONS(1953),
    [anon_sym_point] = ACTIONS(1953),
    [anon_sym_line] = ACTIONS(1953),
    [anon_sym_triangleadj] = ACTIONS(1953),
    [anon_sym_lineadj] = ACTIONS(1953),
    [anon_sym_triangle] = ACTIONS(1953),
    [anon_sym_cbuffer] = ACTIONS(1953),
  },
  [150] = {
    [sym_identifier] = ACTIONS(1917),
    [aux_sym_preproc_include_token1] = ACTIONS(1917),
    [aux_sym_preproc_def_token1] = ACTIONS(1917),
    [aux_sym_preproc_if_token1] = ACTIONS(1917),
    [aux_sym_preproc_if_token2] = ACTIONS(1917),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1917),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1917),
    [aux_sym_preproc_else_token1] = ACTIONS(1917),
    [aux_sym_preproc_elif_token1] = ACTIONS(1917),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1917),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1917),
    [sym_preproc_directive] = ACTIONS(1917),
    [anon_sym_LPAREN2] = ACTIONS(1919),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1919),
    [anon_sym_AMP_AMP] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1917),
    [anon_sym_COLON] = ACTIONS(1917),
    [anon_sym_SEMI] = ACTIONS(1919),
    [anon_sym___extension__] = ACTIONS(1917),
    [anon_sym_typedef] = ACTIONS(1917),
    [anon_sym_in] = ACTIONS(1917),
    [anon_sym_out] = ACTIONS(1917),
    [anon_sym_inout] = ACTIONS(1917),
    [anon_sym_extern] = ACTIONS(1917),
    [anon_sym___attribute__] = ACTIONS(1917),
    [anon_sym_COLON_COLON] = ACTIONS(1919),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1919),
    [anon_sym___declspec] = ACTIONS(1917),
    [anon_sym___based] = ACTIONS(1917),
    [anon_sym___cdecl] = ACTIONS(1917),
    [anon_sym___clrcall] = ACTIONS(1917),
    [anon_sym___stdcall] = ACTIONS(1917),
    [anon_sym___fastcall] = ACTIONS(1917),
    [anon_sym___thiscall] = ACTIONS(1917),
    [anon_sym___vectorcall] = ACTIONS(1917),
    [anon_sym_LBRACE] = ACTIONS(1919),
    [anon_sym_signed] = ACTIONS(1917),
    [anon_sym_unsigned] = ACTIONS(1917),
    [anon_sym_long] = ACTIONS(1917),
    [anon_sym_short] = ACTIONS(1917),
    [anon_sym_LBRACK] = ACTIONS(1917),
    [anon_sym_static] = ACTIONS(1917),
    [anon_sym_register] = ACTIONS(1917),
    [anon_sym_inline] = ACTIONS(1917),
    [anon_sym___inline] = ACTIONS(1917),
    [anon_sym___inline__] = ACTIONS(1917),
    [anon_sym___forceinline] = ACTIONS(1917),
    [anon_sym_thread_local] = ACTIONS(1917),
    [anon_sym___thread] = ACTIONS(1917),
    [anon_sym_const] = ACTIONS(1917),
    [anon_sym_constexpr] = ACTIONS(1917),
    [anon_sym_volatile] = ACTIONS(1917),
    [anon_sym_restrict] = ACTIONS(1917),
    [anon_sym___restrict__] = ACTIONS(1917),
    [anon_sym__Atomic] = ACTIONS(1917),
    [anon_sym__Noreturn] = ACTIONS(1917),
    [anon_sym_noreturn] = ACTIONS(1917),
    [anon_sym_mutable] = ACTIONS(1917),
    [anon_sym_constinit] = ACTIONS(1917),
    [anon_sym_consteval] = ACTIONS(1917),
    [anon_sym_alignas] = ACTIONS(1917),
    [anon_sym__Alignas] = ACTIONS(1917),
    [sym_primitive_type] = ACTIONS(1917),
    [anon_sym_enum] = ACTIONS(1917),
    [anon_sym_class] = ACTIONS(1917),
    [anon_sym_struct] = ACTIONS(1917),
    [anon_sym_union] = ACTIONS(1917),
    [anon_sym_if] = ACTIONS(1917),
    [anon_sym_else] = ACTIONS(1917),
    [anon_sym_switch] = ACTIONS(1917),
    [anon_sym_case] = ACTIONS(1917),
    [anon_sym_default] = ACTIONS(1917),
    [anon_sym_while] = ACTIONS(1917),
    [anon_sym_do] = ACTIONS(1917),
    [anon_sym_for] = ACTIONS(1917),
    [anon_sym_return] = ACTIONS(1917),
    [anon_sym_break] = ACTIONS(1917),
    [anon_sym_continue] = ACTIONS(1917),
    [anon_sym_goto] = ACTIONS(1917),
    [anon_sym___try] = ACTIONS(1917),
    [anon_sym___leave] = ACTIONS(1917),
    [anon_sym_not] = ACTIONS(1917),
    [anon_sym_compl] = ACTIONS(1917),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_sizeof] = ACTIONS(1917),
    [anon_sym___alignof__] = ACTIONS(1917),
    [anon_sym___alignof] = ACTIONS(1917),
    [anon_sym__alignof] = ACTIONS(1917),
    [anon_sym_alignof] = ACTIONS(1917),
    [anon_sym__Alignof] = ACTIONS(1917),
    [anon_sym_offsetof] = ACTIONS(1917),
    [anon_sym__Generic] = ACTIONS(1917),
    [anon_sym_asm] = ACTIONS(1917),
    [anon_sym___asm__] = ACTIONS(1917),
    [sym_number_literal] = ACTIONS(1919),
    [anon_sym_L_SQUOTE] = ACTIONS(1919),
    [anon_sym_u_SQUOTE] = ACTIONS(1919),
    [anon_sym_U_SQUOTE] = ACTIONS(1919),
    [anon_sym_u8_SQUOTE] = ACTIONS(1919),
    [anon_sym_SQUOTE] = ACTIONS(1919),
    [anon_sym_L_DQUOTE] = ACTIONS(1919),
    [anon_sym_u_DQUOTE] = ACTIONS(1919),
    [anon_sym_U_DQUOTE] = ACTIONS(1919),
    [anon_sym_u8_DQUOTE] = ACTIONS(1919),
    [anon_sym_DQUOTE] = ACTIONS(1919),
    [sym_true] = ACTIONS(1917),
    [sym_false] = ACTIONS(1917),
    [anon_sym_NULL] = ACTIONS(1917),
    [anon_sym_nullptr] = ACTIONS(1917),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1917),
    [anon_sym_decltype] = ACTIONS(1917),
    [anon_sym_final] = ACTIONS(1917),
    [anon_sym_override] = ACTIONS(1917),
    [sym_virtual] = ACTIONS(1917),
    [anon_sym_explicit] = ACTIONS(1917),
    [anon_sym_typename] = ACTIONS(1917),
    [anon_sym_template] = ACTIONS(1917),
    [anon_sym_operator] = ACTIONS(1917),
    [anon_sym_try] = ACTIONS(1917),
    [anon_sym_delete] = ACTIONS(1917),
    [anon_sym_throw] = ACTIONS(1917),
    [anon_sym_namespace] = ACTIONS(1917),
    [anon_sym_using] = ACTIONS(1917),
    [anon_sym_static_assert] = ACTIONS(1917),
    [anon_sym_concept] = ACTIONS(1917),
    [anon_sym_co_return] = ACTIONS(1917),
    [anon_sym_co_yield] = ACTIONS(1917),
    [anon_sym_R_DQUOTE] = ACTIONS(1919),
    [anon_sym_LR_DQUOTE] = ACTIONS(1919),
    [anon_sym_uR_DQUOTE] = ACTIONS(1919),
    [anon_sym_UR_DQUOTE] = ACTIONS(1919),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1919),
    [anon_sym_co_await] = ACTIONS(1917),
    [anon_sym_new] = ACTIONS(1917),
    [anon_sym_requires] = ACTIONS(1917),
    [sym_this] = ACTIONS(1917),
    [anon_sym_discard] = ACTIONS(1917),
    [anon_sym_precise] = ACTIONS(1917),
    [anon_sym_shared] = ACTIONS(1917),
    [anon_sym_groupshared] = ACTIONS(1917),
    [anon_sym_uniform] = ACTIONS(1917),
    [anon_sym_row_major] = ACTIONS(1917),
    [anon_sym_column_major] = ACTIONS(1917),
    [anon_sym_globallycoherent] = ACTIONS(1917),
    [anon_sym_centroid] = ACTIONS(1917),
    [anon_sym_noperspective] = ACTIONS(1917),
    [anon_sym_nointerpolation] = ACTIONS(1917),
    [anon_sym_sample] = ACTIONS(1917),
    [anon_sym_linear] = ACTIONS(1917),
    [anon_sym_snorm] = ACTIONS(1917),
    [anon_sym_unorm] = ACTIONS(1917),
    [anon_sym_point] = ACTIONS(1917),
    [anon_sym_line] = ACTIONS(1917),
    [anon_sym_triangleadj] = ACTIONS(1917),
    [anon_sym_lineadj] = ACTIONS(1917),
    [anon_sym_triangle] = ACTIONS(1917),
    [anon_sym_cbuffer] = ACTIONS(1917),
  },
  [151] = {
    [sym_identifier] = ACTIONS(1895),
    [aux_sym_preproc_include_token1] = ACTIONS(1895),
    [aux_sym_preproc_def_token1] = ACTIONS(1895),
    [aux_sym_preproc_if_token1] = ACTIONS(1895),
    [aux_sym_preproc_if_token2] = ACTIONS(1895),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1895),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1895),
    [aux_sym_preproc_else_token1] = ACTIONS(1895),
    [aux_sym_preproc_elif_token1] = ACTIONS(1895),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1895),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1895),
    [sym_preproc_directive] = ACTIONS(1895),
    [anon_sym_LPAREN2] = ACTIONS(1897),
    [anon_sym_BANG] = ACTIONS(1897),
    [anon_sym_TILDE] = ACTIONS(1897),
    [anon_sym_DASH] = ACTIONS(1895),
    [anon_sym_PLUS] = ACTIONS(1895),
    [anon_sym_STAR] = ACTIONS(1897),
    [anon_sym_AMP_AMP] = ACTIONS(1897),
    [anon_sym_AMP] = ACTIONS(1895),
    [anon_sym_COLON] = ACTIONS(1895),
    [anon_sym_SEMI] = ACTIONS(1897),
    [anon_sym___extension__] = ACTIONS(1895),
    [anon_sym_typedef] = ACTIONS(1895),
    [anon_sym_in] = ACTIONS(1895),
    [anon_sym_out] = ACTIONS(1895),
    [anon_sym_inout] = ACTIONS(1895),
    [anon_sym_extern] = ACTIONS(1895),
    [anon_sym___attribute__] = ACTIONS(1895),
    [anon_sym_COLON_COLON] = ACTIONS(1897),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1897),
    [anon_sym___declspec] = ACTIONS(1895),
    [anon_sym___based] = ACTIONS(1895),
    [anon_sym___cdecl] = ACTIONS(1895),
    [anon_sym___clrcall] = ACTIONS(1895),
    [anon_sym___stdcall] = ACTIONS(1895),
    [anon_sym___fastcall] = ACTIONS(1895),
    [anon_sym___thiscall] = ACTIONS(1895),
    [anon_sym___vectorcall] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1897),
    [anon_sym_signed] = ACTIONS(1895),
    [anon_sym_unsigned] = ACTIONS(1895),
    [anon_sym_long] = ACTIONS(1895),
    [anon_sym_short] = ACTIONS(1895),
    [anon_sym_LBRACK] = ACTIONS(1895),
    [anon_sym_static] = ACTIONS(1895),
    [anon_sym_register] = ACTIONS(1895),
    [anon_sym_inline] = ACTIONS(1895),
    [anon_sym___inline] = ACTIONS(1895),
    [anon_sym___inline__] = ACTIONS(1895),
    [anon_sym___forceinline] = ACTIONS(1895),
    [anon_sym_thread_local] = ACTIONS(1895),
    [anon_sym___thread] = ACTIONS(1895),
    [anon_sym_const] = ACTIONS(1895),
    [anon_sym_constexpr] = ACTIONS(1895),
    [anon_sym_volatile] = ACTIONS(1895),
    [anon_sym_restrict] = ACTIONS(1895),
    [anon_sym___restrict__] = ACTIONS(1895),
    [anon_sym__Atomic] = ACTIONS(1895),
    [anon_sym__Noreturn] = ACTIONS(1895),
    [anon_sym_noreturn] = ACTIONS(1895),
    [anon_sym_mutable] = ACTIONS(1895),
    [anon_sym_constinit] = ACTIONS(1895),
    [anon_sym_consteval] = ACTIONS(1895),
    [anon_sym_alignas] = ACTIONS(1895),
    [anon_sym__Alignas] = ACTIONS(1895),
    [sym_primitive_type] = ACTIONS(1895),
    [anon_sym_enum] = ACTIONS(1895),
    [anon_sym_class] = ACTIONS(1895),
    [anon_sym_struct] = ACTIONS(1895),
    [anon_sym_union] = ACTIONS(1895),
    [anon_sym_if] = ACTIONS(1895),
    [anon_sym_else] = ACTIONS(1895),
    [anon_sym_switch] = ACTIONS(1895),
    [anon_sym_case] = ACTIONS(1895),
    [anon_sym_default] = ACTIONS(1895),
    [anon_sym_while] = ACTIONS(1895),
    [anon_sym_do] = ACTIONS(1895),
    [anon_sym_for] = ACTIONS(1895),
    [anon_sym_return] = ACTIONS(1895),
    [anon_sym_break] = ACTIONS(1895),
    [anon_sym_continue] = ACTIONS(1895),
    [anon_sym_goto] = ACTIONS(1895),
    [anon_sym___try] = ACTIONS(1895),
    [anon_sym___leave] = ACTIONS(1895),
    [anon_sym_not] = ACTIONS(1895),
    [anon_sym_compl] = ACTIONS(1895),
    [anon_sym_DASH_DASH] = ACTIONS(1897),
    [anon_sym_PLUS_PLUS] = ACTIONS(1897),
    [anon_sym_sizeof] = ACTIONS(1895),
    [anon_sym___alignof__] = ACTIONS(1895),
    [anon_sym___alignof] = ACTIONS(1895),
    [anon_sym__alignof] = ACTIONS(1895),
    [anon_sym_alignof] = ACTIONS(1895),
    [anon_sym__Alignof] = ACTIONS(1895),
    [anon_sym_offsetof] = ACTIONS(1895),
    [anon_sym__Generic] = ACTIONS(1895),
    [anon_sym_asm] = ACTIONS(1895),
    [anon_sym___asm__] = ACTIONS(1895),
    [sym_number_literal] = ACTIONS(1897),
    [anon_sym_L_SQUOTE] = ACTIONS(1897),
    [anon_sym_u_SQUOTE] = ACTIONS(1897),
    [anon_sym_U_SQUOTE] = ACTIONS(1897),
    [anon_sym_u8_SQUOTE] = ACTIONS(1897),
    [anon_sym_SQUOTE] = ACTIONS(1897),
    [anon_sym_L_DQUOTE] = ACTIONS(1897),
    [anon_sym_u_DQUOTE] = ACTIONS(1897),
    [anon_sym_U_DQUOTE] = ACTIONS(1897),
    [anon_sym_u8_DQUOTE] = ACTIONS(1897),
    [anon_sym_DQUOTE] = ACTIONS(1897),
    [sym_true] = ACTIONS(1895),
    [sym_false] = ACTIONS(1895),
    [anon_sym_NULL] = ACTIONS(1895),
    [anon_sym_nullptr] = ACTIONS(1895),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1895),
    [anon_sym_decltype] = ACTIONS(1895),
    [anon_sym_final] = ACTIONS(1895),
    [anon_sym_override] = ACTIONS(1895),
    [sym_virtual] = ACTIONS(1895),
    [anon_sym_explicit] = ACTIONS(1895),
    [anon_sym_typename] = ACTIONS(1895),
    [anon_sym_template] = ACTIONS(1895),
    [anon_sym_operator] = ACTIONS(1895),
    [anon_sym_try] = ACTIONS(1895),
    [anon_sym_delete] = ACTIONS(1895),
    [anon_sym_throw] = ACTIONS(1895),
    [anon_sym_namespace] = ACTIONS(1895),
    [anon_sym_using] = ACTIONS(1895),
    [anon_sym_static_assert] = ACTIONS(1895),
    [anon_sym_concept] = ACTIONS(1895),
    [anon_sym_co_return] = ACTIONS(1895),
    [anon_sym_co_yield] = ACTIONS(1895),
    [anon_sym_R_DQUOTE] = ACTIONS(1897),
    [anon_sym_LR_DQUOTE] = ACTIONS(1897),
    [anon_sym_uR_DQUOTE] = ACTIONS(1897),
    [anon_sym_UR_DQUOTE] = ACTIONS(1897),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1897),
    [anon_sym_co_await] = ACTIONS(1895),
    [anon_sym_new] = ACTIONS(1895),
    [anon_sym_requires] = ACTIONS(1895),
    [sym_this] = ACTIONS(1895),
    [anon_sym_discard] = ACTIONS(1895),
    [anon_sym_precise] = ACTIONS(1895),
    [anon_sym_shared] = ACTIONS(1895),
    [anon_sym_groupshared] = ACTIONS(1895),
    [anon_sym_uniform] = ACTIONS(1895),
    [anon_sym_row_major] = ACTIONS(1895),
    [anon_sym_column_major] = ACTIONS(1895),
    [anon_sym_globallycoherent] = ACTIONS(1895),
    [anon_sym_centroid] = ACTIONS(1895),
    [anon_sym_noperspective] = ACTIONS(1895),
    [anon_sym_nointerpolation] = ACTIONS(1895),
    [anon_sym_sample] = ACTIONS(1895),
    [anon_sym_linear] = ACTIONS(1895),
    [anon_sym_snorm] = ACTIONS(1895),
    [anon_sym_unorm] = ACTIONS(1895),
    [anon_sym_point] = ACTIONS(1895),
    [anon_sym_line] = ACTIONS(1895),
    [anon_sym_triangleadj] = ACTIONS(1895),
    [anon_sym_lineadj] = ACTIONS(1895),
    [anon_sym_triangle] = ACTIONS(1895),
    [anon_sym_cbuffer] = ACTIONS(1895),
  },
  [152] = {
    [sym_identifier] = ACTIONS(1903),
    [aux_sym_preproc_include_token1] = ACTIONS(1903),
    [aux_sym_preproc_def_token1] = ACTIONS(1903),
    [aux_sym_preproc_if_token1] = ACTIONS(1903),
    [aux_sym_preproc_if_token2] = ACTIONS(1903),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1903),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1903),
    [aux_sym_preproc_else_token1] = ACTIONS(1903),
    [aux_sym_preproc_elif_token1] = ACTIONS(1903),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1903),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1903),
    [sym_preproc_directive] = ACTIONS(1903),
    [anon_sym_LPAREN2] = ACTIONS(1905),
    [anon_sym_BANG] = ACTIONS(1905),
    [anon_sym_TILDE] = ACTIONS(1905),
    [anon_sym_DASH] = ACTIONS(1903),
    [anon_sym_PLUS] = ACTIONS(1903),
    [anon_sym_STAR] = ACTIONS(1905),
    [anon_sym_AMP_AMP] = ACTIONS(1905),
    [anon_sym_AMP] = ACTIONS(1903),
    [anon_sym_COLON] = ACTIONS(1903),
    [anon_sym_SEMI] = ACTIONS(1905),
    [anon_sym___extension__] = ACTIONS(1903),
    [anon_sym_typedef] = ACTIONS(1903),
    [anon_sym_in] = ACTIONS(1903),
    [anon_sym_out] = ACTIONS(1903),
    [anon_sym_inout] = ACTIONS(1903),
    [anon_sym_extern] = ACTIONS(1903),
    [anon_sym___attribute__] = ACTIONS(1903),
    [anon_sym_COLON_COLON] = ACTIONS(1905),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1905),
    [anon_sym___declspec] = ACTIONS(1903),
    [anon_sym___based] = ACTIONS(1903),
    [anon_sym___cdecl] = ACTIONS(1903),
    [anon_sym___clrcall] = ACTIONS(1903),
    [anon_sym___stdcall] = ACTIONS(1903),
    [anon_sym___fastcall] = ACTIONS(1903),
    [anon_sym___thiscall] = ACTIONS(1903),
    [anon_sym___vectorcall] = ACTIONS(1903),
    [anon_sym_LBRACE] = ACTIONS(1905),
    [anon_sym_signed] = ACTIONS(1903),
    [anon_sym_unsigned] = ACTIONS(1903),
    [anon_sym_long] = ACTIONS(1903),
    [anon_sym_short] = ACTIONS(1903),
    [anon_sym_LBRACK] = ACTIONS(1903),
    [anon_sym_static] = ACTIONS(1903),
    [anon_sym_register] = ACTIONS(1903),
    [anon_sym_inline] = ACTIONS(1903),
    [anon_sym___inline] = ACTIONS(1903),
    [anon_sym___inline__] = ACTIONS(1903),
    [anon_sym___forceinline] = ACTIONS(1903),
    [anon_sym_thread_local] = ACTIONS(1903),
    [anon_sym___thread] = ACTIONS(1903),
    [anon_sym_const] = ACTIONS(1903),
    [anon_sym_constexpr] = ACTIONS(1903),
    [anon_sym_volatile] = ACTIONS(1903),
    [anon_sym_restrict] = ACTIONS(1903),
    [anon_sym___restrict__] = ACTIONS(1903),
    [anon_sym__Atomic] = ACTIONS(1903),
    [anon_sym__Noreturn] = ACTIONS(1903),
    [anon_sym_noreturn] = ACTIONS(1903),
    [anon_sym_mutable] = ACTIONS(1903),
    [anon_sym_constinit] = ACTIONS(1903),
    [anon_sym_consteval] = ACTIONS(1903),
    [anon_sym_alignas] = ACTIONS(1903),
    [anon_sym__Alignas] = ACTIONS(1903),
    [sym_primitive_type] = ACTIONS(1903),
    [anon_sym_enum] = ACTIONS(1903),
    [anon_sym_class] = ACTIONS(1903),
    [anon_sym_struct] = ACTIONS(1903),
    [anon_sym_union] = ACTIONS(1903),
    [anon_sym_if] = ACTIONS(1903),
    [anon_sym_else] = ACTIONS(1903),
    [anon_sym_switch] = ACTIONS(1903),
    [anon_sym_case] = ACTIONS(1903),
    [anon_sym_default] = ACTIONS(1903),
    [anon_sym_while] = ACTIONS(1903),
    [anon_sym_do] = ACTIONS(1903),
    [anon_sym_for] = ACTIONS(1903),
    [anon_sym_return] = ACTIONS(1903),
    [anon_sym_break] = ACTIONS(1903),
    [anon_sym_continue] = ACTIONS(1903),
    [anon_sym_goto] = ACTIONS(1903),
    [anon_sym___try] = ACTIONS(1903),
    [anon_sym___leave] = ACTIONS(1903),
    [anon_sym_not] = ACTIONS(1903),
    [anon_sym_compl] = ACTIONS(1903),
    [anon_sym_DASH_DASH] = ACTIONS(1905),
    [anon_sym_PLUS_PLUS] = ACTIONS(1905),
    [anon_sym_sizeof] = ACTIONS(1903),
    [anon_sym___alignof__] = ACTIONS(1903),
    [anon_sym___alignof] = ACTIONS(1903),
    [anon_sym__alignof] = ACTIONS(1903),
    [anon_sym_alignof] = ACTIONS(1903),
    [anon_sym__Alignof] = ACTIONS(1903),
    [anon_sym_offsetof] = ACTIONS(1903),
    [anon_sym__Generic] = ACTIONS(1903),
    [anon_sym_asm] = ACTIONS(1903),
    [anon_sym___asm__] = ACTIONS(1903),
    [sym_number_literal] = ACTIONS(1905),
    [anon_sym_L_SQUOTE] = ACTIONS(1905),
    [anon_sym_u_SQUOTE] = ACTIONS(1905),
    [anon_sym_U_SQUOTE] = ACTIONS(1905),
    [anon_sym_u8_SQUOTE] = ACTIONS(1905),
    [anon_sym_SQUOTE] = ACTIONS(1905),
    [anon_sym_L_DQUOTE] = ACTIONS(1905),
    [anon_sym_u_DQUOTE] = ACTIONS(1905),
    [anon_sym_U_DQUOTE] = ACTIONS(1905),
    [anon_sym_u8_DQUOTE] = ACTIONS(1905),
    [anon_sym_DQUOTE] = ACTIONS(1905),
    [sym_true] = ACTIONS(1903),
    [sym_false] = ACTIONS(1903),
    [anon_sym_NULL] = ACTIONS(1903),
    [anon_sym_nullptr] = ACTIONS(1903),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1903),
    [anon_sym_decltype] = ACTIONS(1903),
    [anon_sym_final] = ACTIONS(1903),
    [anon_sym_override] = ACTIONS(1903),
    [sym_virtual] = ACTIONS(1903),
    [anon_sym_explicit] = ACTIONS(1903),
    [anon_sym_typename] = ACTIONS(1903),
    [anon_sym_template] = ACTIONS(1903),
    [anon_sym_operator] = ACTIONS(1903),
    [anon_sym_try] = ACTIONS(1903),
    [anon_sym_delete] = ACTIONS(1903),
    [anon_sym_throw] = ACTIONS(1903),
    [anon_sym_namespace] = ACTIONS(1903),
    [anon_sym_using] = ACTIONS(1903),
    [anon_sym_static_assert] = ACTIONS(1903),
    [anon_sym_concept] = ACTIONS(1903),
    [anon_sym_co_return] = ACTIONS(1903),
    [anon_sym_co_yield] = ACTIONS(1903),
    [anon_sym_R_DQUOTE] = ACTIONS(1905),
    [anon_sym_LR_DQUOTE] = ACTIONS(1905),
    [anon_sym_uR_DQUOTE] = ACTIONS(1905),
    [anon_sym_UR_DQUOTE] = ACTIONS(1905),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1905),
    [anon_sym_co_await] = ACTIONS(1903),
    [anon_sym_new] = ACTIONS(1903),
    [anon_sym_requires] = ACTIONS(1903),
    [sym_this] = ACTIONS(1903),
    [anon_sym_discard] = ACTIONS(1903),
    [anon_sym_precise] = ACTIONS(1903),
    [anon_sym_shared] = ACTIONS(1903),
    [anon_sym_groupshared] = ACTIONS(1903),
    [anon_sym_uniform] = ACTIONS(1903),
    [anon_sym_row_major] = ACTIONS(1903),
    [anon_sym_column_major] = ACTIONS(1903),
    [anon_sym_globallycoherent] = ACTIONS(1903),
    [anon_sym_centroid] = ACTIONS(1903),
    [anon_sym_noperspective] = ACTIONS(1903),
    [anon_sym_nointerpolation] = ACTIONS(1903),
    [anon_sym_sample] = ACTIONS(1903),
    [anon_sym_linear] = ACTIONS(1903),
    [anon_sym_snorm] = ACTIONS(1903),
    [anon_sym_unorm] = ACTIONS(1903),
    [anon_sym_point] = ACTIONS(1903),
    [anon_sym_line] = ACTIONS(1903),
    [anon_sym_triangleadj] = ACTIONS(1903),
    [anon_sym_lineadj] = ACTIONS(1903),
    [anon_sym_triangle] = ACTIONS(1903),
    [anon_sym_cbuffer] = ACTIONS(1903),
  },
  [153] = {
    [sym_catch_clause] = STATE(153),
    [aux_sym_constructor_try_statement_repeat1] = STATE(153),
    [sym_identifier] = ACTIONS(1973),
    [aux_sym_preproc_include_token1] = ACTIONS(1973),
    [aux_sym_preproc_def_token1] = ACTIONS(1973),
    [aux_sym_preproc_if_token1] = ACTIONS(1973),
    [aux_sym_preproc_if_token2] = ACTIONS(1973),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1973),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1973),
    [aux_sym_preproc_else_token1] = ACTIONS(1973),
    [aux_sym_preproc_elif_token1] = ACTIONS(1973),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1973),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1973),
    [sym_preproc_directive] = ACTIONS(1973),
    [anon_sym_LPAREN2] = ACTIONS(1975),
    [anon_sym_BANG] = ACTIONS(1975),
    [anon_sym_TILDE] = ACTIONS(1975),
    [anon_sym_DASH] = ACTIONS(1973),
    [anon_sym_PLUS] = ACTIONS(1973),
    [anon_sym_STAR] = ACTIONS(1975),
    [anon_sym_AMP_AMP] = ACTIONS(1975),
    [anon_sym_AMP] = ACTIONS(1973),
    [anon_sym_SEMI] = ACTIONS(1975),
    [anon_sym___extension__] = ACTIONS(1973),
    [anon_sym_typedef] = ACTIONS(1973),
    [anon_sym_in] = ACTIONS(1973),
    [anon_sym_out] = ACTIONS(1973),
    [anon_sym_inout] = ACTIONS(1973),
    [anon_sym_extern] = ACTIONS(1973),
    [anon_sym___attribute__] = ACTIONS(1973),
    [anon_sym_COLON_COLON] = ACTIONS(1975),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1975),
    [anon_sym___declspec] = ACTIONS(1973),
    [anon_sym___based] = ACTIONS(1973),
    [anon_sym___cdecl] = ACTIONS(1973),
    [anon_sym___clrcall] = ACTIONS(1973),
    [anon_sym___stdcall] = ACTIONS(1973),
    [anon_sym___fastcall] = ACTIONS(1973),
    [anon_sym___thiscall] = ACTIONS(1973),
    [anon_sym___vectorcall] = ACTIONS(1973),
    [anon_sym_LBRACE] = ACTIONS(1975),
    [anon_sym_signed] = ACTIONS(1973),
    [anon_sym_unsigned] = ACTIONS(1973),
    [anon_sym_long] = ACTIONS(1973),
    [anon_sym_short] = ACTIONS(1973),
    [anon_sym_LBRACK] = ACTIONS(1973),
    [anon_sym_static] = ACTIONS(1973),
    [anon_sym_register] = ACTIONS(1973),
    [anon_sym_inline] = ACTIONS(1973),
    [anon_sym___inline] = ACTIONS(1973),
    [anon_sym___inline__] = ACTIONS(1973),
    [anon_sym___forceinline] = ACTIONS(1973),
    [anon_sym_thread_local] = ACTIONS(1973),
    [anon_sym___thread] = ACTIONS(1973),
    [anon_sym_const] = ACTIONS(1973),
    [anon_sym_constexpr] = ACTIONS(1973),
    [anon_sym_volatile] = ACTIONS(1973),
    [anon_sym_restrict] = ACTIONS(1973),
    [anon_sym___restrict__] = ACTIONS(1973),
    [anon_sym__Atomic] = ACTIONS(1973),
    [anon_sym__Noreturn] = ACTIONS(1973),
    [anon_sym_noreturn] = ACTIONS(1973),
    [anon_sym_mutable] = ACTIONS(1973),
    [anon_sym_constinit] = ACTIONS(1973),
    [anon_sym_consteval] = ACTIONS(1973),
    [anon_sym_alignas] = ACTIONS(1973),
    [anon_sym__Alignas] = ACTIONS(1973),
    [sym_primitive_type] = ACTIONS(1973),
    [anon_sym_enum] = ACTIONS(1973),
    [anon_sym_class] = ACTIONS(1973),
    [anon_sym_struct] = ACTIONS(1973),
    [anon_sym_union] = ACTIONS(1973),
    [anon_sym_if] = ACTIONS(1973),
    [anon_sym_else] = ACTIONS(1973),
    [anon_sym_switch] = ACTIONS(1973),
    [anon_sym_case] = ACTIONS(1973),
    [anon_sym_default] = ACTIONS(1973),
    [anon_sym_while] = ACTIONS(1973),
    [anon_sym_do] = ACTIONS(1973),
    [anon_sym_for] = ACTIONS(1973),
    [anon_sym_return] = ACTIONS(1973),
    [anon_sym_break] = ACTIONS(1973),
    [anon_sym_continue] = ACTIONS(1973),
    [anon_sym_goto] = ACTIONS(1973),
    [anon_sym___try] = ACTIONS(1973),
    [anon_sym___leave] = ACTIONS(1973),
    [anon_sym_not] = ACTIONS(1973),
    [anon_sym_compl] = ACTIONS(1973),
    [anon_sym_DASH_DASH] = ACTIONS(1975),
    [anon_sym_PLUS_PLUS] = ACTIONS(1975),
    [anon_sym_sizeof] = ACTIONS(1973),
    [anon_sym___alignof__] = ACTIONS(1973),
    [anon_sym___alignof] = ACTIONS(1973),
    [anon_sym__alignof] = ACTIONS(1973),
    [anon_sym_alignof] = ACTIONS(1973),
    [anon_sym__Alignof] = ACTIONS(1973),
    [anon_sym_offsetof] = ACTIONS(1973),
    [anon_sym__Generic] = ACTIONS(1973),
    [anon_sym_asm] = ACTIONS(1973),
    [anon_sym___asm__] = ACTIONS(1973),
    [sym_number_literal] = ACTIONS(1975),
    [anon_sym_L_SQUOTE] = ACTIONS(1975),
    [anon_sym_u_SQUOTE] = ACTIONS(1975),
    [anon_sym_U_SQUOTE] = ACTIONS(1975),
    [anon_sym_u8_SQUOTE] = ACTIONS(1975),
    [anon_sym_SQUOTE] = ACTIONS(1975),
    [anon_sym_L_DQUOTE] = ACTIONS(1975),
    [anon_sym_u_DQUOTE] = ACTIONS(1975),
    [anon_sym_U_DQUOTE] = ACTIONS(1975),
    [anon_sym_u8_DQUOTE] = ACTIONS(1975),
    [anon_sym_DQUOTE] = ACTIONS(1975),
    [sym_true] = ACTIONS(1973),
    [sym_false] = ACTIONS(1973),
    [anon_sym_NULL] = ACTIONS(1973),
    [anon_sym_nullptr] = ACTIONS(1973),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1973),
    [anon_sym_decltype] = ACTIONS(1973),
    [sym_virtual] = ACTIONS(1973),
    [anon_sym_explicit] = ACTIONS(1973),
    [anon_sym_typename] = ACTIONS(1973),
    [anon_sym_template] = ACTIONS(1973),
    [anon_sym_operator] = ACTIONS(1973),
    [anon_sym_try] = ACTIONS(1973),
    [anon_sym_delete] = ACTIONS(1973),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_namespace] = ACTIONS(1973),
    [anon_sym_using] = ACTIONS(1973),
    [anon_sym_static_assert] = ACTIONS(1973),
    [anon_sym_concept] = ACTIONS(1973),
    [anon_sym_co_return] = ACTIONS(1973),
    [anon_sym_co_yield] = ACTIONS(1973),
    [anon_sym_catch] = ACTIONS(1977),
    [anon_sym_R_DQUOTE] = ACTIONS(1975),
    [anon_sym_LR_DQUOTE] = ACTIONS(1975),
    [anon_sym_uR_DQUOTE] = ACTIONS(1975),
    [anon_sym_UR_DQUOTE] = ACTIONS(1975),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1975),
    [anon_sym_co_await] = ACTIONS(1973),
    [anon_sym_new] = ACTIONS(1973),
    [anon_sym_requires] = ACTIONS(1973),
    [sym_this] = ACTIONS(1973),
    [anon_sym_discard] = ACTIONS(1973),
    [anon_sym_precise] = ACTIONS(1973),
    [anon_sym_shared] = ACTIONS(1973),
    [anon_sym_groupshared] = ACTIONS(1973),
    [anon_sym_uniform] = ACTIONS(1973),
    [anon_sym_row_major] = ACTIONS(1973),
    [anon_sym_column_major] = ACTIONS(1973),
    [anon_sym_globallycoherent] = ACTIONS(1973),
    [anon_sym_centroid] = ACTIONS(1973),
    [anon_sym_noperspective] = ACTIONS(1973),
    [anon_sym_nointerpolation] = ACTIONS(1973),
    [anon_sym_sample] = ACTIONS(1973),
    [anon_sym_linear] = ACTIONS(1973),
    [anon_sym_snorm] = ACTIONS(1973),
    [anon_sym_unorm] = ACTIONS(1973),
    [anon_sym_point] = ACTIONS(1973),
    [anon_sym_line] = ACTIONS(1973),
    [anon_sym_triangleadj] = ACTIONS(1973),
    [anon_sym_lineadj] = ACTIONS(1973),
    [anon_sym_triangle] = ACTIONS(1973),
    [anon_sym_cbuffer] = ACTIONS(1973),
  },
  [154] = {
    [sym_identifier] = ACTIONS(1925),
    [aux_sym_preproc_include_token1] = ACTIONS(1925),
    [aux_sym_preproc_def_token1] = ACTIONS(1925),
    [aux_sym_preproc_if_token1] = ACTIONS(1925),
    [aux_sym_preproc_if_token2] = ACTIONS(1925),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1925),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1925),
    [aux_sym_preproc_else_token1] = ACTIONS(1925),
    [aux_sym_preproc_elif_token1] = ACTIONS(1925),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1925),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1925),
    [sym_preproc_directive] = ACTIONS(1925),
    [anon_sym_LPAREN2] = ACTIONS(1927),
    [anon_sym_BANG] = ACTIONS(1927),
    [anon_sym_TILDE] = ACTIONS(1927),
    [anon_sym_DASH] = ACTIONS(1925),
    [anon_sym_PLUS] = ACTIONS(1925),
    [anon_sym_STAR] = ACTIONS(1927),
    [anon_sym_AMP_AMP] = ACTIONS(1927),
    [anon_sym_AMP] = ACTIONS(1925),
    [anon_sym_COLON] = ACTIONS(1925),
    [anon_sym_SEMI] = ACTIONS(1927),
    [anon_sym___extension__] = ACTIONS(1925),
    [anon_sym_typedef] = ACTIONS(1925),
    [anon_sym_in] = ACTIONS(1925),
    [anon_sym_out] = ACTIONS(1925),
    [anon_sym_inout] = ACTIONS(1925),
    [anon_sym_extern] = ACTIONS(1925),
    [anon_sym___attribute__] = ACTIONS(1925),
    [anon_sym_COLON_COLON] = ACTIONS(1927),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1927),
    [anon_sym___declspec] = ACTIONS(1925),
    [anon_sym___based] = ACTIONS(1925),
    [anon_sym___cdecl] = ACTIONS(1925),
    [anon_sym___clrcall] = ACTIONS(1925),
    [anon_sym___stdcall] = ACTIONS(1925),
    [anon_sym___fastcall] = ACTIONS(1925),
    [anon_sym___thiscall] = ACTIONS(1925),
    [anon_sym___vectorcall] = ACTIONS(1925),
    [anon_sym_LBRACE] = ACTIONS(1927),
    [anon_sym_signed] = ACTIONS(1925),
    [anon_sym_unsigned] = ACTIONS(1925),
    [anon_sym_long] = ACTIONS(1925),
    [anon_sym_short] = ACTIONS(1925),
    [anon_sym_LBRACK] = ACTIONS(1925),
    [anon_sym_static] = ACTIONS(1925),
    [anon_sym_register] = ACTIONS(1925),
    [anon_sym_inline] = ACTIONS(1925),
    [anon_sym___inline] = ACTIONS(1925),
    [anon_sym___inline__] = ACTIONS(1925),
    [anon_sym___forceinline] = ACTIONS(1925),
    [anon_sym_thread_local] = ACTIONS(1925),
    [anon_sym___thread] = ACTIONS(1925),
    [anon_sym_const] = ACTIONS(1925),
    [anon_sym_constexpr] = ACTIONS(1925),
    [anon_sym_volatile] = ACTIONS(1925),
    [anon_sym_restrict] = ACTIONS(1925),
    [anon_sym___restrict__] = ACTIONS(1925),
    [anon_sym__Atomic] = ACTIONS(1925),
    [anon_sym__Noreturn] = ACTIONS(1925),
    [anon_sym_noreturn] = ACTIONS(1925),
    [anon_sym_mutable] = ACTIONS(1925),
    [anon_sym_constinit] = ACTIONS(1925),
    [anon_sym_consteval] = ACTIONS(1925),
    [anon_sym_alignas] = ACTIONS(1925),
    [anon_sym__Alignas] = ACTIONS(1925),
    [sym_primitive_type] = ACTIONS(1925),
    [anon_sym_enum] = ACTIONS(1925),
    [anon_sym_class] = ACTIONS(1925),
    [anon_sym_struct] = ACTIONS(1925),
    [anon_sym_union] = ACTIONS(1925),
    [anon_sym_if] = ACTIONS(1925),
    [anon_sym_else] = ACTIONS(1925),
    [anon_sym_switch] = ACTIONS(1925),
    [anon_sym_case] = ACTIONS(1925),
    [anon_sym_default] = ACTIONS(1925),
    [anon_sym_while] = ACTIONS(1925),
    [anon_sym_do] = ACTIONS(1925),
    [anon_sym_for] = ACTIONS(1925),
    [anon_sym_return] = ACTIONS(1925),
    [anon_sym_break] = ACTIONS(1925),
    [anon_sym_continue] = ACTIONS(1925),
    [anon_sym_goto] = ACTIONS(1925),
    [anon_sym___try] = ACTIONS(1925),
    [anon_sym___leave] = ACTIONS(1925),
    [anon_sym_not] = ACTIONS(1925),
    [anon_sym_compl] = ACTIONS(1925),
    [anon_sym_DASH_DASH] = ACTIONS(1927),
    [anon_sym_PLUS_PLUS] = ACTIONS(1927),
    [anon_sym_sizeof] = ACTIONS(1925),
    [anon_sym___alignof__] = ACTIONS(1925),
    [anon_sym___alignof] = ACTIONS(1925),
    [anon_sym__alignof] = ACTIONS(1925),
    [anon_sym_alignof] = ACTIONS(1925),
    [anon_sym__Alignof] = ACTIONS(1925),
    [anon_sym_offsetof] = ACTIONS(1925),
    [anon_sym__Generic] = ACTIONS(1925),
    [anon_sym_asm] = ACTIONS(1925),
    [anon_sym___asm__] = ACTIONS(1925),
    [sym_number_literal] = ACTIONS(1927),
    [anon_sym_L_SQUOTE] = ACTIONS(1927),
    [anon_sym_u_SQUOTE] = ACTIONS(1927),
    [anon_sym_U_SQUOTE] = ACTIONS(1927),
    [anon_sym_u8_SQUOTE] = ACTIONS(1927),
    [anon_sym_SQUOTE] = ACTIONS(1927),
    [anon_sym_L_DQUOTE] = ACTIONS(1927),
    [anon_sym_u_DQUOTE] = ACTIONS(1927),
    [anon_sym_U_DQUOTE] = ACTIONS(1927),
    [anon_sym_u8_DQUOTE] = ACTIONS(1927),
    [anon_sym_DQUOTE] = ACTIONS(1927),
    [sym_true] = ACTIONS(1925),
    [sym_false] = ACTIONS(1925),
    [anon_sym_NULL] = ACTIONS(1925),
    [anon_sym_nullptr] = ACTIONS(1925),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1925),
    [anon_sym_decltype] = ACTIONS(1925),
    [anon_sym_final] = ACTIONS(1925),
    [anon_sym_override] = ACTIONS(1925),
    [sym_virtual] = ACTIONS(1925),
    [anon_sym_explicit] = ACTIONS(1925),
    [anon_sym_typename] = ACTIONS(1925),
    [anon_sym_template] = ACTIONS(1925),
    [anon_sym_operator] = ACTIONS(1925),
    [anon_sym_try] = ACTIONS(1925),
    [anon_sym_delete] = ACTIONS(1925),
    [anon_sym_throw] = ACTIONS(1925),
    [anon_sym_namespace] = ACTIONS(1925),
    [anon_sym_using] = ACTIONS(1925),
    [anon_sym_static_assert] = ACTIONS(1925),
    [anon_sym_concept] = ACTIONS(1925),
    [anon_sym_co_return] = ACTIONS(1925),
    [anon_sym_co_yield] = ACTIONS(1925),
    [anon_sym_R_DQUOTE] = ACTIONS(1927),
    [anon_sym_LR_DQUOTE] = ACTIONS(1927),
    [anon_sym_uR_DQUOTE] = ACTIONS(1927),
    [anon_sym_UR_DQUOTE] = ACTIONS(1927),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1927),
    [anon_sym_co_await] = ACTIONS(1925),
    [anon_sym_new] = ACTIONS(1925),
    [anon_sym_requires] = ACTIONS(1925),
    [sym_this] = ACTIONS(1925),
    [anon_sym_discard] = ACTIONS(1925),
    [anon_sym_precise] = ACTIONS(1925),
    [anon_sym_shared] = ACTIONS(1925),
    [anon_sym_groupshared] = ACTIONS(1925),
    [anon_sym_uniform] = ACTIONS(1925),
    [anon_sym_row_major] = ACTIONS(1925),
    [anon_sym_column_major] = ACTIONS(1925),
    [anon_sym_globallycoherent] = ACTIONS(1925),
    [anon_sym_centroid] = ACTIONS(1925),
    [anon_sym_noperspective] = ACTIONS(1925),
    [anon_sym_nointerpolation] = ACTIONS(1925),
    [anon_sym_sample] = ACTIONS(1925),
    [anon_sym_linear] = ACTIONS(1925),
    [anon_sym_snorm] = ACTIONS(1925),
    [anon_sym_unorm] = ACTIONS(1925),
    [anon_sym_point] = ACTIONS(1925),
    [anon_sym_line] = ACTIONS(1925),
    [anon_sym_triangleadj] = ACTIONS(1925),
    [anon_sym_lineadj] = ACTIONS(1925),
    [anon_sym_triangle] = ACTIONS(1925),
    [anon_sym_cbuffer] = ACTIONS(1925),
  },
  [155] = {
    [sym_identifier] = ACTIONS(1887),
    [aux_sym_preproc_include_token1] = ACTIONS(1887),
    [aux_sym_preproc_def_token1] = ACTIONS(1887),
    [aux_sym_preproc_if_token1] = ACTIONS(1887),
    [aux_sym_preproc_if_token2] = ACTIONS(1887),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1887),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1887),
    [aux_sym_preproc_else_token1] = ACTIONS(1887),
    [aux_sym_preproc_elif_token1] = ACTIONS(1887),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1887),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1887),
    [sym_preproc_directive] = ACTIONS(1887),
    [anon_sym_LPAREN2] = ACTIONS(1889),
    [anon_sym_BANG] = ACTIONS(1889),
    [anon_sym_TILDE] = ACTIONS(1889),
    [anon_sym_DASH] = ACTIONS(1887),
    [anon_sym_PLUS] = ACTIONS(1887),
    [anon_sym_STAR] = ACTIONS(1889),
    [anon_sym_AMP_AMP] = ACTIONS(1889),
    [anon_sym_AMP] = ACTIONS(1887),
    [anon_sym_COLON] = ACTIONS(1887),
    [anon_sym_SEMI] = ACTIONS(1889),
    [anon_sym___extension__] = ACTIONS(1887),
    [anon_sym_typedef] = ACTIONS(1887),
    [anon_sym_in] = ACTIONS(1887),
    [anon_sym_out] = ACTIONS(1887),
    [anon_sym_inout] = ACTIONS(1887),
    [anon_sym_extern] = ACTIONS(1887),
    [anon_sym___attribute__] = ACTIONS(1887),
    [anon_sym_COLON_COLON] = ACTIONS(1889),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1889),
    [anon_sym___declspec] = ACTIONS(1887),
    [anon_sym___based] = ACTIONS(1887),
    [anon_sym___cdecl] = ACTIONS(1887),
    [anon_sym___clrcall] = ACTIONS(1887),
    [anon_sym___stdcall] = ACTIONS(1887),
    [anon_sym___fastcall] = ACTIONS(1887),
    [anon_sym___thiscall] = ACTIONS(1887),
    [anon_sym___vectorcall] = ACTIONS(1887),
    [anon_sym_LBRACE] = ACTIONS(1889),
    [anon_sym_signed] = ACTIONS(1887),
    [anon_sym_unsigned] = ACTIONS(1887),
    [anon_sym_long] = ACTIONS(1887),
    [anon_sym_short] = ACTIONS(1887),
    [anon_sym_LBRACK] = ACTIONS(1887),
    [anon_sym_static] = ACTIONS(1887),
    [anon_sym_register] = ACTIONS(1887),
    [anon_sym_inline] = ACTIONS(1887),
    [anon_sym___inline] = ACTIONS(1887),
    [anon_sym___inline__] = ACTIONS(1887),
    [anon_sym___forceinline] = ACTIONS(1887),
    [anon_sym_thread_local] = ACTIONS(1887),
    [anon_sym___thread] = ACTIONS(1887),
    [anon_sym_const] = ACTIONS(1887),
    [anon_sym_constexpr] = ACTIONS(1887),
    [anon_sym_volatile] = ACTIONS(1887),
    [anon_sym_restrict] = ACTIONS(1887),
    [anon_sym___restrict__] = ACTIONS(1887),
    [anon_sym__Atomic] = ACTIONS(1887),
    [anon_sym__Noreturn] = ACTIONS(1887),
    [anon_sym_noreturn] = ACTIONS(1887),
    [anon_sym_mutable] = ACTIONS(1887),
    [anon_sym_constinit] = ACTIONS(1887),
    [anon_sym_consteval] = ACTIONS(1887),
    [anon_sym_alignas] = ACTIONS(1887),
    [anon_sym__Alignas] = ACTIONS(1887),
    [sym_primitive_type] = ACTIONS(1887),
    [anon_sym_enum] = ACTIONS(1887),
    [anon_sym_class] = ACTIONS(1887),
    [anon_sym_struct] = ACTIONS(1887),
    [anon_sym_union] = ACTIONS(1887),
    [anon_sym_if] = ACTIONS(1887),
    [anon_sym_else] = ACTIONS(1887),
    [anon_sym_switch] = ACTIONS(1887),
    [anon_sym_case] = ACTIONS(1887),
    [anon_sym_default] = ACTIONS(1887),
    [anon_sym_while] = ACTIONS(1887),
    [anon_sym_do] = ACTIONS(1887),
    [anon_sym_for] = ACTIONS(1887),
    [anon_sym_return] = ACTIONS(1887),
    [anon_sym_break] = ACTIONS(1887),
    [anon_sym_continue] = ACTIONS(1887),
    [anon_sym_goto] = ACTIONS(1887),
    [anon_sym___try] = ACTIONS(1887),
    [anon_sym___leave] = ACTIONS(1887),
    [anon_sym_not] = ACTIONS(1887),
    [anon_sym_compl] = ACTIONS(1887),
    [anon_sym_DASH_DASH] = ACTIONS(1889),
    [anon_sym_PLUS_PLUS] = ACTIONS(1889),
    [anon_sym_sizeof] = ACTIONS(1887),
    [anon_sym___alignof__] = ACTIONS(1887),
    [anon_sym___alignof] = ACTIONS(1887),
    [anon_sym__alignof] = ACTIONS(1887),
    [anon_sym_alignof] = ACTIONS(1887),
    [anon_sym__Alignof] = ACTIONS(1887),
    [anon_sym_offsetof] = ACTIONS(1887),
    [anon_sym__Generic] = ACTIONS(1887),
    [anon_sym_asm] = ACTIONS(1887),
    [anon_sym___asm__] = ACTIONS(1887),
    [sym_number_literal] = ACTIONS(1889),
    [anon_sym_L_SQUOTE] = ACTIONS(1889),
    [anon_sym_u_SQUOTE] = ACTIONS(1889),
    [anon_sym_U_SQUOTE] = ACTIONS(1889),
    [anon_sym_u8_SQUOTE] = ACTIONS(1889),
    [anon_sym_SQUOTE] = ACTIONS(1889),
    [anon_sym_L_DQUOTE] = ACTIONS(1889),
    [anon_sym_u_DQUOTE] = ACTIONS(1889),
    [anon_sym_U_DQUOTE] = ACTIONS(1889),
    [anon_sym_u8_DQUOTE] = ACTIONS(1889),
    [anon_sym_DQUOTE] = ACTIONS(1889),
    [sym_true] = ACTIONS(1887),
    [sym_false] = ACTIONS(1887),
    [anon_sym_NULL] = ACTIONS(1887),
    [anon_sym_nullptr] = ACTIONS(1887),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1887),
    [anon_sym_decltype] = ACTIONS(1887),
    [anon_sym_final] = ACTIONS(1887),
    [anon_sym_override] = ACTIONS(1887),
    [sym_virtual] = ACTIONS(1887),
    [anon_sym_explicit] = ACTIONS(1887),
    [anon_sym_typename] = ACTIONS(1887),
    [anon_sym_template] = ACTIONS(1887),
    [anon_sym_operator] = ACTIONS(1887),
    [anon_sym_try] = ACTIONS(1887),
    [anon_sym_delete] = ACTIONS(1887),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_namespace] = ACTIONS(1887),
    [anon_sym_using] = ACTIONS(1887),
    [anon_sym_static_assert] = ACTIONS(1887),
    [anon_sym_concept] = ACTIONS(1887),
    [anon_sym_co_return] = ACTIONS(1887),
    [anon_sym_co_yield] = ACTIONS(1887),
    [anon_sym_R_DQUOTE] = ACTIONS(1889),
    [anon_sym_LR_DQUOTE] = ACTIONS(1889),
    [anon_sym_uR_DQUOTE] = ACTIONS(1889),
    [anon_sym_UR_DQUOTE] = ACTIONS(1889),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1889),
    [anon_sym_co_await] = ACTIONS(1887),
    [anon_sym_new] = ACTIONS(1887),
    [anon_sym_requires] = ACTIONS(1887),
    [sym_this] = ACTIONS(1887),
    [anon_sym_discard] = ACTIONS(1887),
    [anon_sym_precise] = ACTIONS(1887),
    [anon_sym_shared] = ACTIONS(1887),
    [anon_sym_groupshared] = ACTIONS(1887),
    [anon_sym_uniform] = ACTIONS(1887),
    [anon_sym_row_major] = ACTIONS(1887),
    [anon_sym_column_major] = ACTIONS(1887),
    [anon_sym_globallycoherent] = ACTIONS(1887),
    [anon_sym_centroid] = ACTIONS(1887),
    [anon_sym_noperspective] = ACTIONS(1887),
    [anon_sym_nointerpolation] = ACTIONS(1887),
    [anon_sym_sample] = ACTIONS(1887),
    [anon_sym_linear] = ACTIONS(1887),
    [anon_sym_snorm] = ACTIONS(1887),
    [anon_sym_unorm] = ACTIONS(1887),
    [anon_sym_point] = ACTIONS(1887),
    [anon_sym_line] = ACTIONS(1887),
    [anon_sym_triangleadj] = ACTIONS(1887),
    [anon_sym_lineadj] = ACTIONS(1887),
    [anon_sym_triangle] = ACTIONS(1887),
    [anon_sym_cbuffer] = ACTIONS(1887),
  },
  [156] = {
    [sym_field_declaration_list] = STATE(497),
    [sym_virtual_specifier] = STATE(6766),
    [sym_base_class_clause] = STATE(7643),
    [ts_builtin_sym_end] = ACTIONS(1923),
    [sym_identifier] = ACTIONS(1921),
    [aux_sym_preproc_include_token1] = ACTIONS(1921),
    [aux_sym_preproc_def_token1] = ACTIONS(1921),
    [aux_sym_preproc_if_token1] = ACTIONS(1921),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1921),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1921),
    [sym_preproc_directive] = ACTIONS(1921),
    [anon_sym_LPAREN2] = ACTIONS(1923),
    [anon_sym_BANG] = ACTIONS(1923),
    [anon_sym_TILDE] = ACTIONS(1923),
    [anon_sym_DASH] = ACTIONS(1921),
    [anon_sym_PLUS] = ACTIONS(1921),
    [anon_sym_STAR] = ACTIONS(1923),
    [anon_sym_AMP_AMP] = ACTIONS(1923),
    [anon_sym_AMP] = ACTIONS(1921),
    [anon_sym_COLON] = ACTIONS(1911),
    [anon_sym_SEMI] = ACTIONS(1923),
    [anon_sym___extension__] = ACTIONS(1921),
    [anon_sym_typedef] = ACTIONS(1921),
    [anon_sym_in] = ACTIONS(1921),
    [anon_sym_out] = ACTIONS(1921),
    [anon_sym_inout] = ACTIONS(1921),
    [anon_sym_extern] = ACTIONS(1921),
    [anon_sym___attribute__] = ACTIONS(1921),
    [anon_sym_COLON_COLON] = ACTIONS(1923),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1923),
    [anon_sym___declspec] = ACTIONS(1921),
    [anon_sym___based] = ACTIONS(1921),
    [anon_sym___cdecl] = ACTIONS(1921),
    [anon_sym___clrcall] = ACTIONS(1921),
    [anon_sym___stdcall] = ACTIONS(1921),
    [anon_sym___fastcall] = ACTIONS(1921),
    [anon_sym___thiscall] = ACTIONS(1921),
    [anon_sym___vectorcall] = ACTIONS(1921),
    [anon_sym_LBRACE] = ACTIONS(1980),
    [anon_sym_signed] = ACTIONS(1921),
    [anon_sym_unsigned] = ACTIONS(1921),
    [anon_sym_long] = ACTIONS(1921),
    [anon_sym_short] = ACTIONS(1921),
    [anon_sym_LBRACK] = ACTIONS(1921),
    [anon_sym_static] = ACTIONS(1921),
    [anon_sym_register] = ACTIONS(1921),
    [anon_sym_inline] = ACTIONS(1921),
    [anon_sym___inline] = ACTIONS(1921),
    [anon_sym___inline__] = ACTIONS(1921),
    [anon_sym___forceinline] = ACTIONS(1921),
    [anon_sym_thread_local] = ACTIONS(1921),
    [anon_sym___thread] = ACTIONS(1921),
    [anon_sym_const] = ACTIONS(1921),
    [anon_sym_constexpr] = ACTIONS(1921),
    [anon_sym_volatile] = ACTIONS(1921),
    [anon_sym_restrict] = ACTIONS(1921),
    [anon_sym___restrict__] = ACTIONS(1921),
    [anon_sym__Atomic] = ACTIONS(1921),
    [anon_sym__Noreturn] = ACTIONS(1921),
    [anon_sym_noreturn] = ACTIONS(1921),
    [anon_sym_mutable] = ACTIONS(1921),
    [anon_sym_constinit] = ACTIONS(1921),
    [anon_sym_consteval] = ACTIONS(1921),
    [anon_sym_alignas] = ACTIONS(1921),
    [anon_sym__Alignas] = ACTIONS(1921),
    [sym_primitive_type] = ACTIONS(1921),
    [anon_sym_enum] = ACTIONS(1921),
    [anon_sym_class] = ACTIONS(1921),
    [anon_sym_struct] = ACTIONS(1921),
    [anon_sym_union] = ACTIONS(1921),
    [anon_sym_if] = ACTIONS(1921),
    [anon_sym_else] = ACTIONS(1921),
    [anon_sym_switch] = ACTIONS(1921),
    [anon_sym_case] = ACTIONS(1921),
    [anon_sym_default] = ACTIONS(1921),
    [anon_sym_while] = ACTIONS(1921),
    [anon_sym_do] = ACTIONS(1921),
    [anon_sym_for] = ACTIONS(1921),
    [anon_sym_return] = ACTIONS(1921),
    [anon_sym_break] = ACTIONS(1921),
    [anon_sym_continue] = ACTIONS(1921),
    [anon_sym_goto] = ACTIONS(1921),
    [anon_sym___try] = ACTIONS(1921),
    [anon_sym___leave] = ACTIONS(1921),
    [anon_sym_not] = ACTIONS(1921),
    [anon_sym_compl] = ACTIONS(1921),
    [anon_sym_DASH_DASH] = ACTIONS(1923),
    [anon_sym_PLUS_PLUS] = ACTIONS(1923),
    [anon_sym_sizeof] = ACTIONS(1921),
    [anon_sym___alignof__] = ACTIONS(1921),
    [anon_sym___alignof] = ACTIONS(1921),
    [anon_sym__alignof] = ACTIONS(1921),
    [anon_sym_alignof] = ACTIONS(1921),
    [anon_sym__Alignof] = ACTIONS(1921),
    [anon_sym_offsetof] = ACTIONS(1921),
    [anon_sym__Generic] = ACTIONS(1921),
    [anon_sym_asm] = ACTIONS(1921),
    [anon_sym___asm__] = ACTIONS(1921),
    [sym_number_literal] = ACTIONS(1923),
    [anon_sym_L_SQUOTE] = ACTIONS(1923),
    [anon_sym_u_SQUOTE] = ACTIONS(1923),
    [anon_sym_U_SQUOTE] = ACTIONS(1923),
    [anon_sym_u8_SQUOTE] = ACTIONS(1923),
    [anon_sym_SQUOTE] = ACTIONS(1923),
    [anon_sym_L_DQUOTE] = ACTIONS(1923),
    [anon_sym_u_DQUOTE] = ACTIONS(1923),
    [anon_sym_U_DQUOTE] = ACTIONS(1923),
    [anon_sym_u8_DQUOTE] = ACTIONS(1923),
    [anon_sym_DQUOTE] = ACTIONS(1923),
    [sym_true] = ACTIONS(1921),
    [sym_false] = ACTIONS(1921),
    [anon_sym_NULL] = ACTIONS(1921),
    [anon_sym_nullptr] = ACTIONS(1921),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1921),
    [anon_sym_decltype] = ACTIONS(1921),
    [anon_sym_final] = ACTIONS(1915),
    [anon_sym_override] = ACTIONS(1915),
    [sym_virtual] = ACTIONS(1921),
    [anon_sym_explicit] = ACTIONS(1921),
    [anon_sym_typename] = ACTIONS(1921),
    [anon_sym_template] = ACTIONS(1921),
    [anon_sym_operator] = ACTIONS(1921),
    [anon_sym_try] = ACTIONS(1921),
    [anon_sym_delete] = ACTIONS(1921),
    [anon_sym_throw] = ACTIONS(1921),
    [anon_sym_namespace] = ACTIONS(1921),
    [anon_sym_using] = ACTIONS(1921),
    [anon_sym_static_assert] = ACTIONS(1921),
    [anon_sym_concept] = ACTIONS(1921),
    [anon_sym_co_return] = ACTIONS(1921),
    [anon_sym_co_yield] = ACTIONS(1921),
    [anon_sym_R_DQUOTE] = ACTIONS(1923),
    [anon_sym_LR_DQUOTE] = ACTIONS(1923),
    [anon_sym_uR_DQUOTE] = ACTIONS(1923),
    [anon_sym_UR_DQUOTE] = ACTIONS(1923),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1923),
    [anon_sym_co_await] = ACTIONS(1921),
    [anon_sym_new] = ACTIONS(1921),
    [anon_sym_requires] = ACTIONS(1921),
    [sym_this] = ACTIONS(1921),
    [anon_sym_discard] = ACTIONS(1921),
    [anon_sym_precise] = ACTIONS(1921),
    [anon_sym_shared] = ACTIONS(1921),
    [anon_sym_groupshared] = ACTIONS(1921),
    [anon_sym_uniform] = ACTIONS(1921),
    [anon_sym_row_major] = ACTIONS(1921),
    [anon_sym_column_major] = ACTIONS(1921),
    [anon_sym_globallycoherent] = ACTIONS(1921),
    [anon_sym_centroid] = ACTIONS(1921),
    [anon_sym_noperspective] = ACTIONS(1921),
    [anon_sym_nointerpolation] = ACTIONS(1921),
    [anon_sym_sample] = ACTIONS(1921),
    [anon_sym_linear] = ACTIONS(1921),
    [anon_sym_snorm] = ACTIONS(1921),
    [anon_sym_unorm] = ACTIONS(1921),
    [anon_sym_point] = ACTIONS(1921),
    [anon_sym_line] = ACTIONS(1921),
    [anon_sym_triangleadj] = ACTIONS(1921),
    [anon_sym_lineadj] = ACTIONS(1921),
    [anon_sym_triangle] = ACTIONS(1921),
    [anon_sym_cbuffer] = ACTIONS(1921),
  },
  [157] = {
    [sym_field_declaration_list] = STATE(410),
    [sym_virtual_specifier] = STATE(6839),
    [sym_base_class_clause] = STATE(7698),
    [sym_identifier] = ACTIONS(1907),
    [aux_sym_preproc_include_token1] = ACTIONS(1907),
    [aux_sym_preproc_def_token1] = ACTIONS(1907),
    [aux_sym_preproc_if_token1] = ACTIONS(1907),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1907),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1907),
    [sym_preproc_directive] = ACTIONS(1907),
    [anon_sym_LPAREN2] = ACTIONS(1909),
    [anon_sym_BANG] = ACTIONS(1909),
    [anon_sym_TILDE] = ACTIONS(1909),
    [anon_sym_DASH] = ACTIONS(1907),
    [anon_sym_PLUS] = ACTIONS(1907),
    [anon_sym_STAR] = ACTIONS(1909),
    [anon_sym_AMP_AMP] = ACTIONS(1909),
    [anon_sym_AMP] = ACTIONS(1907),
    [anon_sym_COLON] = ACTIONS(1911),
    [anon_sym_SEMI] = ACTIONS(1909),
    [anon_sym___extension__] = ACTIONS(1907),
    [anon_sym_typedef] = ACTIONS(1907),
    [anon_sym_in] = ACTIONS(1907),
    [anon_sym_out] = ACTIONS(1907),
    [anon_sym_inout] = ACTIONS(1907),
    [anon_sym_extern] = ACTIONS(1907),
    [anon_sym___attribute__] = ACTIONS(1907),
    [anon_sym_COLON_COLON] = ACTIONS(1909),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1909),
    [anon_sym___declspec] = ACTIONS(1907),
    [anon_sym___based] = ACTIONS(1907),
    [anon_sym___cdecl] = ACTIONS(1907),
    [anon_sym___clrcall] = ACTIONS(1907),
    [anon_sym___stdcall] = ACTIONS(1907),
    [anon_sym___fastcall] = ACTIONS(1907),
    [anon_sym___thiscall] = ACTIONS(1907),
    [anon_sym___vectorcall] = ACTIONS(1907),
    [anon_sym_LBRACE] = ACTIONS(1982),
    [anon_sym_RBRACE] = ACTIONS(1909),
    [anon_sym_signed] = ACTIONS(1907),
    [anon_sym_unsigned] = ACTIONS(1907),
    [anon_sym_long] = ACTIONS(1907),
    [anon_sym_short] = ACTIONS(1907),
    [anon_sym_LBRACK] = ACTIONS(1907),
    [anon_sym_static] = ACTIONS(1907),
    [anon_sym_register] = ACTIONS(1907),
    [anon_sym_inline] = ACTIONS(1907),
    [anon_sym___inline] = ACTIONS(1907),
    [anon_sym___inline__] = ACTIONS(1907),
    [anon_sym___forceinline] = ACTIONS(1907),
    [anon_sym_thread_local] = ACTIONS(1907),
    [anon_sym___thread] = ACTIONS(1907),
    [anon_sym_const] = ACTIONS(1907),
    [anon_sym_constexpr] = ACTIONS(1907),
    [anon_sym_volatile] = ACTIONS(1907),
    [anon_sym_restrict] = ACTIONS(1907),
    [anon_sym___restrict__] = ACTIONS(1907),
    [anon_sym__Atomic] = ACTIONS(1907),
    [anon_sym__Noreturn] = ACTIONS(1907),
    [anon_sym_noreturn] = ACTIONS(1907),
    [anon_sym_mutable] = ACTIONS(1907),
    [anon_sym_constinit] = ACTIONS(1907),
    [anon_sym_consteval] = ACTIONS(1907),
    [anon_sym_alignas] = ACTIONS(1907),
    [anon_sym__Alignas] = ACTIONS(1907),
    [sym_primitive_type] = ACTIONS(1907),
    [anon_sym_enum] = ACTIONS(1907),
    [anon_sym_class] = ACTIONS(1907),
    [anon_sym_struct] = ACTIONS(1907),
    [anon_sym_union] = ACTIONS(1907),
    [anon_sym_if] = ACTIONS(1907),
    [anon_sym_else] = ACTIONS(1907),
    [anon_sym_switch] = ACTIONS(1907),
    [anon_sym_case] = ACTIONS(1907),
    [anon_sym_default] = ACTIONS(1907),
    [anon_sym_while] = ACTIONS(1907),
    [anon_sym_do] = ACTIONS(1907),
    [anon_sym_for] = ACTIONS(1907),
    [anon_sym_return] = ACTIONS(1907),
    [anon_sym_break] = ACTIONS(1907),
    [anon_sym_continue] = ACTIONS(1907),
    [anon_sym_goto] = ACTIONS(1907),
    [anon_sym___try] = ACTIONS(1907),
    [anon_sym___leave] = ACTIONS(1907),
    [anon_sym_not] = ACTIONS(1907),
    [anon_sym_compl] = ACTIONS(1907),
    [anon_sym_DASH_DASH] = ACTIONS(1909),
    [anon_sym_PLUS_PLUS] = ACTIONS(1909),
    [anon_sym_sizeof] = ACTIONS(1907),
    [anon_sym___alignof__] = ACTIONS(1907),
    [anon_sym___alignof] = ACTIONS(1907),
    [anon_sym__alignof] = ACTIONS(1907),
    [anon_sym_alignof] = ACTIONS(1907),
    [anon_sym__Alignof] = ACTIONS(1907),
    [anon_sym_offsetof] = ACTIONS(1907),
    [anon_sym__Generic] = ACTIONS(1907),
    [anon_sym_asm] = ACTIONS(1907),
    [anon_sym___asm__] = ACTIONS(1907),
    [sym_number_literal] = ACTIONS(1909),
    [anon_sym_L_SQUOTE] = ACTIONS(1909),
    [anon_sym_u_SQUOTE] = ACTIONS(1909),
    [anon_sym_U_SQUOTE] = ACTIONS(1909),
    [anon_sym_u8_SQUOTE] = ACTIONS(1909),
    [anon_sym_SQUOTE] = ACTIONS(1909),
    [anon_sym_L_DQUOTE] = ACTIONS(1909),
    [anon_sym_u_DQUOTE] = ACTIONS(1909),
    [anon_sym_U_DQUOTE] = ACTIONS(1909),
    [anon_sym_u8_DQUOTE] = ACTIONS(1909),
    [anon_sym_DQUOTE] = ACTIONS(1909),
    [sym_true] = ACTIONS(1907),
    [sym_false] = ACTIONS(1907),
    [anon_sym_NULL] = ACTIONS(1907),
    [anon_sym_nullptr] = ACTIONS(1907),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1907),
    [anon_sym_decltype] = ACTIONS(1907),
    [anon_sym_final] = ACTIONS(1915),
    [anon_sym_override] = ACTIONS(1915),
    [sym_virtual] = ACTIONS(1907),
    [anon_sym_explicit] = ACTIONS(1907),
    [anon_sym_typename] = ACTIONS(1907),
    [anon_sym_template] = ACTIONS(1907),
    [anon_sym_operator] = ACTIONS(1907),
    [anon_sym_try] = ACTIONS(1907),
    [anon_sym_delete] = ACTIONS(1907),
    [anon_sym_throw] = ACTIONS(1907),
    [anon_sym_namespace] = ACTIONS(1907),
    [anon_sym_using] = ACTIONS(1907),
    [anon_sym_static_assert] = ACTIONS(1907),
    [anon_sym_concept] = ACTIONS(1907),
    [anon_sym_co_return] = ACTIONS(1907),
    [anon_sym_co_yield] = ACTIONS(1907),
    [anon_sym_R_DQUOTE] = ACTIONS(1909),
    [anon_sym_LR_DQUOTE] = ACTIONS(1909),
    [anon_sym_uR_DQUOTE] = ACTIONS(1909),
    [anon_sym_UR_DQUOTE] = ACTIONS(1909),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1909),
    [anon_sym_co_await] = ACTIONS(1907),
    [anon_sym_new] = ACTIONS(1907),
    [anon_sym_requires] = ACTIONS(1907),
    [sym_this] = ACTIONS(1907),
    [anon_sym_discard] = ACTIONS(1907),
    [anon_sym_precise] = ACTIONS(1907),
    [anon_sym_shared] = ACTIONS(1907),
    [anon_sym_groupshared] = ACTIONS(1907),
    [anon_sym_uniform] = ACTIONS(1907),
    [anon_sym_row_major] = ACTIONS(1907),
    [anon_sym_column_major] = ACTIONS(1907),
    [anon_sym_globallycoherent] = ACTIONS(1907),
    [anon_sym_centroid] = ACTIONS(1907),
    [anon_sym_noperspective] = ACTIONS(1907),
    [anon_sym_nointerpolation] = ACTIONS(1907),
    [anon_sym_sample] = ACTIONS(1907),
    [anon_sym_linear] = ACTIONS(1907),
    [anon_sym_snorm] = ACTIONS(1907),
    [anon_sym_unorm] = ACTIONS(1907),
    [anon_sym_point] = ACTIONS(1907),
    [anon_sym_line] = ACTIONS(1907),
    [anon_sym_triangleadj] = ACTIONS(1907),
    [anon_sym_lineadj] = ACTIONS(1907),
    [anon_sym_triangle] = ACTIONS(1907),
    [anon_sym_cbuffer] = ACTIONS(1907),
  },
  [158] = {
    [sym_field_declaration_list] = STATE(512),
    [sym_virtual_specifier] = STATE(6796),
    [sym_base_class_clause] = STATE(7674),
    [ts_builtin_sym_end] = ACTIONS(1909),
    [sym_identifier] = ACTIONS(1907),
    [aux_sym_preproc_include_token1] = ACTIONS(1907),
    [aux_sym_preproc_def_token1] = ACTIONS(1907),
    [aux_sym_preproc_if_token1] = ACTIONS(1907),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1907),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1907),
    [sym_preproc_directive] = ACTIONS(1907),
    [anon_sym_LPAREN2] = ACTIONS(1909),
    [anon_sym_BANG] = ACTIONS(1909),
    [anon_sym_TILDE] = ACTIONS(1909),
    [anon_sym_DASH] = ACTIONS(1907),
    [anon_sym_PLUS] = ACTIONS(1907),
    [anon_sym_STAR] = ACTIONS(1909),
    [anon_sym_AMP_AMP] = ACTIONS(1909),
    [anon_sym_AMP] = ACTIONS(1907),
    [anon_sym_COLON] = ACTIONS(1911),
    [anon_sym_SEMI] = ACTIONS(1909),
    [anon_sym___extension__] = ACTIONS(1907),
    [anon_sym_typedef] = ACTIONS(1907),
    [anon_sym_in] = ACTIONS(1907),
    [anon_sym_out] = ACTIONS(1907),
    [anon_sym_inout] = ACTIONS(1907),
    [anon_sym_extern] = ACTIONS(1907),
    [anon_sym___attribute__] = ACTIONS(1907),
    [anon_sym_COLON_COLON] = ACTIONS(1909),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1909),
    [anon_sym___declspec] = ACTIONS(1907),
    [anon_sym___based] = ACTIONS(1907),
    [anon_sym___cdecl] = ACTIONS(1907),
    [anon_sym___clrcall] = ACTIONS(1907),
    [anon_sym___stdcall] = ACTIONS(1907),
    [anon_sym___fastcall] = ACTIONS(1907),
    [anon_sym___thiscall] = ACTIONS(1907),
    [anon_sym___vectorcall] = ACTIONS(1907),
    [anon_sym_LBRACE] = ACTIONS(1980),
    [anon_sym_signed] = ACTIONS(1907),
    [anon_sym_unsigned] = ACTIONS(1907),
    [anon_sym_long] = ACTIONS(1907),
    [anon_sym_short] = ACTIONS(1907),
    [anon_sym_LBRACK] = ACTIONS(1907),
    [anon_sym_static] = ACTIONS(1907),
    [anon_sym_register] = ACTIONS(1907),
    [anon_sym_inline] = ACTIONS(1907),
    [anon_sym___inline] = ACTIONS(1907),
    [anon_sym___inline__] = ACTIONS(1907),
    [anon_sym___forceinline] = ACTIONS(1907),
    [anon_sym_thread_local] = ACTIONS(1907),
    [anon_sym___thread] = ACTIONS(1907),
    [anon_sym_const] = ACTIONS(1907),
    [anon_sym_constexpr] = ACTIONS(1907),
    [anon_sym_volatile] = ACTIONS(1907),
    [anon_sym_restrict] = ACTIONS(1907),
    [anon_sym___restrict__] = ACTIONS(1907),
    [anon_sym__Atomic] = ACTIONS(1907),
    [anon_sym__Noreturn] = ACTIONS(1907),
    [anon_sym_noreturn] = ACTIONS(1907),
    [anon_sym_mutable] = ACTIONS(1907),
    [anon_sym_constinit] = ACTIONS(1907),
    [anon_sym_consteval] = ACTIONS(1907),
    [anon_sym_alignas] = ACTIONS(1907),
    [anon_sym__Alignas] = ACTIONS(1907),
    [sym_primitive_type] = ACTIONS(1907),
    [anon_sym_enum] = ACTIONS(1907),
    [anon_sym_class] = ACTIONS(1907),
    [anon_sym_struct] = ACTIONS(1907),
    [anon_sym_union] = ACTIONS(1907),
    [anon_sym_if] = ACTIONS(1907),
    [anon_sym_else] = ACTIONS(1907),
    [anon_sym_switch] = ACTIONS(1907),
    [anon_sym_case] = ACTIONS(1907),
    [anon_sym_default] = ACTIONS(1907),
    [anon_sym_while] = ACTIONS(1907),
    [anon_sym_do] = ACTIONS(1907),
    [anon_sym_for] = ACTIONS(1907),
    [anon_sym_return] = ACTIONS(1907),
    [anon_sym_break] = ACTIONS(1907),
    [anon_sym_continue] = ACTIONS(1907),
    [anon_sym_goto] = ACTIONS(1907),
    [anon_sym___try] = ACTIONS(1907),
    [anon_sym___leave] = ACTIONS(1907),
    [anon_sym_not] = ACTIONS(1907),
    [anon_sym_compl] = ACTIONS(1907),
    [anon_sym_DASH_DASH] = ACTIONS(1909),
    [anon_sym_PLUS_PLUS] = ACTIONS(1909),
    [anon_sym_sizeof] = ACTIONS(1907),
    [anon_sym___alignof__] = ACTIONS(1907),
    [anon_sym___alignof] = ACTIONS(1907),
    [anon_sym__alignof] = ACTIONS(1907),
    [anon_sym_alignof] = ACTIONS(1907),
    [anon_sym__Alignof] = ACTIONS(1907),
    [anon_sym_offsetof] = ACTIONS(1907),
    [anon_sym__Generic] = ACTIONS(1907),
    [anon_sym_asm] = ACTIONS(1907),
    [anon_sym___asm__] = ACTIONS(1907),
    [sym_number_literal] = ACTIONS(1909),
    [anon_sym_L_SQUOTE] = ACTIONS(1909),
    [anon_sym_u_SQUOTE] = ACTIONS(1909),
    [anon_sym_U_SQUOTE] = ACTIONS(1909),
    [anon_sym_u8_SQUOTE] = ACTIONS(1909),
    [anon_sym_SQUOTE] = ACTIONS(1909),
    [anon_sym_L_DQUOTE] = ACTIONS(1909),
    [anon_sym_u_DQUOTE] = ACTIONS(1909),
    [anon_sym_U_DQUOTE] = ACTIONS(1909),
    [anon_sym_u8_DQUOTE] = ACTIONS(1909),
    [anon_sym_DQUOTE] = ACTIONS(1909),
    [sym_true] = ACTIONS(1907),
    [sym_false] = ACTIONS(1907),
    [anon_sym_NULL] = ACTIONS(1907),
    [anon_sym_nullptr] = ACTIONS(1907),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1907),
    [anon_sym_decltype] = ACTIONS(1907),
    [anon_sym_final] = ACTIONS(1915),
    [anon_sym_override] = ACTIONS(1915),
    [sym_virtual] = ACTIONS(1907),
    [anon_sym_explicit] = ACTIONS(1907),
    [anon_sym_typename] = ACTIONS(1907),
    [anon_sym_template] = ACTIONS(1907),
    [anon_sym_operator] = ACTIONS(1907),
    [anon_sym_try] = ACTIONS(1907),
    [anon_sym_delete] = ACTIONS(1907),
    [anon_sym_throw] = ACTIONS(1907),
    [anon_sym_namespace] = ACTIONS(1907),
    [anon_sym_using] = ACTIONS(1907),
    [anon_sym_static_assert] = ACTIONS(1907),
    [anon_sym_concept] = ACTIONS(1907),
    [anon_sym_co_return] = ACTIONS(1907),
    [anon_sym_co_yield] = ACTIONS(1907),
    [anon_sym_R_DQUOTE] = ACTIONS(1909),
    [anon_sym_LR_DQUOTE] = ACTIONS(1909),
    [anon_sym_uR_DQUOTE] = ACTIONS(1909),
    [anon_sym_UR_DQUOTE] = ACTIONS(1909),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1909),
    [anon_sym_co_await] = ACTIONS(1907),
    [anon_sym_new] = ACTIONS(1907),
    [anon_sym_requires] = ACTIONS(1907),
    [sym_this] = ACTIONS(1907),
    [anon_sym_discard] = ACTIONS(1907),
    [anon_sym_precise] = ACTIONS(1907),
    [anon_sym_shared] = ACTIONS(1907),
    [anon_sym_groupshared] = ACTIONS(1907),
    [anon_sym_uniform] = ACTIONS(1907),
    [anon_sym_row_major] = ACTIONS(1907),
    [anon_sym_column_major] = ACTIONS(1907),
    [anon_sym_globallycoherent] = ACTIONS(1907),
    [anon_sym_centroid] = ACTIONS(1907),
    [anon_sym_noperspective] = ACTIONS(1907),
    [anon_sym_nointerpolation] = ACTIONS(1907),
    [anon_sym_sample] = ACTIONS(1907),
    [anon_sym_linear] = ACTIONS(1907),
    [anon_sym_snorm] = ACTIONS(1907),
    [anon_sym_unorm] = ACTIONS(1907),
    [anon_sym_point] = ACTIONS(1907),
    [anon_sym_line] = ACTIONS(1907),
    [anon_sym_triangleadj] = ACTIONS(1907),
    [anon_sym_lineadj] = ACTIONS(1907),
    [anon_sym_triangle] = ACTIONS(1907),
    [anon_sym_cbuffer] = ACTIONS(1907),
  },
  [159] = {
    [sym_field_declaration_list] = STATE(463),
    [sym_virtual_specifier] = STATE(6830),
    [sym_base_class_clause] = STATE(7669),
    [sym_identifier] = ACTIONS(1921),
    [aux_sym_preproc_include_token1] = ACTIONS(1921),
    [aux_sym_preproc_def_token1] = ACTIONS(1921),
    [aux_sym_preproc_if_token1] = ACTIONS(1921),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1921),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1921),
    [sym_preproc_directive] = ACTIONS(1921),
    [anon_sym_LPAREN2] = ACTIONS(1923),
    [anon_sym_BANG] = ACTIONS(1923),
    [anon_sym_TILDE] = ACTIONS(1923),
    [anon_sym_DASH] = ACTIONS(1921),
    [anon_sym_PLUS] = ACTIONS(1921),
    [anon_sym_STAR] = ACTIONS(1923),
    [anon_sym_AMP_AMP] = ACTIONS(1923),
    [anon_sym_AMP] = ACTIONS(1921),
    [anon_sym_COLON] = ACTIONS(1911),
    [anon_sym_SEMI] = ACTIONS(1923),
    [anon_sym___extension__] = ACTIONS(1921),
    [anon_sym_typedef] = ACTIONS(1921),
    [anon_sym_in] = ACTIONS(1921),
    [anon_sym_out] = ACTIONS(1921),
    [anon_sym_inout] = ACTIONS(1921),
    [anon_sym_extern] = ACTIONS(1921),
    [anon_sym___attribute__] = ACTIONS(1921),
    [anon_sym_COLON_COLON] = ACTIONS(1923),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1923),
    [anon_sym___declspec] = ACTIONS(1921),
    [anon_sym___based] = ACTIONS(1921),
    [anon_sym___cdecl] = ACTIONS(1921),
    [anon_sym___clrcall] = ACTIONS(1921),
    [anon_sym___stdcall] = ACTIONS(1921),
    [anon_sym___fastcall] = ACTIONS(1921),
    [anon_sym___thiscall] = ACTIONS(1921),
    [anon_sym___vectorcall] = ACTIONS(1921),
    [anon_sym_LBRACE] = ACTIONS(1982),
    [anon_sym_RBRACE] = ACTIONS(1923),
    [anon_sym_signed] = ACTIONS(1921),
    [anon_sym_unsigned] = ACTIONS(1921),
    [anon_sym_long] = ACTIONS(1921),
    [anon_sym_short] = ACTIONS(1921),
    [anon_sym_LBRACK] = ACTIONS(1921),
    [anon_sym_static] = ACTIONS(1921),
    [anon_sym_register] = ACTIONS(1921),
    [anon_sym_inline] = ACTIONS(1921),
    [anon_sym___inline] = ACTIONS(1921),
    [anon_sym___inline__] = ACTIONS(1921),
    [anon_sym___forceinline] = ACTIONS(1921),
    [anon_sym_thread_local] = ACTIONS(1921),
    [anon_sym___thread] = ACTIONS(1921),
    [anon_sym_const] = ACTIONS(1921),
    [anon_sym_constexpr] = ACTIONS(1921),
    [anon_sym_volatile] = ACTIONS(1921),
    [anon_sym_restrict] = ACTIONS(1921),
    [anon_sym___restrict__] = ACTIONS(1921),
    [anon_sym__Atomic] = ACTIONS(1921),
    [anon_sym__Noreturn] = ACTIONS(1921),
    [anon_sym_noreturn] = ACTIONS(1921),
    [anon_sym_mutable] = ACTIONS(1921),
    [anon_sym_constinit] = ACTIONS(1921),
    [anon_sym_consteval] = ACTIONS(1921),
    [anon_sym_alignas] = ACTIONS(1921),
    [anon_sym__Alignas] = ACTIONS(1921),
    [sym_primitive_type] = ACTIONS(1921),
    [anon_sym_enum] = ACTIONS(1921),
    [anon_sym_class] = ACTIONS(1921),
    [anon_sym_struct] = ACTIONS(1921),
    [anon_sym_union] = ACTIONS(1921),
    [anon_sym_if] = ACTIONS(1921),
    [anon_sym_else] = ACTIONS(1921),
    [anon_sym_switch] = ACTIONS(1921),
    [anon_sym_case] = ACTIONS(1921),
    [anon_sym_default] = ACTIONS(1921),
    [anon_sym_while] = ACTIONS(1921),
    [anon_sym_do] = ACTIONS(1921),
    [anon_sym_for] = ACTIONS(1921),
    [anon_sym_return] = ACTIONS(1921),
    [anon_sym_break] = ACTIONS(1921),
    [anon_sym_continue] = ACTIONS(1921),
    [anon_sym_goto] = ACTIONS(1921),
    [anon_sym___try] = ACTIONS(1921),
    [anon_sym___leave] = ACTIONS(1921),
    [anon_sym_not] = ACTIONS(1921),
    [anon_sym_compl] = ACTIONS(1921),
    [anon_sym_DASH_DASH] = ACTIONS(1923),
    [anon_sym_PLUS_PLUS] = ACTIONS(1923),
    [anon_sym_sizeof] = ACTIONS(1921),
    [anon_sym___alignof__] = ACTIONS(1921),
    [anon_sym___alignof] = ACTIONS(1921),
    [anon_sym__alignof] = ACTIONS(1921),
    [anon_sym_alignof] = ACTIONS(1921),
    [anon_sym__Alignof] = ACTIONS(1921),
    [anon_sym_offsetof] = ACTIONS(1921),
    [anon_sym__Generic] = ACTIONS(1921),
    [anon_sym_asm] = ACTIONS(1921),
    [anon_sym___asm__] = ACTIONS(1921),
    [sym_number_literal] = ACTIONS(1923),
    [anon_sym_L_SQUOTE] = ACTIONS(1923),
    [anon_sym_u_SQUOTE] = ACTIONS(1923),
    [anon_sym_U_SQUOTE] = ACTIONS(1923),
    [anon_sym_u8_SQUOTE] = ACTIONS(1923),
    [anon_sym_SQUOTE] = ACTIONS(1923),
    [anon_sym_L_DQUOTE] = ACTIONS(1923),
    [anon_sym_u_DQUOTE] = ACTIONS(1923),
    [anon_sym_U_DQUOTE] = ACTIONS(1923),
    [anon_sym_u8_DQUOTE] = ACTIONS(1923),
    [anon_sym_DQUOTE] = ACTIONS(1923),
    [sym_true] = ACTIONS(1921),
    [sym_false] = ACTIONS(1921),
    [anon_sym_NULL] = ACTIONS(1921),
    [anon_sym_nullptr] = ACTIONS(1921),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1921),
    [anon_sym_decltype] = ACTIONS(1921),
    [anon_sym_final] = ACTIONS(1915),
    [anon_sym_override] = ACTIONS(1915),
    [sym_virtual] = ACTIONS(1921),
    [anon_sym_explicit] = ACTIONS(1921),
    [anon_sym_typename] = ACTIONS(1921),
    [anon_sym_template] = ACTIONS(1921),
    [anon_sym_operator] = ACTIONS(1921),
    [anon_sym_try] = ACTIONS(1921),
    [anon_sym_delete] = ACTIONS(1921),
    [anon_sym_throw] = ACTIONS(1921),
    [anon_sym_namespace] = ACTIONS(1921),
    [anon_sym_using] = ACTIONS(1921),
    [anon_sym_static_assert] = ACTIONS(1921),
    [anon_sym_concept] = ACTIONS(1921),
    [anon_sym_co_return] = ACTIONS(1921),
    [anon_sym_co_yield] = ACTIONS(1921),
    [anon_sym_R_DQUOTE] = ACTIONS(1923),
    [anon_sym_LR_DQUOTE] = ACTIONS(1923),
    [anon_sym_uR_DQUOTE] = ACTIONS(1923),
    [anon_sym_UR_DQUOTE] = ACTIONS(1923),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1923),
    [anon_sym_co_await] = ACTIONS(1921),
    [anon_sym_new] = ACTIONS(1921),
    [anon_sym_requires] = ACTIONS(1921),
    [sym_this] = ACTIONS(1921),
    [anon_sym_discard] = ACTIONS(1921),
    [anon_sym_precise] = ACTIONS(1921),
    [anon_sym_shared] = ACTIONS(1921),
    [anon_sym_groupshared] = ACTIONS(1921),
    [anon_sym_uniform] = ACTIONS(1921),
    [anon_sym_row_major] = ACTIONS(1921),
    [anon_sym_column_major] = ACTIONS(1921),
    [anon_sym_globallycoherent] = ACTIONS(1921),
    [anon_sym_centroid] = ACTIONS(1921),
    [anon_sym_noperspective] = ACTIONS(1921),
    [anon_sym_nointerpolation] = ACTIONS(1921),
    [anon_sym_sample] = ACTIONS(1921),
    [anon_sym_linear] = ACTIONS(1921),
    [anon_sym_snorm] = ACTIONS(1921),
    [anon_sym_unorm] = ACTIONS(1921),
    [anon_sym_point] = ACTIONS(1921),
    [anon_sym_line] = ACTIONS(1921),
    [anon_sym_triangleadj] = ACTIONS(1921),
    [anon_sym_lineadj] = ACTIONS(1921),
    [anon_sym_triangle] = ACTIONS(1921),
    [anon_sym_cbuffer] = ACTIONS(1921),
  },
  [160] = {
    [sym_catch_clause] = STATE(153),
    [aux_sym_constructor_try_statement_repeat1] = STATE(153),
    [sym_identifier] = ACTIONS(1984),
    [aux_sym_preproc_include_token1] = ACTIONS(1984),
    [aux_sym_preproc_def_token1] = ACTIONS(1984),
    [aux_sym_preproc_if_token1] = ACTIONS(1984),
    [aux_sym_preproc_if_token2] = ACTIONS(1984),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1984),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1984),
    [aux_sym_preproc_else_token1] = ACTIONS(1984),
    [aux_sym_preproc_elif_token1] = ACTIONS(1984),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1984),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1984),
    [sym_preproc_directive] = ACTIONS(1984),
    [anon_sym_LPAREN2] = ACTIONS(1986),
    [anon_sym_BANG] = ACTIONS(1986),
    [anon_sym_TILDE] = ACTIONS(1986),
    [anon_sym_DASH] = ACTIONS(1984),
    [anon_sym_PLUS] = ACTIONS(1984),
    [anon_sym_STAR] = ACTIONS(1986),
    [anon_sym_AMP_AMP] = ACTIONS(1986),
    [anon_sym_AMP] = ACTIONS(1984),
    [anon_sym_SEMI] = ACTIONS(1986),
    [anon_sym___extension__] = ACTIONS(1984),
    [anon_sym_typedef] = ACTIONS(1984),
    [anon_sym_in] = ACTIONS(1984),
    [anon_sym_out] = ACTIONS(1984),
    [anon_sym_inout] = ACTIONS(1984),
    [anon_sym_extern] = ACTIONS(1984),
    [anon_sym___attribute__] = ACTIONS(1984),
    [anon_sym_COLON_COLON] = ACTIONS(1986),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1986),
    [anon_sym___declspec] = ACTIONS(1984),
    [anon_sym___based] = ACTIONS(1984),
    [anon_sym___cdecl] = ACTIONS(1984),
    [anon_sym___clrcall] = ACTIONS(1984),
    [anon_sym___stdcall] = ACTIONS(1984),
    [anon_sym___fastcall] = ACTIONS(1984),
    [anon_sym___thiscall] = ACTIONS(1984),
    [anon_sym___vectorcall] = ACTIONS(1984),
    [anon_sym_LBRACE] = ACTIONS(1986),
    [anon_sym_signed] = ACTIONS(1984),
    [anon_sym_unsigned] = ACTIONS(1984),
    [anon_sym_long] = ACTIONS(1984),
    [anon_sym_short] = ACTIONS(1984),
    [anon_sym_LBRACK] = ACTIONS(1984),
    [anon_sym_static] = ACTIONS(1984),
    [anon_sym_register] = ACTIONS(1984),
    [anon_sym_inline] = ACTIONS(1984),
    [anon_sym___inline] = ACTIONS(1984),
    [anon_sym___inline__] = ACTIONS(1984),
    [anon_sym___forceinline] = ACTIONS(1984),
    [anon_sym_thread_local] = ACTIONS(1984),
    [anon_sym___thread] = ACTIONS(1984),
    [anon_sym_const] = ACTIONS(1984),
    [anon_sym_constexpr] = ACTIONS(1984),
    [anon_sym_volatile] = ACTIONS(1984),
    [anon_sym_restrict] = ACTIONS(1984),
    [anon_sym___restrict__] = ACTIONS(1984),
    [anon_sym__Atomic] = ACTIONS(1984),
    [anon_sym__Noreturn] = ACTIONS(1984),
    [anon_sym_noreturn] = ACTIONS(1984),
    [anon_sym_mutable] = ACTIONS(1984),
    [anon_sym_constinit] = ACTIONS(1984),
    [anon_sym_consteval] = ACTIONS(1984),
    [anon_sym_alignas] = ACTIONS(1984),
    [anon_sym__Alignas] = ACTIONS(1984),
    [sym_primitive_type] = ACTIONS(1984),
    [anon_sym_enum] = ACTIONS(1984),
    [anon_sym_class] = ACTIONS(1984),
    [anon_sym_struct] = ACTIONS(1984),
    [anon_sym_union] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(1984),
    [anon_sym_switch] = ACTIONS(1984),
    [anon_sym_case] = ACTIONS(1984),
    [anon_sym_default] = ACTIONS(1984),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_do] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1984),
    [anon_sym_return] = ACTIONS(1984),
    [anon_sym_break] = ACTIONS(1984),
    [anon_sym_continue] = ACTIONS(1984),
    [anon_sym_goto] = ACTIONS(1984),
    [anon_sym___try] = ACTIONS(1984),
    [anon_sym___leave] = ACTIONS(1984),
    [anon_sym_not] = ACTIONS(1984),
    [anon_sym_compl] = ACTIONS(1984),
    [anon_sym_DASH_DASH] = ACTIONS(1986),
    [anon_sym_PLUS_PLUS] = ACTIONS(1986),
    [anon_sym_sizeof] = ACTIONS(1984),
    [anon_sym___alignof__] = ACTIONS(1984),
    [anon_sym___alignof] = ACTIONS(1984),
    [anon_sym__alignof] = ACTIONS(1984),
    [anon_sym_alignof] = ACTIONS(1984),
    [anon_sym__Alignof] = ACTIONS(1984),
    [anon_sym_offsetof] = ACTIONS(1984),
    [anon_sym__Generic] = ACTIONS(1984),
    [anon_sym_asm] = ACTIONS(1984),
    [anon_sym___asm__] = ACTIONS(1984),
    [sym_number_literal] = ACTIONS(1986),
    [anon_sym_L_SQUOTE] = ACTIONS(1986),
    [anon_sym_u_SQUOTE] = ACTIONS(1986),
    [anon_sym_U_SQUOTE] = ACTIONS(1986),
    [anon_sym_u8_SQUOTE] = ACTIONS(1986),
    [anon_sym_SQUOTE] = ACTIONS(1986),
    [anon_sym_L_DQUOTE] = ACTIONS(1986),
    [anon_sym_u_DQUOTE] = ACTIONS(1986),
    [anon_sym_U_DQUOTE] = ACTIONS(1986),
    [anon_sym_u8_DQUOTE] = ACTIONS(1986),
    [anon_sym_DQUOTE] = ACTIONS(1986),
    [sym_true] = ACTIONS(1984),
    [sym_false] = ACTIONS(1984),
    [anon_sym_NULL] = ACTIONS(1984),
    [anon_sym_nullptr] = ACTIONS(1984),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1984),
    [anon_sym_decltype] = ACTIONS(1984),
    [sym_virtual] = ACTIONS(1984),
    [anon_sym_explicit] = ACTIONS(1984),
    [anon_sym_typename] = ACTIONS(1984),
    [anon_sym_template] = ACTIONS(1984),
    [anon_sym_operator] = ACTIONS(1984),
    [anon_sym_try] = ACTIONS(1984),
    [anon_sym_delete] = ACTIONS(1984),
    [anon_sym_throw] = ACTIONS(1984),
    [anon_sym_namespace] = ACTIONS(1984),
    [anon_sym_using] = ACTIONS(1984),
    [anon_sym_static_assert] = ACTIONS(1984),
    [anon_sym_concept] = ACTIONS(1984),
    [anon_sym_co_return] = ACTIONS(1984),
    [anon_sym_co_yield] = ACTIONS(1984),
    [anon_sym_catch] = ACTIONS(1967),
    [anon_sym_R_DQUOTE] = ACTIONS(1986),
    [anon_sym_LR_DQUOTE] = ACTIONS(1986),
    [anon_sym_uR_DQUOTE] = ACTIONS(1986),
    [anon_sym_UR_DQUOTE] = ACTIONS(1986),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1986),
    [anon_sym_co_await] = ACTIONS(1984),
    [anon_sym_new] = ACTIONS(1984),
    [anon_sym_requires] = ACTIONS(1984),
    [sym_this] = ACTIONS(1984),
    [anon_sym_discard] = ACTIONS(1984),
    [anon_sym_precise] = ACTIONS(1984),
    [anon_sym_shared] = ACTIONS(1984),
    [anon_sym_groupshared] = ACTIONS(1984),
    [anon_sym_uniform] = ACTIONS(1984),
    [anon_sym_row_major] = ACTIONS(1984),
    [anon_sym_column_major] = ACTIONS(1984),
    [anon_sym_globallycoherent] = ACTIONS(1984),
    [anon_sym_centroid] = ACTIONS(1984),
    [anon_sym_noperspective] = ACTIONS(1984),
    [anon_sym_nointerpolation] = ACTIONS(1984),
    [anon_sym_sample] = ACTIONS(1984),
    [anon_sym_linear] = ACTIONS(1984),
    [anon_sym_snorm] = ACTIONS(1984),
    [anon_sym_unorm] = ACTIONS(1984),
    [anon_sym_point] = ACTIONS(1984),
    [anon_sym_line] = ACTIONS(1984),
    [anon_sym_triangleadj] = ACTIONS(1984),
    [anon_sym_lineadj] = ACTIONS(1984),
    [anon_sym_triangle] = ACTIONS(1984),
    [anon_sym_cbuffer] = ACTIONS(1984),
  },
  [161] = {
    [sym_field_declaration_list] = STATE(419),
    [sym_virtual_specifier] = STATE(6783),
    [sym_base_class_clause] = STATE(7764),
    [sym_identifier] = ACTIONS(1907),
    [aux_sym_preproc_include_token1] = ACTIONS(1907),
    [aux_sym_preproc_def_token1] = ACTIONS(1907),
    [aux_sym_preproc_if_token1] = ACTIONS(1907),
    [aux_sym_preproc_if_token2] = ACTIONS(1907),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1907),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1907),
    [sym_preproc_directive] = ACTIONS(1907),
    [anon_sym_LPAREN2] = ACTIONS(1909),
    [anon_sym_BANG] = ACTIONS(1909),
    [anon_sym_TILDE] = ACTIONS(1909),
    [anon_sym_DASH] = ACTIONS(1907),
    [anon_sym_PLUS] = ACTIONS(1907),
    [anon_sym_STAR] = ACTIONS(1909),
    [anon_sym_AMP_AMP] = ACTIONS(1909),
    [anon_sym_AMP] = ACTIONS(1907),
    [anon_sym_COLON] = ACTIONS(1911),
    [anon_sym_SEMI] = ACTIONS(1909),
    [anon_sym___extension__] = ACTIONS(1907),
    [anon_sym_typedef] = ACTIONS(1907),
    [anon_sym_in] = ACTIONS(1907),
    [anon_sym_out] = ACTIONS(1907),
    [anon_sym_inout] = ACTIONS(1907),
    [anon_sym_extern] = ACTIONS(1907),
    [anon_sym___attribute__] = ACTIONS(1907),
    [anon_sym_COLON_COLON] = ACTIONS(1909),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1909),
    [anon_sym___declspec] = ACTIONS(1907),
    [anon_sym___based] = ACTIONS(1907),
    [anon_sym___cdecl] = ACTIONS(1907),
    [anon_sym___clrcall] = ACTIONS(1907),
    [anon_sym___stdcall] = ACTIONS(1907),
    [anon_sym___fastcall] = ACTIONS(1907),
    [anon_sym___thiscall] = ACTIONS(1907),
    [anon_sym___vectorcall] = ACTIONS(1907),
    [anon_sym_LBRACE] = ACTIONS(1988),
    [anon_sym_signed] = ACTIONS(1907),
    [anon_sym_unsigned] = ACTIONS(1907),
    [anon_sym_long] = ACTIONS(1907),
    [anon_sym_short] = ACTIONS(1907),
    [anon_sym_LBRACK] = ACTIONS(1907),
    [anon_sym_static] = ACTIONS(1907),
    [anon_sym_register] = ACTIONS(1907),
    [anon_sym_inline] = ACTIONS(1907),
    [anon_sym___inline] = ACTIONS(1907),
    [anon_sym___inline__] = ACTIONS(1907),
    [anon_sym___forceinline] = ACTIONS(1907),
    [anon_sym_thread_local] = ACTIONS(1907),
    [anon_sym___thread] = ACTIONS(1907),
    [anon_sym_const] = ACTIONS(1907),
    [anon_sym_constexpr] = ACTIONS(1907),
    [anon_sym_volatile] = ACTIONS(1907),
    [anon_sym_restrict] = ACTIONS(1907),
    [anon_sym___restrict__] = ACTIONS(1907),
    [anon_sym__Atomic] = ACTIONS(1907),
    [anon_sym__Noreturn] = ACTIONS(1907),
    [anon_sym_noreturn] = ACTIONS(1907),
    [anon_sym_mutable] = ACTIONS(1907),
    [anon_sym_constinit] = ACTIONS(1907),
    [anon_sym_consteval] = ACTIONS(1907),
    [anon_sym_alignas] = ACTIONS(1907),
    [anon_sym__Alignas] = ACTIONS(1907),
    [sym_primitive_type] = ACTIONS(1907),
    [anon_sym_enum] = ACTIONS(1907),
    [anon_sym_class] = ACTIONS(1907),
    [anon_sym_struct] = ACTIONS(1907),
    [anon_sym_union] = ACTIONS(1907),
    [anon_sym_if] = ACTIONS(1907),
    [anon_sym_else] = ACTIONS(1907),
    [anon_sym_switch] = ACTIONS(1907),
    [anon_sym_case] = ACTIONS(1907),
    [anon_sym_default] = ACTIONS(1907),
    [anon_sym_while] = ACTIONS(1907),
    [anon_sym_do] = ACTIONS(1907),
    [anon_sym_for] = ACTIONS(1907),
    [anon_sym_return] = ACTIONS(1907),
    [anon_sym_break] = ACTIONS(1907),
    [anon_sym_continue] = ACTIONS(1907),
    [anon_sym_goto] = ACTIONS(1907),
    [anon_sym___try] = ACTIONS(1907),
    [anon_sym___leave] = ACTIONS(1907),
    [anon_sym_not] = ACTIONS(1907),
    [anon_sym_compl] = ACTIONS(1907),
    [anon_sym_DASH_DASH] = ACTIONS(1909),
    [anon_sym_PLUS_PLUS] = ACTIONS(1909),
    [anon_sym_sizeof] = ACTIONS(1907),
    [anon_sym___alignof__] = ACTIONS(1907),
    [anon_sym___alignof] = ACTIONS(1907),
    [anon_sym__alignof] = ACTIONS(1907),
    [anon_sym_alignof] = ACTIONS(1907),
    [anon_sym__Alignof] = ACTIONS(1907),
    [anon_sym_offsetof] = ACTIONS(1907),
    [anon_sym__Generic] = ACTIONS(1907),
    [anon_sym_asm] = ACTIONS(1907),
    [anon_sym___asm__] = ACTIONS(1907),
    [sym_number_literal] = ACTIONS(1909),
    [anon_sym_L_SQUOTE] = ACTIONS(1909),
    [anon_sym_u_SQUOTE] = ACTIONS(1909),
    [anon_sym_U_SQUOTE] = ACTIONS(1909),
    [anon_sym_u8_SQUOTE] = ACTIONS(1909),
    [anon_sym_SQUOTE] = ACTIONS(1909),
    [anon_sym_L_DQUOTE] = ACTIONS(1909),
    [anon_sym_u_DQUOTE] = ACTIONS(1909),
    [anon_sym_U_DQUOTE] = ACTIONS(1909),
    [anon_sym_u8_DQUOTE] = ACTIONS(1909),
    [anon_sym_DQUOTE] = ACTIONS(1909),
    [sym_true] = ACTIONS(1907),
    [sym_false] = ACTIONS(1907),
    [anon_sym_NULL] = ACTIONS(1907),
    [anon_sym_nullptr] = ACTIONS(1907),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1907),
    [anon_sym_decltype] = ACTIONS(1907),
    [anon_sym_final] = ACTIONS(1915),
    [anon_sym_override] = ACTIONS(1915),
    [sym_virtual] = ACTIONS(1907),
    [anon_sym_explicit] = ACTIONS(1907),
    [anon_sym_typename] = ACTIONS(1907),
    [anon_sym_template] = ACTIONS(1907),
    [anon_sym_operator] = ACTIONS(1907),
    [anon_sym_try] = ACTIONS(1907),
    [anon_sym_delete] = ACTIONS(1907),
    [anon_sym_throw] = ACTIONS(1907),
    [anon_sym_namespace] = ACTIONS(1907),
    [anon_sym_using] = ACTIONS(1907),
    [anon_sym_static_assert] = ACTIONS(1907),
    [anon_sym_concept] = ACTIONS(1907),
    [anon_sym_co_return] = ACTIONS(1907),
    [anon_sym_co_yield] = ACTIONS(1907),
    [anon_sym_R_DQUOTE] = ACTIONS(1909),
    [anon_sym_LR_DQUOTE] = ACTIONS(1909),
    [anon_sym_uR_DQUOTE] = ACTIONS(1909),
    [anon_sym_UR_DQUOTE] = ACTIONS(1909),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1909),
    [anon_sym_co_await] = ACTIONS(1907),
    [anon_sym_new] = ACTIONS(1907),
    [anon_sym_requires] = ACTIONS(1907),
    [sym_this] = ACTIONS(1907),
    [anon_sym_discard] = ACTIONS(1907),
    [anon_sym_precise] = ACTIONS(1907),
    [anon_sym_shared] = ACTIONS(1907),
    [anon_sym_groupshared] = ACTIONS(1907),
    [anon_sym_uniform] = ACTIONS(1907),
    [anon_sym_row_major] = ACTIONS(1907),
    [anon_sym_column_major] = ACTIONS(1907),
    [anon_sym_globallycoherent] = ACTIONS(1907),
    [anon_sym_centroid] = ACTIONS(1907),
    [anon_sym_noperspective] = ACTIONS(1907),
    [anon_sym_nointerpolation] = ACTIONS(1907),
    [anon_sym_sample] = ACTIONS(1907),
    [anon_sym_linear] = ACTIONS(1907),
    [anon_sym_snorm] = ACTIONS(1907),
    [anon_sym_unorm] = ACTIONS(1907),
    [anon_sym_point] = ACTIONS(1907),
    [anon_sym_line] = ACTIONS(1907),
    [anon_sym_triangleadj] = ACTIONS(1907),
    [anon_sym_lineadj] = ACTIONS(1907),
    [anon_sym_triangle] = ACTIONS(1907),
    [anon_sym_cbuffer] = ACTIONS(1907),
  },
  [162] = {
    [sym_field_declaration_list] = STATE(427),
    [sym_virtual_specifier] = STATE(6819),
    [sym_base_class_clause] = STATE(7797),
    [sym_identifier] = ACTIONS(1921),
    [aux_sym_preproc_include_token1] = ACTIONS(1921),
    [aux_sym_preproc_def_token1] = ACTIONS(1921),
    [aux_sym_preproc_if_token1] = ACTIONS(1921),
    [aux_sym_preproc_if_token2] = ACTIONS(1921),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1921),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1921),
    [sym_preproc_directive] = ACTIONS(1921),
    [anon_sym_LPAREN2] = ACTIONS(1923),
    [anon_sym_BANG] = ACTIONS(1923),
    [anon_sym_TILDE] = ACTIONS(1923),
    [anon_sym_DASH] = ACTIONS(1921),
    [anon_sym_PLUS] = ACTIONS(1921),
    [anon_sym_STAR] = ACTIONS(1923),
    [anon_sym_AMP_AMP] = ACTIONS(1923),
    [anon_sym_AMP] = ACTIONS(1921),
    [anon_sym_COLON] = ACTIONS(1911),
    [anon_sym_SEMI] = ACTIONS(1923),
    [anon_sym___extension__] = ACTIONS(1921),
    [anon_sym_typedef] = ACTIONS(1921),
    [anon_sym_in] = ACTIONS(1921),
    [anon_sym_out] = ACTIONS(1921),
    [anon_sym_inout] = ACTIONS(1921),
    [anon_sym_extern] = ACTIONS(1921),
    [anon_sym___attribute__] = ACTIONS(1921),
    [anon_sym_COLON_COLON] = ACTIONS(1923),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1923),
    [anon_sym___declspec] = ACTIONS(1921),
    [anon_sym___based] = ACTIONS(1921),
    [anon_sym___cdecl] = ACTIONS(1921),
    [anon_sym___clrcall] = ACTIONS(1921),
    [anon_sym___stdcall] = ACTIONS(1921),
    [anon_sym___fastcall] = ACTIONS(1921),
    [anon_sym___thiscall] = ACTIONS(1921),
    [anon_sym___vectorcall] = ACTIONS(1921),
    [anon_sym_LBRACE] = ACTIONS(1988),
    [anon_sym_signed] = ACTIONS(1921),
    [anon_sym_unsigned] = ACTIONS(1921),
    [anon_sym_long] = ACTIONS(1921),
    [anon_sym_short] = ACTIONS(1921),
    [anon_sym_LBRACK] = ACTIONS(1921),
    [anon_sym_static] = ACTIONS(1921),
    [anon_sym_register] = ACTIONS(1921),
    [anon_sym_inline] = ACTIONS(1921),
    [anon_sym___inline] = ACTIONS(1921),
    [anon_sym___inline__] = ACTIONS(1921),
    [anon_sym___forceinline] = ACTIONS(1921),
    [anon_sym_thread_local] = ACTIONS(1921),
    [anon_sym___thread] = ACTIONS(1921),
    [anon_sym_const] = ACTIONS(1921),
    [anon_sym_constexpr] = ACTIONS(1921),
    [anon_sym_volatile] = ACTIONS(1921),
    [anon_sym_restrict] = ACTIONS(1921),
    [anon_sym___restrict__] = ACTIONS(1921),
    [anon_sym__Atomic] = ACTIONS(1921),
    [anon_sym__Noreturn] = ACTIONS(1921),
    [anon_sym_noreturn] = ACTIONS(1921),
    [anon_sym_mutable] = ACTIONS(1921),
    [anon_sym_constinit] = ACTIONS(1921),
    [anon_sym_consteval] = ACTIONS(1921),
    [anon_sym_alignas] = ACTIONS(1921),
    [anon_sym__Alignas] = ACTIONS(1921),
    [sym_primitive_type] = ACTIONS(1921),
    [anon_sym_enum] = ACTIONS(1921),
    [anon_sym_class] = ACTIONS(1921),
    [anon_sym_struct] = ACTIONS(1921),
    [anon_sym_union] = ACTIONS(1921),
    [anon_sym_if] = ACTIONS(1921),
    [anon_sym_else] = ACTIONS(1921),
    [anon_sym_switch] = ACTIONS(1921),
    [anon_sym_case] = ACTIONS(1921),
    [anon_sym_default] = ACTIONS(1921),
    [anon_sym_while] = ACTIONS(1921),
    [anon_sym_do] = ACTIONS(1921),
    [anon_sym_for] = ACTIONS(1921),
    [anon_sym_return] = ACTIONS(1921),
    [anon_sym_break] = ACTIONS(1921),
    [anon_sym_continue] = ACTIONS(1921),
    [anon_sym_goto] = ACTIONS(1921),
    [anon_sym___try] = ACTIONS(1921),
    [anon_sym___leave] = ACTIONS(1921),
    [anon_sym_not] = ACTIONS(1921),
    [anon_sym_compl] = ACTIONS(1921),
    [anon_sym_DASH_DASH] = ACTIONS(1923),
    [anon_sym_PLUS_PLUS] = ACTIONS(1923),
    [anon_sym_sizeof] = ACTIONS(1921),
    [anon_sym___alignof__] = ACTIONS(1921),
    [anon_sym___alignof] = ACTIONS(1921),
    [anon_sym__alignof] = ACTIONS(1921),
    [anon_sym_alignof] = ACTIONS(1921),
    [anon_sym__Alignof] = ACTIONS(1921),
    [anon_sym_offsetof] = ACTIONS(1921),
    [anon_sym__Generic] = ACTIONS(1921),
    [anon_sym_asm] = ACTIONS(1921),
    [anon_sym___asm__] = ACTIONS(1921),
    [sym_number_literal] = ACTIONS(1923),
    [anon_sym_L_SQUOTE] = ACTIONS(1923),
    [anon_sym_u_SQUOTE] = ACTIONS(1923),
    [anon_sym_U_SQUOTE] = ACTIONS(1923),
    [anon_sym_u8_SQUOTE] = ACTIONS(1923),
    [anon_sym_SQUOTE] = ACTIONS(1923),
    [anon_sym_L_DQUOTE] = ACTIONS(1923),
    [anon_sym_u_DQUOTE] = ACTIONS(1923),
    [anon_sym_U_DQUOTE] = ACTIONS(1923),
    [anon_sym_u8_DQUOTE] = ACTIONS(1923),
    [anon_sym_DQUOTE] = ACTIONS(1923),
    [sym_true] = ACTIONS(1921),
    [sym_false] = ACTIONS(1921),
    [anon_sym_NULL] = ACTIONS(1921),
    [anon_sym_nullptr] = ACTIONS(1921),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1921),
    [anon_sym_decltype] = ACTIONS(1921),
    [anon_sym_final] = ACTIONS(1915),
    [anon_sym_override] = ACTIONS(1915),
    [sym_virtual] = ACTIONS(1921),
    [anon_sym_explicit] = ACTIONS(1921),
    [anon_sym_typename] = ACTIONS(1921),
    [anon_sym_template] = ACTIONS(1921),
    [anon_sym_operator] = ACTIONS(1921),
    [anon_sym_try] = ACTIONS(1921),
    [anon_sym_delete] = ACTIONS(1921),
    [anon_sym_throw] = ACTIONS(1921),
    [anon_sym_namespace] = ACTIONS(1921),
    [anon_sym_using] = ACTIONS(1921),
    [anon_sym_static_assert] = ACTIONS(1921),
    [anon_sym_concept] = ACTIONS(1921),
    [anon_sym_co_return] = ACTIONS(1921),
    [anon_sym_co_yield] = ACTIONS(1921),
    [anon_sym_R_DQUOTE] = ACTIONS(1923),
    [anon_sym_LR_DQUOTE] = ACTIONS(1923),
    [anon_sym_uR_DQUOTE] = ACTIONS(1923),
    [anon_sym_UR_DQUOTE] = ACTIONS(1923),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1923),
    [anon_sym_co_await] = ACTIONS(1921),
    [anon_sym_new] = ACTIONS(1921),
    [anon_sym_requires] = ACTIONS(1921),
    [sym_this] = ACTIONS(1921),
    [anon_sym_discard] = ACTIONS(1921),
    [anon_sym_precise] = ACTIONS(1921),
    [anon_sym_shared] = ACTIONS(1921),
    [anon_sym_groupshared] = ACTIONS(1921),
    [anon_sym_uniform] = ACTIONS(1921),
    [anon_sym_row_major] = ACTIONS(1921),
    [anon_sym_column_major] = ACTIONS(1921),
    [anon_sym_globallycoherent] = ACTIONS(1921),
    [anon_sym_centroid] = ACTIONS(1921),
    [anon_sym_noperspective] = ACTIONS(1921),
    [anon_sym_nointerpolation] = ACTIONS(1921),
    [anon_sym_sample] = ACTIONS(1921),
    [anon_sym_linear] = ACTIONS(1921),
    [anon_sym_snorm] = ACTIONS(1921),
    [anon_sym_unorm] = ACTIONS(1921),
    [anon_sym_point] = ACTIONS(1921),
    [anon_sym_line] = ACTIONS(1921),
    [anon_sym_triangleadj] = ACTIONS(1921),
    [anon_sym_lineadj] = ACTIONS(1921),
    [anon_sym_triangle] = ACTIONS(1921),
    [anon_sym_cbuffer] = ACTIONS(1921),
  },
  [163] = {
    [sym_catch_clause] = STATE(153),
    [aux_sym_constructor_try_statement_repeat1] = STATE(153),
    [sym_identifier] = ACTIONS(1990),
    [aux_sym_preproc_include_token1] = ACTIONS(1990),
    [aux_sym_preproc_def_token1] = ACTIONS(1990),
    [aux_sym_preproc_if_token1] = ACTIONS(1990),
    [aux_sym_preproc_if_token2] = ACTIONS(1990),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1990),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1990),
    [aux_sym_preproc_else_token1] = ACTIONS(1990),
    [aux_sym_preproc_elif_token1] = ACTIONS(1990),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1990),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1990),
    [sym_preproc_directive] = ACTIONS(1990),
    [anon_sym_LPAREN2] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1992),
    [anon_sym_TILDE] = ACTIONS(1992),
    [anon_sym_DASH] = ACTIONS(1990),
    [anon_sym_PLUS] = ACTIONS(1990),
    [anon_sym_STAR] = ACTIONS(1992),
    [anon_sym_AMP_AMP] = ACTIONS(1992),
    [anon_sym_AMP] = ACTIONS(1990),
    [anon_sym_SEMI] = ACTIONS(1992),
    [anon_sym___extension__] = ACTIONS(1990),
    [anon_sym_typedef] = ACTIONS(1990),
    [anon_sym_in] = ACTIONS(1990),
    [anon_sym_out] = ACTIONS(1990),
    [anon_sym_inout] = ACTIONS(1990),
    [anon_sym_extern] = ACTIONS(1990),
    [anon_sym___attribute__] = ACTIONS(1990),
    [anon_sym_COLON_COLON] = ACTIONS(1992),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1992),
    [anon_sym___declspec] = ACTIONS(1990),
    [anon_sym___based] = ACTIONS(1990),
    [anon_sym___cdecl] = ACTIONS(1990),
    [anon_sym___clrcall] = ACTIONS(1990),
    [anon_sym___stdcall] = ACTIONS(1990),
    [anon_sym___fastcall] = ACTIONS(1990),
    [anon_sym___thiscall] = ACTIONS(1990),
    [anon_sym___vectorcall] = ACTIONS(1990),
    [anon_sym_LBRACE] = ACTIONS(1992),
    [anon_sym_signed] = ACTIONS(1990),
    [anon_sym_unsigned] = ACTIONS(1990),
    [anon_sym_long] = ACTIONS(1990),
    [anon_sym_short] = ACTIONS(1990),
    [anon_sym_LBRACK] = ACTIONS(1990),
    [anon_sym_static] = ACTIONS(1990),
    [anon_sym_register] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1990),
    [anon_sym___inline] = ACTIONS(1990),
    [anon_sym___inline__] = ACTIONS(1990),
    [anon_sym___forceinline] = ACTIONS(1990),
    [anon_sym_thread_local] = ACTIONS(1990),
    [anon_sym___thread] = ACTIONS(1990),
    [anon_sym_const] = ACTIONS(1990),
    [anon_sym_constexpr] = ACTIONS(1990),
    [anon_sym_volatile] = ACTIONS(1990),
    [anon_sym_restrict] = ACTIONS(1990),
    [anon_sym___restrict__] = ACTIONS(1990),
    [anon_sym__Atomic] = ACTIONS(1990),
    [anon_sym__Noreturn] = ACTIONS(1990),
    [anon_sym_noreturn] = ACTIONS(1990),
    [anon_sym_mutable] = ACTIONS(1990),
    [anon_sym_constinit] = ACTIONS(1990),
    [anon_sym_consteval] = ACTIONS(1990),
    [anon_sym_alignas] = ACTIONS(1990),
    [anon_sym__Alignas] = ACTIONS(1990),
    [sym_primitive_type] = ACTIONS(1990),
    [anon_sym_enum] = ACTIONS(1990),
    [anon_sym_class] = ACTIONS(1990),
    [anon_sym_struct] = ACTIONS(1990),
    [anon_sym_union] = ACTIONS(1990),
    [anon_sym_if] = ACTIONS(1990),
    [anon_sym_switch] = ACTIONS(1990),
    [anon_sym_case] = ACTIONS(1990),
    [anon_sym_default] = ACTIONS(1990),
    [anon_sym_while] = ACTIONS(1990),
    [anon_sym_do] = ACTIONS(1990),
    [anon_sym_for] = ACTIONS(1990),
    [anon_sym_return] = ACTIONS(1990),
    [anon_sym_break] = ACTIONS(1990),
    [anon_sym_continue] = ACTIONS(1990),
    [anon_sym_goto] = ACTIONS(1990),
    [anon_sym___try] = ACTIONS(1990),
    [anon_sym___leave] = ACTIONS(1990),
    [anon_sym_not] = ACTIONS(1990),
    [anon_sym_compl] = ACTIONS(1990),
    [anon_sym_DASH_DASH] = ACTIONS(1992),
    [anon_sym_PLUS_PLUS] = ACTIONS(1992),
    [anon_sym_sizeof] = ACTIONS(1990),
    [anon_sym___alignof__] = ACTIONS(1990),
    [anon_sym___alignof] = ACTIONS(1990),
    [anon_sym__alignof] = ACTIONS(1990),
    [anon_sym_alignof] = ACTIONS(1990),
    [anon_sym__Alignof] = ACTIONS(1990),
    [anon_sym_offsetof] = ACTIONS(1990),
    [anon_sym__Generic] = ACTIONS(1990),
    [anon_sym_asm] = ACTIONS(1990),
    [anon_sym___asm__] = ACTIONS(1990),
    [sym_number_literal] = ACTIONS(1992),
    [anon_sym_L_SQUOTE] = ACTIONS(1992),
    [anon_sym_u_SQUOTE] = ACTIONS(1992),
    [anon_sym_U_SQUOTE] = ACTIONS(1992),
    [anon_sym_u8_SQUOTE] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1992),
    [anon_sym_L_DQUOTE] = ACTIONS(1992),
    [anon_sym_u_DQUOTE] = ACTIONS(1992),
    [anon_sym_U_DQUOTE] = ACTIONS(1992),
    [anon_sym_u8_DQUOTE] = ACTIONS(1992),
    [anon_sym_DQUOTE] = ACTIONS(1992),
    [sym_true] = ACTIONS(1990),
    [sym_false] = ACTIONS(1990),
    [anon_sym_NULL] = ACTIONS(1990),
    [anon_sym_nullptr] = ACTIONS(1990),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1990),
    [anon_sym_decltype] = ACTIONS(1990),
    [sym_virtual] = ACTIONS(1990),
    [anon_sym_explicit] = ACTIONS(1990),
    [anon_sym_typename] = ACTIONS(1990),
    [anon_sym_template] = ACTIONS(1990),
    [anon_sym_operator] = ACTIONS(1990),
    [anon_sym_try] = ACTIONS(1990),
    [anon_sym_delete] = ACTIONS(1990),
    [anon_sym_throw] = ACTIONS(1990),
    [anon_sym_namespace] = ACTIONS(1990),
    [anon_sym_using] = ACTIONS(1990),
    [anon_sym_static_assert] = ACTIONS(1990),
    [anon_sym_concept] = ACTIONS(1990),
    [anon_sym_co_return] = ACTIONS(1990),
    [anon_sym_co_yield] = ACTIONS(1990),
    [anon_sym_catch] = ACTIONS(1967),
    [anon_sym_R_DQUOTE] = ACTIONS(1992),
    [anon_sym_LR_DQUOTE] = ACTIONS(1992),
    [anon_sym_uR_DQUOTE] = ACTIONS(1992),
    [anon_sym_UR_DQUOTE] = ACTIONS(1992),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1992),
    [anon_sym_co_await] = ACTIONS(1990),
    [anon_sym_new] = ACTIONS(1990),
    [anon_sym_requires] = ACTIONS(1990),
    [sym_this] = ACTIONS(1990),
    [anon_sym_discard] = ACTIONS(1990),
    [anon_sym_precise] = ACTIONS(1990),
    [anon_sym_shared] = ACTIONS(1990),
    [anon_sym_groupshared] = ACTIONS(1990),
    [anon_sym_uniform] = ACTIONS(1990),
    [anon_sym_row_major] = ACTIONS(1990),
    [anon_sym_column_major] = ACTIONS(1990),
    [anon_sym_globallycoherent] = ACTIONS(1990),
    [anon_sym_centroid] = ACTIONS(1990),
    [anon_sym_noperspective] = ACTIONS(1990),
    [anon_sym_nointerpolation] = ACTIONS(1990),
    [anon_sym_sample] = ACTIONS(1990),
    [anon_sym_linear] = ACTIONS(1990),
    [anon_sym_snorm] = ACTIONS(1990),
    [anon_sym_unorm] = ACTIONS(1990),
    [anon_sym_point] = ACTIONS(1990),
    [anon_sym_line] = ACTIONS(1990),
    [anon_sym_triangleadj] = ACTIONS(1990),
    [anon_sym_lineadj] = ACTIONS(1990),
    [anon_sym_triangle] = ACTIONS(1990),
    [anon_sym_cbuffer] = ACTIONS(1990),
  },
  [164] = {
    [sym_else_clause] = STATE(177),
    [sym_identifier] = ACTIONS(1994),
    [aux_sym_preproc_include_token1] = ACTIONS(1994),
    [aux_sym_preproc_def_token1] = ACTIONS(1994),
    [aux_sym_preproc_if_token1] = ACTIONS(1994),
    [aux_sym_preproc_if_token2] = ACTIONS(1994),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1994),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1994),
    [aux_sym_preproc_else_token1] = ACTIONS(1994),
    [aux_sym_preproc_elif_token1] = ACTIONS(1994),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1994),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1994),
    [sym_preproc_directive] = ACTIONS(1994),
    [anon_sym_LPAREN2] = ACTIONS(1996),
    [anon_sym_BANG] = ACTIONS(1996),
    [anon_sym_TILDE] = ACTIONS(1996),
    [anon_sym_DASH] = ACTIONS(1994),
    [anon_sym_PLUS] = ACTIONS(1994),
    [anon_sym_STAR] = ACTIONS(1996),
    [anon_sym_AMP_AMP] = ACTIONS(1996),
    [anon_sym_AMP] = ACTIONS(1994),
    [anon_sym_SEMI] = ACTIONS(1996),
    [anon_sym___extension__] = ACTIONS(1994),
    [anon_sym_typedef] = ACTIONS(1994),
    [anon_sym_in] = ACTIONS(1994),
    [anon_sym_out] = ACTIONS(1994),
    [anon_sym_inout] = ACTIONS(1994),
    [anon_sym_extern] = ACTIONS(1994),
    [anon_sym___attribute__] = ACTIONS(1994),
    [anon_sym_COLON_COLON] = ACTIONS(1996),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1996),
    [anon_sym___declspec] = ACTIONS(1994),
    [anon_sym___based] = ACTIONS(1994),
    [anon_sym___cdecl] = ACTIONS(1994),
    [anon_sym___clrcall] = ACTIONS(1994),
    [anon_sym___stdcall] = ACTIONS(1994),
    [anon_sym___fastcall] = ACTIONS(1994),
    [anon_sym___thiscall] = ACTIONS(1994),
    [anon_sym___vectorcall] = ACTIONS(1994),
    [anon_sym_LBRACE] = ACTIONS(1996),
    [anon_sym_signed] = ACTIONS(1994),
    [anon_sym_unsigned] = ACTIONS(1994),
    [anon_sym_long] = ACTIONS(1994),
    [anon_sym_short] = ACTIONS(1994),
    [anon_sym_LBRACK] = ACTIONS(1994),
    [anon_sym_static] = ACTIONS(1994),
    [anon_sym_register] = ACTIONS(1994),
    [anon_sym_inline] = ACTIONS(1994),
    [anon_sym___inline] = ACTIONS(1994),
    [anon_sym___inline__] = ACTIONS(1994),
    [anon_sym___forceinline] = ACTIONS(1994),
    [anon_sym_thread_local] = ACTIONS(1994),
    [anon_sym___thread] = ACTIONS(1994),
    [anon_sym_const] = ACTIONS(1994),
    [anon_sym_constexpr] = ACTIONS(1994),
    [anon_sym_volatile] = ACTIONS(1994),
    [anon_sym_restrict] = ACTIONS(1994),
    [anon_sym___restrict__] = ACTIONS(1994),
    [anon_sym__Atomic] = ACTIONS(1994),
    [anon_sym__Noreturn] = ACTIONS(1994),
    [anon_sym_noreturn] = ACTIONS(1994),
    [anon_sym_mutable] = ACTIONS(1994),
    [anon_sym_constinit] = ACTIONS(1994),
    [anon_sym_consteval] = ACTIONS(1994),
    [anon_sym_alignas] = ACTIONS(1994),
    [anon_sym__Alignas] = ACTIONS(1994),
    [sym_primitive_type] = ACTIONS(1994),
    [anon_sym_enum] = ACTIONS(1994),
    [anon_sym_class] = ACTIONS(1994),
    [anon_sym_struct] = ACTIONS(1994),
    [anon_sym_union] = ACTIONS(1994),
    [anon_sym_if] = ACTIONS(1994),
    [anon_sym_else] = ACTIONS(1998),
    [anon_sym_switch] = ACTIONS(1994),
    [anon_sym_case] = ACTIONS(1994),
    [anon_sym_default] = ACTIONS(1994),
    [anon_sym_while] = ACTIONS(1994),
    [anon_sym_do] = ACTIONS(1994),
    [anon_sym_for] = ACTIONS(1994),
    [anon_sym_return] = ACTIONS(1994),
    [anon_sym_break] = ACTIONS(1994),
    [anon_sym_continue] = ACTIONS(1994),
    [anon_sym_goto] = ACTIONS(1994),
    [anon_sym___try] = ACTIONS(1994),
    [anon_sym___leave] = ACTIONS(1994),
    [anon_sym_not] = ACTIONS(1994),
    [anon_sym_compl] = ACTIONS(1994),
    [anon_sym_DASH_DASH] = ACTIONS(1996),
    [anon_sym_PLUS_PLUS] = ACTIONS(1996),
    [anon_sym_sizeof] = ACTIONS(1994),
    [anon_sym___alignof__] = ACTIONS(1994),
    [anon_sym___alignof] = ACTIONS(1994),
    [anon_sym__alignof] = ACTIONS(1994),
    [anon_sym_alignof] = ACTIONS(1994),
    [anon_sym__Alignof] = ACTIONS(1994),
    [anon_sym_offsetof] = ACTIONS(1994),
    [anon_sym__Generic] = ACTIONS(1994),
    [anon_sym_asm] = ACTIONS(1994),
    [anon_sym___asm__] = ACTIONS(1994),
    [sym_number_literal] = ACTIONS(1996),
    [anon_sym_L_SQUOTE] = ACTIONS(1996),
    [anon_sym_u_SQUOTE] = ACTIONS(1996),
    [anon_sym_U_SQUOTE] = ACTIONS(1996),
    [anon_sym_u8_SQUOTE] = ACTIONS(1996),
    [anon_sym_SQUOTE] = ACTIONS(1996),
    [anon_sym_L_DQUOTE] = ACTIONS(1996),
    [anon_sym_u_DQUOTE] = ACTIONS(1996),
    [anon_sym_U_DQUOTE] = ACTIONS(1996),
    [anon_sym_u8_DQUOTE] = ACTIONS(1996),
    [anon_sym_DQUOTE] = ACTIONS(1996),
    [sym_true] = ACTIONS(1994),
    [sym_false] = ACTIONS(1994),
    [anon_sym_NULL] = ACTIONS(1994),
    [anon_sym_nullptr] = ACTIONS(1994),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1994),
    [anon_sym_decltype] = ACTIONS(1994),
    [sym_virtual] = ACTIONS(1994),
    [anon_sym_explicit] = ACTIONS(1994),
    [anon_sym_typename] = ACTIONS(1994),
    [anon_sym_template] = ACTIONS(1994),
    [anon_sym_operator] = ACTIONS(1994),
    [anon_sym_try] = ACTIONS(1994),
    [anon_sym_delete] = ACTIONS(1994),
    [anon_sym_throw] = ACTIONS(1994),
    [anon_sym_namespace] = ACTIONS(1994),
    [anon_sym_using] = ACTIONS(1994),
    [anon_sym_static_assert] = ACTIONS(1994),
    [anon_sym_concept] = ACTIONS(1994),
    [anon_sym_co_return] = ACTIONS(1994),
    [anon_sym_co_yield] = ACTIONS(1994),
    [anon_sym_R_DQUOTE] = ACTIONS(1996),
    [anon_sym_LR_DQUOTE] = ACTIONS(1996),
    [anon_sym_uR_DQUOTE] = ACTIONS(1996),
    [anon_sym_UR_DQUOTE] = ACTIONS(1996),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1996),
    [anon_sym_co_await] = ACTIONS(1994),
    [anon_sym_new] = ACTIONS(1994),
    [anon_sym_requires] = ACTIONS(1994),
    [sym_this] = ACTIONS(1994),
    [anon_sym_discard] = ACTIONS(1994),
    [anon_sym_precise] = ACTIONS(1994),
    [anon_sym_shared] = ACTIONS(1994),
    [anon_sym_groupshared] = ACTIONS(1994),
    [anon_sym_uniform] = ACTIONS(1994),
    [anon_sym_row_major] = ACTIONS(1994),
    [anon_sym_column_major] = ACTIONS(1994),
    [anon_sym_globallycoherent] = ACTIONS(1994),
    [anon_sym_centroid] = ACTIONS(1994),
    [anon_sym_noperspective] = ACTIONS(1994),
    [anon_sym_nointerpolation] = ACTIONS(1994),
    [anon_sym_sample] = ACTIONS(1994),
    [anon_sym_linear] = ACTIONS(1994),
    [anon_sym_snorm] = ACTIONS(1994),
    [anon_sym_unorm] = ACTIONS(1994),
    [anon_sym_point] = ACTIONS(1994),
    [anon_sym_line] = ACTIONS(1994),
    [anon_sym_triangleadj] = ACTIONS(1994),
    [anon_sym_lineadj] = ACTIONS(1994),
    [anon_sym_triangle] = ACTIONS(1994),
    [anon_sym_cbuffer] = ACTIONS(1994),
  },
  [165] = {
    [sym_identifier] = ACTIONS(1931),
    [aux_sym_preproc_include_token1] = ACTIONS(1931),
    [aux_sym_preproc_def_token1] = ACTIONS(1931),
    [aux_sym_preproc_if_token1] = ACTIONS(1931),
    [aux_sym_preproc_if_token2] = ACTIONS(1931),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1931),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1931),
    [aux_sym_preproc_else_token1] = ACTIONS(1931),
    [aux_sym_preproc_elif_token1] = ACTIONS(1931),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1931),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1931),
    [sym_preproc_directive] = ACTIONS(1931),
    [anon_sym_LPAREN2] = ACTIONS(1929),
    [anon_sym_BANG] = ACTIONS(1929),
    [anon_sym_TILDE] = ACTIONS(1929),
    [anon_sym_DASH] = ACTIONS(1931),
    [anon_sym_PLUS] = ACTIONS(1931),
    [anon_sym_STAR] = ACTIONS(1929),
    [anon_sym_AMP_AMP] = ACTIONS(1929),
    [anon_sym_AMP] = ACTIONS(1931),
    [anon_sym_SEMI] = ACTIONS(1929),
    [anon_sym___extension__] = ACTIONS(1931),
    [anon_sym_typedef] = ACTIONS(1931),
    [anon_sym_in] = ACTIONS(1931),
    [anon_sym_out] = ACTIONS(1931),
    [anon_sym_inout] = ACTIONS(1931),
    [anon_sym_extern] = ACTIONS(1931),
    [anon_sym___attribute__] = ACTIONS(1931),
    [anon_sym_COLON_COLON] = ACTIONS(1929),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1929),
    [anon_sym___declspec] = ACTIONS(1931),
    [anon_sym___based] = ACTIONS(1931),
    [anon_sym___cdecl] = ACTIONS(1931),
    [anon_sym___clrcall] = ACTIONS(1931),
    [anon_sym___stdcall] = ACTIONS(1931),
    [anon_sym___fastcall] = ACTIONS(1931),
    [anon_sym___thiscall] = ACTIONS(1931),
    [anon_sym___vectorcall] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1929),
    [anon_sym_signed] = ACTIONS(1931),
    [anon_sym_unsigned] = ACTIONS(1931),
    [anon_sym_long] = ACTIONS(1931),
    [anon_sym_short] = ACTIONS(1931),
    [anon_sym_LBRACK] = ACTIONS(1931),
    [anon_sym_static] = ACTIONS(1931),
    [anon_sym_register] = ACTIONS(1931),
    [anon_sym_inline] = ACTIONS(1931),
    [anon_sym___inline] = ACTIONS(1931),
    [anon_sym___inline__] = ACTIONS(1931),
    [anon_sym___forceinline] = ACTIONS(1931),
    [anon_sym_thread_local] = ACTIONS(1931),
    [anon_sym___thread] = ACTIONS(1931),
    [anon_sym_const] = ACTIONS(1931),
    [anon_sym_constexpr] = ACTIONS(1931),
    [anon_sym_volatile] = ACTIONS(1931),
    [anon_sym_restrict] = ACTIONS(1931),
    [anon_sym___restrict__] = ACTIONS(1931),
    [anon_sym__Atomic] = ACTIONS(1931),
    [anon_sym__Noreturn] = ACTIONS(1931),
    [anon_sym_noreturn] = ACTIONS(1931),
    [anon_sym_mutable] = ACTIONS(1931),
    [anon_sym_constinit] = ACTIONS(1931),
    [anon_sym_consteval] = ACTIONS(1931),
    [anon_sym_alignas] = ACTIONS(1931),
    [anon_sym__Alignas] = ACTIONS(1931),
    [sym_primitive_type] = ACTIONS(1931),
    [anon_sym_enum] = ACTIONS(1931),
    [anon_sym_class] = ACTIONS(1931),
    [anon_sym_struct] = ACTIONS(1931),
    [anon_sym_union] = ACTIONS(1931),
    [anon_sym_if] = ACTIONS(1931),
    [anon_sym_else] = ACTIONS(1931),
    [anon_sym_switch] = ACTIONS(1931),
    [anon_sym_case] = ACTIONS(1931),
    [anon_sym_default] = ACTIONS(1931),
    [anon_sym_while] = ACTIONS(1931),
    [anon_sym_do] = ACTIONS(1931),
    [anon_sym_for] = ACTIONS(1931),
    [anon_sym_return] = ACTIONS(1931),
    [anon_sym_break] = ACTIONS(1931),
    [anon_sym_continue] = ACTIONS(1931),
    [anon_sym_goto] = ACTIONS(1931),
    [anon_sym___try] = ACTIONS(1931),
    [anon_sym___leave] = ACTIONS(1931),
    [anon_sym_not] = ACTIONS(1931),
    [anon_sym_compl] = ACTIONS(1931),
    [anon_sym_DASH_DASH] = ACTIONS(1929),
    [anon_sym_PLUS_PLUS] = ACTIONS(1929),
    [anon_sym_sizeof] = ACTIONS(1931),
    [anon_sym___alignof__] = ACTIONS(1931),
    [anon_sym___alignof] = ACTIONS(1931),
    [anon_sym__alignof] = ACTIONS(1931),
    [anon_sym_alignof] = ACTIONS(1931),
    [anon_sym__Alignof] = ACTIONS(1931),
    [anon_sym_offsetof] = ACTIONS(1931),
    [anon_sym__Generic] = ACTIONS(1931),
    [anon_sym_asm] = ACTIONS(1931),
    [anon_sym___asm__] = ACTIONS(1931),
    [sym_number_literal] = ACTIONS(1929),
    [anon_sym_L_SQUOTE] = ACTIONS(1929),
    [anon_sym_u_SQUOTE] = ACTIONS(1929),
    [anon_sym_U_SQUOTE] = ACTIONS(1929),
    [anon_sym_u8_SQUOTE] = ACTIONS(1929),
    [anon_sym_SQUOTE] = ACTIONS(1929),
    [anon_sym_L_DQUOTE] = ACTIONS(1929),
    [anon_sym_u_DQUOTE] = ACTIONS(1929),
    [anon_sym_U_DQUOTE] = ACTIONS(1929),
    [anon_sym_u8_DQUOTE] = ACTIONS(1929),
    [anon_sym_DQUOTE] = ACTIONS(1929),
    [sym_true] = ACTIONS(1931),
    [sym_false] = ACTIONS(1931),
    [anon_sym_NULL] = ACTIONS(1931),
    [anon_sym_nullptr] = ACTIONS(1931),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1931),
    [anon_sym_decltype] = ACTIONS(1931),
    [sym_virtual] = ACTIONS(1931),
    [anon_sym_explicit] = ACTIONS(1931),
    [anon_sym_typename] = ACTIONS(1931),
    [anon_sym_template] = ACTIONS(1931),
    [anon_sym_operator] = ACTIONS(1931),
    [anon_sym_try] = ACTIONS(1931),
    [anon_sym_delete] = ACTIONS(1931),
    [anon_sym_throw] = ACTIONS(1931),
    [anon_sym_namespace] = ACTIONS(1931),
    [anon_sym_using] = ACTIONS(1931),
    [anon_sym_static_assert] = ACTIONS(1931),
    [anon_sym_concept] = ACTIONS(1931),
    [anon_sym_co_return] = ACTIONS(1931),
    [anon_sym_co_yield] = ACTIONS(1931),
    [anon_sym_catch] = ACTIONS(1931),
    [anon_sym_R_DQUOTE] = ACTIONS(1929),
    [anon_sym_LR_DQUOTE] = ACTIONS(1929),
    [anon_sym_uR_DQUOTE] = ACTIONS(1929),
    [anon_sym_UR_DQUOTE] = ACTIONS(1929),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1929),
    [anon_sym_co_await] = ACTIONS(1931),
    [anon_sym_new] = ACTIONS(1931),
    [anon_sym_requires] = ACTIONS(1931),
    [sym_this] = ACTIONS(1931),
    [anon_sym_discard] = ACTIONS(1931),
    [anon_sym_precise] = ACTIONS(1931),
    [anon_sym_shared] = ACTIONS(1931),
    [anon_sym_groupshared] = ACTIONS(1931),
    [anon_sym_uniform] = ACTIONS(1931),
    [anon_sym_row_major] = ACTIONS(1931),
    [anon_sym_column_major] = ACTIONS(1931),
    [anon_sym_globallycoherent] = ACTIONS(1931),
    [anon_sym_centroid] = ACTIONS(1931),
    [anon_sym_noperspective] = ACTIONS(1931),
    [anon_sym_nointerpolation] = ACTIONS(1931),
    [anon_sym_sample] = ACTIONS(1931),
    [anon_sym_linear] = ACTIONS(1931),
    [anon_sym_snorm] = ACTIONS(1931),
    [anon_sym_unorm] = ACTIONS(1931),
    [anon_sym_point] = ACTIONS(1931),
    [anon_sym_line] = ACTIONS(1931),
    [anon_sym_triangleadj] = ACTIONS(1931),
    [anon_sym_lineadj] = ACTIONS(1931),
    [anon_sym_triangle] = ACTIONS(1931),
    [anon_sym_cbuffer] = ACTIONS(1931),
  },
  [166] = {
    [sym_identifier] = ACTIONS(1947),
    [aux_sym_preproc_include_token1] = ACTIONS(1947),
    [aux_sym_preproc_def_token1] = ACTIONS(1947),
    [aux_sym_preproc_if_token1] = ACTIONS(1947),
    [aux_sym_preproc_if_token2] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1947),
    [aux_sym_preproc_else_token1] = ACTIONS(1947),
    [aux_sym_preproc_elif_token1] = ACTIONS(1947),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1947),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1947),
    [sym_preproc_directive] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1945),
    [anon_sym_BANG] = ACTIONS(1945),
    [anon_sym_TILDE] = ACTIONS(1945),
    [anon_sym_DASH] = ACTIONS(1947),
    [anon_sym_PLUS] = ACTIONS(1947),
    [anon_sym_STAR] = ACTIONS(1945),
    [anon_sym_AMP_AMP] = ACTIONS(1945),
    [anon_sym_AMP] = ACTIONS(1947),
    [anon_sym_SEMI] = ACTIONS(1945),
    [anon_sym___extension__] = ACTIONS(1947),
    [anon_sym_typedef] = ACTIONS(1947),
    [anon_sym_in] = ACTIONS(1947),
    [anon_sym_out] = ACTIONS(1947),
    [anon_sym_inout] = ACTIONS(1947),
    [anon_sym_extern] = ACTIONS(1947),
    [anon_sym___attribute__] = ACTIONS(1947),
    [anon_sym_COLON_COLON] = ACTIONS(1945),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1945),
    [anon_sym___declspec] = ACTIONS(1947),
    [anon_sym___based] = ACTIONS(1947),
    [anon_sym___cdecl] = ACTIONS(1947),
    [anon_sym___clrcall] = ACTIONS(1947),
    [anon_sym___stdcall] = ACTIONS(1947),
    [anon_sym___fastcall] = ACTIONS(1947),
    [anon_sym___thiscall] = ACTIONS(1947),
    [anon_sym___vectorcall] = ACTIONS(1947),
    [anon_sym_LBRACE] = ACTIONS(1945),
    [anon_sym_signed] = ACTIONS(1947),
    [anon_sym_unsigned] = ACTIONS(1947),
    [anon_sym_long] = ACTIONS(1947),
    [anon_sym_short] = ACTIONS(1947),
    [anon_sym_LBRACK] = ACTIONS(1947),
    [anon_sym_static] = ACTIONS(1947),
    [anon_sym_register] = ACTIONS(1947),
    [anon_sym_inline] = ACTIONS(1947),
    [anon_sym___inline] = ACTIONS(1947),
    [anon_sym___inline__] = ACTIONS(1947),
    [anon_sym___forceinline] = ACTIONS(1947),
    [anon_sym_thread_local] = ACTIONS(1947),
    [anon_sym___thread] = ACTIONS(1947),
    [anon_sym_const] = ACTIONS(1947),
    [anon_sym_constexpr] = ACTIONS(1947),
    [anon_sym_volatile] = ACTIONS(1947),
    [anon_sym_restrict] = ACTIONS(1947),
    [anon_sym___restrict__] = ACTIONS(1947),
    [anon_sym__Atomic] = ACTIONS(1947),
    [anon_sym__Noreturn] = ACTIONS(1947),
    [anon_sym_noreturn] = ACTIONS(1947),
    [anon_sym_mutable] = ACTIONS(1947),
    [anon_sym_constinit] = ACTIONS(1947),
    [anon_sym_consteval] = ACTIONS(1947),
    [anon_sym_alignas] = ACTIONS(1947),
    [anon_sym__Alignas] = ACTIONS(1947),
    [sym_primitive_type] = ACTIONS(1947),
    [anon_sym_enum] = ACTIONS(1947),
    [anon_sym_class] = ACTIONS(1947),
    [anon_sym_struct] = ACTIONS(1947),
    [anon_sym_union] = ACTIONS(1947),
    [anon_sym_if] = ACTIONS(1947),
    [anon_sym_else] = ACTIONS(1947),
    [anon_sym_switch] = ACTIONS(1947),
    [anon_sym_case] = ACTIONS(1947),
    [anon_sym_default] = ACTIONS(1947),
    [anon_sym_while] = ACTIONS(1947),
    [anon_sym_do] = ACTIONS(1947),
    [anon_sym_for] = ACTIONS(1947),
    [anon_sym_return] = ACTIONS(1947),
    [anon_sym_break] = ACTIONS(1947),
    [anon_sym_continue] = ACTIONS(1947),
    [anon_sym_goto] = ACTIONS(1947),
    [anon_sym___try] = ACTIONS(1947),
    [anon_sym___leave] = ACTIONS(1947),
    [anon_sym_not] = ACTIONS(1947),
    [anon_sym_compl] = ACTIONS(1947),
    [anon_sym_DASH_DASH] = ACTIONS(1945),
    [anon_sym_PLUS_PLUS] = ACTIONS(1945),
    [anon_sym_sizeof] = ACTIONS(1947),
    [anon_sym___alignof__] = ACTIONS(1947),
    [anon_sym___alignof] = ACTIONS(1947),
    [anon_sym__alignof] = ACTIONS(1947),
    [anon_sym_alignof] = ACTIONS(1947),
    [anon_sym__Alignof] = ACTIONS(1947),
    [anon_sym_offsetof] = ACTIONS(1947),
    [anon_sym__Generic] = ACTIONS(1947),
    [anon_sym_asm] = ACTIONS(1947),
    [anon_sym___asm__] = ACTIONS(1947),
    [sym_number_literal] = ACTIONS(1945),
    [anon_sym_L_SQUOTE] = ACTIONS(1945),
    [anon_sym_u_SQUOTE] = ACTIONS(1945),
    [anon_sym_U_SQUOTE] = ACTIONS(1945),
    [anon_sym_u8_SQUOTE] = ACTIONS(1945),
    [anon_sym_SQUOTE] = ACTIONS(1945),
    [anon_sym_L_DQUOTE] = ACTIONS(1945),
    [anon_sym_u_DQUOTE] = ACTIONS(1945),
    [anon_sym_U_DQUOTE] = ACTIONS(1945),
    [anon_sym_u8_DQUOTE] = ACTIONS(1945),
    [anon_sym_DQUOTE] = ACTIONS(1945),
    [sym_true] = ACTIONS(1947),
    [sym_false] = ACTIONS(1947),
    [anon_sym_NULL] = ACTIONS(1947),
    [anon_sym_nullptr] = ACTIONS(1947),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1947),
    [anon_sym_decltype] = ACTIONS(1947),
    [sym_virtual] = ACTIONS(1947),
    [anon_sym_explicit] = ACTIONS(1947),
    [anon_sym_typename] = ACTIONS(1947),
    [anon_sym_template] = ACTIONS(1947),
    [anon_sym_operator] = ACTIONS(1947),
    [anon_sym_try] = ACTIONS(1947),
    [anon_sym_delete] = ACTIONS(1947),
    [anon_sym_throw] = ACTIONS(1947),
    [anon_sym_namespace] = ACTIONS(1947),
    [anon_sym_using] = ACTIONS(1947),
    [anon_sym_static_assert] = ACTIONS(1947),
    [anon_sym_concept] = ACTIONS(1947),
    [anon_sym_co_return] = ACTIONS(1947),
    [anon_sym_co_yield] = ACTIONS(1947),
    [anon_sym_catch] = ACTIONS(1947),
    [anon_sym_R_DQUOTE] = ACTIONS(1945),
    [anon_sym_LR_DQUOTE] = ACTIONS(1945),
    [anon_sym_uR_DQUOTE] = ACTIONS(1945),
    [anon_sym_UR_DQUOTE] = ACTIONS(1945),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1945),
    [anon_sym_co_await] = ACTIONS(1947),
    [anon_sym_new] = ACTIONS(1947),
    [anon_sym_requires] = ACTIONS(1947),
    [sym_this] = ACTIONS(1947),
    [anon_sym_discard] = ACTIONS(1947),
    [anon_sym_precise] = ACTIONS(1947),
    [anon_sym_shared] = ACTIONS(1947),
    [anon_sym_groupshared] = ACTIONS(1947),
    [anon_sym_uniform] = ACTIONS(1947),
    [anon_sym_row_major] = ACTIONS(1947),
    [anon_sym_column_major] = ACTIONS(1947),
    [anon_sym_globallycoherent] = ACTIONS(1947),
    [anon_sym_centroid] = ACTIONS(1947),
    [anon_sym_noperspective] = ACTIONS(1947),
    [anon_sym_nointerpolation] = ACTIONS(1947),
    [anon_sym_sample] = ACTIONS(1947),
    [anon_sym_linear] = ACTIONS(1947),
    [anon_sym_snorm] = ACTIONS(1947),
    [anon_sym_unorm] = ACTIONS(1947),
    [anon_sym_point] = ACTIONS(1947),
    [anon_sym_line] = ACTIONS(1947),
    [anon_sym_triangleadj] = ACTIONS(1947),
    [anon_sym_lineadj] = ACTIONS(1947),
    [anon_sym_triangle] = ACTIONS(1947),
    [anon_sym_cbuffer] = ACTIONS(1947),
  },
  [167] = {
    [sym_template_argument_list] = STATE(337),
    [sym_identifier] = ACTIONS(1933),
    [aux_sym_preproc_include_token1] = ACTIONS(1933),
    [aux_sym_preproc_def_token1] = ACTIONS(1933),
    [aux_sym_preproc_if_token1] = ACTIONS(1933),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1933),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1933),
    [sym_preproc_directive] = ACTIONS(1933),
    [anon_sym_LPAREN2] = ACTIONS(1935),
    [anon_sym_BANG] = ACTIONS(1935),
    [anon_sym_TILDE] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1933),
    [anon_sym_PLUS] = ACTIONS(1933),
    [anon_sym_STAR] = ACTIONS(1935),
    [anon_sym_AMP_AMP] = ACTIONS(1935),
    [anon_sym_AMP] = ACTIONS(1933),
    [anon_sym_LT] = ACTIONS(2000),
    [anon_sym_COLON] = ACTIONS(1933),
    [anon_sym_SEMI] = ACTIONS(1935),
    [anon_sym___extension__] = ACTIONS(1933),
    [anon_sym_typedef] = ACTIONS(1933),
    [anon_sym_in] = ACTIONS(1933),
    [anon_sym_out] = ACTIONS(1933),
    [anon_sym_inout] = ACTIONS(1933),
    [anon_sym_extern] = ACTIONS(1933),
    [anon_sym___attribute__] = ACTIONS(1933),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1935),
    [anon_sym___declspec] = ACTIONS(1933),
    [anon_sym___based] = ACTIONS(1933),
    [anon_sym___cdecl] = ACTIONS(1933),
    [anon_sym___clrcall] = ACTIONS(1933),
    [anon_sym___stdcall] = ACTIONS(1933),
    [anon_sym___fastcall] = ACTIONS(1933),
    [anon_sym___thiscall] = ACTIONS(1933),
    [anon_sym___vectorcall] = ACTIONS(1933),
    [anon_sym_LBRACE] = ACTIONS(1935),
    [anon_sym_RBRACE] = ACTIONS(1935),
    [anon_sym_signed] = ACTIONS(1933),
    [anon_sym_unsigned] = ACTIONS(1933),
    [anon_sym_long] = ACTIONS(1933),
    [anon_sym_short] = ACTIONS(1933),
    [anon_sym_LBRACK] = ACTIONS(1933),
    [anon_sym_static] = ACTIONS(1933),
    [anon_sym_register] = ACTIONS(1933),
    [anon_sym_inline] = ACTIONS(1933),
    [anon_sym___inline] = ACTIONS(1933),
    [anon_sym___inline__] = ACTIONS(1933),
    [anon_sym___forceinline] = ACTIONS(1933),
    [anon_sym_thread_local] = ACTIONS(1933),
    [anon_sym___thread] = ACTIONS(1933),
    [anon_sym_const] = ACTIONS(1933),
    [anon_sym_constexpr] = ACTIONS(1933),
    [anon_sym_volatile] = ACTIONS(1933),
    [anon_sym_restrict] = ACTIONS(1933),
    [anon_sym___restrict__] = ACTIONS(1933),
    [anon_sym__Atomic] = ACTIONS(1933),
    [anon_sym__Noreturn] = ACTIONS(1933),
    [anon_sym_noreturn] = ACTIONS(1933),
    [anon_sym_mutable] = ACTIONS(1933),
    [anon_sym_constinit] = ACTIONS(1933),
    [anon_sym_consteval] = ACTIONS(1933),
    [anon_sym_alignas] = ACTIONS(1933),
    [anon_sym__Alignas] = ACTIONS(1933),
    [sym_primitive_type] = ACTIONS(1933),
    [anon_sym_enum] = ACTIONS(1933),
    [anon_sym_class] = ACTIONS(1933),
    [anon_sym_struct] = ACTIONS(1933),
    [anon_sym_union] = ACTIONS(1933),
    [anon_sym_if] = ACTIONS(1933),
    [anon_sym_else] = ACTIONS(1933),
    [anon_sym_switch] = ACTIONS(1933),
    [anon_sym_case] = ACTIONS(1933),
    [anon_sym_default] = ACTIONS(1933),
    [anon_sym_while] = ACTIONS(1933),
    [anon_sym_do] = ACTIONS(1933),
    [anon_sym_for] = ACTIONS(1933),
    [anon_sym_return] = ACTIONS(1933),
    [anon_sym_break] = ACTIONS(1933),
    [anon_sym_continue] = ACTIONS(1933),
    [anon_sym_goto] = ACTIONS(1933),
    [anon_sym___try] = ACTIONS(1933),
    [anon_sym___leave] = ACTIONS(1933),
    [anon_sym_not] = ACTIONS(1933),
    [anon_sym_compl] = ACTIONS(1933),
    [anon_sym_DASH_DASH] = ACTIONS(1935),
    [anon_sym_PLUS_PLUS] = ACTIONS(1935),
    [anon_sym_sizeof] = ACTIONS(1933),
    [anon_sym___alignof__] = ACTIONS(1933),
    [anon_sym___alignof] = ACTIONS(1933),
    [anon_sym__alignof] = ACTIONS(1933),
    [anon_sym_alignof] = ACTIONS(1933),
    [anon_sym__Alignof] = ACTIONS(1933),
    [anon_sym_offsetof] = ACTIONS(1933),
    [anon_sym__Generic] = ACTIONS(1933),
    [anon_sym_asm] = ACTIONS(1933),
    [anon_sym___asm__] = ACTIONS(1933),
    [sym_number_literal] = ACTIONS(1935),
    [anon_sym_L_SQUOTE] = ACTIONS(1935),
    [anon_sym_u_SQUOTE] = ACTIONS(1935),
    [anon_sym_U_SQUOTE] = ACTIONS(1935),
    [anon_sym_u8_SQUOTE] = ACTIONS(1935),
    [anon_sym_SQUOTE] = ACTIONS(1935),
    [anon_sym_L_DQUOTE] = ACTIONS(1935),
    [anon_sym_u_DQUOTE] = ACTIONS(1935),
    [anon_sym_U_DQUOTE] = ACTIONS(1935),
    [anon_sym_u8_DQUOTE] = ACTIONS(1935),
    [anon_sym_DQUOTE] = ACTIONS(1935),
    [sym_true] = ACTIONS(1933),
    [sym_false] = ACTIONS(1933),
    [anon_sym_NULL] = ACTIONS(1933),
    [anon_sym_nullptr] = ACTIONS(1933),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1933),
    [anon_sym_decltype] = ACTIONS(1933),
    [anon_sym_final] = ACTIONS(1933),
    [anon_sym_override] = ACTIONS(1933),
    [sym_virtual] = ACTIONS(1933),
    [anon_sym_explicit] = ACTIONS(1933),
    [anon_sym_typename] = ACTIONS(1933),
    [anon_sym_template] = ACTIONS(1933),
    [anon_sym_operator] = ACTIONS(1933),
    [anon_sym_try] = ACTIONS(1933),
    [anon_sym_delete] = ACTIONS(1933),
    [anon_sym_throw] = ACTIONS(1933),
    [anon_sym_namespace] = ACTIONS(1933),
    [anon_sym_using] = ACTIONS(1933),
    [anon_sym_static_assert] = ACTIONS(1933),
    [anon_sym_concept] = ACTIONS(1933),
    [anon_sym_co_return] = ACTIONS(1933),
    [anon_sym_co_yield] = ACTIONS(1933),
    [anon_sym_R_DQUOTE] = ACTIONS(1935),
    [anon_sym_LR_DQUOTE] = ACTIONS(1935),
    [anon_sym_uR_DQUOTE] = ACTIONS(1935),
    [anon_sym_UR_DQUOTE] = ACTIONS(1935),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1935),
    [anon_sym_co_await] = ACTIONS(1933),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_requires] = ACTIONS(1933),
    [sym_this] = ACTIONS(1933),
    [anon_sym_discard] = ACTIONS(1933),
    [anon_sym_precise] = ACTIONS(1933),
    [anon_sym_shared] = ACTIONS(1933),
    [anon_sym_groupshared] = ACTIONS(1933),
    [anon_sym_uniform] = ACTIONS(1933),
    [anon_sym_row_major] = ACTIONS(1933),
    [anon_sym_column_major] = ACTIONS(1933),
    [anon_sym_globallycoherent] = ACTIONS(1933),
    [anon_sym_centroid] = ACTIONS(1933),
    [anon_sym_noperspective] = ACTIONS(1933),
    [anon_sym_nointerpolation] = ACTIONS(1933),
    [anon_sym_sample] = ACTIONS(1933),
    [anon_sym_linear] = ACTIONS(1933),
    [anon_sym_snorm] = ACTIONS(1933),
    [anon_sym_unorm] = ACTIONS(1933),
    [anon_sym_point] = ACTIONS(1933),
    [anon_sym_line] = ACTIONS(1933),
    [anon_sym_triangleadj] = ACTIONS(1933),
    [anon_sym_lineadj] = ACTIONS(1933),
    [anon_sym_triangle] = ACTIONS(1933),
    [anon_sym_cbuffer] = ACTIONS(1933),
  },
  [168] = {
    [sym_template_argument_list] = STATE(337),
    [sym_identifier] = ACTIONS(1941),
    [aux_sym_preproc_include_token1] = ACTIONS(1941),
    [aux_sym_preproc_def_token1] = ACTIONS(1941),
    [aux_sym_preproc_if_token1] = ACTIONS(1941),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1941),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1941),
    [sym_preproc_directive] = ACTIONS(1941),
    [anon_sym_LPAREN2] = ACTIONS(1943),
    [anon_sym_BANG] = ACTIONS(1943),
    [anon_sym_TILDE] = ACTIONS(1943),
    [anon_sym_DASH] = ACTIONS(1941),
    [anon_sym_PLUS] = ACTIONS(1941),
    [anon_sym_STAR] = ACTIONS(1943),
    [anon_sym_AMP_AMP] = ACTIONS(1943),
    [anon_sym_AMP] = ACTIONS(1941),
    [anon_sym_LT] = ACTIONS(2000),
    [anon_sym_COLON] = ACTIONS(1941),
    [anon_sym_SEMI] = ACTIONS(1943),
    [anon_sym___extension__] = ACTIONS(1941),
    [anon_sym_typedef] = ACTIONS(1941),
    [anon_sym_in] = ACTIONS(1941),
    [anon_sym_out] = ACTIONS(1941),
    [anon_sym_inout] = ACTIONS(1941),
    [anon_sym_extern] = ACTIONS(1941),
    [anon_sym___attribute__] = ACTIONS(1941),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1943),
    [anon_sym___declspec] = ACTIONS(1941),
    [anon_sym___based] = ACTIONS(1941),
    [anon_sym___cdecl] = ACTIONS(1941),
    [anon_sym___clrcall] = ACTIONS(1941),
    [anon_sym___stdcall] = ACTIONS(1941),
    [anon_sym___fastcall] = ACTIONS(1941),
    [anon_sym___thiscall] = ACTIONS(1941),
    [anon_sym___vectorcall] = ACTIONS(1941),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_RBRACE] = ACTIONS(1943),
    [anon_sym_signed] = ACTIONS(1941),
    [anon_sym_unsigned] = ACTIONS(1941),
    [anon_sym_long] = ACTIONS(1941),
    [anon_sym_short] = ACTIONS(1941),
    [anon_sym_LBRACK] = ACTIONS(1941),
    [anon_sym_static] = ACTIONS(1941),
    [anon_sym_register] = ACTIONS(1941),
    [anon_sym_inline] = ACTIONS(1941),
    [anon_sym___inline] = ACTIONS(1941),
    [anon_sym___inline__] = ACTIONS(1941),
    [anon_sym___forceinline] = ACTIONS(1941),
    [anon_sym_thread_local] = ACTIONS(1941),
    [anon_sym___thread] = ACTIONS(1941),
    [anon_sym_const] = ACTIONS(1941),
    [anon_sym_constexpr] = ACTIONS(1941),
    [anon_sym_volatile] = ACTIONS(1941),
    [anon_sym_restrict] = ACTIONS(1941),
    [anon_sym___restrict__] = ACTIONS(1941),
    [anon_sym__Atomic] = ACTIONS(1941),
    [anon_sym__Noreturn] = ACTIONS(1941),
    [anon_sym_noreturn] = ACTIONS(1941),
    [anon_sym_mutable] = ACTIONS(1941),
    [anon_sym_constinit] = ACTIONS(1941),
    [anon_sym_consteval] = ACTIONS(1941),
    [anon_sym_alignas] = ACTIONS(1941),
    [anon_sym__Alignas] = ACTIONS(1941),
    [sym_primitive_type] = ACTIONS(1941),
    [anon_sym_enum] = ACTIONS(1941),
    [anon_sym_class] = ACTIONS(1941),
    [anon_sym_struct] = ACTIONS(1941),
    [anon_sym_union] = ACTIONS(1941),
    [anon_sym_if] = ACTIONS(1941),
    [anon_sym_else] = ACTIONS(1941),
    [anon_sym_switch] = ACTIONS(1941),
    [anon_sym_case] = ACTIONS(1941),
    [anon_sym_default] = ACTIONS(1941),
    [anon_sym_while] = ACTIONS(1941),
    [anon_sym_do] = ACTIONS(1941),
    [anon_sym_for] = ACTIONS(1941),
    [anon_sym_return] = ACTIONS(1941),
    [anon_sym_break] = ACTIONS(1941),
    [anon_sym_continue] = ACTIONS(1941),
    [anon_sym_goto] = ACTIONS(1941),
    [anon_sym___try] = ACTIONS(1941),
    [anon_sym___leave] = ACTIONS(1941),
    [anon_sym_not] = ACTIONS(1941),
    [anon_sym_compl] = ACTIONS(1941),
    [anon_sym_DASH_DASH] = ACTIONS(1943),
    [anon_sym_PLUS_PLUS] = ACTIONS(1943),
    [anon_sym_sizeof] = ACTIONS(1941),
    [anon_sym___alignof__] = ACTIONS(1941),
    [anon_sym___alignof] = ACTIONS(1941),
    [anon_sym__alignof] = ACTIONS(1941),
    [anon_sym_alignof] = ACTIONS(1941),
    [anon_sym__Alignof] = ACTIONS(1941),
    [anon_sym_offsetof] = ACTIONS(1941),
    [anon_sym__Generic] = ACTIONS(1941),
    [anon_sym_asm] = ACTIONS(1941),
    [anon_sym___asm__] = ACTIONS(1941),
    [sym_number_literal] = ACTIONS(1943),
    [anon_sym_L_SQUOTE] = ACTIONS(1943),
    [anon_sym_u_SQUOTE] = ACTIONS(1943),
    [anon_sym_U_SQUOTE] = ACTIONS(1943),
    [anon_sym_u8_SQUOTE] = ACTIONS(1943),
    [anon_sym_SQUOTE] = ACTIONS(1943),
    [anon_sym_L_DQUOTE] = ACTIONS(1943),
    [anon_sym_u_DQUOTE] = ACTIONS(1943),
    [anon_sym_U_DQUOTE] = ACTIONS(1943),
    [anon_sym_u8_DQUOTE] = ACTIONS(1943),
    [anon_sym_DQUOTE] = ACTIONS(1943),
    [sym_true] = ACTIONS(1941),
    [sym_false] = ACTIONS(1941),
    [anon_sym_NULL] = ACTIONS(1941),
    [anon_sym_nullptr] = ACTIONS(1941),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1941),
    [anon_sym_decltype] = ACTIONS(1941),
    [anon_sym_final] = ACTIONS(1941),
    [anon_sym_override] = ACTIONS(1941),
    [sym_virtual] = ACTIONS(1941),
    [anon_sym_explicit] = ACTIONS(1941),
    [anon_sym_typename] = ACTIONS(1941),
    [anon_sym_template] = ACTIONS(1941),
    [anon_sym_operator] = ACTIONS(1941),
    [anon_sym_try] = ACTIONS(1941),
    [anon_sym_delete] = ACTIONS(1941),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_namespace] = ACTIONS(1941),
    [anon_sym_using] = ACTIONS(1941),
    [anon_sym_static_assert] = ACTIONS(1941),
    [anon_sym_concept] = ACTIONS(1941),
    [anon_sym_co_return] = ACTIONS(1941),
    [anon_sym_co_yield] = ACTIONS(1941),
    [anon_sym_R_DQUOTE] = ACTIONS(1943),
    [anon_sym_LR_DQUOTE] = ACTIONS(1943),
    [anon_sym_uR_DQUOTE] = ACTIONS(1943),
    [anon_sym_UR_DQUOTE] = ACTIONS(1943),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1943),
    [anon_sym_co_await] = ACTIONS(1941),
    [anon_sym_new] = ACTIONS(1941),
    [anon_sym_requires] = ACTIONS(1941),
    [sym_this] = ACTIONS(1941),
    [anon_sym_discard] = ACTIONS(1941),
    [anon_sym_precise] = ACTIONS(1941),
    [anon_sym_shared] = ACTIONS(1941),
    [anon_sym_groupshared] = ACTIONS(1941),
    [anon_sym_uniform] = ACTIONS(1941),
    [anon_sym_row_major] = ACTIONS(1941),
    [anon_sym_column_major] = ACTIONS(1941),
    [anon_sym_globallycoherent] = ACTIONS(1941),
    [anon_sym_centroid] = ACTIONS(1941),
    [anon_sym_noperspective] = ACTIONS(1941),
    [anon_sym_nointerpolation] = ACTIONS(1941),
    [anon_sym_sample] = ACTIONS(1941),
    [anon_sym_linear] = ACTIONS(1941),
    [anon_sym_snorm] = ACTIONS(1941),
    [anon_sym_unorm] = ACTIONS(1941),
    [anon_sym_point] = ACTIONS(1941),
    [anon_sym_line] = ACTIONS(1941),
    [anon_sym_triangleadj] = ACTIONS(1941),
    [anon_sym_lineadj] = ACTIONS(1941),
    [anon_sym_triangle] = ACTIONS(1941),
    [anon_sym_cbuffer] = ACTIONS(1941),
  },
  [169] = {
    [sym_template_argument_list] = STATE(293),
    [sym_identifier] = ACTIONS(1941),
    [aux_sym_preproc_include_token1] = ACTIONS(1941),
    [aux_sym_preproc_def_token1] = ACTIONS(1941),
    [aux_sym_preproc_if_token1] = ACTIONS(1941),
    [aux_sym_preproc_if_token2] = ACTIONS(1941),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1941),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1941),
    [sym_preproc_directive] = ACTIONS(1941),
    [anon_sym_LPAREN2] = ACTIONS(1943),
    [anon_sym_BANG] = ACTIONS(1943),
    [anon_sym_TILDE] = ACTIONS(1943),
    [anon_sym_DASH] = ACTIONS(1941),
    [anon_sym_PLUS] = ACTIONS(1941),
    [anon_sym_STAR] = ACTIONS(1943),
    [anon_sym_AMP_AMP] = ACTIONS(1943),
    [anon_sym_AMP] = ACTIONS(1941),
    [anon_sym_LT] = ACTIONS(2002),
    [anon_sym_COLON] = ACTIONS(1941),
    [anon_sym_SEMI] = ACTIONS(1943),
    [anon_sym___extension__] = ACTIONS(1941),
    [anon_sym_typedef] = ACTIONS(1941),
    [anon_sym_in] = ACTIONS(1941),
    [anon_sym_out] = ACTIONS(1941),
    [anon_sym_inout] = ACTIONS(1941),
    [anon_sym_extern] = ACTIONS(1941),
    [anon_sym___attribute__] = ACTIONS(1941),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1943),
    [anon_sym___declspec] = ACTIONS(1941),
    [anon_sym___based] = ACTIONS(1941),
    [anon_sym___cdecl] = ACTIONS(1941),
    [anon_sym___clrcall] = ACTIONS(1941),
    [anon_sym___stdcall] = ACTIONS(1941),
    [anon_sym___fastcall] = ACTIONS(1941),
    [anon_sym___thiscall] = ACTIONS(1941),
    [anon_sym___vectorcall] = ACTIONS(1941),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_signed] = ACTIONS(1941),
    [anon_sym_unsigned] = ACTIONS(1941),
    [anon_sym_long] = ACTIONS(1941),
    [anon_sym_short] = ACTIONS(1941),
    [anon_sym_LBRACK] = ACTIONS(1941),
    [anon_sym_static] = ACTIONS(1941),
    [anon_sym_register] = ACTIONS(1941),
    [anon_sym_inline] = ACTIONS(1941),
    [anon_sym___inline] = ACTIONS(1941),
    [anon_sym___inline__] = ACTIONS(1941),
    [anon_sym___forceinline] = ACTIONS(1941),
    [anon_sym_thread_local] = ACTIONS(1941),
    [anon_sym___thread] = ACTIONS(1941),
    [anon_sym_const] = ACTIONS(1941),
    [anon_sym_constexpr] = ACTIONS(1941),
    [anon_sym_volatile] = ACTIONS(1941),
    [anon_sym_restrict] = ACTIONS(1941),
    [anon_sym___restrict__] = ACTIONS(1941),
    [anon_sym__Atomic] = ACTIONS(1941),
    [anon_sym__Noreturn] = ACTIONS(1941),
    [anon_sym_noreturn] = ACTIONS(1941),
    [anon_sym_mutable] = ACTIONS(1941),
    [anon_sym_constinit] = ACTIONS(1941),
    [anon_sym_consteval] = ACTIONS(1941),
    [anon_sym_alignas] = ACTIONS(1941),
    [anon_sym__Alignas] = ACTIONS(1941),
    [sym_primitive_type] = ACTIONS(1941),
    [anon_sym_enum] = ACTIONS(1941),
    [anon_sym_class] = ACTIONS(1941),
    [anon_sym_struct] = ACTIONS(1941),
    [anon_sym_union] = ACTIONS(1941),
    [anon_sym_if] = ACTIONS(1941),
    [anon_sym_else] = ACTIONS(1941),
    [anon_sym_switch] = ACTIONS(1941),
    [anon_sym_case] = ACTIONS(1941),
    [anon_sym_default] = ACTIONS(1941),
    [anon_sym_while] = ACTIONS(1941),
    [anon_sym_do] = ACTIONS(1941),
    [anon_sym_for] = ACTIONS(1941),
    [anon_sym_return] = ACTIONS(1941),
    [anon_sym_break] = ACTIONS(1941),
    [anon_sym_continue] = ACTIONS(1941),
    [anon_sym_goto] = ACTIONS(1941),
    [anon_sym___try] = ACTIONS(1941),
    [anon_sym___leave] = ACTIONS(1941),
    [anon_sym_not] = ACTIONS(1941),
    [anon_sym_compl] = ACTIONS(1941),
    [anon_sym_DASH_DASH] = ACTIONS(1943),
    [anon_sym_PLUS_PLUS] = ACTIONS(1943),
    [anon_sym_sizeof] = ACTIONS(1941),
    [anon_sym___alignof__] = ACTIONS(1941),
    [anon_sym___alignof] = ACTIONS(1941),
    [anon_sym__alignof] = ACTIONS(1941),
    [anon_sym_alignof] = ACTIONS(1941),
    [anon_sym__Alignof] = ACTIONS(1941),
    [anon_sym_offsetof] = ACTIONS(1941),
    [anon_sym__Generic] = ACTIONS(1941),
    [anon_sym_asm] = ACTIONS(1941),
    [anon_sym___asm__] = ACTIONS(1941),
    [sym_number_literal] = ACTIONS(1943),
    [anon_sym_L_SQUOTE] = ACTIONS(1943),
    [anon_sym_u_SQUOTE] = ACTIONS(1943),
    [anon_sym_U_SQUOTE] = ACTIONS(1943),
    [anon_sym_u8_SQUOTE] = ACTIONS(1943),
    [anon_sym_SQUOTE] = ACTIONS(1943),
    [anon_sym_L_DQUOTE] = ACTIONS(1943),
    [anon_sym_u_DQUOTE] = ACTIONS(1943),
    [anon_sym_U_DQUOTE] = ACTIONS(1943),
    [anon_sym_u8_DQUOTE] = ACTIONS(1943),
    [anon_sym_DQUOTE] = ACTIONS(1943),
    [sym_true] = ACTIONS(1941),
    [sym_false] = ACTIONS(1941),
    [anon_sym_NULL] = ACTIONS(1941),
    [anon_sym_nullptr] = ACTIONS(1941),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1941),
    [anon_sym_decltype] = ACTIONS(1941),
    [anon_sym_final] = ACTIONS(1941),
    [anon_sym_override] = ACTIONS(1941),
    [sym_virtual] = ACTIONS(1941),
    [anon_sym_explicit] = ACTIONS(1941),
    [anon_sym_typename] = ACTIONS(1941),
    [anon_sym_template] = ACTIONS(1941),
    [anon_sym_operator] = ACTIONS(1941),
    [anon_sym_try] = ACTIONS(1941),
    [anon_sym_delete] = ACTIONS(1941),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_namespace] = ACTIONS(1941),
    [anon_sym_using] = ACTIONS(1941),
    [anon_sym_static_assert] = ACTIONS(1941),
    [anon_sym_concept] = ACTIONS(1941),
    [anon_sym_co_return] = ACTIONS(1941),
    [anon_sym_co_yield] = ACTIONS(1941),
    [anon_sym_R_DQUOTE] = ACTIONS(1943),
    [anon_sym_LR_DQUOTE] = ACTIONS(1943),
    [anon_sym_uR_DQUOTE] = ACTIONS(1943),
    [anon_sym_UR_DQUOTE] = ACTIONS(1943),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1943),
    [anon_sym_co_await] = ACTIONS(1941),
    [anon_sym_new] = ACTIONS(1941),
    [anon_sym_requires] = ACTIONS(1941),
    [sym_this] = ACTIONS(1941),
    [anon_sym_discard] = ACTIONS(1941),
    [anon_sym_precise] = ACTIONS(1941),
    [anon_sym_shared] = ACTIONS(1941),
    [anon_sym_groupshared] = ACTIONS(1941),
    [anon_sym_uniform] = ACTIONS(1941),
    [anon_sym_row_major] = ACTIONS(1941),
    [anon_sym_column_major] = ACTIONS(1941),
    [anon_sym_globallycoherent] = ACTIONS(1941),
    [anon_sym_centroid] = ACTIONS(1941),
    [anon_sym_noperspective] = ACTIONS(1941),
    [anon_sym_nointerpolation] = ACTIONS(1941),
    [anon_sym_sample] = ACTIONS(1941),
    [anon_sym_linear] = ACTIONS(1941),
    [anon_sym_snorm] = ACTIONS(1941),
    [anon_sym_unorm] = ACTIONS(1941),
    [anon_sym_point] = ACTIONS(1941),
    [anon_sym_line] = ACTIONS(1941),
    [anon_sym_triangleadj] = ACTIONS(1941),
    [anon_sym_lineadj] = ACTIONS(1941),
    [anon_sym_triangle] = ACTIONS(1941),
    [anon_sym_cbuffer] = ACTIONS(1941),
  },
  [170] = {
    [sym_else_clause] = STATE(203),
    [sym_identifier] = ACTIONS(2004),
    [aux_sym_preproc_include_token1] = ACTIONS(2004),
    [aux_sym_preproc_def_token1] = ACTIONS(2004),
    [aux_sym_preproc_if_token1] = ACTIONS(2004),
    [aux_sym_preproc_if_token2] = ACTIONS(2004),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2004),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2004),
    [aux_sym_preproc_else_token1] = ACTIONS(2004),
    [aux_sym_preproc_elif_token1] = ACTIONS(2004),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2004),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2004),
    [sym_preproc_directive] = ACTIONS(2004),
    [anon_sym_LPAREN2] = ACTIONS(2006),
    [anon_sym_BANG] = ACTIONS(2006),
    [anon_sym_TILDE] = ACTIONS(2006),
    [anon_sym_DASH] = ACTIONS(2004),
    [anon_sym_PLUS] = ACTIONS(2004),
    [anon_sym_STAR] = ACTIONS(2006),
    [anon_sym_AMP_AMP] = ACTIONS(2006),
    [anon_sym_AMP] = ACTIONS(2004),
    [anon_sym_SEMI] = ACTIONS(2006),
    [anon_sym___extension__] = ACTIONS(2004),
    [anon_sym_typedef] = ACTIONS(2004),
    [anon_sym_in] = ACTIONS(2004),
    [anon_sym_out] = ACTIONS(2004),
    [anon_sym_inout] = ACTIONS(2004),
    [anon_sym_extern] = ACTIONS(2004),
    [anon_sym___attribute__] = ACTIONS(2004),
    [anon_sym_COLON_COLON] = ACTIONS(2006),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2006),
    [anon_sym___declspec] = ACTIONS(2004),
    [anon_sym___based] = ACTIONS(2004),
    [anon_sym___cdecl] = ACTIONS(2004),
    [anon_sym___clrcall] = ACTIONS(2004),
    [anon_sym___stdcall] = ACTIONS(2004),
    [anon_sym___fastcall] = ACTIONS(2004),
    [anon_sym___thiscall] = ACTIONS(2004),
    [anon_sym___vectorcall] = ACTIONS(2004),
    [anon_sym_LBRACE] = ACTIONS(2006),
    [anon_sym_signed] = ACTIONS(2004),
    [anon_sym_unsigned] = ACTIONS(2004),
    [anon_sym_long] = ACTIONS(2004),
    [anon_sym_short] = ACTIONS(2004),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(2004),
    [anon_sym_register] = ACTIONS(2004),
    [anon_sym_inline] = ACTIONS(2004),
    [anon_sym___inline] = ACTIONS(2004),
    [anon_sym___inline__] = ACTIONS(2004),
    [anon_sym___forceinline] = ACTIONS(2004),
    [anon_sym_thread_local] = ACTIONS(2004),
    [anon_sym___thread] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(2004),
    [anon_sym_constexpr] = ACTIONS(2004),
    [anon_sym_volatile] = ACTIONS(2004),
    [anon_sym_restrict] = ACTIONS(2004),
    [anon_sym___restrict__] = ACTIONS(2004),
    [anon_sym__Atomic] = ACTIONS(2004),
    [anon_sym__Noreturn] = ACTIONS(2004),
    [anon_sym_noreturn] = ACTIONS(2004),
    [anon_sym_mutable] = ACTIONS(2004),
    [anon_sym_constinit] = ACTIONS(2004),
    [anon_sym_consteval] = ACTIONS(2004),
    [anon_sym_alignas] = ACTIONS(2004),
    [anon_sym__Alignas] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2004),
    [anon_sym_enum] = ACTIONS(2004),
    [anon_sym_class] = ACTIONS(2004),
    [anon_sym_struct] = ACTIONS(2004),
    [anon_sym_union] = ACTIONS(2004),
    [anon_sym_if] = ACTIONS(2004),
    [anon_sym_else] = ACTIONS(1998),
    [anon_sym_switch] = ACTIONS(2004),
    [anon_sym_case] = ACTIONS(2004),
    [anon_sym_default] = ACTIONS(2004),
    [anon_sym_while] = ACTIONS(2004),
    [anon_sym_do] = ACTIONS(2004),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_return] = ACTIONS(2004),
    [anon_sym_break] = ACTIONS(2004),
    [anon_sym_continue] = ACTIONS(2004),
    [anon_sym_goto] = ACTIONS(2004),
    [anon_sym___try] = ACTIONS(2004),
    [anon_sym___leave] = ACTIONS(2004),
    [anon_sym_not] = ACTIONS(2004),
    [anon_sym_compl] = ACTIONS(2004),
    [anon_sym_DASH_DASH] = ACTIONS(2006),
    [anon_sym_PLUS_PLUS] = ACTIONS(2006),
    [anon_sym_sizeof] = ACTIONS(2004),
    [anon_sym___alignof__] = ACTIONS(2004),
    [anon_sym___alignof] = ACTIONS(2004),
    [anon_sym__alignof] = ACTIONS(2004),
    [anon_sym_alignof] = ACTIONS(2004),
    [anon_sym__Alignof] = ACTIONS(2004),
    [anon_sym_offsetof] = ACTIONS(2004),
    [anon_sym__Generic] = ACTIONS(2004),
    [anon_sym_asm] = ACTIONS(2004),
    [anon_sym___asm__] = ACTIONS(2004),
    [sym_number_literal] = ACTIONS(2006),
    [anon_sym_L_SQUOTE] = ACTIONS(2006),
    [anon_sym_u_SQUOTE] = ACTIONS(2006),
    [anon_sym_U_SQUOTE] = ACTIONS(2006),
    [anon_sym_u8_SQUOTE] = ACTIONS(2006),
    [anon_sym_SQUOTE] = ACTIONS(2006),
    [anon_sym_L_DQUOTE] = ACTIONS(2006),
    [anon_sym_u_DQUOTE] = ACTIONS(2006),
    [anon_sym_U_DQUOTE] = ACTIONS(2006),
    [anon_sym_u8_DQUOTE] = ACTIONS(2006),
    [anon_sym_DQUOTE] = ACTIONS(2006),
    [sym_true] = ACTIONS(2004),
    [sym_false] = ACTIONS(2004),
    [anon_sym_NULL] = ACTIONS(2004),
    [anon_sym_nullptr] = ACTIONS(2004),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2004),
    [anon_sym_decltype] = ACTIONS(2004),
    [sym_virtual] = ACTIONS(2004),
    [anon_sym_explicit] = ACTIONS(2004),
    [anon_sym_typename] = ACTIONS(2004),
    [anon_sym_template] = ACTIONS(2004),
    [anon_sym_operator] = ACTIONS(2004),
    [anon_sym_try] = ACTIONS(2004),
    [anon_sym_delete] = ACTIONS(2004),
    [anon_sym_throw] = ACTIONS(2004),
    [anon_sym_namespace] = ACTIONS(2004),
    [anon_sym_using] = ACTIONS(2004),
    [anon_sym_static_assert] = ACTIONS(2004),
    [anon_sym_concept] = ACTIONS(2004),
    [anon_sym_co_return] = ACTIONS(2004),
    [anon_sym_co_yield] = ACTIONS(2004),
    [anon_sym_R_DQUOTE] = ACTIONS(2006),
    [anon_sym_LR_DQUOTE] = ACTIONS(2006),
    [anon_sym_uR_DQUOTE] = ACTIONS(2006),
    [anon_sym_UR_DQUOTE] = ACTIONS(2006),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2006),
    [anon_sym_co_await] = ACTIONS(2004),
    [anon_sym_new] = ACTIONS(2004),
    [anon_sym_requires] = ACTIONS(2004),
    [sym_this] = ACTIONS(2004),
    [anon_sym_discard] = ACTIONS(2004),
    [anon_sym_precise] = ACTIONS(2004),
    [anon_sym_shared] = ACTIONS(2004),
    [anon_sym_groupshared] = ACTIONS(2004),
    [anon_sym_uniform] = ACTIONS(2004),
    [anon_sym_row_major] = ACTIONS(2004),
    [anon_sym_column_major] = ACTIONS(2004),
    [anon_sym_globallycoherent] = ACTIONS(2004),
    [anon_sym_centroid] = ACTIONS(2004),
    [anon_sym_noperspective] = ACTIONS(2004),
    [anon_sym_nointerpolation] = ACTIONS(2004),
    [anon_sym_sample] = ACTIONS(2004),
    [anon_sym_linear] = ACTIONS(2004),
    [anon_sym_snorm] = ACTIONS(2004),
    [anon_sym_unorm] = ACTIONS(2004),
    [anon_sym_point] = ACTIONS(2004),
    [anon_sym_line] = ACTIONS(2004),
    [anon_sym_triangleadj] = ACTIONS(2004),
    [anon_sym_lineadj] = ACTIONS(2004),
    [anon_sym_triangle] = ACTIONS(2004),
    [anon_sym_cbuffer] = ACTIONS(2004),
  },
  [171] = {
    [sym_else_clause] = STATE(209),
    [sym_identifier] = ACTIONS(2008),
    [aux_sym_preproc_include_token1] = ACTIONS(2008),
    [aux_sym_preproc_def_token1] = ACTIONS(2008),
    [aux_sym_preproc_if_token1] = ACTIONS(2008),
    [aux_sym_preproc_if_token2] = ACTIONS(2008),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2008),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2008),
    [aux_sym_preproc_else_token1] = ACTIONS(2008),
    [aux_sym_preproc_elif_token1] = ACTIONS(2008),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2008),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2008),
    [sym_preproc_directive] = ACTIONS(2008),
    [anon_sym_LPAREN2] = ACTIONS(2010),
    [anon_sym_BANG] = ACTIONS(2010),
    [anon_sym_TILDE] = ACTIONS(2010),
    [anon_sym_DASH] = ACTIONS(2008),
    [anon_sym_PLUS] = ACTIONS(2008),
    [anon_sym_STAR] = ACTIONS(2010),
    [anon_sym_AMP_AMP] = ACTIONS(2010),
    [anon_sym_AMP] = ACTIONS(2008),
    [anon_sym_SEMI] = ACTIONS(2010),
    [anon_sym___extension__] = ACTIONS(2008),
    [anon_sym_typedef] = ACTIONS(2008),
    [anon_sym_in] = ACTIONS(2008),
    [anon_sym_out] = ACTIONS(2008),
    [anon_sym_inout] = ACTIONS(2008),
    [anon_sym_extern] = ACTIONS(2008),
    [anon_sym___attribute__] = ACTIONS(2008),
    [anon_sym_COLON_COLON] = ACTIONS(2010),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2010),
    [anon_sym___declspec] = ACTIONS(2008),
    [anon_sym___based] = ACTIONS(2008),
    [anon_sym___cdecl] = ACTIONS(2008),
    [anon_sym___clrcall] = ACTIONS(2008),
    [anon_sym___stdcall] = ACTIONS(2008),
    [anon_sym___fastcall] = ACTIONS(2008),
    [anon_sym___thiscall] = ACTIONS(2008),
    [anon_sym___vectorcall] = ACTIONS(2008),
    [anon_sym_LBRACE] = ACTIONS(2010),
    [anon_sym_signed] = ACTIONS(2008),
    [anon_sym_unsigned] = ACTIONS(2008),
    [anon_sym_long] = ACTIONS(2008),
    [anon_sym_short] = ACTIONS(2008),
    [anon_sym_LBRACK] = ACTIONS(2008),
    [anon_sym_static] = ACTIONS(2008),
    [anon_sym_register] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(2008),
    [anon_sym___inline] = ACTIONS(2008),
    [anon_sym___inline__] = ACTIONS(2008),
    [anon_sym___forceinline] = ACTIONS(2008),
    [anon_sym_thread_local] = ACTIONS(2008),
    [anon_sym___thread] = ACTIONS(2008),
    [anon_sym_const] = ACTIONS(2008),
    [anon_sym_constexpr] = ACTIONS(2008),
    [anon_sym_volatile] = ACTIONS(2008),
    [anon_sym_restrict] = ACTIONS(2008),
    [anon_sym___restrict__] = ACTIONS(2008),
    [anon_sym__Atomic] = ACTIONS(2008),
    [anon_sym__Noreturn] = ACTIONS(2008),
    [anon_sym_noreturn] = ACTIONS(2008),
    [anon_sym_mutable] = ACTIONS(2008),
    [anon_sym_constinit] = ACTIONS(2008),
    [anon_sym_consteval] = ACTIONS(2008),
    [anon_sym_alignas] = ACTIONS(2008),
    [anon_sym__Alignas] = ACTIONS(2008),
    [sym_primitive_type] = ACTIONS(2008),
    [anon_sym_enum] = ACTIONS(2008),
    [anon_sym_class] = ACTIONS(2008),
    [anon_sym_struct] = ACTIONS(2008),
    [anon_sym_union] = ACTIONS(2008),
    [anon_sym_if] = ACTIONS(2008),
    [anon_sym_else] = ACTIONS(1998),
    [anon_sym_switch] = ACTIONS(2008),
    [anon_sym_case] = ACTIONS(2008),
    [anon_sym_default] = ACTIONS(2008),
    [anon_sym_while] = ACTIONS(2008),
    [anon_sym_do] = ACTIONS(2008),
    [anon_sym_for] = ACTIONS(2008),
    [anon_sym_return] = ACTIONS(2008),
    [anon_sym_break] = ACTIONS(2008),
    [anon_sym_continue] = ACTIONS(2008),
    [anon_sym_goto] = ACTIONS(2008),
    [anon_sym___try] = ACTIONS(2008),
    [anon_sym___leave] = ACTIONS(2008),
    [anon_sym_not] = ACTIONS(2008),
    [anon_sym_compl] = ACTIONS(2008),
    [anon_sym_DASH_DASH] = ACTIONS(2010),
    [anon_sym_PLUS_PLUS] = ACTIONS(2010),
    [anon_sym_sizeof] = ACTIONS(2008),
    [anon_sym___alignof__] = ACTIONS(2008),
    [anon_sym___alignof] = ACTIONS(2008),
    [anon_sym__alignof] = ACTIONS(2008),
    [anon_sym_alignof] = ACTIONS(2008),
    [anon_sym__Alignof] = ACTIONS(2008),
    [anon_sym_offsetof] = ACTIONS(2008),
    [anon_sym__Generic] = ACTIONS(2008),
    [anon_sym_asm] = ACTIONS(2008),
    [anon_sym___asm__] = ACTIONS(2008),
    [sym_number_literal] = ACTIONS(2010),
    [anon_sym_L_SQUOTE] = ACTIONS(2010),
    [anon_sym_u_SQUOTE] = ACTIONS(2010),
    [anon_sym_U_SQUOTE] = ACTIONS(2010),
    [anon_sym_u8_SQUOTE] = ACTIONS(2010),
    [anon_sym_SQUOTE] = ACTIONS(2010),
    [anon_sym_L_DQUOTE] = ACTIONS(2010),
    [anon_sym_u_DQUOTE] = ACTIONS(2010),
    [anon_sym_U_DQUOTE] = ACTIONS(2010),
    [anon_sym_u8_DQUOTE] = ACTIONS(2010),
    [anon_sym_DQUOTE] = ACTIONS(2010),
    [sym_true] = ACTIONS(2008),
    [sym_false] = ACTIONS(2008),
    [anon_sym_NULL] = ACTIONS(2008),
    [anon_sym_nullptr] = ACTIONS(2008),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2008),
    [anon_sym_decltype] = ACTIONS(2008),
    [sym_virtual] = ACTIONS(2008),
    [anon_sym_explicit] = ACTIONS(2008),
    [anon_sym_typename] = ACTIONS(2008),
    [anon_sym_template] = ACTIONS(2008),
    [anon_sym_operator] = ACTIONS(2008),
    [anon_sym_try] = ACTIONS(2008),
    [anon_sym_delete] = ACTIONS(2008),
    [anon_sym_throw] = ACTIONS(2008),
    [anon_sym_namespace] = ACTIONS(2008),
    [anon_sym_using] = ACTIONS(2008),
    [anon_sym_static_assert] = ACTIONS(2008),
    [anon_sym_concept] = ACTIONS(2008),
    [anon_sym_co_return] = ACTIONS(2008),
    [anon_sym_co_yield] = ACTIONS(2008),
    [anon_sym_R_DQUOTE] = ACTIONS(2010),
    [anon_sym_LR_DQUOTE] = ACTIONS(2010),
    [anon_sym_uR_DQUOTE] = ACTIONS(2010),
    [anon_sym_UR_DQUOTE] = ACTIONS(2010),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2010),
    [anon_sym_co_await] = ACTIONS(2008),
    [anon_sym_new] = ACTIONS(2008),
    [anon_sym_requires] = ACTIONS(2008),
    [sym_this] = ACTIONS(2008),
    [anon_sym_discard] = ACTIONS(2008),
    [anon_sym_precise] = ACTIONS(2008),
    [anon_sym_shared] = ACTIONS(2008),
    [anon_sym_groupshared] = ACTIONS(2008),
    [anon_sym_uniform] = ACTIONS(2008),
    [anon_sym_row_major] = ACTIONS(2008),
    [anon_sym_column_major] = ACTIONS(2008),
    [anon_sym_globallycoherent] = ACTIONS(2008),
    [anon_sym_centroid] = ACTIONS(2008),
    [anon_sym_noperspective] = ACTIONS(2008),
    [anon_sym_nointerpolation] = ACTIONS(2008),
    [anon_sym_sample] = ACTIONS(2008),
    [anon_sym_linear] = ACTIONS(2008),
    [anon_sym_snorm] = ACTIONS(2008),
    [anon_sym_unorm] = ACTIONS(2008),
    [anon_sym_point] = ACTIONS(2008),
    [anon_sym_line] = ACTIONS(2008),
    [anon_sym_triangleadj] = ACTIONS(2008),
    [anon_sym_lineadj] = ACTIONS(2008),
    [anon_sym_triangle] = ACTIONS(2008),
    [anon_sym_cbuffer] = ACTIONS(2008),
  },
  [172] = {
    [sym_identifier] = ACTIONS(2012),
    [aux_sym_preproc_include_token1] = ACTIONS(2012),
    [aux_sym_preproc_def_token1] = ACTIONS(2012),
    [aux_sym_preproc_if_token1] = ACTIONS(2012),
    [aux_sym_preproc_if_token2] = ACTIONS(2012),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2012),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2012),
    [aux_sym_preproc_else_token1] = ACTIONS(2012),
    [aux_sym_preproc_elif_token1] = ACTIONS(2012),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2012),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2012),
    [sym_preproc_directive] = ACTIONS(2012),
    [anon_sym_LPAREN2] = ACTIONS(2014),
    [anon_sym_BANG] = ACTIONS(2014),
    [anon_sym_TILDE] = ACTIONS(2014),
    [anon_sym_DASH] = ACTIONS(2012),
    [anon_sym_PLUS] = ACTIONS(2012),
    [anon_sym_STAR] = ACTIONS(2014),
    [anon_sym_AMP_AMP] = ACTIONS(2014),
    [anon_sym_AMP] = ACTIONS(2012),
    [anon_sym_SEMI] = ACTIONS(2014),
    [anon_sym___extension__] = ACTIONS(2012),
    [anon_sym_typedef] = ACTIONS(2012),
    [anon_sym_in] = ACTIONS(2012),
    [anon_sym_out] = ACTIONS(2012),
    [anon_sym_inout] = ACTIONS(2012),
    [anon_sym_extern] = ACTIONS(2012),
    [anon_sym___attribute__] = ACTIONS(2012),
    [anon_sym_COLON_COLON] = ACTIONS(2014),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2014),
    [anon_sym___declspec] = ACTIONS(2012),
    [anon_sym___based] = ACTIONS(2012),
    [anon_sym___cdecl] = ACTIONS(2012),
    [anon_sym___clrcall] = ACTIONS(2012),
    [anon_sym___stdcall] = ACTIONS(2012),
    [anon_sym___fastcall] = ACTIONS(2012),
    [anon_sym___thiscall] = ACTIONS(2012),
    [anon_sym___vectorcall] = ACTIONS(2012),
    [anon_sym_LBRACE] = ACTIONS(2014),
    [anon_sym_signed] = ACTIONS(2012),
    [anon_sym_unsigned] = ACTIONS(2012),
    [anon_sym_long] = ACTIONS(2012),
    [anon_sym_short] = ACTIONS(2012),
    [anon_sym_LBRACK] = ACTIONS(2012),
    [anon_sym_static] = ACTIONS(2012),
    [anon_sym_register] = ACTIONS(2012),
    [anon_sym_inline] = ACTIONS(2012),
    [anon_sym___inline] = ACTIONS(2012),
    [anon_sym___inline__] = ACTIONS(2012),
    [anon_sym___forceinline] = ACTIONS(2012),
    [anon_sym_thread_local] = ACTIONS(2012),
    [anon_sym___thread] = ACTIONS(2012),
    [anon_sym_const] = ACTIONS(2012),
    [anon_sym_constexpr] = ACTIONS(2012),
    [anon_sym_volatile] = ACTIONS(2012),
    [anon_sym_restrict] = ACTIONS(2012),
    [anon_sym___restrict__] = ACTIONS(2012),
    [anon_sym__Atomic] = ACTIONS(2012),
    [anon_sym__Noreturn] = ACTIONS(2012),
    [anon_sym_noreturn] = ACTIONS(2012),
    [anon_sym_mutable] = ACTIONS(2012),
    [anon_sym_constinit] = ACTIONS(2012),
    [anon_sym_consteval] = ACTIONS(2012),
    [anon_sym_alignas] = ACTIONS(2012),
    [anon_sym__Alignas] = ACTIONS(2012),
    [sym_primitive_type] = ACTIONS(2012),
    [anon_sym_enum] = ACTIONS(2012),
    [anon_sym_class] = ACTIONS(2012),
    [anon_sym_struct] = ACTIONS(2012),
    [anon_sym_union] = ACTIONS(2012),
    [anon_sym_if] = ACTIONS(2012),
    [anon_sym_else] = ACTIONS(2012),
    [anon_sym_switch] = ACTIONS(2012),
    [anon_sym_case] = ACTIONS(2012),
    [anon_sym_default] = ACTIONS(2012),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_do] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2012),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_break] = ACTIONS(2012),
    [anon_sym_continue] = ACTIONS(2012),
    [anon_sym_goto] = ACTIONS(2012),
    [anon_sym___try] = ACTIONS(2012),
    [anon_sym___leave] = ACTIONS(2012),
    [anon_sym_not] = ACTIONS(2012),
    [anon_sym_compl] = ACTIONS(2012),
    [anon_sym_DASH_DASH] = ACTIONS(2014),
    [anon_sym_PLUS_PLUS] = ACTIONS(2014),
    [anon_sym_sizeof] = ACTIONS(2012),
    [anon_sym___alignof__] = ACTIONS(2012),
    [anon_sym___alignof] = ACTIONS(2012),
    [anon_sym__alignof] = ACTIONS(2012),
    [anon_sym_alignof] = ACTIONS(2012),
    [anon_sym__Alignof] = ACTIONS(2012),
    [anon_sym_offsetof] = ACTIONS(2012),
    [anon_sym__Generic] = ACTIONS(2012),
    [anon_sym_asm] = ACTIONS(2012),
    [anon_sym___asm__] = ACTIONS(2012),
    [sym_number_literal] = ACTIONS(2014),
    [anon_sym_L_SQUOTE] = ACTIONS(2014),
    [anon_sym_u_SQUOTE] = ACTIONS(2014),
    [anon_sym_U_SQUOTE] = ACTIONS(2014),
    [anon_sym_u8_SQUOTE] = ACTIONS(2014),
    [anon_sym_SQUOTE] = ACTIONS(2014),
    [anon_sym_L_DQUOTE] = ACTIONS(2014),
    [anon_sym_u_DQUOTE] = ACTIONS(2014),
    [anon_sym_U_DQUOTE] = ACTIONS(2014),
    [anon_sym_u8_DQUOTE] = ACTIONS(2014),
    [anon_sym_DQUOTE] = ACTIONS(2014),
    [sym_true] = ACTIONS(2012),
    [sym_false] = ACTIONS(2012),
    [anon_sym_NULL] = ACTIONS(2012),
    [anon_sym_nullptr] = ACTIONS(2012),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2012),
    [anon_sym_decltype] = ACTIONS(2012),
    [sym_virtual] = ACTIONS(2012),
    [anon_sym_explicit] = ACTIONS(2012),
    [anon_sym_typename] = ACTIONS(2012),
    [anon_sym_template] = ACTIONS(2012),
    [anon_sym_operator] = ACTIONS(2012),
    [anon_sym_try] = ACTIONS(2012),
    [anon_sym_delete] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2012),
    [anon_sym_namespace] = ACTIONS(2012),
    [anon_sym_using] = ACTIONS(2012),
    [anon_sym_static_assert] = ACTIONS(2012),
    [anon_sym_concept] = ACTIONS(2012),
    [anon_sym_co_return] = ACTIONS(2012),
    [anon_sym_co_yield] = ACTIONS(2012),
    [anon_sym_catch] = ACTIONS(2012),
    [anon_sym_R_DQUOTE] = ACTIONS(2014),
    [anon_sym_LR_DQUOTE] = ACTIONS(2014),
    [anon_sym_uR_DQUOTE] = ACTIONS(2014),
    [anon_sym_UR_DQUOTE] = ACTIONS(2014),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2014),
    [anon_sym_co_await] = ACTIONS(2012),
    [anon_sym_new] = ACTIONS(2012),
    [anon_sym_requires] = ACTIONS(2012),
    [sym_this] = ACTIONS(2012),
    [anon_sym_discard] = ACTIONS(2012),
    [anon_sym_precise] = ACTIONS(2012),
    [anon_sym_shared] = ACTIONS(2012),
    [anon_sym_groupshared] = ACTIONS(2012),
    [anon_sym_uniform] = ACTIONS(2012),
    [anon_sym_row_major] = ACTIONS(2012),
    [anon_sym_column_major] = ACTIONS(2012),
    [anon_sym_globallycoherent] = ACTIONS(2012),
    [anon_sym_centroid] = ACTIONS(2012),
    [anon_sym_noperspective] = ACTIONS(2012),
    [anon_sym_nointerpolation] = ACTIONS(2012),
    [anon_sym_sample] = ACTIONS(2012),
    [anon_sym_linear] = ACTIONS(2012),
    [anon_sym_snorm] = ACTIONS(2012),
    [anon_sym_unorm] = ACTIONS(2012),
    [anon_sym_point] = ACTIONS(2012),
    [anon_sym_line] = ACTIONS(2012),
    [anon_sym_triangleadj] = ACTIONS(2012),
    [anon_sym_lineadj] = ACTIONS(2012),
    [anon_sym_triangle] = ACTIONS(2012),
    [anon_sym_cbuffer] = ACTIONS(2012),
  },
  [173] = {
    [sym_template_argument_list] = STATE(293),
    [sym_identifier] = ACTIONS(1933),
    [aux_sym_preproc_include_token1] = ACTIONS(1933),
    [aux_sym_preproc_def_token1] = ACTIONS(1933),
    [aux_sym_preproc_if_token1] = ACTIONS(1933),
    [aux_sym_preproc_if_token2] = ACTIONS(1933),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1933),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1933),
    [sym_preproc_directive] = ACTIONS(1933),
    [anon_sym_LPAREN2] = ACTIONS(1935),
    [anon_sym_BANG] = ACTIONS(1935),
    [anon_sym_TILDE] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1933),
    [anon_sym_PLUS] = ACTIONS(1933),
    [anon_sym_STAR] = ACTIONS(1935),
    [anon_sym_AMP_AMP] = ACTIONS(1935),
    [anon_sym_AMP] = ACTIONS(1933),
    [anon_sym_LT] = ACTIONS(2002),
    [anon_sym_COLON] = ACTIONS(1933),
    [anon_sym_SEMI] = ACTIONS(1935),
    [anon_sym___extension__] = ACTIONS(1933),
    [anon_sym_typedef] = ACTIONS(1933),
    [anon_sym_in] = ACTIONS(1933),
    [anon_sym_out] = ACTIONS(1933),
    [anon_sym_inout] = ACTIONS(1933),
    [anon_sym_extern] = ACTIONS(1933),
    [anon_sym___attribute__] = ACTIONS(1933),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1935),
    [anon_sym___declspec] = ACTIONS(1933),
    [anon_sym___based] = ACTIONS(1933),
    [anon_sym___cdecl] = ACTIONS(1933),
    [anon_sym___clrcall] = ACTIONS(1933),
    [anon_sym___stdcall] = ACTIONS(1933),
    [anon_sym___fastcall] = ACTIONS(1933),
    [anon_sym___thiscall] = ACTIONS(1933),
    [anon_sym___vectorcall] = ACTIONS(1933),
    [anon_sym_LBRACE] = ACTIONS(1935),
    [anon_sym_signed] = ACTIONS(1933),
    [anon_sym_unsigned] = ACTIONS(1933),
    [anon_sym_long] = ACTIONS(1933),
    [anon_sym_short] = ACTIONS(1933),
    [anon_sym_LBRACK] = ACTIONS(1933),
    [anon_sym_static] = ACTIONS(1933),
    [anon_sym_register] = ACTIONS(1933),
    [anon_sym_inline] = ACTIONS(1933),
    [anon_sym___inline] = ACTIONS(1933),
    [anon_sym___inline__] = ACTIONS(1933),
    [anon_sym___forceinline] = ACTIONS(1933),
    [anon_sym_thread_local] = ACTIONS(1933),
    [anon_sym___thread] = ACTIONS(1933),
    [anon_sym_const] = ACTIONS(1933),
    [anon_sym_constexpr] = ACTIONS(1933),
    [anon_sym_volatile] = ACTIONS(1933),
    [anon_sym_restrict] = ACTIONS(1933),
    [anon_sym___restrict__] = ACTIONS(1933),
    [anon_sym__Atomic] = ACTIONS(1933),
    [anon_sym__Noreturn] = ACTIONS(1933),
    [anon_sym_noreturn] = ACTIONS(1933),
    [anon_sym_mutable] = ACTIONS(1933),
    [anon_sym_constinit] = ACTIONS(1933),
    [anon_sym_consteval] = ACTIONS(1933),
    [anon_sym_alignas] = ACTIONS(1933),
    [anon_sym__Alignas] = ACTIONS(1933),
    [sym_primitive_type] = ACTIONS(1933),
    [anon_sym_enum] = ACTIONS(1933),
    [anon_sym_class] = ACTIONS(1933),
    [anon_sym_struct] = ACTIONS(1933),
    [anon_sym_union] = ACTIONS(1933),
    [anon_sym_if] = ACTIONS(1933),
    [anon_sym_else] = ACTIONS(1933),
    [anon_sym_switch] = ACTIONS(1933),
    [anon_sym_case] = ACTIONS(1933),
    [anon_sym_default] = ACTIONS(1933),
    [anon_sym_while] = ACTIONS(1933),
    [anon_sym_do] = ACTIONS(1933),
    [anon_sym_for] = ACTIONS(1933),
    [anon_sym_return] = ACTIONS(1933),
    [anon_sym_break] = ACTIONS(1933),
    [anon_sym_continue] = ACTIONS(1933),
    [anon_sym_goto] = ACTIONS(1933),
    [anon_sym___try] = ACTIONS(1933),
    [anon_sym___leave] = ACTIONS(1933),
    [anon_sym_not] = ACTIONS(1933),
    [anon_sym_compl] = ACTIONS(1933),
    [anon_sym_DASH_DASH] = ACTIONS(1935),
    [anon_sym_PLUS_PLUS] = ACTIONS(1935),
    [anon_sym_sizeof] = ACTIONS(1933),
    [anon_sym___alignof__] = ACTIONS(1933),
    [anon_sym___alignof] = ACTIONS(1933),
    [anon_sym__alignof] = ACTIONS(1933),
    [anon_sym_alignof] = ACTIONS(1933),
    [anon_sym__Alignof] = ACTIONS(1933),
    [anon_sym_offsetof] = ACTIONS(1933),
    [anon_sym__Generic] = ACTIONS(1933),
    [anon_sym_asm] = ACTIONS(1933),
    [anon_sym___asm__] = ACTIONS(1933),
    [sym_number_literal] = ACTIONS(1935),
    [anon_sym_L_SQUOTE] = ACTIONS(1935),
    [anon_sym_u_SQUOTE] = ACTIONS(1935),
    [anon_sym_U_SQUOTE] = ACTIONS(1935),
    [anon_sym_u8_SQUOTE] = ACTIONS(1935),
    [anon_sym_SQUOTE] = ACTIONS(1935),
    [anon_sym_L_DQUOTE] = ACTIONS(1935),
    [anon_sym_u_DQUOTE] = ACTIONS(1935),
    [anon_sym_U_DQUOTE] = ACTIONS(1935),
    [anon_sym_u8_DQUOTE] = ACTIONS(1935),
    [anon_sym_DQUOTE] = ACTIONS(1935),
    [sym_true] = ACTIONS(1933),
    [sym_false] = ACTIONS(1933),
    [anon_sym_NULL] = ACTIONS(1933),
    [anon_sym_nullptr] = ACTIONS(1933),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1933),
    [anon_sym_decltype] = ACTIONS(1933),
    [anon_sym_final] = ACTIONS(1933),
    [anon_sym_override] = ACTIONS(1933),
    [sym_virtual] = ACTIONS(1933),
    [anon_sym_explicit] = ACTIONS(1933),
    [anon_sym_typename] = ACTIONS(1933),
    [anon_sym_template] = ACTIONS(1933),
    [anon_sym_operator] = ACTIONS(1933),
    [anon_sym_try] = ACTIONS(1933),
    [anon_sym_delete] = ACTIONS(1933),
    [anon_sym_throw] = ACTIONS(1933),
    [anon_sym_namespace] = ACTIONS(1933),
    [anon_sym_using] = ACTIONS(1933),
    [anon_sym_static_assert] = ACTIONS(1933),
    [anon_sym_concept] = ACTIONS(1933),
    [anon_sym_co_return] = ACTIONS(1933),
    [anon_sym_co_yield] = ACTIONS(1933),
    [anon_sym_R_DQUOTE] = ACTIONS(1935),
    [anon_sym_LR_DQUOTE] = ACTIONS(1935),
    [anon_sym_uR_DQUOTE] = ACTIONS(1935),
    [anon_sym_UR_DQUOTE] = ACTIONS(1935),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1935),
    [anon_sym_co_await] = ACTIONS(1933),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_requires] = ACTIONS(1933),
    [sym_this] = ACTIONS(1933),
    [anon_sym_discard] = ACTIONS(1933),
    [anon_sym_precise] = ACTIONS(1933),
    [anon_sym_shared] = ACTIONS(1933),
    [anon_sym_groupshared] = ACTIONS(1933),
    [anon_sym_uniform] = ACTIONS(1933),
    [anon_sym_row_major] = ACTIONS(1933),
    [anon_sym_column_major] = ACTIONS(1933),
    [anon_sym_globallycoherent] = ACTIONS(1933),
    [anon_sym_centroid] = ACTIONS(1933),
    [anon_sym_noperspective] = ACTIONS(1933),
    [anon_sym_nointerpolation] = ACTIONS(1933),
    [anon_sym_sample] = ACTIONS(1933),
    [anon_sym_linear] = ACTIONS(1933),
    [anon_sym_snorm] = ACTIONS(1933),
    [anon_sym_unorm] = ACTIONS(1933),
    [anon_sym_point] = ACTIONS(1933),
    [anon_sym_line] = ACTIONS(1933),
    [anon_sym_triangleadj] = ACTIONS(1933),
    [anon_sym_lineadj] = ACTIONS(1933),
    [anon_sym_triangle] = ACTIONS(1933),
    [anon_sym_cbuffer] = ACTIONS(1933),
  },
  [174] = {
    [sym_template_argument_list] = STATE(324),
    [ts_builtin_sym_end] = ACTIONS(1935),
    [sym_identifier] = ACTIONS(1933),
    [aux_sym_preproc_include_token1] = ACTIONS(1933),
    [aux_sym_preproc_def_token1] = ACTIONS(1933),
    [aux_sym_preproc_if_token1] = ACTIONS(1933),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1933),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1933),
    [sym_preproc_directive] = ACTIONS(1933),
    [anon_sym_LPAREN2] = ACTIONS(1935),
    [anon_sym_BANG] = ACTIONS(1935),
    [anon_sym_TILDE] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1933),
    [anon_sym_PLUS] = ACTIONS(1933),
    [anon_sym_STAR] = ACTIONS(1935),
    [anon_sym_AMP_AMP] = ACTIONS(1935),
    [anon_sym_AMP] = ACTIONS(1933),
    [anon_sym_LT] = ACTIONS(2016),
    [anon_sym_COLON] = ACTIONS(1933),
    [anon_sym_SEMI] = ACTIONS(1935),
    [anon_sym___extension__] = ACTIONS(1933),
    [anon_sym_typedef] = ACTIONS(1933),
    [anon_sym_in] = ACTIONS(1933),
    [anon_sym_out] = ACTIONS(1933),
    [anon_sym_inout] = ACTIONS(1933),
    [anon_sym_extern] = ACTIONS(1933),
    [anon_sym___attribute__] = ACTIONS(1933),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1935),
    [anon_sym___declspec] = ACTIONS(1933),
    [anon_sym___based] = ACTIONS(1933),
    [anon_sym___cdecl] = ACTIONS(1933),
    [anon_sym___clrcall] = ACTIONS(1933),
    [anon_sym___stdcall] = ACTIONS(1933),
    [anon_sym___fastcall] = ACTIONS(1933),
    [anon_sym___thiscall] = ACTIONS(1933),
    [anon_sym___vectorcall] = ACTIONS(1933),
    [anon_sym_LBRACE] = ACTIONS(1935),
    [anon_sym_signed] = ACTIONS(1933),
    [anon_sym_unsigned] = ACTIONS(1933),
    [anon_sym_long] = ACTIONS(1933),
    [anon_sym_short] = ACTIONS(1933),
    [anon_sym_LBRACK] = ACTIONS(1933),
    [anon_sym_static] = ACTIONS(1933),
    [anon_sym_register] = ACTIONS(1933),
    [anon_sym_inline] = ACTIONS(1933),
    [anon_sym___inline] = ACTIONS(1933),
    [anon_sym___inline__] = ACTIONS(1933),
    [anon_sym___forceinline] = ACTIONS(1933),
    [anon_sym_thread_local] = ACTIONS(1933),
    [anon_sym___thread] = ACTIONS(1933),
    [anon_sym_const] = ACTIONS(1933),
    [anon_sym_constexpr] = ACTIONS(1933),
    [anon_sym_volatile] = ACTIONS(1933),
    [anon_sym_restrict] = ACTIONS(1933),
    [anon_sym___restrict__] = ACTIONS(1933),
    [anon_sym__Atomic] = ACTIONS(1933),
    [anon_sym__Noreturn] = ACTIONS(1933),
    [anon_sym_noreturn] = ACTIONS(1933),
    [anon_sym_mutable] = ACTIONS(1933),
    [anon_sym_constinit] = ACTIONS(1933),
    [anon_sym_consteval] = ACTIONS(1933),
    [anon_sym_alignas] = ACTIONS(1933),
    [anon_sym__Alignas] = ACTIONS(1933),
    [sym_primitive_type] = ACTIONS(1933),
    [anon_sym_enum] = ACTIONS(1933),
    [anon_sym_class] = ACTIONS(1933),
    [anon_sym_struct] = ACTIONS(1933),
    [anon_sym_union] = ACTIONS(1933),
    [anon_sym_if] = ACTIONS(1933),
    [anon_sym_else] = ACTIONS(1933),
    [anon_sym_switch] = ACTIONS(1933),
    [anon_sym_case] = ACTIONS(1933),
    [anon_sym_default] = ACTIONS(1933),
    [anon_sym_while] = ACTIONS(1933),
    [anon_sym_do] = ACTIONS(1933),
    [anon_sym_for] = ACTIONS(1933),
    [anon_sym_return] = ACTIONS(1933),
    [anon_sym_break] = ACTIONS(1933),
    [anon_sym_continue] = ACTIONS(1933),
    [anon_sym_goto] = ACTIONS(1933),
    [anon_sym___try] = ACTIONS(1933),
    [anon_sym___leave] = ACTIONS(1933),
    [anon_sym_not] = ACTIONS(1933),
    [anon_sym_compl] = ACTIONS(1933),
    [anon_sym_DASH_DASH] = ACTIONS(1935),
    [anon_sym_PLUS_PLUS] = ACTIONS(1935),
    [anon_sym_sizeof] = ACTIONS(1933),
    [anon_sym___alignof__] = ACTIONS(1933),
    [anon_sym___alignof] = ACTIONS(1933),
    [anon_sym__alignof] = ACTIONS(1933),
    [anon_sym_alignof] = ACTIONS(1933),
    [anon_sym__Alignof] = ACTIONS(1933),
    [anon_sym_offsetof] = ACTIONS(1933),
    [anon_sym__Generic] = ACTIONS(1933),
    [anon_sym_asm] = ACTIONS(1933),
    [anon_sym___asm__] = ACTIONS(1933),
    [sym_number_literal] = ACTIONS(1935),
    [anon_sym_L_SQUOTE] = ACTIONS(1935),
    [anon_sym_u_SQUOTE] = ACTIONS(1935),
    [anon_sym_U_SQUOTE] = ACTIONS(1935),
    [anon_sym_u8_SQUOTE] = ACTIONS(1935),
    [anon_sym_SQUOTE] = ACTIONS(1935),
    [anon_sym_L_DQUOTE] = ACTIONS(1935),
    [anon_sym_u_DQUOTE] = ACTIONS(1935),
    [anon_sym_U_DQUOTE] = ACTIONS(1935),
    [anon_sym_u8_DQUOTE] = ACTIONS(1935),
    [anon_sym_DQUOTE] = ACTIONS(1935),
    [sym_true] = ACTIONS(1933),
    [sym_false] = ACTIONS(1933),
    [anon_sym_NULL] = ACTIONS(1933),
    [anon_sym_nullptr] = ACTIONS(1933),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1933),
    [anon_sym_decltype] = ACTIONS(1933),
    [anon_sym_final] = ACTIONS(1933),
    [anon_sym_override] = ACTIONS(1933),
    [sym_virtual] = ACTIONS(1933),
    [anon_sym_explicit] = ACTIONS(1933),
    [anon_sym_typename] = ACTIONS(1933),
    [anon_sym_template] = ACTIONS(1933),
    [anon_sym_operator] = ACTIONS(1933),
    [anon_sym_try] = ACTIONS(1933),
    [anon_sym_delete] = ACTIONS(1933),
    [anon_sym_throw] = ACTIONS(1933),
    [anon_sym_namespace] = ACTIONS(1933),
    [anon_sym_using] = ACTIONS(1933),
    [anon_sym_static_assert] = ACTIONS(1933),
    [anon_sym_concept] = ACTIONS(1933),
    [anon_sym_co_return] = ACTIONS(1933),
    [anon_sym_co_yield] = ACTIONS(1933),
    [anon_sym_R_DQUOTE] = ACTIONS(1935),
    [anon_sym_LR_DQUOTE] = ACTIONS(1935),
    [anon_sym_uR_DQUOTE] = ACTIONS(1935),
    [anon_sym_UR_DQUOTE] = ACTIONS(1935),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1935),
    [anon_sym_co_await] = ACTIONS(1933),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_requires] = ACTIONS(1933),
    [sym_this] = ACTIONS(1933),
    [anon_sym_discard] = ACTIONS(1933),
    [anon_sym_precise] = ACTIONS(1933),
    [anon_sym_shared] = ACTIONS(1933),
    [anon_sym_groupshared] = ACTIONS(1933),
    [anon_sym_uniform] = ACTIONS(1933),
    [anon_sym_row_major] = ACTIONS(1933),
    [anon_sym_column_major] = ACTIONS(1933),
    [anon_sym_globallycoherent] = ACTIONS(1933),
    [anon_sym_centroid] = ACTIONS(1933),
    [anon_sym_noperspective] = ACTIONS(1933),
    [anon_sym_nointerpolation] = ACTIONS(1933),
    [anon_sym_sample] = ACTIONS(1933),
    [anon_sym_linear] = ACTIONS(1933),
    [anon_sym_snorm] = ACTIONS(1933),
    [anon_sym_unorm] = ACTIONS(1933),
    [anon_sym_point] = ACTIONS(1933),
    [anon_sym_line] = ACTIONS(1933),
    [anon_sym_triangleadj] = ACTIONS(1933),
    [anon_sym_lineadj] = ACTIONS(1933),
    [anon_sym_triangle] = ACTIONS(1933),
    [anon_sym_cbuffer] = ACTIONS(1933),
  },
  [175] = {
    [sym_template_argument_list] = STATE(324),
    [ts_builtin_sym_end] = ACTIONS(1943),
    [sym_identifier] = ACTIONS(1941),
    [aux_sym_preproc_include_token1] = ACTIONS(1941),
    [aux_sym_preproc_def_token1] = ACTIONS(1941),
    [aux_sym_preproc_if_token1] = ACTIONS(1941),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1941),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1941),
    [sym_preproc_directive] = ACTIONS(1941),
    [anon_sym_LPAREN2] = ACTIONS(1943),
    [anon_sym_BANG] = ACTIONS(1943),
    [anon_sym_TILDE] = ACTIONS(1943),
    [anon_sym_DASH] = ACTIONS(1941),
    [anon_sym_PLUS] = ACTIONS(1941),
    [anon_sym_STAR] = ACTIONS(1943),
    [anon_sym_AMP_AMP] = ACTIONS(1943),
    [anon_sym_AMP] = ACTIONS(1941),
    [anon_sym_LT] = ACTIONS(2016),
    [anon_sym_COLON] = ACTIONS(1941),
    [anon_sym_SEMI] = ACTIONS(1943),
    [anon_sym___extension__] = ACTIONS(1941),
    [anon_sym_typedef] = ACTIONS(1941),
    [anon_sym_in] = ACTIONS(1941),
    [anon_sym_out] = ACTIONS(1941),
    [anon_sym_inout] = ACTIONS(1941),
    [anon_sym_extern] = ACTIONS(1941),
    [anon_sym___attribute__] = ACTIONS(1941),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1943),
    [anon_sym___declspec] = ACTIONS(1941),
    [anon_sym___based] = ACTIONS(1941),
    [anon_sym___cdecl] = ACTIONS(1941),
    [anon_sym___clrcall] = ACTIONS(1941),
    [anon_sym___stdcall] = ACTIONS(1941),
    [anon_sym___fastcall] = ACTIONS(1941),
    [anon_sym___thiscall] = ACTIONS(1941),
    [anon_sym___vectorcall] = ACTIONS(1941),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_signed] = ACTIONS(1941),
    [anon_sym_unsigned] = ACTIONS(1941),
    [anon_sym_long] = ACTIONS(1941),
    [anon_sym_short] = ACTIONS(1941),
    [anon_sym_LBRACK] = ACTIONS(1941),
    [anon_sym_static] = ACTIONS(1941),
    [anon_sym_register] = ACTIONS(1941),
    [anon_sym_inline] = ACTIONS(1941),
    [anon_sym___inline] = ACTIONS(1941),
    [anon_sym___inline__] = ACTIONS(1941),
    [anon_sym___forceinline] = ACTIONS(1941),
    [anon_sym_thread_local] = ACTIONS(1941),
    [anon_sym___thread] = ACTIONS(1941),
    [anon_sym_const] = ACTIONS(1941),
    [anon_sym_constexpr] = ACTIONS(1941),
    [anon_sym_volatile] = ACTIONS(1941),
    [anon_sym_restrict] = ACTIONS(1941),
    [anon_sym___restrict__] = ACTIONS(1941),
    [anon_sym__Atomic] = ACTIONS(1941),
    [anon_sym__Noreturn] = ACTIONS(1941),
    [anon_sym_noreturn] = ACTIONS(1941),
    [anon_sym_mutable] = ACTIONS(1941),
    [anon_sym_constinit] = ACTIONS(1941),
    [anon_sym_consteval] = ACTIONS(1941),
    [anon_sym_alignas] = ACTIONS(1941),
    [anon_sym__Alignas] = ACTIONS(1941),
    [sym_primitive_type] = ACTIONS(1941),
    [anon_sym_enum] = ACTIONS(1941),
    [anon_sym_class] = ACTIONS(1941),
    [anon_sym_struct] = ACTIONS(1941),
    [anon_sym_union] = ACTIONS(1941),
    [anon_sym_if] = ACTIONS(1941),
    [anon_sym_else] = ACTIONS(1941),
    [anon_sym_switch] = ACTIONS(1941),
    [anon_sym_case] = ACTIONS(1941),
    [anon_sym_default] = ACTIONS(1941),
    [anon_sym_while] = ACTIONS(1941),
    [anon_sym_do] = ACTIONS(1941),
    [anon_sym_for] = ACTIONS(1941),
    [anon_sym_return] = ACTIONS(1941),
    [anon_sym_break] = ACTIONS(1941),
    [anon_sym_continue] = ACTIONS(1941),
    [anon_sym_goto] = ACTIONS(1941),
    [anon_sym___try] = ACTIONS(1941),
    [anon_sym___leave] = ACTIONS(1941),
    [anon_sym_not] = ACTIONS(1941),
    [anon_sym_compl] = ACTIONS(1941),
    [anon_sym_DASH_DASH] = ACTIONS(1943),
    [anon_sym_PLUS_PLUS] = ACTIONS(1943),
    [anon_sym_sizeof] = ACTIONS(1941),
    [anon_sym___alignof__] = ACTIONS(1941),
    [anon_sym___alignof] = ACTIONS(1941),
    [anon_sym__alignof] = ACTIONS(1941),
    [anon_sym_alignof] = ACTIONS(1941),
    [anon_sym__Alignof] = ACTIONS(1941),
    [anon_sym_offsetof] = ACTIONS(1941),
    [anon_sym__Generic] = ACTIONS(1941),
    [anon_sym_asm] = ACTIONS(1941),
    [anon_sym___asm__] = ACTIONS(1941),
    [sym_number_literal] = ACTIONS(1943),
    [anon_sym_L_SQUOTE] = ACTIONS(1943),
    [anon_sym_u_SQUOTE] = ACTIONS(1943),
    [anon_sym_U_SQUOTE] = ACTIONS(1943),
    [anon_sym_u8_SQUOTE] = ACTIONS(1943),
    [anon_sym_SQUOTE] = ACTIONS(1943),
    [anon_sym_L_DQUOTE] = ACTIONS(1943),
    [anon_sym_u_DQUOTE] = ACTIONS(1943),
    [anon_sym_U_DQUOTE] = ACTIONS(1943),
    [anon_sym_u8_DQUOTE] = ACTIONS(1943),
    [anon_sym_DQUOTE] = ACTIONS(1943),
    [sym_true] = ACTIONS(1941),
    [sym_false] = ACTIONS(1941),
    [anon_sym_NULL] = ACTIONS(1941),
    [anon_sym_nullptr] = ACTIONS(1941),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1941),
    [anon_sym_decltype] = ACTIONS(1941),
    [anon_sym_final] = ACTIONS(1941),
    [anon_sym_override] = ACTIONS(1941),
    [sym_virtual] = ACTIONS(1941),
    [anon_sym_explicit] = ACTIONS(1941),
    [anon_sym_typename] = ACTIONS(1941),
    [anon_sym_template] = ACTIONS(1941),
    [anon_sym_operator] = ACTIONS(1941),
    [anon_sym_try] = ACTIONS(1941),
    [anon_sym_delete] = ACTIONS(1941),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_namespace] = ACTIONS(1941),
    [anon_sym_using] = ACTIONS(1941),
    [anon_sym_static_assert] = ACTIONS(1941),
    [anon_sym_concept] = ACTIONS(1941),
    [anon_sym_co_return] = ACTIONS(1941),
    [anon_sym_co_yield] = ACTIONS(1941),
    [anon_sym_R_DQUOTE] = ACTIONS(1943),
    [anon_sym_LR_DQUOTE] = ACTIONS(1943),
    [anon_sym_uR_DQUOTE] = ACTIONS(1943),
    [anon_sym_UR_DQUOTE] = ACTIONS(1943),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1943),
    [anon_sym_co_await] = ACTIONS(1941),
    [anon_sym_new] = ACTIONS(1941),
    [anon_sym_requires] = ACTIONS(1941),
    [sym_this] = ACTIONS(1941),
    [anon_sym_discard] = ACTIONS(1941),
    [anon_sym_precise] = ACTIONS(1941),
    [anon_sym_shared] = ACTIONS(1941),
    [anon_sym_groupshared] = ACTIONS(1941),
    [anon_sym_uniform] = ACTIONS(1941),
    [anon_sym_row_major] = ACTIONS(1941),
    [anon_sym_column_major] = ACTIONS(1941),
    [anon_sym_globallycoherent] = ACTIONS(1941),
    [anon_sym_centroid] = ACTIONS(1941),
    [anon_sym_noperspective] = ACTIONS(1941),
    [anon_sym_nointerpolation] = ACTIONS(1941),
    [anon_sym_sample] = ACTIONS(1941),
    [anon_sym_linear] = ACTIONS(1941),
    [anon_sym_snorm] = ACTIONS(1941),
    [anon_sym_unorm] = ACTIONS(1941),
    [anon_sym_point] = ACTIONS(1941),
    [anon_sym_line] = ACTIONS(1941),
    [anon_sym_triangleadj] = ACTIONS(1941),
    [anon_sym_lineadj] = ACTIONS(1941),
    [anon_sym_triangle] = ACTIONS(1941),
    [anon_sym_cbuffer] = ACTIONS(1941),
  },
  [176] = {
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(5254),
    [sym__declarator] = STATE(6515),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6270),
    [sym_array_declarator] = STATE(6270),
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3112),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8573),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(8572),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3415),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8570),
    [sym__unary_right_fold] = STATE(8567),
    [sym__binary_fold] = STATE(8566),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5594),
    [sym_qualified_identifier] = STATE(3419),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8565),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(2018),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(2028),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2030),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(2034),
    [anon_sym___clrcall] = ACTIONS(2034),
    [anon_sym___stdcall] = ACTIONS(2034),
    [anon_sym___fastcall] = ACTIONS(2034),
    [anon_sym___thiscall] = ACTIONS(2034),
    [anon_sym___vectorcall] = ACTIONS(2034),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(2038),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(2078),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [177] = {
    [sym_identifier] = ACTIONS(2090),
    [aux_sym_preproc_include_token1] = ACTIONS(2090),
    [aux_sym_preproc_def_token1] = ACTIONS(2090),
    [aux_sym_preproc_if_token1] = ACTIONS(2090),
    [aux_sym_preproc_if_token2] = ACTIONS(2090),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2090),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2090),
    [aux_sym_preproc_else_token1] = ACTIONS(2090),
    [aux_sym_preproc_elif_token1] = ACTIONS(2090),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2090),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2090),
    [sym_preproc_directive] = ACTIONS(2090),
    [anon_sym_LPAREN2] = ACTIONS(2092),
    [anon_sym_BANG] = ACTIONS(2092),
    [anon_sym_TILDE] = ACTIONS(2092),
    [anon_sym_DASH] = ACTIONS(2090),
    [anon_sym_PLUS] = ACTIONS(2090),
    [anon_sym_STAR] = ACTIONS(2092),
    [anon_sym_AMP_AMP] = ACTIONS(2092),
    [anon_sym_AMP] = ACTIONS(2090),
    [anon_sym_SEMI] = ACTIONS(2092),
    [anon_sym___extension__] = ACTIONS(2090),
    [anon_sym_typedef] = ACTIONS(2090),
    [anon_sym_in] = ACTIONS(2090),
    [anon_sym_out] = ACTIONS(2090),
    [anon_sym_inout] = ACTIONS(2090),
    [anon_sym_extern] = ACTIONS(2090),
    [anon_sym___attribute__] = ACTIONS(2090),
    [anon_sym_COLON_COLON] = ACTIONS(2092),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2092),
    [anon_sym___declspec] = ACTIONS(2090),
    [anon_sym___based] = ACTIONS(2090),
    [anon_sym___cdecl] = ACTIONS(2090),
    [anon_sym___clrcall] = ACTIONS(2090),
    [anon_sym___stdcall] = ACTIONS(2090),
    [anon_sym___fastcall] = ACTIONS(2090),
    [anon_sym___thiscall] = ACTIONS(2090),
    [anon_sym___vectorcall] = ACTIONS(2090),
    [anon_sym_LBRACE] = ACTIONS(2092),
    [anon_sym_signed] = ACTIONS(2090),
    [anon_sym_unsigned] = ACTIONS(2090),
    [anon_sym_long] = ACTIONS(2090),
    [anon_sym_short] = ACTIONS(2090),
    [anon_sym_LBRACK] = ACTIONS(2090),
    [anon_sym_static] = ACTIONS(2090),
    [anon_sym_register] = ACTIONS(2090),
    [anon_sym_inline] = ACTIONS(2090),
    [anon_sym___inline] = ACTIONS(2090),
    [anon_sym___inline__] = ACTIONS(2090),
    [anon_sym___forceinline] = ACTIONS(2090),
    [anon_sym_thread_local] = ACTIONS(2090),
    [anon_sym___thread] = ACTIONS(2090),
    [anon_sym_const] = ACTIONS(2090),
    [anon_sym_constexpr] = ACTIONS(2090),
    [anon_sym_volatile] = ACTIONS(2090),
    [anon_sym_restrict] = ACTIONS(2090),
    [anon_sym___restrict__] = ACTIONS(2090),
    [anon_sym__Atomic] = ACTIONS(2090),
    [anon_sym__Noreturn] = ACTIONS(2090),
    [anon_sym_noreturn] = ACTIONS(2090),
    [anon_sym_mutable] = ACTIONS(2090),
    [anon_sym_constinit] = ACTIONS(2090),
    [anon_sym_consteval] = ACTIONS(2090),
    [anon_sym_alignas] = ACTIONS(2090),
    [anon_sym__Alignas] = ACTIONS(2090),
    [sym_primitive_type] = ACTIONS(2090),
    [anon_sym_enum] = ACTIONS(2090),
    [anon_sym_class] = ACTIONS(2090),
    [anon_sym_struct] = ACTIONS(2090),
    [anon_sym_union] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(2090),
    [anon_sym_else] = ACTIONS(2090),
    [anon_sym_switch] = ACTIONS(2090),
    [anon_sym_case] = ACTIONS(2090),
    [anon_sym_default] = ACTIONS(2090),
    [anon_sym_while] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(2090),
    [anon_sym_for] = ACTIONS(2090),
    [anon_sym_return] = ACTIONS(2090),
    [anon_sym_break] = ACTIONS(2090),
    [anon_sym_continue] = ACTIONS(2090),
    [anon_sym_goto] = ACTIONS(2090),
    [anon_sym___try] = ACTIONS(2090),
    [anon_sym___leave] = ACTIONS(2090),
    [anon_sym_not] = ACTIONS(2090),
    [anon_sym_compl] = ACTIONS(2090),
    [anon_sym_DASH_DASH] = ACTIONS(2092),
    [anon_sym_PLUS_PLUS] = ACTIONS(2092),
    [anon_sym_sizeof] = ACTIONS(2090),
    [anon_sym___alignof__] = ACTIONS(2090),
    [anon_sym___alignof] = ACTIONS(2090),
    [anon_sym__alignof] = ACTIONS(2090),
    [anon_sym_alignof] = ACTIONS(2090),
    [anon_sym__Alignof] = ACTIONS(2090),
    [anon_sym_offsetof] = ACTIONS(2090),
    [anon_sym__Generic] = ACTIONS(2090),
    [anon_sym_asm] = ACTIONS(2090),
    [anon_sym___asm__] = ACTIONS(2090),
    [sym_number_literal] = ACTIONS(2092),
    [anon_sym_L_SQUOTE] = ACTIONS(2092),
    [anon_sym_u_SQUOTE] = ACTIONS(2092),
    [anon_sym_U_SQUOTE] = ACTIONS(2092),
    [anon_sym_u8_SQUOTE] = ACTIONS(2092),
    [anon_sym_SQUOTE] = ACTIONS(2092),
    [anon_sym_L_DQUOTE] = ACTIONS(2092),
    [anon_sym_u_DQUOTE] = ACTIONS(2092),
    [anon_sym_U_DQUOTE] = ACTIONS(2092),
    [anon_sym_u8_DQUOTE] = ACTIONS(2092),
    [anon_sym_DQUOTE] = ACTIONS(2092),
    [sym_true] = ACTIONS(2090),
    [sym_false] = ACTIONS(2090),
    [anon_sym_NULL] = ACTIONS(2090),
    [anon_sym_nullptr] = ACTIONS(2090),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2090),
    [anon_sym_decltype] = ACTIONS(2090),
    [sym_virtual] = ACTIONS(2090),
    [anon_sym_explicit] = ACTIONS(2090),
    [anon_sym_typename] = ACTIONS(2090),
    [anon_sym_template] = ACTIONS(2090),
    [anon_sym_operator] = ACTIONS(2090),
    [anon_sym_try] = ACTIONS(2090),
    [anon_sym_delete] = ACTIONS(2090),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_namespace] = ACTIONS(2090),
    [anon_sym_using] = ACTIONS(2090),
    [anon_sym_static_assert] = ACTIONS(2090),
    [anon_sym_concept] = ACTIONS(2090),
    [anon_sym_co_return] = ACTIONS(2090),
    [anon_sym_co_yield] = ACTIONS(2090),
    [anon_sym_R_DQUOTE] = ACTIONS(2092),
    [anon_sym_LR_DQUOTE] = ACTIONS(2092),
    [anon_sym_uR_DQUOTE] = ACTIONS(2092),
    [anon_sym_UR_DQUOTE] = ACTIONS(2092),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2092),
    [anon_sym_co_await] = ACTIONS(2090),
    [anon_sym_new] = ACTIONS(2090),
    [anon_sym_requires] = ACTIONS(2090),
    [sym_this] = ACTIONS(2090),
    [anon_sym_discard] = ACTIONS(2090),
    [anon_sym_precise] = ACTIONS(2090),
    [anon_sym_shared] = ACTIONS(2090),
    [anon_sym_groupshared] = ACTIONS(2090),
    [anon_sym_uniform] = ACTIONS(2090),
    [anon_sym_row_major] = ACTIONS(2090),
    [anon_sym_column_major] = ACTIONS(2090),
    [anon_sym_globallycoherent] = ACTIONS(2090),
    [anon_sym_centroid] = ACTIONS(2090),
    [anon_sym_noperspective] = ACTIONS(2090),
    [anon_sym_nointerpolation] = ACTIONS(2090),
    [anon_sym_sample] = ACTIONS(2090),
    [anon_sym_linear] = ACTIONS(2090),
    [anon_sym_snorm] = ACTIONS(2090),
    [anon_sym_unorm] = ACTIONS(2090),
    [anon_sym_point] = ACTIONS(2090),
    [anon_sym_line] = ACTIONS(2090),
    [anon_sym_triangleadj] = ACTIONS(2090),
    [anon_sym_lineadj] = ACTIONS(2090),
    [anon_sym_triangle] = ACTIONS(2090),
    [anon_sym_cbuffer] = ACTIONS(2090),
  },
  [178] = {
    [sym_identifier] = ACTIONS(2094),
    [aux_sym_preproc_include_token1] = ACTIONS(2094),
    [aux_sym_preproc_def_token1] = ACTIONS(2094),
    [aux_sym_preproc_if_token1] = ACTIONS(2094),
    [aux_sym_preproc_if_token2] = ACTIONS(2094),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2094),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2094),
    [aux_sym_preproc_else_token1] = ACTIONS(2094),
    [aux_sym_preproc_elif_token1] = ACTIONS(2094),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2094),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2094),
    [sym_preproc_directive] = ACTIONS(2094),
    [anon_sym_LPAREN2] = ACTIONS(2096),
    [anon_sym_BANG] = ACTIONS(2096),
    [anon_sym_TILDE] = ACTIONS(2096),
    [anon_sym_DASH] = ACTIONS(2094),
    [anon_sym_PLUS] = ACTIONS(2094),
    [anon_sym_STAR] = ACTIONS(2096),
    [anon_sym_AMP_AMP] = ACTIONS(2096),
    [anon_sym_AMP] = ACTIONS(2094),
    [anon_sym_SEMI] = ACTIONS(2096),
    [anon_sym___extension__] = ACTIONS(2094),
    [anon_sym_typedef] = ACTIONS(2094),
    [anon_sym_in] = ACTIONS(2094),
    [anon_sym_out] = ACTIONS(2094),
    [anon_sym_inout] = ACTIONS(2094),
    [anon_sym_extern] = ACTIONS(2094),
    [anon_sym___attribute__] = ACTIONS(2094),
    [anon_sym_COLON_COLON] = ACTIONS(2096),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2096),
    [anon_sym___declspec] = ACTIONS(2094),
    [anon_sym___based] = ACTIONS(2094),
    [anon_sym___cdecl] = ACTIONS(2094),
    [anon_sym___clrcall] = ACTIONS(2094),
    [anon_sym___stdcall] = ACTIONS(2094),
    [anon_sym___fastcall] = ACTIONS(2094),
    [anon_sym___thiscall] = ACTIONS(2094),
    [anon_sym___vectorcall] = ACTIONS(2094),
    [anon_sym_LBRACE] = ACTIONS(2096),
    [anon_sym_signed] = ACTIONS(2094),
    [anon_sym_unsigned] = ACTIONS(2094),
    [anon_sym_long] = ACTIONS(2094),
    [anon_sym_short] = ACTIONS(2094),
    [anon_sym_LBRACK] = ACTIONS(2094),
    [anon_sym_static] = ACTIONS(2094),
    [anon_sym_register] = ACTIONS(2094),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym___inline] = ACTIONS(2094),
    [anon_sym___inline__] = ACTIONS(2094),
    [anon_sym___forceinline] = ACTIONS(2094),
    [anon_sym_thread_local] = ACTIONS(2094),
    [anon_sym___thread] = ACTIONS(2094),
    [anon_sym_const] = ACTIONS(2094),
    [anon_sym_constexpr] = ACTIONS(2094),
    [anon_sym_volatile] = ACTIONS(2094),
    [anon_sym_restrict] = ACTIONS(2094),
    [anon_sym___restrict__] = ACTIONS(2094),
    [anon_sym__Atomic] = ACTIONS(2094),
    [anon_sym__Noreturn] = ACTIONS(2094),
    [anon_sym_noreturn] = ACTIONS(2094),
    [anon_sym_mutable] = ACTIONS(2094),
    [anon_sym_constinit] = ACTIONS(2094),
    [anon_sym_consteval] = ACTIONS(2094),
    [anon_sym_alignas] = ACTIONS(2094),
    [anon_sym__Alignas] = ACTIONS(2094),
    [sym_primitive_type] = ACTIONS(2094),
    [anon_sym_enum] = ACTIONS(2094),
    [anon_sym_class] = ACTIONS(2094),
    [anon_sym_struct] = ACTIONS(2094),
    [anon_sym_union] = ACTIONS(2094),
    [anon_sym_if] = ACTIONS(2094),
    [anon_sym_else] = ACTIONS(2094),
    [anon_sym_switch] = ACTIONS(2094),
    [anon_sym_case] = ACTIONS(2094),
    [anon_sym_default] = ACTIONS(2094),
    [anon_sym_while] = ACTIONS(2094),
    [anon_sym_do] = ACTIONS(2094),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_return] = ACTIONS(2094),
    [anon_sym_break] = ACTIONS(2094),
    [anon_sym_continue] = ACTIONS(2094),
    [anon_sym_goto] = ACTIONS(2094),
    [anon_sym___try] = ACTIONS(2094),
    [anon_sym___leave] = ACTIONS(2094),
    [anon_sym_not] = ACTIONS(2094),
    [anon_sym_compl] = ACTIONS(2094),
    [anon_sym_DASH_DASH] = ACTIONS(2096),
    [anon_sym_PLUS_PLUS] = ACTIONS(2096),
    [anon_sym_sizeof] = ACTIONS(2094),
    [anon_sym___alignof__] = ACTIONS(2094),
    [anon_sym___alignof] = ACTIONS(2094),
    [anon_sym__alignof] = ACTIONS(2094),
    [anon_sym_alignof] = ACTIONS(2094),
    [anon_sym__Alignof] = ACTIONS(2094),
    [anon_sym_offsetof] = ACTIONS(2094),
    [anon_sym__Generic] = ACTIONS(2094),
    [anon_sym_asm] = ACTIONS(2094),
    [anon_sym___asm__] = ACTIONS(2094),
    [sym_number_literal] = ACTIONS(2096),
    [anon_sym_L_SQUOTE] = ACTIONS(2096),
    [anon_sym_u_SQUOTE] = ACTIONS(2096),
    [anon_sym_U_SQUOTE] = ACTIONS(2096),
    [anon_sym_u8_SQUOTE] = ACTIONS(2096),
    [anon_sym_SQUOTE] = ACTIONS(2096),
    [anon_sym_L_DQUOTE] = ACTIONS(2096),
    [anon_sym_u_DQUOTE] = ACTIONS(2096),
    [anon_sym_U_DQUOTE] = ACTIONS(2096),
    [anon_sym_u8_DQUOTE] = ACTIONS(2096),
    [anon_sym_DQUOTE] = ACTIONS(2096),
    [sym_true] = ACTIONS(2094),
    [sym_false] = ACTIONS(2094),
    [anon_sym_NULL] = ACTIONS(2094),
    [anon_sym_nullptr] = ACTIONS(2094),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2094),
    [anon_sym_decltype] = ACTIONS(2094),
    [sym_virtual] = ACTIONS(2094),
    [anon_sym_explicit] = ACTIONS(2094),
    [anon_sym_typename] = ACTIONS(2094),
    [anon_sym_template] = ACTIONS(2094),
    [anon_sym_operator] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2094),
    [anon_sym_delete] = ACTIONS(2094),
    [anon_sym_throw] = ACTIONS(2094),
    [anon_sym_namespace] = ACTIONS(2094),
    [anon_sym_using] = ACTIONS(2094),
    [anon_sym_static_assert] = ACTIONS(2094),
    [anon_sym_concept] = ACTIONS(2094),
    [anon_sym_co_return] = ACTIONS(2094),
    [anon_sym_co_yield] = ACTIONS(2094),
    [anon_sym_R_DQUOTE] = ACTIONS(2096),
    [anon_sym_LR_DQUOTE] = ACTIONS(2096),
    [anon_sym_uR_DQUOTE] = ACTIONS(2096),
    [anon_sym_UR_DQUOTE] = ACTIONS(2096),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2096),
    [anon_sym_co_await] = ACTIONS(2094),
    [anon_sym_new] = ACTIONS(2094),
    [anon_sym_requires] = ACTIONS(2094),
    [sym_this] = ACTIONS(2094),
    [anon_sym_discard] = ACTIONS(2094),
    [anon_sym_precise] = ACTIONS(2094),
    [anon_sym_shared] = ACTIONS(2094),
    [anon_sym_groupshared] = ACTIONS(2094),
    [anon_sym_uniform] = ACTIONS(2094),
    [anon_sym_row_major] = ACTIONS(2094),
    [anon_sym_column_major] = ACTIONS(2094),
    [anon_sym_globallycoherent] = ACTIONS(2094),
    [anon_sym_centroid] = ACTIONS(2094),
    [anon_sym_noperspective] = ACTIONS(2094),
    [anon_sym_nointerpolation] = ACTIONS(2094),
    [anon_sym_sample] = ACTIONS(2094),
    [anon_sym_linear] = ACTIONS(2094),
    [anon_sym_snorm] = ACTIONS(2094),
    [anon_sym_unorm] = ACTIONS(2094),
    [anon_sym_point] = ACTIONS(2094),
    [anon_sym_line] = ACTIONS(2094),
    [anon_sym_triangleadj] = ACTIONS(2094),
    [anon_sym_lineadj] = ACTIONS(2094),
    [anon_sym_triangle] = ACTIONS(2094),
    [anon_sym_cbuffer] = ACTIONS(2094),
  },
  [179] = {
    [sym_identifier] = ACTIONS(2098),
    [aux_sym_preproc_include_token1] = ACTIONS(2098),
    [aux_sym_preproc_def_token1] = ACTIONS(2098),
    [aux_sym_preproc_if_token1] = ACTIONS(2098),
    [aux_sym_preproc_if_token2] = ACTIONS(2098),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2098),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2098),
    [aux_sym_preproc_else_token1] = ACTIONS(2098),
    [aux_sym_preproc_elif_token1] = ACTIONS(2098),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2098),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2098),
    [sym_preproc_directive] = ACTIONS(2098),
    [anon_sym_LPAREN2] = ACTIONS(2100),
    [anon_sym_BANG] = ACTIONS(2100),
    [anon_sym_TILDE] = ACTIONS(2100),
    [anon_sym_DASH] = ACTIONS(2098),
    [anon_sym_PLUS] = ACTIONS(2098),
    [anon_sym_STAR] = ACTIONS(2100),
    [anon_sym_AMP_AMP] = ACTIONS(2100),
    [anon_sym_AMP] = ACTIONS(2098),
    [anon_sym_SEMI] = ACTIONS(2100),
    [anon_sym___extension__] = ACTIONS(2098),
    [anon_sym_typedef] = ACTIONS(2098),
    [anon_sym_in] = ACTIONS(2098),
    [anon_sym_out] = ACTIONS(2098),
    [anon_sym_inout] = ACTIONS(2098),
    [anon_sym_extern] = ACTIONS(2098),
    [anon_sym___attribute__] = ACTIONS(2098),
    [anon_sym_COLON_COLON] = ACTIONS(2100),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2100),
    [anon_sym___declspec] = ACTIONS(2098),
    [anon_sym___based] = ACTIONS(2098),
    [anon_sym___cdecl] = ACTIONS(2098),
    [anon_sym___clrcall] = ACTIONS(2098),
    [anon_sym___stdcall] = ACTIONS(2098),
    [anon_sym___fastcall] = ACTIONS(2098),
    [anon_sym___thiscall] = ACTIONS(2098),
    [anon_sym___vectorcall] = ACTIONS(2098),
    [anon_sym_LBRACE] = ACTIONS(2100),
    [anon_sym_signed] = ACTIONS(2098),
    [anon_sym_unsigned] = ACTIONS(2098),
    [anon_sym_long] = ACTIONS(2098),
    [anon_sym_short] = ACTIONS(2098),
    [anon_sym_LBRACK] = ACTIONS(2098),
    [anon_sym_static] = ACTIONS(2098),
    [anon_sym_register] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(2098),
    [anon_sym___inline] = ACTIONS(2098),
    [anon_sym___inline__] = ACTIONS(2098),
    [anon_sym___forceinline] = ACTIONS(2098),
    [anon_sym_thread_local] = ACTIONS(2098),
    [anon_sym___thread] = ACTIONS(2098),
    [anon_sym_const] = ACTIONS(2098),
    [anon_sym_constexpr] = ACTIONS(2098),
    [anon_sym_volatile] = ACTIONS(2098),
    [anon_sym_restrict] = ACTIONS(2098),
    [anon_sym___restrict__] = ACTIONS(2098),
    [anon_sym__Atomic] = ACTIONS(2098),
    [anon_sym__Noreturn] = ACTIONS(2098),
    [anon_sym_noreturn] = ACTIONS(2098),
    [anon_sym_mutable] = ACTIONS(2098),
    [anon_sym_constinit] = ACTIONS(2098),
    [anon_sym_consteval] = ACTIONS(2098),
    [anon_sym_alignas] = ACTIONS(2098),
    [anon_sym__Alignas] = ACTIONS(2098),
    [sym_primitive_type] = ACTIONS(2098),
    [anon_sym_enum] = ACTIONS(2098),
    [anon_sym_class] = ACTIONS(2098),
    [anon_sym_struct] = ACTIONS(2098),
    [anon_sym_union] = ACTIONS(2098),
    [anon_sym_if] = ACTIONS(2098),
    [anon_sym_else] = ACTIONS(2098),
    [anon_sym_switch] = ACTIONS(2098),
    [anon_sym_case] = ACTIONS(2098),
    [anon_sym_default] = ACTIONS(2098),
    [anon_sym_while] = ACTIONS(2098),
    [anon_sym_do] = ACTIONS(2098),
    [anon_sym_for] = ACTIONS(2098),
    [anon_sym_return] = ACTIONS(2098),
    [anon_sym_break] = ACTIONS(2098),
    [anon_sym_continue] = ACTIONS(2098),
    [anon_sym_goto] = ACTIONS(2098),
    [anon_sym___try] = ACTIONS(2098),
    [anon_sym___leave] = ACTIONS(2098),
    [anon_sym_not] = ACTIONS(2098),
    [anon_sym_compl] = ACTIONS(2098),
    [anon_sym_DASH_DASH] = ACTIONS(2100),
    [anon_sym_PLUS_PLUS] = ACTIONS(2100),
    [anon_sym_sizeof] = ACTIONS(2098),
    [anon_sym___alignof__] = ACTIONS(2098),
    [anon_sym___alignof] = ACTIONS(2098),
    [anon_sym__alignof] = ACTIONS(2098),
    [anon_sym_alignof] = ACTIONS(2098),
    [anon_sym__Alignof] = ACTIONS(2098),
    [anon_sym_offsetof] = ACTIONS(2098),
    [anon_sym__Generic] = ACTIONS(2098),
    [anon_sym_asm] = ACTIONS(2098),
    [anon_sym___asm__] = ACTIONS(2098),
    [sym_number_literal] = ACTIONS(2100),
    [anon_sym_L_SQUOTE] = ACTIONS(2100),
    [anon_sym_u_SQUOTE] = ACTIONS(2100),
    [anon_sym_U_SQUOTE] = ACTIONS(2100),
    [anon_sym_u8_SQUOTE] = ACTIONS(2100),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [anon_sym_L_DQUOTE] = ACTIONS(2100),
    [anon_sym_u_DQUOTE] = ACTIONS(2100),
    [anon_sym_U_DQUOTE] = ACTIONS(2100),
    [anon_sym_u8_DQUOTE] = ACTIONS(2100),
    [anon_sym_DQUOTE] = ACTIONS(2100),
    [sym_true] = ACTIONS(2098),
    [sym_false] = ACTIONS(2098),
    [anon_sym_NULL] = ACTIONS(2098),
    [anon_sym_nullptr] = ACTIONS(2098),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2098),
    [anon_sym_decltype] = ACTIONS(2098),
    [sym_virtual] = ACTIONS(2098),
    [anon_sym_explicit] = ACTIONS(2098),
    [anon_sym_typename] = ACTIONS(2098),
    [anon_sym_template] = ACTIONS(2098),
    [anon_sym_operator] = ACTIONS(2098),
    [anon_sym_try] = ACTIONS(2098),
    [anon_sym_delete] = ACTIONS(2098),
    [anon_sym_throw] = ACTIONS(2098),
    [anon_sym_namespace] = ACTIONS(2098),
    [anon_sym_using] = ACTIONS(2098),
    [anon_sym_static_assert] = ACTIONS(2098),
    [anon_sym_concept] = ACTIONS(2098),
    [anon_sym_co_return] = ACTIONS(2098),
    [anon_sym_co_yield] = ACTIONS(2098),
    [anon_sym_R_DQUOTE] = ACTIONS(2100),
    [anon_sym_LR_DQUOTE] = ACTIONS(2100),
    [anon_sym_uR_DQUOTE] = ACTIONS(2100),
    [anon_sym_UR_DQUOTE] = ACTIONS(2100),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2100),
    [anon_sym_co_await] = ACTIONS(2098),
    [anon_sym_new] = ACTIONS(2098),
    [anon_sym_requires] = ACTIONS(2098),
    [sym_this] = ACTIONS(2098),
    [anon_sym_discard] = ACTIONS(2098),
    [anon_sym_precise] = ACTIONS(2098),
    [anon_sym_shared] = ACTIONS(2098),
    [anon_sym_groupshared] = ACTIONS(2098),
    [anon_sym_uniform] = ACTIONS(2098),
    [anon_sym_row_major] = ACTIONS(2098),
    [anon_sym_column_major] = ACTIONS(2098),
    [anon_sym_globallycoherent] = ACTIONS(2098),
    [anon_sym_centroid] = ACTIONS(2098),
    [anon_sym_noperspective] = ACTIONS(2098),
    [anon_sym_nointerpolation] = ACTIONS(2098),
    [anon_sym_sample] = ACTIONS(2098),
    [anon_sym_linear] = ACTIONS(2098),
    [anon_sym_snorm] = ACTIONS(2098),
    [anon_sym_unorm] = ACTIONS(2098),
    [anon_sym_point] = ACTIONS(2098),
    [anon_sym_line] = ACTIONS(2098),
    [anon_sym_triangleadj] = ACTIONS(2098),
    [anon_sym_lineadj] = ACTIONS(2098),
    [anon_sym_triangle] = ACTIONS(2098),
    [anon_sym_cbuffer] = ACTIONS(2098),
  },
  [180] = {
    [sym_identifier] = ACTIONS(2102),
    [aux_sym_preproc_include_token1] = ACTIONS(2102),
    [aux_sym_preproc_def_token1] = ACTIONS(2102),
    [aux_sym_preproc_if_token1] = ACTIONS(2102),
    [aux_sym_preproc_if_token2] = ACTIONS(2102),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2102),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2102),
    [aux_sym_preproc_else_token1] = ACTIONS(2102),
    [aux_sym_preproc_elif_token1] = ACTIONS(2102),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2102),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2102),
    [sym_preproc_directive] = ACTIONS(2102),
    [anon_sym_LPAREN2] = ACTIONS(2104),
    [anon_sym_BANG] = ACTIONS(2104),
    [anon_sym_TILDE] = ACTIONS(2104),
    [anon_sym_DASH] = ACTIONS(2102),
    [anon_sym_PLUS] = ACTIONS(2102),
    [anon_sym_STAR] = ACTIONS(2104),
    [anon_sym_AMP_AMP] = ACTIONS(2104),
    [anon_sym_AMP] = ACTIONS(2102),
    [anon_sym_SEMI] = ACTIONS(2104),
    [anon_sym___extension__] = ACTIONS(2102),
    [anon_sym_typedef] = ACTIONS(2102),
    [anon_sym_in] = ACTIONS(2102),
    [anon_sym_out] = ACTIONS(2102),
    [anon_sym_inout] = ACTIONS(2102),
    [anon_sym_extern] = ACTIONS(2102),
    [anon_sym___attribute__] = ACTIONS(2102),
    [anon_sym_COLON_COLON] = ACTIONS(2104),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2104),
    [anon_sym___declspec] = ACTIONS(2102),
    [anon_sym___based] = ACTIONS(2102),
    [anon_sym___cdecl] = ACTIONS(2102),
    [anon_sym___clrcall] = ACTIONS(2102),
    [anon_sym___stdcall] = ACTIONS(2102),
    [anon_sym___fastcall] = ACTIONS(2102),
    [anon_sym___thiscall] = ACTIONS(2102),
    [anon_sym___vectorcall] = ACTIONS(2102),
    [anon_sym_LBRACE] = ACTIONS(2104),
    [anon_sym_signed] = ACTIONS(2102),
    [anon_sym_unsigned] = ACTIONS(2102),
    [anon_sym_long] = ACTIONS(2102),
    [anon_sym_short] = ACTIONS(2102),
    [anon_sym_LBRACK] = ACTIONS(2102),
    [anon_sym_static] = ACTIONS(2102),
    [anon_sym_register] = ACTIONS(2102),
    [anon_sym_inline] = ACTIONS(2102),
    [anon_sym___inline] = ACTIONS(2102),
    [anon_sym___inline__] = ACTIONS(2102),
    [anon_sym___forceinline] = ACTIONS(2102),
    [anon_sym_thread_local] = ACTIONS(2102),
    [anon_sym___thread] = ACTIONS(2102),
    [anon_sym_const] = ACTIONS(2102),
    [anon_sym_constexpr] = ACTIONS(2102),
    [anon_sym_volatile] = ACTIONS(2102),
    [anon_sym_restrict] = ACTIONS(2102),
    [anon_sym___restrict__] = ACTIONS(2102),
    [anon_sym__Atomic] = ACTIONS(2102),
    [anon_sym__Noreturn] = ACTIONS(2102),
    [anon_sym_noreturn] = ACTIONS(2102),
    [anon_sym_mutable] = ACTIONS(2102),
    [anon_sym_constinit] = ACTIONS(2102),
    [anon_sym_consteval] = ACTIONS(2102),
    [anon_sym_alignas] = ACTIONS(2102),
    [anon_sym__Alignas] = ACTIONS(2102),
    [sym_primitive_type] = ACTIONS(2102),
    [anon_sym_enum] = ACTIONS(2102),
    [anon_sym_class] = ACTIONS(2102),
    [anon_sym_struct] = ACTIONS(2102),
    [anon_sym_union] = ACTIONS(2102),
    [anon_sym_if] = ACTIONS(2102),
    [anon_sym_else] = ACTIONS(2102),
    [anon_sym_switch] = ACTIONS(2102),
    [anon_sym_case] = ACTIONS(2102),
    [anon_sym_default] = ACTIONS(2102),
    [anon_sym_while] = ACTIONS(2102),
    [anon_sym_do] = ACTIONS(2102),
    [anon_sym_for] = ACTIONS(2102),
    [anon_sym_return] = ACTIONS(2102),
    [anon_sym_break] = ACTIONS(2102),
    [anon_sym_continue] = ACTIONS(2102),
    [anon_sym_goto] = ACTIONS(2102),
    [anon_sym___try] = ACTIONS(2102),
    [anon_sym___leave] = ACTIONS(2102),
    [anon_sym_not] = ACTIONS(2102),
    [anon_sym_compl] = ACTIONS(2102),
    [anon_sym_DASH_DASH] = ACTIONS(2104),
    [anon_sym_PLUS_PLUS] = ACTIONS(2104),
    [anon_sym_sizeof] = ACTIONS(2102),
    [anon_sym___alignof__] = ACTIONS(2102),
    [anon_sym___alignof] = ACTIONS(2102),
    [anon_sym__alignof] = ACTIONS(2102),
    [anon_sym_alignof] = ACTIONS(2102),
    [anon_sym__Alignof] = ACTIONS(2102),
    [anon_sym_offsetof] = ACTIONS(2102),
    [anon_sym__Generic] = ACTIONS(2102),
    [anon_sym_asm] = ACTIONS(2102),
    [anon_sym___asm__] = ACTIONS(2102),
    [sym_number_literal] = ACTIONS(2104),
    [anon_sym_L_SQUOTE] = ACTIONS(2104),
    [anon_sym_u_SQUOTE] = ACTIONS(2104),
    [anon_sym_U_SQUOTE] = ACTIONS(2104),
    [anon_sym_u8_SQUOTE] = ACTIONS(2104),
    [anon_sym_SQUOTE] = ACTIONS(2104),
    [anon_sym_L_DQUOTE] = ACTIONS(2104),
    [anon_sym_u_DQUOTE] = ACTIONS(2104),
    [anon_sym_U_DQUOTE] = ACTIONS(2104),
    [anon_sym_u8_DQUOTE] = ACTIONS(2104),
    [anon_sym_DQUOTE] = ACTIONS(2104),
    [sym_true] = ACTIONS(2102),
    [sym_false] = ACTIONS(2102),
    [anon_sym_NULL] = ACTIONS(2102),
    [anon_sym_nullptr] = ACTIONS(2102),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2102),
    [anon_sym_decltype] = ACTIONS(2102),
    [sym_virtual] = ACTIONS(2102),
    [anon_sym_explicit] = ACTIONS(2102),
    [anon_sym_typename] = ACTIONS(2102),
    [anon_sym_template] = ACTIONS(2102),
    [anon_sym_operator] = ACTIONS(2102),
    [anon_sym_try] = ACTIONS(2102),
    [anon_sym_delete] = ACTIONS(2102),
    [anon_sym_throw] = ACTIONS(2102),
    [anon_sym_namespace] = ACTIONS(2102),
    [anon_sym_using] = ACTIONS(2102),
    [anon_sym_static_assert] = ACTIONS(2102),
    [anon_sym_concept] = ACTIONS(2102),
    [anon_sym_co_return] = ACTIONS(2102),
    [anon_sym_co_yield] = ACTIONS(2102),
    [anon_sym_R_DQUOTE] = ACTIONS(2104),
    [anon_sym_LR_DQUOTE] = ACTIONS(2104),
    [anon_sym_uR_DQUOTE] = ACTIONS(2104),
    [anon_sym_UR_DQUOTE] = ACTIONS(2104),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2104),
    [anon_sym_co_await] = ACTIONS(2102),
    [anon_sym_new] = ACTIONS(2102),
    [anon_sym_requires] = ACTIONS(2102),
    [sym_this] = ACTIONS(2102),
    [anon_sym_discard] = ACTIONS(2102),
    [anon_sym_precise] = ACTIONS(2102),
    [anon_sym_shared] = ACTIONS(2102),
    [anon_sym_groupshared] = ACTIONS(2102),
    [anon_sym_uniform] = ACTIONS(2102),
    [anon_sym_row_major] = ACTIONS(2102),
    [anon_sym_column_major] = ACTIONS(2102),
    [anon_sym_globallycoherent] = ACTIONS(2102),
    [anon_sym_centroid] = ACTIONS(2102),
    [anon_sym_noperspective] = ACTIONS(2102),
    [anon_sym_nointerpolation] = ACTIONS(2102),
    [anon_sym_sample] = ACTIONS(2102),
    [anon_sym_linear] = ACTIONS(2102),
    [anon_sym_snorm] = ACTIONS(2102),
    [anon_sym_unorm] = ACTIONS(2102),
    [anon_sym_point] = ACTIONS(2102),
    [anon_sym_line] = ACTIONS(2102),
    [anon_sym_triangleadj] = ACTIONS(2102),
    [anon_sym_lineadj] = ACTIONS(2102),
    [anon_sym_triangle] = ACTIONS(2102),
    [anon_sym_cbuffer] = ACTIONS(2102),
  },
  [181] = {
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(5254),
    [sym__declarator] = STATE(6515),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6270),
    [sym_array_declarator] = STATE(6270),
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3138),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8453),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(8552),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3415),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8551),
    [sym__unary_right_fold] = STATE(8550),
    [sym__binary_fold] = STATE(8549),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5594),
    [sym_qualified_identifier] = STATE(3419),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8546),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(2018),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(2028),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2030),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(2034),
    [anon_sym___clrcall] = ACTIONS(2034),
    [anon_sym___stdcall] = ACTIONS(2034),
    [anon_sym___fastcall] = ACTIONS(2034),
    [anon_sym___thiscall] = ACTIONS(2034),
    [anon_sym___vectorcall] = ACTIONS(2034),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(2038),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(2078),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [182] = {
    [sym_identifier] = ACTIONS(2106),
    [aux_sym_preproc_include_token1] = ACTIONS(2106),
    [aux_sym_preproc_def_token1] = ACTIONS(2106),
    [aux_sym_preproc_if_token1] = ACTIONS(2106),
    [aux_sym_preproc_if_token2] = ACTIONS(2106),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2106),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2106),
    [aux_sym_preproc_else_token1] = ACTIONS(2106),
    [aux_sym_preproc_elif_token1] = ACTIONS(2106),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2106),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2106),
    [sym_preproc_directive] = ACTIONS(2106),
    [anon_sym_LPAREN2] = ACTIONS(2108),
    [anon_sym_BANG] = ACTIONS(2108),
    [anon_sym_TILDE] = ACTIONS(2108),
    [anon_sym_DASH] = ACTIONS(2106),
    [anon_sym_PLUS] = ACTIONS(2106),
    [anon_sym_STAR] = ACTIONS(2108),
    [anon_sym_AMP_AMP] = ACTIONS(2108),
    [anon_sym_AMP] = ACTIONS(2106),
    [anon_sym_SEMI] = ACTIONS(2108),
    [anon_sym___extension__] = ACTIONS(2106),
    [anon_sym_typedef] = ACTIONS(2106),
    [anon_sym_in] = ACTIONS(2106),
    [anon_sym_out] = ACTIONS(2106),
    [anon_sym_inout] = ACTIONS(2106),
    [anon_sym_extern] = ACTIONS(2106),
    [anon_sym___attribute__] = ACTIONS(2106),
    [anon_sym_COLON_COLON] = ACTIONS(2108),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2108),
    [anon_sym___declspec] = ACTIONS(2106),
    [anon_sym___based] = ACTIONS(2106),
    [anon_sym___cdecl] = ACTIONS(2106),
    [anon_sym___clrcall] = ACTIONS(2106),
    [anon_sym___stdcall] = ACTIONS(2106),
    [anon_sym___fastcall] = ACTIONS(2106),
    [anon_sym___thiscall] = ACTIONS(2106),
    [anon_sym___vectorcall] = ACTIONS(2106),
    [anon_sym_LBRACE] = ACTIONS(2108),
    [anon_sym_signed] = ACTIONS(2106),
    [anon_sym_unsigned] = ACTIONS(2106),
    [anon_sym_long] = ACTIONS(2106),
    [anon_sym_short] = ACTIONS(2106),
    [anon_sym_LBRACK] = ACTIONS(2106),
    [anon_sym_static] = ACTIONS(2106),
    [anon_sym_register] = ACTIONS(2106),
    [anon_sym_inline] = ACTIONS(2106),
    [anon_sym___inline] = ACTIONS(2106),
    [anon_sym___inline__] = ACTIONS(2106),
    [anon_sym___forceinline] = ACTIONS(2106),
    [anon_sym_thread_local] = ACTIONS(2106),
    [anon_sym___thread] = ACTIONS(2106),
    [anon_sym_const] = ACTIONS(2106),
    [anon_sym_constexpr] = ACTIONS(2106),
    [anon_sym_volatile] = ACTIONS(2106),
    [anon_sym_restrict] = ACTIONS(2106),
    [anon_sym___restrict__] = ACTIONS(2106),
    [anon_sym__Atomic] = ACTIONS(2106),
    [anon_sym__Noreturn] = ACTIONS(2106),
    [anon_sym_noreturn] = ACTIONS(2106),
    [anon_sym_mutable] = ACTIONS(2106),
    [anon_sym_constinit] = ACTIONS(2106),
    [anon_sym_consteval] = ACTIONS(2106),
    [anon_sym_alignas] = ACTIONS(2106),
    [anon_sym__Alignas] = ACTIONS(2106),
    [sym_primitive_type] = ACTIONS(2106),
    [anon_sym_enum] = ACTIONS(2106),
    [anon_sym_class] = ACTIONS(2106),
    [anon_sym_struct] = ACTIONS(2106),
    [anon_sym_union] = ACTIONS(2106),
    [anon_sym_if] = ACTIONS(2106),
    [anon_sym_else] = ACTIONS(2106),
    [anon_sym_switch] = ACTIONS(2106),
    [anon_sym_case] = ACTIONS(2106),
    [anon_sym_default] = ACTIONS(2106),
    [anon_sym_while] = ACTIONS(2106),
    [anon_sym_do] = ACTIONS(2106),
    [anon_sym_for] = ACTIONS(2106),
    [anon_sym_return] = ACTIONS(2106),
    [anon_sym_break] = ACTIONS(2106),
    [anon_sym_continue] = ACTIONS(2106),
    [anon_sym_goto] = ACTIONS(2106),
    [anon_sym___try] = ACTIONS(2106),
    [anon_sym___leave] = ACTIONS(2106),
    [anon_sym_not] = ACTIONS(2106),
    [anon_sym_compl] = ACTIONS(2106),
    [anon_sym_DASH_DASH] = ACTIONS(2108),
    [anon_sym_PLUS_PLUS] = ACTIONS(2108),
    [anon_sym_sizeof] = ACTIONS(2106),
    [anon_sym___alignof__] = ACTIONS(2106),
    [anon_sym___alignof] = ACTIONS(2106),
    [anon_sym__alignof] = ACTIONS(2106),
    [anon_sym_alignof] = ACTIONS(2106),
    [anon_sym__Alignof] = ACTIONS(2106),
    [anon_sym_offsetof] = ACTIONS(2106),
    [anon_sym__Generic] = ACTIONS(2106),
    [anon_sym_asm] = ACTIONS(2106),
    [anon_sym___asm__] = ACTIONS(2106),
    [sym_number_literal] = ACTIONS(2108),
    [anon_sym_L_SQUOTE] = ACTIONS(2108),
    [anon_sym_u_SQUOTE] = ACTIONS(2108),
    [anon_sym_U_SQUOTE] = ACTIONS(2108),
    [anon_sym_u8_SQUOTE] = ACTIONS(2108),
    [anon_sym_SQUOTE] = ACTIONS(2108),
    [anon_sym_L_DQUOTE] = ACTIONS(2108),
    [anon_sym_u_DQUOTE] = ACTIONS(2108),
    [anon_sym_U_DQUOTE] = ACTIONS(2108),
    [anon_sym_u8_DQUOTE] = ACTIONS(2108),
    [anon_sym_DQUOTE] = ACTIONS(2108),
    [sym_true] = ACTIONS(2106),
    [sym_false] = ACTIONS(2106),
    [anon_sym_NULL] = ACTIONS(2106),
    [anon_sym_nullptr] = ACTIONS(2106),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2106),
    [anon_sym_decltype] = ACTIONS(2106),
    [sym_virtual] = ACTIONS(2106),
    [anon_sym_explicit] = ACTIONS(2106),
    [anon_sym_typename] = ACTIONS(2106),
    [anon_sym_template] = ACTIONS(2106),
    [anon_sym_operator] = ACTIONS(2106),
    [anon_sym_try] = ACTIONS(2106),
    [anon_sym_delete] = ACTIONS(2106),
    [anon_sym_throw] = ACTIONS(2106),
    [anon_sym_namespace] = ACTIONS(2106),
    [anon_sym_using] = ACTIONS(2106),
    [anon_sym_static_assert] = ACTIONS(2106),
    [anon_sym_concept] = ACTIONS(2106),
    [anon_sym_co_return] = ACTIONS(2106),
    [anon_sym_co_yield] = ACTIONS(2106),
    [anon_sym_R_DQUOTE] = ACTIONS(2108),
    [anon_sym_LR_DQUOTE] = ACTIONS(2108),
    [anon_sym_uR_DQUOTE] = ACTIONS(2108),
    [anon_sym_UR_DQUOTE] = ACTIONS(2108),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2108),
    [anon_sym_co_await] = ACTIONS(2106),
    [anon_sym_new] = ACTIONS(2106),
    [anon_sym_requires] = ACTIONS(2106),
    [sym_this] = ACTIONS(2106),
    [anon_sym_discard] = ACTIONS(2106),
    [anon_sym_precise] = ACTIONS(2106),
    [anon_sym_shared] = ACTIONS(2106),
    [anon_sym_groupshared] = ACTIONS(2106),
    [anon_sym_uniform] = ACTIONS(2106),
    [anon_sym_row_major] = ACTIONS(2106),
    [anon_sym_column_major] = ACTIONS(2106),
    [anon_sym_globallycoherent] = ACTIONS(2106),
    [anon_sym_centroid] = ACTIONS(2106),
    [anon_sym_noperspective] = ACTIONS(2106),
    [anon_sym_nointerpolation] = ACTIONS(2106),
    [anon_sym_sample] = ACTIONS(2106),
    [anon_sym_linear] = ACTIONS(2106),
    [anon_sym_snorm] = ACTIONS(2106),
    [anon_sym_unorm] = ACTIONS(2106),
    [anon_sym_point] = ACTIONS(2106),
    [anon_sym_line] = ACTIONS(2106),
    [anon_sym_triangleadj] = ACTIONS(2106),
    [anon_sym_lineadj] = ACTIONS(2106),
    [anon_sym_triangle] = ACTIONS(2106),
    [anon_sym_cbuffer] = ACTIONS(2106),
  },
  [183] = {
    [sym_identifier] = ACTIONS(2110),
    [aux_sym_preproc_include_token1] = ACTIONS(2110),
    [aux_sym_preproc_def_token1] = ACTIONS(2110),
    [aux_sym_preproc_if_token1] = ACTIONS(2110),
    [aux_sym_preproc_if_token2] = ACTIONS(2110),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2110),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2110),
    [aux_sym_preproc_else_token1] = ACTIONS(2110),
    [aux_sym_preproc_elif_token1] = ACTIONS(2110),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2110),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2110),
    [sym_preproc_directive] = ACTIONS(2110),
    [anon_sym_LPAREN2] = ACTIONS(2112),
    [anon_sym_BANG] = ACTIONS(2112),
    [anon_sym_TILDE] = ACTIONS(2112),
    [anon_sym_DASH] = ACTIONS(2110),
    [anon_sym_PLUS] = ACTIONS(2110),
    [anon_sym_STAR] = ACTIONS(2112),
    [anon_sym_AMP_AMP] = ACTIONS(2112),
    [anon_sym_AMP] = ACTIONS(2110),
    [anon_sym_SEMI] = ACTIONS(2112),
    [anon_sym___extension__] = ACTIONS(2110),
    [anon_sym_typedef] = ACTIONS(2110),
    [anon_sym_in] = ACTIONS(2110),
    [anon_sym_out] = ACTIONS(2110),
    [anon_sym_inout] = ACTIONS(2110),
    [anon_sym_extern] = ACTIONS(2110),
    [anon_sym___attribute__] = ACTIONS(2110),
    [anon_sym_COLON_COLON] = ACTIONS(2112),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2112),
    [anon_sym___declspec] = ACTIONS(2110),
    [anon_sym___based] = ACTIONS(2110),
    [anon_sym___cdecl] = ACTIONS(2110),
    [anon_sym___clrcall] = ACTIONS(2110),
    [anon_sym___stdcall] = ACTIONS(2110),
    [anon_sym___fastcall] = ACTIONS(2110),
    [anon_sym___thiscall] = ACTIONS(2110),
    [anon_sym___vectorcall] = ACTIONS(2110),
    [anon_sym_LBRACE] = ACTIONS(2112),
    [anon_sym_signed] = ACTIONS(2110),
    [anon_sym_unsigned] = ACTIONS(2110),
    [anon_sym_long] = ACTIONS(2110),
    [anon_sym_short] = ACTIONS(2110),
    [anon_sym_LBRACK] = ACTIONS(2110),
    [anon_sym_static] = ACTIONS(2110),
    [anon_sym_register] = ACTIONS(2110),
    [anon_sym_inline] = ACTIONS(2110),
    [anon_sym___inline] = ACTIONS(2110),
    [anon_sym___inline__] = ACTIONS(2110),
    [anon_sym___forceinline] = ACTIONS(2110),
    [anon_sym_thread_local] = ACTIONS(2110),
    [anon_sym___thread] = ACTIONS(2110),
    [anon_sym_const] = ACTIONS(2110),
    [anon_sym_constexpr] = ACTIONS(2110),
    [anon_sym_volatile] = ACTIONS(2110),
    [anon_sym_restrict] = ACTIONS(2110),
    [anon_sym___restrict__] = ACTIONS(2110),
    [anon_sym__Atomic] = ACTIONS(2110),
    [anon_sym__Noreturn] = ACTIONS(2110),
    [anon_sym_noreturn] = ACTIONS(2110),
    [anon_sym_mutable] = ACTIONS(2110),
    [anon_sym_constinit] = ACTIONS(2110),
    [anon_sym_consteval] = ACTIONS(2110),
    [anon_sym_alignas] = ACTIONS(2110),
    [anon_sym__Alignas] = ACTIONS(2110),
    [sym_primitive_type] = ACTIONS(2110),
    [anon_sym_enum] = ACTIONS(2110),
    [anon_sym_class] = ACTIONS(2110),
    [anon_sym_struct] = ACTIONS(2110),
    [anon_sym_union] = ACTIONS(2110),
    [anon_sym_if] = ACTIONS(2110),
    [anon_sym_else] = ACTIONS(2110),
    [anon_sym_switch] = ACTIONS(2110),
    [anon_sym_case] = ACTIONS(2110),
    [anon_sym_default] = ACTIONS(2110),
    [anon_sym_while] = ACTIONS(2110),
    [anon_sym_do] = ACTIONS(2110),
    [anon_sym_for] = ACTIONS(2110),
    [anon_sym_return] = ACTIONS(2110),
    [anon_sym_break] = ACTIONS(2110),
    [anon_sym_continue] = ACTIONS(2110),
    [anon_sym_goto] = ACTIONS(2110),
    [anon_sym___try] = ACTIONS(2110),
    [anon_sym___leave] = ACTIONS(2110),
    [anon_sym_not] = ACTIONS(2110),
    [anon_sym_compl] = ACTIONS(2110),
    [anon_sym_DASH_DASH] = ACTIONS(2112),
    [anon_sym_PLUS_PLUS] = ACTIONS(2112),
    [anon_sym_sizeof] = ACTIONS(2110),
    [anon_sym___alignof__] = ACTIONS(2110),
    [anon_sym___alignof] = ACTIONS(2110),
    [anon_sym__alignof] = ACTIONS(2110),
    [anon_sym_alignof] = ACTIONS(2110),
    [anon_sym__Alignof] = ACTIONS(2110),
    [anon_sym_offsetof] = ACTIONS(2110),
    [anon_sym__Generic] = ACTIONS(2110),
    [anon_sym_asm] = ACTIONS(2110),
    [anon_sym___asm__] = ACTIONS(2110),
    [sym_number_literal] = ACTIONS(2112),
    [anon_sym_L_SQUOTE] = ACTIONS(2112),
    [anon_sym_u_SQUOTE] = ACTIONS(2112),
    [anon_sym_U_SQUOTE] = ACTIONS(2112),
    [anon_sym_u8_SQUOTE] = ACTIONS(2112),
    [anon_sym_SQUOTE] = ACTIONS(2112),
    [anon_sym_L_DQUOTE] = ACTIONS(2112),
    [anon_sym_u_DQUOTE] = ACTIONS(2112),
    [anon_sym_U_DQUOTE] = ACTIONS(2112),
    [anon_sym_u8_DQUOTE] = ACTIONS(2112),
    [anon_sym_DQUOTE] = ACTIONS(2112),
    [sym_true] = ACTIONS(2110),
    [sym_false] = ACTIONS(2110),
    [anon_sym_NULL] = ACTIONS(2110),
    [anon_sym_nullptr] = ACTIONS(2110),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2110),
    [anon_sym_decltype] = ACTIONS(2110),
    [sym_virtual] = ACTIONS(2110),
    [anon_sym_explicit] = ACTIONS(2110),
    [anon_sym_typename] = ACTIONS(2110),
    [anon_sym_template] = ACTIONS(2110),
    [anon_sym_operator] = ACTIONS(2110),
    [anon_sym_try] = ACTIONS(2110),
    [anon_sym_delete] = ACTIONS(2110),
    [anon_sym_throw] = ACTIONS(2110),
    [anon_sym_namespace] = ACTIONS(2110),
    [anon_sym_using] = ACTIONS(2110),
    [anon_sym_static_assert] = ACTIONS(2110),
    [anon_sym_concept] = ACTIONS(2110),
    [anon_sym_co_return] = ACTIONS(2110),
    [anon_sym_co_yield] = ACTIONS(2110),
    [anon_sym_R_DQUOTE] = ACTIONS(2112),
    [anon_sym_LR_DQUOTE] = ACTIONS(2112),
    [anon_sym_uR_DQUOTE] = ACTIONS(2112),
    [anon_sym_UR_DQUOTE] = ACTIONS(2112),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2112),
    [anon_sym_co_await] = ACTIONS(2110),
    [anon_sym_new] = ACTIONS(2110),
    [anon_sym_requires] = ACTIONS(2110),
    [sym_this] = ACTIONS(2110),
    [anon_sym_discard] = ACTIONS(2110),
    [anon_sym_precise] = ACTIONS(2110),
    [anon_sym_shared] = ACTIONS(2110),
    [anon_sym_groupshared] = ACTIONS(2110),
    [anon_sym_uniform] = ACTIONS(2110),
    [anon_sym_row_major] = ACTIONS(2110),
    [anon_sym_column_major] = ACTIONS(2110),
    [anon_sym_globallycoherent] = ACTIONS(2110),
    [anon_sym_centroid] = ACTIONS(2110),
    [anon_sym_noperspective] = ACTIONS(2110),
    [anon_sym_nointerpolation] = ACTIONS(2110),
    [anon_sym_sample] = ACTIONS(2110),
    [anon_sym_linear] = ACTIONS(2110),
    [anon_sym_snorm] = ACTIONS(2110),
    [anon_sym_unorm] = ACTIONS(2110),
    [anon_sym_point] = ACTIONS(2110),
    [anon_sym_line] = ACTIONS(2110),
    [anon_sym_triangleadj] = ACTIONS(2110),
    [anon_sym_lineadj] = ACTIONS(2110),
    [anon_sym_triangle] = ACTIONS(2110),
    [anon_sym_cbuffer] = ACTIONS(2110),
  },
  [184] = {
    [sym_identifier] = ACTIONS(2114),
    [aux_sym_preproc_include_token1] = ACTIONS(2114),
    [aux_sym_preproc_def_token1] = ACTIONS(2114),
    [aux_sym_preproc_if_token1] = ACTIONS(2114),
    [aux_sym_preproc_if_token2] = ACTIONS(2114),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2114),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2114),
    [aux_sym_preproc_else_token1] = ACTIONS(2114),
    [aux_sym_preproc_elif_token1] = ACTIONS(2114),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2114),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2114),
    [sym_preproc_directive] = ACTIONS(2114),
    [anon_sym_LPAREN2] = ACTIONS(2116),
    [anon_sym_BANG] = ACTIONS(2116),
    [anon_sym_TILDE] = ACTIONS(2116),
    [anon_sym_DASH] = ACTIONS(2114),
    [anon_sym_PLUS] = ACTIONS(2114),
    [anon_sym_STAR] = ACTIONS(2116),
    [anon_sym_AMP_AMP] = ACTIONS(2116),
    [anon_sym_AMP] = ACTIONS(2114),
    [anon_sym_SEMI] = ACTIONS(2116),
    [anon_sym___extension__] = ACTIONS(2114),
    [anon_sym_typedef] = ACTIONS(2114),
    [anon_sym_in] = ACTIONS(2114),
    [anon_sym_out] = ACTIONS(2114),
    [anon_sym_inout] = ACTIONS(2114),
    [anon_sym_extern] = ACTIONS(2114),
    [anon_sym___attribute__] = ACTIONS(2114),
    [anon_sym_COLON_COLON] = ACTIONS(2116),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2116),
    [anon_sym___declspec] = ACTIONS(2114),
    [anon_sym___based] = ACTIONS(2114),
    [anon_sym___cdecl] = ACTIONS(2114),
    [anon_sym___clrcall] = ACTIONS(2114),
    [anon_sym___stdcall] = ACTIONS(2114),
    [anon_sym___fastcall] = ACTIONS(2114),
    [anon_sym___thiscall] = ACTIONS(2114),
    [anon_sym___vectorcall] = ACTIONS(2114),
    [anon_sym_LBRACE] = ACTIONS(2116),
    [anon_sym_signed] = ACTIONS(2114),
    [anon_sym_unsigned] = ACTIONS(2114),
    [anon_sym_long] = ACTIONS(2114),
    [anon_sym_short] = ACTIONS(2114),
    [anon_sym_LBRACK] = ACTIONS(2114),
    [anon_sym_static] = ACTIONS(2114),
    [anon_sym_register] = ACTIONS(2114),
    [anon_sym_inline] = ACTIONS(2114),
    [anon_sym___inline] = ACTIONS(2114),
    [anon_sym___inline__] = ACTIONS(2114),
    [anon_sym___forceinline] = ACTIONS(2114),
    [anon_sym_thread_local] = ACTIONS(2114),
    [anon_sym___thread] = ACTIONS(2114),
    [anon_sym_const] = ACTIONS(2114),
    [anon_sym_constexpr] = ACTIONS(2114),
    [anon_sym_volatile] = ACTIONS(2114),
    [anon_sym_restrict] = ACTIONS(2114),
    [anon_sym___restrict__] = ACTIONS(2114),
    [anon_sym__Atomic] = ACTIONS(2114),
    [anon_sym__Noreturn] = ACTIONS(2114),
    [anon_sym_noreturn] = ACTIONS(2114),
    [anon_sym_mutable] = ACTIONS(2114),
    [anon_sym_constinit] = ACTIONS(2114),
    [anon_sym_consteval] = ACTIONS(2114),
    [anon_sym_alignas] = ACTIONS(2114),
    [anon_sym__Alignas] = ACTIONS(2114),
    [sym_primitive_type] = ACTIONS(2114),
    [anon_sym_enum] = ACTIONS(2114),
    [anon_sym_class] = ACTIONS(2114),
    [anon_sym_struct] = ACTIONS(2114),
    [anon_sym_union] = ACTIONS(2114),
    [anon_sym_if] = ACTIONS(2114),
    [anon_sym_else] = ACTIONS(2114),
    [anon_sym_switch] = ACTIONS(2114),
    [anon_sym_case] = ACTIONS(2114),
    [anon_sym_default] = ACTIONS(2114),
    [anon_sym_while] = ACTIONS(2114),
    [anon_sym_do] = ACTIONS(2114),
    [anon_sym_for] = ACTIONS(2114),
    [anon_sym_return] = ACTIONS(2114),
    [anon_sym_break] = ACTIONS(2114),
    [anon_sym_continue] = ACTIONS(2114),
    [anon_sym_goto] = ACTIONS(2114),
    [anon_sym___try] = ACTIONS(2114),
    [anon_sym___leave] = ACTIONS(2114),
    [anon_sym_not] = ACTIONS(2114),
    [anon_sym_compl] = ACTIONS(2114),
    [anon_sym_DASH_DASH] = ACTIONS(2116),
    [anon_sym_PLUS_PLUS] = ACTIONS(2116),
    [anon_sym_sizeof] = ACTIONS(2114),
    [anon_sym___alignof__] = ACTIONS(2114),
    [anon_sym___alignof] = ACTIONS(2114),
    [anon_sym__alignof] = ACTIONS(2114),
    [anon_sym_alignof] = ACTIONS(2114),
    [anon_sym__Alignof] = ACTIONS(2114),
    [anon_sym_offsetof] = ACTIONS(2114),
    [anon_sym__Generic] = ACTIONS(2114),
    [anon_sym_asm] = ACTIONS(2114),
    [anon_sym___asm__] = ACTIONS(2114),
    [sym_number_literal] = ACTIONS(2116),
    [anon_sym_L_SQUOTE] = ACTIONS(2116),
    [anon_sym_u_SQUOTE] = ACTIONS(2116),
    [anon_sym_U_SQUOTE] = ACTIONS(2116),
    [anon_sym_u8_SQUOTE] = ACTIONS(2116),
    [anon_sym_SQUOTE] = ACTIONS(2116),
    [anon_sym_L_DQUOTE] = ACTIONS(2116),
    [anon_sym_u_DQUOTE] = ACTIONS(2116),
    [anon_sym_U_DQUOTE] = ACTIONS(2116),
    [anon_sym_u8_DQUOTE] = ACTIONS(2116),
    [anon_sym_DQUOTE] = ACTIONS(2116),
    [sym_true] = ACTIONS(2114),
    [sym_false] = ACTIONS(2114),
    [anon_sym_NULL] = ACTIONS(2114),
    [anon_sym_nullptr] = ACTIONS(2114),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2114),
    [anon_sym_decltype] = ACTIONS(2114),
    [sym_virtual] = ACTIONS(2114),
    [anon_sym_explicit] = ACTIONS(2114),
    [anon_sym_typename] = ACTIONS(2114),
    [anon_sym_template] = ACTIONS(2114),
    [anon_sym_operator] = ACTIONS(2114),
    [anon_sym_try] = ACTIONS(2114),
    [anon_sym_delete] = ACTIONS(2114),
    [anon_sym_throw] = ACTIONS(2114),
    [anon_sym_namespace] = ACTIONS(2114),
    [anon_sym_using] = ACTIONS(2114),
    [anon_sym_static_assert] = ACTIONS(2114),
    [anon_sym_concept] = ACTIONS(2114),
    [anon_sym_co_return] = ACTIONS(2114),
    [anon_sym_co_yield] = ACTIONS(2114),
    [anon_sym_R_DQUOTE] = ACTIONS(2116),
    [anon_sym_LR_DQUOTE] = ACTIONS(2116),
    [anon_sym_uR_DQUOTE] = ACTIONS(2116),
    [anon_sym_UR_DQUOTE] = ACTIONS(2116),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2116),
    [anon_sym_co_await] = ACTIONS(2114),
    [anon_sym_new] = ACTIONS(2114),
    [anon_sym_requires] = ACTIONS(2114),
    [sym_this] = ACTIONS(2114),
    [anon_sym_discard] = ACTIONS(2114),
    [anon_sym_precise] = ACTIONS(2114),
    [anon_sym_shared] = ACTIONS(2114),
    [anon_sym_groupshared] = ACTIONS(2114),
    [anon_sym_uniform] = ACTIONS(2114),
    [anon_sym_row_major] = ACTIONS(2114),
    [anon_sym_column_major] = ACTIONS(2114),
    [anon_sym_globallycoherent] = ACTIONS(2114),
    [anon_sym_centroid] = ACTIONS(2114),
    [anon_sym_noperspective] = ACTIONS(2114),
    [anon_sym_nointerpolation] = ACTIONS(2114),
    [anon_sym_sample] = ACTIONS(2114),
    [anon_sym_linear] = ACTIONS(2114),
    [anon_sym_snorm] = ACTIONS(2114),
    [anon_sym_unorm] = ACTIONS(2114),
    [anon_sym_point] = ACTIONS(2114),
    [anon_sym_line] = ACTIONS(2114),
    [anon_sym_triangleadj] = ACTIONS(2114),
    [anon_sym_lineadj] = ACTIONS(2114),
    [anon_sym_triangle] = ACTIONS(2114),
    [anon_sym_cbuffer] = ACTIONS(2114),
  },
  [185] = {
    [sym_identifier] = ACTIONS(2118),
    [aux_sym_preproc_include_token1] = ACTIONS(2118),
    [aux_sym_preproc_def_token1] = ACTIONS(2118),
    [aux_sym_preproc_if_token1] = ACTIONS(2118),
    [aux_sym_preproc_if_token2] = ACTIONS(2118),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2118),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2118),
    [aux_sym_preproc_else_token1] = ACTIONS(2118),
    [aux_sym_preproc_elif_token1] = ACTIONS(2118),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2118),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2118),
    [sym_preproc_directive] = ACTIONS(2118),
    [anon_sym_LPAREN2] = ACTIONS(2120),
    [anon_sym_BANG] = ACTIONS(2120),
    [anon_sym_TILDE] = ACTIONS(2120),
    [anon_sym_DASH] = ACTIONS(2118),
    [anon_sym_PLUS] = ACTIONS(2118),
    [anon_sym_STAR] = ACTIONS(2120),
    [anon_sym_AMP_AMP] = ACTIONS(2120),
    [anon_sym_AMP] = ACTIONS(2118),
    [anon_sym_SEMI] = ACTIONS(2120),
    [anon_sym___extension__] = ACTIONS(2118),
    [anon_sym_typedef] = ACTIONS(2118),
    [anon_sym_in] = ACTIONS(2118),
    [anon_sym_out] = ACTIONS(2118),
    [anon_sym_inout] = ACTIONS(2118),
    [anon_sym_extern] = ACTIONS(2118),
    [anon_sym___attribute__] = ACTIONS(2118),
    [anon_sym_COLON_COLON] = ACTIONS(2120),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2120),
    [anon_sym___declspec] = ACTIONS(2118),
    [anon_sym___based] = ACTIONS(2118),
    [anon_sym___cdecl] = ACTIONS(2118),
    [anon_sym___clrcall] = ACTIONS(2118),
    [anon_sym___stdcall] = ACTIONS(2118),
    [anon_sym___fastcall] = ACTIONS(2118),
    [anon_sym___thiscall] = ACTIONS(2118),
    [anon_sym___vectorcall] = ACTIONS(2118),
    [anon_sym_LBRACE] = ACTIONS(2120),
    [anon_sym_signed] = ACTIONS(2118),
    [anon_sym_unsigned] = ACTIONS(2118),
    [anon_sym_long] = ACTIONS(2118),
    [anon_sym_short] = ACTIONS(2118),
    [anon_sym_LBRACK] = ACTIONS(2118),
    [anon_sym_static] = ACTIONS(2118),
    [anon_sym_register] = ACTIONS(2118),
    [anon_sym_inline] = ACTIONS(2118),
    [anon_sym___inline] = ACTIONS(2118),
    [anon_sym___inline__] = ACTIONS(2118),
    [anon_sym___forceinline] = ACTIONS(2118),
    [anon_sym_thread_local] = ACTIONS(2118),
    [anon_sym___thread] = ACTIONS(2118),
    [anon_sym_const] = ACTIONS(2118),
    [anon_sym_constexpr] = ACTIONS(2118),
    [anon_sym_volatile] = ACTIONS(2118),
    [anon_sym_restrict] = ACTIONS(2118),
    [anon_sym___restrict__] = ACTIONS(2118),
    [anon_sym__Atomic] = ACTIONS(2118),
    [anon_sym__Noreturn] = ACTIONS(2118),
    [anon_sym_noreturn] = ACTIONS(2118),
    [anon_sym_mutable] = ACTIONS(2118),
    [anon_sym_constinit] = ACTIONS(2118),
    [anon_sym_consteval] = ACTIONS(2118),
    [anon_sym_alignas] = ACTIONS(2118),
    [anon_sym__Alignas] = ACTIONS(2118),
    [sym_primitive_type] = ACTIONS(2118),
    [anon_sym_enum] = ACTIONS(2118),
    [anon_sym_class] = ACTIONS(2118),
    [anon_sym_struct] = ACTIONS(2118),
    [anon_sym_union] = ACTIONS(2118),
    [anon_sym_if] = ACTIONS(2118),
    [anon_sym_else] = ACTIONS(2118),
    [anon_sym_switch] = ACTIONS(2118),
    [anon_sym_case] = ACTIONS(2118),
    [anon_sym_default] = ACTIONS(2118),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_do] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2118),
    [anon_sym_return] = ACTIONS(2118),
    [anon_sym_break] = ACTIONS(2118),
    [anon_sym_continue] = ACTIONS(2118),
    [anon_sym_goto] = ACTIONS(2118),
    [anon_sym___try] = ACTIONS(2118),
    [anon_sym___leave] = ACTIONS(2118),
    [anon_sym_not] = ACTIONS(2118),
    [anon_sym_compl] = ACTIONS(2118),
    [anon_sym_DASH_DASH] = ACTIONS(2120),
    [anon_sym_PLUS_PLUS] = ACTIONS(2120),
    [anon_sym_sizeof] = ACTIONS(2118),
    [anon_sym___alignof__] = ACTIONS(2118),
    [anon_sym___alignof] = ACTIONS(2118),
    [anon_sym__alignof] = ACTIONS(2118),
    [anon_sym_alignof] = ACTIONS(2118),
    [anon_sym__Alignof] = ACTIONS(2118),
    [anon_sym_offsetof] = ACTIONS(2118),
    [anon_sym__Generic] = ACTIONS(2118),
    [anon_sym_asm] = ACTIONS(2118),
    [anon_sym___asm__] = ACTIONS(2118),
    [sym_number_literal] = ACTIONS(2120),
    [anon_sym_L_SQUOTE] = ACTIONS(2120),
    [anon_sym_u_SQUOTE] = ACTIONS(2120),
    [anon_sym_U_SQUOTE] = ACTIONS(2120),
    [anon_sym_u8_SQUOTE] = ACTIONS(2120),
    [anon_sym_SQUOTE] = ACTIONS(2120),
    [anon_sym_L_DQUOTE] = ACTIONS(2120),
    [anon_sym_u_DQUOTE] = ACTIONS(2120),
    [anon_sym_U_DQUOTE] = ACTIONS(2120),
    [anon_sym_u8_DQUOTE] = ACTIONS(2120),
    [anon_sym_DQUOTE] = ACTIONS(2120),
    [sym_true] = ACTIONS(2118),
    [sym_false] = ACTIONS(2118),
    [anon_sym_NULL] = ACTIONS(2118),
    [anon_sym_nullptr] = ACTIONS(2118),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2118),
    [anon_sym_decltype] = ACTIONS(2118),
    [sym_virtual] = ACTIONS(2118),
    [anon_sym_explicit] = ACTIONS(2118),
    [anon_sym_typename] = ACTIONS(2118),
    [anon_sym_template] = ACTIONS(2118),
    [anon_sym_operator] = ACTIONS(2118),
    [anon_sym_try] = ACTIONS(2118),
    [anon_sym_delete] = ACTIONS(2118),
    [anon_sym_throw] = ACTIONS(2118),
    [anon_sym_namespace] = ACTIONS(2118),
    [anon_sym_using] = ACTIONS(2118),
    [anon_sym_static_assert] = ACTIONS(2118),
    [anon_sym_concept] = ACTIONS(2118),
    [anon_sym_co_return] = ACTIONS(2118),
    [anon_sym_co_yield] = ACTIONS(2118),
    [anon_sym_R_DQUOTE] = ACTIONS(2120),
    [anon_sym_LR_DQUOTE] = ACTIONS(2120),
    [anon_sym_uR_DQUOTE] = ACTIONS(2120),
    [anon_sym_UR_DQUOTE] = ACTIONS(2120),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2120),
    [anon_sym_co_await] = ACTIONS(2118),
    [anon_sym_new] = ACTIONS(2118),
    [anon_sym_requires] = ACTIONS(2118),
    [sym_this] = ACTIONS(2118),
    [anon_sym_discard] = ACTIONS(2118),
    [anon_sym_precise] = ACTIONS(2118),
    [anon_sym_shared] = ACTIONS(2118),
    [anon_sym_groupshared] = ACTIONS(2118),
    [anon_sym_uniform] = ACTIONS(2118),
    [anon_sym_row_major] = ACTIONS(2118),
    [anon_sym_column_major] = ACTIONS(2118),
    [anon_sym_globallycoherent] = ACTIONS(2118),
    [anon_sym_centroid] = ACTIONS(2118),
    [anon_sym_noperspective] = ACTIONS(2118),
    [anon_sym_nointerpolation] = ACTIONS(2118),
    [anon_sym_sample] = ACTIONS(2118),
    [anon_sym_linear] = ACTIONS(2118),
    [anon_sym_snorm] = ACTIONS(2118),
    [anon_sym_unorm] = ACTIONS(2118),
    [anon_sym_point] = ACTIONS(2118),
    [anon_sym_line] = ACTIONS(2118),
    [anon_sym_triangleadj] = ACTIONS(2118),
    [anon_sym_lineadj] = ACTIONS(2118),
    [anon_sym_triangle] = ACTIONS(2118),
    [anon_sym_cbuffer] = ACTIONS(2118),
  },
  [186] = {
    [sym_identifier] = ACTIONS(2122),
    [aux_sym_preproc_include_token1] = ACTIONS(2122),
    [aux_sym_preproc_def_token1] = ACTIONS(2122),
    [aux_sym_preproc_if_token1] = ACTIONS(2122),
    [aux_sym_preproc_if_token2] = ACTIONS(2122),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2122),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2122),
    [aux_sym_preproc_else_token1] = ACTIONS(2122),
    [aux_sym_preproc_elif_token1] = ACTIONS(2122),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2122),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2122),
    [sym_preproc_directive] = ACTIONS(2122),
    [anon_sym_LPAREN2] = ACTIONS(2124),
    [anon_sym_BANG] = ACTIONS(2124),
    [anon_sym_TILDE] = ACTIONS(2124),
    [anon_sym_DASH] = ACTIONS(2122),
    [anon_sym_PLUS] = ACTIONS(2122),
    [anon_sym_STAR] = ACTIONS(2124),
    [anon_sym_AMP_AMP] = ACTIONS(2124),
    [anon_sym_AMP] = ACTIONS(2122),
    [anon_sym_SEMI] = ACTIONS(2124),
    [anon_sym___extension__] = ACTIONS(2122),
    [anon_sym_typedef] = ACTIONS(2122),
    [anon_sym_in] = ACTIONS(2122),
    [anon_sym_out] = ACTIONS(2122),
    [anon_sym_inout] = ACTIONS(2122),
    [anon_sym_extern] = ACTIONS(2122),
    [anon_sym___attribute__] = ACTIONS(2122),
    [anon_sym_COLON_COLON] = ACTIONS(2124),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2124),
    [anon_sym___declspec] = ACTIONS(2122),
    [anon_sym___based] = ACTIONS(2122),
    [anon_sym___cdecl] = ACTIONS(2122),
    [anon_sym___clrcall] = ACTIONS(2122),
    [anon_sym___stdcall] = ACTIONS(2122),
    [anon_sym___fastcall] = ACTIONS(2122),
    [anon_sym___thiscall] = ACTIONS(2122),
    [anon_sym___vectorcall] = ACTIONS(2122),
    [anon_sym_LBRACE] = ACTIONS(2124),
    [anon_sym_signed] = ACTIONS(2122),
    [anon_sym_unsigned] = ACTIONS(2122),
    [anon_sym_long] = ACTIONS(2122),
    [anon_sym_short] = ACTIONS(2122),
    [anon_sym_LBRACK] = ACTIONS(2122),
    [anon_sym_static] = ACTIONS(2122),
    [anon_sym_register] = ACTIONS(2122),
    [anon_sym_inline] = ACTIONS(2122),
    [anon_sym___inline] = ACTIONS(2122),
    [anon_sym___inline__] = ACTIONS(2122),
    [anon_sym___forceinline] = ACTIONS(2122),
    [anon_sym_thread_local] = ACTIONS(2122),
    [anon_sym___thread] = ACTIONS(2122),
    [anon_sym_const] = ACTIONS(2122),
    [anon_sym_constexpr] = ACTIONS(2122),
    [anon_sym_volatile] = ACTIONS(2122),
    [anon_sym_restrict] = ACTIONS(2122),
    [anon_sym___restrict__] = ACTIONS(2122),
    [anon_sym__Atomic] = ACTIONS(2122),
    [anon_sym__Noreturn] = ACTIONS(2122),
    [anon_sym_noreturn] = ACTIONS(2122),
    [anon_sym_mutable] = ACTIONS(2122),
    [anon_sym_constinit] = ACTIONS(2122),
    [anon_sym_consteval] = ACTIONS(2122),
    [anon_sym_alignas] = ACTIONS(2122),
    [anon_sym__Alignas] = ACTIONS(2122),
    [sym_primitive_type] = ACTIONS(2122),
    [anon_sym_enum] = ACTIONS(2122),
    [anon_sym_class] = ACTIONS(2122),
    [anon_sym_struct] = ACTIONS(2122),
    [anon_sym_union] = ACTIONS(2122),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_else] = ACTIONS(2122),
    [anon_sym_switch] = ACTIONS(2122),
    [anon_sym_case] = ACTIONS(2122),
    [anon_sym_default] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2122),
    [anon_sym_do] = ACTIONS(2122),
    [anon_sym_for] = ACTIONS(2122),
    [anon_sym_return] = ACTIONS(2122),
    [anon_sym_break] = ACTIONS(2122),
    [anon_sym_continue] = ACTIONS(2122),
    [anon_sym_goto] = ACTIONS(2122),
    [anon_sym___try] = ACTIONS(2122),
    [anon_sym___leave] = ACTIONS(2122),
    [anon_sym_not] = ACTIONS(2122),
    [anon_sym_compl] = ACTIONS(2122),
    [anon_sym_DASH_DASH] = ACTIONS(2124),
    [anon_sym_PLUS_PLUS] = ACTIONS(2124),
    [anon_sym_sizeof] = ACTIONS(2122),
    [anon_sym___alignof__] = ACTIONS(2122),
    [anon_sym___alignof] = ACTIONS(2122),
    [anon_sym__alignof] = ACTIONS(2122),
    [anon_sym_alignof] = ACTIONS(2122),
    [anon_sym__Alignof] = ACTIONS(2122),
    [anon_sym_offsetof] = ACTIONS(2122),
    [anon_sym__Generic] = ACTIONS(2122),
    [anon_sym_asm] = ACTIONS(2122),
    [anon_sym___asm__] = ACTIONS(2122),
    [sym_number_literal] = ACTIONS(2124),
    [anon_sym_L_SQUOTE] = ACTIONS(2124),
    [anon_sym_u_SQUOTE] = ACTIONS(2124),
    [anon_sym_U_SQUOTE] = ACTIONS(2124),
    [anon_sym_u8_SQUOTE] = ACTIONS(2124),
    [anon_sym_SQUOTE] = ACTIONS(2124),
    [anon_sym_L_DQUOTE] = ACTIONS(2124),
    [anon_sym_u_DQUOTE] = ACTIONS(2124),
    [anon_sym_U_DQUOTE] = ACTIONS(2124),
    [anon_sym_u8_DQUOTE] = ACTIONS(2124),
    [anon_sym_DQUOTE] = ACTIONS(2124),
    [sym_true] = ACTIONS(2122),
    [sym_false] = ACTIONS(2122),
    [anon_sym_NULL] = ACTIONS(2122),
    [anon_sym_nullptr] = ACTIONS(2122),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2122),
    [anon_sym_decltype] = ACTIONS(2122),
    [sym_virtual] = ACTIONS(2122),
    [anon_sym_explicit] = ACTIONS(2122),
    [anon_sym_typename] = ACTIONS(2122),
    [anon_sym_template] = ACTIONS(2122),
    [anon_sym_operator] = ACTIONS(2122),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_delete] = ACTIONS(2122),
    [anon_sym_throw] = ACTIONS(2122),
    [anon_sym_namespace] = ACTIONS(2122),
    [anon_sym_using] = ACTIONS(2122),
    [anon_sym_static_assert] = ACTIONS(2122),
    [anon_sym_concept] = ACTIONS(2122),
    [anon_sym_co_return] = ACTIONS(2122),
    [anon_sym_co_yield] = ACTIONS(2122),
    [anon_sym_R_DQUOTE] = ACTIONS(2124),
    [anon_sym_LR_DQUOTE] = ACTIONS(2124),
    [anon_sym_uR_DQUOTE] = ACTIONS(2124),
    [anon_sym_UR_DQUOTE] = ACTIONS(2124),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2124),
    [anon_sym_co_await] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(2122),
    [anon_sym_requires] = ACTIONS(2122),
    [sym_this] = ACTIONS(2122),
    [anon_sym_discard] = ACTIONS(2122),
    [anon_sym_precise] = ACTIONS(2122),
    [anon_sym_shared] = ACTIONS(2122),
    [anon_sym_groupshared] = ACTIONS(2122),
    [anon_sym_uniform] = ACTIONS(2122),
    [anon_sym_row_major] = ACTIONS(2122),
    [anon_sym_column_major] = ACTIONS(2122),
    [anon_sym_globallycoherent] = ACTIONS(2122),
    [anon_sym_centroid] = ACTIONS(2122),
    [anon_sym_noperspective] = ACTIONS(2122),
    [anon_sym_nointerpolation] = ACTIONS(2122),
    [anon_sym_sample] = ACTIONS(2122),
    [anon_sym_linear] = ACTIONS(2122),
    [anon_sym_snorm] = ACTIONS(2122),
    [anon_sym_unorm] = ACTIONS(2122),
    [anon_sym_point] = ACTIONS(2122),
    [anon_sym_line] = ACTIONS(2122),
    [anon_sym_triangleadj] = ACTIONS(2122),
    [anon_sym_lineadj] = ACTIONS(2122),
    [anon_sym_triangle] = ACTIONS(2122),
    [anon_sym_cbuffer] = ACTIONS(2122),
  },
  [187] = {
    [sym_identifier] = ACTIONS(2126),
    [aux_sym_preproc_include_token1] = ACTIONS(2126),
    [aux_sym_preproc_def_token1] = ACTIONS(2126),
    [aux_sym_preproc_if_token1] = ACTIONS(2126),
    [aux_sym_preproc_if_token2] = ACTIONS(2126),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2126),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2126),
    [aux_sym_preproc_else_token1] = ACTIONS(2126),
    [aux_sym_preproc_elif_token1] = ACTIONS(2126),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2126),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2126),
    [sym_preproc_directive] = ACTIONS(2126),
    [anon_sym_LPAREN2] = ACTIONS(2128),
    [anon_sym_BANG] = ACTIONS(2128),
    [anon_sym_TILDE] = ACTIONS(2128),
    [anon_sym_DASH] = ACTIONS(2126),
    [anon_sym_PLUS] = ACTIONS(2126),
    [anon_sym_STAR] = ACTIONS(2128),
    [anon_sym_AMP_AMP] = ACTIONS(2128),
    [anon_sym_AMP] = ACTIONS(2126),
    [anon_sym_SEMI] = ACTIONS(2128),
    [anon_sym___extension__] = ACTIONS(2126),
    [anon_sym_typedef] = ACTIONS(2126),
    [anon_sym_in] = ACTIONS(2126),
    [anon_sym_out] = ACTIONS(2126),
    [anon_sym_inout] = ACTIONS(2126),
    [anon_sym_extern] = ACTIONS(2126),
    [anon_sym___attribute__] = ACTIONS(2126),
    [anon_sym_COLON_COLON] = ACTIONS(2128),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2128),
    [anon_sym___declspec] = ACTIONS(2126),
    [anon_sym___based] = ACTIONS(2126),
    [anon_sym___cdecl] = ACTIONS(2126),
    [anon_sym___clrcall] = ACTIONS(2126),
    [anon_sym___stdcall] = ACTIONS(2126),
    [anon_sym___fastcall] = ACTIONS(2126),
    [anon_sym___thiscall] = ACTIONS(2126),
    [anon_sym___vectorcall] = ACTIONS(2126),
    [anon_sym_LBRACE] = ACTIONS(2128),
    [anon_sym_signed] = ACTIONS(2126),
    [anon_sym_unsigned] = ACTIONS(2126),
    [anon_sym_long] = ACTIONS(2126),
    [anon_sym_short] = ACTIONS(2126),
    [anon_sym_LBRACK] = ACTIONS(2126),
    [anon_sym_static] = ACTIONS(2126),
    [anon_sym_register] = ACTIONS(2126),
    [anon_sym_inline] = ACTIONS(2126),
    [anon_sym___inline] = ACTIONS(2126),
    [anon_sym___inline__] = ACTIONS(2126),
    [anon_sym___forceinline] = ACTIONS(2126),
    [anon_sym_thread_local] = ACTIONS(2126),
    [anon_sym___thread] = ACTIONS(2126),
    [anon_sym_const] = ACTIONS(2126),
    [anon_sym_constexpr] = ACTIONS(2126),
    [anon_sym_volatile] = ACTIONS(2126),
    [anon_sym_restrict] = ACTIONS(2126),
    [anon_sym___restrict__] = ACTIONS(2126),
    [anon_sym__Atomic] = ACTIONS(2126),
    [anon_sym__Noreturn] = ACTIONS(2126),
    [anon_sym_noreturn] = ACTIONS(2126),
    [anon_sym_mutable] = ACTIONS(2126),
    [anon_sym_constinit] = ACTIONS(2126),
    [anon_sym_consteval] = ACTIONS(2126),
    [anon_sym_alignas] = ACTIONS(2126),
    [anon_sym__Alignas] = ACTIONS(2126),
    [sym_primitive_type] = ACTIONS(2126),
    [anon_sym_enum] = ACTIONS(2126),
    [anon_sym_class] = ACTIONS(2126),
    [anon_sym_struct] = ACTIONS(2126),
    [anon_sym_union] = ACTIONS(2126),
    [anon_sym_if] = ACTIONS(2126),
    [anon_sym_else] = ACTIONS(2126),
    [anon_sym_switch] = ACTIONS(2126),
    [anon_sym_case] = ACTIONS(2126),
    [anon_sym_default] = ACTIONS(2126),
    [anon_sym_while] = ACTIONS(2126),
    [anon_sym_do] = ACTIONS(2126),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_return] = ACTIONS(2126),
    [anon_sym_break] = ACTIONS(2126),
    [anon_sym_continue] = ACTIONS(2126),
    [anon_sym_goto] = ACTIONS(2126),
    [anon_sym___try] = ACTIONS(2126),
    [anon_sym___leave] = ACTIONS(2126),
    [anon_sym_not] = ACTIONS(2126),
    [anon_sym_compl] = ACTIONS(2126),
    [anon_sym_DASH_DASH] = ACTIONS(2128),
    [anon_sym_PLUS_PLUS] = ACTIONS(2128),
    [anon_sym_sizeof] = ACTIONS(2126),
    [anon_sym___alignof__] = ACTIONS(2126),
    [anon_sym___alignof] = ACTIONS(2126),
    [anon_sym__alignof] = ACTIONS(2126),
    [anon_sym_alignof] = ACTIONS(2126),
    [anon_sym__Alignof] = ACTIONS(2126),
    [anon_sym_offsetof] = ACTIONS(2126),
    [anon_sym__Generic] = ACTIONS(2126),
    [anon_sym_asm] = ACTIONS(2126),
    [anon_sym___asm__] = ACTIONS(2126),
    [sym_number_literal] = ACTIONS(2128),
    [anon_sym_L_SQUOTE] = ACTIONS(2128),
    [anon_sym_u_SQUOTE] = ACTIONS(2128),
    [anon_sym_U_SQUOTE] = ACTIONS(2128),
    [anon_sym_u8_SQUOTE] = ACTIONS(2128),
    [anon_sym_SQUOTE] = ACTIONS(2128),
    [anon_sym_L_DQUOTE] = ACTIONS(2128),
    [anon_sym_u_DQUOTE] = ACTIONS(2128),
    [anon_sym_U_DQUOTE] = ACTIONS(2128),
    [anon_sym_u8_DQUOTE] = ACTIONS(2128),
    [anon_sym_DQUOTE] = ACTIONS(2128),
    [sym_true] = ACTIONS(2126),
    [sym_false] = ACTIONS(2126),
    [anon_sym_NULL] = ACTIONS(2126),
    [anon_sym_nullptr] = ACTIONS(2126),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2126),
    [anon_sym_decltype] = ACTIONS(2126),
    [sym_virtual] = ACTIONS(2126),
    [anon_sym_explicit] = ACTIONS(2126),
    [anon_sym_typename] = ACTIONS(2126),
    [anon_sym_template] = ACTIONS(2126),
    [anon_sym_operator] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2126),
    [anon_sym_delete] = ACTIONS(2126),
    [anon_sym_throw] = ACTIONS(2126),
    [anon_sym_namespace] = ACTIONS(2126),
    [anon_sym_using] = ACTIONS(2126),
    [anon_sym_static_assert] = ACTIONS(2126),
    [anon_sym_concept] = ACTIONS(2126),
    [anon_sym_co_return] = ACTIONS(2126),
    [anon_sym_co_yield] = ACTIONS(2126),
    [anon_sym_R_DQUOTE] = ACTIONS(2128),
    [anon_sym_LR_DQUOTE] = ACTIONS(2128),
    [anon_sym_uR_DQUOTE] = ACTIONS(2128),
    [anon_sym_UR_DQUOTE] = ACTIONS(2128),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2128),
    [anon_sym_co_await] = ACTIONS(2126),
    [anon_sym_new] = ACTIONS(2126),
    [anon_sym_requires] = ACTIONS(2126),
    [sym_this] = ACTIONS(2126),
    [anon_sym_discard] = ACTIONS(2126),
    [anon_sym_precise] = ACTIONS(2126),
    [anon_sym_shared] = ACTIONS(2126),
    [anon_sym_groupshared] = ACTIONS(2126),
    [anon_sym_uniform] = ACTIONS(2126),
    [anon_sym_row_major] = ACTIONS(2126),
    [anon_sym_column_major] = ACTIONS(2126),
    [anon_sym_globallycoherent] = ACTIONS(2126),
    [anon_sym_centroid] = ACTIONS(2126),
    [anon_sym_noperspective] = ACTIONS(2126),
    [anon_sym_nointerpolation] = ACTIONS(2126),
    [anon_sym_sample] = ACTIONS(2126),
    [anon_sym_linear] = ACTIONS(2126),
    [anon_sym_snorm] = ACTIONS(2126),
    [anon_sym_unorm] = ACTIONS(2126),
    [anon_sym_point] = ACTIONS(2126),
    [anon_sym_line] = ACTIONS(2126),
    [anon_sym_triangleadj] = ACTIONS(2126),
    [anon_sym_lineadj] = ACTIONS(2126),
    [anon_sym_triangle] = ACTIONS(2126),
    [anon_sym_cbuffer] = ACTIONS(2126),
  },
  [188] = {
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(5254),
    [sym__declarator] = STATE(6515),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6270),
    [sym_array_declarator] = STATE(6270),
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3138),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8453),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(8261),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3415),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8259),
    [sym__unary_right_fold] = STATE(8258),
    [sym__binary_fold] = STATE(8257),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5594),
    [sym_qualified_identifier] = STATE(3419),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8546),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(2018),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(2028),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2030),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(2034),
    [anon_sym___clrcall] = ACTIONS(2034),
    [anon_sym___stdcall] = ACTIONS(2034),
    [anon_sym___fastcall] = ACTIONS(2034),
    [anon_sym___thiscall] = ACTIONS(2034),
    [anon_sym___vectorcall] = ACTIONS(2034),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(2038),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(2078),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [189] = {
    [sym_identifier] = ACTIONS(2130),
    [aux_sym_preproc_include_token1] = ACTIONS(2130),
    [aux_sym_preproc_def_token1] = ACTIONS(2130),
    [aux_sym_preproc_if_token1] = ACTIONS(2130),
    [aux_sym_preproc_if_token2] = ACTIONS(2130),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2130),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2130),
    [aux_sym_preproc_else_token1] = ACTIONS(2130),
    [aux_sym_preproc_elif_token1] = ACTIONS(2130),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2130),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2130),
    [sym_preproc_directive] = ACTIONS(2130),
    [anon_sym_LPAREN2] = ACTIONS(2132),
    [anon_sym_BANG] = ACTIONS(2132),
    [anon_sym_TILDE] = ACTIONS(2132),
    [anon_sym_DASH] = ACTIONS(2130),
    [anon_sym_PLUS] = ACTIONS(2130),
    [anon_sym_STAR] = ACTIONS(2132),
    [anon_sym_AMP_AMP] = ACTIONS(2132),
    [anon_sym_AMP] = ACTIONS(2130),
    [anon_sym_SEMI] = ACTIONS(2132),
    [anon_sym___extension__] = ACTIONS(2130),
    [anon_sym_typedef] = ACTIONS(2130),
    [anon_sym_in] = ACTIONS(2130),
    [anon_sym_out] = ACTIONS(2130),
    [anon_sym_inout] = ACTIONS(2130),
    [anon_sym_extern] = ACTIONS(2130),
    [anon_sym___attribute__] = ACTIONS(2130),
    [anon_sym_COLON_COLON] = ACTIONS(2132),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2132),
    [anon_sym___declspec] = ACTIONS(2130),
    [anon_sym___based] = ACTIONS(2130),
    [anon_sym___cdecl] = ACTIONS(2130),
    [anon_sym___clrcall] = ACTIONS(2130),
    [anon_sym___stdcall] = ACTIONS(2130),
    [anon_sym___fastcall] = ACTIONS(2130),
    [anon_sym___thiscall] = ACTIONS(2130),
    [anon_sym___vectorcall] = ACTIONS(2130),
    [anon_sym_LBRACE] = ACTIONS(2132),
    [anon_sym_signed] = ACTIONS(2130),
    [anon_sym_unsigned] = ACTIONS(2130),
    [anon_sym_long] = ACTIONS(2130),
    [anon_sym_short] = ACTIONS(2130),
    [anon_sym_LBRACK] = ACTIONS(2130),
    [anon_sym_static] = ACTIONS(2130),
    [anon_sym_register] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(2130),
    [anon_sym___inline] = ACTIONS(2130),
    [anon_sym___inline__] = ACTIONS(2130),
    [anon_sym___forceinline] = ACTIONS(2130),
    [anon_sym_thread_local] = ACTIONS(2130),
    [anon_sym___thread] = ACTIONS(2130),
    [anon_sym_const] = ACTIONS(2130),
    [anon_sym_constexpr] = ACTIONS(2130),
    [anon_sym_volatile] = ACTIONS(2130),
    [anon_sym_restrict] = ACTIONS(2130),
    [anon_sym___restrict__] = ACTIONS(2130),
    [anon_sym__Atomic] = ACTIONS(2130),
    [anon_sym__Noreturn] = ACTIONS(2130),
    [anon_sym_noreturn] = ACTIONS(2130),
    [anon_sym_mutable] = ACTIONS(2130),
    [anon_sym_constinit] = ACTIONS(2130),
    [anon_sym_consteval] = ACTIONS(2130),
    [anon_sym_alignas] = ACTIONS(2130),
    [anon_sym__Alignas] = ACTIONS(2130),
    [sym_primitive_type] = ACTIONS(2130),
    [anon_sym_enum] = ACTIONS(2130),
    [anon_sym_class] = ACTIONS(2130),
    [anon_sym_struct] = ACTIONS(2130),
    [anon_sym_union] = ACTIONS(2130),
    [anon_sym_if] = ACTIONS(2130),
    [anon_sym_else] = ACTIONS(2130),
    [anon_sym_switch] = ACTIONS(2130),
    [anon_sym_case] = ACTIONS(2130),
    [anon_sym_default] = ACTIONS(2130),
    [anon_sym_while] = ACTIONS(2130),
    [anon_sym_do] = ACTIONS(2130),
    [anon_sym_for] = ACTIONS(2130),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_break] = ACTIONS(2130),
    [anon_sym_continue] = ACTIONS(2130),
    [anon_sym_goto] = ACTIONS(2130),
    [anon_sym___try] = ACTIONS(2130),
    [anon_sym___leave] = ACTIONS(2130),
    [anon_sym_not] = ACTIONS(2130),
    [anon_sym_compl] = ACTIONS(2130),
    [anon_sym_DASH_DASH] = ACTIONS(2132),
    [anon_sym_PLUS_PLUS] = ACTIONS(2132),
    [anon_sym_sizeof] = ACTIONS(2130),
    [anon_sym___alignof__] = ACTIONS(2130),
    [anon_sym___alignof] = ACTIONS(2130),
    [anon_sym__alignof] = ACTIONS(2130),
    [anon_sym_alignof] = ACTIONS(2130),
    [anon_sym__Alignof] = ACTIONS(2130),
    [anon_sym_offsetof] = ACTIONS(2130),
    [anon_sym__Generic] = ACTIONS(2130),
    [anon_sym_asm] = ACTIONS(2130),
    [anon_sym___asm__] = ACTIONS(2130),
    [sym_number_literal] = ACTIONS(2132),
    [anon_sym_L_SQUOTE] = ACTIONS(2132),
    [anon_sym_u_SQUOTE] = ACTIONS(2132),
    [anon_sym_U_SQUOTE] = ACTIONS(2132),
    [anon_sym_u8_SQUOTE] = ACTIONS(2132),
    [anon_sym_SQUOTE] = ACTIONS(2132),
    [anon_sym_L_DQUOTE] = ACTIONS(2132),
    [anon_sym_u_DQUOTE] = ACTIONS(2132),
    [anon_sym_U_DQUOTE] = ACTIONS(2132),
    [anon_sym_u8_DQUOTE] = ACTIONS(2132),
    [anon_sym_DQUOTE] = ACTIONS(2132),
    [sym_true] = ACTIONS(2130),
    [sym_false] = ACTIONS(2130),
    [anon_sym_NULL] = ACTIONS(2130),
    [anon_sym_nullptr] = ACTIONS(2130),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2130),
    [anon_sym_decltype] = ACTIONS(2130),
    [sym_virtual] = ACTIONS(2130),
    [anon_sym_explicit] = ACTIONS(2130),
    [anon_sym_typename] = ACTIONS(2130),
    [anon_sym_template] = ACTIONS(2130),
    [anon_sym_operator] = ACTIONS(2130),
    [anon_sym_try] = ACTIONS(2130),
    [anon_sym_delete] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2130),
    [anon_sym_namespace] = ACTIONS(2130),
    [anon_sym_using] = ACTIONS(2130),
    [anon_sym_static_assert] = ACTIONS(2130),
    [anon_sym_concept] = ACTIONS(2130),
    [anon_sym_co_return] = ACTIONS(2130),
    [anon_sym_co_yield] = ACTIONS(2130),
    [anon_sym_R_DQUOTE] = ACTIONS(2132),
    [anon_sym_LR_DQUOTE] = ACTIONS(2132),
    [anon_sym_uR_DQUOTE] = ACTIONS(2132),
    [anon_sym_UR_DQUOTE] = ACTIONS(2132),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2132),
    [anon_sym_co_await] = ACTIONS(2130),
    [anon_sym_new] = ACTIONS(2130),
    [anon_sym_requires] = ACTIONS(2130),
    [sym_this] = ACTIONS(2130),
    [anon_sym_discard] = ACTIONS(2130),
    [anon_sym_precise] = ACTIONS(2130),
    [anon_sym_shared] = ACTIONS(2130),
    [anon_sym_groupshared] = ACTIONS(2130),
    [anon_sym_uniform] = ACTIONS(2130),
    [anon_sym_row_major] = ACTIONS(2130),
    [anon_sym_column_major] = ACTIONS(2130),
    [anon_sym_globallycoherent] = ACTIONS(2130),
    [anon_sym_centroid] = ACTIONS(2130),
    [anon_sym_noperspective] = ACTIONS(2130),
    [anon_sym_nointerpolation] = ACTIONS(2130),
    [anon_sym_sample] = ACTIONS(2130),
    [anon_sym_linear] = ACTIONS(2130),
    [anon_sym_snorm] = ACTIONS(2130),
    [anon_sym_unorm] = ACTIONS(2130),
    [anon_sym_point] = ACTIONS(2130),
    [anon_sym_line] = ACTIONS(2130),
    [anon_sym_triangleadj] = ACTIONS(2130),
    [anon_sym_lineadj] = ACTIONS(2130),
    [anon_sym_triangle] = ACTIONS(2130),
    [anon_sym_cbuffer] = ACTIONS(2130),
  },
  [190] = {
    [sym_identifier] = ACTIONS(2134),
    [aux_sym_preproc_include_token1] = ACTIONS(2134),
    [aux_sym_preproc_def_token1] = ACTIONS(2134),
    [aux_sym_preproc_if_token1] = ACTIONS(2134),
    [aux_sym_preproc_if_token2] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2134),
    [aux_sym_preproc_else_token1] = ACTIONS(2134),
    [aux_sym_preproc_elif_token1] = ACTIONS(2134),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2134),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2134),
    [sym_preproc_directive] = ACTIONS(2134),
    [anon_sym_LPAREN2] = ACTIONS(2136),
    [anon_sym_BANG] = ACTIONS(2136),
    [anon_sym_TILDE] = ACTIONS(2136),
    [anon_sym_DASH] = ACTIONS(2134),
    [anon_sym_PLUS] = ACTIONS(2134),
    [anon_sym_STAR] = ACTIONS(2136),
    [anon_sym_AMP_AMP] = ACTIONS(2136),
    [anon_sym_AMP] = ACTIONS(2134),
    [anon_sym_SEMI] = ACTIONS(2136),
    [anon_sym___extension__] = ACTIONS(2134),
    [anon_sym_typedef] = ACTIONS(2134),
    [anon_sym_in] = ACTIONS(2134),
    [anon_sym_out] = ACTIONS(2134),
    [anon_sym_inout] = ACTIONS(2134),
    [anon_sym_extern] = ACTIONS(2134),
    [anon_sym___attribute__] = ACTIONS(2134),
    [anon_sym_COLON_COLON] = ACTIONS(2136),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2136),
    [anon_sym___declspec] = ACTIONS(2134),
    [anon_sym___based] = ACTIONS(2134),
    [anon_sym___cdecl] = ACTIONS(2134),
    [anon_sym___clrcall] = ACTIONS(2134),
    [anon_sym___stdcall] = ACTIONS(2134),
    [anon_sym___fastcall] = ACTIONS(2134),
    [anon_sym___thiscall] = ACTIONS(2134),
    [anon_sym___vectorcall] = ACTIONS(2134),
    [anon_sym_LBRACE] = ACTIONS(2136),
    [anon_sym_signed] = ACTIONS(2134),
    [anon_sym_unsigned] = ACTIONS(2134),
    [anon_sym_long] = ACTIONS(2134),
    [anon_sym_short] = ACTIONS(2134),
    [anon_sym_LBRACK] = ACTIONS(2134),
    [anon_sym_static] = ACTIONS(2134),
    [anon_sym_register] = ACTIONS(2134),
    [anon_sym_inline] = ACTIONS(2134),
    [anon_sym___inline] = ACTIONS(2134),
    [anon_sym___inline__] = ACTIONS(2134),
    [anon_sym___forceinline] = ACTIONS(2134),
    [anon_sym_thread_local] = ACTIONS(2134),
    [anon_sym___thread] = ACTIONS(2134),
    [anon_sym_const] = ACTIONS(2134),
    [anon_sym_constexpr] = ACTIONS(2134),
    [anon_sym_volatile] = ACTIONS(2134),
    [anon_sym_restrict] = ACTIONS(2134),
    [anon_sym___restrict__] = ACTIONS(2134),
    [anon_sym__Atomic] = ACTIONS(2134),
    [anon_sym__Noreturn] = ACTIONS(2134),
    [anon_sym_noreturn] = ACTIONS(2134),
    [anon_sym_mutable] = ACTIONS(2134),
    [anon_sym_constinit] = ACTIONS(2134),
    [anon_sym_consteval] = ACTIONS(2134),
    [anon_sym_alignas] = ACTIONS(2134),
    [anon_sym__Alignas] = ACTIONS(2134),
    [sym_primitive_type] = ACTIONS(2134),
    [anon_sym_enum] = ACTIONS(2134),
    [anon_sym_class] = ACTIONS(2134),
    [anon_sym_struct] = ACTIONS(2134),
    [anon_sym_union] = ACTIONS(2134),
    [anon_sym_if] = ACTIONS(2134),
    [anon_sym_else] = ACTIONS(2134),
    [anon_sym_switch] = ACTIONS(2134),
    [anon_sym_case] = ACTIONS(2134),
    [anon_sym_default] = ACTIONS(2134),
    [anon_sym_while] = ACTIONS(2134),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_for] = ACTIONS(2134),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_break] = ACTIONS(2134),
    [anon_sym_continue] = ACTIONS(2134),
    [anon_sym_goto] = ACTIONS(2134),
    [anon_sym___try] = ACTIONS(2134),
    [anon_sym___leave] = ACTIONS(2134),
    [anon_sym_not] = ACTIONS(2134),
    [anon_sym_compl] = ACTIONS(2134),
    [anon_sym_DASH_DASH] = ACTIONS(2136),
    [anon_sym_PLUS_PLUS] = ACTIONS(2136),
    [anon_sym_sizeof] = ACTIONS(2134),
    [anon_sym___alignof__] = ACTIONS(2134),
    [anon_sym___alignof] = ACTIONS(2134),
    [anon_sym__alignof] = ACTIONS(2134),
    [anon_sym_alignof] = ACTIONS(2134),
    [anon_sym__Alignof] = ACTIONS(2134),
    [anon_sym_offsetof] = ACTIONS(2134),
    [anon_sym__Generic] = ACTIONS(2134),
    [anon_sym_asm] = ACTIONS(2134),
    [anon_sym___asm__] = ACTIONS(2134),
    [sym_number_literal] = ACTIONS(2136),
    [anon_sym_L_SQUOTE] = ACTIONS(2136),
    [anon_sym_u_SQUOTE] = ACTIONS(2136),
    [anon_sym_U_SQUOTE] = ACTIONS(2136),
    [anon_sym_u8_SQUOTE] = ACTIONS(2136),
    [anon_sym_SQUOTE] = ACTIONS(2136),
    [anon_sym_L_DQUOTE] = ACTIONS(2136),
    [anon_sym_u_DQUOTE] = ACTIONS(2136),
    [anon_sym_U_DQUOTE] = ACTIONS(2136),
    [anon_sym_u8_DQUOTE] = ACTIONS(2136),
    [anon_sym_DQUOTE] = ACTIONS(2136),
    [sym_true] = ACTIONS(2134),
    [sym_false] = ACTIONS(2134),
    [anon_sym_NULL] = ACTIONS(2134),
    [anon_sym_nullptr] = ACTIONS(2134),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2134),
    [anon_sym_decltype] = ACTIONS(2134),
    [sym_virtual] = ACTIONS(2134),
    [anon_sym_explicit] = ACTIONS(2134),
    [anon_sym_typename] = ACTIONS(2134),
    [anon_sym_template] = ACTIONS(2134),
    [anon_sym_operator] = ACTIONS(2134),
    [anon_sym_try] = ACTIONS(2134),
    [anon_sym_delete] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2134),
    [anon_sym_namespace] = ACTIONS(2134),
    [anon_sym_using] = ACTIONS(2134),
    [anon_sym_static_assert] = ACTIONS(2134),
    [anon_sym_concept] = ACTIONS(2134),
    [anon_sym_co_return] = ACTIONS(2134),
    [anon_sym_co_yield] = ACTIONS(2134),
    [anon_sym_R_DQUOTE] = ACTIONS(2136),
    [anon_sym_LR_DQUOTE] = ACTIONS(2136),
    [anon_sym_uR_DQUOTE] = ACTIONS(2136),
    [anon_sym_UR_DQUOTE] = ACTIONS(2136),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2136),
    [anon_sym_co_await] = ACTIONS(2134),
    [anon_sym_new] = ACTIONS(2134),
    [anon_sym_requires] = ACTIONS(2134),
    [sym_this] = ACTIONS(2134),
    [anon_sym_discard] = ACTIONS(2134),
    [anon_sym_precise] = ACTIONS(2134),
    [anon_sym_shared] = ACTIONS(2134),
    [anon_sym_groupshared] = ACTIONS(2134),
    [anon_sym_uniform] = ACTIONS(2134),
    [anon_sym_row_major] = ACTIONS(2134),
    [anon_sym_column_major] = ACTIONS(2134),
    [anon_sym_globallycoherent] = ACTIONS(2134),
    [anon_sym_centroid] = ACTIONS(2134),
    [anon_sym_noperspective] = ACTIONS(2134),
    [anon_sym_nointerpolation] = ACTIONS(2134),
    [anon_sym_sample] = ACTIONS(2134),
    [anon_sym_linear] = ACTIONS(2134),
    [anon_sym_snorm] = ACTIONS(2134),
    [anon_sym_unorm] = ACTIONS(2134),
    [anon_sym_point] = ACTIONS(2134),
    [anon_sym_line] = ACTIONS(2134),
    [anon_sym_triangleadj] = ACTIONS(2134),
    [anon_sym_lineadj] = ACTIONS(2134),
    [anon_sym_triangle] = ACTIONS(2134),
    [anon_sym_cbuffer] = ACTIONS(2134),
  },
  [191] = {
    [sym_identifier] = ACTIONS(2138),
    [aux_sym_preproc_include_token1] = ACTIONS(2138),
    [aux_sym_preproc_def_token1] = ACTIONS(2138),
    [aux_sym_preproc_if_token1] = ACTIONS(2138),
    [aux_sym_preproc_if_token2] = ACTIONS(2138),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2138),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2138),
    [aux_sym_preproc_else_token1] = ACTIONS(2138),
    [aux_sym_preproc_elif_token1] = ACTIONS(2138),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2138),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2138),
    [sym_preproc_directive] = ACTIONS(2138),
    [anon_sym_LPAREN2] = ACTIONS(2140),
    [anon_sym_BANG] = ACTIONS(2140),
    [anon_sym_TILDE] = ACTIONS(2140),
    [anon_sym_DASH] = ACTIONS(2138),
    [anon_sym_PLUS] = ACTIONS(2138),
    [anon_sym_STAR] = ACTIONS(2140),
    [anon_sym_AMP_AMP] = ACTIONS(2140),
    [anon_sym_AMP] = ACTIONS(2138),
    [anon_sym_SEMI] = ACTIONS(2140),
    [anon_sym___extension__] = ACTIONS(2138),
    [anon_sym_typedef] = ACTIONS(2138),
    [anon_sym_in] = ACTIONS(2138),
    [anon_sym_out] = ACTIONS(2138),
    [anon_sym_inout] = ACTIONS(2138),
    [anon_sym_extern] = ACTIONS(2138),
    [anon_sym___attribute__] = ACTIONS(2138),
    [anon_sym_COLON_COLON] = ACTIONS(2140),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2140),
    [anon_sym___declspec] = ACTIONS(2138),
    [anon_sym___based] = ACTIONS(2138),
    [anon_sym___cdecl] = ACTIONS(2138),
    [anon_sym___clrcall] = ACTIONS(2138),
    [anon_sym___stdcall] = ACTIONS(2138),
    [anon_sym___fastcall] = ACTIONS(2138),
    [anon_sym___thiscall] = ACTIONS(2138),
    [anon_sym___vectorcall] = ACTIONS(2138),
    [anon_sym_LBRACE] = ACTIONS(2140),
    [anon_sym_signed] = ACTIONS(2138),
    [anon_sym_unsigned] = ACTIONS(2138),
    [anon_sym_long] = ACTIONS(2138),
    [anon_sym_short] = ACTIONS(2138),
    [anon_sym_LBRACK] = ACTIONS(2138),
    [anon_sym_static] = ACTIONS(2138),
    [anon_sym_register] = ACTIONS(2138),
    [anon_sym_inline] = ACTIONS(2138),
    [anon_sym___inline] = ACTIONS(2138),
    [anon_sym___inline__] = ACTIONS(2138),
    [anon_sym___forceinline] = ACTIONS(2138),
    [anon_sym_thread_local] = ACTIONS(2138),
    [anon_sym___thread] = ACTIONS(2138),
    [anon_sym_const] = ACTIONS(2138),
    [anon_sym_constexpr] = ACTIONS(2138),
    [anon_sym_volatile] = ACTIONS(2138),
    [anon_sym_restrict] = ACTIONS(2138),
    [anon_sym___restrict__] = ACTIONS(2138),
    [anon_sym__Atomic] = ACTIONS(2138),
    [anon_sym__Noreturn] = ACTIONS(2138),
    [anon_sym_noreturn] = ACTIONS(2138),
    [anon_sym_mutable] = ACTIONS(2138),
    [anon_sym_constinit] = ACTIONS(2138),
    [anon_sym_consteval] = ACTIONS(2138),
    [anon_sym_alignas] = ACTIONS(2138),
    [anon_sym__Alignas] = ACTIONS(2138),
    [sym_primitive_type] = ACTIONS(2138),
    [anon_sym_enum] = ACTIONS(2138),
    [anon_sym_class] = ACTIONS(2138),
    [anon_sym_struct] = ACTIONS(2138),
    [anon_sym_union] = ACTIONS(2138),
    [anon_sym_if] = ACTIONS(2138),
    [anon_sym_else] = ACTIONS(2138),
    [anon_sym_switch] = ACTIONS(2138),
    [anon_sym_case] = ACTIONS(2138),
    [anon_sym_default] = ACTIONS(2138),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_do] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2138),
    [anon_sym_return] = ACTIONS(2138),
    [anon_sym_break] = ACTIONS(2138),
    [anon_sym_continue] = ACTIONS(2138),
    [anon_sym_goto] = ACTIONS(2138),
    [anon_sym___try] = ACTIONS(2138),
    [anon_sym___leave] = ACTIONS(2138),
    [anon_sym_not] = ACTIONS(2138),
    [anon_sym_compl] = ACTIONS(2138),
    [anon_sym_DASH_DASH] = ACTIONS(2140),
    [anon_sym_PLUS_PLUS] = ACTIONS(2140),
    [anon_sym_sizeof] = ACTIONS(2138),
    [anon_sym___alignof__] = ACTIONS(2138),
    [anon_sym___alignof] = ACTIONS(2138),
    [anon_sym__alignof] = ACTIONS(2138),
    [anon_sym_alignof] = ACTIONS(2138),
    [anon_sym__Alignof] = ACTIONS(2138),
    [anon_sym_offsetof] = ACTIONS(2138),
    [anon_sym__Generic] = ACTIONS(2138),
    [anon_sym_asm] = ACTIONS(2138),
    [anon_sym___asm__] = ACTIONS(2138),
    [sym_number_literal] = ACTIONS(2140),
    [anon_sym_L_SQUOTE] = ACTIONS(2140),
    [anon_sym_u_SQUOTE] = ACTIONS(2140),
    [anon_sym_U_SQUOTE] = ACTIONS(2140),
    [anon_sym_u8_SQUOTE] = ACTIONS(2140),
    [anon_sym_SQUOTE] = ACTIONS(2140),
    [anon_sym_L_DQUOTE] = ACTIONS(2140),
    [anon_sym_u_DQUOTE] = ACTIONS(2140),
    [anon_sym_U_DQUOTE] = ACTIONS(2140),
    [anon_sym_u8_DQUOTE] = ACTIONS(2140),
    [anon_sym_DQUOTE] = ACTIONS(2140),
    [sym_true] = ACTIONS(2138),
    [sym_false] = ACTIONS(2138),
    [anon_sym_NULL] = ACTIONS(2138),
    [anon_sym_nullptr] = ACTIONS(2138),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2138),
    [anon_sym_decltype] = ACTIONS(2138),
    [sym_virtual] = ACTIONS(2138),
    [anon_sym_explicit] = ACTIONS(2138),
    [anon_sym_typename] = ACTIONS(2138),
    [anon_sym_template] = ACTIONS(2138),
    [anon_sym_operator] = ACTIONS(2138),
    [anon_sym_try] = ACTIONS(2138),
    [anon_sym_delete] = ACTIONS(2138),
    [anon_sym_throw] = ACTIONS(2138),
    [anon_sym_namespace] = ACTIONS(2138),
    [anon_sym_using] = ACTIONS(2138),
    [anon_sym_static_assert] = ACTIONS(2138),
    [anon_sym_concept] = ACTIONS(2138),
    [anon_sym_co_return] = ACTIONS(2138),
    [anon_sym_co_yield] = ACTIONS(2138),
    [anon_sym_R_DQUOTE] = ACTIONS(2140),
    [anon_sym_LR_DQUOTE] = ACTIONS(2140),
    [anon_sym_uR_DQUOTE] = ACTIONS(2140),
    [anon_sym_UR_DQUOTE] = ACTIONS(2140),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2140),
    [anon_sym_co_await] = ACTIONS(2138),
    [anon_sym_new] = ACTIONS(2138),
    [anon_sym_requires] = ACTIONS(2138),
    [sym_this] = ACTIONS(2138),
    [anon_sym_discard] = ACTIONS(2138),
    [anon_sym_precise] = ACTIONS(2138),
    [anon_sym_shared] = ACTIONS(2138),
    [anon_sym_groupshared] = ACTIONS(2138),
    [anon_sym_uniform] = ACTIONS(2138),
    [anon_sym_row_major] = ACTIONS(2138),
    [anon_sym_column_major] = ACTIONS(2138),
    [anon_sym_globallycoherent] = ACTIONS(2138),
    [anon_sym_centroid] = ACTIONS(2138),
    [anon_sym_noperspective] = ACTIONS(2138),
    [anon_sym_nointerpolation] = ACTIONS(2138),
    [anon_sym_sample] = ACTIONS(2138),
    [anon_sym_linear] = ACTIONS(2138),
    [anon_sym_snorm] = ACTIONS(2138),
    [anon_sym_unorm] = ACTIONS(2138),
    [anon_sym_point] = ACTIONS(2138),
    [anon_sym_line] = ACTIONS(2138),
    [anon_sym_triangleadj] = ACTIONS(2138),
    [anon_sym_lineadj] = ACTIONS(2138),
    [anon_sym_triangle] = ACTIONS(2138),
    [anon_sym_cbuffer] = ACTIONS(2138),
  },
  [192] = {
    [sym_identifier] = ACTIONS(2142),
    [aux_sym_preproc_include_token1] = ACTIONS(2142),
    [aux_sym_preproc_def_token1] = ACTIONS(2142),
    [aux_sym_preproc_if_token1] = ACTIONS(2142),
    [aux_sym_preproc_if_token2] = ACTIONS(2142),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2142),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2142),
    [aux_sym_preproc_else_token1] = ACTIONS(2142),
    [aux_sym_preproc_elif_token1] = ACTIONS(2142),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2142),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2142),
    [sym_preproc_directive] = ACTIONS(2142),
    [anon_sym_LPAREN2] = ACTIONS(2144),
    [anon_sym_BANG] = ACTIONS(2144),
    [anon_sym_TILDE] = ACTIONS(2144),
    [anon_sym_DASH] = ACTIONS(2142),
    [anon_sym_PLUS] = ACTIONS(2142),
    [anon_sym_STAR] = ACTIONS(2144),
    [anon_sym_AMP_AMP] = ACTIONS(2144),
    [anon_sym_AMP] = ACTIONS(2142),
    [anon_sym_SEMI] = ACTIONS(2144),
    [anon_sym___extension__] = ACTIONS(2142),
    [anon_sym_typedef] = ACTIONS(2142),
    [anon_sym_in] = ACTIONS(2142),
    [anon_sym_out] = ACTIONS(2142),
    [anon_sym_inout] = ACTIONS(2142),
    [anon_sym_extern] = ACTIONS(2142),
    [anon_sym___attribute__] = ACTIONS(2142),
    [anon_sym_COLON_COLON] = ACTIONS(2144),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2144),
    [anon_sym___declspec] = ACTIONS(2142),
    [anon_sym___based] = ACTIONS(2142),
    [anon_sym___cdecl] = ACTIONS(2142),
    [anon_sym___clrcall] = ACTIONS(2142),
    [anon_sym___stdcall] = ACTIONS(2142),
    [anon_sym___fastcall] = ACTIONS(2142),
    [anon_sym___thiscall] = ACTIONS(2142),
    [anon_sym___vectorcall] = ACTIONS(2142),
    [anon_sym_LBRACE] = ACTIONS(2144),
    [anon_sym_signed] = ACTIONS(2142),
    [anon_sym_unsigned] = ACTIONS(2142),
    [anon_sym_long] = ACTIONS(2142),
    [anon_sym_short] = ACTIONS(2142),
    [anon_sym_LBRACK] = ACTIONS(2142),
    [anon_sym_static] = ACTIONS(2142),
    [anon_sym_register] = ACTIONS(2142),
    [anon_sym_inline] = ACTIONS(2142),
    [anon_sym___inline] = ACTIONS(2142),
    [anon_sym___inline__] = ACTIONS(2142),
    [anon_sym___forceinline] = ACTIONS(2142),
    [anon_sym_thread_local] = ACTIONS(2142),
    [anon_sym___thread] = ACTIONS(2142),
    [anon_sym_const] = ACTIONS(2142),
    [anon_sym_constexpr] = ACTIONS(2142),
    [anon_sym_volatile] = ACTIONS(2142),
    [anon_sym_restrict] = ACTIONS(2142),
    [anon_sym___restrict__] = ACTIONS(2142),
    [anon_sym__Atomic] = ACTIONS(2142),
    [anon_sym__Noreturn] = ACTIONS(2142),
    [anon_sym_noreturn] = ACTIONS(2142),
    [anon_sym_mutable] = ACTIONS(2142),
    [anon_sym_constinit] = ACTIONS(2142),
    [anon_sym_consteval] = ACTIONS(2142),
    [anon_sym_alignas] = ACTIONS(2142),
    [anon_sym__Alignas] = ACTIONS(2142),
    [sym_primitive_type] = ACTIONS(2142),
    [anon_sym_enum] = ACTIONS(2142),
    [anon_sym_class] = ACTIONS(2142),
    [anon_sym_struct] = ACTIONS(2142),
    [anon_sym_union] = ACTIONS(2142),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_else] = ACTIONS(2142),
    [anon_sym_switch] = ACTIONS(2142),
    [anon_sym_case] = ACTIONS(2142),
    [anon_sym_default] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2142),
    [anon_sym_do] = ACTIONS(2142),
    [anon_sym_for] = ACTIONS(2142),
    [anon_sym_return] = ACTIONS(2142),
    [anon_sym_break] = ACTIONS(2142),
    [anon_sym_continue] = ACTIONS(2142),
    [anon_sym_goto] = ACTIONS(2142),
    [anon_sym___try] = ACTIONS(2142),
    [anon_sym___leave] = ACTIONS(2142),
    [anon_sym_not] = ACTIONS(2142),
    [anon_sym_compl] = ACTIONS(2142),
    [anon_sym_DASH_DASH] = ACTIONS(2144),
    [anon_sym_PLUS_PLUS] = ACTIONS(2144),
    [anon_sym_sizeof] = ACTIONS(2142),
    [anon_sym___alignof__] = ACTIONS(2142),
    [anon_sym___alignof] = ACTIONS(2142),
    [anon_sym__alignof] = ACTIONS(2142),
    [anon_sym_alignof] = ACTIONS(2142),
    [anon_sym__Alignof] = ACTIONS(2142),
    [anon_sym_offsetof] = ACTIONS(2142),
    [anon_sym__Generic] = ACTIONS(2142),
    [anon_sym_asm] = ACTIONS(2142),
    [anon_sym___asm__] = ACTIONS(2142),
    [sym_number_literal] = ACTIONS(2144),
    [anon_sym_L_SQUOTE] = ACTIONS(2144),
    [anon_sym_u_SQUOTE] = ACTIONS(2144),
    [anon_sym_U_SQUOTE] = ACTIONS(2144),
    [anon_sym_u8_SQUOTE] = ACTIONS(2144),
    [anon_sym_SQUOTE] = ACTIONS(2144),
    [anon_sym_L_DQUOTE] = ACTIONS(2144),
    [anon_sym_u_DQUOTE] = ACTIONS(2144),
    [anon_sym_U_DQUOTE] = ACTIONS(2144),
    [anon_sym_u8_DQUOTE] = ACTIONS(2144),
    [anon_sym_DQUOTE] = ACTIONS(2144),
    [sym_true] = ACTIONS(2142),
    [sym_false] = ACTIONS(2142),
    [anon_sym_NULL] = ACTIONS(2142),
    [anon_sym_nullptr] = ACTIONS(2142),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2142),
    [anon_sym_decltype] = ACTIONS(2142),
    [sym_virtual] = ACTIONS(2142),
    [anon_sym_explicit] = ACTIONS(2142),
    [anon_sym_typename] = ACTIONS(2142),
    [anon_sym_template] = ACTIONS(2142),
    [anon_sym_operator] = ACTIONS(2142),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_delete] = ACTIONS(2142),
    [anon_sym_throw] = ACTIONS(2142),
    [anon_sym_namespace] = ACTIONS(2142),
    [anon_sym_using] = ACTIONS(2142),
    [anon_sym_static_assert] = ACTIONS(2142),
    [anon_sym_concept] = ACTIONS(2142),
    [anon_sym_co_return] = ACTIONS(2142),
    [anon_sym_co_yield] = ACTIONS(2142),
    [anon_sym_R_DQUOTE] = ACTIONS(2144),
    [anon_sym_LR_DQUOTE] = ACTIONS(2144),
    [anon_sym_uR_DQUOTE] = ACTIONS(2144),
    [anon_sym_UR_DQUOTE] = ACTIONS(2144),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2144),
    [anon_sym_co_await] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(2142),
    [anon_sym_requires] = ACTIONS(2142),
    [sym_this] = ACTIONS(2142),
    [anon_sym_discard] = ACTIONS(2142),
    [anon_sym_precise] = ACTIONS(2142),
    [anon_sym_shared] = ACTIONS(2142),
    [anon_sym_groupshared] = ACTIONS(2142),
    [anon_sym_uniform] = ACTIONS(2142),
    [anon_sym_row_major] = ACTIONS(2142),
    [anon_sym_column_major] = ACTIONS(2142),
    [anon_sym_globallycoherent] = ACTIONS(2142),
    [anon_sym_centroid] = ACTIONS(2142),
    [anon_sym_noperspective] = ACTIONS(2142),
    [anon_sym_nointerpolation] = ACTIONS(2142),
    [anon_sym_sample] = ACTIONS(2142),
    [anon_sym_linear] = ACTIONS(2142),
    [anon_sym_snorm] = ACTIONS(2142),
    [anon_sym_unorm] = ACTIONS(2142),
    [anon_sym_point] = ACTIONS(2142),
    [anon_sym_line] = ACTIONS(2142),
    [anon_sym_triangleadj] = ACTIONS(2142),
    [anon_sym_lineadj] = ACTIONS(2142),
    [anon_sym_triangle] = ACTIONS(2142),
    [anon_sym_cbuffer] = ACTIONS(2142),
  },
  [193] = {
    [sym_identifier] = ACTIONS(2146),
    [aux_sym_preproc_include_token1] = ACTIONS(2146),
    [aux_sym_preproc_def_token1] = ACTIONS(2146),
    [aux_sym_preproc_if_token1] = ACTIONS(2146),
    [aux_sym_preproc_if_token2] = ACTIONS(2146),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2146),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2146),
    [aux_sym_preproc_else_token1] = ACTIONS(2146),
    [aux_sym_preproc_elif_token1] = ACTIONS(2146),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2146),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2146),
    [sym_preproc_directive] = ACTIONS(2146),
    [anon_sym_LPAREN2] = ACTIONS(2148),
    [anon_sym_BANG] = ACTIONS(2148),
    [anon_sym_TILDE] = ACTIONS(2148),
    [anon_sym_DASH] = ACTIONS(2146),
    [anon_sym_PLUS] = ACTIONS(2146),
    [anon_sym_STAR] = ACTIONS(2148),
    [anon_sym_AMP_AMP] = ACTIONS(2148),
    [anon_sym_AMP] = ACTIONS(2146),
    [anon_sym_SEMI] = ACTIONS(2148),
    [anon_sym___extension__] = ACTIONS(2146),
    [anon_sym_typedef] = ACTIONS(2146),
    [anon_sym_in] = ACTIONS(2146),
    [anon_sym_out] = ACTIONS(2146),
    [anon_sym_inout] = ACTIONS(2146),
    [anon_sym_extern] = ACTIONS(2146),
    [anon_sym___attribute__] = ACTIONS(2146),
    [anon_sym_COLON_COLON] = ACTIONS(2148),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2148),
    [anon_sym___declspec] = ACTIONS(2146),
    [anon_sym___based] = ACTIONS(2146),
    [anon_sym___cdecl] = ACTIONS(2146),
    [anon_sym___clrcall] = ACTIONS(2146),
    [anon_sym___stdcall] = ACTIONS(2146),
    [anon_sym___fastcall] = ACTIONS(2146),
    [anon_sym___thiscall] = ACTIONS(2146),
    [anon_sym___vectorcall] = ACTIONS(2146),
    [anon_sym_LBRACE] = ACTIONS(2148),
    [anon_sym_signed] = ACTIONS(2146),
    [anon_sym_unsigned] = ACTIONS(2146),
    [anon_sym_long] = ACTIONS(2146),
    [anon_sym_short] = ACTIONS(2146),
    [anon_sym_LBRACK] = ACTIONS(2146),
    [anon_sym_static] = ACTIONS(2146),
    [anon_sym_register] = ACTIONS(2146),
    [anon_sym_inline] = ACTIONS(2146),
    [anon_sym___inline] = ACTIONS(2146),
    [anon_sym___inline__] = ACTIONS(2146),
    [anon_sym___forceinline] = ACTIONS(2146),
    [anon_sym_thread_local] = ACTIONS(2146),
    [anon_sym___thread] = ACTIONS(2146),
    [anon_sym_const] = ACTIONS(2146),
    [anon_sym_constexpr] = ACTIONS(2146),
    [anon_sym_volatile] = ACTIONS(2146),
    [anon_sym_restrict] = ACTIONS(2146),
    [anon_sym___restrict__] = ACTIONS(2146),
    [anon_sym__Atomic] = ACTIONS(2146),
    [anon_sym__Noreturn] = ACTIONS(2146),
    [anon_sym_noreturn] = ACTIONS(2146),
    [anon_sym_mutable] = ACTIONS(2146),
    [anon_sym_constinit] = ACTIONS(2146),
    [anon_sym_consteval] = ACTIONS(2146),
    [anon_sym_alignas] = ACTIONS(2146),
    [anon_sym__Alignas] = ACTIONS(2146),
    [sym_primitive_type] = ACTIONS(2146),
    [anon_sym_enum] = ACTIONS(2146),
    [anon_sym_class] = ACTIONS(2146),
    [anon_sym_struct] = ACTIONS(2146),
    [anon_sym_union] = ACTIONS(2146),
    [anon_sym_if] = ACTIONS(2146),
    [anon_sym_else] = ACTIONS(2146),
    [anon_sym_switch] = ACTIONS(2146),
    [anon_sym_case] = ACTIONS(2146),
    [anon_sym_default] = ACTIONS(2146),
    [anon_sym_while] = ACTIONS(2146),
    [anon_sym_do] = ACTIONS(2146),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_return] = ACTIONS(2146),
    [anon_sym_break] = ACTIONS(2146),
    [anon_sym_continue] = ACTIONS(2146),
    [anon_sym_goto] = ACTIONS(2146),
    [anon_sym___try] = ACTIONS(2146),
    [anon_sym___leave] = ACTIONS(2146),
    [anon_sym_not] = ACTIONS(2146),
    [anon_sym_compl] = ACTIONS(2146),
    [anon_sym_DASH_DASH] = ACTIONS(2148),
    [anon_sym_PLUS_PLUS] = ACTIONS(2148),
    [anon_sym_sizeof] = ACTIONS(2146),
    [anon_sym___alignof__] = ACTIONS(2146),
    [anon_sym___alignof] = ACTIONS(2146),
    [anon_sym__alignof] = ACTIONS(2146),
    [anon_sym_alignof] = ACTIONS(2146),
    [anon_sym__Alignof] = ACTIONS(2146),
    [anon_sym_offsetof] = ACTIONS(2146),
    [anon_sym__Generic] = ACTIONS(2146),
    [anon_sym_asm] = ACTIONS(2146),
    [anon_sym___asm__] = ACTIONS(2146),
    [sym_number_literal] = ACTIONS(2148),
    [anon_sym_L_SQUOTE] = ACTIONS(2148),
    [anon_sym_u_SQUOTE] = ACTIONS(2148),
    [anon_sym_U_SQUOTE] = ACTIONS(2148),
    [anon_sym_u8_SQUOTE] = ACTIONS(2148),
    [anon_sym_SQUOTE] = ACTIONS(2148),
    [anon_sym_L_DQUOTE] = ACTIONS(2148),
    [anon_sym_u_DQUOTE] = ACTIONS(2148),
    [anon_sym_U_DQUOTE] = ACTIONS(2148),
    [anon_sym_u8_DQUOTE] = ACTIONS(2148),
    [anon_sym_DQUOTE] = ACTIONS(2148),
    [sym_true] = ACTIONS(2146),
    [sym_false] = ACTIONS(2146),
    [anon_sym_NULL] = ACTIONS(2146),
    [anon_sym_nullptr] = ACTIONS(2146),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2146),
    [anon_sym_decltype] = ACTIONS(2146),
    [sym_virtual] = ACTIONS(2146),
    [anon_sym_explicit] = ACTIONS(2146),
    [anon_sym_typename] = ACTIONS(2146),
    [anon_sym_template] = ACTIONS(2146),
    [anon_sym_operator] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2146),
    [anon_sym_delete] = ACTIONS(2146),
    [anon_sym_throw] = ACTIONS(2146),
    [anon_sym_namespace] = ACTIONS(2146),
    [anon_sym_using] = ACTIONS(2146),
    [anon_sym_static_assert] = ACTIONS(2146),
    [anon_sym_concept] = ACTIONS(2146),
    [anon_sym_co_return] = ACTIONS(2146),
    [anon_sym_co_yield] = ACTIONS(2146),
    [anon_sym_R_DQUOTE] = ACTIONS(2148),
    [anon_sym_LR_DQUOTE] = ACTIONS(2148),
    [anon_sym_uR_DQUOTE] = ACTIONS(2148),
    [anon_sym_UR_DQUOTE] = ACTIONS(2148),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2148),
    [anon_sym_co_await] = ACTIONS(2146),
    [anon_sym_new] = ACTIONS(2146),
    [anon_sym_requires] = ACTIONS(2146),
    [sym_this] = ACTIONS(2146),
    [anon_sym_discard] = ACTIONS(2146),
    [anon_sym_precise] = ACTIONS(2146),
    [anon_sym_shared] = ACTIONS(2146),
    [anon_sym_groupshared] = ACTIONS(2146),
    [anon_sym_uniform] = ACTIONS(2146),
    [anon_sym_row_major] = ACTIONS(2146),
    [anon_sym_column_major] = ACTIONS(2146),
    [anon_sym_globallycoherent] = ACTIONS(2146),
    [anon_sym_centroid] = ACTIONS(2146),
    [anon_sym_noperspective] = ACTIONS(2146),
    [anon_sym_nointerpolation] = ACTIONS(2146),
    [anon_sym_sample] = ACTIONS(2146),
    [anon_sym_linear] = ACTIONS(2146),
    [anon_sym_snorm] = ACTIONS(2146),
    [anon_sym_unorm] = ACTIONS(2146),
    [anon_sym_point] = ACTIONS(2146),
    [anon_sym_line] = ACTIONS(2146),
    [anon_sym_triangleadj] = ACTIONS(2146),
    [anon_sym_lineadj] = ACTIONS(2146),
    [anon_sym_triangle] = ACTIONS(2146),
    [anon_sym_cbuffer] = ACTIONS(2146),
  },
  [194] = {
    [sym_identifier] = ACTIONS(2150),
    [aux_sym_preproc_include_token1] = ACTIONS(2150),
    [aux_sym_preproc_def_token1] = ACTIONS(2150),
    [aux_sym_preproc_if_token1] = ACTIONS(2150),
    [aux_sym_preproc_if_token2] = ACTIONS(2150),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2150),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2150),
    [aux_sym_preproc_else_token1] = ACTIONS(2150),
    [aux_sym_preproc_elif_token1] = ACTIONS(2150),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2150),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2150),
    [sym_preproc_directive] = ACTIONS(2150),
    [anon_sym_LPAREN2] = ACTIONS(2152),
    [anon_sym_BANG] = ACTIONS(2152),
    [anon_sym_TILDE] = ACTIONS(2152),
    [anon_sym_DASH] = ACTIONS(2150),
    [anon_sym_PLUS] = ACTIONS(2150),
    [anon_sym_STAR] = ACTIONS(2152),
    [anon_sym_AMP_AMP] = ACTIONS(2152),
    [anon_sym_AMP] = ACTIONS(2150),
    [anon_sym_SEMI] = ACTIONS(2152),
    [anon_sym___extension__] = ACTIONS(2150),
    [anon_sym_typedef] = ACTIONS(2150),
    [anon_sym_in] = ACTIONS(2150),
    [anon_sym_out] = ACTIONS(2150),
    [anon_sym_inout] = ACTIONS(2150),
    [anon_sym_extern] = ACTIONS(2150),
    [anon_sym___attribute__] = ACTIONS(2150),
    [anon_sym_COLON_COLON] = ACTIONS(2152),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2152),
    [anon_sym___declspec] = ACTIONS(2150),
    [anon_sym___based] = ACTIONS(2150),
    [anon_sym___cdecl] = ACTIONS(2150),
    [anon_sym___clrcall] = ACTIONS(2150),
    [anon_sym___stdcall] = ACTIONS(2150),
    [anon_sym___fastcall] = ACTIONS(2150),
    [anon_sym___thiscall] = ACTIONS(2150),
    [anon_sym___vectorcall] = ACTIONS(2150),
    [anon_sym_LBRACE] = ACTIONS(2152),
    [anon_sym_signed] = ACTIONS(2150),
    [anon_sym_unsigned] = ACTIONS(2150),
    [anon_sym_long] = ACTIONS(2150),
    [anon_sym_short] = ACTIONS(2150),
    [anon_sym_LBRACK] = ACTIONS(2150),
    [anon_sym_static] = ACTIONS(2150),
    [anon_sym_register] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(2150),
    [anon_sym___inline] = ACTIONS(2150),
    [anon_sym___inline__] = ACTIONS(2150),
    [anon_sym___forceinline] = ACTIONS(2150),
    [anon_sym_thread_local] = ACTIONS(2150),
    [anon_sym___thread] = ACTIONS(2150),
    [anon_sym_const] = ACTIONS(2150),
    [anon_sym_constexpr] = ACTIONS(2150),
    [anon_sym_volatile] = ACTIONS(2150),
    [anon_sym_restrict] = ACTIONS(2150),
    [anon_sym___restrict__] = ACTIONS(2150),
    [anon_sym__Atomic] = ACTIONS(2150),
    [anon_sym__Noreturn] = ACTIONS(2150),
    [anon_sym_noreturn] = ACTIONS(2150),
    [anon_sym_mutable] = ACTIONS(2150),
    [anon_sym_constinit] = ACTIONS(2150),
    [anon_sym_consteval] = ACTIONS(2150),
    [anon_sym_alignas] = ACTIONS(2150),
    [anon_sym__Alignas] = ACTIONS(2150),
    [sym_primitive_type] = ACTIONS(2150),
    [anon_sym_enum] = ACTIONS(2150),
    [anon_sym_class] = ACTIONS(2150),
    [anon_sym_struct] = ACTIONS(2150),
    [anon_sym_union] = ACTIONS(2150),
    [anon_sym_if] = ACTIONS(2150),
    [anon_sym_else] = ACTIONS(2150),
    [anon_sym_switch] = ACTIONS(2150),
    [anon_sym_case] = ACTIONS(2150),
    [anon_sym_default] = ACTIONS(2150),
    [anon_sym_while] = ACTIONS(2150),
    [anon_sym_do] = ACTIONS(2150),
    [anon_sym_for] = ACTIONS(2150),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_break] = ACTIONS(2150),
    [anon_sym_continue] = ACTIONS(2150),
    [anon_sym_goto] = ACTIONS(2150),
    [anon_sym___try] = ACTIONS(2150),
    [anon_sym___leave] = ACTIONS(2150),
    [anon_sym_not] = ACTIONS(2150),
    [anon_sym_compl] = ACTIONS(2150),
    [anon_sym_DASH_DASH] = ACTIONS(2152),
    [anon_sym_PLUS_PLUS] = ACTIONS(2152),
    [anon_sym_sizeof] = ACTIONS(2150),
    [anon_sym___alignof__] = ACTIONS(2150),
    [anon_sym___alignof] = ACTIONS(2150),
    [anon_sym__alignof] = ACTIONS(2150),
    [anon_sym_alignof] = ACTIONS(2150),
    [anon_sym__Alignof] = ACTIONS(2150),
    [anon_sym_offsetof] = ACTIONS(2150),
    [anon_sym__Generic] = ACTIONS(2150),
    [anon_sym_asm] = ACTIONS(2150),
    [anon_sym___asm__] = ACTIONS(2150),
    [sym_number_literal] = ACTIONS(2152),
    [anon_sym_L_SQUOTE] = ACTIONS(2152),
    [anon_sym_u_SQUOTE] = ACTIONS(2152),
    [anon_sym_U_SQUOTE] = ACTIONS(2152),
    [anon_sym_u8_SQUOTE] = ACTIONS(2152),
    [anon_sym_SQUOTE] = ACTIONS(2152),
    [anon_sym_L_DQUOTE] = ACTIONS(2152),
    [anon_sym_u_DQUOTE] = ACTIONS(2152),
    [anon_sym_U_DQUOTE] = ACTIONS(2152),
    [anon_sym_u8_DQUOTE] = ACTIONS(2152),
    [anon_sym_DQUOTE] = ACTIONS(2152),
    [sym_true] = ACTIONS(2150),
    [sym_false] = ACTIONS(2150),
    [anon_sym_NULL] = ACTIONS(2150),
    [anon_sym_nullptr] = ACTIONS(2150),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2150),
    [anon_sym_decltype] = ACTIONS(2150),
    [sym_virtual] = ACTIONS(2150),
    [anon_sym_explicit] = ACTIONS(2150),
    [anon_sym_typename] = ACTIONS(2150),
    [anon_sym_template] = ACTIONS(2150),
    [anon_sym_operator] = ACTIONS(2150),
    [anon_sym_try] = ACTIONS(2150),
    [anon_sym_delete] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2150),
    [anon_sym_namespace] = ACTIONS(2150),
    [anon_sym_using] = ACTIONS(2150),
    [anon_sym_static_assert] = ACTIONS(2150),
    [anon_sym_concept] = ACTIONS(2150),
    [anon_sym_co_return] = ACTIONS(2150),
    [anon_sym_co_yield] = ACTIONS(2150),
    [anon_sym_R_DQUOTE] = ACTIONS(2152),
    [anon_sym_LR_DQUOTE] = ACTIONS(2152),
    [anon_sym_uR_DQUOTE] = ACTIONS(2152),
    [anon_sym_UR_DQUOTE] = ACTIONS(2152),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2152),
    [anon_sym_co_await] = ACTIONS(2150),
    [anon_sym_new] = ACTIONS(2150),
    [anon_sym_requires] = ACTIONS(2150),
    [sym_this] = ACTIONS(2150),
    [anon_sym_discard] = ACTIONS(2150),
    [anon_sym_precise] = ACTIONS(2150),
    [anon_sym_shared] = ACTIONS(2150),
    [anon_sym_groupshared] = ACTIONS(2150),
    [anon_sym_uniform] = ACTIONS(2150),
    [anon_sym_row_major] = ACTIONS(2150),
    [anon_sym_column_major] = ACTIONS(2150),
    [anon_sym_globallycoherent] = ACTIONS(2150),
    [anon_sym_centroid] = ACTIONS(2150),
    [anon_sym_noperspective] = ACTIONS(2150),
    [anon_sym_nointerpolation] = ACTIONS(2150),
    [anon_sym_sample] = ACTIONS(2150),
    [anon_sym_linear] = ACTIONS(2150),
    [anon_sym_snorm] = ACTIONS(2150),
    [anon_sym_unorm] = ACTIONS(2150),
    [anon_sym_point] = ACTIONS(2150),
    [anon_sym_line] = ACTIONS(2150),
    [anon_sym_triangleadj] = ACTIONS(2150),
    [anon_sym_lineadj] = ACTIONS(2150),
    [anon_sym_triangle] = ACTIONS(2150),
    [anon_sym_cbuffer] = ACTIONS(2150),
  },
  [195] = {
    [sym_identifier] = ACTIONS(2154),
    [aux_sym_preproc_include_token1] = ACTIONS(2154),
    [aux_sym_preproc_def_token1] = ACTIONS(2154),
    [aux_sym_preproc_if_token1] = ACTIONS(2154),
    [aux_sym_preproc_if_token2] = ACTIONS(2154),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2154),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2154),
    [aux_sym_preproc_else_token1] = ACTIONS(2154),
    [aux_sym_preproc_elif_token1] = ACTIONS(2154),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2154),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2154),
    [sym_preproc_directive] = ACTIONS(2154),
    [anon_sym_LPAREN2] = ACTIONS(2156),
    [anon_sym_BANG] = ACTIONS(2156),
    [anon_sym_TILDE] = ACTIONS(2156),
    [anon_sym_DASH] = ACTIONS(2154),
    [anon_sym_PLUS] = ACTIONS(2154),
    [anon_sym_STAR] = ACTIONS(2156),
    [anon_sym_AMP_AMP] = ACTIONS(2156),
    [anon_sym_AMP] = ACTIONS(2154),
    [anon_sym_SEMI] = ACTIONS(2156),
    [anon_sym___extension__] = ACTIONS(2154),
    [anon_sym_typedef] = ACTIONS(2154),
    [anon_sym_in] = ACTIONS(2154),
    [anon_sym_out] = ACTIONS(2154),
    [anon_sym_inout] = ACTIONS(2154),
    [anon_sym_extern] = ACTIONS(2154),
    [anon_sym___attribute__] = ACTIONS(2154),
    [anon_sym_COLON_COLON] = ACTIONS(2156),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2156),
    [anon_sym___declspec] = ACTIONS(2154),
    [anon_sym___based] = ACTIONS(2154),
    [anon_sym___cdecl] = ACTIONS(2154),
    [anon_sym___clrcall] = ACTIONS(2154),
    [anon_sym___stdcall] = ACTIONS(2154),
    [anon_sym___fastcall] = ACTIONS(2154),
    [anon_sym___thiscall] = ACTIONS(2154),
    [anon_sym___vectorcall] = ACTIONS(2154),
    [anon_sym_LBRACE] = ACTIONS(2156),
    [anon_sym_signed] = ACTIONS(2154),
    [anon_sym_unsigned] = ACTIONS(2154),
    [anon_sym_long] = ACTIONS(2154),
    [anon_sym_short] = ACTIONS(2154),
    [anon_sym_LBRACK] = ACTIONS(2154),
    [anon_sym_static] = ACTIONS(2154),
    [anon_sym_register] = ACTIONS(2154),
    [anon_sym_inline] = ACTIONS(2154),
    [anon_sym___inline] = ACTIONS(2154),
    [anon_sym___inline__] = ACTIONS(2154),
    [anon_sym___forceinline] = ACTIONS(2154),
    [anon_sym_thread_local] = ACTIONS(2154),
    [anon_sym___thread] = ACTIONS(2154),
    [anon_sym_const] = ACTIONS(2154),
    [anon_sym_constexpr] = ACTIONS(2154),
    [anon_sym_volatile] = ACTIONS(2154),
    [anon_sym_restrict] = ACTIONS(2154),
    [anon_sym___restrict__] = ACTIONS(2154),
    [anon_sym__Atomic] = ACTIONS(2154),
    [anon_sym__Noreturn] = ACTIONS(2154),
    [anon_sym_noreturn] = ACTIONS(2154),
    [anon_sym_mutable] = ACTIONS(2154),
    [anon_sym_constinit] = ACTIONS(2154),
    [anon_sym_consteval] = ACTIONS(2154),
    [anon_sym_alignas] = ACTIONS(2154),
    [anon_sym__Alignas] = ACTIONS(2154),
    [sym_primitive_type] = ACTIONS(2154),
    [anon_sym_enum] = ACTIONS(2154),
    [anon_sym_class] = ACTIONS(2154),
    [anon_sym_struct] = ACTIONS(2154),
    [anon_sym_union] = ACTIONS(2154),
    [anon_sym_if] = ACTIONS(2154),
    [anon_sym_else] = ACTIONS(2154),
    [anon_sym_switch] = ACTIONS(2154),
    [anon_sym_case] = ACTIONS(2154),
    [anon_sym_default] = ACTIONS(2154),
    [anon_sym_while] = ACTIONS(2154),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_for] = ACTIONS(2154),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_break] = ACTIONS(2154),
    [anon_sym_continue] = ACTIONS(2154),
    [anon_sym_goto] = ACTIONS(2154),
    [anon_sym___try] = ACTIONS(2154),
    [anon_sym___leave] = ACTIONS(2154),
    [anon_sym_not] = ACTIONS(2154),
    [anon_sym_compl] = ACTIONS(2154),
    [anon_sym_DASH_DASH] = ACTIONS(2156),
    [anon_sym_PLUS_PLUS] = ACTIONS(2156),
    [anon_sym_sizeof] = ACTIONS(2154),
    [anon_sym___alignof__] = ACTIONS(2154),
    [anon_sym___alignof] = ACTIONS(2154),
    [anon_sym__alignof] = ACTIONS(2154),
    [anon_sym_alignof] = ACTIONS(2154),
    [anon_sym__Alignof] = ACTIONS(2154),
    [anon_sym_offsetof] = ACTIONS(2154),
    [anon_sym__Generic] = ACTIONS(2154),
    [anon_sym_asm] = ACTIONS(2154),
    [anon_sym___asm__] = ACTIONS(2154),
    [sym_number_literal] = ACTIONS(2156),
    [anon_sym_L_SQUOTE] = ACTIONS(2156),
    [anon_sym_u_SQUOTE] = ACTIONS(2156),
    [anon_sym_U_SQUOTE] = ACTIONS(2156),
    [anon_sym_u8_SQUOTE] = ACTIONS(2156),
    [anon_sym_SQUOTE] = ACTIONS(2156),
    [anon_sym_L_DQUOTE] = ACTIONS(2156),
    [anon_sym_u_DQUOTE] = ACTIONS(2156),
    [anon_sym_U_DQUOTE] = ACTIONS(2156),
    [anon_sym_u8_DQUOTE] = ACTIONS(2156),
    [anon_sym_DQUOTE] = ACTIONS(2156),
    [sym_true] = ACTIONS(2154),
    [sym_false] = ACTIONS(2154),
    [anon_sym_NULL] = ACTIONS(2154),
    [anon_sym_nullptr] = ACTIONS(2154),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2154),
    [anon_sym_decltype] = ACTIONS(2154),
    [sym_virtual] = ACTIONS(2154),
    [anon_sym_explicit] = ACTIONS(2154),
    [anon_sym_typename] = ACTIONS(2154),
    [anon_sym_template] = ACTIONS(2154),
    [anon_sym_operator] = ACTIONS(2154),
    [anon_sym_try] = ACTIONS(2154),
    [anon_sym_delete] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2154),
    [anon_sym_namespace] = ACTIONS(2154),
    [anon_sym_using] = ACTIONS(2154),
    [anon_sym_static_assert] = ACTIONS(2154),
    [anon_sym_concept] = ACTIONS(2154),
    [anon_sym_co_return] = ACTIONS(2154),
    [anon_sym_co_yield] = ACTIONS(2154),
    [anon_sym_R_DQUOTE] = ACTIONS(2156),
    [anon_sym_LR_DQUOTE] = ACTIONS(2156),
    [anon_sym_uR_DQUOTE] = ACTIONS(2156),
    [anon_sym_UR_DQUOTE] = ACTIONS(2156),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2156),
    [anon_sym_co_await] = ACTIONS(2154),
    [anon_sym_new] = ACTIONS(2154),
    [anon_sym_requires] = ACTIONS(2154),
    [sym_this] = ACTIONS(2154),
    [anon_sym_discard] = ACTIONS(2154),
    [anon_sym_precise] = ACTIONS(2154),
    [anon_sym_shared] = ACTIONS(2154),
    [anon_sym_groupshared] = ACTIONS(2154),
    [anon_sym_uniform] = ACTIONS(2154),
    [anon_sym_row_major] = ACTIONS(2154),
    [anon_sym_column_major] = ACTIONS(2154),
    [anon_sym_globallycoherent] = ACTIONS(2154),
    [anon_sym_centroid] = ACTIONS(2154),
    [anon_sym_noperspective] = ACTIONS(2154),
    [anon_sym_nointerpolation] = ACTIONS(2154),
    [anon_sym_sample] = ACTIONS(2154),
    [anon_sym_linear] = ACTIONS(2154),
    [anon_sym_snorm] = ACTIONS(2154),
    [anon_sym_unorm] = ACTIONS(2154),
    [anon_sym_point] = ACTIONS(2154),
    [anon_sym_line] = ACTIONS(2154),
    [anon_sym_triangleadj] = ACTIONS(2154),
    [anon_sym_lineadj] = ACTIONS(2154),
    [anon_sym_triangle] = ACTIONS(2154),
    [anon_sym_cbuffer] = ACTIONS(2154),
  },
  [196] = {
    [sym_identifier] = ACTIONS(2158),
    [aux_sym_preproc_include_token1] = ACTIONS(2158),
    [aux_sym_preproc_def_token1] = ACTIONS(2158),
    [aux_sym_preproc_if_token1] = ACTIONS(2158),
    [aux_sym_preproc_if_token2] = ACTIONS(2158),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2158),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2158),
    [aux_sym_preproc_else_token1] = ACTIONS(2158),
    [aux_sym_preproc_elif_token1] = ACTIONS(2158),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2158),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2158),
    [sym_preproc_directive] = ACTIONS(2158),
    [anon_sym_LPAREN2] = ACTIONS(2160),
    [anon_sym_BANG] = ACTIONS(2160),
    [anon_sym_TILDE] = ACTIONS(2160),
    [anon_sym_DASH] = ACTIONS(2158),
    [anon_sym_PLUS] = ACTIONS(2158),
    [anon_sym_STAR] = ACTIONS(2160),
    [anon_sym_AMP_AMP] = ACTIONS(2160),
    [anon_sym_AMP] = ACTIONS(2158),
    [anon_sym_SEMI] = ACTIONS(2160),
    [anon_sym___extension__] = ACTIONS(2158),
    [anon_sym_typedef] = ACTIONS(2158),
    [anon_sym_in] = ACTIONS(2158),
    [anon_sym_out] = ACTIONS(2158),
    [anon_sym_inout] = ACTIONS(2158),
    [anon_sym_extern] = ACTIONS(2158),
    [anon_sym___attribute__] = ACTIONS(2158),
    [anon_sym_COLON_COLON] = ACTIONS(2160),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2160),
    [anon_sym___declspec] = ACTIONS(2158),
    [anon_sym___based] = ACTIONS(2158),
    [anon_sym___cdecl] = ACTIONS(2158),
    [anon_sym___clrcall] = ACTIONS(2158),
    [anon_sym___stdcall] = ACTIONS(2158),
    [anon_sym___fastcall] = ACTIONS(2158),
    [anon_sym___thiscall] = ACTIONS(2158),
    [anon_sym___vectorcall] = ACTIONS(2158),
    [anon_sym_LBRACE] = ACTIONS(2160),
    [anon_sym_signed] = ACTIONS(2158),
    [anon_sym_unsigned] = ACTIONS(2158),
    [anon_sym_long] = ACTIONS(2158),
    [anon_sym_short] = ACTIONS(2158),
    [anon_sym_LBRACK] = ACTIONS(2158),
    [anon_sym_static] = ACTIONS(2158),
    [anon_sym_register] = ACTIONS(2158),
    [anon_sym_inline] = ACTIONS(2158),
    [anon_sym___inline] = ACTIONS(2158),
    [anon_sym___inline__] = ACTIONS(2158),
    [anon_sym___forceinline] = ACTIONS(2158),
    [anon_sym_thread_local] = ACTIONS(2158),
    [anon_sym___thread] = ACTIONS(2158),
    [anon_sym_const] = ACTIONS(2158),
    [anon_sym_constexpr] = ACTIONS(2158),
    [anon_sym_volatile] = ACTIONS(2158),
    [anon_sym_restrict] = ACTIONS(2158),
    [anon_sym___restrict__] = ACTIONS(2158),
    [anon_sym__Atomic] = ACTIONS(2158),
    [anon_sym__Noreturn] = ACTIONS(2158),
    [anon_sym_noreturn] = ACTIONS(2158),
    [anon_sym_mutable] = ACTIONS(2158),
    [anon_sym_constinit] = ACTIONS(2158),
    [anon_sym_consteval] = ACTIONS(2158),
    [anon_sym_alignas] = ACTIONS(2158),
    [anon_sym__Alignas] = ACTIONS(2158),
    [sym_primitive_type] = ACTIONS(2158),
    [anon_sym_enum] = ACTIONS(2158),
    [anon_sym_class] = ACTIONS(2158),
    [anon_sym_struct] = ACTIONS(2158),
    [anon_sym_union] = ACTIONS(2158),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_else] = ACTIONS(2158),
    [anon_sym_switch] = ACTIONS(2158),
    [anon_sym_case] = ACTIONS(2158),
    [anon_sym_default] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2158),
    [anon_sym_do] = ACTIONS(2158),
    [anon_sym_for] = ACTIONS(2158),
    [anon_sym_return] = ACTIONS(2158),
    [anon_sym_break] = ACTIONS(2158),
    [anon_sym_continue] = ACTIONS(2158),
    [anon_sym_goto] = ACTIONS(2158),
    [anon_sym___try] = ACTIONS(2158),
    [anon_sym___leave] = ACTIONS(2158),
    [anon_sym_not] = ACTIONS(2158),
    [anon_sym_compl] = ACTIONS(2158),
    [anon_sym_DASH_DASH] = ACTIONS(2160),
    [anon_sym_PLUS_PLUS] = ACTIONS(2160),
    [anon_sym_sizeof] = ACTIONS(2158),
    [anon_sym___alignof__] = ACTIONS(2158),
    [anon_sym___alignof] = ACTIONS(2158),
    [anon_sym__alignof] = ACTIONS(2158),
    [anon_sym_alignof] = ACTIONS(2158),
    [anon_sym__Alignof] = ACTIONS(2158),
    [anon_sym_offsetof] = ACTIONS(2158),
    [anon_sym__Generic] = ACTIONS(2158),
    [anon_sym_asm] = ACTIONS(2158),
    [anon_sym___asm__] = ACTIONS(2158),
    [sym_number_literal] = ACTIONS(2160),
    [anon_sym_L_SQUOTE] = ACTIONS(2160),
    [anon_sym_u_SQUOTE] = ACTIONS(2160),
    [anon_sym_U_SQUOTE] = ACTIONS(2160),
    [anon_sym_u8_SQUOTE] = ACTIONS(2160),
    [anon_sym_SQUOTE] = ACTIONS(2160),
    [anon_sym_L_DQUOTE] = ACTIONS(2160),
    [anon_sym_u_DQUOTE] = ACTIONS(2160),
    [anon_sym_U_DQUOTE] = ACTIONS(2160),
    [anon_sym_u8_DQUOTE] = ACTIONS(2160),
    [anon_sym_DQUOTE] = ACTIONS(2160),
    [sym_true] = ACTIONS(2158),
    [sym_false] = ACTIONS(2158),
    [anon_sym_NULL] = ACTIONS(2158),
    [anon_sym_nullptr] = ACTIONS(2158),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2158),
    [anon_sym_decltype] = ACTIONS(2158),
    [sym_virtual] = ACTIONS(2158),
    [anon_sym_explicit] = ACTIONS(2158),
    [anon_sym_typename] = ACTIONS(2158),
    [anon_sym_template] = ACTIONS(2158),
    [anon_sym_operator] = ACTIONS(2158),
    [anon_sym_try] = ACTIONS(2158),
    [anon_sym_delete] = ACTIONS(2158),
    [anon_sym_throw] = ACTIONS(2158),
    [anon_sym_namespace] = ACTIONS(2158),
    [anon_sym_using] = ACTIONS(2158),
    [anon_sym_static_assert] = ACTIONS(2158),
    [anon_sym_concept] = ACTIONS(2158),
    [anon_sym_co_return] = ACTIONS(2158),
    [anon_sym_co_yield] = ACTIONS(2158),
    [anon_sym_R_DQUOTE] = ACTIONS(2160),
    [anon_sym_LR_DQUOTE] = ACTIONS(2160),
    [anon_sym_uR_DQUOTE] = ACTIONS(2160),
    [anon_sym_UR_DQUOTE] = ACTIONS(2160),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2160),
    [anon_sym_co_await] = ACTIONS(2158),
    [anon_sym_new] = ACTIONS(2158),
    [anon_sym_requires] = ACTIONS(2158),
    [sym_this] = ACTIONS(2158),
    [anon_sym_discard] = ACTIONS(2158),
    [anon_sym_precise] = ACTIONS(2158),
    [anon_sym_shared] = ACTIONS(2158),
    [anon_sym_groupshared] = ACTIONS(2158),
    [anon_sym_uniform] = ACTIONS(2158),
    [anon_sym_row_major] = ACTIONS(2158),
    [anon_sym_column_major] = ACTIONS(2158),
    [anon_sym_globallycoherent] = ACTIONS(2158),
    [anon_sym_centroid] = ACTIONS(2158),
    [anon_sym_noperspective] = ACTIONS(2158),
    [anon_sym_nointerpolation] = ACTIONS(2158),
    [anon_sym_sample] = ACTIONS(2158),
    [anon_sym_linear] = ACTIONS(2158),
    [anon_sym_snorm] = ACTIONS(2158),
    [anon_sym_unorm] = ACTIONS(2158),
    [anon_sym_point] = ACTIONS(2158),
    [anon_sym_line] = ACTIONS(2158),
    [anon_sym_triangleadj] = ACTIONS(2158),
    [anon_sym_lineadj] = ACTIONS(2158),
    [anon_sym_triangle] = ACTIONS(2158),
    [anon_sym_cbuffer] = ACTIONS(2158),
  },
  [197] = {
    [sym_identifier] = ACTIONS(2162),
    [aux_sym_preproc_include_token1] = ACTIONS(2162),
    [aux_sym_preproc_def_token1] = ACTIONS(2162),
    [aux_sym_preproc_if_token1] = ACTIONS(2162),
    [aux_sym_preproc_if_token2] = ACTIONS(2162),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2162),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2162),
    [aux_sym_preproc_else_token1] = ACTIONS(2162),
    [aux_sym_preproc_elif_token1] = ACTIONS(2162),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2162),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2162),
    [sym_preproc_directive] = ACTIONS(2162),
    [anon_sym_LPAREN2] = ACTIONS(2164),
    [anon_sym_BANG] = ACTIONS(2164),
    [anon_sym_TILDE] = ACTIONS(2164),
    [anon_sym_DASH] = ACTIONS(2162),
    [anon_sym_PLUS] = ACTIONS(2162),
    [anon_sym_STAR] = ACTIONS(2164),
    [anon_sym_AMP_AMP] = ACTIONS(2164),
    [anon_sym_AMP] = ACTIONS(2162),
    [anon_sym_SEMI] = ACTIONS(2164),
    [anon_sym___extension__] = ACTIONS(2162),
    [anon_sym_typedef] = ACTIONS(2162),
    [anon_sym_in] = ACTIONS(2162),
    [anon_sym_out] = ACTIONS(2162),
    [anon_sym_inout] = ACTIONS(2162),
    [anon_sym_extern] = ACTIONS(2162),
    [anon_sym___attribute__] = ACTIONS(2162),
    [anon_sym_COLON_COLON] = ACTIONS(2164),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2164),
    [anon_sym___declspec] = ACTIONS(2162),
    [anon_sym___based] = ACTIONS(2162),
    [anon_sym___cdecl] = ACTIONS(2162),
    [anon_sym___clrcall] = ACTIONS(2162),
    [anon_sym___stdcall] = ACTIONS(2162),
    [anon_sym___fastcall] = ACTIONS(2162),
    [anon_sym___thiscall] = ACTIONS(2162),
    [anon_sym___vectorcall] = ACTIONS(2162),
    [anon_sym_LBRACE] = ACTIONS(2164),
    [anon_sym_signed] = ACTIONS(2162),
    [anon_sym_unsigned] = ACTIONS(2162),
    [anon_sym_long] = ACTIONS(2162),
    [anon_sym_short] = ACTIONS(2162),
    [anon_sym_LBRACK] = ACTIONS(2162),
    [anon_sym_static] = ACTIONS(2162),
    [anon_sym_register] = ACTIONS(2162),
    [anon_sym_inline] = ACTIONS(2162),
    [anon_sym___inline] = ACTIONS(2162),
    [anon_sym___inline__] = ACTIONS(2162),
    [anon_sym___forceinline] = ACTIONS(2162),
    [anon_sym_thread_local] = ACTIONS(2162),
    [anon_sym___thread] = ACTIONS(2162),
    [anon_sym_const] = ACTIONS(2162),
    [anon_sym_constexpr] = ACTIONS(2162),
    [anon_sym_volatile] = ACTIONS(2162),
    [anon_sym_restrict] = ACTIONS(2162),
    [anon_sym___restrict__] = ACTIONS(2162),
    [anon_sym__Atomic] = ACTIONS(2162),
    [anon_sym__Noreturn] = ACTIONS(2162),
    [anon_sym_noreturn] = ACTIONS(2162),
    [anon_sym_mutable] = ACTIONS(2162),
    [anon_sym_constinit] = ACTIONS(2162),
    [anon_sym_consteval] = ACTIONS(2162),
    [anon_sym_alignas] = ACTIONS(2162),
    [anon_sym__Alignas] = ACTIONS(2162),
    [sym_primitive_type] = ACTIONS(2162),
    [anon_sym_enum] = ACTIONS(2162),
    [anon_sym_class] = ACTIONS(2162),
    [anon_sym_struct] = ACTIONS(2162),
    [anon_sym_union] = ACTIONS(2162),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_else] = ACTIONS(2162),
    [anon_sym_switch] = ACTIONS(2162),
    [anon_sym_case] = ACTIONS(2162),
    [anon_sym_default] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(2162),
    [anon_sym_do] = ACTIONS(2162),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_return] = ACTIONS(2162),
    [anon_sym_break] = ACTIONS(2162),
    [anon_sym_continue] = ACTIONS(2162),
    [anon_sym_goto] = ACTIONS(2162),
    [anon_sym___try] = ACTIONS(2162),
    [anon_sym___leave] = ACTIONS(2162),
    [anon_sym_not] = ACTIONS(2162),
    [anon_sym_compl] = ACTIONS(2162),
    [anon_sym_DASH_DASH] = ACTIONS(2164),
    [anon_sym_PLUS_PLUS] = ACTIONS(2164),
    [anon_sym_sizeof] = ACTIONS(2162),
    [anon_sym___alignof__] = ACTIONS(2162),
    [anon_sym___alignof] = ACTIONS(2162),
    [anon_sym__alignof] = ACTIONS(2162),
    [anon_sym_alignof] = ACTIONS(2162),
    [anon_sym__Alignof] = ACTIONS(2162),
    [anon_sym_offsetof] = ACTIONS(2162),
    [anon_sym__Generic] = ACTIONS(2162),
    [anon_sym_asm] = ACTIONS(2162),
    [anon_sym___asm__] = ACTIONS(2162),
    [sym_number_literal] = ACTIONS(2164),
    [anon_sym_L_SQUOTE] = ACTIONS(2164),
    [anon_sym_u_SQUOTE] = ACTIONS(2164),
    [anon_sym_U_SQUOTE] = ACTIONS(2164),
    [anon_sym_u8_SQUOTE] = ACTIONS(2164),
    [anon_sym_SQUOTE] = ACTIONS(2164),
    [anon_sym_L_DQUOTE] = ACTIONS(2164),
    [anon_sym_u_DQUOTE] = ACTIONS(2164),
    [anon_sym_U_DQUOTE] = ACTIONS(2164),
    [anon_sym_u8_DQUOTE] = ACTIONS(2164),
    [anon_sym_DQUOTE] = ACTIONS(2164),
    [sym_true] = ACTIONS(2162),
    [sym_false] = ACTIONS(2162),
    [anon_sym_NULL] = ACTIONS(2162),
    [anon_sym_nullptr] = ACTIONS(2162),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2162),
    [anon_sym_decltype] = ACTIONS(2162),
    [sym_virtual] = ACTIONS(2162),
    [anon_sym_explicit] = ACTIONS(2162),
    [anon_sym_typename] = ACTIONS(2162),
    [anon_sym_template] = ACTIONS(2162),
    [anon_sym_operator] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2162),
    [anon_sym_delete] = ACTIONS(2162),
    [anon_sym_throw] = ACTIONS(2162),
    [anon_sym_namespace] = ACTIONS(2162),
    [anon_sym_using] = ACTIONS(2162),
    [anon_sym_static_assert] = ACTIONS(2162),
    [anon_sym_concept] = ACTIONS(2162),
    [anon_sym_co_return] = ACTIONS(2162),
    [anon_sym_co_yield] = ACTIONS(2162),
    [anon_sym_R_DQUOTE] = ACTIONS(2164),
    [anon_sym_LR_DQUOTE] = ACTIONS(2164),
    [anon_sym_uR_DQUOTE] = ACTIONS(2164),
    [anon_sym_UR_DQUOTE] = ACTIONS(2164),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2164),
    [anon_sym_co_await] = ACTIONS(2162),
    [anon_sym_new] = ACTIONS(2162),
    [anon_sym_requires] = ACTIONS(2162),
    [sym_this] = ACTIONS(2162),
    [anon_sym_discard] = ACTIONS(2162),
    [anon_sym_precise] = ACTIONS(2162),
    [anon_sym_shared] = ACTIONS(2162),
    [anon_sym_groupshared] = ACTIONS(2162),
    [anon_sym_uniform] = ACTIONS(2162),
    [anon_sym_row_major] = ACTIONS(2162),
    [anon_sym_column_major] = ACTIONS(2162),
    [anon_sym_globallycoherent] = ACTIONS(2162),
    [anon_sym_centroid] = ACTIONS(2162),
    [anon_sym_noperspective] = ACTIONS(2162),
    [anon_sym_nointerpolation] = ACTIONS(2162),
    [anon_sym_sample] = ACTIONS(2162),
    [anon_sym_linear] = ACTIONS(2162),
    [anon_sym_snorm] = ACTIONS(2162),
    [anon_sym_unorm] = ACTIONS(2162),
    [anon_sym_point] = ACTIONS(2162),
    [anon_sym_line] = ACTIONS(2162),
    [anon_sym_triangleadj] = ACTIONS(2162),
    [anon_sym_lineadj] = ACTIONS(2162),
    [anon_sym_triangle] = ACTIONS(2162),
    [anon_sym_cbuffer] = ACTIONS(2162),
  },
  [198] = {
    [sym_identifier] = ACTIONS(2166),
    [aux_sym_preproc_include_token1] = ACTIONS(2166),
    [aux_sym_preproc_def_token1] = ACTIONS(2166),
    [aux_sym_preproc_if_token1] = ACTIONS(2166),
    [aux_sym_preproc_if_token2] = ACTIONS(2166),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2166),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2166),
    [aux_sym_preproc_else_token1] = ACTIONS(2166),
    [aux_sym_preproc_elif_token1] = ACTIONS(2166),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2166),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2166),
    [sym_preproc_directive] = ACTIONS(2166),
    [anon_sym_LPAREN2] = ACTIONS(2168),
    [anon_sym_BANG] = ACTIONS(2168),
    [anon_sym_TILDE] = ACTIONS(2168),
    [anon_sym_DASH] = ACTIONS(2166),
    [anon_sym_PLUS] = ACTIONS(2166),
    [anon_sym_STAR] = ACTIONS(2168),
    [anon_sym_AMP_AMP] = ACTIONS(2168),
    [anon_sym_AMP] = ACTIONS(2166),
    [anon_sym_SEMI] = ACTIONS(2168),
    [anon_sym___extension__] = ACTIONS(2166),
    [anon_sym_typedef] = ACTIONS(2166),
    [anon_sym_in] = ACTIONS(2166),
    [anon_sym_out] = ACTIONS(2166),
    [anon_sym_inout] = ACTIONS(2166),
    [anon_sym_extern] = ACTIONS(2166),
    [anon_sym___attribute__] = ACTIONS(2166),
    [anon_sym_COLON_COLON] = ACTIONS(2168),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2168),
    [anon_sym___declspec] = ACTIONS(2166),
    [anon_sym___based] = ACTIONS(2166),
    [anon_sym___cdecl] = ACTIONS(2166),
    [anon_sym___clrcall] = ACTIONS(2166),
    [anon_sym___stdcall] = ACTIONS(2166),
    [anon_sym___fastcall] = ACTIONS(2166),
    [anon_sym___thiscall] = ACTIONS(2166),
    [anon_sym___vectorcall] = ACTIONS(2166),
    [anon_sym_LBRACE] = ACTIONS(2168),
    [anon_sym_signed] = ACTIONS(2166),
    [anon_sym_unsigned] = ACTIONS(2166),
    [anon_sym_long] = ACTIONS(2166),
    [anon_sym_short] = ACTIONS(2166),
    [anon_sym_LBRACK] = ACTIONS(2166),
    [anon_sym_static] = ACTIONS(2166),
    [anon_sym_register] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(2166),
    [anon_sym___inline] = ACTIONS(2166),
    [anon_sym___inline__] = ACTIONS(2166),
    [anon_sym___forceinline] = ACTIONS(2166),
    [anon_sym_thread_local] = ACTIONS(2166),
    [anon_sym___thread] = ACTIONS(2166),
    [anon_sym_const] = ACTIONS(2166),
    [anon_sym_constexpr] = ACTIONS(2166),
    [anon_sym_volatile] = ACTIONS(2166),
    [anon_sym_restrict] = ACTIONS(2166),
    [anon_sym___restrict__] = ACTIONS(2166),
    [anon_sym__Atomic] = ACTIONS(2166),
    [anon_sym__Noreturn] = ACTIONS(2166),
    [anon_sym_noreturn] = ACTIONS(2166),
    [anon_sym_mutable] = ACTIONS(2166),
    [anon_sym_constinit] = ACTIONS(2166),
    [anon_sym_consteval] = ACTIONS(2166),
    [anon_sym_alignas] = ACTIONS(2166),
    [anon_sym__Alignas] = ACTIONS(2166),
    [sym_primitive_type] = ACTIONS(2166),
    [anon_sym_enum] = ACTIONS(2166),
    [anon_sym_class] = ACTIONS(2166),
    [anon_sym_struct] = ACTIONS(2166),
    [anon_sym_union] = ACTIONS(2166),
    [anon_sym_if] = ACTIONS(2166),
    [anon_sym_else] = ACTIONS(2166),
    [anon_sym_switch] = ACTIONS(2166),
    [anon_sym_case] = ACTIONS(2166),
    [anon_sym_default] = ACTIONS(2166),
    [anon_sym_while] = ACTIONS(2166),
    [anon_sym_do] = ACTIONS(2166),
    [anon_sym_for] = ACTIONS(2166),
    [anon_sym_return] = ACTIONS(2166),
    [anon_sym_break] = ACTIONS(2166),
    [anon_sym_continue] = ACTIONS(2166),
    [anon_sym_goto] = ACTIONS(2166),
    [anon_sym___try] = ACTIONS(2166),
    [anon_sym___leave] = ACTIONS(2166),
    [anon_sym_not] = ACTIONS(2166),
    [anon_sym_compl] = ACTIONS(2166),
    [anon_sym_DASH_DASH] = ACTIONS(2168),
    [anon_sym_PLUS_PLUS] = ACTIONS(2168),
    [anon_sym_sizeof] = ACTIONS(2166),
    [anon_sym___alignof__] = ACTIONS(2166),
    [anon_sym___alignof] = ACTIONS(2166),
    [anon_sym__alignof] = ACTIONS(2166),
    [anon_sym_alignof] = ACTIONS(2166),
    [anon_sym__Alignof] = ACTIONS(2166),
    [anon_sym_offsetof] = ACTIONS(2166),
    [anon_sym__Generic] = ACTIONS(2166),
    [anon_sym_asm] = ACTIONS(2166),
    [anon_sym___asm__] = ACTIONS(2166),
    [sym_number_literal] = ACTIONS(2168),
    [anon_sym_L_SQUOTE] = ACTIONS(2168),
    [anon_sym_u_SQUOTE] = ACTIONS(2168),
    [anon_sym_U_SQUOTE] = ACTIONS(2168),
    [anon_sym_u8_SQUOTE] = ACTIONS(2168),
    [anon_sym_SQUOTE] = ACTIONS(2168),
    [anon_sym_L_DQUOTE] = ACTIONS(2168),
    [anon_sym_u_DQUOTE] = ACTIONS(2168),
    [anon_sym_U_DQUOTE] = ACTIONS(2168),
    [anon_sym_u8_DQUOTE] = ACTIONS(2168),
    [anon_sym_DQUOTE] = ACTIONS(2168),
    [sym_true] = ACTIONS(2166),
    [sym_false] = ACTIONS(2166),
    [anon_sym_NULL] = ACTIONS(2166),
    [anon_sym_nullptr] = ACTIONS(2166),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2166),
    [anon_sym_decltype] = ACTIONS(2166),
    [sym_virtual] = ACTIONS(2166),
    [anon_sym_explicit] = ACTIONS(2166),
    [anon_sym_typename] = ACTIONS(2166),
    [anon_sym_template] = ACTIONS(2166),
    [anon_sym_operator] = ACTIONS(2166),
    [anon_sym_try] = ACTIONS(2166),
    [anon_sym_delete] = ACTIONS(2166),
    [anon_sym_throw] = ACTIONS(2166),
    [anon_sym_namespace] = ACTIONS(2166),
    [anon_sym_using] = ACTIONS(2166),
    [anon_sym_static_assert] = ACTIONS(2166),
    [anon_sym_concept] = ACTIONS(2166),
    [anon_sym_co_return] = ACTIONS(2166),
    [anon_sym_co_yield] = ACTIONS(2166),
    [anon_sym_R_DQUOTE] = ACTIONS(2168),
    [anon_sym_LR_DQUOTE] = ACTIONS(2168),
    [anon_sym_uR_DQUOTE] = ACTIONS(2168),
    [anon_sym_UR_DQUOTE] = ACTIONS(2168),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2168),
    [anon_sym_co_await] = ACTIONS(2166),
    [anon_sym_new] = ACTIONS(2166),
    [anon_sym_requires] = ACTIONS(2166),
    [sym_this] = ACTIONS(2166),
    [anon_sym_discard] = ACTIONS(2166),
    [anon_sym_precise] = ACTIONS(2166),
    [anon_sym_shared] = ACTIONS(2166),
    [anon_sym_groupshared] = ACTIONS(2166),
    [anon_sym_uniform] = ACTIONS(2166),
    [anon_sym_row_major] = ACTIONS(2166),
    [anon_sym_column_major] = ACTIONS(2166),
    [anon_sym_globallycoherent] = ACTIONS(2166),
    [anon_sym_centroid] = ACTIONS(2166),
    [anon_sym_noperspective] = ACTIONS(2166),
    [anon_sym_nointerpolation] = ACTIONS(2166),
    [anon_sym_sample] = ACTIONS(2166),
    [anon_sym_linear] = ACTIONS(2166),
    [anon_sym_snorm] = ACTIONS(2166),
    [anon_sym_unorm] = ACTIONS(2166),
    [anon_sym_point] = ACTIONS(2166),
    [anon_sym_line] = ACTIONS(2166),
    [anon_sym_triangleadj] = ACTIONS(2166),
    [anon_sym_lineadj] = ACTIONS(2166),
    [anon_sym_triangle] = ACTIONS(2166),
    [anon_sym_cbuffer] = ACTIONS(2166),
  },
  [199] = {
    [sym_identifier] = ACTIONS(2170),
    [aux_sym_preproc_include_token1] = ACTIONS(2170),
    [aux_sym_preproc_def_token1] = ACTIONS(2170),
    [aux_sym_preproc_if_token1] = ACTIONS(2170),
    [aux_sym_preproc_if_token2] = ACTIONS(2170),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2170),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2170),
    [aux_sym_preproc_else_token1] = ACTIONS(2170),
    [aux_sym_preproc_elif_token1] = ACTIONS(2170),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2170),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2170),
    [sym_preproc_directive] = ACTIONS(2170),
    [anon_sym_LPAREN2] = ACTIONS(2172),
    [anon_sym_BANG] = ACTIONS(2172),
    [anon_sym_TILDE] = ACTIONS(2172),
    [anon_sym_DASH] = ACTIONS(2170),
    [anon_sym_PLUS] = ACTIONS(2170),
    [anon_sym_STAR] = ACTIONS(2172),
    [anon_sym_AMP_AMP] = ACTIONS(2172),
    [anon_sym_AMP] = ACTIONS(2170),
    [anon_sym_SEMI] = ACTIONS(2172),
    [anon_sym___extension__] = ACTIONS(2170),
    [anon_sym_typedef] = ACTIONS(2170),
    [anon_sym_in] = ACTIONS(2170),
    [anon_sym_out] = ACTIONS(2170),
    [anon_sym_inout] = ACTIONS(2170),
    [anon_sym_extern] = ACTIONS(2170),
    [anon_sym___attribute__] = ACTIONS(2170),
    [anon_sym_COLON_COLON] = ACTIONS(2172),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2172),
    [anon_sym___declspec] = ACTIONS(2170),
    [anon_sym___based] = ACTIONS(2170),
    [anon_sym___cdecl] = ACTIONS(2170),
    [anon_sym___clrcall] = ACTIONS(2170),
    [anon_sym___stdcall] = ACTIONS(2170),
    [anon_sym___fastcall] = ACTIONS(2170),
    [anon_sym___thiscall] = ACTIONS(2170),
    [anon_sym___vectorcall] = ACTIONS(2170),
    [anon_sym_LBRACE] = ACTIONS(2172),
    [anon_sym_signed] = ACTIONS(2170),
    [anon_sym_unsigned] = ACTIONS(2170),
    [anon_sym_long] = ACTIONS(2170),
    [anon_sym_short] = ACTIONS(2170),
    [anon_sym_LBRACK] = ACTIONS(2170),
    [anon_sym_static] = ACTIONS(2170),
    [anon_sym_register] = ACTIONS(2170),
    [anon_sym_inline] = ACTIONS(2170),
    [anon_sym___inline] = ACTIONS(2170),
    [anon_sym___inline__] = ACTIONS(2170),
    [anon_sym___forceinline] = ACTIONS(2170),
    [anon_sym_thread_local] = ACTIONS(2170),
    [anon_sym___thread] = ACTIONS(2170),
    [anon_sym_const] = ACTIONS(2170),
    [anon_sym_constexpr] = ACTIONS(2170),
    [anon_sym_volatile] = ACTIONS(2170),
    [anon_sym_restrict] = ACTIONS(2170),
    [anon_sym___restrict__] = ACTIONS(2170),
    [anon_sym__Atomic] = ACTIONS(2170),
    [anon_sym__Noreturn] = ACTIONS(2170),
    [anon_sym_noreturn] = ACTIONS(2170),
    [anon_sym_mutable] = ACTIONS(2170),
    [anon_sym_constinit] = ACTIONS(2170),
    [anon_sym_consteval] = ACTIONS(2170),
    [anon_sym_alignas] = ACTIONS(2170),
    [anon_sym__Alignas] = ACTIONS(2170),
    [sym_primitive_type] = ACTIONS(2170),
    [anon_sym_enum] = ACTIONS(2170),
    [anon_sym_class] = ACTIONS(2170),
    [anon_sym_struct] = ACTIONS(2170),
    [anon_sym_union] = ACTIONS(2170),
    [anon_sym_if] = ACTIONS(2170),
    [anon_sym_else] = ACTIONS(2170),
    [anon_sym_switch] = ACTIONS(2170),
    [anon_sym_case] = ACTIONS(2170),
    [anon_sym_default] = ACTIONS(2170),
    [anon_sym_while] = ACTIONS(2170),
    [anon_sym_do] = ACTIONS(2170),
    [anon_sym_for] = ACTIONS(2170),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_break] = ACTIONS(2170),
    [anon_sym_continue] = ACTIONS(2170),
    [anon_sym_goto] = ACTIONS(2170),
    [anon_sym___try] = ACTIONS(2170),
    [anon_sym___leave] = ACTIONS(2170),
    [anon_sym_not] = ACTIONS(2170),
    [anon_sym_compl] = ACTIONS(2170),
    [anon_sym_DASH_DASH] = ACTIONS(2172),
    [anon_sym_PLUS_PLUS] = ACTIONS(2172),
    [anon_sym_sizeof] = ACTIONS(2170),
    [anon_sym___alignof__] = ACTIONS(2170),
    [anon_sym___alignof] = ACTIONS(2170),
    [anon_sym__alignof] = ACTIONS(2170),
    [anon_sym_alignof] = ACTIONS(2170),
    [anon_sym__Alignof] = ACTIONS(2170),
    [anon_sym_offsetof] = ACTIONS(2170),
    [anon_sym__Generic] = ACTIONS(2170),
    [anon_sym_asm] = ACTIONS(2170),
    [anon_sym___asm__] = ACTIONS(2170),
    [sym_number_literal] = ACTIONS(2172),
    [anon_sym_L_SQUOTE] = ACTIONS(2172),
    [anon_sym_u_SQUOTE] = ACTIONS(2172),
    [anon_sym_U_SQUOTE] = ACTIONS(2172),
    [anon_sym_u8_SQUOTE] = ACTIONS(2172),
    [anon_sym_SQUOTE] = ACTIONS(2172),
    [anon_sym_L_DQUOTE] = ACTIONS(2172),
    [anon_sym_u_DQUOTE] = ACTIONS(2172),
    [anon_sym_U_DQUOTE] = ACTIONS(2172),
    [anon_sym_u8_DQUOTE] = ACTIONS(2172),
    [anon_sym_DQUOTE] = ACTIONS(2172),
    [sym_true] = ACTIONS(2170),
    [sym_false] = ACTIONS(2170),
    [anon_sym_NULL] = ACTIONS(2170),
    [anon_sym_nullptr] = ACTIONS(2170),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2170),
    [anon_sym_decltype] = ACTIONS(2170),
    [sym_virtual] = ACTIONS(2170),
    [anon_sym_explicit] = ACTIONS(2170),
    [anon_sym_typename] = ACTIONS(2170),
    [anon_sym_template] = ACTIONS(2170),
    [anon_sym_operator] = ACTIONS(2170),
    [anon_sym_try] = ACTIONS(2170),
    [anon_sym_delete] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2170),
    [anon_sym_namespace] = ACTIONS(2170),
    [anon_sym_using] = ACTIONS(2170),
    [anon_sym_static_assert] = ACTIONS(2170),
    [anon_sym_concept] = ACTIONS(2170),
    [anon_sym_co_return] = ACTIONS(2170),
    [anon_sym_co_yield] = ACTIONS(2170),
    [anon_sym_R_DQUOTE] = ACTIONS(2172),
    [anon_sym_LR_DQUOTE] = ACTIONS(2172),
    [anon_sym_uR_DQUOTE] = ACTIONS(2172),
    [anon_sym_UR_DQUOTE] = ACTIONS(2172),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2172),
    [anon_sym_co_await] = ACTIONS(2170),
    [anon_sym_new] = ACTIONS(2170),
    [anon_sym_requires] = ACTIONS(2170),
    [sym_this] = ACTIONS(2170),
    [anon_sym_discard] = ACTIONS(2170),
    [anon_sym_precise] = ACTIONS(2170),
    [anon_sym_shared] = ACTIONS(2170),
    [anon_sym_groupshared] = ACTIONS(2170),
    [anon_sym_uniform] = ACTIONS(2170),
    [anon_sym_row_major] = ACTIONS(2170),
    [anon_sym_column_major] = ACTIONS(2170),
    [anon_sym_globallycoherent] = ACTIONS(2170),
    [anon_sym_centroid] = ACTIONS(2170),
    [anon_sym_noperspective] = ACTIONS(2170),
    [anon_sym_nointerpolation] = ACTIONS(2170),
    [anon_sym_sample] = ACTIONS(2170),
    [anon_sym_linear] = ACTIONS(2170),
    [anon_sym_snorm] = ACTIONS(2170),
    [anon_sym_unorm] = ACTIONS(2170),
    [anon_sym_point] = ACTIONS(2170),
    [anon_sym_line] = ACTIONS(2170),
    [anon_sym_triangleadj] = ACTIONS(2170),
    [anon_sym_lineadj] = ACTIONS(2170),
    [anon_sym_triangle] = ACTIONS(2170),
    [anon_sym_cbuffer] = ACTIONS(2170),
  },
  [200] = {
    [sym_identifier] = ACTIONS(2174),
    [aux_sym_preproc_include_token1] = ACTIONS(2174),
    [aux_sym_preproc_def_token1] = ACTIONS(2174),
    [aux_sym_preproc_if_token1] = ACTIONS(2174),
    [aux_sym_preproc_if_token2] = ACTIONS(2174),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2174),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2174),
    [aux_sym_preproc_else_token1] = ACTIONS(2174),
    [aux_sym_preproc_elif_token1] = ACTIONS(2174),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2174),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2174),
    [sym_preproc_directive] = ACTIONS(2174),
    [anon_sym_LPAREN2] = ACTIONS(2176),
    [anon_sym_BANG] = ACTIONS(2176),
    [anon_sym_TILDE] = ACTIONS(2176),
    [anon_sym_DASH] = ACTIONS(2174),
    [anon_sym_PLUS] = ACTIONS(2174),
    [anon_sym_STAR] = ACTIONS(2176),
    [anon_sym_AMP_AMP] = ACTIONS(2176),
    [anon_sym_AMP] = ACTIONS(2174),
    [anon_sym_SEMI] = ACTIONS(2176),
    [anon_sym___extension__] = ACTIONS(2174),
    [anon_sym_typedef] = ACTIONS(2174),
    [anon_sym_in] = ACTIONS(2174),
    [anon_sym_out] = ACTIONS(2174),
    [anon_sym_inout] = ACTIONS(2174),
    [anon_sym_extern] = ACTIONS(2174),
    [anon_sym___attribute__] = ACTIONS(2174),
    [anon_sym_COLON_COLON] = ACTIONS(2176),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2176),
    [anon_sym___declspec] = ACTIONS(2174),
    [anon_sym___based] = ACTIONS(2174),
    [anon_sym___cdecl] = ACTIONS(2174),
    [anon_sym___clrcall] = ACTIONS(2174),
    [anon_sym___stdcall] = ACTIONS(2174),
    [anon_sym___fastcall] = ACTIONS(2174),
    [anon_sym___thiscall] = ACTIONS(2174),
    [anon_sym___vectorcall] = ACTIONS(2174),
    [anon_sym_LBRACE] = ACTIONS(2176),
    [anon_sym_signed] = ACTIONS(2174),
    [anon_sym_unsigned] = ACTIONS(2174),
    [anon_sym_long] = ACTIONS(2174),
    [anon_sym_short] = ACTIONS(2174),
    [anon_sym_LBRACK] = ACTIONS(2174),
    [anon_sym_static] = ACTIONS(2174),
    [anon_sym_register] = ACTIONS(2174),
    [anon_sym_inline] = ACTIONS(2174),
    [anon_sym___inline] = ACTIONS(2174),
    [anon_sym___inline__] = ACTIONS(2174),
    [anon_sym___forceinline] = ACTIONS(2174),
    [anon_sym_thread_local] = ACTIONS(2174),
    [anon_sym___thread] = ACTIONS(2174),
    [anon_sym_const] = ACTIONS(2174),
    [anon_sym_constexpr] = ACTIONS(2174),
    [anon_sym_volatile] = ACTIONS(2174),
    [anon_sym_restrict] = ACTIONS(2174),
    [anon_sym___restrict__] = ACTIONS(2174),
    [anon_sym__Atomic] = ACTIONS(2174),
    [anon_sym__Noreturn] = ACTIONS(2174),
    [anon_sym_noreturn] = ACTIONS(2174),
    [anon_sym_mutable] = ACTIONS(2174),
    [anon_sym_constinit] = ACTIONS(2174),
    [anon_sym_consteval] = ACTIONS(2174),
    [anon_sym_alignas] = ACTIONS(2174),
    [anon_sym__Alignas] = ACTIONS(2174),
    [sym_primitive_type] = ACTIONS(2174),
    [anon_sym_enum] = ACTIONS(2174),
    [anon_sym_class] = ACTIONS(2174),
    [anon_sym_struct] = ACTIONS(2174),
    [anon_sym_union] = ACTIONS(2174),
    [anon_sym_if] = ACTIONS(2174),
    [anon_sym_else] = ACTIONS(2174),
    [anon_sym_switch] = ACTIONS(2174),
    [anon_sym_case] = ACTIONS(2174),
    [anon_sym_default] = ACTIONS(2174),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_do] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2174),
    [anon_sym_return] = ACTIONS(2174),
    [anon_sym_break] = ACTIONS(2174),
    [anon_sym_continue] = ACTIONS(2174),
    [anon_sym_goto] = ACTIONS(2174),
    [anon_sym___try] = ACTIONS(2174),
    [anon_sym___leave] = ACTIONS(2174),
    [anon_sym_not] = ACTIONS(2174),
    [anon_sym_compl] = ACTIONS(2174),
    [anon_sym_DASH_DASH] = ACTIONS(2176),
    [anon_sym_PLUS_PLUS] = ACTIONS(2176),
    [anon_sym_sizeof] = ACTIONS(2174),
    [anon_sym___alignof__] = ACTIONS(2174),
    [anon_sym___alignof] = ACTIONS(2174),
    [anon_sym__alignof] = ACTIONS(2174),
    [anon_sym_alignof] = ACTIONS(2174),
    [anon_sym__Alignof] = ACTIONS(2174),
    [anon_sym_offsetof] = ACTIONS(2174),
    [anon_sym__Generic] = ACTIONS(2174),
    [anon_sym_asm] = ACTIONS(2174),
    [anon_sym___asm__] = ACTIONS(2174),
    [sym_number_literal] = ACTIONS(2176),
    [anon_sym_L_SQUOTE] = ACTIONS(2176),
    [anon_sym_u_SQUOTE] = ACTIONS(2176),
    [anon_sym_U_SQUOTE] = ACTIONS(2176),
    [anon_sym_u8_SQUOTE] = ACTIONS(2176),
    [anon_sym_SQUOTE] = ACTIONS(2176),
    [anon_sym_L_DQUOTE] = ACTIONS(2176),
    [anon_sym_u_DQUOTE] = ACTIONS(2176),
    [anon_sym_U_DQUOTE] = ACTIONS(2176),
    [anon_sym_u8_DQUOTE] = ACTIONS(2176),
    [anon_sym_DQUOTE] = ACTIONS(2176),
    [sym_true] = ACTIONS(2174),
    [sym_false] = ACTIONS(2174),
    [anon_sym_NULL] = ACTIONS(2174),
    [anon_sym_nullptr] = ACTIONS(2174),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2174),
    [anon_sym_decltype] = ACTIONS(2174),
    [sym_virtual] = ACTIONS(2174),
    [anon_sym_explicit] = ACTIONS(2174),
    [anon_sym_typename] = ACTIONS(2174),
    [anon_sym_template] = ACTIONS(2174),
    [anon_sym_operator] = ACTIONS(2174),
    [anon_sym_try] = ACTIONS(2174),
    [anon_sym_delete] = ACTIONS(2174),
    [anon_sym_throw] = ACTIONS(2174),
    [anon_sym_namespace] = ACTIONS(2174),
    [anon_sym_using] = ACTIONS(2174),
    [anon_sym_static_assert] = ACTIONS(2174),
    [anon_sym_concept] = ACTIONS(2174),
    [anon_sym_co_return] = ACTIONS(2174),
    [anon_sym_co_yield] = ACTIONS(2174),
    [anon_sym_R_DQUOTE] = ACTIONS(2176),
    [anon_sym_LR_DQUOTE] = ACTIONS(2176),
    [anon_sym_uR_DQUOTE] = ACTIONS(2176),
    [anon_sym_UR_DQUOTE] = ACTIONS(2176),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2176),
    [anon_sym_co_await] = ACTIONS(2174),
    [anon_sym_new] = ACTIONS(2174),
    [anon_sym_requires] = ACTIONS(2174),
    [sym_this] = ACTIONS(2174),
    [anon_sym_discard] = ACTIONS(2174),
    [anon_sym_precise] = ACTIONS(2174),
    [anon_sym_shared] = ACTIONS(2174),
    [anon_sym_groupshared] = ACTIONS(2174),
    [anon_sym_uniform] = ACTIONS(2174),
    [anon_sym_row_major] = ACTIONS(2174),
    [anon_sym_column_major] = ACTIONS(2174),
    [anon_sym_globallycoherent] = ACTIONS(2174),
    [anon_sym_centroid] = ACTIONS(2174),
    [anon_sym_noperspective] = ACTIONS(2174),
    [anon_sym_nointerpolation] = ACTIONS(2174),
    [anon_sym_sample] = ACTIONS(2174),
    [anon_sym_linear] = ACTIONS(2174),
    [anon_sym_snorm] = ACTIONS(2174),
    [anon_sym_unorm] = ACTIONS(2174),
    [anon_sym_point] = ACTIONS(2174),
    [anon_sym_line] = ACTIONS(2174),
    [anon_sym_triangleadj] = ACTIONS(2174),
    [anon_sym_lineadj] = ACTIONS(2174),
    [anon_sym_triangle] = ACTIONS(2174),
    [anon_sym_cbuffer] = ACTIONS(2174),
  },
  [201] = {
    [sym_identifier] = ACTIONS(2178),
    [aux_sym_preproc_include_token1] = ACTIONS(2178),
    [aux_sym_preproc_def_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token2] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2178),
    [aux_sym_preproc_else_token1] = ACTIONS(2178),
    [aux_sym_preproc_elif_token1] = ACTIONS(2178),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2178),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2178),
    [sym_preproc_directive] = ACTIONS(2178),
    [anon_sym_LPAREN2] = ACTIONS(2180),
    [anon_sym_BANG] = ACTIONS(2180),
    [anon_sym_TILDE] = ACTIONS(2180),
    [anon_sym_DASH] = ACTIONS(2178),
    [anon_sym_PLUS] = ACTIONS(2178),
    [anon_sym_STAR] = ACTIONS(2180),
    [anon_sym_AMP_AMP] = ACTIONS(2180),
    [anon_sym_AMP] = ACTIONS(2178),
    [anon_sym_SEMI] = ACTIONS(2180),
    [anon_sym___extension__] = ACTIONS(2178),
    [anon_sym_typedef] = ACTIONS(2178),
    [anon_sym_in] = ACTIONS(2178),
    [anon_sym_out] = ACTIONS(2178),
    [anon_sym_inout] = ACTIONS(2178),
    [anon_sym_extern] = ACTIONS(2178),
    [anon_sym___attribute__] = ACTIONS(2178),
    [anon_sym_COLON_COLON] = ACTIONS(2180),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2180),
    [anon_sym___declspec] = ACTIONS(2178),
    [anon_sym___based] = ACTIONS(2178),
    [anon_sym___cdecl] = ACTIONS(2178),
    [anon_sym___clrcall] = ACTIONS(2178),
    [anon_sym___stdcall] = ACTIONS(2178),
    [anon_sym___fastcall] = ACTIONS(2178),
    [anon_sym___thiscall] = ACTIONS(2178),
    [anon_sym___vectorcall] = ACTIONS(2178),
    [anon_sym_LBRACE] = ACTIONS(2180),
    [anon_sym_signed] = ACTIONS(2178),
    [anon_sym_unsigned] = ACTIONS(2178),
    [anon_sym_long] = ACTIONS(2178),
    [anon_sym_short] = ACTIONS(2178),
    [anon_sym_LBRACK] = ACTIONS(2178),
    [anon_sym_static] = ACTIONS(2178),
    [anon_sym_register] = ACTIONS(2178),
    [anon_sym_inline] = ACTIONS(2178),
    [anon_sym___inline] = ACTIONS(2178),
    [anon_sym___inline__] = ACTIONS(2178),
    [anon_sym___forceinline] = ACTIONS(2178),
    [anon_sym_thread_local] = ACTIONS(2178),
    [anon_sym___thread] = ACTIONS(2178),
    [anon_sym_const] = ACTIONS(2178),
    [anon_sym_constexpr] = ACTIONS(2178),
    [anon_sym_volatile] = ACTIONS(2178),
    [anon_sym_restrict] = ACTIONS(2178),
    [anon_sym___restrict__] = ACTIONS(2178),
    [anon_sym__Atomic] = ACTIONS(2178),
    [anon_sym__Noreturn] = ACTIONS(2178),
    [anon_sym_noreturn] = ACTIONS(2178),
    [anon_sym_mutable] = ACTIONS(2178),
    [anon_sym_constinit] = ACTIONS(2178),
    [anon_sym_consteval] = ACTIONS(2178),
    [anon_sym_alignas] = ACTIONS(2178),
    [anon_sym__Alignas] = ACTIONS(2178),
    [sym_primitive_type] = ACTIONS(2178),
    [anon_sym_enum] = ACTIONS(2178),
    [anon_sym_class] = ACTIONS(2178),
    [anon_sym_struct] = ACTIONS(2178),
    [anon_sym_union] = ACTIONS(2178),
    [anon_sym_if] = ACTIONS(2178),
    [anon_sym_else] = ACTIONS(2178),
    [anon_sym_switch] = ACTIONS(2178),
    [anon_sym_case] = ACTIONS(2178),
    [anon_sym_default] = ACTIONS(2178),
    [anon_sym_while] = ACTIONS(2178),
    [anon_sym_do] = ACTIONS(2178),
    [anon_sym_for] = ACTIONS(2178),
    [anon_sym_return] = ACTIONS(2178),
    [anon_sym_break] = ACTIONS(2178),
    [anon_sym_continue] = ACTIONS(2178),
    [anon_sym_goto] = ACTIONS(2178),
    [anon_sym___try] = ACTIONS(2178),
    [anon_sym___leave] = ACTIONS(2178),
    [anon_sym_not] = ACTIONS(2178),
    [anon_sym_compl] = ACTIONS(2178),
    [anon_sym_DASH_DASH] = ACTIONS(2180),
    [anon_sym_PLUS_PLUS] = ACTIONS(2180),
    [anon_sym_sizeof] = ACTIONS(2178),
    [anon_sym___alignof__] = ACTIONS(2178),
    [anon_sym___alignof] = ACTIONS(2178),
    [anon_sym__alignof] = ACTIONS(2178),
    [anon_sym_alignof] = ACTIONS(2178),
    [anon_sym__Alignof] = ACTIONS(2178),
    [anon_sym_offsetof] = ACTIONS(2178),
    [anon_sym__Generic] = ACTIONS(2178),
    [anon_sym_asm] = ACTIONS(2178),
    [anon_sym___asm__] = ACTIONS(2178),
    [sym_number_literal] = ACTIONS(2180),
    [anon_sym_L_SQUOTE] = ACTIONS(2180),
    [anon_sym_u_SQUOTE] = ACTIONS(2180),
    [anon_sym_U_SQUOTE] = ACTIONS(2180),
    [anon_sym_u8_SQUOTE] = ACTIONS(2180),
    [anon_sym_SQUOTE] = ACTIONS(2180),
    [anon_sym_L_DQUOTE] = ACTIONS(2180),
    [anon_sym_u_DQUOTE] = ACTIONS(2180),
    [anon_sym_U_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8_DQUOTE] = ACTIONS(2180),
    [anon_sym_DQUOTE] = ACTIONS(2180),
    [sym_true] = ACTIONS(2178),
    [sym_false] = ACTIONS(2178),
    [anon_sym_NULL] = ACTIONS(2178),
    [anon_sym_nullptr] = ACTIONS(2178),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2178),
    [anon_sym_decltype] = ACTIONS(2178),
    [sym_virtual] = ACTIONS(2178),
    [anon_sym_explicit] = ACTIONS(2178),
    [anon_sym_typename] = ACTIONS(2178),
    [anon_sym_template] = ACTIONS(2178),
    [anon_sym_operator] = ACTIONS(2178),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_delete] = ACTIONS(2178),
    [anon_sym_throw] = ACTIONS(2178),
    [anon_sym_namespace] = ACTIONS(2178),
    [anon_sym_using] = ACTIONS(2178),
    [anon_sym_static_assert] = ACTIONS(2178),
    [anon_sym_concept] = ACTIONS(2178),
    [anon_sym_co_return] = ACTIONS(2178),
    [anon_sym_co_yield] = ACTIONS(2178),
    [anon_sym_R_DQUOTE] = ACTIONS(2180),
    [anon_sym_LR_DQUOTE] = ACTIONS(2180),
    [anon_sym_uR_DQUOTE] = ACTIONS(2180),
    [anon_sym_UR_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2180),
    [anon_sym_co_await] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2178),
    [anon_sym_requires] = ACTIONS(2178),
    [sym_this] = ACTIONS(2178),
    [anon_sym_discard] = ACTIONS(2178),
    [anon_sym_precise] = ACTIONS(2178),
    [anon_sym_shared] = ACTIONS(2178),
    [anon_sym_groupshared] = ACTIONS(2178),
    [anon_sym_uniform] = ACTIONS(2178),
    [anon_sym_row_major] = ACTIONS(2178),
    [anon_sym_column_major] = ACTIONS(2178),
    [anon_sym_globallycoherent] = ACTIONS(2178),
    [anon_sym_centroid] = ACTIONS(2178),
    [anon_sym_noperspective] = ACTIONS(2178),
    [anon_sym_nointerpolation] = ACTIONS(2178),
    [anon_sym_sample] = ACTIONS(2178),
    [anon_sym_linear] = ACTIONS(2178),
    [anon_sym_snorm] = ACTIONS(2178),
    [anon_sym_unorm] = ACTIONS(2178),
    [anon_sym_point] = ACTIONS(2178),
    [anon_sym_line] = ACTIONS(2178),
    [anon_sym_triangleadj] = ACTIONS(2178),
    [anon_sym_lineadj] = ACTIONS(2178),
    [anon_sym_triangle] = ACTIONS(2178),
    [anon_sym_cbuffer] = ACTIONS(2178),
  },
  [202] = {
    [sym_identifier] = ACTIONS(2182),
    [aux_sym_preproc_include_token1] = ACTIONS(2182),
    [aux_sym_preproc_def_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token2] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2182),
    [aux_sym_preproc_else_token1] = ACTIONS(2182),
    [aux_sym_preproc_elif_token1] = ACTIONS(2182),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2182),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2182),
    [sym_preproc_directive] = ACTIONS(2182),
    [anon_sym_LPAREN2] = ACTIONS(2184),
    [anon_sym_BANG] = ACTIONS(2184),
    [anon_sym_TILDE] = ACTIONS(2184),
    [anon_sym_DASH] = ACTIONS(2182),
    [anon_sym_PLUS] = ACTIONS(2182),
    [anon_sym_STAR] = ACTIONS(2184),
    [anon_sym_AMP_AMP] = ACTIONS(2184),
    [anon_sym_AMP] = ACTIONS(2182),
    [anon_sym_SEMI] = ACTIONS(2184),
    [anon_sym___extension__] = ACTIONS(2182),
    [anon_sym_typedef] = ACTIONS(2182),
    [anon_sym_in] = ACTIONS(2182),
    [anon_sym_out] = ACTIONS(2182),
    [anon_sym_inout] = ACTIONS(2182),
    [anon_sym_extern] = ACTIONS(2182),
    [anon_sym___attribute__] = ACTIONS(2182),
    [anon_sym_COLON_COLON] = ACTIONS(2184),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2184),
    [anon_sym___declspec] = ACTIONS(2182),
    [anon_sym___based] = ACTIONS(2182),
    [anon_sym___cdecl] = ACTIONS(2182),
    [anon_sym___clrcall] = ACTIONS(2182),
    [anon_sym___stdcall] = ACTIONS(2182),
    [anon_sym___fastcall] = ACTIONS(2182),
    [anon_sym___thiscall] = ACTIONS(2182),
    [anon_sym___vectorcall] = ACTIONS(2182),
    [anon_sym_LBRACE] = ACTIONS(2184),
    [anon_sym_signed] = ACTIONS(2182),
    [anon_sym_unsigned] = ACTIONS(2182),
    [anon_sym_long] = ACTIONS(2182),
    [anon_sym_short] = ACTIONS(2182),
    [anon_sym_LBRACK] = ACTIONS(2182),
    [anon_sym_static] = ACTIONS(2182),
    [anon_sym_register] = ACTIONS(2182),
    [anon_sym_inline] = ACTIONS(2182),
    [anon_sym___inline] = ACTIONS(2182),
    [anon_sym___inline__] = ACTIONS(2182),
    [anon_sym___forceinline] = ACTIONS(2182),
    [anon_sym_thread_local] = ACTIONS(2182),
    [anon_sym___thread] = ACTIONS(2182),
    [anon_sym_const] = ACTIONS(2182),
    [anon_sym_constexpr] = ACTIONS(2182),
    [anon_sym_volatile] = ACTIONS(2182),
    [anon_sym_restrict] = ACTIONS(2182),
    [anon_sym___restrict__] = ACTIONS(2182),
    [anon_sym__Atomic] = ACTIONS(2182),
    [anon_sym__Noreturn] = ACTIONS(2182),
    [anon_sym_noreturn] = ACTIONS(2182),
    [anon_sym_mutable] = ACTIONS(2182),
    [anon_sym_constinit] = ACTIONS(2182),
    [anon_sym_consteval] = ACTIONS(2182),
    [anon_sym_alignas] = ACTIONS(2182),
    [anon_sym__Alignas] = ACTIONS(2182),
    [sym_primitive_type] = ACTIONS(2182),
    [anon_sym_enum] = ACTIONS(2182),
    [anon_sym_class] = ACTIONS(2182),
    [anon_sym_struct] = ACTIONS(2182),
    [anon_sym_union] = ACTIONS(2182),
    [anon_sym_if] = ACTIONS(2182),
    [anon_sym_else] = ACTIONS(2182),
    [anon_sym_switch] = ACTIONS(2182),
    [anon_sym_case] = ACTIONS(2182),
    [anon_sym_default] = ACTIONS(2182),
    [anon_sym_while] = ACTIONS(2182),
    [anon_sym_do] = ACTIONS(2182),
    [anon_sym_for] = ACTIONS(2182),
    [anon_sym_return] = ACTIONS(2182),
    [anon_sym_break] = ACTIONS(2182),
    [anon_sym_continue] = ACTIONS(2182),
    [anon_sym_goto] = ACTIONS(2182),
    [anon_sym___try] = ACTIONS(2182),
    [anon_sym___leave] = ACTIONS(2182),
    [anon_sym_not] = ACTIONS(2182),
    [anon_sym_compl] = ACTIONS(2182),
    [anon_sym_DASH_DASH] = ACTIONS(2184),
    [anon_sym_PLUS_PLUS] = ACTIONS(2184),
    [anon_sym_sizeof] = ACTIONS(2182),
    [anon_sym___alignof__] = ACTIONS(2182),
    [anon_sym___alignof] = ACTIONS(2182),
    [anon_sym__alignof] = ACTIONS(2182),
    [anon_sym_alignof] = ACTIONS(2182),
    [anon_sym__Alignof] = ACTIONS(2182),
    [anon_sym_offsetof] = ACTIONS(2182),
    [anon_sym__Generic] = ACTIONS(2182),
    [anon_sym_asm] = ACTIONS(2182),
    [anon_sym___asm__] = ACTIONS(2182),
    [sym_number_literal] = ACTIONS(2184),
    [anon_sym_L_SQUOTE] = ACTIONS(2184),
    [anon_sym_u_SQUOTE] = ACTIONS(2184),
    [anon_sym_U_SQUOTE] = ACTIONS(2184),
    [anon_sym_u8_SQUOTE] = ACTIONS(2184),
    [anon_sym_SQUOTE] = ACTIONS(2184),
    [anon_sym_L_DQUOTE] = ACTIONS(2184),
    [anon_sym_u_DQUOTE] = ACTIONS(2184),
    [anon_sym_U_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8_DQUOTE] = ACTIONS(2184),
    [anon_sym_DQUOTE] = ACTIONS(2184),
    [sym_true] = ACTIONS(2182),
    [sym_false] = ACTIONS(2182),
    [anon_sym_NULL] = ACTIONS(2182),
    [anon_sym_nullptr] = ACTIONS(2182),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2182),
    [anon_sym_decltype] = ACTIONS(2182),
    [sym_virtual] = ACTIONS(2182),
    [anon_sym_explicit] = ACTIONS(2182),
    [anon_sym_typename] = ACTIONS(2182),
    [anon_sym_template] = ACTIONS(2182),
    [anon_sym_operator] = ACTIONS(2182),
    [anon_sym_try] = ACTIONS(2182),
    [anon_sym_delete] = ACTIONS(2182),
    [anon_sym_throw] = ACTIONS(2182),
    [anon_sym_namespace] = ACTIONS(2182),
    [anon_sym_using] = ACTIONS(2182),
    [anon_sym_static_assert] = ACTIONS(2182),
    [anon_sym_concept] = ACTIONS(2182),
    [anon_sym_co_return] = ACTIONS(2182),
    [anon_sym_co_yield] = ACTIONS(2182),
    [anon_sym_R_DQUOTE] = ACTIONS(2184),
    [anon_sym_LR_DQUOTE] = ACTIONS(2184),
    [anon_sym_uR_DQUOTE] = ACTIONS(2184),
    [anon_sym_UR_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2184),
    [anon_sym_co_await] = ACTIONS(2182),
    [anon_sym_new] = ACTIONS(2182),
    [anon_sym_requires] = ACTIONS(2182),
    [sym_this] = ACTIONS(2182),
    [anon_sym_discard] = ACTIONS(2182),
    [anon_sym_precise] = ACTIONS(2182),
    [anon_sym_shared] = ACTIONS(2182),
    [anon_sym_groupshared] = ACTIONS(2182),
    [anon_sym_uniform] = ACTIONS(2182),
    [anon_sym_row_major] = ACTIONS(2182),
    [anon_sym_column_major] = ACTIONS(2182),
    [anon_sym_globallycoherent] = ACTIONS(2182),
    [anon_sym_centroid] = ACTIONS(2182),
    [anon_sym_noperspective] = ACTIONS(2182),
    [anon_sym_nointerpolation] = ACTIONS(2182),
    [anon_sym_sample] = ACTIONS(2182),
    [anon_sym_linear] = ACTIONS(2182),
    [anon_sym_snorm] = ACTIONS(2182),
    [anon_sym_unorm] = ACTIONS(2182),
    [anon_sym_point] = ACTIONS(2182),
    [anon_sym_line] = ACTIONS(2182),
    [anon_sym_triangleadj] = ACTIONS(2182),
    [anon_sym_lineadj] = ACTIONS(2182),
    [anon_sym_triangle] = ACTIONS(2182),
    [anon_sym_cbuffer] = ACTIONS(2182),
  },
  [203] = {
    [sym_identifier] = ACTIONS(2186),
    [aux_sym_preproc_include_token1] = ACTIONS(2186),
    [aux_sym_preproc_def_token1] = ACTIONS(2186),
    [aux_sym_preproc_if_token1] = ACTIONS(2186),
    [aux_sym_preproc_if_token2] = ACTIONS(2186),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2186),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2186),
    [aux_sym_preproc_else_token1] = ACTIONS(2186),
    [aux_sym_preproc_elif_token1] = ACTIONS(2186),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2186),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2186),
    [sym_preproc_directive] = ACTIONS(2186),
    [anon_sym_LPAREN2] = ACTIONS(2188),
    [anon_sym_BANG] = ACTIONS(2188),
    [anon_sym_TILDE] = ACTIONS(2188),
    [anon_sym_DASH] = ACTIONS(2186),
    [anon_sym_PLUS] = ACTIONS(2186),
    [anon_sym_STAR] = ACTIONS(2188),
    [anon_sym_AMP_AMP] = ACTIONS(2188),
    [anon_sym_AMP] = ACTIONS(2186),
    [anon_sym_SEMI] = ACTIONS(2188),
    [anon_sym___extension__] = ACTIONS(2186),
    [anon_sym_typedef] = ACTIONS(2186),
    [anon_sym_in] = ACTIONS(2186),
    [anon_sym_out] = ACTIONS(2186),
    [anon_sym_inout] = ACTIONS(2186),
    [anon_sym_extern] = ACTIONS(2186),
    [anon_sym___attribute__] = ACTIONS(2186),
    [anon_sym_COLON_COLON] = ACTIONS(2188),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2188),
    [anon_sym___declspec] = ACTIONS(2186),
    [anon_sym___based] = ACTIONS(2186),
    [anon_sym___cdecl] = ACTIONS(2186),
    [anon_sym___clrcall] = ACTIONS(2186),
    [anon_sym___stdcall] = ACTIONS(2186),
    [anon_sym___fastcall] = ACTIONS(2186),
    [anon_sym___thiscall] = ACTIONS(2186),
    [anon_sym___vectorcall] = ACTIONS(2186),
    [anon_sym_LBRACE] = ACTIONS(2188),
    [anon_sym_signed] = ACTIONS(2186),
    [anon_sym_unsigned] = ACTIONS(2186),
    [anon_sym_long] = ACTIONS(2186),
    [anon_sym_short] = ACTIONS(2186),
    [anon_sym_LBRACK] = ACTIONS(2186),
    [anon_sym_static] = ACTIONS(2186),
    [anon_sym_register] = ACTIONS(2186),
    [anon_sym_inline] = ACTIONS(2186),
    [anon_sym___inline] = ACTIONS(2186),
    [anon_sym___inline__] = ACTIONS(2186),
    [anon_sym___forceinline] = ACTIONS(2186),
    [anon_sym_thread_local] = ACTIONS(2186),
    [anon_sym___thread] = ACTIONS(2186),
    [anon_sym_const] = ACTIONS(2186),
    [anon_sym_constexpr] = ACTIONS(2186),
    [anon_sym_volatile] = ACTIONS(2186),
    [anon_sym_restrict] = ACTIONS(2186),
    [anon_sym___restrict__] = ACTIONS(2186),
    [anon_sym__Atomic] = ACTIONS(2186),
    [anon_sym__Noreturn] = ACTIONS(2186),
    [anon_sym_noreturn] = ACTIONS(2186),
    [anon_sym_mutable] = ACTIONS(2186),
    [anon_sym_constinit] = ACTIONS(2186),
    [anon_sym_consteval] = ACTIONS(2186),
    [anon_sym_alignas] = ACTIONS(2186),
    [anon_sym__Alignas] = ACTIONS(2186),
    [sym_primitive_type] = ACTIONS(2186),
    [anon_sym_enum] = ACTIONS(2186),
    [anon_sym_class] = ACTIONS(2186),
    [anon_sym_struct] = ACTIONS(2186),
    [anon_sym_union] = ACTIONS(2186),
    [anon_sym_if] = ACTIONS(2186),
    [anon_sym_else] = ACTIONS(2186),
    [anon_sym_switch] = ACTIONS(2186),
    [anon_sym_case] = ACTIONS(2186),
    [anon_sym_default] = ACTIONS(2186),
    [anon_sym_while] = ACTIONS(2186),
    [anon_sym_do] = ACTIONS(2186),
    [anon_sym_for] = ACTIONS(2186),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_break] = ACTIONS(2186),
    [anon_sym_continue] = ACTIONS(2186),
    [anon_sym_goto] = ACTIONS(2186),
    [anon_sym___try] = ACTIONS(2186),
    [anon_sym___leave] = ACTIONS(2186),
    [anon_sym_not] = ACTIONS(2186),
    [anon_sym_compl] = ACTIONS(2186),
    [anon_sym_DASH_DASH] = ACTIONS(2188),
    [anon_sym_PLUS_PLUS] = ACTIONS(2188),
    [anon_sym_sizeof] = ACTIONS(2186),
    [anon_sym___alignof__] = ACTIONS(2186),
    [anon_sym___alignof] = ACTIONS(2186),
    [anon_sym__alignof] = ACTIONS(2186),
    [anon_sym_alignof] = ACTIONS(2186),
    [anon_sym__Alignof] = ACTIONS(2186),
    [anon_sym_offsetof] = ACTIONS(2186),
    [anon_sym__Generic] = ACTIONS(2186),
    [anon_sym_asm] = ACTIONS(2186),
    [anon_sym___asm__] = ACTIONS(2186),
    [sym_number_literal] = ACTIONS(2188),
    [anon_sym_L_SQUOTE] = ACTIONS(2188),
    [anon_sym_u_SQUOTE] = ACTIONS(2188),
    [anon_sym_U_SQUOTE] = ACTIONS(2188),
    [anon_sym_u8_SQUOTE] = ACTIONS(2188),
    [anon_sym_SQUOTE] = ACTIONS(2188),
    [anon_sym_L_DQUOTE] = ACTIONS(2188),
    [anon_sym_u_DQUOTE] = ACTIONS(2188),
    [anon_sym_U_DQUOTE] = ACTIONS(2188),
    [anon_sym_u8_DQUOTE] = ACTIONS(2188),
    [anon_sym_DQUOTE] = ACTIONS(2188),
    [sym_true] = ACTIONS(2186),
    [sym_false] = ACTIONS(2186),
    [anon_sym_NULL] = ACTIONS(2186),
    [anon_sym_nullptr] = ACTIONS(2186),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2186),
    [anon_sym_decltype] = ACTIONS(2186),
    [sym_virtual] = ACTIONS(2186),
    [anon_sym_explicit] = ACTIONS(2186),
    [anon_sym_typename] = ACTIONS(2186),
    [anon_sym_template] = ACTIONS(2186),
    [anon_sym_operator] = ACTIONS(2186),
    [anon_sym_try] = ACTIONS(2186),
    [anon_sym_delete] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2186),
    [anon_sym_namespace] = ACTIONS(2186),
    [anon_sym_using] = ACTIONS(2186),
    [anon_sym_static_assert] = ACTIONS(2186),
    [anon_sym_concept] = ACTIONS(2186),
    [anon_sym_co_return] = ACTIONS(2186),
    [anon_sym_co_yield] = ACTIONS(2186),
    [anon_sym_R_DQUOTE] = ACTIONS(2188),
    [anon_sym_LR_DQUOTE] = ACTIONS(2188),
    [anon_sym_uR_DQUOTE] = ACTIONS(2188),
    [anon_sym_UR_DQUOTE] = ACTIONS(2188),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2188),
    [anon_sym_co_await] = ACTIONS(2186),
    [anon_sym_new] = ACTIONS(2186),
    [anon_sym_requires] = ACTIONS(2186),
    [sym_this] = ACTIONS(2186),
    [anon_sym_discard] = ACTIONS(2186),
    [anon_sym_precise] = ACTIONS(2186),
    [anon_sym_shared] = ACTIONS(2186),
    [anon_sym_groupshared] = ACTIONS(2186),
    [anon_sym_uniform] = ACTIONS(2186),
    [anon_sym_row_major] = ACTIONS(2186),
    [anon_sym_column_major] = ACTIONS(2186),
    [anon_sym_globallycoherent] = ACTIONS(2186),
    [anon_sym_centroid] = ACTIONS(2186),
    [anon_sym_noperspective] = ACTIONS(2186),
    [anon_sym_nointerpolation] = ACTIONS(2186),
    [anon_sym_sample] = ACTIONS(2186),
    [anon_sym_linear] = ACTIONS(2186),
    [anon_sym_snorm] = ACTIONS(2186),
    [anon_sym_unorm] = ACTIONS(2186),
    [anon_sym_point] = ACTIONS(2186),
    [anon_sym_line] = ACTIONS(2186),
    [anon_sym_triangleadj] = ACTIONS(2186),
    [anon_sym_lineadj] = ACTIONS(2186),
    [anon_sym_triangle] = ACTIONS(2186),
    [anon_sym_cbuffer] = ACTIONS(2186),
  },
  [204] = {
    [sym_identifier] = ACTIONS(2190),
    [aux_sym_preproc_include_token1] = ACTIONS(2190),
    [aux_sym_preproc_def_token1] = ACTIONS(2190),
    [aux_sym_preproc_if_token1] = ACTIONS(2190),
    [aux_sym_preproc_if_token2] = ACTIONS(2190),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2190),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2190),
    [aux_sym_preproc_else_token1] = ACTIONS(2190),
    [aux_sym_preproc_elif_token1] = ACTIONS(2190),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2190),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2190),
    [sym_preproc_directive] = ACTIONS(2190),
    [anon_sym_LPAREN2] = ACTIONS(2192),
    [anon_sym_BANG] = ACTIONS(2192),
    [anon_sym_TILDE] = ACTIONS(2192),
    [anon_sym_DASH] = ACTIONS(2190),
    [anon_sym_PLUS] = ACTIONS(2190),
    [anon_sym_STAR] = ACTIONS(2192),
    [anon_sym_AMP_AMP] = ACTIONS(2192),
    [anon_sym_AMP] = ACTIONS(2190),
    [anon_sym_SEMI] = ACTIONS(2192),
    [anon_sym___extension__] = ACTIONS(2190),
    [anon_sym_typedef] = ACTIONS(2190),
    [anon_sym_in] = ACTIONS(2190),
    [anon_sym_out] = ACTIONS(2190),
    [anon_sym_inout] = ACTIONS(2190),
    [anon_sym_extern] = ACTIONS(2190),
    [anon_sym___attribute__] = ACTIONS(2190),
    [anon_sym_COLON_COLON] = ACTIONS(2192),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2192),
    [anon_sym___declspec] = ACTIONS(2190),
    [anon_sym___based] = ACTIONS(2190),
    [anon_sym___cdecl] = ACTIONS(2190),
    [anon_sym___clrcall] = ACTIONS(2190),
    [anon_sym___stdcall] = ACTIONS(2190),
    [anon_sym___fastcall] = ACTIONS(2190),
    [anon_sym___thiscall] = ACTIONS(2190),
    [anon_sym___vectorcall] = ACTIONS(2190),
    [anon_sym_LBRACE] = ACTIONS(2192),
    [anon_sym_signed] = ACTIONS(2190),
    [anon_sym_unsigned] = ACTIONS(2190),
    [anon_sym_long] = ACTIONS(2190),
    [anon_sym_short] = ACTIONS(2190),
    [anon_sym_LBRACK] = ACTIONS(2190),
    [anon_sym_static] = ACTIONS(2190),
    [anon_sym_register] = ACTIONS(2190),
    [anon_sym_inline] = ACTIONS(2190),
    [anon_sym___inline] = ACTIONS(2190),
    [anon_sym___inline__] = ACTIONS(2190),
    [anon_sym___forceinline] = ACTIONS(2190),
    [anon_sym_thread_local] = ACTIONS(2190),
    [anon_sym___thread] = ACTIONS(2190),
    [anon_sym_const] = ACTIONS(2190),
    [anon_sym_constexpr] = ACTIONS(2190),
    [anon_sym_volatile] = ACTIONS(2190),
    [anon_sym_restrict] = ACTIONS(2190),
    [anon_sym___restrict__] = ACTIONS(2190),
    [anon_sym__Atomic] = ACTIONS(2190),
    [anon_sym__Noreturn] = ACTIONS(2190),
    [anon_sym_noreturn] = ACTIONS(2190),
    [anon_sym_mutable] = ACTIONS(2190),
    [anon_sym_constinit] = ACTIONS(2190),
    [anon_sym_consteval] = ACTIONS(2190),
    [anon_sym_alignas] = ACTIONS(2190),
    [anon_sym__Alignas] = ACTIONS(2190),
    [sym_primitive_type] = ACTIONS(2190),
    [anon_sym_enum] = ACTIONS(2190),
    [anon_sym_class] = ACTIONS(2190),
    [anon_sym_struct] = ACTIONS(2190),
    [anon_sym_union] = ACTIONS(2190),
    [anon_sym_if] = ACTIONS(2190),
    [anon_sym_else] = ACTIONS(2190),
    [anon_sym_switch] = ACTIONS(2190),
    [anon_sym_case] = ACTIONS(2190),
    [anon_sym_default] = ACTIONS(2190),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_do] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2190),
    [anon_sym_return] = ACTIONS(2190),
    [anon_sym_break] = ACTIONS(2190),
    [anon_sym_continue] = ACTIONS(2190),
    [anon_sym_goto] = ACTIONS(2190),
    [anon_sym___try] = ACTIONS(2190),
    [anon_sym___leave] = ACTIONS(2190),
    [anon_sym_not] = ACTIONS(2190),
    [anon_sym_compl] = ACTIONS(2190),
    [anon_sym_DASH_DASH] = ACTIONS(2192),
    [anon_sym_PLUS_PLUS] = ACTIONS(2192),
    [anon_sym_sizeof] = ACTIONS(2190),
    [anon_sym___alignof__] = ACTIONS(2190),
    [anon_sym___alignof] = ACTIONS(2190),
    [anon_sym__alignof] = ACTIONS(2190),
    [anon_sym_alignof] = ACTIONS(2190),
    [anon_sym__Alignof] = ACTIONS(2190),
    [anon_sym_offsetof] = ACTIONS(2190),
    [anon_sym__Generic] = ACTIONS(2190),
    [anon_sym_asm] = ACTIONS(2190),
    [anon_sym___asm__] = ACTIONS(2190),
    [sym_number_literal] = ACTIONS(2192),
    [anon_sym_L_SQUOTE] = ACTIONS(2192),
    [anon_sym_u_SQUOTE] = ACTIONS(2192),
    [anon_sym_U_SQUOTE] = ACTIONS(2192),
    [anon_sym_u8_SQUOTE] = ACTIONS(2192),
    [anon_sym_SQUOTE] = ACTIONS(2192),
    [anon_sym_L_DQUOTE] = ACTIONS(2192),
    [anon_sym_u_DQUOTE] = ACTIONS(2192),
    [anon_sym_U_DQUOTE] = ACTIONS(2192),
    [anon_sym_u8_DQUOTE] = ACTIONS(2192),
    [anon_sym_DQUOTE] = ACTIONS(2192),
    [sym_true] = ACTIONS(2190),
    [sym_false] = ACTIONS(2190),
    [anon_sym_NULL] = ACTIONS(2190),
    [anon_sym_nullptr] = ACTIONS(2190),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2190),
    [anon_sym_decltype] = ACTIONS(2190),
    [sym_virtual] = ACTIONS(2190),
    [anon_sym_explicit] = ACTIONS(2190),
    [anon_sym_typename] = ACTIONS(2190),
    [anon_sym_template] = ACTIONS(2190),
    [anon_sym_operator] = ACTIONS(2190),
    [anon_sym_try] = ACTIONS(2190),
    [anon_sym_delete] = ACTIONS(2190),
    [anon_sym_throw] = ACTIONS(2190),
    [anon_sym_namespace] = ACTIONS(2190),
    [anon_sym_using] = ACTIONS(2190),
    [anon_sym_static_assert] = ACTIONS(2190),
    [anon_sym_concept] = ACTIONS(2190),
    [anon_sym_co_return] = ACTIONS(2190),
    [anon_sym_co_yield] = ACTIONS(2190),
    [anon_sym_R_DQUOTE] = ACTIONS(2192),
    [anon_sym_LR_DQUOTE] = ACTIONS(2192),
    [anon_sym_uR_DQUOTE] = ACTIONS(2192),
    [anon_sym_UR_DQUOTE] = ACTIONS(2192),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2192),
    [anon_sym_co_await] = ACTIONS(2190),
    [anon_sym_new] = ACTIONS(2190),
    [anon_sym_requires] = ACTIONS(2190),
    [sym_this] = ACTIONS(2190),
    [anon_sym_discard] = ACTIONS(2190),
    [anon_sym_precise] = ACTIONS(2190),
    [anon_sym_shared] = ACTIONS(2190),
    [anon_sym_groupshared] = ACTIONS(2190),
    [anon_sym_uniform] = ACTIONS(2190),
    [anon_sym_row_major] = ACTIONS(2190),
    [anon_sym_column_major] = ACTIONS(2190),
    [anon_sym_globallycoherent] = ACTIONS(2190),
    [anon_sym_centroid] = ACTIONS(2190),
    [anon_sym_noperspective] = ACTIONS(2190),
    [anon_sym_nointerpolation] = ACTIONS(2190),
    [anon_sym_sample] = ACTIONS(2190),
    [anon_sym_linear] = ACTIONS(2190),
    [anon_sym_snorm] = ACTIONS(2190),
    [anon_sym_unorm] = ACTIONS(2190),
    [anon_sym_point] = ACTIONS(2190),
    [anon_sym_line] = ACTIONS(2190),
    [anon_sym_triangleadj] = ACTIONS(2190),
    [anon_sym_lineadj] = ACTIONS(2190),
    [anon_sym_triangle] = ACTIONS(2190),
    [anon_sym_cbuffer] = ACTIONS(2190),
  },
  [205] = {
    [sym_identifier] = ACTIONS(2194),
    [aux_sym_preproc_include_token1] = ACTIONS(2194),
    [aux_sym_preproc_def_token1] = ACTIONS(2194),
    [aux_sym_preproc_if_token1] = ACTIONS(2194),
    [aux_sym_preproc_if_token2] = ACTIONS(2194),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2194),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2194),
    [aux_sym_preproc_else_token1] = ACTIONS(2194),
    [aux_sym_preproc_elif_token1] = ACTIONS(2194),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2194),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2194),
    [sym_preproc_directive] = ACTIONS(2194),
    [anon_sym_LPAREN2] = ACTIONS(2196),
    [anon_sym_BANG] = ACTIONS(2196),
    [anon_sym_TILDE] = ACTIONS(2196),
    [anon_sym_DASH] = ACTIONS(2194),
    [anon_sym_PLUS] = ACTIONS(2194),
    [anon_sym_STAR] = ACTIONS(2196),
    [anon_sym_AMP_AMP] = ACTIONS(2196),
    [anon_sym_AMP] = ACTIONS(2194),
    [anon_sym_SEMI] = ACTIONS(2196),
    [anon_sym___extension__] = ACTIONS(2194),
    [anon_sym_typedef] = ACTIONS(2194),
    [anon_sym_in] = ACTIONS(2194),
    [anon_sym_out] = ACTIONS(2194),
    [anon_sym_inout] = ACTIONS(2194),
    [anon_sym_extern] = ACTIONS(2194),
    [anon_sym___attribute__] = ACTIONS(2194),
    [anon_sym_COLON_COLON] = ACTIONS(2196),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2196),
    [anon_sym___declspec] = ACTIONS(2194),
    [anon_sym___based] = ACTIONS(2194),
    [anon_sym___cdecl] = ACTIONS(2194),
    [anon_sym___clrcall] = ACTIONS(2194),
    [anon_sym___stdcall] = ACTIONS(2194),
    [anon_sym___fastcall] = ACTIONS(2194),
    [anon_sym___thiscall] = ACTIONS(2194),
    [anon_sym___vectorcall] = ACTIONS(2194),
    [anon_sym_LBRACE] = ACTIONS(2196),
    [anon_sym_signed] = ACTIONS(2194),
    [anon_sym_unsigned] = ACTIONS(2194),
    [anon_sym_long] = ACTIONS(2194),
    [anon_sym_short] = ACTIONS(2194),
    [anon_sym_LBRACK] = ACTIONS(2194),
    [anon_sym_static] = ACTIONS(2194),
    [anon_sym_register] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(2194),
    [anon_sym___inline] = ACTIONS(2194),
    [anon_sym___inline__] = ACTIONS(2194),
    [anon_sym___forceinline] = ACTIONS(2194),
    [anon_sym_thread_local] = ACTIONS(2194),
    [anon_sym___thread] = ACTIONS(2194),
    [anon_sym_const] = ACTIONS(2194),
    [anon_sym_constexpr] = ACTIONS(2194),
    [anon_sym_volatile] = ACTIONS(2194),
    [anon_sym_restrict] = ACTIONS(2194),
    [anon_sym___restrict__] = ACTIONS(2194),
    [anon_sym__Atomic] = ACTIONS(2194),
    [anon_sym__Noreturn] = ACTIONS(2194),
    [anon_sym_noreturn] = ACTIONS(2194),
    [anon_sym_mutable] = ACTIONS(2194),
    [anon_sym_constinit] = ACTIONS(2194),
    [anon_sym_consteval] = ACTIONS(2194),
    [anon_sym_alignas] = ACTIONS(2194),
    [anon_sym__Alignas] = ACTIONS(2194),
    [sym_primitive_type] = ACTIONS(2194),
    [anon_sym_enum] = ACTIONS(2194),
    [anon_sym_class] = ACTIONS(2194),
    [anon_sym_struct] = ACTIONS(2194),
    [anon_sym_union] = ACTIONS(2194),
    [anon_sym_if] = ACTIONS(2194),
    [anon_sym_else] = ACTIONS(2194),
    [anon_sym_switch] = ACTIONS(2194),
    [anon_sym_case] = ACTIONS(2194),
    [anon_sym_default] = ACTIONS(2194),
    [anon_sym_while] = ACTIONS(2194),
    [anon_sym_do] = ACTIONS(2194),
    [anon_sym_for] = ACTIONS(2194),
    [anon_sym_return] = ACTIONS(2194),
    [anon_sym_break] = ACTIONS(2194),
    [anon_sym_continue] = ACTIONS(2194),
    [anon_sym_goto] = ACTIONS(2194),
    [anon_sym___try] = ACTIONS(2194),
    [anon_sym___leave] = ACTIONS(2194),
    [anon_sym_not] = ACTIONS(2194),
    [anon_sym_compl] = ACTIONS(2194),
    [anon_sym_DASH_DASH] = ACTIONS(2196),
    [anon_sym_PLUS_PLUS] = ACTIONS(2196),
    [anon_sym_sizeof] = ACTIONS(2194),
    [anon_sym___alignof__] = ACTIONS(2194),
    [anon_sym___alignof] = ACTIONS(2194),
    [anon_sym__alignof] = ACTIONS(2194),
    [anon_sym_alignof] = ACTIONS(2194),
    [anon_sym__Alignof] = ACTIONS(2194),
    [anon_sym_offsetof] = ACTIONS(2194),
    [anon_sym__Generic] = ACTIONS(2194),
    [anon_sym_asm] = ACTIONS(2194),
    [anon_sym___asm__] = ACTIONS(2194),
    [sym_number_literal] = ACTIONS(2196),
    [anon_sym_L_SQUOTE] = ACTIONS(2196),
    [anon_sym_u_SQUOTE] = ACTIONS(2196),
    [anon_sym_U_SQUOTE] = ACTIONS(2196),
    [anon_sym_u8_SQUOTE] = ACTIONS(2196),
    [anon_sym_SQUOTE] = ACTIONS(2196),
    [anon_sym_L_DQUOTE] = ACTIONS(2196),
    [anon_sym_u_DQUOTE] = ACTIONS(2196),
    [anon_sym_U_DQUOTE] = ACTIONS(2196),
    [anon_sym_u8_DQUOTE] = ACTIONS(2196),
    [anon_sym_DQUOTE] = ACTIONS(2196),
    [sym_true] = ACTIONS(2194),
    [sym_false] = ACTIONS(2194),
    [anon_sym_NULL] = ACTIONS(2194),
    [anon_sym_nullptr] = ACTIONS(2194),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2194),
    [anon_sym_decltype] = ACTIONS(2194),
    [sym_virtual] = ACTIONS(2194),
    [anon_sym_explicit] = ACTIONS(2194),
    [anon_sym_typename] = ACTIONS(2194),
    [anon_sym_template] = ACTIONS(2194),
    [anon_sym_operator] = ACTIONS(2194),
    [anon_sym_try] = ACTIONS(2194),
    [anon_sym_delete] = ACTIONS(2194),
    [anon_sym_throw] = ACTIONS(2194),
    [anon_sym_namespace] = ACTIONS(2194),
    [anon_sym_using] = ACTIONS(2194),
    [anon_sym_static_assert] = ACTIONS(2194),
    [anon_sym_concept] = ACTIONS(2194),
    [anon_sym_co_return] = ACTIONS(2194),
    [anon_sym_co_yield] = ACTIONS(2194),
    [anon_sym_R_DQUOTE] = ACTIONS(2196),
    [anon_sym_LR_DQUOTE] = ACTIONS(2196),
    [anon_sym_uR_DQUOTE] = ACTIONS(2196),
    [anon_sym_UR_DQUOTE] = ACTIONS(2196),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2196),
    [anon_sym_co_await] = ACTIONS(2194),
    [anon_sym_new] = ACTIONS(2194),
    [anon_sym_requires] = ACTIONS(2194),
    [sym_this] = ACTIONS(2194),
    [anon_sym_discard] = ACTIONS(2194),
    [anon_sym_precise] = ACTIONS(2194),
    [anon_sym_shared] = ACTIONS(2194),
    [anon_sym_groupshared] = ACTIONS(2194),
    [anon_sym_uniform] = ACTIONS(2194),
    [anon_sym_row_major] = ACTIONS(2194),
    [anon_sym_column_major] = ACTIONS(2194),
    [anon_sym_globallycoherent] = ACTIONS(2194),
    [anon_sym_centroid] = ACTIONS(2194),
    [anon_sym_noperspective] = ACTIONS(2194),
    [anon_sym_nointerpolation] = ACTIONS(2194),
    [anon_sym_sample] = ACTIONS(2194),
    [anon_sym_linear] = ACTIONS(2194),
    [anon_sym_snorm] = ACTIONS(2194),
    [anon_sym_unorm] = ACTIONS(2194),
    [anon_sym_point] = ACTIONS(2194),
    [anon_sym_line] = ACTIONS(2194),
    [anon_sym_triangleadj] = ACTIONS(2194),
    [anon_sym_lineadj] = ACTIONS(2194),
    [anon_sym_triangle] = ACTIONS(2194),
    [anon_sym_cbuffer] = ACTIONS(2194),
  },
  [206] = {
    [sym_identifier] = ACTIONS(2198),
    [aux_sym_preproc_include_token1] = ACTIONS(2198),
    [aux_sym_preproc_def_token1] = ACTIONS(2198),
    [aux_sym_preproc_if_token1] = ACTIONS(2198),
    [aux_sym_preproc_if_token2] = ACTIONS(2198),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2198),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2198),
    [aux_sym_preproc_else_token1] = ACTIONS(2198),
    [aux_sym_preproc_elif_token1] = ACTIONS(2198),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2198),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2198),
    [sym_preproc_directive] = ACTIONS(2198),
    [anon_sym_LPAREN2] = ACTIONS(2200),
    [anon_sym_BANG] = ACTIONS(2200),
    [anon_sym_TILDE] = ACTIONS(2200),
    [anon_sym_DASH] = ACTIONS(2198),
    [anon_sym_PLUS] = ACTIONS(2198),
    [anon_sym_STAR] = ACTIONS(2200),
    [anon_sym_AMP_AMP] = ACTIONS(2200),
    [anon_sym_AMP] = ACTIONS(2198),
    [anon_sym_SEMI] = ACTIONS(2200),
    [anon_sym___extension__] = ACTIONS(2198),
    [anon_sym_typedef] = ACTIONS(2198),
    [anon_sym_in] = ACTIONS(2198),
    [anon_sym_out] = ACTIONS(2198),
    [anon_sym_inout] = ACTIONS(2198),
    [anon_sym_extern] = ACTIONS(2198),
    [anon_sym___attribute__] = ACTIONS(2198),
    [anon_sym_COLON_COLON] = ACTIONS(2200),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2200),
    [anon_sym___declspec] = ACTIONS(2198),
    [anon_sym___based] = ACTIONS(2198),
    [anon_sym___cdecl] = ACTIONS(2198),
    [anon_sym___clrcall] = ACTIONS(2198),
    [anon_sym___stdcall] = ACTIONS(2198),
    [anon_sym___fastcall] = ACTIONS(2198),
    [anon_sym___thiscall] = ACTIONS(2198),
    [anon_sym___vectorcall] = ACTIONS(2198),
    [anon_sym_LBRACE] = ACTIONS(2200),
    [anon_sym_signed] = ACTIONS(2198),
    [anon_sym_unsigned] = ACTIONS(2198),
    [anon_sym_long] = ACTIONS(2198),
    [anon_sym_short] = ACTIONS(2198),
    [anon_sym_LBRACK] = ACTIONS(2198),
    [anon_sym_static] = ACTIONS(2198),
    [anon_sym_register] = ACTIONS(2198),
    [anon_sym_inline] = ACTIONS(2198),
    [anon_sym___inline] = ACTIONS(2198),
    [anon_sym___inline__] = ACTIONS(2198),
    [anon_sym___forceinline] = ACTIONS(2198),
    [anon_sym_thread_local] = ACTIONS(2198),
    [anon_sym___thread] = ACTIONS(2198),
    [anon_sym_const] = ACTIONS(2198),
    [anon_sym_constexpr] = ACTIONS(2198),
    [anon_sym_volatile] = ACTIONS(2198),
    [anon_sym_restrict] = ACTIONS(2198),
    [anon_sym___restrict__] = ACTIONS(2198),
    [anon_sym__Atomic] = ACTIONS(2198),
    [anon_sym__Noreturn] = ACTIONS(2198),
    [anon_sym_noreturn] = ACTIONS(2198),
    [anon_sym_mutable] = ACTIONS(2198),
    [anon_sym_constinit] = ACTIONS(2198),
    [anon_sym_consteval] = ACTIONS(2198),
    [anon_sym_alignas] = ACTIONS(2198),
    [anon_sym__Alignas] = ACTIONS(2198),
    [sym_primitive_type] = ACTIONS(2198),
    [anon_sym_enum] = ACTIONS(2198),
    [anon_sym_class] = ACTIONS(2198),
    [anon_sym_struct] = ACTIONS(2198),
    [anon_sym_union] = ACTIONS(2198),
    [anon_sym_if] = ACTIONS(2198),
    [anon_sym_else] = ACTIONS(2198),
    [anon_sym_switch] = ACTIONS(2198),
    [anon_sym_case] = ACTIONS(2198),
    [anon_sym_default] = ACTIONS(2198),
    [anon_sym_while] = ACTIONS(2198),
    [anon_sym_do] = ACTIONS(2198),
    [anon_sym_for] = ACTIONS(2198),
    [anon_sym_return] = ACTIONS(2198),
    [anon_sym_break] = ACTIONS(2198),
    [anon_sym_continue] = ACTIONS(2198),
    [anon_sym_goto] = ACTIONS(2198),
    [anon_sym___try] = ACTIONS(2198),
    [anon_sym___leave] = ACTIONS(2198),
    [anon_sym_not] = ACTIONS(2198),
    [anon_sym_compl] = ACTIONS(2198),
    [anon_sym_DASH_DASH] = ACTIONS(2200),
    [anon_sym_PLUS_PLUS] = ACTIONS(2200),
    [anon_sym_sizeof] = ACTIONS(2198),
    [anon_sym___alignof__] = ACTIONS(2198),
    [anon_sym___alignof] = ACTIONS(2198),
    [anon_sym__alignof] = ACTIONS(2198),
    [anon_sym_alignof] = ACTIONS(2198),
    [anon_sym__Alignof] = ACTIONS(2198),
    [anon_sym_offsetof] = ACTIONS(2198),
    [anon_sym__Generic] = ACTIONS(2198),
    [anon_sym_asm] = ACTIONS(2198),
    [anon_sym___asm__] = ACTIONS(2198),
    [sym_number_literal] = ACTIONS(2200),
    [anon_sym_L_SQUOTE] = ACTIONS(2200),
    [anon_sym_u_SQUOTE] = ACTIONS(2200),
    [anon_sym_U_SQUOTE] = ACTIONS(2200),
    [anon_sym_u8_SQUOTE] = ACTIONS(2200),
    [anon_sym_SQUOTE] = ACTIONS(2200),
    [anon_sym_L_DQUOTE] = ACTIONS(2200),
    [anon_sym_u_DQUOTE] = ACTIONS(2200),
    [anon_sym_U_DQUOTE] = ACTIONS(2200),
    [anon_sym_u8_DQUOTE] = ACTIONS(2200),
    [anon_sym_DQUOTE] = ACTIONS(2200),
    [sym_true] = ACTIONS(2198),
    [sym_false] = ACTIONS(2198),
    [anon_sym_NULL] = ACTIONS(2198),
    [anon_sym_nullptr] = ACTIONS(2198),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2198),
    [anon_sym_decltype] = ACTIONS(2198),
    [sym_virtual] = ACTIONS(2198),
    [anon_sym_explicit] = ACTIONS(2198),
    [anon_sym_typename] = ACTIONS(2198),
    [anon_sym_template] = ACTIONS(2198),
    [anon_sym_operator] = ACTIONS(2198),
    [anon_sym_try] = ACTIONS(2198),
    [anon_sym_delete] = ACTIONS(2198),
    [anon_sym_throw] = ACTIONS(2198),
    [anon_sym_namespace] = ACTIONS(2198),
    [anon_sym_using] = ACTIONS(2198),
    [anon_sym_static_assert] = ACTIONS(2198),
    [anon_sym_concept] = ACTIONS(2198),
    [anon_sym_co_return] = ACTIONS(2198),
    [anon_sym_co_yield] = ACTIONS(2198),
    [anon_sym_R_DQUOTE] = ACTIONS(2200),
    [anon_sym_LR_DQUOTE] = ACTIONS(2200),
    [anon_sym_uR_DQUOTE] = ACTIONS(2200),
    [anon_sym_UR_DQUOTE] = ACTIONS(2200),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2200),
    [anon_sym_co_await] = ACTIONS(2198),
    [anon_sym_new] = ACTIONS(2198),
    [anon_sym_requires] = ACTIONS(2198),
    [sym_this] = ACTIONS(2198),
    [anon_sym_discard] = ACTIONS(2198),
    [anon_sym_precise] = ACTIONS(2198),
    [anon_sym_shared] = ACTIONS(2198),
    [anon_sym_groupshared] = ACTIONS(2198),
    [anon_sym_uniform] = ACTIONS(2198),
    [anon_sym_row_major] = ACTIONS(2198),
    [anon_sym_column_major] = ACTIONS(2198),
    [anon_sym_globallycoherent] = ACTIONS(2198),
    [anon_sym_centroid] = ACTIONS(2198),
    [anon_sym_noperspective] = ACTIONS(2198),
    [anon_sym_nointerpolation] = ACTIONS(2198),
    [anon_sym_sample] = ACTIONS(2198),
    [anon_sym_linear] = ACTIONS(2198),
    [anon_sym_snorm] = ACTIONS(2198),
    [anon_sym_unorm] = ACTIONS(2198),
    [anon_sym_point] = ACTIONS(2198),
    [anon_sym_line] = ACTIONS(2198),
    [anon_sym_triangleadj] = ACTIONS(2198),
    [anon_sym_lineadj] = ACTIONS(2198),
    [anon_sym_triangle] = ACTIONS(2198),
    [anon_sym_cbuffer] = ACTIONS(2198),
  },
  [207] = {
    [sym_identifier] = ACTIONS(1947),
    [aux_sym_preproc_include_token1] = ACTIONS(1947),
    [aux_sym_preproc_def_token1] = ACTIONS(1947),
    [anon_sym_COMMA] = ACTIONS(2202),
    [aux_sym_preproc_if_token1] = ACTIONS(1947),
    [aux_sym_preproc_if_token2] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1947),
    [aux_sym_preproc_else_token1] = ACTIONS(1947),
    [aux_sym_preproc_elif_token1] = ACTIONS(1947),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1947),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1947),
    [sym_preproc_directive] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1945),
    [anon_sym_BANG] = ACTIONS(1945),
    [anon_sym_TILDE] = ACTIONS(1945),
    [anon_sym_DASH] = ACTIONS(1947),
    [anon_sym_PLUS] = ACTIONS(1947),
    [anon_sym_STAR] = ACTIONS(1945),
    [anon_sym_AMP_AMP] = ACTIONS(1945),
    [anon_sym_AMP] = ACTIONS(1947),
    [anon_sym_SEMI] = ACTIONS(2202),
    [anon_sym___extension__] = ACTIONS(1947),
    [anon_sym_typedef] = ACTIONS(1947),
    [anon_sym_in] = ACTIONS(1947),
    [anon_sym_out] = ACTIONS(1947),
    [anon_sym_inout] = ACTIONS(1947),
    [anon_sym_extern] = ACTIONS(1947),
    [anon_sym___attribute__] = ACTIONS(1947),
    [anon_sym_COLON_COLON] = ACTIONS(1945),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1945),
    [anon_sym___declspec] = ACTIONS(1947),
    [anon_sym___based] = ACTIONS(1947),
    [anon_sym___cdecl] = ACTIONS(1947),
    [anon_sym___clrcall] = ACTIONS(1947),
    [anon_sym___stdcall] = ACTIONS(1947),
    [anon_sym___fastcall] = ACTIONS(1947),
    [anon_sym___thiscall] = ACTIONS(1947),
    [anon_sym___vectorcall] = ACTIONS(1947),
    [anon_sym_LBRACE] = ACTIONS(1945),
    [anon_sym_signed] = ACTIONS(1947),
    [anon_sym_unsigned] = ACTIONS(1947),
    [anon_sym_long] = ACTIONS(1947),
    [anon_sym_short] = ACTIONS(1947),
    [anon_sym_LBRACK] = ACTIONS(1947),
    [anon_sym_static] = ACTIONS(1947),
    [anon_sym_register] = ACTIONS(1947),
    [anon_sym_inline] = ACTIONS(1947),
    [anon_sym___inline] = ACTIONS(1947),
    [anon_sym___inline__] = ACTIONS(1947),
    [anon_sym___forceinline] = ACTIONS(1947),
    [anon_sym_thread_local] = ACTIONS(1947),
    [anon_sym___thread] = ACTIONS(1947),
    [anon_sym_const] = ACTIONS(1947),
    [anon_sym_constexpr] = ACTIONS(1947),
    [anon_sym_volatile] = ACTIONS(1947),
    [anon_sym_restrict] = ACTIONS(1947),
    [anon_sym___restrict__] = ACTIONS(1947),
    [anon_sym__Atomic] = ACTIONS(1947),
    [anon_sym__Noreturn] = ACTIONS(1947),
    [anon_sym_noreturn] = ACTIONS(1947),
    [anon_sym_mutable] = ACTIONS(1947),
    [anon_sym_constinit] = ACTIONS(1947),
    [anon_sym_consteval] = ACTIONS(1947),
    [anon_sym_alignas] = ACTIONS(1947),
    [anon_sym__Alignas] = ACTIONS(1947),
    [sym_primitive_type] = ACTIONS(1947),
    [anon_sym_enum] = ACTIONS(1947),
    [anon_sym_class] = ACTIONS(1947),
    [anon_sym_struct] = ACTIONS(1947),
    [anon_sym_union] = ACTIONS(1947),
    [anon_sym_if] = ACTIONS(1947),
    [anon_sym_switch] = ACTIONS(1947),
    [anon_sym_case] = ACTIONS(1947),
    [anon_sym_default] = ACTIONS(1947),
    [anon_sym_while] = ACTIONS(1947),
    [anon_sym_do] = ACTIONS(1947),
    [anon_sym_for] = ACTIONS(1947),
    [anon_sym_return] = ACTIONS(1947),
    [anon_sym_break] = ACTIONS(1947),
    [anon_sym_continue] = ACTIONS(1947),
    [anon_sym_goto] = ACTIONS(1947),
    [anon_sym___try] = ACTIONS(1947),
    [anon_sym___leave] = ACTIONS(1947),
    [anon_sym_not] = ACTIONS(1947),
    [anon_sym_compl] = ACTIONS(1947),
    [anon_sym_DASH_DASH] = ACTIONS(1945),
    [anon_sym_PLUS_PLUS] = ACTIONS(1945),
    [anon_sym_sizeof] = ACTIONS(1947),
    [anon_sym___alignof__] = ACTIONS(1947),
    [anon_sym___alignof] = ACTIONS(1947),
    [anon_sym__alignof] = ACTIONS(1947),
    [anon_sym_alignof] = ACTIONS(1947),
    [anon_sym__Alignof] = ACTIONS(1947),
    [anon_sym_offsetof] = ACTIONS(1947),
    [anon_sym__Generic] = ACTIONS(1947),
    [anon_sym_asm] = ACTIONS(1947),
    [anon_sym___asm__] = ACTIONS(1947),
    [sym_number_literal] = ACTIONS(1945),
    [anon_sym_L_SQUOTE] = ACTIONS(1945),
    [anon_sym_u_SQUOTE] = ACTIONS(1945),
    [anon_sym_U_SQUOTE] = ACTIONS(1945),
    [anon_sym_u8_SQUOTE] = ACTIONS(1945),
    [anon_sym_SQUOTE] = ACTIONS(1945),
    [anon_sym_L_DQUOTE] = ACTIONS(1945),
    [anon_sym_u_DQUOTE] = ACTIONS(1945),
    [anon_sym_U_DQUOTE] = ACTIONS(1945),
    [anon_sym_u8_DQUOTE] = ACTIONS(1945),
    [anon_sym_DQUOTE] = ACTIONS(1945),
    [sym_true] = ACTIONS(1947),
    [sym_false] = ACTIONS(1947),
    [anon_sym_NULL] = ACTIONS(1947),
    [anon_sym_nullptr] = ACTIONS(1947),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1947),
    [anon_sym_decltype] = ACTIONS(1947),
    [sym_virtual] = ACTIONS(1947),
    [anon_sym_explicit] = ACTIONS(1947),
    [anon_sym_typename] = ACTIONS(1947),
    [anon_sym_template] = ACTIONS(1947),
    [anon_sym_operator] = ACTIONS(1947),
    [anon_sym_try] = ACTIONS(1947),
    [anon_sym_delete] = ACTIONS(1947),
    [anon_sym_throw] = ACTIONS(1947),
    [anon_sym_namespace] = ACTIONS(1947),
    [anon_sym_using] = ACTIONS(1947),
    [anon_sym_static_assert] = ACTIONS(1947),
    [anon_sym_concept] = ACTIONS(1947),
    [anon_sym_co_return] = ACTIONS(1947),
    [anon_sym_co_yield] = ACTIONS(1947),
    [anon_sym_R_DQUOTE] = ACTIONS(1945),
    [anon_sym_LR_DQUOTE] = ACTIONS(1945),
    [anon_sym_uR_DQUOTE] = ACTIONS(1945),
    [anon_sym_UR_DQUOTE] = ACTIONS(1945),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1945),
    [anon_sym_co_await] = ACTIONS(1947),
    [anon_sym_new] = ACTIONS(1947),
    [anon_sym_requires] = ACTIONS(1947),
    [sym_this] = ACTIONS(1947),
    [anon_sym_discard] = ACTIONS(1947),
    [anon_sym_precise] = ACTIONS(1947),
    [anon_sym_shared] = ACTIONS(1947),
    [anon_sym_groupshared] = ACTIONS(1947),
    [anon_sym_uniform] = ACTIONS(1947),
    [anon_sym_row_major] = ACTIONS(1947),
    [anon_sym_column_major] = ACTIONS(1947),
    [anon_sym_globallycoherent] = ACTIONS(1947),
    [anon_sym_centroid] = ACTIONS(1947),
    [anon_sym_noperspective] = ACTIONS(1947),
    [anon_sym_nointerpolation] = ACTIONS(1947),
    [anon_sym_sample] = ACTIONS(1947),
    [anon_sym_linear] = ACTIONS(1947),
    [anon_sym_snorm] = ACTIONS(1947),
    [anon_sym_unorm] = ACTIONS(1947),
    [anon_sym_point] = ACTIONS(1947),
    [anon_sym_line] = ACTIONS(1947),
    [anon_sym_triangleadj] = ACTIONS(1947),
    [anon_sym_lineadj] = ACTIONS(1947),
    [anon_sym_triangle] = ACTIONS(1947),
    [anon_sym_cbuffer] = ACTIONS(1947),
  },
  [208] = {
    [sym_identifier] = ACTIONS(2204),
    [aux_sym_preproc_include_token1] = ACTIONS(2204),
    [aux_sym_preproc_def_token1] = ACTIONS(2204),
    [aux_sym_preproc_if_token1] = ACTIONS(2204),
    [aux_sym_preproc_if_token2] = ACTIONS(2204),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2204),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2204),
    [aux_sym_preproc_else_token1] = ACTIONS(2204),
    [aux_sym_preproc_elif_token1] = ACTIONS(2204),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2204),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2204),
    [sym_preproc_directive] = ACTIONS(2204),
    [anon_sym_LPAREN2] = ACTIONS(2206),
    [anon_sym_BANG] = ACTIONS(2206),
    [anon_sym_TILDE] = ACTIONS(2206),
    [anon_sym_DASH] = ACTIONS(2204),
    [anon_sym_PLUS] = ACTIONS(2204),
    [anon_sym_STAR] = ACTIONS(2206),
    [anon_sym_AMP_AMP] = ACTIONS(2206),
    [anon_sym_AMP] = ACTIONS(2204),
    [anon_sym_SEMI] = ACTIONS(2206),
    [anon_sym___extension__] = ACTIONS(2204),
    [anon_sym_typedef] = ACTIONS(2204),
    [anon_sym_in] = ACTIONS(2204),
    [anon_sym_out] = ACTIONS(2204),
    [anon_sym_inout] = ACTIONS(2204),
    [anon_sym_extern] = ACTIONS(2204),
    [anon_sym___attribute__] = ACTIONS(2204),
    [anon_sym_COLON_COLON] = ACTIONS(2206),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2206),
    [anon_sym___declspec] = ACTIONS(2204),
    [anon_sym___based] = ACTIONS(2204),
    [anon_sym___cdecl] = ACTIONS(2204),
    [anon_sym___clrcall] = ACTIONS(2204),
    [anon_sym___stdcall] = ACTIONS(2204),
    [anon_sym___fastcall] = ACTIONS(2204),
    [anon_sym___thiscall] = ACTIONS(2204),
    [anon_sym___vectorcall] = ACTIONS(2204),
    [anon_sym_LBRACE] = ACTIONS(2206),
    [anon_sym_signed] = ACTIONS(2204),
    [anon_sym_unsigned] = ACTIONS(2204),
    [anon_sym_long] = ACTIONS(2204),
    [anon_sym_short] = ACTIONS(2204),
    [anon_sym_LBRACK] = ACTIONS(2204),
    [anon_sym_static] = ACTIONS(2204),
    [anon_sym_register] = ACTIONS(2204),
    [anon_sym_inline] = ACTIONS(2204),
    [anon_sym___inline] = ACTIONS(2204),
    [anon_sym___inline__] = ACTIONS(2204),
    [anon_sym___forceinline] = ACTIONS(2204),
    [anon_sym_thread_local] = ACTIONS(2204),
    [anon_sym___thread] = ACTIONS(2204),
    [anon_sym_const] = ACTIONS(2204),
    [anon_sym_constexpr] = ACTIONS(2204),
    [anon_sym_volatile] = ACTIONS(2204),
    [anon_sym_restrict] = ACTIONS(2204),
    [anon_sym___restrict__] = ACTIONS(2204),
    [anon_sym__Atomic] = ACTIONS(2204),
    [anon_sym__Noreturn] = ACTIONS(2204),
    [anon_sym_noreturn] = ACTIONS(2204),
    [anon_sym_mutable] = ACTIONS(2204),
    [anon_sym_constinit] = ACTIONS(2204),
    [anon_sym_consteval] = ACTIONS(2204),
    [anon_sym_alignas] = ACTIONS(2204),
    [anon_sym__Alignas] = ACTIONS(2204),
    [sym_primitive_type] = ACTIONS(2204),
    [anon_sym_enum] = ACTIONS(2204),
    [anon_sym_class] = ACTIONS(2204),
    [anon_sym_struct] = ACTIONS(2204),
    [anon_sym_union] = ACTIONS(2204),
    [anon_sym_if] = ACTIONS(2204),
    [anon_sym_else] = ACTIONS(2204),
    [anon_sym_switch] = ACTIONS(2204),
    [anon_sym_case] = ACTIONS(2204),
    [anon_sym_default] = ACTIONS(2204),
    [anon_sym_while] = ACTIONS(2204),
    [anon_sym_do] = ACTIONS(2204),
    [anon_sym_for] = ACTIONS(2204),
    [anon_sym_return] = ACTIONS(2204),
    [anon_sym_break] = ACTIONS(2204),
    [anon_sym_continue] = ACTIONS(2204),
    [anon_sym_goto] = ACTIONS(2204),
    [anon_sym___try] = ACTIONS(2204),
    [anon_sym___leave] = ACTIONS(2204),
    [anon_sym_not] = ACTIONS(2204),
    [anon_sym_compl] = ACTIONS(2204),
    [anon_sym_DASH_DASH] = ACTIONS(2206),
    [anon_sym_PLUS_PLUS] = ACTIONS(2206),
    [anon_sym_sizeof] = ACTIONS(2204),
    [anon_sym___alignof__] = ACTIONS(2204),
    [anon_sym___alignof] = ACTIONS(2204),
    [anon_sym__alignof] = ACTIONS(2204),
    [anon_sym_alignof] = ACTIONS(2204),
    [anon_sym__Alignof] = ACTIONS(2204),
    [anon_sym_offsetof] = ACTIONS(2204),
    [anon_sym__Generic] = ACTIONS(2204),
    [anon_sym_asm] = ACTIONS(2204),
    [anon_sym___asm__] = ACTIONS(2204),
    [sym_number_literal] = ACTIONS(2206),
    [anon_sym_L_SQUOTE] = ACTIONS(2206),
    [anon_sym_u_SQUOTE] = ACTIONS(2206),
    [anon_sym_U_SQUOTE] = ACTIONS(2206),
    [anon_sym_u8_SQUOTE] = ACTIONS(2206),
    [anon_sym_SQUOTE] = ACTIONS(2206),
    [anon_sym_L_DQUOTE] = ACTIONS(2206),
    [anon_sym_u_DQUOTE] = ACTIONS(2206),
    [anon_sym_U_DQUOTE] = ACTIONS(2206),
    [anon_sym_u8_DQUOTE] = ACTIONS(2206),
    [anon_sym_DQUOTE] = ACTIONS(2206),
    [sym_true] = ACTIONS(2204),
    [sym_false] = ACTIONS(2204),
    [anon_sym_NULL] = ACTIONS(2204),
    [anon_sym_nullptr] = ACTIONS(2204),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2204),
    [anon_sym_decltype] = ACTIONS(2204),
    [sym_virtual] = ACTIONS(2204),
    [anon_sym_explicit] = ACTIONS(2204),
    [anon_sym_typename] = ACTIONS(2204),
    [anon_sym_template] = ACTIONS(2204),
    [anon_sym_operator] = ACTIONS(2204),
    [anon_sym_try] = ACTIONS(2204),
    [anon_sym_delete] = ACTIONS(2204),
    [anon_sym_throw] = ACTIONS(2204),
    [anon_sym_namespace] = ACTIONS(2204),
    [anon_sym_using] = ACTIONS(2204),
    [anon_sym_static_assert] = ACTIONS(2204),
    [anon_sym_concept] = ACTIONS(2204),
    [anon_sym_co_return] = ACTIONS(2204),
    [anon_sym_co_yield] = ACTIONS(2204),
    [anon_sym_R_DQUOTE] = ACTIONS(2206),
    [anon_sym_LR_DQUOTE] = ACTIONS(2206),
    [anon_sym_uR_DQUOTE] = ACTIONS(2206),
    [anon_sym_UR_DQUOTE] = ACTIONS(2206),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2206),
    [anon_sym_co_await] = ACTIONS(2204),
    [anon_sym_new] = ACTIONS(2204),
    [anon_sym_requires] = ACTIONS(2204),
    [sym_this] = ACTIONS(2204),
    [anon_sym_discard] = ACTIONS(2204),
    [anon_sym_precise] = ACTIONS(2204),
    [anon_sym_shared] = ACTIONS(2204),
    [anon_sym_groupshared] = ACTIONS(2204),
    [anon_sym_uniform] = ACTIONS(2204),
    [anon_sym_row_major] = ACTIONS(2204),
    [anon_sym_column_major] = ACTIONS(2204),
    [anon_sym_globallycoherent] = ACTIONS(2204),
    [anon_sym_centroid] = ACTIONS(2204),
    [anon_sym_noperspective] = ACTIONS(2204),
    [anon_sym_nointerpolation] = ACTIONS(2204),
    [anon_sym_sample] = ACTIONS(2204),
    [anon_sym_linear] = ACTIONS(2204),
    [anon_sym_snorm] = ACTIONS(2204),
    [anon_sym_unorm] = ACTIONS(2204),
    [anon_sym_point] = ACTIONS(2204),
    [anon_sym_line] = ACTIONS(2204),
    [anon_sym_triangleadj] = ACTIONS(2204),
    [anon_sym_lineadj] = ACTIONS(2204),
    [anon_sym_triangle] = ACTIONS(2204),
    [anon_sym_cbuffer] = ACTIONS(2204),
  },
  [209] = {
    [sym_identifier] = ACTIONS(2208),
    [aux_sym_preproc_include_token1] = ACTIONS(2208),
    [aux_sym_preproc_def_token1] = ACTIONS(2208),
    [aux_sym_preproc_if_token1] = ACTIONS(2208),
    [aux_sym_preproc_if_token2] = ACTIONS(2208),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2208),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2208),
    [aux_sym_preproc_else_token1] = ACTIONS(2208),
    [aux_sym_preproc_elif_token1] = ACTIONS(2208),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2208),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2208),
    [sym_preproc_directive] = ACTIONS(2208),
    [anon_sym_LPAREN2] = ACTIONS(2210),
    [anon_sym_BANG] = ACTIONS(2210),
    [anon_sym_TILDE] = ACTIONS(2210),
    [anon_sym_DASH] = ACTIONS(2208),
    [anon_sym_PLUS] = ACTIONS(2208),
    [anon_sym_STAR] = ACTIONS(2210),
    [anon_sym_AMP_AMP] = ACTIONS(2210),
    [anon_sym_AMP] = ACTIONS(2208),
    [anon_sym_SEMI] = ACTIONS(2210),
    [anon_sym___extension__] = ACTIONS(2208),
    [anon_sym_typedef] = ACTIONS(2208),
    [anon_sym_in] = ACTIONS(2208),
    [anon_sym_out] = ACTIONS(2208),
    [anon_sym_inout] = ACTIONS(2208),
    [anon_sym_extern] = ACTIONS(2208),
    [anon_sym___attribute__] = ACTIONS(2208),
    [anon_sym_COLON_COLON] = ACTIONS(2210),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2210),
    [anon_sym___declspec] = ACTIONS(2208),
    [anon_sym___based] = ACTIONS(2208),
    [anon_sym___cdecl] = ACTIONS(2208),
    [anon_sym___clrcall] = ACTIONS(2208),
    [anon_sym___stdcall] = ACTIONS(2208),
    [anon_sym___fastcall] = ACTIONS(2208),
    [anon_sym___thiscall] = ACTIONS(2208),
    [anon_sym___vectorcall] = ACTIONS(2208),
    [anon_sym_LBRACE] = ACTIONS(2210),
    [anon_sym_signed] = ACTIONS(2208),
    [anon_sym_unsigned] = ACTIONS(2208),
    [anon_sym_long] = ACTIONS(2208),
    [anon_sym_short] = ACTIONS(2208),
    [anon_sym_LBRACK] = ACTIONS(2208),
    [anon_sym_static] = ACTIONS(2208),
    [anon_sym_register] = ACTIONS(2208),
    [anon_sym_inline] = ACTIONS(2208),
    [anon_sym___inline] = ACTIONS(2208),
    [anon_sym___inline__] = ACTIONS(2208),
    [anon_sym___forceinline] = ACTIONS(2208),
    [anon_sym_thread_local] = ACTIONS(2208),
    [anon_sym___thread] = ACTIONS(2208),
    [anon_sym_const] = ACTIONS(2208),
    [anon_sym_constexpr] = ACTIONS(2208),
    [anon_sym_volatile] = ACTIONS(2208),
    [anon_sym_restrict] = ACTIONS(2208),
    [anon_sym___restrict__] = ACTIONS(2208),
    [anon_sym__Atomic] = ACTIONS(2208),
    [anon_sym__Noreturn] = ACTIONS(2208),
    [anon_sym_noreturn] = ACTIONS(2208),
    [anon_sym_mutable] = ACTIONS(2208),
    [anon_sym_constinit] = ACTIONS(2208),
    [anon_sym_consteval] = ACTIONS(2208),
    [anon_sym_alignas] = ACTIONS(2208),
    [anon_sym__Alignas] = ACTIONS(2208),
    [sym_primitive_type] = ACTIONS(2208),
    [anon_sym_enum] = ACTIONS(2208),
    [anon_sym_class] = ACTIONS(2208),
    [anon_sym_struct] = ACTIONS(2208),
    [anon_sym_union] = ACTIONS(2208),
    [anon_sym_if] = ACTIONS(2208),
    [anon_sym_else] = ACTIONS(2208),
    [anon_sym_switch] = ACTIONS(2208),
    [anon_sym_case] = ACTIONS(2208),
    [anon_sym_default] = ACTIONS(2208),
    [anon_sym_while] = ACTIONS(2208),
    [anon_sym_do] = ACTIONS(2208),
    [anon_sym_for] = ACTIONS(2208),
    [anon_sym_return] = ACTIONS(2208),
    [anon_sym_break] = ACTIONS(2208),
    [anon_sym_continue] = ACTIONS(2208),
    [anon_sym_goto] = ACTIONS(2208),
    [anon_sym___try] = ACTIONS(2208),
    [anon_sym___leave] = ACTIONS(2208),
    [anon_sym_not] = ACTIONS(2208),
    [anon_sym_compl] = ACTIONS(2208),
    [anon_sym_DASH_DASH] = ACTIONS(2210),
    [anon_sym_PLUS_PLUS] = ACTIONS(2210),
    [anon_sym_sizeof] = ACTIONS(2208),
    [anon_sym___alignof__] = ACTIONS(2208),
    [anon_sym___alignof] = ACTIONS(2208),
    [anon_sym__alignof] = ACTIONS(2208),
    [anon_sym_alignof] = ACTIONS(2208),
    [anon_sym__Alignof] = ACTIONS(2208),
    [anon_sym_offsetof] = ACTIONS(2208),
    [anon_sym__Generic] = ACTIONS(2208),
    [anon_sym_asm] = ACTIONS(2208),
    [anon_sym___asm__] = ACTIONS(2208),
    [sym_number_literal] = ACTIONS(2210),
    [anon_sym_L_SQUOTE] = ACTIONS(2210),
    [anon_sym_u_SQUOTE] = ACTIONS(2210),
    [anon_sym_U_SQUOTE] = ACTIONS(2210),
    [anon_sym_u8_SQUOTE] = ACTIONS(2210),
    [anon_sym_SQUOTE] = ACTIONS(2210),
    [anon_sym_L_DQUOTE] = ACTIONS(2210),
    [anon_sym_u_DQUOTE] = ACTIONS(2210),
    [anon_sym_U_DQUOTE] = ACTIONS(2210),
    [anon_sym_u8_DQUOTE] = ACTIONS(2210),
    [anon_sym_DQUOTE] = ACTIONS(2210),
    [sym_true] = ACTIONS(2208),
    [sym_false] = ACTIONS(2208),
    [anon_sym_NULL] = ACTIONS(2208),
    [anon_sym_nullptr] = ACTIONS(2208),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2208),
    [anon_sym_decltype] = ACTIONS(2208),
    [sym_virtual] = ACTIONS(2208),
    [anon_sym_explicit] = ACTIONS(2208),
    [anon_sym_typename] = ACTIONS(2208),
    [anon_sym_template] = ACTIONS(2208),
    [anon_sym_operator] = ACTIONS(2208),
    [anon_sym_try] = ACTIONS(2208),
    [anon_sym_delete] = ACTIONS(2208),
    [anon_sym_throw] = ACTIONS(2208),
    [anon_sym_namespace] = ACTIONS(2208),
    [anon_sym_using] = ACTIONS(2208),
    [anon_sym_static_assert] = ACTIONS(2208),
    [anon_sym_concept] = ACTIONS(2208),
    [anon_sym_co_return] = ACTIONS(2208),
    [anon_sym_co_yield] = ACTIONS(2208),
    [anon_sym_R_DQUOTE] = ACTIONS(2210),
    [anon_sym_LR_DQUOTE] = ACTIONS(2210),
    [anon_sym_uR_DQUOTE] = ACTIONS(2210),
    [anon_sym_UR_DQUOTE] = ACTIONS(2210),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2210),
    [anon_sym_co_await] = ACTIONS(2208),
    [anon_sym_new] = ACTIONS(2208),
    [anon_sym_requires] = ACTIONS(2208),
    [sym_this] = ACTIONS(2208),
    [anon_sym_discard] = ACTIONS(2208),
    [anon_sym_precise] = ACTIONS(2208),
    [anon_sym_shared] = ACTIONS(2208),
    [anon_sym_groupshared] = ACTIONS(2208),
    [anon_sym_uniform] = ACTIONS(2208),
    [anon_sym_row_major] = ACTIONS(2208),
    [anon_sym_column_major] = ACTIONS(2208),
    [anon_sym_globallycoherent] = ACTIONS(2208),
    [anon_sym_centroid] = ACTIONS(2208),
    [anon_sym_noperspective] = ACTIONS(2208),
    [anon_sym_nointerpolation] = ACTIONS(2208),
    [anon_sym_sample] = ACTIONS(2208),
    [anon_sym_linear] = ACTIONS(2208),
    [anon_sym_snorm] = ACTIONS(2208),
    [anon_sym_unorm] = ACTIONS(2208),
    [anon_sym_point] = ACTIONS(2208),
    [anon_sym_line] = ACTIONS(2208),
    [anon_sym_triangleadj] = ACTIONS(2208),
    [anon_sym_lineadj] = ACTIONS(2208),
    [anon_sym_triangle] = ACTIONS(2208),
    [anon_sym_cbuffer] = ACTIONS(2208),
  },
  [210] = {
    [sym_identifier] = ACTIONS(2212),
    [aux_sym_preproc_include_token1] = ACTIONS(2212),
    [aux_sym_preproc_def_token1] = ACTIONS(2212),
    [aux_sym_preproc_if_token1] = ACTIONS(2212),
    [aux_sym_preproc_if_token2] = ACTIONS(2212),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2212),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2212),
    [aux_sym_preproc_else_token1] = ACTIONS(2212),
    [aux_sym_preproc_elif_token1] = ACTIONS(2212),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2212),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2212),
    [sym_preproc_directive] = ACTIONS(2212),
    [anon_sym_LPAREN2] = ACTIONS(2214),
    [anon_sym_BANG] = ACTIONS(2214),
    [anon_sym_TILDE] = ACTIONS(2214),
    [anon_sym_DASH] = ACTIONS(2212),
    [anon_sym_PLUS] = ACTIONS(2212),
    [anon_sym_STAR] = ACTIONS(2214),
    [anon_sym_AMP_AMP] = ACTIONS(2214),
    [anon_sym_AMP] = ACTIONS(2212),
    [anon_sym_SEMI] = ACTIONS(2214),
    [anon_sym___extension__] = ACTIONS(2212),
    [anon_sym_typedef] = ACTIONS(2212),
    [anon_sym_in] = ACTIONS(2212),
    [anon_sym_out] = ACTIONS(2212),
    [anon_sym_inout] = ACTIONS(2212),
    [anon_sym_extern] = ACTIONS(2212),
    [anon_sym___attribute__] = ACTIONS(2212),
    [anon_sym_COLON_COLON] = ACTIONS(2214),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2214),
    [anon_sym___declspec] = ACTIONS(2212),
    [anon_sym___based] = ACTIONS(2212),
    [anon_sym___cdecl] = ACTIONS(2212),
    [anon_sym___clrcall] = ACTIONS(2212),
    [anon_sym___stdcall] = ACTIONS(2212),
    [anon_sym___fastcall] = ACTIONS(2212),
    [anon_sym___thiscall] = ACTIONS(2212),
    [anon_sym___vectorcall] = ACTIONS(2212),
    [anon_sym_LBRACE] = ACTIONS(2214),
    [anon_sym_signed] = ACTIONS(2212),
    [anon_sym_unsigned] = ACTIONS(2212),
    [anon_sym_long] = ACTIONS(2212),
    [anon_sym_short] = ACTIONS(2212),
    [anon_sym_LBRACK] = ACTIONS(2212),
    [anon_sym_static] = ACTIONS(2212),
    [anon_sym_register] = ACTIONS(2212),
    [anon_sym_inline] = ACTIONS(2212),
    [anon_sym___inline] = ACTIONS(2212),
    [anon_sym___inline__] = ACTIONS(2212),
    [anon_sym___forceinline] = ACTIONS(2212),
    [anon_sym_thread_local] = ACTIONS(2212),
    [anon_sym___thread] = ACTIONS(2212),
    [anon_sym_const] = ACTIONS(2212),
    [anon_sym_constexpr] = ACTIONS(2212),
    [anon_sym_volatile] = ACTIONS(2212),
    [anon_sym_restrict] = ACTIONS(2212),
    [anon_sym___restrict__] = ACTIONS(2212),
    [anon_sym__Atomic] = ACTIONS(2212),
    [anon_sym__Noreturn] = ACTIONS(2212),
    [anon_sym_noreturn] = ACTIONS(2212),
    [anon_sym_mutable] = ACTIONS(2212),
    [anon_sym_constinit] = ACTIONS(2212),
    [anon_sym_consteval] = ACTIONS(2212),
    [anon_sym_alignas] = ACTIONS(2212),
    [anon_sym__Alignas] = ACTIONS(2212),
    [sym_primitive_type] = ACTIONS(2212),
    [anon_sym_enum] = ACTIONS(2212),
    [anon_sym_class] = ACTIONS(2212),
    [anon_sym_struct] = ACTIONS(2212),
    [anon_sym_union] = ACTIONS(2212),
    [anon_sym_if] = ACTIONS(2212),
    [anon_sym_else] = ACTIONS(2212),
    [anon_sym_switch] = ACTIONS(2212),
    [anon_sym_case] = ACTIONS(2212),
    [anon_sym_default] = ACTIONS(2212),
    [anon_sym_while] = ACTIONS(2212),
    [anon_sym_do] = ACTIONS(2212),
    [anon_sym_for] = ACTIONS(2212),
    [anon_sym_return] = ACTIONS(2212),
    [anon_sym_break] = ACTIONS(2212),
    [anon_sym_continue] = ACTIONS(2212),
    [anon_sym_goto] = ACTIONS(2212),
    [anon_sym___try] = ACTIONS(2212),
    [anon_sym___leave] = ACTIONS(2212),
    [anon_sym_not] = ACTIONS(2212),
    [anon_sym_compl] = ACTIONS(2212),
    [anon_sym_DASH_DASH] = ACTIONS(2214),
    [anon_sym_PLUS_PLUS] = ACTIONS(2214),
    [anon_sym_sizeof] = ACTIONS(2212),
    [anon_sym___alignof__] = ACTIONS(2212),
    [anon_sym___alignof] = ACTIONS(2212),
    [anon_sym__alignof] = ACTIONS(2212),
    [anon_sym_alignof] = ACTIONS(2212),
    [anon_sym__Alignof] = ACTIONS(2212),
    [anon_sym_offsetof] = ACTIONS(2212),
    [anon_sym__Generic] = ACTIONS(2212),
    [anon_sym_asm] = ACTIONS(2212),
    [anon_sym___asm__] = ACTIONS(2212),
    [sym_number_literal] = ACTIONS(2214),
    [anon_sym_L_SQUOTE] = ACTIONS(2214),
    [anon_sym_u_SQUOTE] = ACTIONS(2214),
    [anon_sym_U_SQUOTE] = ACTIONS(2214),
    [anon_sym_u8_SQUOTE] = ACTIONS(2214),
    [anon_sym_SQUOTE] = ACTIONS(2214),
    [anon_sym_L_DQUOTE] = ACTIONS(2214),
    [anon_sym_u_DQUOTE] = ACTIONS(2214),
    [anon_sym_U_DQUOTE] = ACTIONS(2214),
    [anon_sym_u8_DQUOTE] = ACTIONS(2214),
    [anon_sym_DQUOTE] = ACTIONS(2214),
    [sym_true] = ACTIONS(2212),
    [sym_false] = ACTIONS(2212),
    [anon_sym_NULL] = ACTIONS(2212),
    [anon_sym_nullptr] = ACTIONS(2212),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2212),
    [anon_sym_decltype] = ACTIONS(2212),
    [sym_virtual] = ACTIONS(2212),
    [anon_sym_explicit] = ACTIONS(2212),
    [anon_sym_typename] = ACTIONS(2212),
    [anon_sym_template] = ACTIONS(2212),
    [anon_sym_operator] = ACTIONS(2212),
    [anon_sym_try] = ACTIONS(2212),
    [anon_sym_delete] = ACTIONS(2212),
    [anon_sym_throw] = ACTIONS(2212),
    [anon_sym_namespace] = ACTIONS(2212),
    [anon_sym_using] = ACTIONS(2212),
    [anon_sym_static_assert] = ACTIONS(2212),
    [anon_sym_concept] = ACTIONS(2212),
    [anon_sym_co_return] = ACTIONS(2212),
    [anon_sym_co_yield] = ACTIONS(2212),
    [anon_sym_R_DQUOTE] = ACTIONS(2214),
    [anon_sym_LR_DQUOTE] = ACTIONS(2214),
    [anon_sym_uR_DQUOTE] = ACTIONS(2214),
    [anon_sym_UR_DQUOTE] = ACTIONS(2214),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2214),
    [anon_sym_co_await] = ACTIONS(2212),
    [anon_sym_new] = ACTIONS(2212),
    [anon_sym_requires] = ACTIONS(2212),
    [sym_this] = ACTIONS(2212),
    [anon_sym_discard] = ACTIONS(2212),
    [anon_sym_precise] = ACTIONS(2212),
    [anon_sym_shared] = ACTIONS(2212),
    [anon_sym_groupshared] = ACTIONS(2212),
    [anon_sym_uniform] = ACTIONS(2212),
    [anon_sym_row_major] = ACTIONS(2212),
    [anon_sym_column_major] = ACTIONS(2212),
    [anon_sym_globallycoherent] = ACTIONS(2212),
    [anon_sym_centroid] = ACTIONS(2212),
    [anon_sym_noperspective] = ACTIONS(2212),
    [anon_sym_nointerpolation] = ACTIONS(2212),
    [anon_sym_sample] = ACTIONS(2212),
    [anon_sym_linear] = ACTIONS(2212),
    [anon_sym_snorm] = ACTIONS(2212),
    [anon_sym_unorm] = ACTIONS(2212),
    [anon_sym_point] = ACTIONS(2212),
    [anon_sym_line] = ACTIONS(2212),
    [anon_sym_triangleadj] = ACTIONS(2212),
    [anon_sym_lineadj] = ACTIONS(2212),
    [anon_sym_triangle] = ACTIONS(2212),
    [anon_sym_cbuffer] = ACTIONS(2212),
  },
  [211] = {
    [sym_identifier] = ACTIONS(2216),
    [aux_sym_preproc_include_token1] = ACTIONS(2216),
    [aux_sym_preproc_def_token1] = ACTIONS(2216),
    [aux_sym_preproc_if_token1] = ACTIONS(2216),
    [aux_sym_preproc_if_token2] = ACTIONS(2216),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2216),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2216),
    [aux_sym_preproc_else_token1] = ACTIONS(2216),
    [aux_sym_preproc_elif_token1] = ACTIONS(2216),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2216),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2216),
    [sym_preproc_directive] = ACTIONS(2216),
    [anon_sym_LPAREN2] = ACTIONS(2218),
    [anon_sym_BANG] = ACTIONS(2218),
    [anon_sym_TILDE] = ACTIONS(2218),
    [anon_sym_DASH] = ACTIONS(2216),
    [anon_sym_PLUS] = ACTIONS(2216),
    [anon_sym_STAR] = ACTIONS(2218),
    [anon_sym_AMP_AMP] = ACTIONS(2218),
    [anon_sym_AMP] = ACTIONS(2216),
    [anon_sym_SEMI] = ACTIONS(2218),
    [anon_sym___extension__] = ACTIONS(2216),
    [anon_sym_typedef] = ACTIONS(2216),
    [anon_sym_in] = ACTIONS(2216),
    [anon_sym_out] = ACTIONS(2216),
    [anon_sym_inout] = ACTIONS(2216),
    [anon_sym_extern] = ACTIONS(2216),
    [anon_sym___attribute__] = ACTIONS(2216),
    [anon_sym_COLON_COLON] = ACTIONS(2218),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2218),
    [anon_sym___declspec] = ACTIONS(2216),
    [anon_sym___based] = ACTIONS(2216),
    [anon_sym___cdecl] = ACTIONS(2216),
    [anon_sym___clrcall] = ACTIONS(2216),
    [anon_sym___stdcall] = ACTIONS(2216),
    [anon_sym___fastcall] = ACTIONS(2216),
    [anon_sym___thiscall] = ACTIONS(2216),
    [anon_sym___vectorcall] = ACTIONS(2216),
    [anon_sym_LBRACE] = ACTIONS(2218),
    [anon_sym_signed] = ACTIONS(2216),
    [anon_sym_unsigned] = ACTIONS(2216),
    [anon_sym_long] = ACTIONS(2216),
    [anon_sym_short] = ACTIONS(2216),
    [anon_sym_LBRACK] = ACTIONS(2216),
    [anon_sym_static] = ACTIONS(2216),
    [anon_sym_register] = ACTIONS(2216),
    [anon_sym_inline] = ACTIONS(2216),
    [anon_sym___inline] = ACTIONS(2216),
    [anon_sym___inline__] = ACTIONS(2216),
    [anon_sym___forceinline] = ACTIONS(2216),
    [anon_sym_thread_local] = ACTIONS(2216),
    [anon_sym___thread] = ACTIONS(2216),
    [anon_sym_const] = ACTIONS(2216),
    [anon_sym_constexpr] = ACTIONS(2216),
    [anon_sym_volatile] = ACTIONS(2216),
    [anon_sym_restrict] = ACTIONS(2216),
    [anon_sym___restrict__] = ACTIONS(2216),
    [anon_sym__Atomic] = ACTIONS(2216),
    [anon_sym__Noreturn] = ACTIONS(2216),
    [anon_sym_noreturn] = ACTIONS(2216),
    [anon_sym_mutable] = ACTIONS(2216),
    [anon_sym_constinit] = ACTIONS(2216),
    [anon_sym_consteval] = ACTIONS(2216),
    [anon_sym_alignas] = ACTIONS(2216),
    [anon_sym__Alignas] = ACTIONS(2216),
    [sym_primitive_type] = ACTIONS(2216),
    [anon_sym_enum] = ACTIONS(2216),
    [anon_sym_class] = ACTIONS(2216),
    [anon_sym_struct] = ACTIONS(2216),
    [anon_sym_union] = ACTIONS(2216),
    [anon_sym_if] = ACTIONS(2216),
    [anon_sym_else] = ACTIONS(2216),
    [anon_sym_switch] = ACTIONS(2216),
    [anon_sym_case] = ACTIONS(2216),
    [anon_sym_default] = ACTIONS(2216),
    [anon_sym_while] = ACTIONS(2216),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_for] = ACTIONS(2216),
    [anon_sym_return] = ACTIONS(2216),
    [anon_sym_break] = ACTIONS(2216),
    [anon_sym_continue] = ACTIONS(2216),
    [anon_sym_goto] = ACTIONS(2216),
    [anon_sym___try] = ACTIONS(2216),
    [anon_sym___leave] = ACTIONS(2216),
    [anon_sym_not] = ACTIONS(2216),
    [anon_sym_compl] = ACTIONS(2216),
    [anon_sym_DASH_DASH] = ACTIONS(2218),
    [anon_sym_PLUS_PLUS] = ACTIONS(2218),
    [anon_sym_sizeof] = ACTIONS(2216),
    [anon_sym___alignof__] = ACTIONS(2216),
    [anon_sym___alignof] = ACTIONS(2216),
    [anon_sym__alignof] = ACTIONS(2216),
    [anon_sym_alignof] = ACTIONS(2216),
    [anon_sym__Alignof] = ACTIONS(2216),
    [anon_sym_offsetof] = ACTIONS(2216),
    [anon_sym__Generic] = ACTIONS(2216),
    [anon_sym_asm] = ACTIONS(2216),
    [anon_sym___asm__] = ACTIONS(2216),
    [sym_number_literal] = ACTIONS(2218),
    [anon_sym_L_SQUOTE] = ACTIONS(2218),
    [anon_sym_u_SQUOTE] = ACTIONS(2218),
    [anon_sym_U_SQUOTE] = ACTIONS(2218),
    [anon_sym_u8_SQUOTE] = ACTIONS(2218),
    [anon_sym_SQUOTE] = ACTIONS(2218),
    [anon_sym_L_DQUOTE] = ACTIONS(2218),
    [anon_sym_u_DQUOTE] = ACTIONS(2218),
    [anon_sym_U_DQUOTE] = ACTIONS(2218),
    [anon_sym_u8_DQUOTE] = ACTIONS(2218),
    [anon_sym_DQUOTE] = ACTIONS(2218),
    [sym_true] = ACTIONS(2216),
    [sym_false] = ACTIONS(2216),
    [anon_sym_NULL] = ACTIONS(2216),
    [anon_sym_nullptr] = ACTIONS(2216),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2216),
    [anon_sym_decltype] = ACTIONS(2216),
    [sym_virtual] = ACTIONS(2216),
    [anon_sym_explicit] = ACTIONS(2216),
    [anon_sym_typename] = ACTIONS(2216),
    [anon_sym_template] = ACTIONS(2216),
    [anon_sym_operator] = ACTIONS(2216),
    [anon_sym_try] = ACTIONS(2216),
    [anon_sym_delete] = ACTIONS(2216),
    [anon_sym_throw] = ACTIONS(2216),
    [anon_sym_namespace] = ACTIONS(2216),
    [anon_sym_using] = ACTIONS(2216),
    [anon_sym_static_assert] = ACTIONS(2216),
    [anon_sym_concept] = ACTIONS(2216),
    [anon_sym_co_return] = ACTIONS(2216),
    [anon_sym_co_yield] = ACTIONS(2216),
    [anon_sym_R_DQUOTE] = ACTIONS(2218),
    [anon_sym_LR_DQUOTE] = ACTIONS(2218),
    [anon_sym_uR_DQUOTE] = ACTIONS(2218),
    [anon_sym_UR_DQUOTE] = ACTIONS(2218),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2218),
    [anon_sym_co_await] = ACTIONS(2216),
    [anon_sym_new] = ACTIONS(2216),
    [anon_sym_requires] = ACTIONS(2216),
    [sym_this] = ACTIONS(2216),
    [anon_sym_discard] = ACTIONS(2216),
    [anon_sym_precise] = ACTIONS(2216),
    [anon_sym_shared] = ACTIONS(2216),
    [anon_sym_groupshared] = ACTIONS(2216),
    [anon_sym_uniform] = ACTIONS(2216),
    [anon_sym_row_major] = ACTIONS(2216),
    [anon_sym_column_major] = ACTIONS(2216),
    [anon_sym_globallycoherent] = ACTIONS(2216),
    [anon_sym_centroid] = ACTIONS(2216),
    [anon_sym_noperspective] = ACTIONS(2216),
    [anon_sym_nointerpolation] = ACTIONS(2216),
    [anon_sym_sample] = ACTIONS(2216),
    [anon_sym_linear] = ACTIONS(2216),
    [anon_sym_snorm] = ACTIONS(2216),
    [anon_sym_unorm] = ACTIONS(2216),
    [anon_sym_point] = ACTIONS(2216),
    [anon_sym_line] = ACTIONS(2216),
    [anon_sym_triangleadj] = ACTIONS(2216),
    [anon_sym_lineadj] = ACTIONS(2216),
    [anon_sym_triangle] = ACTIONS(2216),
    [anon_sym_cbuffer] = ACTIONS(2216),
  },
  [212] = {
    [sym_identifier] = ACTIONS(2220),
    [aux_sym_preproc_include_token1] = ACTIONS(2220),
    [aux_sym_preproc_def_token1] = ACTIONS(2220),
    [aux_sym_preproc_if_token1] = ACTIONS(2220),
    [aux_sym_preproc_if_token2] = ACTIONS(2220),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2220),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2220),
    [aux_sym_preproc_else_token1] = ACTIONS(2220),
    [aux_sym_preproc_elif_token1] = ACTIONS(2220),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2220),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2220),
    [sym_preproc_directive] = ACTIONS(2220),
    [anon_sym_LPAREN2] = ACTIONS(2222),
    [anon_sym_BANG] = ACTIONS(2222),
    [anon_sym_TILDE] = ACTIONS(2222),
    [anon_sym_DASH] = ACTIONS(2220),
    [anon_sym_PLUS] = ACTIONS(2220),
    [anon_sym_STAR] = ACTIONS(2222),
    [anon_sym_AMP_AMP] = ACTIONS(2222),
    [anon_sym_AMP] = ACTIONS(2220),
    [anon_sym_SEMI] = ACTIONS(2222),
    [anon_sym___extension__] = ACTIONS(2220),
    [anon_sym_typedef] = ACTIONS(2220),
    [anon_sym_in] = ACTIONS(2220),
    [anon_sym_out] = ACTIONS(2220),
    [anon_sym_inout] = ACTIONS(2220),
    [anon_sym_extern] = ACTIONS(2220),
    [anon_sym___attribute__] = ACTIONS(2220),
    [anon_sym_COLON_COLON] = ACTIONS(2222),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2222),
    [anon_sym___declspec] = ACTIONS(2220),
    [anon_sym___based] = ACTIONS(2220),
    [anon_sym___cdecl] = ACTIONS(2220),
    [anon_sym___clrcall] = ACTIONS(2220),
    [anon_sym___stdcall] = ACTIONS(2220),
    [anon_sym___fastcall] = ACTIONS(2220),
    [anon_sym___thiscall] = ACTIONS(2220),
    [anon_sym___vectorcall] = ACTIONS(2220),
    [anon_sym_LBRACE] = ACTIONS(2222),
    [anon_sym_signed] = ACTIONS(2220),
    [anon_sym_unsigned] = ACTIONS(2220),
    [anon_sym_long] = ACTIONS(2220),
    [anon_sym_short] = ACTIONS(2220),
    [anon_sym_LBRACK] = ACTIONS(2220),
    [anon_sym_static] = ACTIONS(2220),
    [anon_sym_register] = ACTIONS(2220),
    [anon_sym_inline] = ACTIONS(2220),
    [anon_sym___inline] = ACTIONS(2220),
    [anon_sym___inline__] = ACTIONS(2220),
    [anon_sym___forceinline] = ACTIONS(2220),
    [anon_sym_thread_local] = ACTIONS(2220),
    [anon_sym___thread] = ACTIONS(2220),
    [anon_sym_const] = ACTIONS(2220),
    [anon_sym_constexpr] = ACTIONS(2220),
    [anon_sym_volatile] = ACTIONS(2220),
    [anon_sym_restrict] = ACTIONS(2220),
    [anon_sym___restrict__] = ACTIONS(2220),
    [anon_sym__Atomic] = ACTIONS(2220),
    [anon_sym__Noreturn] = ACTIONS(2220),
    [anon_sym_noreturn] = ACTIONS(2220),
    [anon_sym_mutable] = ACTIONS(2220),
    [anon_sym_constinit] = ACTIONS(2220),
    [anon_sym_consteval] = ACTIONS(2220),
    [anon_sym_alignas] = ACTIONS(2220),
    [anon_sym__Alignas] = ACTIONS(2220),
    [sym_primitive_type] = ACTIONS(2220),
    [anon_sym_enum] = ACTIONS(2220),
    [anon_sym_class] = ACTIONS(2220),
    [anon_sym_struct] = ACTIONS(2220),
    [anon_sym_union] = ACTIONS(2220),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_else] = ACTIONS(2220),
    [anon_sym_switch] = ACTIONS(2220),
    [anon_sym_case] = ACTIONS(2220),
    [anon_sym_default] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2220),
    [anon_sym_do] = ACTIONS(2220),
    [anon_sym_for] = ACTIONS(2220),
    [anon_sym_return] = ACTIONS(2220),
    [anon_sym_break] = ACTIONS(2220),
    [anon_sym_continue] = ACTIONS(2220),
    [anon_sym_goto] = ACTIONS(2220),
    [anon_sym___try] = ACTIONS(2220),
    [anon_sym___leave] = ACTIONS(2220),
    [anon_sym_not] = ACTIONS(2220),
    [anon_sym_compl] = ACTIONS(2220),
    [anon_sym_DASH_DASH] = ACTIONS(2222),
    [anon_sym_PLUS_PLUS] = ACTIONS(2222),
    [anon_sym_sizeof] = ACTIONS(2220),
    [anon_sym___alignof__] = ACTIONS(2220),
    [anon_sym___alignof] = ACTIONS(2220),
    [anon_sym__alignof] = ACTIONS(2220),
    [anon_sym_alignof] = ACTIONS(2220),
    [anon_sym__Alignof] = ACTIONS(2220),
    [anon_sym_offsetof] = ACTIONS(2220),
    [anon_sym__Generic] = ACTIONS(2220),
    [anon_sym_asm] = ACTIONS(2220),
    [anon_sym___asm__] = ACTIONS(2220),
    [sym_number_literal] = ACTIONS(2222),
    [anon_sym_L_SQUOTE] = ACTIONS(2222),
    [anon_sym_u_SQUOTE] = ACTIONS(2222),
    [anon_sym_U_SQUOTE] = ACTIONS(2222),
    [anon_sym_u8_SQUOTE] = ACTIONS(2222),
    [anon_sym_SQUOTE] = ACTIONS(2222),
    [anon_sym_L_DQUOTE] = ACTIONS(2222),
    [anon_sym_u_DQUOTE] = ACTIONS(2222),
    [anon_sym_U_DQUOTE] = ACTIONS(2222),
    [anon_sym_u8_DQUOTE] = ACTIONS(2222),
    [anon_sym_DQUOTE] = ACTIONS(2222),
    [sym_true] = ACTIONS(2220),
    [sym_false] = ACTIONS(2220),
    [anon_sym_NULL] = ACTIONS(2220),
    [anon_sym_nullptr] = ACTIONS(2220),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2220),
    [anon_sym_decltype] = ACTIONS(2220),
    [sym_virtual] = ACTIONS(2220),
    [anon_sym_explicit] = ACTIONS(2220),
    [anon_sym_typename] = ACTIONS(2220),
    [anon_sym_template] = ACTIONS(2220),
    [anon_sym_operator] = ACTIONS(2220),
    [anon_sym_try] = ACTIONS(2220),
    [anon_sym_delete] = ACTIONS(2220),
    [anon_sym_throw] = ACTIONS(2220),
    [anon_sym_namespace] = ACTIONS(2220),
    [anon_sym_using] = ACTIONS(2220),
    [anon_sym_static_assert] = ACTIONS(2220),
    [anon_sym_concept] = ACTIONS(2220),
    [anon_sym_co_return] = ACTIONS(2220),
    [anon_sym_co_yield] = ACTIONS(2220),
    [anon_sym_R_DQUOTE] = ACTIONS(2222),
    [anon_sym_LR_DQUOTE] = ACTIONS(2222),
    [anon_sym_uR_DQUOTE] = ACTIONS(2222),
    [anon_sym_UR_DQUOTE] = ACTIONS(2222),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2222),
    [anon_sym_co_await] = ACTIONS(2220),
    [anon_sym_new] = ACTIONS(2220),
    [anon_sym_requires] = ACTIONS(2220),
    [sym_this] = ACTIONS(2220),
    [anon_sym_discard] = ACTIONS(2220),
    [anon_sym_precise] = ACTIONS(2220),
    [anon_sym_shared] = ACTIONS(2220),
    [anon_sym_groupshared] = ACTIONS(2220),
    [anon_sym_uniform] = ACTIONS(2220),
    [anon_sym_row_major] = ACTIONS(2220),
    [anon_sym_column_major] = ACTIONS(2220),
    [anon_sym_globallycoherent] = ACTIONS(2220),
    [anon_sym_centroid] = ACTIONS(2220),
    [anon_sym_noperspective] = ACTIONS(2220),
    [anon_sym_nointerpolation] = ACTIONS(2220),
    [anon_sym_sample] = ACTIONS(2220),
    [anon_sym_linear] = ACTIONS(2220),
    [anon_sym_snorm] = ACTIONS(2220),
    [anon_sym_unorm] = ACTIONS(2220),
    [anon_sym_point] = ACTIONS(2220),
    [anon_sym_line] = ACTIONS(2220),
    [anon_sym_triangleadj] = ACTIONS(2220),
    [anon_sym_lineadj] = ACTIONS(2220),
    [anon_sym_triangle] = ACTIONS(2220),
    [anon_sym_cbuffer] = ACTIONS(2220),
  },
  [213] = {
    [sym_identifier] = ACTIONS(2224),
    [aux_sym_preproc_include_token1] = ACTIONS(2224),
    [aux_sym_preproc_def_token1] = ACTIONS(2224),
    [aux_sym_preproc_if_token1] = ACTIONS(2224),
    [aux_sym_preproc_if_token2] = ACTIONS(2224),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2224),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2224),
    [aux_sym_preproc_else_token1] = ACTIONS(2224),
    [aux_sym_preproc_elif_token1] = ACTIONS(2224),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2224),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2224),
    [sym_preproc_directive] = ACTIONS(2224),
    [anon_sym_LPAREN2] = ACTIONS(2226),
    [anon_sym_BANG] = ACTIONS(2226),
    [anon_sym_TILDE] = ACTIONS(2226),
    [anon_sym_DASH] = ACTIONS(2224),
    [anon_sym_PLUS] = ACTIONS(2224),
    [anon_sym_STAR] = ACTIONS(2226),
    [anon_sym_AMP_AMP] = ACTIONS(2226),
    [anon_sym_AMP] = ACTIONS(2224),
    [anon_sym_SEMI] = ACTIONS(2226),
    [anon_sym___extension__] = ACTIONS(2224),
    [anon_sym_typedef] = ACTIONS(2224),
    [anon_sym_in] = ACTIONS(2224),
    [anon_sym_out] = ACTIONS(2224),
    [anon_sym_inout] = ACTIONS(2224),
    [anon_sym_extern] = ACTIONS(2224),
    [anon_sym___attribute__] = ACTIONS(2224),
    [anon_sym_COLON_COLON] = ACTIONS(2226),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2226),
    [anon_sym___declspec] = ACTIONS(2224),
    [anon_sym___based] = ACTIONS(2224),
    [anon_sym___cdecl] = ACTIONS(2224),
    [anon_sym___clrcall] = ACTIONS(2224),
    [anon_sym___stdcall] = ACTIONS(2224),
    [anon_sym___fastcall] = ACTIONS(2224),
    [anon_sym___thiscall] = ACTIONS(2224),
    [anon_sym___vectorcall] = ACTIONS(2224),
    [anon_sym_LBRACE] = ACTIONS(2226),
    [anon_sym_signed] = ACTIONS(2224),
    [anon_sym_unsigned] = ACTIONS(2224),
    [anon_sym_long] = ACTIONS(2224),
    [anon_sym_short] = ACTIONS(2224),
    [anon_sym_LBRACK] = ACTIONS(2224),
    [anon_sym_static] = ACTIONS(2224),
    [anon_sym_register] = ACTIONS(2224),
    [anon_sym_inline] = ACTIONS(2224),
    [anon_sym___inline] = ACTIONS(2224),
    [anon_sym___inline__] = ACTIONS(2224),
    [anon_sym___forceinline] = ACTIONS(2224),
    [anon_sym_thread_local] = ACTIONS(2224),
    [anon_sym___thread] = ACTIONS(2224),
    [anon_sym_const] = ACTIONS(2224),
    [anon_sym_constexpr] = ACTIONS(2224),
    [anon_sym_volatile] = ACTIONS(2224),
    [anon_sym_restrict] = ACTIONS(2224),
    [anon_sym___restrict__] = ACTIONS(2224),
    [anon_sym__Atomic] = ACTIONS(2224),
    [anon_sym__Noreturn] = ACTIONS(2224),
    [anon_sym_noreturn] = ACTIONS(2224),
    [anon_sym_mutable] = ACTIONS(2224),
    [anon_sym_constinit] = ACTIONS(2224),
    [anon_sym_consteval] = ACTIONS(2224),
    [anon_sym_alignas] = ACTIONS(2224),
    [anon_sym__Alignas] = ACTIONS(2224),
    [sym_primitive_type] = ACTIONS(2224),
    [anon_sym_enum] = ACTIONS(2224),
    [anon_sym_class] = ACTIONS(2224),
    [anon_sym_struct] = ACTIONS(2224),
    [anon_sym_union] = ACTIONS(2224),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_else] = ACTIONS(2224),
    [anon_sym_switch] = ACTIONS(2224),
    [anon_sym_case] = ACTIONS(2224),
    [anon_sym_default] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(2224),
    [anon_sym_do] = ACTIONS(2224),
    [anon_sym_for] = ACTIONS(2224),
    [anon_sym_return] = ACTIONS(2224),
    [anon_sym_break] = ACTIONS(2224),
    [anon_sym_continue] = ACTIONS(2224),
    [anon_sym_goto] = ACTIONS(2224),
    [anon_sym___try] = ACTIONS(2224),
    [anon_sym___leave] = ACTIONS(2224),
    [anon_sym_not] = ACTIONS(2224),
    [anon_sym_compl] = ACTIONS(2224),
    [anon_sym_DASH_DASH] = ACTIONS(2226),
    [anon_sym_PLUS_PLUS] = ACTIONS(2226),
    [anon_sym_sizeof] = ACTIONS(2224),
    [anon_sym___alignof__] = ACTIONS(2224),
    [anon_sym___alignof] = ACTIONS(2224),
    [anon_sym__alignof] = ACTIONS(2224),
    [anon_sym_alignof] = ACTIONS(2224),
    [anon_sym__Alignof] = ACTIONS(2224),
    [anon_sym_offsetof] = ACTIONS(2224),
    [anon_sym__Generic] = ACTIONS(2224),
    [anon_sym_asm] = ACTIONS(2224),
    [anon_sym___asm__] = ACTIONS(2224),
    [sym_number_literal] = ACTIONS(2226),
    [anon_sym_L_SQUOTE] = ACTIONS(2226),
    [anon_sym_u_SQUOTE] = ACTIONS(2226),
    [anon_sym_U_SQUOTE] = ACTIONS(2226),
    [anon_sym_u8_SQUOTE] = ACTIONS(2226),
    [anon_sym_SQUOTE] = ACTIONS(2226),
    [anon_sym_L_DQUOTE] = ACTIONS(2226),
    [anon_sym_u_DQUOTE] = ACTIONS(2226),
    [anon_sym_U_DQUOTE] = ACTIONS(2226),
    [anon_sym_u8_DQUOTE] = ACTIONS(2226),
    [anon_sym_DQUOTE] = ACTIONS(2226),
    [sym_true] = ACTIONS(2224),
    [sym_false] = ACTIONS(2224),
    [anon_sym_NULL] = ACTIONS(2224),
    [anon_sym_nullptr] = ACTIONS(2224),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2224),
    [anon_sym_decltype] = ACTIONS(2224),
    [sym_virtual] = ACTIONS(2224),
    [anon_sym_explicit] = ACTIONS(2224),
    [anon_sym_typename] = ACTIONS(2224),
    [anon_sym_template] = ACTIONS(2224),
    [anon_sym_operator] = ACTIONS(2224),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_delete] = ACTIONS(2224),
    [anon_sym_throw] = ACTIONS(2224),
    [anon_sym_namespace] = ACTIONS(2224),
    [anon_sym_using] = ACTIONS(2224),
    [anon_sym_static_assert] = ACTIONS(2224),
    [anon_sym_concept] = ACTIONS(2224),
    [anon_sym_co_return] = ACTIONS(2224),
    [anon_sym_co_yield] = ACTIONS(2224),
    [anon_sym_R_DQUOTE] = ACTIONS(2226),
    [anon_sym_LR_DQUOTE] = ACTIONS(2226),
    [anon_sym_uR_DQUOTE] = ACTIONS(2226),
    [anon_sym_UR_DQUOTE] = ACTIONS(2226),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2226),
    [anon_sym_co_await] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(2224),
    [anon_sym_requires] = ACTIONS(2224),
    [sym_this] = ACTIONS(2224),
    [anon_sym_discard] = ACTIONS(2224),
    [anon_sym_precise] = ACTIONS(2224),
    [anon_sym_shared] = ACTIONS(2224),
    [anon_sym_groupshared] = ACTIONS(2224),
    [anon_sym_uniform] = ACTIONS(2224),
    [anon_sym_row_major] = ACTIONS(2224),
    [anon_sym_column_major] = ACTIONS(2224),
    [anon_sym_globallycoherent] = ACTIONS(2224),
    [anon_sym_centroid] = ACTIONS(2224),
    [anon_sym_noperspective] = ACTIONS(2224),
    [anon_sym_nointerpolation] = ACTIONS(2224),
    [anon_sym_sample] = ACTIONS(2224),
    [anon_sym_linear] = ACTIONS(2224),
    [anon_sym_snorm] = ACTIONS(2224),
    [anon_sym_unorm] = ACTIONS(2224),
    [anon_sym_point] = ACTIONS(2224),
    [anon_sym_line] = ACTIONS(2224),
    [anon_sym_triangleadj] = ACTIONS(2224),
    [anon_sym_lineadj] = ACTIONS(2224),
    [anon_sym_triangle] = ACTIONS(2224),
    [anon_sym_cbuffer] = ACTIONS(2224),
  },
  [214] = {
    [sym_identifier] = ACTIONS(2228),
    [aux_sym_preproc_include_token1] = ACTIONS(2228),
    [aux_sym_preproc_def_token1] = ACTIONS(2228),
    [aux_sym_preproc_if_token1] = ACTIONS(2228),
    [aux_sym_preproc_if_token2] = ACTIONS(2228),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2228),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2228),
    [aux_sym_preproc_else_token1] = ACTIONS(2228),
    [aux_sym_preproc_elif_token1] = ACTIONS(2228),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2228),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2228),
    [sym_preproc_directive] = ACTIONS(2228),
    [anon_sym_LPAREN2] = ACTIONS(2230),
    [anon_sym_BANG] = ACTIONS(2230),
    [anon_sym_TILDE] = ACTIONS(2230),
    [anon_sym_DASH] = ACTIONS(2228),
    [anon_sym_PLUS] = ACTIONS(2228),
    [anon_sym_STAR] = ACTIONS(2230),
    [anon_sym_AMP_AMP] = ACTIONS(2230),
    [anon_sym_AMP] = ACTIONS(2228),
    [anon_sym_SEMI] = ACTIONS(2230),
    [anon_sym___extension__] = ACTIONS(2228),
    [anon_sym_typedef] = ACTIONS(2228),
    [anon_sym_in] = ACTIONS(2228),
    [anon_sym_out] = ACTIONS(2228),
    [anon_sym_inout] = ACTIONS(2228),
    [anon_sym_extern] = ACTIONS(2228),
    [anon_sym___attribute__] = ACTIONS(2228),
    [anon_sym_COLON_COLON] = ACTIONS(2230),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2230),
    [anon_sym___declspec] = ACTIONS(2228),
    [anon_sym___based] = ACTIONS(2228),
    [anon_sym___cdecl] = ACTIONS(2228),
    [anon_sym___clrcall] = ACTIONS(2228),
    [anon_sym___stdcall] = ACTIONS(2228),
    [anon_sym___fastcall] = ACTIONS(2228),
    [anon_sym___thiscall] = ACTIONS(2228),
    [anon_sym___vectorcall] = ACTIONS(2228),
    [anon_sym_LBRACE] = ACTIONS(2230),
    [anon_sym_signed] = ACTIONS(2228),
    [anon_sym_unsigned] = ACTIONS(2228),
    [anon_sym_long] = ACTIONS(2228),
    [anon_sym_short] = ACTIONS(2228),
    [anon_sym_LBRACK] = ACTIONS(2228),
    [anon_sym_static] = ACTIONS(2228),
    [anon_sym_register] = ACTIONS(2228),
    [anon_sym_inline] = ACTIONS(2228),
    [anon_sym___inline] = ACTIONS(2228),
    [anon_sym___inline__] = ACTIONS(2228),
    [anon_sym___forceinline] = ACTIONS(2228),
    [anon_sym_thread_local] = ACTIONS(2228),
    [anon_sym___thread] = ACTIONS(2228),
    [anon_sym_const] = ACTIONS(2228),
    [anon_sym_constexpr] = ACTIONS(2228),
    [anon_sym_volatile] = ACTIONS(2228),
    [anon_sym_restrict] = ACTIONS(2228),
    [anon_sym___restrict__] = ACTIONS(2228),
    [anon_sym__Atomic] = ACTIONS(2228),
    [anon_sym__Noreturn] = ACTIONS(2228),
    [anon_sym_noreturn] = ACTIONS(2228),
    [anon_sym_mutable] = ACTIONS(2228),
    [anon_sym_constinit] = ACTIONS(2228),
    [anon_sym_consteval] = ACTIONS(2228),
    [anon_sym_alignas] = ACTIONS(2228),
    [anon_sym__Alignas] = ACTIONS(2228),
    [sym_primitive_type] = ACTIONS(2228),
    [anon_sym_enum] = ACTIONS(2228),
    [anon_sym_class] = ACTIONS(2228),
    [anon_sym_struct] = ACTIONS(2228),
    [anon_sym_union] = ACTIONS(2228),
    [anon_sym_if] = ACTIONS(2228),
    [anon_sym_else] = ACTIONS(2228),
    [anon_sym_switch] = ACTIONS(2228),
    [anon_sym_case] = ACTIONS(2228),
    [anon_sym_default] = ACTIONS(2228),
    [anon_sym_while] = ACTIONS(2228),
    [anon_sym_do] = ACTIONS(2228),
    [anon_sym_for] = ACTIONS(2228),
    [anon_sym_return] = ACTIONS(2228),
    [anon_sym_break] = ACTIONS(2228),
    [anon_sym_continue] = ACTIONS(2228),
    [anon_sym_goto] = ACTIONS(2228),
    [anon_sym___try] = ACTIONS(2228),
    [anon_sym___leave] = ACTIONS(2228),
    [anon_sym_not] = ACTIONS(2228),
    [anon_sym_compl] = ACTIONS(2228),
    [anon_sym_DASH_DASH] = ACTIONS(2230),
    [anon_sym_PLUS_PLUS] = ACTIONS(2230),
    [anon_sym_sizeof] = ACTIONS(2228),
    [anon_sym___alignof__] = ACTIONS(2228),
    [anon_sym___alignof] = ACTIONS(2228),
    [anon_sym__alignof] = ACTIONS(2228),
    [anon_sym_alignof] = ACTIONS(2228),
    [anon_sym__Alignof] = ACTIONS(2228),
    [anon_sym_offsetof] = ACTIONS(2228),
    [anon_sym__Generic] = ACTIONS(2228),
    [anon_sym_asm] = ACTIONS(2228),
    [anon_sym___asm__] = ACTIONS(2228),
    [sym_number_literal] = ACTIONS(2230),
    [anon_sym_L_SQUOTE] = ACTIONS(2230),
    [anon_sym_u_SQUOTE] = ACTIONS(2230),
    [anon_sym_U_SQUOTE] = ACTIONS(2230),
    [anon_sym_u8_SQUOTE] = ACTIONS(2230),
    [anon_sym_SQUOTE] = ACTIONS(2230),
    [anon_sym_L_DQUOTE] = ACTIONS(2230),
    [anon_sym_u_DQUOTE] = ACTIONS(2230),
    [anon_sym_U_DQUOTE] = ACTIONS(2230),
    [anon_sym_u8_DQUOTE] = ACTIONS(2230),
    [anon_sym_DQUOTE] = ACTIONS(2230),
    [sym_true] = ACTIONS(2228),
    [sym_false] = ACTIONS(2228),
    [anon_sym_NULL] = ACTIONS(2228),
    [anon_sym_nullptr] = ACTIONS(2228),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2228),
    [anon_sym_decltype] = ACTIONS(2228),
    [sym_virtual] = ACTIONS(2228),
    [anon_sym_explicit] = ACTIONS(2228),
    [anon_sym_typename] = ACTIONS(2228),
    [anon_sym_template] = ACTIONS(2228),
    [anon_sym_operator] = ACTIONS(2228),
    [anon_sym_try] = ACTIONS(2228),
    [anon_sym_delete] = ACTIONS(2228),
    [anon_sym_throw] = ACTIONS(2228),
    [anon_sym_namespace] = ACTIONS(2228),
    [anon_sym_using] = ACTIONS(2228),
    [anon_sym_static_assert] = ACTIONS(2228),
    [anon_sym_concept] = ACTIONS(2228),
    [anon_sym_co_return] = ACTIONS(2228),
    [anon_sym_co_yield] = ACTIONS(2228),
    [anon_sym_R_DQUOTE] = ACTIONS(2230),
    [anon_sym_LR_DQUOTE] = ACTIONS(2230),
    [anon_sym_uR_DQUOTE] = ACTIONS(2230),
    [anon_sym_UR_DQUOTE] = ACTIONS(2230),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2230),
    [anon_sym_co_await] = ACTIONS(2228),
    [anon_sym_new] = ACTIONS(2228),
    [anon_sym_requires] = ACTIONS(2228),
    [sym_this] = ACTIONS(2228),
    [anon_sym_discard] = ACTIONS(2228),
    [anon_sym_precise] = ACTIONS(2228),
    [anon_sym_shared] = ACTIONS(2228),
    [anon_sym_groupshared] = ACTIONS(2228),
    [anon_sym_uniform] = ACTIONS(2228),
    [anon_sym_row_major] = ACTIONS(2228),
    [anon_sym_column_major] = ACTIONS(2228),
    [anon_sym_globallycoherent] = ACTIONS(2228),
    [anon_sym_centroid] = ACTIONS(2228),
    [anon_sym_noperspective] = ACTIONS(2228),
    [anon_sym_nointerpolation] = ACTIONS(2228),
    [anon_sym_sample] = ACTIONS(2228),
    [anon_sym_linear] = ACTIONS(2228),
    [anon_sym_snorm] = ACTIONS(2228),
    [anon_sym_unorm] = ACTIONS(2228),
    [anon_sym_point] = ACTIONS(2228),
    [anon_sym_line] = ACTIONS(2228),
    [anon_sym_triangleadj] = ACTIONS(2228),
    [anon_sym_lineadj] = ACTIONS(2228),
    [anon_sym_triangle] = ACTIONS(2228),
    [anon_sym_cbuffer] = ACTIONS(2228),
  },
  [215] = {
    [sym_identifier] = ACTIONS(2232),
    [aux_sym_preproc_include_token1] = ACTIONS(2232),
    [aux_sym_preproc_def_token1] = ACTIONS(2232),
    [aux_sym_preproc_if_token1] = ACTIONS(2232),
    [aux_sym_preproc_if_token2] = ACTIONS(2232),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2232),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2232),
    [aux_sym_preproc_else_token1] = ACTIONS(2232),
    [aux_sym_preproc_elif_token1] = ACTIONS(2232),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2232),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2232),
    [sym_preproc_directive] = ACTIONS(2232),
    [anon_sym_LPAREN2] = ACTIONS(2234),
    [anon_sym_BANG] = ACTIONS(2234),
    [anon_sym_TILDE] = ACTIONS(2234),
    [anon_sym_DASH] = ACTIONS(2232),
    [anon_sym_PLUS] = ACTIONS(2232),
    [anon_sym_STAR] = ACTIONS(2234),
    [anon_sym_AMP_AMP] = ACTIONS(2234),
    [anon_sym_AMP] = ACTIONS(2232),
    [anon_sym_SEMI] = ACTIONS(2234),
    [anon_sym___extension__] = ACTIONS(2232),
    [anon_sym_typedef] = ACTIONS(2232),
    [anon_sym_in] = ACTIONS(2232),
    [anon_sym_out] = ACTIONS(2232),
    [anon_sym_inout] = ACTIONS(2232),
    [anon_sym_extern] = ACTIONS(2232),
    [anon_sym___attribute__] = ACTIONS(2232),
    [anon_sym_COLON_COLON] = ACTIONS(2234),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2234),
    [anon_sym___declspec] = ACTIONS(2232),
    [anon_sym___based] = ACTIONS(2232),
    [anon_sym___cdecl] = ACTIONS(2232),
    [anon_sym___clrcall] = ACTIONS(2232),
    [anon_sym___stdcall] = ACTIONS(2232),
    [anon_sym___fastcall] = ACTIONS(2232),
    [anon_sym___thiscall] = ACTIONS(2232),
    [anon_sym___vectorcall] = ACTIONS(2232),
    [anon_sym_LBRACE] = ACTIONS(2234),
    [anon_sym_signed] = ACTIONS(2232),
    [anon_sym_unsigned] = ACTIONS(2232),
    [anon_sym_long] = ACTIONS(2232),
    [anon_sym_short] = ACTIONS(2232),
    [anon_sym_LBRACK] = ACTIONS(2232),
    [anon_sym_static] = ACTIONS(2232),
    [anon_sym_register] = ACTIONS(2232),
    [anon_sym_inline] = ACTIONS(2232),
    [anon_sym___inline] = ACTIONS(2232),
    [anon_sym___inline__] = ACTIONS(2232),
    [anon_sym___forceinline] = ACTIONS(2232),
    [anon_sym_thread_local] = ACTIONS(2232),
    [anon_sym___thread] = ACTIONS(2232),
    [anon_sym_const] = ACTIONS(2232),
    [anon_sym_constexpr] = ACTIONS(2232),
    [anon_sym_volatile] = ACTIONS(2232),
    [anon_sym_restrict] = ACTIONS(2232),
    [anon_sym___restrict__] = ACTIONS(2232),
    [anon_sym__Atomic] = ACTIONS(2232),
    [anon_sym__Noreturn] = ACTIONS(2232),
    [anon_sym_noreturn] = ACTIONS(2232),
    [anon_sym_mutable] = ACTIONS(2232),
    [anon_sym_constinit] = ACTIONS(2232),
    [anon_sym_consteval] = ACTIONS(2232),
    [anon_sym_alignas] = ACTIONS(2232),
    [anon_sym__Alignas] = ACTIONS(2232),
    [sym_primitive_type] = ACTIONS(2232),
    [anon_sym_enum] = ACTIONS(2232),
    [anon_sym_class] = ACTIONS(2232),
    [anon_sym_struct] = ACTIONS(2232),
    [anon_sym_union] = ACTIONS(2232),
    [anon_sym_if] = ACTIONS(2232),
    [anon_sym_else] = ACTIONS(2232),
    [anon_sym_switch] = ACTIONS(2232),
    [anon_sym_case] = ACTIONS(2232),
    [anon_sym_default] = ACTIONS(2232),
    [anon_sym_while] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(2232),
    [anon_sym_for] = ACTIONS(2232),
    [anon_sym_return] = ACTIONS(2232),
    [anon_sym_break] = ACTIONS(2232),
    [anon_sym_continue] = ACTIONS(2232),
    [anon_sym_goto] = ACTIONS(2232),
    [anon_sym___try] = ACTIONS(2232),
    [anon_sym___leave] = ACTIONS(2232),
    [anon_sym_not] = ACTIONS(2232),
    [anon_sym_compl] = ACTIONS(2232),
    [anon_sym_DASH_DASH] = ACTIONS(2234),
    [anon_sym_PLUS_PLUS] = ACTIONS(2234),
    [anon_sym_sizeof] = ACTIONS(2232),
    [anon_sym___alignof__] = ACTIONS(2232),
    [anon_sym___alignof] = ACTIONS(2232),
    [anon_sym__alignof] = ACTIONS(2232),
    [anon_sym_alignof] = ACTIONS(2232),
    [anon_sym__Alignof] = ACTIONS(2232),
    [anon_sym_offsetof] = ACTIONS(2232),
    [anon_sym__Generic] = ACTIONS(2232),
    [anon_sym_asm] = ACTIONS(2232),
    [anon_sym___asm__] = ACTIONS(2232),
    [sym_number_literal] = ACTIONS(2234),
    [anon_sym_L_SQUOTE] = ACTIONS(2234),
    [anon_sym_u_SQUOTE] = ACTIONS(2234),
    [anon_sym_U_SQUOTE] = ACTIONS(2234),
    [anon_sym_u8_SQUOTE] = ACTIONS(2234),
    [anon_sym_SQUOTE] = ACTIONS(2234),
    [anon_sym_L_DQUOTE] = ACTIONS(2234),
    [anon_sym_u_DQUOTE] = ACTIONS(2234),
    [anon_sym_U_DQUOTE] = ACTIONS(2234),
    [anon_sym_u8_DQUOTE] = ACTIONS(2234),
    [anon_sym_DQUOTE] = ACTIONS(2234),
    [sym_true] = ACTIONS(2232),
    [sym_false] = ACTIONS(2232),
    [anon_sym_NULL] = ACTIONS(2232),
    [anon_sym_nullptr] = ACTIONS(2232),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2232),
    [anon_sym_decltype] = ACTIONS(2232),
    [sym_virtual] = ACTIONS(2232),
    [anon_sym_explicit] = ACTIONS(2232),
    [anon_sym_typename] = ACTIONS(2232),
    [anon_sym_template] = ACTIONS(2232),
    [anon_sym_operator] = ACTIONS(2232),
    [anon_sym_try] = ACTIONS(2232),
    [anon_sym_delete] = ACTIONS(2232),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_namespace] = ACTIONS(2232),
    [anon_sym_using] = ACTIONS(2232),
    [anon_sym_static_assert] = ACTIONS(2232),
    [anon_sym_concept] = ACTIONS(2232),
    [anon_sym_co_return] = ACTIONS(2232),
    [anon_sym_co_yield] = ACTIONS(2232),
    [anon_sym_R_DQUOTE] = ACTIONS(2234),
    [anon_sym_LR_DQUOTE] = ACTIONS(2234),
    [anon_sym_uR_DQUOTE] = ACTIONS(2234),
    [anon_sym_UR_DQUOTE] = ACTIONS(2234),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2234),
    [anon_sym_co_await] = ACTIONS(2232),
    [anon_sym_new] = ACTIONS(2232),
    [anon_sym_requires] = ACTIONS(2232),
    [sym_this] = ACTIONS(2232),
    [anon_sym_discard] = ACTIONS(2232),
    [anon_sym_precise] = ACTIONS(2232),
    [anon_sym_shared] = ACTIONS(2232),
    [anon_sym_groupshared] = ACTIONS(2232),
    [anon_sym_uniform] = ACTIONS(2232),
    [anon_sym_row_major] = ACTIONS(2232),
    [anon_sym_column_major] = ACTIONS(2232),
    [anon_sym_globallycoherent] = ACTIONS(2232),
    [anon_sym_centroid] = ACTIONS(2232),
    [anon_sym_noperspective] = ACTIONS(2232),
    [anon_sym_nointerpolation] = ACTIONS(2232),
    [anon_sym_sample] = ACTIONS(2232),
    [anon_sym_linear] = ACTIONS(2232),
    [anon_sym_snorm] = ACTIONS(2232),
    [anon_sym_unorm] = ACTIONS(2232),
    [anon_sym_point] = ACTIONS(2232),
    [anon_sym_line] = ACTIONS(2232),
    [anon_sym_triangleadj] = ACTIONS(2232),
    [anon_sym_lineadj] = ACTIONS(2232),
    [anon_sym_triangle] = ACTIONS(2232),
    [anon_sym_cbuffer] = ACTIONS(2232),
  },
  [216] = {
    [sym_identifier] = ACTIONS(2236),
    [aux_sym_preproc_include_token1] = ACTIONS(2236),
    [aux_sym_preproc_def_token1] = ACTIONS(2236),
    [aux_sym_preproc_if_token1] = ACTIONS(2236),
    [aux_sym_preproc_if_token2] = ACTIONS(2236),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2236),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2236),
    [aux_sym_preproc_else_token1] = ACTIONS(2236),
    [aux_sym_preproc_elif_token1] = ACTIONS(2236),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2236),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2236),
    [sym_preproc_directive] = ACTIONS(2236),
    [anon_sym_LPAREN2] = ACTIONS(2238),
    [anon_sym_BANG] = ACTIONS(2238),
    [anon_sym_TILDE] = ACTIONS(2238),
    [anon_sym_DASH] = ACTIONS(2236),
    [anon_sym_PLUS] = ACTIONS(2236),
    [anon_sym_STAR] = ACTIONS(2238),
    [anon_sym_AMP_AMP] = ACTIONS(2238),
    [anon_sym_AMP] = ACTIONS(2236),
    [anon_sym_SEMI] = ACTIONS(2238),
    [anon_sym___extension__] = ACTIONS(2236),
    [anon_sym_typedef] = ACTIONS(2236),
    [anon_sym_in] = ACTIONS(2236),
    [anon_sym_out] = ACTIONS(2236),
    [anon_sym_inout] = ACTIONS(2236),
    [anon_sym_extern] = ACTIONS(2236),
    [anon_sym___attribute__] = ACTIONS(2236),
    [anon_sym_COLON_COLON] = ACTIONS(2238),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2238),
    [anon_sym___declspec] = ACTIONS(2236),
    [anon_sym___based] = ACTIONS(2236),
    [anon_sym___cdecl] = ACTIONS(2236),
    [anon_sym___clrcall] = ACTIONS(2236),
    [anon_sym___stdcall] = ACTIONS(2236),
    [anon_sym___fastcall] = ACTIONS(2236),
    [anon_sym___thiscall] = ACTIONS(2236),
    [anon_sym___vectorcall] = ACTIONS(2236),
    [anon_sym_LBRACE] = ACTIONS(2238),
    [anon_sym_signed] = ACTIONS(2236),
    [anon_sym_unsigned] = ACTIONS(2236),
    [anon_sym_long] = ACTIONS(2236),
    [anon_sym_short] = ACTIONS(2236),
    [anon_sym_LBRACK] = ACTIONS(2236),
    [anon_sym_static] = ACTIONS(2236),
    [anon_sym_register] = ACTIONS(2236),
    [anon_sym_inline] = ACTIONS(2236),
    [anon_sym___inline] = ACTIONS(2236),
    [anon_sym___inline__] = ACTIONS(2236),
    [anon_sym___forceinline] = ACTIONS(2236),
    [anon_sym_thread_local] = ACTIONS(2236),
    [anon_sym___thread] = ACTIONS(2236),
    [anon_sym_const] = ACTIONS(2236),
    [anon_sym_constexpr] = ACTIONS(2236),
    [anon_sym_volatile] = ACTIONS(2236),
    [anon_sym_restrict] = ACTIONS(2236),
    [anon_sym___restrict__] = ACTIONS(2236),
    [anon_sym__Atomic] = ACTIONS(2236),
    [anon_sym__Noreturn] = ACTIONS(2236),
    [anon_sym_noreturn] = ACTIONS(2236),
    [anon_sym_mutable] = ACTIONS(2236),
    [anon_sym_constinit] = ACTIONS(2236),
    [anon_sym_consteval] = ACTIONS(2236),
    [anon_sym_alignas] = ACTIONS(2236),
    [anon_sym__Alignas] = ACTIONS(2236),
    [sym_primitive_type] = ACTIONS(2236),
    [anon_sym_enum] = ACTIONS(2236),
    [anon_sym_class] = ACTIONS(2236),
    [anon_sym_struct] = ACTIONS(2236),
    [anon_sym_union] = ACTIONS(2236),
    [anon_sym_if] = ACTIONS(2236),
    [anon_sym_else] = ACTIONS(2236),
    [anon_sym_switch] = ACTIONS(2236),
    [anon_sym_case] = ACTIONS(2236),
    [anon_sym_default] = ACTIONS(2236),
    [anon_sym_while] = ACTIONS(2236),
    [anon_sym_do] = ACTIONS(2236),
    [anon_sym_for] = ACTIONS(2236),
    [anon_sym_return] = ACTIONS(2236),
    [anon_sym_break] = ACTIONS(2236),
    [anon_sym_continue] = ACTIONS(2236),
    [anon_sym_goto] = ACTIONS(2236),
    [anon_sym___try] = ACTIONS(2236),
    [anon_sym___leave] = ACTIONS(2236),
    [anon_sym_not] = ACTIONS(2236),
    [anon_sym_compl] = ACTIONS(2236),
    [anon_sym_DASH_DASH] = ACTIONS(2238),
    [anon_sym_PLUS_PLUS] = ACTIONS(2238),
    [anon_sym_sizeof] = ACTIONS(2236),
    [anon_sym___alignof__] = ACTIONS(2236),
    [anon_sym___alignof] = ACTIONS(2236),
    [anon_sym__alignof] = ACTIONS(2236),
    [anon_sym_alignof] = ACTIONS(2236),
    [anon_sym__Alignof] = ACTIONS(2236),
    [anon_sym_offsetof] = ACTIONS(2236),
    [anon_sym__Generic] = ACTIONS(2236),
    [anon_sym_asm] = ACTIONS(2236),
    [anon_sym___asm__] = ACTIONS(2236),
    [sym_number_literal] = ACTIONS(2238),
    [anon_sym_L_SQUOTE] = ACTIONS(2238),
    [anon_sym_u_SQUOTE] = ACTIONS(2238),
    [anon_sym_U_SQUOTE] = ACTIONS(2238),
    [anon_sym_u8_SQUOTE] = ACTIONS(2238),
    [anon_sym_SQUOTE] = ACTIONS(2238),
    [anon_sym_L_DQUOTE] = ACTIONS(2238),
    [anon_sym_u_DQUOTE] = ACTIONS(2238),
    [anon_sym_U_DQUOTE] = ACTIONS(2238),
    [anon_sym_u8_DQUOTE] = ACTIONS(2238),
    [anon_sym_DQUOTE] = ACTIONS(2238),
    [sym_true] = ACTIONS(2236),
    [sym_false] = ACTIONS(2236),
    [anon_sym_NULL] = ACTIONS(2236),
    [anon_sym_nullptr] = ACTIONS(2236),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2236),
    [anon_sym_decltype] = ACTIONS(2236),
    [sym_virtual] = ACTIONS(2236),
    [anon_sym_explicit] = ACTIONS(2236),
    [anon_sym_typename] = ACTIONS(2236),
    [anon_sym_template] = ACTIONS(2236),
    [anon_sym_operator] = ACTIONS(2236),
    [anon_sym_try] = ACTIONS(2236),
    [anon_sym_delete] = ACTIONS(2236),
    [anon_sym_throw] = ACTIONS(2236),
    [anon_sym_namespace] = ACTIONS(2236),
    [anon_sym_using] = ACTIONS(2236),
    [anon_sym_static_assert] = ACTIONS(2236),
    [anon_sym_concept] = ACTIONS(2236),
    [anon_sym_co_return] = ACTIONS(2236),
    [anon_sym_co_yield] = ACTIONS(2236),
    [anon_sym_R_DQUOTE] = ACTIONS(2238),
    [anon_sym_LR_DQUOTE] = ACTIONS(2238),
    [anon_sym_uR_DQUOTE] = ACTIONS(2238),
    [anon_sym_UR_DQUOTE] = ACTIONS(2238),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2238),
    [anon_sym_co_await] = ACTIONS(2236),
    [anon_sym_new] = ACTIONS(2236),
    [anon_sym_requires] = ACTIONS(2236),
    [sym_this] = ACTIONS(2236),
    [anon_sym_discard] = ACTIONS(2236),
    [anon_sym_precise] = ACTIONS(2236),
    [anon_sym_shared] = ACTIONS(2236),
    [anon_sym_groupshared] = ACTIONS(2236),
    [anon_sym_uniform] = ACTIONS(2236),
    [anon_sym_row_major] = ACTIONS(2236),
    [anon_sym_column_major] = ACTIONS(2236),
    [anon_sym_globallycoherent] = ACTIONS(2236),
    [anon_sym_centroid] = ACTIONS(2236),
    [anon_sym_noperspective] = ACTIONS(2236),
    [anon_sym_nointerpolation] = ACTIONS(2236),
    [anon_sym_sample] = ACTIONS(2236),
    [anon_sym_linear] = ACTIONS(2236),
    [anon_sym_snorm] = ACTIONS(2236),
    [anon_sym_unorm] = ACTIONS(2236),
    [anon_sym_point] = ACTIONS(2236),
    [anon_sym_line] = ACTIONS(2236),
    [anon_sym_triangleadj] = ACTIONS(2236),
    [anon_sym_lineadj] = ACTIONS(2236),
    [anon_sym_triangle] = ACTIONS(2236),
    [anon_sym_cbuffer] = ACTIONS(2236),
  },
  [217] = {
    [sym_identifier] = ACTIONS(2240),
    [aux_sym_preproc_include_token1] = ACTIONS(2240),
    [aux_sym_preproc_def_token1] = ACTIONS(2240),
    [aux_sym_preproc_if_token1] = ACTIONS(2240),
    [aux_sym_preproc_if_token2] = ACTIONS(2240),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2240),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2240),
    [aux_sym_preproc_else_token1] = ACTIONS(2240),
    [aux_sym_preproc_elif_token1] = ACTIONS(2240),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2240),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2240),
    [sym_preproc_directive] = ACTIONS(2240),
    [anon_sym_LPAREN2] = ACTIONS(2242),
    [anon_sym_BANG] = ACTIONS(2242),
    [anon_sym_TILDE] = ACTIONS(2242),
    [anon_sym_DASH] = ACTIONS(2240),
    [anon_sym_PLUS] = ACTIONS(2240),
    [anon_sym_STAR] = ACTIONS(2242),
    [anon_sym_AMP_AMP] = ACTIONS(2242),
    [anon_sym_AMP] = ACTIONS(2240),
    [anon_sym_SEMI] = ACTIONS(2242),
    [anon_sym___extension__] = ACTIONS(2240),
    [anon_sym_typedef] = ACTIONS(2240),
    [anon_sym_in] = ACTIONS(2240),
    [anon_sym_out] = ACTIONS(2240),
    [anon_sym_inout] = ACTIONS(2240),
    [anon_sym_extern] = ACTIONS(2240),
    [anon_sym___attribute__] = ACTIONS(2240),
    [anon_sym_COLON_COLON] = ACTIONS(2242),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2242),
    [anon_sym___declspec] = ACTIONS(2240),
    [anon_sym___based] = ACTIONS(2240),
    [anon_sym___cdecl] = ACTIONS(2240),
    [anon_sym___clrcall] = ACTIONS(2240),
    [anon_sym___stdcall] = ACTIONS(2240),
    [anon_sym___fastcall] = ACTIONS(2240),
    [anon_sym___thiscall] = ACTIONS(2240),
    [anon_sym___vectorcall] = ACTIONS(2240),
    [anon_sym_LBRACE] = ACTIONS(2242),
    [anon_sym_signed] = ACTIONS(2240),
    [anon_sym_unsigned] = ACTIONS(2240),
    [anon_sym_long] = ACTIONS(2240),
    [anon_sym_short] = ACTIONS(2240),
    [anon_sym_LBRACK] = ACTIONS(2240),
    [anon_sym_static] = ACTIONS(2240),
    [anon_sym_register] = ACTIONS(2240),
    [anon_sym_inline] = ACTIONS(2240),
    [anon_sym___inline] = ACTIONS(2240),
    [anon_sym___inline__] = ACTIONS(2240),
    [anon_sym___forceinline] = ACTIONS(2240),
    [anon_sym_thread_local] = ACTIONS(2240),
    [anon_sym___thread] = ACTIONS(2240),
    [anon_sym_const] = ACTIONS(2240),
    [anon_sym_constexpr] = ACTIONS(2240),
    [anon_sym_volatile] = ACTIONS(2240),
    [anon_sym_restrict] = ACTIONS(2240),
    [anon_sym___restrict__] = ACTIONS(2240),
    [anon_sym__Atomic] = ACTIONS(2240),
    [anon_sym__Noreturn] = ACTIONS(2240),
    [anon_sym_noreturn] = ACTIONS(2240),
    [anon_sym_mutable] = ACTIONS(2240),
    [anon_sym_constinit] = ACTIONS(2240),
    [anon_sym_consteval] = ACTIONS(2240),
    [anon_sym_alignas] = ACTIONS(2240),
    [anon_sym__Alignas] = ACTIONS(2240),
    [sym_primitive_type] = ACTIONS(2240),
    [anon_sym_enum] = ACTIONS(2240),
    [anon_sym_class] = ACTIONS(2240),
    [anon_sym_struct] = ACTIONS(2240),
    [anon_sym_union] = ACTIONS(2240),
    [anon_sym_if] = ACTIONS(2240),
    [anon_sym_else] = ACTIONS(2240),
    [anon_sym_switch] = ACTIONS(2240),
    [anon_sym_case] = ACTIONS(2240),
    [anon_sym_default] = ACTIONS(2240),
    [anon_sym_while] = ACTIONS(2240),
    [anon_sym_do] = ACTIONS(2240),
    [anon_sym_for] = ACTIONS(2240),
    [anon_sym_return] = ACTIONS(2240),
    [anon_sym_break] = ACTIONS(2240),
    [anon_sym_continue] = ACTIONS(2240),
    [anon_sym_goto] = ACTIONS(2240),
    [anon_sym___try] = ACTIONS(2240),
    [anon_sym___leave] = ACTIONS(2240),
    [anon_sym_not] = ACTIONS(2240),
    [anon_sym_compl] = ACTIONS(2240),
    [anon_sym_DASH_DASH] = ACTIONS(2242),
    [anon_sym_PLUS_PLUS] = ACTIONS(2242),
    [anon_sym_sizeof] = ACTIONS(2240),
    [anon_sym___alignof__] = ACTIONS(2240),
    [anon_sym___alignof] = ACTIONS(2240),
    [anon_sym__alignof] = ACTIONS(2240),
    [anon_sym_alignof] = ACTIONS(2240),
    [anon_sym__Alignof] = ACTIONS(2240),
    [anon_sym_offsetof] = ACTIONS(2240),
    [anon_sym__Generic] = ACTIONS(2240),
    [anon_sym_asm] = ACTIONS(2240),
    [anon_sym___asm__] = ACTIONS(2240),
    [sym_number_literal] = ACTIONS(2242),
    [anon_sym_L_SQUOTE] = ACTIONS(2242),
    [anon_sym_u_SQUOTE] = ACTIONS(2242),
    [anon_sym_U_SQUOTE] = ACTIONS(2242),
    [anon_sym_u8_SQUOTE] = ACTIONS(2242),
    [anon_sym_SQUOTE] = ACTIONS(2242),
    [anon_sym_L_DQUOTE] = ACTIONS(2242),
    [anon_sym_u_DQUOTE] = ACTIONS(2242),
    [anon_sym_U_DQUOTE] = ACTIONS(2242),
    [anon_sym_u8_DQUOTE] = ACTIONS(2242),
    [anon_sym_DQUOTE] = ACTIONS(2242),
    [sym_true] = ACTIONS(2240),
    [sym_false] = ACTIONS(2240),
    [anon_sym_NULL] = ACTIONS(2240),
    [anon_sym_nullptr] = ACTIONS(2240),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2240),
    [anon_sym_decltype] = ACTIONS(2240),
    [sym_virtual] = ACTIONS(2240),
    [anon_sym_explicit] = ACTIONS(2240),
    [anon_sym_typename] = ACTIONS(2240),
    [anon_sym_template] = ACTIONS(2240),
    [anon_sym_operator] = ACTIONS(2240),
    [anon_sym_try] = ACTIONS(2240),
    [anon_sym_delete] = ACTIONS(2240),
    [anon_sym_throw] = ACTIONS(2240),
    [anon_sym_namespace] = ACTIONS(2240),
    [anon_sym_using] = ACTIONS(2240),
    [anon_sym_static_assert] = ACTIONS(2240),
    [anon_sym_concept] = ACTIONS(2240),
    [anon_sym_co_return] = ACTIONS(2240),
    [anon_sym_co_yield] = ACTIONS(2240),
    [anon_sym_R_DQUOTE] = ACTIONS(2242),
    [anon_sym_LR_DQUOTE] = ACTIONS(2242),
    [anon_sym_uR_DQUOTE] = ACTIONS(2242),
    [anon_sym_UR_DQUOTE] = ACTIONS(2242),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2242),
    [anon_sym_co_await] = ACTIONS(2240),
    [anon_sym_new] = ACTIONS(2240),
    [anon_sym_requires] = ACTIONS(2240),
    [sym_this] = ACTIONS(2240),
    [anon_sym_discard] = ACTIONS(2240),
    [anon_sym_precise] = ACTIONS(2240),
    [anon_sym_shared] = ACTIONS(2240),
    [anon_sym_groupshared] = ACTIONS(2240),
    [anon_sym_uniform] = ACTIONS(2240),
    [anon_sym_row_major] = ACTIONS(2240),
    [anon_sym_column_major] = ACTIONS(2240),
    [anon_sym_globallycoherent] = ACTIONS(2240),
    [anon_sym_centroid] = ACTIONS(2240),
    [anon_sym_noperspective] = ACTIONS(2240),
    [anon_sym_nointerpolation] = ACTIONS(2240),
    [anon_sym_sample] = ACTIONS(2240),
    [anon_sym_linear] = ACTIONS(2240),
    [anon_sym_snorm] = ACTIONS(2240),
    [anon_sym_unorm] = ACTIONS(2240),
    [anon_sym_point] = ACTIONS(2240),
    [anon_sym_line] = ACTIONS(2240),
    [anon_sym_triangleadj] = ACTIONS(2240),
    [anon_sym_lineadj] = ACTIONS(2240),
    [anon_sym_triangle] = ACTIONS(2240),
    [anon_sym_cbuffer] = ACTIONS(2240),
  },
  [218] = {
    [sym_identifier] = ACTIONS(2244),
    [aux_sym_preproc_include_token1] = ACTIONS(2244),
    [aux_sym_preproc_def_token1] = ACTIONS(2244),
    [aux_sym_preproc_if_token1] = ACTIONS(2244),
    [aux_sym_preproc_if_token2] = ACTIONS(2244),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2244),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2244),
    [aux_sym_preproc_else_token1] = ACTIONS(2244),
    [aux_sym_preproc_elif_token1] = ACTIONS(2244),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2244),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2244),
    [sym_preproc_directive] = ACTIONS(2244),
    [anon_sym_LPAREN2] = ACTIONS(2246),
    [anon_sym_BANG] = ACTIONS(2246),
    [anon_sym_TILDE] = ACTIONS(2246),
    [anon_sym_DASH] = ACTIONS(2244),
    [anon_sym_PLUS] = ACTIONS(2244),
    [anon_sym_STAR] = ACTIONS(2246),
    [anon_sym_AMP_AMP] = ACTIONS(2246),
    [anon_sym_AMP] = ACTIONS(2244),
    [anon_sym_SEMI] = ACTIONS(2246),
    [anon_sym___extension__] = ACTIONS(2244),
    [anon_sym_typedef] = ACTIONS(2244),
    [anon_sym_in] = ACTIONS(2244),
    [anon_sym_out] = ACTIONS(2244),
    [anon_sym_inout] = ACTIONS(2244),
    [anon_sym_extern] = ACTIONS(2244),
    [anon_sym___attribute__] = ACTIONS(2244),
    [anon_sym_COLON_COLON] = ACTIONS(2246),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2246),
    [anon_sym___declspec] = ACTIONS(2244),
    [anon_sym___based] = ACTIONS(2244),
    [anon_sym___cdecl] = ACTIONS(2244),
    [anon_sym___clrcall] = ACTIONS(2244),
    [anon_sym___stdcall] = ACTIONS(2244),
    [anon_sym___fastcall] = ACTIONS(2244),
    [anon_sym___thiscall] = ACTIONS(2244),
    [anon_sym___vectorcall] = ACTIONS(2244),
    [anon_sym_LBRACE] = ACTIONS(2246),
    [anon_sym_signed] = ACTIONS(2244),
    [anon_sym_unsigned] = ACTIONS(2244),
    [anon_sym_long] = ACTIONS(2244),
    [anon_sym_short] = ACTIONS(2244),
    [anon_sym_LBRACK] = ACTIONS(2244),
    [anon_sym_static] = ACTIONS(2244),
    [anon_sym_register] = ACTIONS(2244),
    [anon_sym_inline] = ACTIONS(2244),
    [anon_sym___inline] = ACTIONS(2244),
    [anon_sym___inline__] = ACTIONS(2244),
    [anon_sym___forceinline] = ACTIONS(2244),
    [anon_sym_thread_local] = ACTIONS(2244),
    [anon_sym___thread] = ACTIONS(2244),
    [anon_sym_const] = ACTIONS(2244),
    [anon_sym_constexpr] = ACTIONS(2244),
    [anon_sym_volatile] = ACTIONS(2244),
    [anon_sym_restrict] = ACTIONS(2244),
    [anon_sym___restrict__] = ACTIONS(2244),
    [anon_sym__Atomic] = ACTIONS(2244),
    [anon_sym__Noreturn] = ACTIONS(2244),
    [anon_sym_noreturn] = ACTIONS(2244),
    [anon_sym_mutable] = ACTIONS(2244),
    [anon_sym_constinit] = ACTIONS(2244),
    [anon_sym_consteval] = ACTIONS(2244),
    [anon_sym_alignas] = ACTIONS(2244),
    [anon_sym__Alignas] = ACTIONS(2244),
    [sym_primitive_type] = ACTIONS(2244),
    [anon_sym_enum] = ACTIONS(2244),
    [anon_sym_class] = ACTIONS(2244),
    [anon_sym_struct] = ACTIONS(2244),
    [anon_sym_union] = ACTIONS(2244),
    [anon_sym_if] = ACTIONS(2244),
    [anon_sym_else] = ACTIONS(2244),
    [anon_sym_switch] = ACTIONS(2244),
    [anon_sym_case] = ACTIONS(2244),
    [anon_sym_default] = ACTIONS(2244),
    [anon_sym_while] = ACTIONS(2244),
    [anon_sym_do] = ACTIONS(2244),
    [anon_sym_for] = ACTIONS(2244),
    [anon_sym_return] = ACTIONS(2244),
    [anon_sym_break] = ACTIONS(2244),
    [anon_sym_continue] = ACTIONS(2244),
    [anon_sym_goto] = ACTIONS(2244),
    [anon_sym___try] = ACTIONS(2244),
    [anon_sym___leave] = ACTIONS(2244),
    [anon_sym_not] = ACTIONS(2244),
    [anon_sym_compl] = ACTIONS(2244),
    [anon_sym_DASH_DASH] = ACTIONS(2246),
    [anon_sym_PLUS_PLUS] = ACTIONS(2246),
    [anon_sym_sizeof] = ACTIONS(2244),
    [anon_sym___alignof__] = ACTIONS(2244),
    [anon_sym___alignof] = ACTIONS(2244),
    [anon_sym__alignof] = ACTIONS(2244),
    [anon_sym_alignof] = ACTIONS(2244),
    [anon_sym__Alignof] = ACTIONS(2244),
    [anon_sym_offsetof] = ACTIONS(2244),
    [anon_sym__Generic] = ACTIONS(2244),
    [anon_sym_asm] = ACTIONS(2244),
    [anon_sym___asm__] = ACTIONS(2244),
    [sym_number_literal] = ACTIONS(2246),
    [anon_sym_L_SQUOTE] = ACTIONS(2246),
    [anon_sym_u_SQUOTE] = ACTIONS(2246),
    [anon_sym_U_SQUOTE] = ACTIONS(2246),
    [anon_sym_u8_SQUOTE] = ACTIONS(2246),
    [anon_sym_SQUOTE] = ACTIONS(2246),
    [anon_sym_L_DQUOTE] = ACTIONS(2246),
    [anon_sym_u_DQUOTE] = ACTIONS(2246),
    [anon_sym_U_DQUOTE] = ACTIONS(2246),
    [anon_sym_u8_DQUOTE] = ACTIONS(2246),
    [anon_sym_DQUOTE] = ACTIONS(2246),
    [sym_true] = ACTIONS(2244),
    [sym_false] = ACTIONS(2244),
    [anon_sym_NULL] = ACTIONS(2244),
    [anon_sym_nullptr] = ACTIONS(2244),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2244),
    [anon_sym_decltype] = ACTIONS(2244),
    [sym_virtual] = ACTIONS(2244),
    [anon_sym_explicit] = ACTIONS(2244),
    [anon_sym_typename] = ACTIONS(2244),
    [anon_sym_template] = ACTIONS(2244),
    [anon_sym_operator] = ACTIONS(2244),
    [anon_sym_try] = ACTIONS(2244),
    [anon_sym_delete] = ACTIONS(2244),
    [anon_sym_throw] = ACTIONS(2244),
    [anon_sym_namespace] = ACTIONS(2244),
    [anon_sym_using] = ACTIONS(2244),
    [anon_sym_static_assert] = ACTIONS(2244),
    [anon_sym_concept] = ACTIONS(2244),
    [anon_sym_co_return] = ACTIONS(2244),
    [anon_sym_co_yield] = ACTIONS(2244),
    [anon_sym_R_DQUOTE] = ACTIONS(2246),
    [anon_sym_LR_DQUOTE] = ACTIONS(2246),
    [anon_sym_uR_DQUOTE] = ACTIONS(2246),
    [anon_sym_UR_DQUOTE] = ACTIONS(2246),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2246),
    [anon_sym_co_await] = ACTIONS(2244),
    [anon_sym_new] = ACTIONS(2244),
    [anon_sym_requires] = ACTIONS(2244),
    [sym_this] = ACTIONS(2244),
    [anon_sym_discard] = ACTIONS(2244),
    [anon_sym_precise] = ACTIONS(2244),
    [anon_sym_shared] = ACTIONS(2244),
    [anon_sym_groupshared] = ACTIONS(2244),
    [anon_sym_uniform] = ACTIONS(2244),
    [anon_sym_row_major] = ACTIONS(2244),
    [anon_sym_column_major] = ACTIONS(2244),
    [anon_sym_globallycoherent] = ACTIONS(2244),
    [anon_sym_centroid] = ACTIONS(2244),
    [anon_sym_noperspective] = ACTIONS(2244),
    [anon_sym_nointerpolation] = ACTIONS(2244),
    [anon_sym_sample] = ACTIONS(2244),
    [anon_sym_linear] = ACTIONS(2244),
    [anon_sym_snorm] = ACTIONS(2244),
    [anon_sym_unorm] = ACTIONS(2244),
    [anon_sym_point] = ACTIONS(2244),
    [anon_sym_line] = ACTIONS(2244),
    [anon_sym_triangleadj] = ACTIONS(2244),
    [anon_sym_lineadj] = ACTIONS(2244),
    [anon_sym_triangle] = ACTIONS(2244),
    [anon_sym_cbuffer] = ACTIONS(2244),
  },
  [219] = {
    [sym_identifier] = ACTIONS(2248),
    [aux_sym_preproc_include_token1] = ACTIONS(2248),
    [aux_sym_preproc_def_token1] = ACTIONS(2248),
    [aux_sym_preproc_if_token1] = ACTIONS(2248),
    [aux_sym_preproc_if_token2] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2248),
    [aux_sym_preproc_else_token1] = ACTIONS(2248),
    [aux_sym_preproc_elif_token1] = ACTIONS(2248),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2248),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2248),
    [sym_preproc_directive] = ACTIONS(2248),
    [anon_sym_LPAREN2] = ACTIONS(2250),
    [anon_sym_BANG] = ACTIONS(2250),
    [anon_sym_TILDE] = ACTIONS(2250),
    [anon_sym_DASH] = ACTIONS(2248),
    [anon_sym_PLUS] = ACTIONS(2248),
    [anon_sym_STAR] = ACTIONS(2250),
    [anon_sym_AMP_AMP] = ACTIONS(2250),
    [anon_sym_AMP] = ACTIONS(2248),
    [anon_sym_SEMI] = ACTIONS(2250),
    [anon_sym___extension__] = ACTIONS(2248),
    [anon_sym_typedef] = ACTIONS(2248),
    [anon_sym_in] = ACTIONS(2248),
    [anon_sym_out] = ACTIONS(2248),
    [anon_sym_inout] = ACTIONS(2248),
    [anon_sym_extern] = ACTIONS(2248),
    [anon_sym___attribute__] = ACTIONS(2248),
    [anon_sym_COLON_COLON] = ACTIONS(2250),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2250),
    [anon_sym___declspec] = ACTIONS(2248),
    [anon_sym___based] = ACTIONS(2248),
    [anon_sym___cdecl] = ACTIONS(2248),
    [anon_sym___clrcall] = ACTIONS(2248),
    [anon_sym___stdcall] = ACTIONS(2248),
    [anon_sym___fastcall] = ACTIONS(2248),
    [anon_sym___thiscall] = ACTIONS(2248),
    [anon_sym___vectorcall] = ACTIONS(2248),
    [anon_sym_LBRACE] = ACTIONS(2250),
    [anon_sym_signed] = ACTIONS(2248),
    [anon_sym_unsigned] = ACTIONS(2248),
    [anon_sym_long] = ACTIONS(2248),
    [anon_sym_short] = ACTIONS(2248),
    [anon_sym_LBRACK] = ACTIONS(2248),
    [anon_sym_static] = ACTIONS(2248),
    [anon_sym_register] = ACTIONS(2248),
    [anon_sym_inline] = ACTIONS(2248),
    [anon_sym___inline] = ACTIONS(2248),
    [anon_sym___inline__] = ACTIONS(2248),
    [anon_sym___forceinline] = ACTIONS(2248),
    [anon_sym_thread_local] = ACTIONS(2248),
    [anon_sym___thread] = ACTIONS(2248),
    [anon_sym_const] = ACTIONS(2248),
    [anon_sym_constexpr] = ACTIONS(2248),
    [anon_sym_volatile] = ACTIONS(2248),
    [anon_sym_restrict] = ACTIONS(2248),
    [anon_sym___restrict__] = ACTIONS(2248),
    [anon_sym__Atomic] = ACTIONS(2248),
    [anon_sym__Noreturn] = ACTIONS(2248),
    [anon_sym_noreturn] = ACTIONS(2248),
    [anon_sym_mutable] = ACTIONS(2248),
    [anon_sym_constinit] = ACTIONS(2248),
    [anon_sym_consteval] = ACTIONS(2248),
    [anon_sym_alignas] = ACTIONS(2248),
    [anon_sym__Alignas] = ACTIONS(2248),
    [sym_primitive_type] = ACTIONS(2248),
    [anon_sym_enum] = ACTIONS(2248),
    [anon_sym_class] = ACTIONS(2248),
    [anon_sym_struct] = ACTIONS(2248),
    [anon_sym_union] = ACTIONS(2248),
    [anon_sym_if] = ACTIONS(2248),
    [anon_sym_else] = ACTIONS(2248),
    [anon_sym_switch] = ACTIONS(2248),
    [anon_sym_case] = ACTIONS(2248),
    [anon_sym_default] = ACTIONS(2248),
    [anon_sym_while] = ACTIONS(2248),
    [anon_sym_do] = ACTIONS(2248),
    [anon_sym_for] = ACTIONS(2248),
    [anon_sym_return] = ACTIONS(2248),
    [anon_sym_break] = ACTIONS(2248),
    [anon_sym_continue] = ACTIONS(2248),
    [anon_sym_goto] = ACTIONS(2248),
    [anon_sym___try] = ACTIONS(2248),
    [anon_sym___leave] = ACTIONS(2248),
    [anon_sym_not] = ACTIONS(2248),
    [anon_sym_compl] = ACTIONS(2248),
    [anon_sym_DASH_DASH] = ACTIONS(2250),
    [anon_sym_PLUS_PLUS] = ACTIONS(2250),
    [anon_sym_sizeof] = ACTIONS(2248),
    [anon_sym___alignof__] = ACTIONS(2248),
    [anon_sym___alignof] = ACTIONS(2248),
    [anon_sym__alignof] = ACTIONS(2248),
    [anon_sym_alignof] = ACTIONS(2248),
    [anon_sym__Alignof] = ACTIONS(2248),
    [anon_sym_offsetof] = ACTIONS(2248),
    [anon_sym__Generic] = ACTIONS(2248),
    [anon_sym_asm] = ACTIONS(2248),
    [anon_sym___asm__] = ACTIONS(2248),
    [sym_number_literal] = ACTIONS(2250),
    [anon_sym_L_SQUOTE] = ACTIONS(2250),
    [anon_sym_u_SQUOTE] = ACTIONS(2250),
    [anon_sym_U_SQUOTE] = ACTIONS(2250),
    [anon_sym_u8_SQUOTE] = ACTIONS(2250),
    [anon_sym_SQUOTE] = ACTIONS(2250),
    [anon_sym_L_DQUOTE] = ACTIONS(2250),
    [anon_sym_u_DQUOTE] = ACTIONS(2250),
    [anon_sym_U_DQUOTE] = ACTIONS(2250),
    [anon_sym_u8_DQUOTE] = ACTIONS(2250),
    [anon_sym_DQUOTE] = ACTIONS(2250),
    [sym_true] = ACTIONS(2248),
    [sym_false] = ACTIONS(2248),
    [anon_sym_NULL] = ACTIONS(2248),
    [anon_sym_nullptr] = ACTIONS(2248),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2248),
    [anon_sym_decltype] = ACTIONS(2248),
    [sym_virtual] = ACTIONS(2248),
    [anon_sym_explicit] = ACTIONS(2248),
    [anon_sym_typename] = ACTIONS(2248),
    [anon_sym_template] = ACTIONS(2248),
    [anon_sym_operator] = ACTIONS(2248),
    [anon_sym_try] = ACTIONS(2248),
    [anon_sym_delete] = ACTIONS(2248),
    [anon_sym_throw] = ACTIONS(2248),
    [anon_sym_namespace] = ACTIONS(2248),
    [anon_sym_using] = ACTIONS(2248),
    [anon_sym_static_assert] = ACTIONS(2248),
    [anon_sym_concept] = ACTIONS(2248),
    [anon_sym_co_return] = ACTIONS(2248),
    [anon_sym_co_yield] = ACTIONS(2248),
    [anon_sym_R_DQUOTE] = ACTIONS(2250),
    [anon_sym_LR_DQUOTE] = ACTIONS(2250),
    [anon_sym_uR_DQUOTE] = ACTIONS(2250),
    [anon_sym_UR_DQUOTE] = ACTIONS(2250),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2250),
    [anon_sym_co_await] = ACTIONS(2248),
    [anon_sym_new] = ACTIONS(2248),
    [anon_sym_requires] = ACTIONS(2248),
    [sym_this] = ACTIONS(2248),
    [anon_sym_discard] = ACTIONS(2248),
    [anon_sym_precise] = ACTIONS(2248),
    [anon_sym_shared] = ACTIONS(2248),
    [anon_sym_groupshared] = ACTIONS(2248),
    [anon_sym_uniform] = ACTIONS(2248),
    [anon_sym_row_major] = ACTIONS(2248),
    [anon_sym_column_major] = ACTIONS(2248),
    [anon_sym_globallycoherent] = ACTIONS(2248),
    [anon_sym_centroid] = ACTIONS(2248),
    [anon_sym_noperspective] = ACTIONS(2248),
    [anon_sym_nointerpolation] = ACTIONS(2248),
    [anon_sym_sample] = ACTIONS(2248),
    [anon_sym_linear] = ACTIONS(2248),
    [anon_sym_snorm] = ACTIONS(2248),
    [anon_sym_unorm] = ACTIONS(2248),
    [anon_sym_point] = ACTIONS(2248),
    [anon_sym_line] = ACTIONS(2248),
    [anon_sym_triangleadj] = ACTIONS(2248),
    [anon_sym_lineadj] = ACTIONS(2248),
    [anon_sym_triangle] = ACTIONS(2248),
    [anon_sym_cbuffer] = ACTIONS(2248),
  },
  [220] = {
    [sym_identifier] = ACTIONS(2252),
    [aux_sym_preproc_include_token1] = ACTIONS(2252),
    [aux_sym_preproc_def_token1] = ACTIONS(2252),
    [aux_sym_preproc_if_token1] = ACTIONS(2252),
    [aux_sym_preproc_if_token2] = ACTIONS(2252),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2252),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2252),
    [aux_sym_preproc_else_token1] = ACTIONS(2252),
    [aux_sym_preproc_elif_token1] = ACTIONS(2252),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2252),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2252),
    [sym_preproc_directive] = ACTIONS(2252),
    [anon_sym_LPAREN2] = ACTIONS(2254),
    [anon_sym_BANG] = ACTIONS(2254),
    [anon_sym_TILDE] = ACTIONS(2254),
    [anon_sym_DASH] = ACTIONS(2252),
    [anon_sym_PLUS] = ACTIONS(2252),
    [anon_sym_STAR] = ACTIONS(2254),
    [anon_sym_AMP_AMP] = ACTIONS(2254),
    [anon_sym_AMP] = ACTIONS(2252),
    [anon_sym_SEMI] = ACTIONS(2254),
    [anon_sym___extension__] = ACTIONS(2252),
    [anon_sym_typedef] = ACTIONS(2252),
    [anon_sym_in] = ACTIONS(2252),
    [anon_sym_out] = ACTIONS(2252),
    [anon_sym_inout] = ACTIONS(2252),
    [anon_sym_extern] = ACTIONS(2252),
    [anon_sym___attribute__] = ACTIONS(2252),
    [anon_sym_COLON_COLON] = ACTIONS(2254),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2254),
    [anon_sym___declspec] = ACTIONS(2252),
    [anon_sym___based] = ACTIONS(2252),
    [anon_sym___cdecl] = ACTIONS(2252),
    [anon_sym___clrcall] = ACTIONS(2252),
    [anon_sym___stdcall] = ACTIONS(2252),
    [anon_sym___fastcall] = ACTIONS(2252),
    [anon_sym___thiscall] = ACTIONS(2252),
    [anon_sym___vectorcall] = ACTIONS(2252),
    [anon_sym_LBRACE] = ACTIONS(2254),
    [anon_sym_signed] = ACTIONS(2252),
    [anon_sym_unsigned] = ACTIONS(2252),
    [anon_sym_long] = ACTIONS(2252),
    [anon_sym_short] = ACTIONS(2252),
    [anon_sym_LBRACK] = ACTIONS(2252),
    [anon_sym_static] = ACTIONS(2252),
    [anon_sym_register] = ACTIONS(2252),
    [anon_sym_inline] = ACTIONS(2252),
    [anon_sym___inline] = ACTIONS(2252),
    [anon_sym___inline__] = ACTIONS(2252),
    [anon_sym___forceinline] = ACTIONS(2252),
    [anon_sym_thread_local] = ACTIONS(2252),
    [anon_sym___thread] = ACTIONS(2252),
    [anon_sym_const] = ACTIONS(2252),
    [anon_sym_constexpr] = ACTIONS(2252),
    [anon_sym_volatile] = ACTIONS(2252),
    [anon_sym_restrict] = ACTIONS(2252),
    [anon_sym___restrict__] = ACTIONS(2252),
    [anon_sym__Atomic] = ACTIONS(2252),
    [anon_sym__Noreturn] = ACTIONS(2252),
    [anon_sym_noreturn] = ACTIONS(2252),
    [anon_sym_mutable] = ACTIONS(2252),
    [anon_sym_constinit] = ACTIONS(2252),
    [anon_sym_consteval] = ACTIONS(2252),
    [anon_sym_alignas] = ACTIONS(2252),
    [anon_sym__Alignas] = ACTIONS(2252),
    [sym_primitive_type] = ACTIONS(2252),
    [anon_sym_enum] = ACTIONS(2252),
    [anon_sym_class] = ACTIONS(2252),
    [anon_sym_struct] = ACTIONS(2252),
    [anon_sym_union] = ACTIONS(2252),
    [anon_sym_if] = ACTIONS(2252),
    [anon_sym_else] = ACTIONS(2252),
    [anon_sym_switch] = ACTIONS(2252),
    [anon_sym_case] = ACTIONS(2252),
    [anon_sym_default] = ACTIONS(2252),
    [anon_sym_while] = ACTIONS(2252),
    [anon_sym_do] = ACTIONS(2252),
    [anon_sym_for] = ACTIONS(2252),
    [anon_sym_return] = ACTIONS(2252),
    [anon_sym_break] = ACTIONS(2252),
    [anon_sym_continue] = ACTIONS(2252),
    [anon_sym_goto] = ACTIONS(2252),
    [anon_sym___try] = ACTIONS(2252),
    [anon_sym___leave] = ACTIONS(2252),
    [anon_sym_not] = ACTIONS(2252),
    [anon_sym_compl] = ACTIONS(2252),
    [anon_sym_DASH_DASH] = ACTIONS(2254),
    [anon_sym_PLUS_PLUS] = ACTIONS(2254),
    [anon_sym_sizeof] = ACTIONS(2252),
    [anon_sym___alignof__] = ACTIONS(2252),
    [anon_sym___alignof] = ACTIONS(2252),
    [anon_sym__alignof] = ACTIONS(2252),
    [anon_sym_alignof] = ACTIONS(2252),
    [anon_sym__Alignof] = ACTIONS(2252),
    [anon_sym_offsetof] = ACTIONS(2252),
    [anon_sym__Generic] = ACTIONS(2252),
    [anon_sym_asm] = ACTIONS(2252),
    [anon_sym___asm__] = ACTIONS(2252),
    [sym_number_literal] = ACTIONS(2254),
    [anon_sym_L_SQUOTE] = ACTIONS(2254),
    [anon_sym_u_SQUOTE] = ACTIONS(2254),
    [anon_sym_U_SQUOTE] = ACTIONS(2254),
    [anon_sym_u8_SQUOTE] = ACTIONS(2254),
    [anon_sym_SQUOTE] = ACTIONS(2254),
    [anon_sym_L_DQUOTE] = ACTIONS(2254),
    [anon_sym_u_DQUOTE] = ACTIONS(2254),
    [anon_sym_U_DQUOTE] = ACTIONS(2254),
    [anon_sym_u8_DQUOTE] = ACTIONS(2254),
    [anon_sym_DQUOTE] = ACTIONS(2254),
    [sym_true] = ACTIONS(2252),
    [sym_false] = ACTIONS(2252),
    [anon_sym_NULL] = ACTIONS(2252),
    [anon_sym_nullptr] = ACTIONS(2252),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2252),
    [anon_sym_decltype] = ACTIONS(2252),
    [sym_virtual] = ACTIONS(2252),
    [anon_sym_explicit] = ACTIONS(2252),
    [anon_sym_typename] = ACTIONS(2252),
    [anon_sym_template] = ACTIONS(2252),
    [anon_sym_operator] = ACTIONS(2252),
    [anon_sym_try] = ACTIONS(2252),
    [anon_sym_delete] = ACTIONS(2252),
    [anon_sym_throw] = ACTIONS(2252),
    [anon_sym_namespace] = ACTIONS(2252),
    [anon_sym_using] = ACTIONS(2252),
    [anon_sym_static_assert] = ACTIONS(2252),
    [anon_sym_concept] = ACTIONS(2252),
    [anon_sym_co_return] = ACTIONS(2252),
    [anon_sym_co_yield] = ACTIONS(2252),
    [anon_sym_R_DQUOTE] = ACTIONS(2254),
    [anon_sym_LR_DQUOTE] = ACTIONS(2254),
    [anon_sym_uR_DQUOTE] = ACTIONS(2254),
    [anon_sym_UR_DQUOTE] = ACTIONS(2254),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2254),
    [anon_sym_co_await] = ACTIONS(2252),
    [anon_sym_new] = ACTIONS(2252),
    [anon_sym_requires] = ACTIONS(2252),
    [sym_this] = ACTIONS(2252),
    [anon_sym_discard] = ACTIONS(2252),
    [anon_sym_precise] = ACTIONS(2252),
    [anon_sym_shared] = ACTIONS(2252),
    [anon_sym_groupshared] = ACTIONS(2252),
    [anon_sym_uniform] = ACTIONS(2252),
    [anon_sym_row_major] = ACTIONS(2252),
    [anon_sym_column_major] = ACTIONS(2252),
    [anon_sym_globallycoherent] = ACTIONS(2252),
    [anon_sym_centroid] = ACTIONS(2252),
    [anon_sym_noperspective] = ACTIONS(2252),
    [anon_sym_nointerpolation] = ACTIONS(2252),
    [anon_sym_sample] = ACTIONS(2252),
    [anon_sym_linear] = ACTIONS(2252),
    [anon_sym_snorm] = ACTIONS(2252),
    [anon_sym_unorm] = ACTIONS(2252),
    [anon_sym_point] = ACTIONS(2252),
    [anon_sym_line] = ACTIONS(2252),
    [anon_sym_triangleadj] = ACTIONS(2252),
    [anon_sym_lineadj] = ACTIONS(2252),
    [anon_sym_triangle] = ACTIONS(2252),
    [anon_sym_cbuffer] = ACTIONS(2252),
  },
  [221] = {
    [sym_identifier] = ACTIONS(2256),
    [aux_sym_preproc_include_token1] = ACTIONS(2256),
    [aux_sym_preproc_def_token1] = ACTIONS(2256),
    [aux_sym_preproc_if_token1] = ACTIONS(2256),
    [aux_sym_preproc_if_token2] = ACTIONS(2256),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2256),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2256),
    [aux_sym_preproc_else_token1] = ACTIONS(2256),
    [aux_sym_preproc_elif_token1] = ACTIONS(2256),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2256),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2256),
    [sym_preproc_directive] = ACTIONS(2256),
    [anon_sym_LPAREN2] = ACTIONS(2258),
    [anon_sym_BANG] = ACTIONS(2258),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_DASH] = ACTIONS(2256),
    [anon_sym_PLUS] = ACTIONS(2256),
    [anon_sym_STAR] = ACTIONS(2258),
    [anon_sym_AMP_AMP] = ACTIONS(2258),
    [anon_sym_AMP] = ACTIONS(2256),
    [anon_sym_SEMI] = ACTIONS(2258),
    [anon_sym___extension__] = ACTIONS(2256),
    [anon_sym_typedef] = ACTIONS(2256),
    [anon_sym_in] = ACTIONS(2256),
    [anon_sym_out] = ACTIONS(2256),
    [anon_sym_inout] = ACTIONS(2256),
    [anon_sym_extern] = ACTIONS(2256),
    [anon_sym___attribute__] = ACTIONS(2256),
    [anon_sym_COLON_COLON] = ACTIONS(2258),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2258),
    [anon_sym___declspec] = ACTIONS(2256),
    [anon_sym___based] = ACTIONS(2256),
    [anon_sym___cdecl] = ACTIONS(2256),
    [anon_sym___clrcall] = ACTIONS(2256),
    [anon_sym___stdcall] = ACTIONS(2256),
    [anon_sym___fastcall] = ACTIONS(2256),
    [anon_sym___thiscall] = ACTIONS(2256),
    [anon_sym___vectorcall] = ACTIONS(2256),
    [anon_sym_LBRACE] = ACTIONS(2258),
    [anon_sym_signed] = ACTIONS(2256),
    [anon_sym_unsigned] = ACTIONS(2256),
    [anon_sym_long] = ACTIONS(2256),
    [anon_sym_short] = ACTIONS(2256),
    [anon_sym_LBRACK] = ACTIONS(2256),
    [anon_sym_static] = ACTIONS(2256),
    [anon_sym_register] = ACTIONS(2256),
    [anon_sym_inline] = ACTIONS(2256),
    [anon_sym___inline] = ACTIONS(2256),
    [anon_sym___inline__] = ACTIONS(2256),
    [anon_sym___forceinline] = ACTIONS(2256),
    [anon_sym_thread_local] = ACTIONS(2256),
    [anon_sym___thread] = ACTIONS(2256),
    [anon_sym_const] = ACTIONS(2256),
    [anon_sym_constexpr] = ACTIONS(2256),
    [anon_sym_volatile] = ACTIONS(2256),
    [anon_sym_restrict] = ACTIONS(2256),
    [anon_sym___restrict__] = ACTIONS(2256),
    [anon_sym__Atomic] = ACTIONS(2256),
    [anon_sym__Noreturn] = ACTIONS(2256),
    [anon_sym_noreturn] = ACTIONS(2256),
    [anon_sym_mutable] = ACTIONS(2256),
    [anon_sym_constinit] = ACTIONS(2256),
    [anon_sym_consteval] = ACTIONS(2256),
    [anon_sym_alignas] = ACTIONS(2256),
    [anon_sym__Alignas] = ACTIONS(2256),
    [sym_primitive_type] = ACTIONS(2256),
    [anon_sym_enum] = ACTIONS(2256),
    [anon_sym_class] = ACTIONS(2256),
    [anon_sym_struct] = ACTIONS(2256),
    [anon_sym_union] = ACTIONS(2256),
    [anon_sym_if] = ACTIONS(2256),
    [anon_sym_else] = ACTIONS(2256),
    [anon_sym_switch] = ACTIONS(2256),
    [anon_sym_case] = ACTIONS(2256),
    [anon_sym_default] = ACTIONS(2256),
    [anon_sym_while] = ACTIONS(2256),
    [anon_sym_do] = ACTIONS(2256),
    [anon_sym_for] = ACTIONS(2256),
    [anon_sym_return] = ACTIONS(2256),
    [anon_sym_break] = ACTIONS(2256),
    [anon_sym_continue] = ACTIONS(2256),
    [anon_sym_goto] = ACTIONS(2256),
    [anon_sym___try] = ACTIONS(2256),
    [anon_sym___leave] = ACTIONS(2256),
    [anon_sym_not] = ACTIONS(2256),
    [anon_sym_compl] = ACTIONS(2256),
    [anon_sym_DASH_DASH] = ACTIONS(2258),
    [anon_sym_PLUS_PLUS] = ACTIONS(2258),
    [anon_sym_sizeof] = ACTIONS(2256),
    [anon_sym___alignof__] = ACTIONS(2256),
    [anon_sym___alignof] = ACTIONS(2256),
    [anon_sym__alignof] = ACTIONS(2256),
    [anon_sym_alignof] = ACTIONS(2256),
    [anon_sym__Alignof] = ACTIONS(2256),
    [anon_sym_offsetof] = ACTIONS(2256),
    [anon_sym__Generic] = ACTIONS(2256),
    [anon_sym_asm] = ACTIONS(2256),
    [anon_sym___asm__] = ACTIONS(2256),
    [sym_number_literal] = ACTIONS(2258),
    [anon_sym_L_SQUOTE] = ACTIONS(2258),
    [anon_sym_u_SQUOTE] = ACTIONS(2258),
    [anon_sym_U_SQUOTE] = ACTIONS(2258),
    [anon_sym_u8_SQUOTE] = ACTIONS(2258),
    [anon_sym_SQUOTE] = ACTIONS(2258),
    [anon_sym_L_DQUOTE] = ACTIONS(2258),
    [anon_sym_u_DQUOTE] = ACTIONS(2258),
    [anon_sym_U_DQUOTE] = ACTIONS(2258),
    [anon_sym_u8_DQUOTE] = ACTIONS(2258),
    [anon_sym_DQUOTE] = ACTIONS(2258),
    [sym_true] = ACTIONS(2256),
    [sym_false] = ACTIONS(2256),
    [anon_sym_NULL] = ACTIONS(2256),
    [anon_sym_nullptr] = ACTIONS(2256),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2256),
    [anon_sym_decltype] = ACTIONS(2256),
    [sym_virtual] = ACTIONS(2256),
    [anon_sym_explicit] = ACTIONS(2256),
    [anon_sym_typename] = ACTIONS(2256),
    [anon_sym_template] = ACTIONS(2256),
    [anon_sym_operator] = ACTIONS(2256),
    [anon_sym_try] = ACTIONS(2256),
    [anon_sym_delete] = ACTIONS(2256),
    [anon_sym_throw] = ACTIONS(2256),
    [anon_sym_namespace] = ACTIONS(2256),
    [anon_sym_using] = ACTIONS(2256),
    [anon_sym_static_assert] = ACTIONS(2256),
    [anon_sym_concept] = ACTIONS(2256),
    [anon_sym_co_return] = ACTIONS(2256),
    [anon_sym_co_yield] = ACTIONS(2256),
    [anon_sym_R_DQUOTE] = ACTIONS(2258),
    [anon_sym_LR_DQUOTE] = ACTIONS(2258),
    [anon_sym_uR_DQUOTE] = ACTIONS(2258),
    [anon_sym_UR_DQUOTE] = ACTIONS(2258),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2258),
    [anon_sym_co_await] = ACTIONS(2256),
    [anon_sym_new] = ACTIONS(2256),
    [anon_sym_requires] = ACTIONS(2256),
    [sym_this] = ACTIONS(2256),
    [anon_sym_discard] = ACTIONS(2256),
    [anon_sym_precise] = ACTIONS(2256),
    [anon_sym_shared] = ACTIONS(2256),
    [anon_sym_groupshared] = ACTIONS(2256),
    [anon_sym_uniform] = ACTIONS(2256),
    [anon_sym_row_major] = ACTIONS(2256),
    [anon_sym_column_major] = ACTIONS(2256),
    [anon_sym_globallycoherent] = ACTIONS(2256),
    [anon_sym_centroid] = ACTIONS(2256),
    [anon_sym_noperspective] = ACTIONS(2256),
    [anon_sym_nointerpolation] = ACTIONS(2256),
    [anon_sym_sample] = ACTIONS(2256),
    [anon_sym_linear] = ACTIONS(2256),
    [anon_sym_snorm] = ACTIONS(2256),
    [anon_sym_unorm] = ACTIONS(2256),
    [anon_sym_point] = ACTIONS(2256),
    [anon_sym_line] = ACTIONS(2256),
    [anon_sym_triangleadj] = ACTIONS(2256),
    [anon_sym_lineadj] = ACTIONS(2256),
    [anon_sym_triangle] = ACTIONS(2256),
    [anon_sym_cbuffer] = ACTIONS(2256),
  },
  [222] = {
    [sym_identifier] = ACTIONS(2248),
    [aux_sym_preproc_include_token1] = ACTIONS(2248),
    [aux_sym_preproc_def_token1] = ACTIONS(2248),
    [aux_sym_preproc_if_token1] = ACTIONS(2248),
    [aux_sym_preproc_if_token2] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2248),
    [aux_sym_preproc_else_token1] = ACTIONS(2248),
    [aux_sym_preproc_elif_token1] = ACTIONS(2248),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2248),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2248),
    [sym_preproc_directive] = ACTIONS(2248),
    [anon_sym_LPAREN2] = ACTIONS(2250),
    [anon_sym_BANG] = ACTIONS(2250),
    [anon_sym_TILDE] = ACTIONS(2250),
    [anon_sym_DASH] = ACTIONS(2248),
    [anon_sym_PLUS] = ACTIONS(2248),
    [anon_sym_STAR] = ACTIONS(2250),
    [anon_sym_AMP_AMP] = ACTIONS(2250),
    [anon_sym_AMP] = ACTIONS(2248),
    [anon_sym_SEMI] = ACTIONS(2250),
    [anon_sym___extension__] = ACTIONS(2248),
    [anon_sym_typedef] = ACTIONS(2248),
    [anon_sym_in] = ACTIONS(2248),
    [anon_sym_out] = ACTIONS(2248),
    [anon_sym_inout] = ACTIONS(2248),
    [anon_sym_extern] = ACTIONS(2248),
    [anon_sym___attribute__] = ACTIONS(2248),
    [anon_sym_COLON_COLON] = ACTIONS(2250),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2250),
    [anon_sym___declspec] = ACTIONS(2248),
    [anon_sym___based] = ACTIONS(2248),
    [anon_sym___cdecl] = ACTIONS(2248),
    [anon_sym___clrcall] = ACTIONS(2248),
    [anon_sym___stdcall] = ACTIONS(2248),
    [anon_sym___fastcall] = ACTIONS(2248),
    [anon_sym___thiscall] = ACTIONS(2248),
    [anon_sym___vectorcall] = ACTIONS(2248),
    [anon_sym_LBRACE] = ACTIONS(2250),
    [anon_sym_signed] = ACTIONS(2248),
    [anon_sym_unsigned] = ACTIONS(2248),
    [anon_sym_long] = ACTIONS(2248),
    [anon_sym_short] = ACTIONS(2248),
    [anon_sym_LBRACK] = ACTIONS(2248),
    [anon_sym_static] = ACTIONS(2248),
    [anon_sym_register] = ACTIONS(2248),
    [anon_sym_inline] = ACTIONS(2248),
    [anon_sym___inline] = ACTIONS(2248),
    [anon_sym___inline__] = ACTIONS(2248),
    [anon_sym___forceinline] = ACTIONS(2248),
    [anon_sym_thread_local] = ACTIONS(2248),
    [anon_sym___thread] = ACTIONS(2248),
    [anon_sym_const] = ACTIONS(2248),
    [anon_sym_constexpr] = ACTIONS(2248),
    [anon_sym_volatile] = ACTIONS(2248),
    [anon_sym_restrict] = ACTIONS(2248),
    [anon_sym___restrict__] = ACTIONS(2248),
    [anon_sym__Atomic] = ACTIONS(2248),
    [anon_sym__Noreturn] = ACTIONS(2248),
    [anon_sym_noreturn] = ACTIONS(2248),
    [anon_sym_mutable] = ACTIONS(2248),
    [anon_sym_constinit] = ACTIONS(2248),
    [anon_sym_consteval] = ACTIONS(2248),
    [anon_sym_alignas] = ACTIONS(2248),
    [anon_sym__Alignas] = ACTIONS(2248),
    [sym_primitive_type] = ACTIONS(2248),
    [anon_sym_enum] = ACTIONS(2248),
    [anon_sym_class] = ACTIONS(2248),
    [anon_sym_struct] = ACTIONS(2248),
    [anon_sym_union] = ACTIONS(2248),
    [anon_sym_if] = ACTIONS(2248),
    [anon_sym_else] = ACTIONS(2248),
    [anon_sym_switch] = ACTIONS(2248),
    [anon_sym_case] = ACTIONS(2248),
    [anon_sym_default] = ACTIONS(2248),
    [anon_sym_while] = ACTIONS(2248),
    [anon_sym_do] = ACTIONS(2248),
    [anon_sym_for] = ACTIONS(2248),
    [anon_sym_return] = ACTIONS(2248),
    [anon_sym_break] = ACTIONS(2248),
    [anon_sym_continue] = ACTIONS(2248),
    [anon_sym_goto] = ACTIONS(2248),
    [anon_sym___try] = ACTIONS(2248),
    [anon_sym___leave] = ACTIONS(2248),
    [anon_sym_not] = ACTIONS(2248),
    [anon_sym_compl] = ACTIONS(2248),
    [anon_sym_DASH_DASH] = ACTIONS(2250),
    [anon_sym_PLUS_PLUS] = ACTIONS(2250),
    [anon_sym_sizeof] = ACTIONS(2248),
    [anon_sym___alignof__] = ACTIONS(2248),
    [anon_sym___alignof] = ACTIONS(2248),
    [anon_sym__alignof] = ACTIONS(2248),
    [anon_sym_alignof] = ACTIONS(2248),
    [anon_sym__Alignof] = ACTIONS(2248),
    [anon_sym_offsetof] = ACTIONS(2248),
    [anon_sym__Generic] = ACTIONS(2248),
    [anon_sym_asm] = ACTIONS(2248),
    [anon_sym___asm__] = ACTIONS(2248),
    [sym_number_literal] = ACTIONS(2250),
    [anon_sym_L_SQUOTE] = ACTIONS(2250),
    [anon_sym_u_SQUOTE] = ACTIONS(2250),
    [anon_sym_U_SQUOTE] = ACTIONS(2250),
    [anon_sym_u8_SQUOTE] = ACTIONS(2250),
    [anon_sym_SQUOTE] = ACTIONS(2250),
    [anon_sym_L_DQUOTE] = ACTIONS(2250),
    [anon_sym_u_DQUOTE] = ACTIONS(2250),
    [anon_sym_U_DQUOTE] = ACTIONS(2250),
    [anon_sym_u8_DQUOTE] = ACTIONS(2250),
    [anon_sym_DQUOTE] = ACTIONS(2250),
    [sym_true] = ACTIONS(2248),
    [sym_false] = ACTIONS(2248),
    [anon_sym_NULL] = ACTIONS(2248),
    [anon_sym_nullptr] = ACTIONS(2248),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2248),
    [anon_sym_decltype] = ACTIONS(2248),
    [sym_virtual] = ACTIONS(2248),
    [anon_sym_explicit] = ACTIONS(2248),
    [anon_sym_typename] = ACTIONS(2248),
    [anon_sym_template] = ACTIONS(2248),
    [anon_sym_operator] = ACTIONS(2248),
    [anon_sym_try] = ACTIONS(2248),
    [anon_sym_delete] = ACTIONS(2248),
    [anon_sym_throw] = ACTIONS(2248),
    [anon_sym_namespace] = ACTIONS(2248),
    [anon_sym_using] = ACTIONS(2248),
    [anon_sym_static_assert] = ACTIONS(2248),
    [anon_sym_concept] = ACTIONS(2248),
    [anon_sym_co_return] = ACTIONS(2248),
    [anon_sym_co_yield] = ACTIONS(2248),
    [anon_sym_R_DQUOTE] = ACTIONS(2250),
    [anon_sym_LR_DQUOTE] = ACTIONS(2250),
    [anon_sym_uR_DQUOTE] = ACTIONS(2250),
    [anon_sym_UR_DQUOTE] = ACTIONS(2250),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2250),
    [anon_sym_co_await] = ACTIONS(2248),
    [anon_sym_new] = ACTIONS(2248),
    [anon_sym_requires] = ACTIONS(2248),
    [sym_this] = ACTIONS(2248),
    [anon_sym_discard] = ACTIONS(2248),
    [anon_sym_precise] = ACTIONS(2248),
    [anon_sym_shared] = ACTIONS(2248),
    [anon_sym_groupshared] = ACTIONS(2248),
    [anon_sym_uniform] = ACTIONS(2248),
    [anon_sym_row_major] = ACTIONS(2248),
    [anon_sym_column_major] = ACTIONS(2248),
    [anon_sym_globallycoherent] = ACTIONS(2248),
    [anon_sym_centroid] = ACTIONS(2248),
    [anon_sym_noperspective] = ACTIONS(2248),
    [anon_sym_nointerpolation] = ACTIONS(2248),
    [anon_sym_sample] = ACTIONS(2248),
    [anon_sym_linear] = ACTIONS(2248),
    [anon_sym_snorm] = ACTIONS(2248),
    [anon_sym_unorm] = ACTIONS(2248),
    [anon_sym_point] = ACTIONS(2248),
    [anon_sym_line] = ACTIONS(2248),
    [anon_sym_triangleadj] = ACTIONS(2248),
    [anon_sym_lineadj] = ACTIONS(2248),
    [anon_sym_triangle] = ACTIONS(2248),
    [anon_sym_cbuffer] = ACTIONS(2248),
  },
  [223] = {
    [sym_identifier] = ACTIONS(2260),
    [aux_sym_preproc_include_token1] = ACTIONS(2260),
    [aux_sym_preproc_def_token1] = ACTIONS(2260),
    [aux_sym_preproc_if_token1] = ACTIONS(2260),
    [aux_sym_preproc_if_token2] = ACTIONS(2260),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2260),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2260),
    [aux_sym_preproc_else_token1] = ACTIONS(2260),
    [aux_sym_preproc_elif_token1] = ACTIONS(2260),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2260),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2260),
    [sym_preproc_directive] = ACTIONS(2260),
    [anon_sym_LPAREN2] = ACTIONS(2262),
    [anon_sym_BANG] = ACTIONS(2262),
    [anon_sym_TILDE] = ACTIONS(2262),
    [anon_sym_DASH] = ACTIONS(2260),
    [anon_sym_PLUS] = ACTIONS(2260),
    [anon_sym_STAR] = ACTIONS(2262),
    [anon_sym_AMP_AMP] = ACTIONS(2262),
    [anon_sym_AMP] = ACTIONS(2260),
    [anon_sym_SEMI] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(2260),
    [anon_sym_typedef] = ACTIONS(2260),
    [anon_sym_in] = ACTIONS(2260),
    [anon_sym_out] = ACTIONS(2260),
    [anon_sym_inout] = ACTIONS(2260),
    [anon_sym_extern] = ACTIONS(2260),
    [anon_sym___attribute__] = ACTIONS(2260),
    [anon_sym_COLON_COLON] = ACTIONS(2262),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2262),
    [anon_sym___declspec] = ACTIONS(2260),
    [anon_sym___based] = ACTIONS(2260),
    [anon_sym___cdecl] = ACTIONS(2260),
    [anon_sym___clrcall] = ACTIONS(2260),
    [anon_sym___stdcall] = ACTIONS(2260),
    [anon_sym___fastcall] = ACTIONS(2260),
    [anon_sym___thiscall] = ACTIONS(2260),
    [anon_sym___vectorcall] = ACTIONS(2260),
    [anon_sym_LBRACE] = ACTIONS(2262),
    [anon_sym_signed] = ACTIONS(2260),
    [anon_sym_unsigned] = ACTIONS(2260),
    [anon_sym_long] = ACTIONS(2260),
    [anon_sym_short] = ACTIONS(2260),
    [anon_sym_LBRACK] = ACTIONS(2260),
    [anon_sym_static] = ACTIONS(2260),
    [anon_sym_register] = ACTIONS(2260),
    [anon_sym_inline] = ACTIONS(2260),
    [anon_sym___inline] = ACTIONS(2260),
    [anon_sym___inline__] = ACTIONS(2260),
    [anon_sym___forceinline] = ACTIONS(2260),
    [anon_sym_thread_local] = ACTIONS(2260),
    [anon_sym___thread] = ACTIONS(2260),
    [anon_sym_const] = ACTIONS(2260),
    [anon_sym_constexpr] = ACTIONS(2260),
    [anon_sym_volatile] = ACTIONS(2260),
    [anon_sym_restrict] = ACTIONS(2260),
    [anon_sym___restrict__] = ACTIONS(2260),
    [anon_sym__Atomic] = ACTIONS(2260),
    [anon_sym__Noreturn] = ACTIONS(2260),
    [anon_sym_noreturn] = ACTIONS(2260),
    [anon_sym_mutable] = ACTIONS(2260),
    [anon_sym_constinit] = ACTIONS(2260),
    [anon_sym_consteval] = ACTIONS(2260),
    [anon_sym_alignas] = ACTIONS(2260),
    [anon_sym__Alignas] = ACTIONS(2260),
    [sym_primitive_type] = ACTIONS(2260),
    [anon_sym_enum] = ACTIONS(2260),
    [anon_sym_class] = ACTIONS(2260),
    [anon_sym_struct] = ACTIONS(2260),
    [anon_sym_union] = ACTIONS(2260),
    [anon_sym_if] = ACTIONS(2260),
    [anon_sym_else] = ACTIONS(2260),
    [anon_sym_switch] = ACTIONS(2260),
    [anon_sym_case] = ACTIONS(2260),
    [anon_sym_default] = ACTIONS(2260),
    [anon_sym_while] = ACTIONS(2260),
    [anon_sym_do] = ACTIONS(2260),
    [anon_sym_for] = ACTIONS(2260),
    [anon_sym_return] = ACTIONS(2260),
    [anon_sym_break] = ACTIONS(2260),
    [anon_sym_continue] = ACTIONS(2260),
    [anon_sym_goto] = ACTIONS(2260),
    [anon_sym___try] = ACTIONS(2260),
    [anon_sym___leave] = ACTIONS(2260),
    [anon_sym_not] = ACTIONS(2260),
    [anon_sym_compl] = ACTIONS(2260),
    [anon_sym_DASH_DASH] = ACTIONS(2262),
    [anon_sym_PLUS_PLUS] = ACTIONS(2262),
    [anon_sym_sizeof] = ACTIONS(2260),
    [anon_sym___alignof__] = ACTIONS(2260),
    [anon_sym___alignof] = ACTIONS(2260),
    [anon_sym__alignof] = ACTIONS(2260),
    [anon_sym_alignof] = ACTIONS(2260),
    [anon_sym__Alignof] = ACTIONS(2260),
    [anon_sym_offsetof] = ACTIONS(2260),
    [anon_sym__Generic] = ACTIONS(2260),
    [anon_sym_asm] = ACTIONS(2260),
    [anon_sym___asm__] = ACTIONS(2260),
    [sym_number_literal] = ACTIONS(2262),
    [anon_sym_L_SQUOTE] = ACTIONS(2262),
    [anon_sym_u_SQUOTE] = ACTIONS(2262),
    [anon_sym_U_SQUOTE] = ACTIONS(2262),
    [anon_sym_u8_SQUOTE] = ACTIONS(2262),
    [anon_sym_SQUOTE] = ACTIONS(2262),
    [anon_sym_L_DQUOTE] = ACTIONS(2262),
    [anon_sym_u_DQUOTE] = ACTIONS(2262),
    [anon_sym_U_DQUOTE] = ACTIONS(2262),
    [anon_sym_u8_DQUOTE] = ACTIONS(2262),
    [anon_sym_DQUOTE] = ACTIONS(2262),
    [sym_true] = ACTIONS(2260),
    [sym_false] = ACTIONS(2260),
    [anon_sym_NULL] = ACTIONS(2260),
    [anon_sym_nullptr] = ACTIONS(2260),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2260),
    [anon_sym_decltype] = ACTIONS(2260),
    [sym_virtual] = ACTIONS(2260),
    [anon_sym_explicit] = ACTIONS(2260),
    [anon_sym_typename] = ACTIONS(2260),
    [anon_sym_template] = ACTIONS(2260),
    [anon_sym_operator] = ACTIONS(2260),
    [anon_sym_try] = ACTIONS(2260),
    [anon_sym_delete] = ACTIONS(2260),
    [anon_sym_throw] = ACTIONS(2260),
    [anon_sym_namespace] = ACTIONS(2260),
    [anon_sym_using] = ACTIONS(2260),
    [anon_sym_static_assert] = ACTIONS(2260),
    [anon_sym_concept] = ACTIONS(2260),
    [anon_sym_co_return] = ACTIONS(2260),
    [anon_sym_co_yield] = ACTIONS(2260),
    [anon_sym_R_DQUOTE] = ACTIONS(2262),
    [anon_sym_LR_DQUOTE] = ACTIONS(2262),
    [anon_sym_uR_DQUOTE] = ACTIONS(2262),
    [anon_sym_UR_DQUOTE] = ACTIONS(2262),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2262),
    [anon_sym_co_await] = ACTIONS(2260),
    [anon_sym_new] = ACTIONS(2260),
    [anon_sym_requires] = ACTIONS(2260),
    [sym_this] = ACTIONS(2260),
    [anon_sym_discard] = ACTIONS(2260),
    [anon_sym_precise] = ACTIONS(2260),
    [anon_sym_shared] = ACTIONS(2260),
    [anon_sym_groupshared] = ACTIONS(2260),
    [anon_sym_uniform] = ACTIONS(2260),
    [anon_sym_row_major] = ACTIONS(2260),
    [anon_sym_column_major] = ACTIONS(2260),
    [anon_sym_globallycoherent] = ACTIONS(2260),
    [anon_sym_centroid] = ACTIONS(2260),
    [anon_sym_noperspective] = ACTIONS(2260),
    [anon_sym_nointerpolation] = ACTIONS(2260),
    [anon_sym_sample] = ACTIONS(2260),
    [anon_sym_linear] = ACTIONS(2260),
    [anon_sym_snorm] = ACTIONS(2260),
    [anon_sym_unorm] = ACTIONS(2260),
    [anon_sym_point] = ACTIONS(2260),
    [anon_sym_line] = ACTIONS(2260),
    [anon_sym_triangleadj] = ACTIONS(2260),
    [anon_sym_lineadj] = ACTIONS(2260),
    [anon_sym_triangle] = ACTIONS(2260),
    [anon_sym_cbuffer] = ACTIONS(2260),
  },
  [224] = {
    [sym_identifier] = ACTIONS(2264),
    [aux_sym_preproc_include_token1] = ACTIONS(2264),
    [aux_sym_preproc_def_token1] = ACTIONS(2264),
    [aux_sym_preproc_if_token1] = ACTIONS(2264),
    [aux_sym_preproc_if_token2] = ACTIONS(2264),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2264),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2264),
    [aux_sym_preproc_else_token1] = ACTIONS(2264),
    [aux_sym_preproc_elif_token1] = ACTIONS(2264),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2264),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2264),
    [sym_preproc_directive] = ACTIONS(2264),
    [anon_sym_LPAREN2] = ACTIONS(2266),
    [anon_sym_BANG] = ACTIONS(2266),
    [anon_sym_TILDE] = ACTIONS(2266),
    [anon_sym_DASH] = ACTIONS(2264),
    [anon_sym_PLUS] = ACTIONS(2264),
    [anon_sym_STAR] = ACTIONS(2266),
    [anon_sym_AMP_AMP] = ACTIONS(2266),
    [anon_sym_AMP] = ACTIONS(2264),
    [anon_sym_SEMI] = ACTIONS(2266),
    [anon_sym___extension__] = ACTIONS(2264),
    [anon_sym_typedef] = ACTIONS(2264),
    [anon_sym_in] = ACTIONS(2264),
    [anon_sym_out] = ACTIONS(2264),
    [anon_sym_inout] = ACTIONS(2264),
    [anon_sym_extern] = ACTIONS(2264),
    [anon_sym___attribute__] = ACTIONS(2264),
    [anon_sym_COLON_COLON] = ACTIONS(2266),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2266),
    [anon_sym___declspec] = ACTIONS(2264),
    [anon_sym___based] = ACTIONS(2264),
    [anon_sym___cdecl] = ACTIONS(2264),
    [anon_sym___clrcall] = ACTIONS(2264),
    [anon_sym___stdcall] = ACTIONS(2264),
    [anon_sym___fastcall] = ACTIONS(2264),
    [anon_sym___thiscall] = ACTIONS(2264),
    [anon_sym___vectorcall] = ACTIONS(2264),
    [anon_sym_LBRACE] = ACTIONS(2266),
    [anon_sym_signed] = ACTIONS(2264),
    [anon_sym_unsigned] = ACTIONS(2264),
    [anon_sym_long] = ACTIONS(2264),
    [anon_sym_short] = ACTIONS(2264),
    [anon_sym_LBRACK] = ACTIONS(2264),
    [anon_sym_static] = ACTIONS(2264),
    [anon_sym_register] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(2264),
    [anon_sym___inline] = ACTIONS(2264),
    [anon_sym___inline__] = ACTIONS(2264),
    [anon_sym___forceinline] = ACTIONS(2264),
    [anon_sym_thread_local] = ACTIONS(2264),
    [anon_sym___thread] = ACTIONS(2264),
    [anon_sym_const] = ACTIONS(2264),
    [anon_sym_constexpr] = ACTIONS(2264),
    [anon_sym_volatile] = ACTIONS(2264),
    [anon_sym_restrict] = ACTIONS(2264),
    [anon_sym___restrict__] = ACTIONS(2264),
    [anon_sym__Atomic] = ACTIONS(2264),
    [anon_sym__Noreturn] = ACTIONS(2264),
    [anon_sym_noreturn] = ACTIONS(2264),
    [anon_sym_mutable] = ACTIONS(2264),
    [anon_sym_constinit] = ACTIONS(2264),
    [anon_sym_consteval] = ACTIONS(2264),
    [anon_sym_alignas] = ACTIONS(2264),
    [anon_sym__Alignas] = ACTIONS(2264),
    [sym_primitive_type] = ACTIONS(2264),
    [anon_sym_enum] = ACTIONS(2264),
    [anon_sym_class] = ACTIONS(2264),
    [anon_sym_struct] = ACTIONS(2264),
    [anon_sym_union] = ACTIONS(2264),
    [anon_sym_if] = ACTIONS(2264),
    [anon_sym_else] = ACTIONS(2264),
    [anon_sym_switch] = ACTIONS(2264),
    [anon_sym_case] = ACTIONS(2264),
    [anon_sym_default] = ACTIONS(2264),
    [anon_sym_while] = ACTIONS(2264),
    [anon_sym_do] = ACTIONS(2264),
    [anon_sym_for] = ACTIONS(2264),
    [anon_sym_return] = ACTIONS(2264),
    [anon_sym_break] = ACTIONS(2264),
    [anon_sym_continue] = ACTIONS(2264),
    [anon_sym_goto] = ACTIONS(2264),
    [anon_sym___try] = ACTIONS(2264),
    [anon_sym___leave] = ACTIONS(2264),
    [anon_sym_not] = ACTIONS(2264),
    [anon_sym_compl] = ACTIONS(2264),
    [anon_sym_DASH_DASH] = ACTIONS(2266),
    [anon_sym_PLUS_PLUS] = ACTIONS(2266),
    [anon_sym_sizeof] = ACTIONS(2264),
    [anon_sym___alignof__] = ACTIONS(2264),
    [anon_sym___alignof] = ACTIONS(2264),
    [anon_sym__alignof] = ACTIONS(2264),
    [anon_sym_alignof] = ACTIONS(2264),
    [anon_sym__Alignof] = ACTIONS(2264),
    [anon_sym_offsetof] = ACTIONS(2264),
    [anon_sym__Generic] = ACTIONS(2264),
    [anon_sym_asm] = ACTIONS(2264),
    [anon_sym___asm__] = ACTIONS(2264),
    [sym_number_literal] = ACTIONS(2266),
    [anon_sym_L_SQUOTE] = ACTIONS(2266),
    [anon_sym_u_SQUOTE] = ACTIONS(2266),
    [anon_sym_U_SQUOTE] = ACTIONS(2266),
    [anon_sym_u8_SQUOTE] = ACTIONS(2266),
    [anon_sym_SQUOTE] = ACTIONS(2266),
    [anon_sym_L_DQUOTE] = ACTIONS(2266),
    [anon_sym_u_DQUOTE] = ACTIONS(2266),
    [anon_sym_U_DQUOTE] = ACTIONS(2266),
    [anon_sym_u8_DQUOTE] = ACTIONS(2266),
    [anon_sym_DQUOTE] = ACTIONS(2266),
    [sym_true] = ACTIONS(2264),
    [sym_false] = ACTIONS(2264),
    [anon_sym_NULL] = ACTIONS(2264),
    [anon_sym_nullptr] = ACTIONS(2264),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2264),
    [anon_sym_decltype] = ACTIONS(2264),
    [sym_virtual] = ACTIONS(2264),
    [anon_sym_explicit] = ACTIONS(2264),
    [anon_sym_typename] = ACTIONS(2264),
    [anon_sym_template] = ACTIONS(2264),
    [anon_sym_operator] = ACTIONS(2264),
    [anon_sym_try] = ACTIONS(2264),
    [anon_sym_delete] = ACTIONS(2264),
    [anon_sym_throw] = ACTIONS(2264),
    [anon_sym_namespace] = ACTIONS(2264),
    [anon_sym_using] = ACTIONS(2264),
    [anon_sym_static_assert] = ACTIONS(2264),
    [anon_sym_concept] = ACTIONS(2264),
    [anon_sym_co_return] = ACTIONS(2264),
    [anon_sym_co_yield] = ACTIONS(2264),
    [anon_sym_R_DQUOTE] = ACTIONS(2266),
    [anon_sym_LR_DQUOTE] = ACTIONS(2266),
    [anon_sym_uR_DQUOTE] = ACTIONS(2266),
    [anon_sym_UR_DQUOTE] = ACTIONS(2266),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2266),
    [anon_sym_co_await] = ACTIONS(2264),
    [anon_sym_new] = ACTIONS(2264),
    [anon_sym_requires] = ACTIONS(2264),
    [sym_this] = ACTIONS(2264),
    [anon_sym_discard] = ACTIONS(2264),
    [anon_sym_precise] = ACTIONS(2264),
    [anon_sym_shared] = ACTIONS(2264),
    [anon_sym_groupshared] = ACTIONS(2264),
    [anon_sym_uniform] = ACTIONS(2264),
    [anon_sym_row_major] = ACTIONS(2264),
    [anon_sym_column_major] = ACTIONS(2264),
    [anon_sym_globallycoherent] = ACTIONS(2264),
    [anon_sym_centroid] = ACTIONS(2264),
    [anon_sym_noperspective] = ACTIONS(2264),
    [anon_sym_nointerpolation] = ACTIONS(2264),
    [anon_sym_sample] = ACTIONS(2264),
    [anon_sym_linear] = ACTIONS(2264),
    [anon_sym_snorm] = ACTIONS(2264),
    [anon_sym_unorm] = ACTIONS(2264),
    [anon_sym_point] = ACTIONS(2264),
    [anon_sym_line] = ACTIONS(2264),
    [anon_sym_triangleadj] = ACTIONS(2264),
    [anon_sym_lineadj] = ACTIONS(2264),
    [anon_sym_triangle] = ACTIONS(2264),
    [anon_sym_cbuffer] = ACTIONS(2264),
  },
  [225] = {
    [sym_identifier] = ACTIONS(2268),
    [aux_sym_preproc_include_token1] = ACTIONS(2268),
    [aux_sym_preproc_def_token1] = ACTIONS(2268),
    [aux_sym_preproc_if_token1] = ACTIONS(2268),
    [aux_sym_preproc_if_token2] = ACTIONS(2268),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2268),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2268),
    [aux_sym_preproc_else_token1] = ACTIONS(2268),
    [aux_sym_preproc_elif_token1] = ACTIONS(2268),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2268),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2268),
    [sym_preproc_directive] = ACTIONS(2268),
    [anon_sym_LPAREN2] = ACTIONS(2270),
    [anon_sym_BANG] = ACTIONS(2270),
    [anon_sym_TILDE] = ACTIONS(2270),
    [anon_sym_DASH] = ACTIONS(2268),
    [anon_sym_PLUS] = ACTIONS(2268),
    [anon_sym_STAR] = ACTIONS(2270),
    [anon_sym_AMP_AMP] = ACTIONS(2270),
    [anon_sym_AMP] = ACTIONS(2268),
    [anon_sym_SEMI] = ACTIONS(2270),
    [anon_sym___extension__] = ACTIONS(2268),
    [anon_sym_typedef] = ACTIONS(2268),
    [anon_sym_in] = ACTIONS(2268),
    [anon_sym_out] = ACTIONS(2268),
    [anon_sym_inout] = ACTIONS(2268),
    [anon_sym_extern] = ACTIONS(2268),
    [anon_sym___attribute__] = ACTIONS(2268),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2270),
    [anon_sym___declspec] = ACTIONS(2268),
    [anon_sym___based] = ACTIONS(2268),
    [anon_sym___cdecl] = ACTIONS(2268),
    [anon_sym___clrcall] = ACTIONS(2268),
    [anon_sym___stdcall] = ACTIONS(2268),
    [anon_sym___fastcall] = ACTIONS(2268),
    [anon_sym___thiscall] = ACTIONS(2268),
    [anon_sym___vectorcall] = ACTIONS(2268),
    [anon_sym_LBRACE] = ACTIONS(2270),
    [anon_sym_signed] = ACTIONS(2268),
    [anon_sym_unsigned] = ACTIONS(2268),
    [anon_sym_long] = ACTIONS(2268),
    [anon_sym_short] = ACTIONS(2268),
    [anon_sym_LBRACK] = ACTIONS(2268),
    [anon_sym_static] = ACTIONS(2268),
    [anon_sym_register] = ACTIONS(2268),
    [anon_sym_inline] = ACTIONS(2268),
    [anon_sym___inline] = ACTIONS(2268),
    [anon_sym___inline__] = ACTIONS(2268),
    [anon_sym___forceinline] = ACTIONS(2268),
    [anon_sym_thread_local] = ACTIONS(2268),
    [anon_sym___thread] = ACTIONS(2268),
    [anon_sym_const] = ACTIONS(2268),
    [anon_sym_constexpr] = ACTIONS(2268),
    [anon_sym_volatile] = ACTIONS(2268),
    [anon_sym_restrict] = ACTIONS(2268),
    [anon_sym___restrict__] = ACTIONS(2268),
    [anon_sym__Atomic] = ACTIONS(2268),
    [anon_sym__Noreturn] = ACTIONS(2268),
    [anon_sym_noreturn] = ACTIONS(2268),
    [anon_sym_mutable] = ACTIONS(2268),
    [anon_sym_constinit] = ACTIONS(2268),
    [anon_sym_consteval] = ACTIONS(2268),
    [anon_sym_alignas] = ACTIONS(2268),
    [anon_sym__Alignas] = ACTIONS(2268),
    [sym_primitive_type] = ACTIONS(2268),
    [anon_sym_enum] = ACTIONS(2268),
    [anon_sym_class] = ACTIONS(2268),
    [anon_sym_struct] = ACTIONS(2268),
    [anon_sym_union] = ACTIONS(2268),
    [anon_sym_if] = ACTIONS(2268),
    [anon_sym_else] = ACTIONS(2268),
    [anon_sym_switch] = ACTIONS(2268),
    [anon_sym_case] = ACTIONS(2268),
    [anon_sym_default] = ACTIONS(2268),
    [anon_sym_while] = ACTIONS(2268),
    [anon_sym_do] = ACTIONS(2268),
    [anon_sym_for] = ACTIONS(2268),
    [anon_sym_return] = ACTIONS(2268),
    [anon_sym_break] = ACTIONS(2268),
    [anon_sym_continue] = ACTIONS(2268),
    [anon_sym_goto] = ACTIONS(2268),
    [anon_sym___try] = ACTIONS(2268),
    [anon_sym___leave] = ACTIONS(2268),
    [anon_sym_not] = ACTIONS(2268),
    [anon_sym_compl] = ACTIONS(2268),
    [anon_sym_DASH_DASH] = ACTIONS(2270),
    [anon_sym_PLUS_PLUS] = ACTIONS(2270),
    [anon_sym_sizeof] = ACTIONS(2268),
    [anon_sym___alignof__] = ACTIONS(2268),
    [anon_sym___alignof] = ACTIONS(2268),
    [anon_sym__alignof] = ACTIONS(2268),
    [anon_sym_alignof] = ACTIONS(2268),
    [anon_sym__Alignof] = ACTIONS(2268),
    [anon_sym_offsetof] = ACTIONS(2268),
    [anon_sym__Generic] = ACTIONS(2268),
    [anon_sym_asm] = ACTIONS(2268),
    [anon_sym___asm__] = ACTIONS(2268),
    [sym_number_literal] = ACTIONS(2270),
    [anon_sym_L_SQUOTE] = ACTIONS(2270),
    [anon_sym_u_SQUOTE] = ACTIONS(2270),
    [anon_sym_U_SQUOTE] = ACTIONS(2270),
    [anon_sym_u8_SQUOTE] = ACTIONS(2270),
    [anon_sym_SQUOTE] = ACTIONS(2270),
    [anon_sym_L_DQUOTE] = ACTIONS(2270),
    [anon_sym_u_DQUOTE] = ACTIONS(2270),
    [anon_sym_U_DQUOTE] = ACTIONS(2270),
    [anon_sym_u8_DQUOTE] = ACTIONS(2270),
    [anon_sym_DQUOTE] = ACTIONS(2270),
    [sym_true] = ACTIONS(2268),
    [sym_false] = ACTIONS(2268),
    [anon_sym_NULL] = ACTIONS(2268),
    [anon_sym_nullptr] = ACTIONS(2268),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2268),
    [anon_sym_decltype] = ACTIONS(2268),
    [sym_virtual] = ACTIONS(2268),
    [anon_sym_explicit] = ACTIONS(2268),
    [anon_sym_typename] = ACTIONS(2268),
    [anon_sym_template] = ACTIONS(2268),
    [anon_sym_operator] = ACTIONS(2268),
    [anon_sym_try] = ACTIONS(2268),
    [anon_sym_delete] = ACTIONS(2268),
    [anon_sym_throw] = ACTIONS(2268),
    [anon_sym_namespace] = ACTIONS(2268),
    [anon_sym_using] = ACTIONS(2268),
    [anon_sym_static_assert] = ACTIONS(2268),
    [anon_sym_concept] = ACTIONS(2268),
    [anon_sym_co_return] = ACTIONS(2268),
    [anon_sym_co_yield] = ACTIONS(2268),
    [anon_sym_R_DQUOTE] = ACTIONS(2270),
    [anon_sym_LR_DQUOTE] = ACTIONS(2270),
    [anon_sym_uR_DQUOTE] = ACTIONS(2270),
    [anon_sym_UR_DQUOTE] = ACTIONS(2270),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2270),
    [anon_sym_co_await] = ACTIONS(2268),
    [anon_sym_new] = ACTIONS(2268),
    [anon_sym_requires] = ACTIONS(2268),
    [sym_this] = ACTIONS(2268),
    [anon_sym_discard] = ACTIONS(2268),
    [anon_sym_precise] = ACTIONS(2268),
    [anon_sym_shared] = ACTIONS(2268),
    [anon_sym_groupshared] = ACTIONS(2268),
    [anon_sym_uniform] = ACTIONS(2268),
    [anon_sym_row_major] = ACTIONS(2268),
    [anon_sym_column_major] = ACTIONS(2268),
    [anon_sym_globallycoherent] = ACTIONS(2268),
    [anon_sym_centroid] = ACTIONS(2268),
    [anon_sym_noperspective] = ACTIONS(2268),
    [anon_sym_nointerpolation] = ACTIONS(2268),
    [anon_sym_sample] = ACTIONS(2268),
    [anon_sym_linear] = ACTIONS(2268),
    [anon_sym_snorm] = ACTIONS(2268),
    [anon_sym_unorm] = ACTIONS(2268),
    [anon_sym_point] = ACTIONS(2268),
    [anon_sym_line] = ACTIONS(2268),
    [anon_sym_triangleadj] = ACTIONS(2268),
    [anon_sym_lineadj] = ACTIONS(2268),
    [anon_sym_triangle] = ACTIONS(2268),
    [anon_sym_cbuffer] = ACTIONS(2268),
  },
  [226] = {
    [sym_identifier] = ACTIONS(2272),
    [aux_sym_preproc_include_token1] = ACTIONS(2272),
    [aux_sym_preproc_def_token1] = ACTIONS(2272),
    [aux_sym_preproc_if_token1] = ACTIONS(2272),
    [aux_sym_preproc_if_token2] = ACTIONS(2272),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2272),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2272),
    [aux_sym_preproc_else_token1] = ACTIONS(2272),
    [aux_sym_preproc_elif_token1] = ACTIONS(2272),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2272),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2272),
    [sym_preproc_directive] = ACTIONS(2272),
    [anon_sym_LPAREN2] = ACTIONS(2274),
    [anon_sym_BANG] = ACTIONS(2274),
    [anon_sym_TILDE] = ACTIONS(2274),
    [anon_sym_DASH] = ACTIONS(2272),
    [anon_sym_PLUS] = ACTIONS(2272),
    [anon_sym_STAR] = ACTIONS(2274),
    [anon_sym_AMP_AMP] = ACTIONS(2274),
    [anon_sym_AMP] = ACTIONS(2272),
    [anon_sym_SEMI] = ACTIONS(2274),
    [anon_sym___extension__] = ACTIONS(2272),
    [anon_sym_typedef] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2272),
    [anon_sym_out] = ACTIONS(2272),
    [anon_sym_inout] = ACTIONS(2272),
    [anon_sym_extern] = ACTIONS(2272),
    [anon_sym___attribute__] = ACTIONS(2272),
    [anon_sym_COLON_COLON] = ACTIONS(2274),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2274),
    [anon_sym___declspec] = ACTIONS(2272),
    [anon_sym___based] = ACTIONS(2272),
    [anon_sym___cdecl] = ACTIONS(2272),
    [anon_sym___clrcall] = ACTIONS(2272),
    [anon_sym___stdcall] = ACTIONS(2272),
    [anon_sym___fastcall] = ACTIONS(2272),
    [anon_sym___thiscall] = ACTIONS(2272),
    [anon_sym___vectorcall] = ACTIONS(2272),
    [anon_sym_LBRACE] = ACTIONS(2274),
    [anon_sym_signed] = ACTIONS(2272),
    [anon_sym_unsigned] = ACTIONS(2272),
    [anon_sym_long] = ACTIONS(2272),
    [anon_sym_short] = ACTIONS(2272),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(2272),
    [anon_sym_register] = ACTIONS(2272),
    [anon_sym_inline] = ACTIONS(2272),
    [anon_sym___inline] = ACTIONS(2272),
    [anon_sym___inline__] = ACTIONS(2272),
    [anon_sym___forceinline] = ACTIONS(2272),
    [anon_sym_thread_local] = ACTIONS(2272),
    [anon_sym___thread] = ACTIONS(2272),
    [anon_sym_const] = ACTIONS(2272),
    [anon_sym_constexpr] = ACTIONS(2272),
    [anon_sym_volatile] = ACTIONS(2272),
    [anon_sym_restrict] = ACTIONS(2272),
    [anon_sym___restrict__] = ACTIONS(2272),
    [anon_sym__Atomic] = ACTIONS(2272),
    [anon_sym__Noreturn] = ACTIONS(2272),
    [anon_sym_noreturn] = ACTIONS(2272),
    [anon_sym_mutable] = ACTIONS(2272),
    [anon_sym_constinit] = ACTIONS(2272),
    [anon_sym_consteval] = ACTIONS(2272),
    [anon_sym_alignas] = ACTIONS(2272),
    [anon_sym__Alignas] = ACTIONS(2272),
    [sym_primitive_type] = ACTIONS(2272),
    [anon_sym_enum] = ACTIONS(2272),
    [anon_sym_class] = ACTIONS(2272),
    [anon_sym_struct] = ACTIONS(2272),
    [anon_sym_union] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2272),
    [anon_sym_else] = ACTIONS(2272),
    [anon_sym_switch] = ACTIONS(2272),
    [anon_sym_case] = ACTIONS(2272),
    [anon_sym_default] = ACTIONS(2272),
    [anon_sym_while] = ACTIONS(2272),
    [anon_sym_do] = ACTIONS(2272),
    [anon_sym_for] = ACTIONS(2272),
    [anon_sym_return] = ACTIONS(2272),
    [anon_sym_break] = ACTIONS(2272),
    [anon_sym_continue] = ACTIONS(2272),
    [anon_sym_goto] = ACTIONS(2272),
    [anon_sym___try] = ACTIONS(2272),
    [anon_sym___leave] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2272),
    [anon_sym_compl] = ACTIONS(2272),
    [anon_sym_DASH_DASH] = ACTIONS(2274),
    [anon_sym_PLUS_PLUS] = ACTIONS(2274),
    [anon_sym_sizeof] = ACTIONS(2272),
    [anon_sym___alignof__] = ACTIONS(2272),
    [anon_sym___alignof] = ACTIONS(2272),
    [anon_sym__alignof] = ACTIONS(2272),
    [anon_sym_alignof] = ACTIONS(2272),
    [anon_sym__Alignof] = ACTIONS(2272),
    [anon_sym_offsetof] = ACTIONS(2272),
    [anon_sym__Generic] = ACTIONS(2272),
    [anon_sym_asm] = ACTIONS(2272),
    [anon_sym___asm__] = ACTIONS(2272),
    [sym_number_literal] = ACTIONS(2274),
    [anon_sym_L_SQUOTE] = ACTIONS(2274),
    [anon_sym_u_SQUOTE] = ACTIONS(2274),
    [anon_sym_U_SQUOTE] = ACTIONS(2274),
    [anon_sym_u8_SQUOTE] = ACTIONS(2274),
    [anon_sym_SQUOTE] = ACTIONS(2274),
    [anon_sym_L_DQUOTE] = ACTIONS(2274),
    [anon_sym_u_DQUOTE] = ACTIONS(2274),
    [anon_sym_U_DQUOTE] = ACTIONS(2274),
    [anon_sym_u8_DQUOTE] = ACTIONS(2274),
    [anon_sym_DQUOTE] = ACTIONS(2274),
    [sym_true] = ACTIONS(2272),
    [sym_false] = ACTIONS(2272),
    [anon_sym_NULL] = ACTIONS(2272),
    [anon_sym_nullptr] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2272),
    [anon_sym_decltype] = ACTIONS(2272),
    [sym_virtual] = ACTIONS(2272),
    [anon_sym_explicit] = ACTIONS(2272),
    [anon_sym_typename] = ACTIONS(2272),
    [anon_sym_template] = ACTIONS(2272),
    [anon_sym_operator] = ACTIONS(2272),
    [anon_sym_try] = ACTIONS(2272),
    [anon_sym_delete] = ACTIONS(2272),
    [anon_sym_throw] = ACTIONS(2272),
    [anon_sym_namespace] = ACTIONS(2272),
    [anon_sym_using] = ACTIONS(2272),
    [anon_sym_static_assert] = ACTIONS(2272),
    [anon_sym_concept] = ACTIONS(2272),
    [anon_sym_co_return] = ACTIONS(2272),
    [anon_sym_co_yield] = ACTIONS(2272),
    [anon_sym_R_DQUOTE] = ACTIONS(2274),
    [anon_sym_LR_DQUOTE] = ACTIONS(2274),
    [anon_sym_uR_DQUOTE] = ACTIONS(2274),
    [anon_sym_UR_DQUOTE] = ACTIONS(2274),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2274),
    [anon_sym_co_await] = ACTIONS(2272),
    [anon_sym_new] = ACTIONS(2272),
    [anon_sym_requires] = ACTIONS(2272),
    [sym_this] = ACTIONS(2272),
    [anon_sym_discard] = ACTIONS(2272),
    [anon_sym_precise] = ACTIONS(2272),
    [anon_sym_shared] = ACTIONS(2272),
    [anon_sym_groupshared] = ACTIONS(2272),
    [anon_sym_uniform] = ACTIONS(2272),
    [anon_sym_row_major] = ACTIONS(2272),
    [anon_sym_column_major] = ACTIONS(2272),
    [anon_sym_globallycoherent] = ACTIONS(2272),
    [anon_sym_centroid] = ACTIONS(2272),
    [anon_sym_noperspective] = ACTIONS(2272),
    [anon_sym_nointerpolation] = ACTIONS(2272),
    [anon_sym_sample] = ACTIONS(2272),
    [anon_sym_linear] = ACTIONS(2272),
    [anon_sym_snorm] = ACTIONS(2272),
    [anon_sym_unorm] = ACTIONS(2272),
    [anon_sym_point] = ACTIONS(2272),
    [anon_sym_line] = ACTIONS(2272),
    [anon_sym_triangleadj] = ACTIONS(2272),
    [anon_sym_lineadj] = ACTIONS(2272),
    [anon_sym_triangle] = ACTIONS(2272),
    [anon_sym_cbuffer] = ACTIONS(2272),
  },
  [227] = {
    [sym_identifier] = ACTIONS(2276),
    [aux_sym_preproc_include_token1] = ACTIONS(2276),
    [aux_sym_preproc_def_token1] = ACTIONS(2276),
    [aux_sym_preproc_if_token1] = ACTIONS(2276),
    [aux_sym_preproc_if_token2] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2276),
    [aux_sym_preproc_else_token1] = ACTIONS(2276),
    [aux_sym_preproc_elif_token1] = ACTIONS(2276),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2276),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2276),
    [sym_preproc_directive] = ACTIONS(2276),
    [anon_sym_LPAREN2] = ACTIONS(2278),
    [anon_sym_BANG] = ACTIONS(2278),
    [anon_sym_TILDE] = ACTIONS(2278),
    [anon_sym_DASH] = ACTIONS(2276),
    [anon_sym_PLUS] = ACTIONS(2276),
    [anon_sym_STAR] = ACTIONS(2278),
    [anon_sym_AMP_AMP] = ACTIONS(2278),
    [anon_sym_AMP] = ACTIONS(2276),
    [anon_sym_SEMI] = ACTIONS(2278),
    [anon_sym___extension__] = ACTIONS(2276),
    [anon_sym_typedef] = ACTIONS(2276),
    [anon_sym_in] = ACTIONS(2276),
    [anon_sym_out] = ACTIONS(2276),
    [anon_sym_inout] = ACTIONS(2276),
    [anon_sym_extern] = ACTIONS(2276),
    [anon_sym___attribute__] = ACTIONS(2276),
    [anon_sym_COLON_COLON] = ACTIONS(2278),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2278),
    [anon_sym___declspec] = ACTIONS(2276),
    [anon_sym___based] = ACTIONS(2276),
    [anon_sym___cdecl] = ACTIONS(2276),
    [anon_sym___clrcall] = ACTIONS(2276),
    [anon_sym___stdcall] = ACTIONS(2276),
    [anon_sym___fastcall] = ACTIONS(2276),
    [anon_sym___thiscall] = ACTIONS(2276),
    [anon_sym___vectorcall] = ACTIONS(2276),
    [anon_sym_LBRACE] = ACTIONS(2278),
    [anon_sym_signed] = ACTIONS(2276),
    [anon_sym_unsigned] = ACTIONS(2276),
    [anon_sym_long] = ACTIONS(2276),
    [anon_sym_short] = ACTIONS(2276),
    [anon_sym_LBRACK] = ACTIONS(2276),
    [anon_sym_static] = ACTIONS(2276),
    [anon_sym_register] = ACTIONS(2276),
    [anon_sym_inline] = ACTIONS(2276),
    [anon_sym___inline] = ACTIONS(2276),
    [anon_sym___inline__] = ACTIONS(2276),
    [anon_sym___forceinline] = ACTIONS(2276),
    [anon_sym_thread_local] = ACTIONS(2276),
    [anon_sym___thread] = ACTIONS(2276),
    [anon_sym_const] = ACTIONS(2276),
    [anon_sym_constexpr] = ACTIONS(2276),
    [anon_sym_volatile] = ACTIONS(2276),
    [anon_sym_restrict] = ACTIONS(2276),
    [anon_sym___restrict__] = ACTIONS(2276),
    [anon_sym__Atomic] = ACTIONS(2276),
    [anon_sym__Noreturn] = ACTIONS(2276),
    [anon_sym_noreturn] = ACTIONS(2276),
    [anon_sym_mutable] = ACTIONS(2276),
    [anon_sym_constinit] = ACTIONS(2276),
    [anon_sym_consteval] = ACTIONS(2276),
    [anon_sym_alignas] = ACTIONS(2276),
    [anon_sym__Alignas] = ACTIONS(2276),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2276),
    [anon_sym_class] = ACTIONS(2276),
    [anon_sym_struct] = ACTIONS(2276),
    [anon_sym_union] = ACTIONS(2276),
    [anon_sym_if] = ACTIONS(2276),
    [anon_sym_else] = ACTIONS(2276),
    [anon_sym_switch] = ACTIONS(2276),
    [anon_sym_case] = ACTIONS(2276),
    [anon_sym_default] = ACTIONS(2276),
    [anon_sym_while] = ACTIONS(2276),
    [anon_sym_do] = ACTIONS(2276),
    [anon_sym_for] = ACTIONS(2276),
    [anon_sym_return] = ACTIONS(2276),
    [anon_sym_break] = ACTIONS(2276),
    [anon_sym_continue] = ACTIONS(2276),
    [anon_sym_goto] = ACTIONS(2276),
    [anon_sym___try] = ACTIONS(2276),
    [anon_sym___leave] = ACTIONS(2276),
    [anon_sym_not] = ACTIONS(2276),
    [anon_sym_compl] = ACTIONS(2276),
    [anon_sym_DASH_DASH] = ACTIONS(2278),
    [anon_sym_PLUS_PLUS] = ACTIONS(2278),
    [anon_sym_sizeof] = ACTIONS(2276),
    [anon_sym___alignof__] = ACTIONS(2276),
    [anon_sym___alignof] = ACTIONS(2276),
    [anon_sym__alignof] = ACTIONS(2276),
    [anon_sym_alignof] = ACTIONS(2276),
    [anon_sym__Alignof] = ACTIONS(2276),
    [anon_sym_offsetof] = ACTIONS(2276),
    [anon_sym__Generic] = ACTIONS(2276),
    [anon_sym_asm] = ACTIONS(2276),
    [anon_sym___asm__] = ACTIONS(2276),
    [sym_number_literal] = ACTIONS(2278),
    [anon_sym_L_SQUOTE] = ACTIONS(2278),
    [anon_sym_u_SQUOTE] = ACTIONS(2278),
    [anon_sym_U_SQUOTE] = ACTIONS(2278),
    [anon_sym_u8_SQUOTE] = ACTIONS(2278),
    [anon_sym_SQUOTE] = ACTIONS(2278),
    [anon_sym_L_DQUOTE] = ACTIONS(2278),
    [anon_sym_u_DQUOTE] = ACTIONS(2278),
    [anon_sym_U_DQUOTE] = ACTIONS(2278),
    [anon_sym_u8_DQUOTE] = ACTIONS(2278),
    [anon_sym_DQUOTE] = ACTIONS(2278),
    [sym_true] = ACTIONS(2276),
    [sym_false] = ACTIONS(2276),
    [anon_sym_NULL] = ACTIONS(2276),
    [anon_sym_nullptr] = ACTIONS(2276),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2276),
    [anon_sym_decltype] = ACTIONS(2276),
    [sym_virtual] = ACTIONS(2276),
    [anon_sym_explicit] = ACTIONS(2276),
    [anon_sym_typename] = ACTIONS(2276),
    [anon_sym_template] = ACTIONS(2276),
    [anon_sym_operator] = ACTIONS(2276),
    [anon_sym_try] = ACTIONS(2276),
    [anon_sym_delete] = ACTIONS(2276),
    [anon_sym_throw] = ACTIONS(2276),
    [anon_sym_namespace] = ACTIONS(2276),
    [anon_sym_using] = ACTIONS(2276),
    [anon_sym_static_assert] = ACTIONS(2276),
    [anon_sym_concept] = ACTIONS(2276),
    [anon_sym_co_return] = ACTIONS(2276),
    [anon_sym_co_yield] = ACTIONS(2276),
    [anon_sym_R_DQUOTE] = ACTIONS(2278),
    [anon_sym_LR_DQUOTE] = ACTIONS(2278),
    [anon_sym_uR_DQUOTE] = ACTIONS(2278),
    [anon_sym_UR_DQUOTE] = ACTIONS(2278),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2278),
    [anon_sym_co_await] = ACTIONS(2276),
    [anon_sym_new] = ACTIONS(2276),
    [anon_sym_requires] = ACTIONS(2276),
    [sym_this] = ACTIONS(2276),
    [anon_sym_discard] = ACTIONS(2276),
    [anon_sym_precise] = ACTIONS(2276),
    [anon_sym_shared] = ACTIONS(2276),
    [anon_sym_groupshared] = ACTIONS(2276),
    [anon_sym_uniform] = ACTIONS(2276),
    [anon_sym_row_major] = ACTIONS(2276),
    [anon_sym_column_major] = ACTIONS(2276),
    [anon_sym_globallycoherent] = ACTIONS(2276),
    [anon_sym_centroid] = ACTIONS(2276),
    [anon_sym_noperspective] = ACTIONS(2276),
    [anon_sym_nointerpolation] = ACTIONS(2276),
    [anon_sym_sample] = ACTIONS(2276),
    [anon_sym_linear] = ACTIONS(2276),
    [anon_sym_snorm] = ACTIONS(2276),
    [anon_sym_unorm] = ACTIONS(2276),
    [anon_sym_point] = ACTIONS(2276),
    [anon_sym_line] = ACTIONS(2276),
    [anon_sym_triangleadj] = ACTIONS(2276),
    [anon_sym_lineadj] = ACTIONS(2276),
    [anon_sym_triangle] = ACTIONS(2276),
    [anon_sym_cbuffer] = ACTIONS(2276),
  },
  [228] = {
    [sym_identifier] = ACTIONS(2276),
    [aux_sym_preproc_include_token1] = ACTIONS(2276),
    [aux_sym_preproc_def_token1] = ACTIONS(2276),
    [aux_sym_preproc_if_token1] = ACTIONS(2276),
    [aux_sym_preproc_if_token2] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2276),
    [aux_sym_preproc_else_token1] = ACTIONS(2276),
    [aux_sym_preproc_elif_token1] = ACTIONS(2276),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2276),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2276),
    [sym_preproc_directive] = ACTIONS(2276),
    [anon_sym_LPAREN2] = ACTIONS(2278),
    [anon_sym_BANG] = ACTIONS(2278),
    [anon_sym_TILDE] = ACTIONS(2278),
    [anon_sym_DASH] = ACTIONS(2276),
    [anon_sym_PLUS] = ACTIONS(2276),
    [anon_sym_STAR] = ACTIONS(2278),
    [anon_sym_AMP_AMP] = ACTIONS(2278),
    [anon_sym_AMP] = ACTIONS(2276),
    [anon_sym_SEMI] = ACTIONS(2278),
    [anon_sym___extension__] = ACTIONS(2276),
    [anon_sym_typedef] = ACTIONS(2276),
    [anon_sym_in] = ACTIONS(2276),
    [anon_sym_out] = ACTIONS(2276),
    [anon_sym_inout] = ACTIONS(2276),
    [anon_sym_extern] = ACTIONS(2276),
    [anon_sym___attribute__] = ACTIONS(2276),
    [anon_sym_COLON_COLON] = ACTIONS(2278),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2278),
    [anon_sym___declspec] = ACTIONS(2276),
    [anon_sym___based] = ACTIONS(2276),
    [anon_sym___cdecl] = ACTIONS(2276),
    [anon_sym___clrcall] = ACTIONS(2276),
    [anon_sym___stdcall] = ACTIONS(2276),
    [anon_sym___fastcall] = ACTIONS(2276),
    [anon_sym___thiscall] = ACTIONS(2276),
    [anon_sym___vectorcall] = ACTIONS(2276),
    [anon_sym_LBRACE] = ACTIONS(2278),
    [anon_sym_signed] = ACTIONS(2276),
    [anon_sym_unsigned] = ACTIONS(2276),
    [anon_sym_long] = ACTIONS(2276),
    [anon_sym_short] = ACTIONS(2276),
    [anon_sym_LBRACK] = ACTIONS(2276),
    [anon_sym_static] = ACTIONS(2276),
    [anon_sym_register] = ACTIONS(2276),
    [anon_sym_inline] = ACTIONS(2276),
    [anon_sym___inline] = ACTIONS(2276),
    [anon_sym___inline__] = ACTIONS(2276),
    [anon_sym___forceinline] = ACTIONS(2276),
    [anon_sym_thread_local] = ACTIONS(2276),
    [anon_sym___thread] = ACTIONS(2276),
    [anon_sym_const] = ACTIONS(2276),
    [anon_sym_constexpr] = ACTIONS(2276),
    [anon_sym_volatile] = ACTIONS(2276),
    [anon_sym_restrict] = ACTIONS(2276),
    [anon_sym___restrict__] = ACTIONS(2276),
    [anon_sym__Atomic] = ACTIONS(2276),
    [anon_sym__Noreturn] = ACTIONS(2276),
    [anon_sym_noreturn] = ACTIONS(2276),
    [anon_sym_mutable] = ACTIONS(2276),
    [anon_sym_constinit] = ACTIONS(2276),
    [anon_sym_consteval] = ACTIONS(2276),
    [anon_sym_alignas] = ACTIONS(2276),
    [anon_sym__Alignas] = ACTIONS(2276),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2276),
    [anon_sym_class] = ACTIONS(2276),
    [anon_sym_struct] = ACTIONS(2276),
    [anon_sym_union] = ACTIONS(2276),
    [anon_sym_if] = ACTIONS(2276),
    [anon_sym_else] = ACTIONS(2276),
    [anon_sym_switch] = ACTIONS(2276),
    [anon_sym_case] = ACTIONS(2276),
    [anon_sym_default] = ACTIONS(2276),
    [anon_sym_while] = ACTIONS(2276),
    [anon_sym_do] = ACTIONS(2276),
    [anon_sym_for] = ACTIONS(2276),
    [anon_sym_return] = ACTIONS(2276),
    [anon_sym_break] = ACTIONS(2276),
    [anon_sym_continue] = ACTIONS(2276),
    [anon_sym_goto] = ACTIONS(2276),
    [anon_sym___try] = ACTIONS(2276),
    [anon_sym___leave] = ACTIONS(2276),
    [anon_sym_not] = ACTIONS(2276),
    [anon_sym_compl] = ACTIONS(2276),
    [anon_sym_DASH_DASH] = ACTIONS(2278),
    [anon_sym_PLUS_PLUS] = ACTIONS(2278),
    [anon_sym_sizeof] = ACTIONS(2276),
    [anon_sym___alignof__] = ACTIONS(2276),
    [anon_sym___alignof] = ACTIONS(2276),
    [anon_sym__alignof] = ACTIONS(2276),
    [anon_sym_alignof] = ACTIONS(2276),
    [anon_sym__Alignof] = ACTIONS(2276),
    [anon_sym_offsetof] = ACTIONS(2276),
    [anon_sym__Generic] = ACTIONS(2276),
    [anon_sym_asm] = ACTIONS(2276),
    [anon_sym___asm__] = ACTIONS(2276),
    [sym_number_literal] = ACTIONS(2278),
    [anon_sym_L_SQUOTE] = ACTIONS(2278),
    [anon_sym_u_SQUOTE] = ACTIONS(2278),
    [anon_sym_U_SQUOTE] = ACTIONS(2278),
    [anon_sym_u8_SQUOTE] = ACTIONS(2278),
    [anon_sym_SQUOTE] = ACTIONS(2278),
    [anon_sym_L_DQUOTE] = ACTIONS(2278),
    [anon_sym_u_DQUOTE] = ACTIONS(2278),
    [anon_sym_U_DQUOTE] = ACTIONS(2278),
    [anon_sym_u8_DQUOTE] = ACTIONS(2278),
    [anon_sym_DQUOTE] = ACTIONS(2278),
    [sym_true] = ACTIONS(2276),
    [sym_false] = ACTIONS(2276),
    [anon_sym_NULL] = ACTIONS(2276),
    [anon_sym_nullptr] = ACTIONS(2276),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2276),
    [anon_sym_decltype] = ACTIONS(2276),
    [sym_virtual] = ACTIONS(2276),
    [anon_sym_explicit] = ACTIONS(2276),
    [anon_sym_typename] = ACTIONS(2276),
    [anon_sym_template] = ACTIONS(2276),
    [anon_sym_operator] = ACTIONS(2276),
    [anon_sym_try] = ACTIONS(2276),
    [anon_sym_delete] = ACTIONS(2276),
    [anon_sym_throw] = ACTIONS(2276),
    [anon_sym_namespace] = ACTIONS(2276),
    [anon_sym_using] = ACTIONS(2276),
    [anon_sym_static_assert] = ACTIONS(2276),
    [anon_sym_concept] = ACTIONS(2276),
    [anon_sym_co_return] = ACTIONS(2276),
    [anon_sym_co_yield] = ACTIONS(2276),
    [anon_sym_R_DQUOTE] = ACTIONS(2278),
    [anon_sym_LR_DQUOTE] = ACTIONS(2278),
    [anon_sym_uR_DQUOTE] = ACTIONS(2278),
    [anon_sym_UR_DQUOTE] = ACTIONS(2278),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2278),
    [anon_sym_co_await] = ACTIONS(2276),
    [anon_sym_new] = ACTIONS(2276),
    [anon_sym_requires] = ACTIONS(2276),
    [sym_this] = ACTIONS(2276),
    [anon_sym_discard] = ACTIONS(2276),
    [anon_sym_precise] = ACTIONS(2276),
    [anon_sym_shared] = ACTIONS(2276),
    [anon_sym_groupshared] = ACTIONS(2276),
    [anon_sym_uniform] = ACTIONS(2276),
    [anon_sym_row_major] = ACTIONS(2276),
    [anon_sym_column_major] = ACTIONS(2276),
    [anon_sym_globallycoherent] = ACTIONS(2276),
    [anon_sym_centroid] = ACTIONS(2276),
    [anon_sym_noperspective] = ACTIONS(2276),
    [anon_sym_nointerpolation] = ACTIONS(2276),
    [anon_sym_sample] = ACTIONS(2276),
    [anon_sym_linear] = ACTIONS(2276),
    [anon_sym_snorm] = ACTIONS(2276),
    [anon_sym_unorm] = ACTIONS(2276),
    [anon_sym_point] = ACTIONS(2276),
    [anon_sym_line] = ACTIONS(2276),
    [anon_sym_triangleadj] = ACTIONS(2276),
    [anon_sym_lineadj] = ACTIONS(2276),
    [anon_sym_triangle] = ACTIONS(2276),
    [anon_sym_cbuffer] = ACTIONS(2276),
  },
  [229] = {
    [sym_identifier] = ACTIONS(2280),
    [aux_sym_preproc_include_token1] = ACTIONS(2280),
    [aux_sym_preproc_def_token1] = ACTIONS(2280),
    [aux_sym_preproc_if_token1] = ACTIONS(2280),
    [aux_sym_preproc_if_token2] = ACTIONS(2280),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2280),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2280),
    [aux_sym_preproc_else_token1] = ACTIONS(2280),
    [aux_sym_preproc_elif_token1] = ACTIONS(2280),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2280),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2280),
    [sym_preproc_directive] = ACTIONS(2280),
    [anon_sym_LPAREN2] = ACTIONS(2282),
    [anon_sym_BANG] = ACTIONS(2282),
    [anon_sym_TILDE] = ACTIONS(2282),
    [anon_sym_DASH] = ACTIONS(2280),
    [anon_sym_PLUS] = ACTIONS(2280),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_AMP_AMP] = ACTIONS(2282),
    [anon_sym_AMP] = ACTIONS(2280),
    [anon_sym_SEMI] = ACTIONS(2282),
    [anon_sym___extension__] = ACTIONS(2280),
    [anon_sym_typedef] = ACTIONS(2280),
    [anon_sym_in] = ACTIONS(2280),
    [anon_sym_out] = ACTIONS(2280),
    [anon_sym_inout] = ACTIONS(2280),
    [anon_sym_extern] = ACTIONS(2280),
    [anon_sym___attribute__] = ACTIONS(2280),
    [anon_sym_COLON_COLON] = ACTIONS(2282),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2282),
    [anon_sym___declspec] = ACTIONS(2280),
    [anon_sym___based] = ACTIONS(2280),
    [anon_sym___cdecl] = ACTIONS(2280),
    [anon_sym___clrcall] = ACTIONS(2280),
    [anon_sym___stdcall] = ACTIONS(2280),
    [anon_sym___fastcall] = ACTIONS(2280),
    [anon_sym___thiscall] = ACTIONS(2280),
    [anon_sym___vectorcall] = ACTIONS(2280),
    [anon_sym_LBRACE] = ACTIONS(2282),
    [anon_sym_signed] = ACTIONS(2280),
    [anon_sym_unsigned] = ACTIONS(2280),
    [anon_sym_long] = ACTIONS(2280),
    [anon_sym_short] = ACTIONS(2280),
    [anon_sym_LBRACK] = ACTIONS(2280),
    [anon_sym_static] = ACTIONS(2280),
    [anon_sym_register] = ACTIONS(2280),
    [anon_sym_inline] = ACTIONS(2280),
    [anon_sym___inline] = ACTIONS(2280),
    [anon_sym___inline__] = ACTIONS(2280),
    [anon_sym___forceinline] = ACTIONS(2280),
    [anon_sym_thread_local] = ACTIONS(2280),
    [anon_sym___thread] = ACTIONS(2280),
    [anon_sym_const] = ACTIONS(2280),
    [anon_sym_constexpr] = ACTIONS(2280),
    [anon_sym_volatile] = ACTIONS(2280),
    [anon_sym_restrict] = ACTIONS(2280),
    [anon_sym___restrict__] = ACTIONS(2280),
    [anon_sym__Atomic] = ACTIONS(2280),
    [anon_sym__Noreturn] = ACTIONS(2280),
    [anon_sym_noreturn] = ACTIONS(2280),
    [anon_sym_mutable] = ACTIONS(2280),
    [anon_sym_constinit] = ACTIONS(2280),
    [anon_sym_consteval] = ACTIONS(2280),
    [anon_sym_alignas] = ACTIONS(2280),
    [anon_sym__Alignas] = ACTIONS(2280),
    [sym_primitive_type] = ACTIONS(2280),
    [anon_sym_enum] = ACTIONS(2280),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2280),
    [anon_sym_union] = ACTIONS(2280),
    [anon_sym_if] = ACTIONS(2280),
    [anon_sym_else] = ACTIONS(2280),
    [anon_sym_switch] = ACTIONS(2280),
    [anon_sym_case] = ACTIONS(2280),
    [anon_sym_default] = ACTIONS(2280),
    [anon_sym_while] = ACTIONS(2280),
    [anon_sym_do] = ACTIONS(2280),
    [anon_sym_for] = ACTIONS(2280),
    [anon_sym_return] = ACTIONS(2280),
    [anon_sym_break] = ACTIONS(2280),
    [anon_sym_continue] = ACTIONS(2280),
    [anon_sym_goto] = ACTIONS(2280),
    [anon_sym___try] = ACTIONS(2280),
    [anon_sym___leave] = ACTIONS(2280),
    [anon_sym_not] = ACTIONS(2280),
    [anon_sym_compl] = ACTIONS(2280),
    [anon_sym_DASH_DASH] = ACTIONS(2282),
    [anon_sym_PLUS_PLUS] = ACTIONS(2282),
    [anon_sym_sizeof] = ACTIONS(2280),
    [anon_sym___alignof__] = ACTIONS(2280),
    [anon_sym___alignof] = ACTIONS(2280),
    [anon_sym__alignof] = ACTIONS(2280),
    [anon_sym_alignof] = ACTIONS(2280),
    [anon_sym__Alignof] = ACTIONS(2280),
    [anon_sym_offsetof] = ACTIONS(2280),
    [anon_sym__Generic] = ACTIONS(2280),
    [anon_sym_asm] = ACTIONS(2280),
    [anon_sym___asm__] = ACTIONS(2280),
    [sym_number_literal] = ACTIONS(2282),
    [anon_sym_L_SQUOTE] = ACTIONS(2282),
    [anon_sym_u_SQUOTE] = ACTIONS(2282),
    [anon_sym_U_SQUOTE] = ACTIONS(2282),
    [anon_sym_u8_SQUOTE] = ACTIONS(2282),
    [anon_sym_SQUOTE] = ACTIONS(2282),
    [anon_sym_L_DQUOTE] = ACTIONS(2282),
    [anon_sym_u_DQUOTE] = ACTIONS(2282),
    [anon_sym_U_DQUOTE] = ACTIONS(2282),
    [anon_sym_u8_DQUOTE] = ACTIONS(2282),
    [anon_sym_DQUOTE] = ACTIONS(2282),
    [sym_true] = ACTIONS(2280),
    [sym_false] = ACTIONS(2280),
    [anon_sym_NULL] = ACTIONS(2280),
    [anon_sym_nullptr] = ACTIONS(2280),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2280),
    [anon_sym_decltype] = ACTIONS(2280),
    [sym_virtual] = ACTIONS(2280),
    [anon_sym_explicit] = ACTIONS(2280),
    [anon_sym_typename] = ACTIONS(2280),
    [anon_sym_template] = ACTIONS(2280),
    [anon_sym_operator] = ACTIONS(2280),
    [anon_sym_try] = ACTIONS(2280),
    [anon_sym_delete] = ACTIONS(2280),
    [anon_sym_throw] = ACTIONS(2280),
    [anon_sym_namespace] = ACTIONS(2280),
    [anon_sym_using] = ACTIONS(2280),
    [anon_sym_static_assert] = ACTIONS(2280),
    [anon_sym_concept] = ACTIONS(2280),
    [anon_sym_co_return] = ACTIONS(2280),
    [anon_sym_co_yield] = ACTIONS(2280),
    [anon_sym_R_DQUOTE] = ACTIONS(2282),
    [anon_sym_LR_DQUOTE] = ACTIONS(2282),
    [anon_sym_uR_DQUOTE] = ACTIONS(2282),
    [anon_sym_UR_DQUOTE] = ACTIONS(2282),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2282),
    [anon_sym_co_await] = ACTIONS(2280),
    [anon_sym_new] = ACTIONS(2280),
    [anon_sym_requires] = ACTIONS(2280),
    [sym_this] = ACTIONS(2280),
    [anon_sym_discard] = ACTIONS(2280),
    [anon_sym_precise] = ACTIONS(2280),
    [anon_sym_shared] = ACTIONS(2280),
    [anon_sym_groupshared] = ACTIONS(2280),
    [anon_sym_uniform] = ACTIONS(2280),
    [anon_sym_row_major] = ACTIONS(2280),
    [anon_sym_column_major] = ACTIONS(2280),
    [anon_sym_globallycoherent] = ACTIONS(2280),
    [anon_sym_centroid] = ACTIONS(2280),
    [anon_sym_noperspective] = ACTIONS(2280),
    [anon_sym_nointerpolation] = ACTIONS(2280),
    [anon_sym_sample] = ACTIONS(2280),
    [anon_sym_linear] = ACTIONS(2280),
    [anon_sym_snorm] = ACTIONS(2280),
    [anon_sym_unorm] = ACTIONS(2280),
    [anon_sym_point] = ACTIONS(2280),
    [anon_sym_line] = ACTIONS(2280),
    [anon_sym_triangleadj] = ACTIONS(2280),
    [anon_sym_lineadj] = ACTIONS(2280),
    [anon_sym_triangle] = ACTIONS(2280),
    [anon_sym_cbuffer] = ACTIONS(2280),
  },
  [230] = {
    [sym_identifier] = ACTIONS(2284),
    [aux_sym_preproc_include_token1] = ACTIONS(2284),
    [aux_sym_preproc_def_token1] = ACTIONS(2284),
    [aux_sym_preproc_if_token1] = ACTIONS(2284),
    [aux_sym_preproc_if_token2] = ACTIONS(2284),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2284),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2284),
    [aux_sym_preproc_else_token1] = ACTIONS(2284),
    [aux_sym_preproc_elif_token1] = ACTIONS(2284),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2284),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2284),
    [sym_preproc_directive] = ACTIONS(2284),
    [anon_sym_LPAREN2] = ACTIONS(2286),
    [anon_sym_BANG] = ACTIONS(2286),
    [anon_sym_TILDE] = ACTIONS(2286),
    [anon_sym_DASH] = ACTIONS(2284),
    [anon_sym_PLUS] = ACTIONS(2284),
    [anon_sym_STAR] = ACTIONS(2286),
    [anon_sym_AMP_AMP] = ACTIONS(2286),
    [anon_sym_AMP] = ACTIONS(2284),
    [anon_sym_SEMI] = ACTIONS(2286),
    [anon_sym___extension__] = ACTIONS(2284),
    [anon_sym_typedef] = ACTIONS(2284),
    [anon_sym_in] = ACTIONS(2284),
    [anon_sym_out] = ACTIONS(2284),
    [anon_sym_inout] = ACTIONS(2284),
    [anon_sym_extern] = ACTIONS(2284),
    [anon_sym___attribute__] = ACTIONS(2284),
    [anon_sym_COLON_COLON] = ACTIONS(2286),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2286),
    [anon_sym___declspec] = ACTIONS(2284),
    [anon_sym___based] = ACTIONS(2284),
    [anon_sym___cdecl] = ACTIONS(2284),
    [anon_sym___clrcall] = ACTIONS(2284),
    [anon_sym___stdcall] = ACTIONS(2284),
    [anon_sym___fastcall] = ACTIONS(2284),
    [anon_sym___thiscall] = ACTIONS(2284),
    [anon_sym___vectorcall] = ACTIONS(2284),
    [anon_sym_LBRACE] = ACTIONS(2286),
    [anon_sym_signed] = ACTIONS(2284),
    [anon_sym_unsigned] = ACTIONS(2284),
    [anon_sym_long] = ACTIONS(2284),
    [anon_sym_short] = ACTIONS(2284),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [anon_sym_static] = ACTIONS(2284),
    [anon_sym_register] = ACTIONS(2284),
    [anon_sym_inline] = ACTIONS(2284),
    [anon_sym___inline] = ACTIONS(2284),
    [anon_sym___inline__] = ACTIONS(2284),
    [anon_sym___forceinline] = ACTIONS(2284),
    [anon_sym_thread_local] = ACTIONS(2284),
    [anon_sym___thread] = ACTIONS(2284),
    [anon_sym_const] = ACTIONS(2284),
    [anon_sym_constexpr] = ACTIONS(2284),
    [anon_sym_volatile] = ACTIONS(2284),
    [anon_sym_restrict] = ACTIONS(2284),
    [anon_sym___restrict__] = ACTIONS(2284),
    [anon_sym__Atomic] = ACTIONS(2284),
    [anon_sym__Noreturn] = ACTIONS(2284),
    [anon_sym_noreturn] = ACTIONS(2284),
    [anon_sym_mutable] = ACTIONS(2284),
    [anon_sym_constinit] = ACTIONS(2284),
    [anon_sym_consteval] = ACTIONS(2284),
    [anon_sym_alignas] = ACTIONS(2284),
    [anon_sym__Alignas] = ACTIONS(2284),
    [sym_primitive_type] = ACTIONS(2284),
    [anon_sym_enum] = ACTIONS(2284),
    [anon_sym_class] = ACTIONS(2284),
    [anon_sym_struct] = ACTIONS(2284),
    [anon_sym_union] = ACTIONS(2284),
    [anon_sym_if] = ACTIONS(2284),
    [anon_sym_else] = ACTIONS(2284),
    [anon_sym_switch] = ACTIONS(2284),
    [anon_sym_case] = ACTIONS(2284),
    [anon_sym_default] = ACTIONS(2284),
    [anon_sym_while] = ACTIONS(2284),
    [anon_sym_do] = ACTIONS(2284),
    [anon_sym_for] = ACTIONS(2284),
    [anon_sym_return] = ACTIONS(2284),
    [anon_sym_break] = ACTIONS(2284),
    [anon_sym_continue] = ACTIONS(2284),
    [anon_sym_goto] = ACTIONS(2284),
    [anon_sym___try] = ACTIONS(2284),
    [anon_sym___leave] = ACTIONS(2284),
    [anon_sym_not] = ACTIONS(2284),
    [anon_sym_compl] = ACTIONS(2284),
    [anon_sym_DASH_DASH] = ACTIONS(2286),
    [anon_sym_PLUS_PLUS] = ACTIONS(2286),
    [anon_sym_sizeof] = ACTIONS(2284),
    [anon_sym___alignof__] = ACTIONS(2284),
    [anon_sym___alignof] = ACTIONS(2284),
    [anon_sym__alignof] = ACTIONS(2284),
    [anon_sym_alignof] = ACTIONS(2284),
    [anon_sym__Alignof] = ACTIONS(2284),
    [anon_sym_offsetof] = ACTIONS(2284),
    [anon_sym__Generic] = ACTIONS(2284),
    [anon_sym_asm] = ACTIONS(2284),
    [anon_sym___asm__] = ACTIONS(2284),
    [sym_number_literal] = ACTIONS(2286),
    [anon_sym_L_SQUOTE] = ACTIONS(2286),
    [anon_sym_u_SQUOTE] = ACTIONS(2286),
    [anon_sym_U_SQUOTE] = ACTIONS(2286),
    [anon_sym_u8_SQUOTE] = ACTIONS(2286),
    [anon_sym_SQUOTE] = ACTIONS(2286),
    [anon_sym_L_DQUOTE] = ACTIONS(2286),
    [anon_sym_u_DQUOTE] = ACTIONS(2286),
    [anon_sym_U_DQUOTE] = ACTIONS(2286),
    [anon_sym_u8_DQUOTE] = ACTIONS(2286),
    [anon_sym_DQUOTE] = ACTIONS(2286),
    [sym_true] = ACTIONS(2284),
    [sym_false] = ACTIONS(2284),
    [anon_sym_NULL] = ACTIONS(2284),
    [anon_sym_nullptr] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2284),
    [anon_sym_decltype] = ACTIONS(2284),
    [sym_virtual] = ACTIONS(2284),
    [anon_sym_explicit] = ACTIONS(2284),
    [anon_sym_typename] = ACTIONS(2284),
    [anon_sym_template] = ACTIONS(2284),
    [anon_sym_operator] = ACTIONS(2284),
    [anon_sym_try] = ACTIONS(2284),
    [anon_sym_delete] = ACTIONS(2284),
    [anon_sym_throw] = ACTIONS(2284),
    [anon_sym_namespace] = ACTIONS(2284),
    [anon_sym_using] = ACTIONS(2284),
    [anon_sym_static_assert] = ACTIONS(2284),
    [anon_sym_concept] = ACTIONS(2284),
    [anon_sym_co_return] = ACTIONS(2284),
    [anon_sym_co_yield] = ACTIONS(2284),
    [anon_sym_R_DQUOTE] = ACTIONS(2286),
    [anon_sym_LR_DQUOTE] = ACTIONS(2286),
    [anon_sym_uR_DQUOTE] = ACTIONS(2286),
    [anon_sym_UR_DQUOTE] = ACTIONS(2286),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2286),
    [anon_sym_co_await] = ACTIONS(2284),
    [anon_sym_new] = ACTIONS(2284),
    [anon_sym_requires] = ACTIONS(2284),
    [sym_this] = ACTIONS(2284),
    [anon_sym_discard] = ACTIONS(2284),
    [anon_sym_precise] = ACTIONS(2284),
    [anon_sym_shared] = ACTIONS(2284),
    [anon_sym_groupshared] = ACTIONS(2284),
    [anon_sym_uniform] = ACTIONS(2284),
    [anon_sym_row_major] = ACTIONS(2284),
    [anon_sym_column_major] = ACTIONS(2284),
    [anon_sym_globallycoherent] = ACTIONS(2284),
    [anon_sym_centroid] = ACTIONS(2284),
    [anon_sym_noperspective] = ACTIONS(2284),
    [anon_sym_nointerpolation] = ACTIONS(2284),
    [anon_sym_sample] = ACTIONS(2284),
    [anon_sym_linear] = ACTIONS(2284),
    [anon_sym_snorm] = ACTIONS(2284),
    [anon_sym_unorm] = ACTIONS(2284),
    [anon_sym_point] = ACTIONS(2284),
    [anon_sym_line] = ACTIONS(2284),
    [anon_sym_triangleadj] = ACTIONS(2284),
    [anon_sym_lineadj] = ACTIONS(2284),
    [anon_sym_triangle] = ACTIONS(2284),
    [anon_sym_cbuffer] = ACTIONS(2284),
  },
  [231] = {
    [sym_identifier] = ACTIONS(2288),
    [aux_sym_preproc_include_token1] = ACTIONS(2288),
    [aux_sym_preproc_def_token1] = ACTIONS(2288),
    [aux_sym_preproc_if_token1] = ACTIONS(2288),
    [aux_sym_preproc_if_token2] = ACTIONS(2288),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2288),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2288),
    [aux_sym_preproc_else_token1] = ACTIONS(2288),
    [aux_sym_preproc_elif_token1] = ACTIONS(2288),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2288),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2288),
    [sym_preproc_directive] = ACTIONS(2288),
    [anon_sym_LPAREN2] = ACTIONS(2290),
    [anon_sym_BANG] = ACTIONS(2290),
    [anon_sym_TILDE] = ACTIONS(2290),
    [anon_sym_DASH] = ACTIONS(2288),
    [anon_sym_PLUS] = ACTIONS(2288),
    [anon_sym_STAR] = ACTIONS(2290),
    [anon_sym_AMP_AMP] = ACTIONS(2290),
    [anon_sym_AMP] = ACTIONS(2288),
    [anon_sym_SEMI] = ACTIONS(2290),
    [anon_sym___extension__] = ACTIONS(2288),
    [anon_sym_typedef] = ACTIONS(2288),
    [anon_sym_in] = ACTIONS(2288),
    [anon_sym_out] = ACTIONS(2288),
    [anon_sym_inout] = ACTIONS(2288),
    [anon_sym_extern] = ACTIONS(2288),
    [anon_sym___attribute__] = ACTIONS(2288),
    [anon_sym_COLON_COLON] = ACTIONS(2290),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2290),
    [anon_sym___declspec] = ACTIONS(2288),
    [anon_sym___based] = ACTIONS(2288),
    [anon_sym___cdecl] = ACTIONS(2288),
    [anon_sym___clrcall] = ACTIONS(2288),
    [anon_sym___stdcall] = ACTIONS(2288),
    [anon_sym___fastcall] = ACTIONS(2288),
    [anon_sym___thiscall] = ACTIONS(2288),
    [anon_sym___vectorcall] = ACTIONS(2288),
    [anon_sym_LBRACE] = ACTIONS(2290),
    [anon_sym_signed] = ACTIONS(2288),
    [anon_sym_unsigned] = ACTIONS(2288),
    [anon_sym_long] = ACTIONS(2288),
    [anon_sym_short] = ACTIONS(2288),
    [anon_sym_LBRACK] = ACTIONS(2288),
    [anon_sym_static] = ACTIONS(2288),
    [anon_sym_register] = ACTIONS(2288),
    [anon_sym_inline] = ACTIONS(2288),
    [anon_sym___inline] = ACTIONS(2288),
    [anon_sym___inline__] = ACTIONS(2288),
    [anon_sym___forceinline] = ACTIONS(2288),
    [anon_sym_thread_local] = ACTIONS(2288),
    [anon_sym___thread] = ACTIONS(2288),
    [anon_sym_const] = ACTIONS(2288),
    [anon_sym_constexpr] = ACTIONS(2288),
    [anon_sym_volatile] = ACTIONS(2288),
    [anon_sym_restrict] = ACTIONS(2288),
    [anon_sym___restrict__] = ACTIONS(2288),
    [anon_sym__Atomic] = ACTIONS(2288),
    [anon_sym__Noreturn] = ACTIONS(2288),
    [anon_sym_noreturn] = ACTIONS(2288),
    [anon_sym_mutable] = ACTIONS(2288),
    [anon_sym_constinit] = ACTIONS(2288),
    [anon_sym_consteval] = ACTIONS(2288),
    [anon_sym_alignas] = ACTIONS(2288),
    [anon_sym__Alignas] = ACTIONS(2288),
    [sym_primitive_type] = ACTIONS(2288),
    [anon_sym_enum] = ACTIONS(2288),
    [anon_sym_class] = ACTIONS(2288),
    [anon_sym_struct] = ACTIONS(2288),
    [anon_sym_union] = ACTIONS(2288),
    [anon_sym_if] = ACTIONS(2288),
    [anon_sym_else] = ACTIONS(2288),
    [anon_sym_switch] = ACTIONS(2288),
    [anon_sym_case] = ACTIONS(2288),
    [anon_sym_default] = ACTIONS(2288),
    [anon_sym_while] = ACTIONS(2288),
    [anon_sym_do] = ACTIONS(2288),
    [anon_sym_for] = ACTIONS(2288),
    [anon_sym_return] = ACTIONS(2288),
    [anon_sym_break] = ACTIONS(2288),
    [anon_sym_continue] = ACTIONS(2288),
    [anon_sym_goto] = ACTIONS(2288),
    [anon_sym___try] = ACTIONS(2288),
    [anon_sym___leave] = ACTIONS(2288),
    [anon_sym_not] = ACTIONS(2288),
    [anon_sym_compl] = ACTIONS(2288),
    [anon_sym_DASH_DASH] = ACTIONS(2290),
    [anon_sym_PLUS_PLUS] = ACTIONS(2290),
    [anon_sym_sizeof] = ACTIONS(2288),
    [anon_sym___alignof__] = ACTIONS(2288),
    [anon_sym___alignof] = ACTIONS(2288),
    [anon_sym__alignof] = ACTIONS(2288),
    [anon_sym_alignof] = ACTIONS(2288),
    [anon_sym__Alignof] = ACTIONS(2288),
    [anon_sym_offsetof] = ACTIONS(2288),
    [anon_sym__Generic] = ACTIONS(2288),
    [anon_sym_asm] = ACTIONS(2288),
    [anon_sym___asm__] = ACTIONS(2288),
    [sym_number_literal] = ACTIONS(2290),
    [anon_sym_L_SQUOTE] = ACTIONS(2290),
    [anon_sym_u_SQUOTE] = ACTIONS(2290),
    [anon_sym_U_SQUOTE] = ACTIONS(2290),
    [anon_sym_u8_SQUOTE] = ACTIONS(2290),
    [anon_sym_SQUOTE] = ACTIONS(2290),
    [anon_sym_L_DQUOTE] = ACTIONS(2290),
    [anon_sym_u_DQUOTE] = ACTIONS(2290),
    [anon_sym_U_DQUOTE] = ACTIONS(2290),
    [anon_sym_u8_DQUOTE] = ACTIONS(2290),
    [anon_sym_DQUOTE] = ACTIONS(2290),
    [sym_true] = ACTIONS(2288),
    [sym_false] = ACTIONS(2288),
    [anon_sym_NULL] = ACTIONS(2288),
    [anon_sym_nullptr] = ACTIONS(2288),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2288),
    [anon_sym_decltype] = ACTIONS(2288),
    [sym_virtual] = ACTIONS(2288),
    [anon_sym_explicit] = ACTIONS(2288),
    [anon_sym_typename] = ACTIONS(2288),
    [anon_sym_template] = ACTIONS(2288),
    [anon_sym_operator] = ACTIONS(2288),
    [anon_sym_try] = ACTIONS(2288),
    [anon_sym_delete] = ACTIONS(2288),
    [anon_sym_throw] = ACTIONS(2288),
    [anon_sym_namespace] = ACTIONS(2288),
    [anon_sym_using] = ACTIONS(2288),
    [anon_sym_static_assert] = ACTIONS(2288),
    [anon_sym_concept] = ACTIONS(2288),
    [anon_sym_co_return] = ACTIONS(2288),
    [anon_sym_co_yield] = ACTIONS(2288),
    [anon_sym_R_DQUOTE] = ACTIONS(2290),
    [anon_sym_LR_DQUOTE] = ACTIONS(2290),
    [anon_sym_uR_DQUOTE] = ACTIONS(2290),
    [anon_sym_UR_DQUOTE] = ACTIONS(2290),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2290),
    [anon_sym_co_await] = ACTIONS(2288),
    [anon_sym_new] = ACTIONS(2288),
    [anon_sym_requires] = ACTIONS(2288),
    [sym_this] = ACTIONS(2288),
    [anon_sym_discard] = ACTIONS(2288),
    [anon_sym_precise] = ACTIONS(2288),
    [anon_sym_shared] = ACTIONS(2288),
    [anon_sym_groupshared] = ACTIONS(2288),
    [anon_sym_uniform] = ACTIONS(2288),
    [anon_sym_row_major] = ACTIONS(2288),
    [anon_sym_column_major] = ACTIONS(2288),
    [anon_sym_globallycoherent] = ACTIONS(2288),
    [anon_sym_centroid] = ACTIONS(2288),
    [anon_sym_noperspective] = ACTIONS(2288),
    [anon_sym_nointerpolation] = ACTIONS(2288),
    [anon_sym_sample] = ACTIONS(2288),
    [anon_sym_linear] = ACTIONS(2288),
    [anon_sym_snorm] = ACTIONS(2288),
    [anon_sym_unorm] = ACTIONS(2288),
    [anon_sym_point] = ACTIONS(2288),
    [anon_sym_line] = ACTIONS(2288),
    [anon_sym_triangleadj] = ACTIONS(2288),
    [anon_sym_lineadj] = ACTIONS(2288),
    [anon_sym_triangle] = ACTIONS(2288),
    [anon_sym_cbuffer] = ACTIONS(2288),
  },
  [232] = {
    [sym_identifier] = ACTIONS(2292),
    [aux_sym_preproc_include_token1] = ACTIONS(2292),
    [aux_sym_preproc_def_token1] = ACTIONS(2292),
    [aux_sym_preproc_if_token1] = ACTIONS(2292),
    [aux_sym_preproc_if_token2] = ACTIONS(2292),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2292),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2292),
    [aux_sym_preproc_else_token1] = ACTIONS(2292),
    [aux_sym_preproc_elif_token1] = ACTIONS(2292),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2292),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2292),
    [sym_preproc_directive] = ACTIONS(2292),
    [anon_sym_LPAREN2] = ACTIONS(2294),
    [anon_sym_BANG] = ACTIONS(2294),
    [anon_sym_TILDE] = ACTIONS(2294),
    [anon_sym_DASH] = ACTIONS(2292),
    [anon_sym_PLUS] = ACTIONS(2292),
    [anon_sym_STAR] = ACTIONS(2294),
    [anon_sym_AMP_AMP] = ACTIONS(2294),
    [anon_sym_AMP] = ACTIONS(2292),
    [anon_sym_SEMI] = ACTIONS(2294),
    [anon_sym___extension__] = ACTIONS(2292),
    [anon_sym_typedef] = ACTIONS(2292),
    [anon_sym_in] = ACTIONS(2292),
    [anon_sym_out] = ACTIONS(2292),
    [anon_sym_inout] = ACTIONS(2292),
    [anon_sym_extern] = ACTIONS(2292),
    [anon_sym___attribute__] = ACTIONS(2292),
    [anon_sym_COLON_COLON] = ACTIONS(2294),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2294),
    [anon_sym___declspec] = ACTIONS(2292),
    [anon_sym___based] = ACTIONS(2292),
    [anon_sym___cdecl] = ACTIONS(2292),
    [anon_sym___clrcall] = ACTIONS(2292),
    [anon_sym___stdcall] = ACTIONS(2292),
    [anon_sym___fastcall] = ACTIONS(2292),
    [anon_sym___thiscall] = ACTIONS(2292),
    [anon_sym___vectorcall] = ACTIONS(2292),
    [anon_sym_LBRACE] = ACTIONS(2294),
    [anon_sym_signed] = ACTIONS(2292),
    [anon_sym_unsigned] = ACTIONS(2292),
    [anon_sym_long] = ACTIONS(2292),
    [anon_sym_short] = ACTIONS(2292),
    [anon_sym_LBRACK] = ACTIONS(2292),
    [anon_sym_static] = ACTIONS(2292),
    [anon_sym_register] = ACTIONS(2292),
    [anon_sym_inline] = ACTIONS(2292),
    [anon_sym___inline] = ACTIONS(2292),
    [anon_sym___inline__] = ACTIONS(2292),
    [anon_sym___forceinline] = ACTIONS(2292),
    [anon_sym_thread_local] = ACTIONS(2292),
    [anon_sym___thread] = ACTIONS(2292),
    [anon_sym_const] = ACTIONS(2292),
    [anon_sym_constexpr] = ACTIONS(2292),
    [anon_sym_volatile] = ACTIONS(2292),
    [anon_sym_restrict] = ACTIONS(2292),
    [anon_sym___restrict__] = ACTIONS(2292),
    [anon_sym__Atomic] = ACTIONS(2292),
    [anon_sym__Noreturn] = ACTIONS(2292),
    [anon_sym_noreturn] = ACTIONS(2292),
    [anon_sym_mutable] = ACTIONS(2292),
    [anon_sym_constinit] = ACTIONS(2292),
    [anon_sym_consteval] = ACTIONS(2292),
    [anon_sym_alignas] = ACTIONS(2292),
    [anon_sym__Alignas] = ACTIONS(2292),
    [sym_primitive_type] = ACTIONS(2292),
    [anon_sym_enum] = ACTIONS(2292),
    [anon_sym_class] = ACTIONS(2292),
    [anon_sym_struct] = ACTIONS(2292),
    [anon_sym_union] = ACTIONS(2292),
    [anon_sym_if] = ACTIONS(2292),
    [anon_sym_switch] = ACTIONS(2292),
    [anon_sym_case] = ACTIONS(2292),
    [anon_sym_default] = ACTIONS(2292),
    [anon_sym_while] = ACTIONS(2292),
    [anon_sym_do] = ACTIONS(2292),
    [anon_sym_for] = ACTIONS(2292),
    [anon_sym_return] = ACTIONS(2292),
    [anon_sym_break] = ACTIONS(2292),
    [anon_sym_continue] = ACTIONS(2292),
    [anon_sym_goto] = ACTIONS(2292),
    [anon_sym___try] = ACTIONS(2292),
    [anon_sym___leave] = ACTIONS(2292),
    [anon_sym_not] = ACTIONS(2292),
    [anon_sym_compl] = ACTIONS(2292),
    [anon_sym_DASH_DASH] = ACTIONS(2294),
    [anon_sym_PLUS_PLUS] = ACTIONS(2294),
    [anon_sym_sizeof] = ACTIONS(2292),
    [anon_sym___alignof__] = ACTIONS(2292),
    [anon_sym___alignof] = ACTIONS(2292),
    [anon_sym__alignof] = ACTIONS(2292),
    [anon_sym_alignof] = ACTIONS(2292),
    [anon_sym__Alignof] = ACTIONS(2292),
    [anon_sym_offsetof] = ACTIONS(2292),
    [anon_sym__Generic] = ACTIONS(2292),
    [anon_sym_asm] = ACTIONS(2292),
    [anon_sym___asm__] = ACTIONS(2292),
    [sym_number_literal] = ACTIONS(2294),
    [anon_sym_L_SQUOTE] = ACTIONS(2294),
    [anon_sym_u_SQUOTE] = ACTIONS(2294),
    [anon_sym_U_SQUOTE] = ACTIONS(2294),
    [anon_sym_u8_SQUOTE] = ACTIONS(2294),
    [anon_sym_SQUOTE] = ACTIONS(2294),
    [anon_sym_L_DQUOTE] = ACTIONS(2294),
    [anon_sym_u_DQUOTE] = ACTIONS(2294),
    [anon_sym_U_DQUOTE] = ACTIONS(2294),
    [anon_sym_u8_DQUOTE] = ACTIONS(2294),
    [anon_sym_DQUOTE] = ACTIONS(2294),
    [sym_true] = ACTIONS(2292),
    [sym_false] = ACTIONS(2292),
    [anon_sym_NULL] = ACTIONS(2292),
    [anon_sym_nullptr] = ACTIONS(2292),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2292),
    [anon_sym_decltype] = ACTIONS(2292),
    [sym_virtual] = ACTIONS(2292),
    [anon_sym_explicit] = ACTIONS(2292),
    [anon_sym_typename] = ACTIONS(2292),
    [anon_sym_template] = ACTIONS(2292),
    [anon_sym_operator] = ACTIONS(2292),
    [anon_sym_try] = ACTIONS(2292),
    [anon_sym_delete] = ACTIONS(2292),
    [anon_sym_throw] = ACTIONS(2292),
    [anon_sym_namespace] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(2292),
    [anon_sym_static_assert] = ACTIONS(2292),
    [anon_sym_concept] = ACTIONS(2292),
    [anon_sym_co_return] = ACTIONS(2292),
    [anon_sym_co_yield] = ACTIONS(2292),
    [anon_sym_R_DQUOTE] = ACTIONS(2294),
    [anon_sym_LR_DQUOTE] = ACTIONS(2294),
    [anon_sym_uR_DQUOTE] = ACTIONS(2294),
    [anon_sym_UR_DQUOTE] = ACTIONS(2294),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2294),
    [anon_sym_co_await] = ACTIONS(2292),
    [anon_sym_new] = ACTIONS(2292),
    [anon_sym_requires] = ACTIONS(2292),
    [sym_this] = ACTIONS(2292),
    [anon_sym_discard] = ACTIONS(2292),
    [anon_sym_precise] = ACTIONS(2292),
    [anon_sym_shared] = ACTIONS(2292),
    [anon_sym_groupshared] = ACTIONS(2292),
    [anon_sym_uniform] = ACTIONS(2292),
    [anon_sym_row_major] = ACTIONS(2292),
    [anon_sym_column_major] = ACTIONS(2292),
    [anon_sym_globallycoherent] = ACTIONS(2292),
    [anon_sym_centroid] = ACTIONS(2292),
    [anon_sym_noperspective] = ACTIONS(2292),
    [anon_sym_nointerpolation] = ACTIONS(2292),
    [anon_sym_sample] = ACTIONS(2292),
    [anon_sym_linear] = ACTIONS(2292),
    [anon_sym_snorm] = ACTIONS(2292),
    [anon_sym_unorm] = ACTIONS(2292),
    [anon_sym_point] = ACTIONS(2292),
    [anon_sym_line] = ACTIONS(2292),
    [anon_sym_triangleadj] = ACTIONS(2292),
    [anon_sym_lineadj] = ACTIONS(2292),
    [anon_sym_triangle] = ACTIONS(2292),
    [anon_sym_cbuffer] = ACTIONS(2292),
  },
  [233] = {
    [sym_identifier] = ACTIONS(2296),
    [aux_sym_preproc_include_token1] = ACTIONS(2296),
    [aux_sym_preproc_def_token1] = ACTIONS(2296),
    [aux_sym_preproc_if_token1] = ACTIONS(2296),
    [aux_sym_preproc_if_token2] = ACTIONS(2296),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2296),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2296),
    [aux_sym_preproc_else_token1] = ACTIONS(2296),
    [aux_sym_preproc_elif_token1] = ACTIONS(2296),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2296),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2296),
    [sym_preproc_directive] = ACTIONS(2296),
    [anon_sym_LPAREN2] = ACTIONS(2298),
    [anon_sym_BANG] = ACTIONS(2298),
    [anon_sym_TILDE] = ACTIONS(2298),
    [anon_sym_DASH] = ACTIONS(2296),
    [anon_sym_PLUS] = ACTIONS(2296),
    [anon_sym_STAR] = ACTIONS(2298),
    [anon_sym_AMP_AMP] = ACTIONS(2298),
    [anon_sym_AMP] = ACTIONS(2296),
    [anon_sym_SEMI] = ACTIONS(2298),
    [anon_sym___extension__] = ACTIONS(2296),
    [anon_sym_typedef] = ACTIONS(2296),
    [anon_sym_in] = ACTIONS(2296),
    [anon_sym_out] = ACTIONS(2296),
    [anon_sym_inout] = ACTIONS(2296),
    [anon_sym_extern] = ACTIONS(2296),
    [anon_sym___attribute__] = ACTIONS(2296),
    [anon_sym_COLON_COLON] = ACTIONS(2298),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2298),
    [anon_sym___declspec] = ACTIONS(2296),
    [anon_sym___based] = ACTIONS(2296),
    [anon_sym___cdecl] = ACTIONS(2296),
    [anon_sym___clrcall] = ACTIONS(2296),
    [anon_sym___stdcall] = ACTIONS(2296),
    [anon_sym___fastcall] = ACTIONS(2296),
    [anon_sym___thiscall] = ACTIONS(2296),
    [anon_sym___vectorcall] = ACTIONS(2296),
    [anon_sym_LBRACE] = ACTIONS(2298),
    [anon_sym_signed] = ACTIONS(2296),
    [anon_sym_unsigned] = ACTIONS(2296),
    [anon_sym_long] = ACTIONS(2296),
    [anon_sym_short] = ACTIONS(2296),
    [anon_sym_LBRACK] = ACTIONS(2296),
    [anon_sym_static] = ACTIONS(2296),
    [anon_sym_register] = ACTIONS(2296),
    [anon_sym_inline] = ACTIONS(2296),
    [anon_sym___inline] = ACTIONS(2296),
    [anon_sym___inline__] = ACTIONS(2296),
    [anon_sym___forceinline] = ACTIONS(2296),
    [anon_sym_thread_local] = ACTIONS(2296),
    [anon_sym___thread] = ACTIONS(2296),
    [anon_sym_const] = ACTIONS(2296),
    [anon_sym_constexpr] = ACTIONS(2296),
    [anon_sym_volatile] = ACTIONS(2296),
    [anon_sym_restrict] = ACTIONS(2296),
    [anon_sym___restrict__] = ACTIONS(2296),
    [anon_sym__Atomic] = ACTIONS(2296),
    [anon_sym__Noreturn] = ACTIONS(2296),
    [anon_sym_noreturn] = ACTIONS(2296),
    [anon_sym_mutable] = ACTIONS(2296),
    [anon_sym_constinit] = ACTIONS(2296),
    [anon_sym_consteval] = ACTIONS(2296),
    [anon_sym_alignas] = ACTIONS(2296),
    [anon_sym__Alignas] = ACTIONS(2296),
    [sym_primitive_type] = ACTIONS(2296),
    [anon_sym_enum] = ACTIONS(2296),
    [anon_sym_class] = ACTIONS(2296),
    [anon_sym_struct] = ACTIONS(2296),
    [anon_sym_union] = ACTIONS(2296),
    [anon_sym_if] = ACTIONS(2296),
    [anon_sym_switch] = ACTIONS(2296),
    [anon_sym_case] = ACTIONS(2296),
    [anon_sym_default] = ACTIONS(2296),
    [anon_sym_while] = ACTIONS(2296),
    [anon_sym_do] = ACTIONS(2296),
    [anon_sym_for] = ACTIONS(2296),
    [anon_sym_return] = ACTIONS(2296),
    [anon_sym_break] = ACTIONS(2296),
    [anon_sym_continue] = ACTIONS(2296),
    [anon_sym_goto] = ACTIONS(2296),
    [anon_sym___try] = ACTIONS(2296),
    [anon_sym___leave] = ACTIONS(2296),
    [anon_sym_not] = ACTIONS(2296),
    [anon_sym_compl] = ACTIONS(2296),
    [anon_sym_DASH_DASH] = ACTIONS(2298),
    [anon_sym_PLUS_PLUS] = ACTIONS(2298),
    [anon_sym_sizeof] = ACTIONS(2296),
    [anon_sym___alignof__] = ACTIONS(2296),
    [anon_sym___alignof] = ACTIONS(2296),
    [anon_sym__alignof] = ACTIONS(2296),
    [anon_sym_alignof] = ACTIONS(2296),
    [anon_sym__Alignof] = ACTIONS(2296),
    [anon_sym_offsetof] = ACTIONS(2296),
    [anon_sym__Generic] = ACTIONS(2296),
    [anon_sym_asm] = ACTIONS(2296),
    [anon_sym___asm__] = ACTIONS(2296),
    [sym_number_literal] = ACTIONS(2298),
    [anon_sym_L_SQUOTE] = ACTIONS(2298),
    [anon_sym_u_SQUOTE] = ACTIONS(2298),
    [anon_sym_U_SQUOTE] = ACTIONS(2298),
    [anon_sym_u8_SQUOTE] = ACTIONS(2298),
    [anon_sym_SQUOTE] = ACTIONS(2298),
    [anon_sym_L_DQUOTE] = ACTIONS(2298),
    [anon_sym_u_DQUOTE] = ACTIONS(2298),
    [anon_sym_U_DQUOTE] = ACTIONS(2298),
    [anon_sym_u8_DQUOTE] = ACTIONS(2298),
    [anon_sym_DQUOTE] = ACTIONS(2298),
    [sym_true] = ACTIONS(2296),
    [sym_false] = ACTIONS(2296),
    [anon_sym_NULL] = ACTIONS(2296),
    [anon_sym_nullptr] = ACTIONS(2296),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2296),
    [anon_sym_decltype] = ACTIONS(2296),
    [sym_virtual] = ACTIONS(2296),
    [anon_sym_explicit] = ACTIONS(2296),
    [anon_sym_typename] = ACTIONS(2296),
    [anon_sym_template] = ACTIONS(2296),
    [anon_sym_operator] = ACTIONS(2296),
    [anon_sym_try] = ACTIONS(2296),
    [anon_sym_delete] = ACTIONS(2296),
    [anon_sym_throw] = ACTIONS(2296),
    [anon_sym_namespace] = ACTIONS(2296),
    [anon_sym_using] = ACTIONS(2296),
    [anon_sym_static_assert] = ACTIONS(2296),
    [anon_sym_concept] = ACTIONS(2296),
    [anon_sym_co_return] = ACTIONS(2296),
    [anon_sym_co_yield] = ACTIONS(2296),
    [anon_sym_R_DQUOTE] = ACTIONS(2298),
    [anon_sym_LR_DQUOTE] = ACTIONS(2298),
    [anon_sym_uR_DQUOTE] = ACTIONS(2298),
    [anon_sym_UR_DQUOTE] = ACTIONS(2298),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2298),
    [anon_sym_co_await] = ACTIONS(2296),
    [anon_sym_new] = ACTIONS(2296),
    [anon_sym_requires] = ACTIONS(2296),
    [sym_this] = ACTIONS(2296),
    [anon_sym_discard] = ACTIONS(2296),
    [anon_sym_precise] = ACTIONS(2296),
    [anon_sym_shared] = ACTIONS(2296),
    [anon_sym_groupshared] = ACTIONS(2296),
    [anon_sym_uniform] = ACTIONS(2296),
    [anon_sym_row_major] = ACTIONS(2296),
    [anon_sym_column_major] = ACTIONS(2296),
    [anon_sym_globallycoherent] = ACTIONS(2296),
    [anon_sym_centroid] = ACTIONS(2296),
    [anon_sym_noperspective] = ACTIONS(2296),
    [anon_sym_nointerpolation] = ACTIONS(2296),
    [anon_sym_sample] = ACTIONS(2296),
    [anon_sym_linear] = ACTIONS(2296),
    [anon_sym_snorm] = ACTIONS(2296),
    [anon_sym_unorm] = ACTIONS(2296),
    [anon_sym_point] = ACTIONS(2296),
    [anon_sym_line] = ACTIONS(2296),
    [anon_sym_triangleadj] = ACTIONS(2296),
    [anon_sym_lineadj] = ACTIONS(2296),
    [anon_sym_triangle] = ACTIONS(2296),
    [anon_sym_cbuffer] = ACTIONS(2296),
  },
  [234] = {
    [sym_identifier] = ACTIONS(2300),
    [aux_sym_preproc_include_token1] = ACTIONS(2300),
    [aux_sym_preproc_def_token1] = ACTIONS(2300),
    [aux_sym_preproc_if_token1] = ACTIONS(2300),
    [aux_sym_preproc_if_token2] = ACTIONS(2300),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2300),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2300),
    [aux_sym_preproc_else_token1] = ACTIONS(2300),
    [aux_sym_preproc_elif_token1] = ACTIONS(2300),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2300),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2300),
    [sym_preproc_directive] = ACTIONS(2300),
    [anon_sym_LPAREN2] = ACTIONS(2302),
    [anon_sym_BANG] = ACTIONS(2302),
    [anon_sym_TILDE] = ACTIONS(2302),
    [anon_sym_DASH] = ACTIONS(2300),
    [anon_sym_PLUS] = ACTIONS(2300),
    [anon_sym_STAR] = ACTIONS(2302),
    [anon_sym_AMP_AMP] = ACTIONS(2302),
    [anon_sym_AMP] = ACTIONS(2300),
    [anon_sym_SEMI] = ACTIONS(2302),
    [anon_sym___extension__] = ACTIONS(2300),
    [anon_sym_typedef] = ACTIONS(2300),
    [anon_sym_in] = ACTIONS(2300),
    [anon_sym_out] = ACTIONS(2300),
    [anon_sym_inout] = ACTIONS(2300),
    [anon_sym_extern] = ACTIONS(2300),
    [anon_sym___attribute__] = ACTIONS(2300),
    [anon_sym_COLON_COLON] = ACTIONS(2302),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2302),
    [anon_sym___declspec] = ACTIONS(2300),
    [anon_sym___based] = ACTIONS(2300),
    [anon_sym___cdecl] = ACTIONS(2300),
    [anon_sym___clrcall] = ACTIONS(2300),
    [anon_sym___stdcall] = ACTIONS(2300),
    [anon_sym___fastcall] = ACTIONS(2300),
    [anon_sym___thiscall] = ACTIONS(2300),
    [anon_sym___vectorcall] = ACTIONS(2300),
    [anon_sym_LBRACE] = ACTIONS(2302),
    [anon_sym_signed] = ACTIONS(2300),
    [anon_sym_unsigned] = ACTIONS(2300),
    [anon_sym_long] = ACTIONS(2300),
    [anon_sym_short] = ACTIONS(2300),
    [anon_sym_LBRACK] = ACTIONS(2300),
    [anon_sym_static] = ACTIONS(2300),
    [anon_sym_register] = ACTIONS(2300),
    [anon_sym_inline] = ACTIONS(2300),
    [anon_sym___inline] = ACTIONS(2300),
    [anon_sym___inline__] = ACTIONS(2300),
    [anon_sym___forceinline] = ACTIONS(2300),
    [anon_sym_thread_local] = ACTIONS(2300),
    [anon_sym___thread] = ACTIONS(2300),
    [anon_sym_const] = ACTIONS(2300),
    [anon_sym_constexpr] = ACTIONS(2300),
    [anon_sym_volatile] = ACTIONS(2300),
    [anon_sym_restrict] = ACTIONS(2300),
    [anon_sym___restrict__] = ACTIONS(2300),
    [anon_sym__Atomic] = ACTIONS(2300),
    [anon_sym__Noreturn] = ACTIONS(2300),
    [anon_sym_noreturn] = ACTIONS(2300),
    [anon_sym_mutable] = ACTIONS(2300),
    [anon_sym_constinit] = ACTIONS(2300),
    [anon_sym_consteval] = ACTIONS(2300),
    [anon_sym_alignas] = ACTIONS(2300),
    [anon_sym__Alignas] = ACTIONS(2300),
    [sym_primitive_type] = ACTIONS(2300),
    [anon_sym_enum] = ACTIONS(2300),
    [anon_sym_class] = ACTIONS(2300),
    [anon_sym_struct] = ACTIONS(2300),
    [anon_sym_union] = ACTIONS(2300),
    [anon_sym_if] = ACTIONS(2300),
    [anon_sym_switch] = ACTIONS(2300),
    [anon_sym_case] = ACTIONS(2300),
    [anon_sym_default] = ACTIONS(2300),
    [anon_sym_while] = ACTIONS(2300),
    [anon_sym_do] = ACTIONS(2300),
    [anon_sym_for] = ACTIONS(2300),
    [anon_sym_return] = ACTIONS(2300),
    [anon_sym_break] = ACTIONS(2300),
    [anon_sym_continue] = ACTIONS(2300),
    [anon_sym_goto] = ACTIONS(2300),
    [anon_sym___try] = ACTIONS(2300),
    [anon_sym___leave] = ACTIONS(2300),
    [anon_sym_not] = ACTIONS(2300),
    [anon_sym_compl] = ACTIONS(2300),
    [anon_sym_DASH_DASH] = ACTIONS(2302),
    [anon_sym_PLUS_PLUS] = ACTIONS(2302),
    [anon_sym_sizeof] = ACTIONS(2300),
    [anon_sym___alignof__] = ACTIONS(2300),
    [anon_sym___alignof] = ACTIONS(2300),
    [anon_sym__alignof] = ACTIONS(2300),
    [anon_sym_alignof] = ACTIONS(2300),
    [anon_sym__Alignof] = ACTIONS(2300),
    [anon_sym_offsetof] = ACTIONS(2300),
    [anon_sym__Generic] = ACTIONS(2300),
    [anon_sym_asm] = ACTIONS(2300),
    [anon_sym___asm__] = ACTIONS(2300),
    [sym_number_literal] = ACTIONS(2302),
    [anon_sym_L_SQUOTE] = ACTIONS(2302),
    [anon_sym_u_SQUOTE] = ACTIONS(2302),
    [anon_sym_U_SQUOTE] = ACTIONS(2302),
    [anon_sym_u8_SQUOTE] = ACTIONS(2302),
    [anon_sym_SQUOTE] = ACTIONS(2302),
    [anon_sym_L_DQUOTE] = ACTIONS(2302),
    [anon_sym_u_DQUOTE] = ACTIONS(2302),
    [anon_sym_U_DQUOTE] = ACTIONS(2302),
    [anon_sym_u8_DQUOTE] = ACTIONS(2302),
    [anon_sym_DQUOTE] = ACTIONS(2302),
    [sym_true] = ACTIONS(2300),
    [sym_false] = ACTIONS(2300),
    [anon_sym_NULL] = ACTIONS(2300),
    [anon_sym_nullptr] = ACTIONS(2300),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2300),
    [anon_sym_decltype] = ACTIONS(2300),
    [sym_virtual] = ACTIONS(2300),
    [anon_sym_explicit] = ACTIONS(2300),
    [anon_sym_typename] = ACTIONS(2300),
    [anon_sym_template] = ACTIONS(2300),
    [anon_sym_operator] = ACTIONS(2300),
    [anon_sym_try] = ACTIONS(2300),
    [anon_sym_delete] = ACTIONS(2300),
    [anon_sym_throw] = ACTIONS(2300),
    [anon_sym_namespace] = ACTIONS(2300),
    [anon_sym_using] = ACTIONS(2300),
    [anon_sym_static_assert] = ACTIONS(2300),
    [anon_sym_concept] = ACTIONS(2300),
    [anon_sym_co_return] = ACTIONS(2300),
    [anon_sym_co_yield] = ACTIONS(2300),
    [anon_sym_R_DQUOTE] = ACTIONS(2302),
    [anon_sym_LR_DQUOTE] = ACTIONS(2302),
    [anon_sym_uR_DQUOTE] = ACTIONS(2302),
    [anon_sym_UR_DQUOTE] = ACTIONS(2302),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2302),
    [anon_sym_co_await] = ACTIONS(2300),
    [anon_sym_new] = ACTIONS(2300),
    [anon_sym_requires] = ACTIONS(2300),
    [sym_this] = ACTIONS(2300),
    [anon_sym_discard] = ACTIONS(2300),
    [anon_sym_precise] = ACTIONS(2300),
    [anon_sym_shared] = ACTIONS(2300),
    [anon_sym_groupshared] = ACTIONS(2300),
    [anon_sym_uniform] = ACTIONS(2300),
    [anon_sym_row_major] = ACTIONS(2300),
    [anon_sym_column_major] = ACTIONS(2300),
    [anon_sym_globallycoherent] = ACTIONS(2300),
    [anon_sym_centroid] = ACTIONS(2300),
    [anon_sym_noperspective] = ACTIONS(2300),
    [anon_sym_nointerpolation] = ACTIONS(2300),
    [anon_sym_sample] = ACTIONS(2300),
    [anon_sym_linear] = ACTIONS(2300),
    [anon_sym_snorm] = ACTIONS(2300),
    [anon_sym_unorm] = ACTIONS(2300),
    [anon_sym_point] = ACTIONS(2300),
    [anon_sym_line] = ACTIONS(2300),
    [anon_sym_triangleadj] = ACTIONS(2300),
    [anon_sym_lineadj] = ACTIONS(2300),
    [anon_sym_triangle] = ACTIONS(2300),
    [anon_sym_cbuffer] = ACTIONS(2300),
  },
  [235] = {
    [sym_identifier] = ACTIONS(2304),
    [aux_sym_preproc_include_token1] = ACTIONS(2304),
    [aux_sym_preproc_def_token1] = ACTIONS(2304),
    [aux_sym_preproc_if_token1] = ACTIONS(2304),
    [aux_sym_preproc_if_token2] = ACTIONS(2304),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2304),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2304),
    [aux_sym_preproc_else_token1] = ACTIONS(2304),
    [aux_sym_preproc_elif_token1] = ACTIONS(2304),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2304),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2304),
    [sym_preproc_directive] = ACTIONS(2304),
    [anon_sym_LPAREN2] = ACTIONS(2306),
    [anon_sym_BANG] = ACTIONS(2306),
    [anon_sym_TILDE] = ACTIONS(2306),
    [anon_sym_DASH] = ACTIONS(2304),
    [anon_sym_PLUS] = ACTIONS(2304),
    [anon_sym_STAR] = ACTIONS(2306),
    [anon_sym_AMP_AMP] = ACTIONS(2306),
    [anon_sym_AMP] = ACTIONS(2304),
    [anon_sym_SEMI] = ACTIONS(2306),
    [anon_sym___extension__] = ACTIONS(2304),
    [anon_sym_typedef] = ACTIONS(2304),
    [anon_sym_in] = ACTIONS(2304),
    [anon_sym_out] = ACTIONS(2304),
    [anon_sym_inout] = ACTIONS(2304),
    [anon_sym_extern] = ACTIONS(2304),
    [anon_sym___attribute__] = ACTIONS(2304),
    [anon_sym_COLON_COLON] = ACTIONS(2306),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2306),
    [anon_sym___declspec] = ACTIONS(2304),
    [anon_sym___based] = ACTIONS(2304),
    [anon_sym___cdecl] = ACTIONS(2304),
    [anon_sym___clrcall] = ACTIONS(2304),
    [anon_sym___stdcall] = ACTIONS(2304),
    [anon_sym___fastcall] = ACTIONS(2304),
    [anon_sym___thiscall] = ACTIONS(2304),
    [anon_sym___vectorcall] = ACTIONS(2304),
    [anon_sym_LBRACE] = ACTIONS(2306),
    [anon_sym_signed] = ACTIONS(2304),
    [anon_sym_unsigned] = ACTIONS(2304),
    [anon_sym_long] = ACTIONS(2304),
    [anon_sym_short] = ACTIONS(2304),
    [anon_sym_LBRACK] = ACTIONS(2304),
    [anon_sym_static] = ACTIONS(2304),
    [anon_sym_register] = ACTIONS(2304),
    [anon_sym_inline] = ACTIONS(2304),
    [anon_sym___inline] = ACTIONS(2304),
    [anon_sym___inline__] = ACTIONS(2304),
    [anon_sym___forceinline] = ACTIONS(2304),
    [anon_sym_thread_local] = ACTIONS(2304),
    [anon_sym___thread] = ACTIONS(2304),
    [anon_sym_const] = ACTIONS(2304),
    [anon_sym_constexpr] = ACTIONS(2304),
    [anon_sym_volatile] = ACTIONS(2304),
    [anon_sym_restrict] = ACTIONS(2304),
    [anon_sym___restrict__] = ACTIONS(2304),
    [anon_sym__Atomic] = ACTIONS(2304),
    [anon_sym__Noreturn] = ACTIONS(2304),
    [anon_sym_noreturn] = ACTIONS(2304),
    [anon_sym_mutable] = ACTIONS(2304),
    [anon_sym_constinit] = ACTIONS(2304),
    [anon_sym_consteval] = ACTIONS(2304),
    [anon_sym_alignas] = ACTIONS(2304),
    [anon_sym__Alignas] = ACTIONS(2304),
    [sym_primitive_type] = ACTIONS(2304),
    [anon_sym_enum] = ACTIONS(2304),
    [anon_sym_class] = ACTIONS(2304),
    [anon_sym_struct] = ACTIONS(2304),
    [anon_sym_union] = ACTIONS(2304),
    [anon_sym_if] = ACTIONS(2304),
    [anon_sym_switch] = ACTIONS(2304),
    [anon_sym_case] = ACTIONS(2304),
    [anon_sym_default] = ACTIONS(2304),
    [anon_sym_while] = ACTIONS(2304),
    [anon_sym_do] = ACTIONS(2304),
    [anon_sym_for] = ACTIONS(2304),
    [anon_sym_return] = ACTIONS(2304),
    [anon_sym_break] = ACTIONS(2304),
    [anon_sym_continue] = ACTIONS(2304),
    [anon_sym_goto] = ACTIONS(2304),
    [anon_sym___try] = ACTIONS(2304),
    [anon_sym___leave] = ACTIONS(2304),
    [anon_sym_not] = ACTIONS(2304),
    [anon_sym_compl] = ACTIONS(2304),
    [anon_sym_DASH_DASH] = ACTIONS(2306),
    [anon_sym_PLUS_PLUS] = ACTIONS(2306),
    [anon_sym_sizeof] = ACTIONS(2304),
    [anon_sym___alignof__] = ACTIONS(2304),
    [anon_sym___alignof] = ACTIONS(2304),
    [anon_sym__alignof] = ACTIONS(2304),
    [anon_sym_alignof] = ACTIONS(2304),
    [anon_sym__Alignof] = ACTIONS(2304),
    [anon_sym_offsetof] = ACTIONS(2304),
    [anon_sym__Generic] = ACTIONS(2304),
    [anon_sym_asm] = ACTIONS(2304),
    [anon_sym___asm__] = ACTIONS(2304),
    [sym_number_literal] = ACTIONS(2306),
    [anon_sym_L_SQUOTE] = ACTIONS(2306),
    [anon_sym_u_SQUOTE] = ACTIONS(2306),
    [anon_sym_U_SQUOTE] = ACTIONS(2306),
    [anon_sym_u8_SQUOTE] = ACTIONS(2306),
    [anon_sym_SQUOTE] = ACTIONS(2306),
    [anon_sym_L_DQUOTE] = ACTIONS(2306),
    [anon_sym_u_DQUOTE] = ACTIONS(2306),
    [anon_sym_U_DQUOTE] = ACTIONS(2306),
    [anon_sym_u8_DQUOTE] = ACTIONS(2306),
    [anon_sym_DQUOTE] = ACTIONS(2306),
    [sym_true] = ACTIONS(2304),
    [sym_false] = ACTIONS(2304),
    [anon_sym_NULL] = ACTIONS(2304),
    [anon_sym_nullptr] = ACTIONS(2304),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2304),
    [anon_sym_decltype] = ACTIONS(2304),
    [sym_virtual] = ACTIONS(2304),
    [anon_sym_explicit] = ACTIONS(2304),
    [anon_sym_typename] = ACTIONS(2304),
    [anon_sym_template] = ACTIONS(2304),
    [anon_sym_operator] = ACTIONS(2304),
    [anon_sym_try] = ACTIONS(2304),
    [anon_sym_delete] = ACTIONS(2304),
    [anon_sym_throw] = ACTIONS(2304),
    [anon_sym_namespace] = ACTIONS(2304),
    [anon_sym_using] = ACTIONS(2304),
    [anon_sym_static_assert] = ACTIONS(2304),
    [anon_sym_concept] = ACTIONS(2304),
    [anon_sym_co_return] = ACTIONS(2304),
    [anon_sym_co_yield] = ACTIONS(2304),
    [anon_sym_R_DQUOTE] = ACTIONS(2306),
    [anon_sym_LR_DQUOTE] = ACTIONS(2306),
    [anon_sym_uR_DQUOTE] = ACTIONS(2306),
    [anon_sym_UR_DQUOTE] = ACTIONS(2306),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2306),
    [anon_sym_co_await] = ACTIONS(2304),
    [anon_sym_new] = ACTIONS(2304),
    [anon_sym_requires] = ACTIONS(2304),
    [sym_this] = ACTIONS(2304),
    [anon_sym_discard] = ACTIONS(2304),
    [anon_sym_precise] = ACTIONS(2304),
    [anon_sym_shared] = ACTIONS(2304),
    [anon_sym_groupshared] = ACTIONS(2304),
    [anon_sym_uniform] = ACTIONS(2304),
    [anon_sym_row_major] = ACTIONS(2304),
    [anon_sym_column_major] = ACTIONS(2304),
    [anon_sym_globallycoherent] = ACTIONS(2304),
    [anon_sym_centroid] = ACTIONS(2304),
    [anon_sym_noperspective] = ACTIONS(2304),
    [anon_sym_nointerpolation] = ACTIONS(2304),
    [anon_sym_sample] = ACTIONS(2304),
    [anon_sym_linear] = ACTIONS(2304),
    [anon_sym_snorm] = ACTIONS(2304),
    [anon_sym_unorm] = ACTIONS(2304),
    [anon_sym_point] = ACTIONS(2304),
    [anon_sym_line] = ACTIONS(2304),
    [anon_sym_triangleadj] = ACTIONS(2304),
    [anon_sym_lineadj] = ACTIONS(2304),
    [anon_sym_triangle] = ACTIONS(2304),
    [anon_sym_cbuffer] = ACTIONS(2304),
  },
  [236] = {
    [sym_identifier] = ACTIONS(2308),
    [aux_sym_preproc_include_token1] = ACTIONS(2308),
    [aux_sym_preproc_def_token1] = ACTIONS(2308),
    [aux_sym_preproc_if_token1] = ACTIONS(2308),
    [aux_sym_preproc_if_token2] = ACTIONS(2308),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2308),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2308),
    [aux_sym_preproc_else_token1] = ACTIONS(2308),
    [aux_sym_preproc_elif_token1] = ACTIONS(2308),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2308),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2308),
    [sym_preproc_directive] = ACTIONS(2308),
    [anon_sym_LPAREN2] = ACTIONS(2310),
    [anon_sym_BANG] = ACTIONS(2310),
    [anon_sym_TILDE] = ACTIONS(2310),
    [anon_sym_DASH] = ACTIONS(2308),
    [anon_sym_PLUS] = ACTIONS(2308),
    [anon_sym_STAR] = ACTIONS(2310),
    [anon_sym_AMP_AMP] = ACTIONS(2310),
    [anon_sym_AMP] = ACTIONS(2308),
    [anon_sym_SEMI] = ACTIONS(2310),
    [anon_sym___extension__] = ACTIONS(2308),
    [anon_sym_typedef] = ACTIONS(2308),
    [anon_sym_in] = ACTIONS(2308),
    [anon_sym_out] = ACTIONS(2308),
    [anon_sym_inout] = ACTIONS(2308),
    [anon_sym_extern] = ACTIONS(2308),
    [anon_sym___attribute__] = ACTIONS(2308),
    [anon_sym_COLON_COLON] = ACTIONS(2310),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2310),
    [anon_sym___declspec] = ACTIONS(2308),
    [anon_sym___based] = ACTIONS(2308),
    [anon_sym___cdecl] = ACTIONS(2308),
    [anon_sym___clrcall] = ACTIONS(2308),
    [anon_sym___stdcall] = ACTIONS(2308),
    [anon_sym___fastcall] = ACTIONS(2308),
    [anon_sym___thiscall] = ACTIONS(2308),
    [anon_sym___vectorcall] = ACTIONS(2308),
    [anon_sym_LBRACE] = ACTIONS(2310),
    [anon_sym_signed] = ACTIONS(2308),
    [anon_sym_unsigned] = ACTIONS(2308),
    [anon_sym_long] = ACTIONS(2308),
    [anon_sym_short] = ACTIONS(2308),
    [anon_sym_LBRACK] = ACTIONS(2308),
    [anon_sym_static] = ACTIONS(2308),
    [anon_sym_register] = ACTIONS(2308),
    [anon_sym_inline] = ACTIONS(2308),
    [anon_sym___inline] = ACTIONS(2308),
    [anon_sym___inline__] = ACTIONS(2308),
    [anon_sym___forceinline] = ACTIONS(2308),
    [anon_sym_thread_local] = ACTIONS(2308),
    [anon_sym___thread] = ACTIONS(2308),
    [anon_sym_const] = ACTIONS(2308),
    [anon_sym_constexpr] = ACTIONS(2308),
    [anon_sym_volatile] = ACTIONS(2308),
    [anon_sym_restrict] = ACTIONS(2308),
    [anon_sym___restrict__] = ACTIONS(2308),
    [anon_sym__Atomic] = ACTIONS(2308),
    [anon_sym__Noreturn] = ACTIONS(2308),
    [anon_sym_noreturn] = ACTIONS(2308),
    [anon_sym_mutable] = ACTIONS(2308),
    [anon_sym_constinit] = ACTIONS(2308),
    [anon_sym_consteval] = ACTIONS(2308),
    [anon_sym_alignas] = ACTIONS(2308),
    [anon_sym__Alignas] = ACTIONS(2308),
    [sym_primitive_type] = ACTIONS(2308),
    [anon_sym_enum] = ACTIONS(2308),
    [anon_sym_class] = ACTIONS(2308),
    [anon_sym_struct] = ACTIONS(2308),
    [anon_sym_union] = ACTIONS(2308),
    [anon_sym_if] = ACTIONS(2308),
    [anon_sym_switch] = ACTIONS(2308),
    [anon_sym_case] = ACTIONS(2308),
    [anon_sym_default] = ACTIONS(2308),
    [anon_sym_while] = ACTIONS(2308),
    [anon_sym_do] = ACTIONS(2308),
    [anon_sym_for] = ACTIONS(2308),
    [anon_sym_return] = ACTIONS(2308),
    [anon_sym_break] = ACTIONS(2308),
    [anon_sym_continue] = ACTIONS(2308),
    [anon_sym_goto] = ACTIONS(2308),
    [anon_sym___try] = ACTIONS(2308),
    [anon_sym___leave] = ACTIONS(2308),
    [anon_sym_not] = ACTIONS(2308),
    [anon_sym_compl] = ACTIONS(2308),
    [anon_sym_DASH_DASH] = ACTIONS(2310),
    [anon_sym_PLUS_PLUS] = ACTIONS(2310),
    [anon_sym_sizeof] = ACTIONS(2308),
    [anon_sym___alignof__] = ACTIONS(2308),
    [anon_sym___alignof] = ACTIONS(2308),
    [anon_sym__alignof] = ACTIONS(2308),
    [anon_sym_alignof] = ACTIONS(2308),
    [anon_sym__Alignof] = ACTIONS(2308),
    [anon_sym_offsetof] = ACTIONS(2308),
    [anon_sym__Generic] = ACTIONS(2308),
    [anon_sym_asm] = ACTIONS(2308),
    [anon_sym___asm__] = ACTIONS(2308),
    [sym_number_literal] = ACTIONS(2310),
    [anon_sym_L_SQUOTE] = ACTIONS(2310),
    [anon_sym_u_SQUOTE] = ACTIONS(2310),
    [anon_sym_U_SQUOTE] = ACTIONS(2310),
    [anon_sym_u8_SQUOTE] = ACTIONS(2310),
    [anon_sym_SQUOTE] = ACTIONS(2310),
    [anon_sym_L_DQUOTE] = ACTIONS(2310),
    [anon_sym_u_DQUOTE] = ACTIONS(2310),
    [anon_sym_U_DQUOTE] = ACTIONS(2310),
    [anon_sym_u8_DQUOTE] = ACTIONS(2310),
    [anon_sym_DQUOTE] = ACTIONS(2310),
    [sym_true] = ACTIONS(2308),
    [sym_false] = ACTIONS(2308),
    [anon_sym_NULL] = ACTIONS(2308),
    [anon_sym_nullptr] = ACTIONS(2308),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2308),
    [anon_sym_decltype] = ACTIONS(2308),
    [sym_virtual] = ACTIONS(2308),
    [anon_sym_explicit] = ACTIONS(2308),
    [anon_sym_typename] = ACTIONS(2308),
    [anon_sym_template] = ACTIONS(2308),
    [anon_sym_operator] = ACTIONS(2308),
    [anon_sym_try] = ACTIONS(2308),
    [anon_sym_delete] = ACTIONS(2308),
    [anon_sym_throw] = ACTIONS(2308),
    [anon_sym_namespace] = ACTIONS(2308),
    [anon_sym_using] = ACTIONS(2308),
    [anon_sym_static_assert] = ACTIONS(2308),
    [anon_sym_concept] = ACTIONS(2308),
    [anon_sym_co_return] = ACTIONS(2308),
    [anon_sym_co_yield] = ACTIONS(2308),
    [anon_sym_R_DQUOTE] = ACTIONS(2310),
    [anon_sym_LR_DQUOTE] = ACTIONS(2310),
    [anon_sym_uR_DQUOTE] = ACTIONS(2310),
    [anon_sym_UR_DQUOTE] = ACTIONS(2310),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2310),
    [anon_sym_co_await] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(2308),
    [anon_sym_requires] = ACTIONS(2308),
    [sym_this] = ACTIONS(2308),
    [anon_sym_discard] = ACTIONS(2308),
    [anon_sym_precise] = ACTIONS(2308),
    [anon_sym_shared] = ACTIONS(2308),
    [anon_sym_groupshared] = ACTIONS(2308),
    [anon_sym_uniform] = ACTIONS(2308),
    [anon_sym_row_major] = ACTIONS(2308),
    [anon_sym_column_major] = ACTIONS(2308),
    [anon_sym_globallycoherent] = ACTIONS(2308),
    [anon_sym_centroid] = ACTIONS(2308),
    [anon_sym_noperspective] = ACTIONS(2308),
    [anon_sym_nointerpolation] = ACTIONS(2308),
    [anon_sym_sample] = ACTIONS(2308),
    [anon_sym_linear] = ACTIONS(2308),
    [anon_sym_snorm] = ACTIONS(2308),
    [anon_sym_unorm] = ACTIONS(2308),
    [anon_sym_point] = ACTIONS(2308),
    [anon_sym_line] = ACTIONS(2308),
    [anon_sym_triangleadj] = ACTIONS(2308),
    [anon_sym_lineadj] = ACTIONS(2308),
    [anon_sym_triangle] = ACTIONS(2308),
    [anon_sym_cbuffer] = ACTIONS(2308),
  },
  [237] = {
    [sym_identifier] = ACTIONS(2312),
    [aux_sym_preproc_include_token1] = ACTIONS(2312),
    [aux_sym_preproc_def_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token2] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2312),
    [aux_sym_preproc_else_token1] = ACTIONS(2312),
    [aux_sym_preproc_elif_token1] = ACTIONS(2312),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2312),
    [sym_preproc_directive] = ACTIONS(2312),
    [anon_sym_LPAREN2] = ACTIONS(2314),
    [anon_sym_BANG] = ACTIONS(2314),
    [anon_sym_TILDE] = ACTIONS(2314),
    [anon_sym_DASH] = ACTIONS(2312),
    [anon_sym_PLUS] = ACTIONS(2312),
    [anon_sym_STAR] = ACTIONS(2314),
    [anon_sym_AMP_AMP] = ACTIONS(2314),
    [anon_sym_AMP] = ACTIONS(2312),
    [anon_sym_SEMI] = ACTIONS(2314),
    [anon_sym___extension__] = ACTIONS(2312),
    [anon_sym_typedef] = ACTIONS(2312),
    [anon_sym_in] = ACTIONS(2312),
    [anon_sym_out] = ACTIONS(2312),
    [anon_sym_inout] = ACTIONS(2312),
    [anon_sym_extern] = ACTIONS(2312),
    [anon_sym___attribute__] = ACTIONS(2312),
    [anon_sym_COLON_COLON] = ACTIONS(2314),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2314),
    [anon_sym___declspec] = ACTIONS(2312),
    [anon_sym___based] = ACTIONS(2312),
    [anon_sym___cdecl] = ACTIONS(2312),
    [anon_sym___clrcall] = ACTIONS(2312),
    [anon_sym___stdcall] = ACTIONS(2312),
    [anon_sym___fastcall] = ACTIONS(2312),
    [anon_sym___thiscall] = ACTIONS(2312),
    [anon_sym___vectorcall] = ACTIONS(2312),
    [anon_sym_LBRACE] = ACTIONS(2314),
    [anon_sym_signed] = ACTIONS(2312),
    [anon_sym_unsigned] = ACTIONS(2312),
    [anon_sym_long] = ACTIONS(2312),
    [anon_sym_short] = ACTIONS(2312),
    [anon_sym_LBRACK] = ACTIONS(2312),
    [anon_sym_static] = ACTIONS(2312),
    [anon_sym_register] = ACTIONS(2312),
    [anon_sym_inline] = ACTIONS(2312),
    [anon_sym___inline] = ACTIONS(2312),
    [anon_sym___inline__] = ACTIONS(2312),
    [anon_sym___forceinline] = ACTIONS(2312),
    [anon_sym_thread_local] = ACTIONS(2312),
    [anon_sym___thread] = ACTIONS(2312),
    [anon_sym_const] = ACTIONS(2312),
    [anon_sym_constexpr] = ACTIONS(2312),
    [anon_sym_volatile] = ACTIONS(2312),
    [anon_sym_restrict] = ACTIONS(2312),
    [anon_sym___restrict__] = ACTIONS(2312),
    [anon_sym__Atomic] = ACTIONS(2312),
    [anon_sym__Noreturn] = ACTIONS(2312),
    [anon_sym_noreturn] = ACTIONS(2312),
    [anon_sym_mutable] = ACTIONS(2312),
    [anon_sym_constinit] = ACTIONS(2312),
    [anon_sym_consteval] = ACTIONS(2312),
    [anon_sym_alignas] = ACTIONS(2312),
    [anon_sym__Alignas] = ACTIONS(2312),
    [sym_primitive_type] = ACTIONS(2312),
    [anon_sym_enum] = ACTIONS(2312),
    [anon_sym_class] = ACTIONS(2312),
    [anon_sym_struct] = ACTIONS(2312),
    [anon_sym_union] = ACTIONS(2312),
    [anon_sym_if] = ACTIONS(2312),
    [anon_sym_switch] = ACTIONS(2312),
    [anon_sym_case] = ACTIONS(2312),
    [anon_sym_default] = ACTIONS(2312),
    [anon_sym_while] = ACTIONS(2312),
    [anon_sym_do] = ACTIONS(2312),
    [anon_sym_for] = ACTIONS(2312),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_break] = ACTIONS(2312),
    [anon_sym_continue] = ACTIONS(2312),
    [anon_sym_goto] = ACTIONS(2312),
    [anon_sym___try] = ACTIONS(2312),
    [anon_sym___leave] = ACTIONS(2312),
    [anon_sym_not] = ACTIONS(2312),
    [anon_sym_compl] = ACTIONS(2312),
    [anon_sym_DASH_DASH] = ACTIONS(2314),
    [anon_sym_PLUS_PLUS] = ACTIONS(2314),
    [anon_sym_sizeof] = ACTIONS(2312),
    [anon_sym___alignof__] = ACTIONS(2312),
    [anon_sym___alignof] = ACTIONS(2312),
    [anon_sym__alignof] = ACTIONS(2312),
    [anon_sym_alignof] = ACTIONS(2312),
    [anon_sym__Alignof] = ACTIONS(2312),
    [anon_sym_offsetof] = ACTIONS(2312),
    [anon_sym__Generic] = ACTIONS(2312),
    [anon_sym_asm] = ACTIONS(2312),
    [anon_sym___asm__] = ACTIONS(2312),
    [sym_number_literal] = ACTIONS(2314),
    [anon_sym_L_SQUOTE] = ACTIONS(2314),
    [anon_sym_u_SQUOTE] = ACTIONS(2314),
    [anon_sym_U_SQUOTE] = ACTIONS(2314),
    [anon_sym_u8_SQUOTE] = ACTIONS(2314),
    [anon_sym_SQUOTE] = ACTIONS(2314),
    [anon_sym_L_DQUOTE] = ACTIONS(2314),
    [anon_sym_u_DQUOTE] = ACTIONS(2314),
    [anon_sym_U_DQUOTE] = ACTIONS(2314),
    [anon_sym_u8_DQUOTE] = ACTIONS(2314),
    [anon_sym_DQUOTE] = ACTIONS(2314),
    [sym_true] = ACTIONS(2312),
    [sym_false] = ACTIONS(2312),
    [anon_sym_NULL] = ACTIONS(2312),
    [anon_sym_nullptr] = ACTIONS(2312),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2312),
    [anon_sym_decltype] = ACTIONS(2312),
    [sym_virtual] = ACTIONS(2312),
    [anon_sym_explicit] = ACTIONS(2312),
    [anon_sym_typename] = ACTIONS(2312),
    [anon_sym_template] = ACTIONS(2312),
    [anon_sym_operator] = ACTIONS(2312),
    [anon_sym_try] = ACTIONS(2312),
    [anon_sym_delete] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2312),
    [anon_sym_namespace] = ACTIONS(2312),
    [anon_sym_using] = ACTIONS(2312),
    [anon_sym_static_assert] = ACTIONS(2312),
    [anon_sym_concept] = ACTIONS(2312),
    [anon_sym_co_return] = ACTIONS(2312),
    [anon_sym_co_yield] = ACTIONS(2312),
    [anon_sym_R_DQUOTE] = ACTIONS(2314),
    [anon_sym_LR_DQUOTE] = ACTIONS(2314),
    [anon_sym_uR_DQUOTE] = ACTIONS(2314),
    [anon_sym_UR_DQUOTE] = ACTIONS(2314),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2314),
    [anon_sym_co_await] = ACTIONS(2312),
    [anon_sym_new] = ACTIONS(2312),
    [anon_sym_requires] = ACTIONS(2312),
    [sym_this] = ACTIONS(2312),
    [anon_sym_discard] = ACTIONS(2312),
    [anon_sym_precise] = ACTIONS(2312),
    [anon_sym_shared] = ACTIONS(2312),
    [anon_sym_groupshared] = ACTIONS(2312),
    [anon_sym_uniform] = ACTIONS(2312),
    [anon_sym_row_major] = ACTIONS(2312),
    [anon_sym_column_major] = ACTIONS(2312),
    [anon_sym_globallycoherent] = ACTIONS(2312),
    [anon_sym_centroid] = ACTIONS(2312),
    [anon_sym_noperspective] = ACTIONS(2312),
    [anon_sym_nointerpolation] = ACTIONS(2312),
    [anon_sym_sample] = ACTIONS(2312),
    [anon_sym_linear] = ACTIONS(2312),
    [anon_sym_snorm] = ACTIONS(2312),
    [anon_sym_unorm] = ACTIONS(2312),
    [anon_sym_point] = ACTIONS(2312),
    [anon_sym_line] = ACTIONS(2312),
    [anon_sym_triangleadj] = ACTIONS(2312),
    [anon_sym_lineadj] = ACTIONS(2312),
    [anon_sym_triangle] = ACTIONS(2312),
    [anon_sym_cbuffer] = ACTIONS(2312),
  },
  [238] = {
    [sym_identifier] = ACTIONS(2316),
    [aux_sym_preproc_include_token1] = ACTIONS(2316),
    [aux_sym_preproc_def_token1] = ACTIONS(2316),
    [aux_sym_preproc_if_token1] = ACTIONS(2316),
    [aux_sym_preproc_if_token2] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2316),
    [aux_sym_preproc_else_token1] = ACTIONS(2316),
    [aux_sym_preproc_elif_token1] = ACTIONS(2316),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2316),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2316),
    [sym_preproc_directive] = ACTIONS(2316),
    [anon_sym_LPAREN2] = ACTIONS(2318),
    [anon_sym_BANG] = ACTIONS(2318),
    [anon_sym_TILDE] = ACTIONS(2318),
    [anon_sym_DASH] = ACTIONS(2316),
    [anon_sym_PLUS] = ACTIONS(2316),
    [anon_sym_STAR] = ACTIONS(2318),
    [anon_sym_AMP_AMP] = ACTIONS(2318),
    [anon_sym_AMP] = ACTIONS(2316),
    [anon_sym_SEMI] = ACTIONS(2318),
    [anon_sym___extension__] = ACTIONS(2316),
    [anon_sym_typedef] = ACTIONS(2316),
    [anon_sym_in] = ACTIONS(2316),
    [anon_sym_out] = ACTIONS(2316),
    [anon_sym_inout] = ACTIONS(2316),
    [anon_sym_extern] = ACTIONS(2316),
    [anon_sym___attribute__] = ACTIONS(2316),
    [anon_sym_COLON_COLON] = ACTIONS(2318),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2318),
    [anon_sym___declspec] = ACTIONS(2316),
    [anon_sym___based] = ACTIONS(2316),
    [anon_sym___cdecl] = ACTIONS(2316),
    [anon_sym___clrcall] = ACTIONS(2316),
    [anon_sym___stdcall] = ACTIONS(2316),
    [anon_sym___fastcall] = ACTIONS(2316),
    [anon_sym___thiscall] = ACTIONS(2316),
    [anon_sym___vectorcall] = ACTIONS(2316),
    [anon_sym_LBRACE] = ACTIONS(2318),
    [anon_sym_signed] = ACTIONS(2316),
    [anon_sym_unsigned] = ACTIONS(2316),
    [anon_sym_long] = ACTIONS(2316),
    [anon_sym_short] = ACTIONS(2316),
    [anon_sym_LBRACK] = ACTIONS(2316),
    [anon_sym_static] = ACTIONS(2316),
    [anon_sym_register] = ACTIONS(2316),
    [anon_sym_inline] = ACTIONS(2316),
    [anon_sym___inline] = ACTIONS(2316),
    [anon_sym___inline__] = ACTIONS(2316),
    [anon_sym___forceinline] = ACTIONS(2316),
    [anon_sym_thread_local] = ACTIONS(2316),
    [anon_sym___thread] = ACTIONS(2316),
    [anon_sym_const] = ACTIONS(2316),
    [anon_sym_constexpr] = ACTIONS(2316),
    [anon_sym_volatile] = ACTIONS(2316),
    [anon_sym_restrict] = ACTIONS(2316),
    [anon_sym___restrict__] = ACTIONS(2316),
    [anon_sym__Atomic] = ACTIONS(2316),
    [anon_sym__Noreturn] = ACTIONS(2316),
    [anon_sym_noreturn] = ACTIONS(2316),
    [anon_sym_mutable] = ACTIONS(2316),
    [anon_sym_constinit] = ACTIONS(2316),
    [anon_sym_consteval] = ACTIONS(2316),
    [anon_sym_alignas] = ACTIONS(2316),
    [anon_sym__Alignas] = ACTIONS(2316),
    [sym_primitive_type] = ACTIONS(2316),
    [anon_sym_enum] = ACTIONS(2316),
    [anon_sym_class] = ACTIONS(2316),
    [anon_sym_struct] = ACTIONS(2316),
    [anon_sym_union] = ACTIONS(2316),
    [anon_sym_if] = ACTIONS(2316),
    [anon_sym_switch] = ACTIONS(2316),
    [anon_sym_case] = ACTIONS(2316),
    [anon_sym_default] = ACTIONS(2316),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2316),
    [anon_sym_return] = ACTIONS(2316),
    [anon_sym_break] = ACTIONS(2316),
    [anon_sym_continue] = ACTIONS(2316),
    [anon_sym_goto] = ACTIONS(2316),
    [anon_sym___try] = ACTIONS(2316),
    [anon_sym___leave] = ACTIONS(2316),
    [anon_sym_not] = ACTIONS(2316),
    [anon_sym_compl] = ACTIONS(2316),
    [anon_sym_DASH_DASH] = ACTIONS(2318),
    [anon_sym_PLUS_PLUS] = ACTIONS(2318),
    [anon_sym_sizeof] = ACTIONS(2316),
    [anon_sym___alignof__] = ACTIONS(2316),
    [anon_sym___alignof] = ACTIONS(2316),
    [anon_sym__alignof] = ACTIONS(2316),
    [anon_sym_alignof] = ACTIONS(2316),
    [anon_sym__Alignof] = ACTIONS(2316),
    [anon_sym_offsetof] = ACTIONS(2316),
    [anon_sym__Generic] = ACTIONS(2316),
    [anon_sym_asm] = ACTIONS(2316),
    [anon_sym___asm__] = ACTIONS(2316),
    [sym_number_literal] = ACTIONS(2318),
    [anon_sym_L_SQUOTE] = ACTIONS(2318),
    [anon_sym_u_SQUOTE] = ACTIONS(2318),
    [anon_sym_U_SQUOTE] = ACTIONS(2318),
    [anon_sym_u8_SQUOTE] = ACTIONS(2318),
    [anon_sym_SQUOTE] = ACTIONS(2318),
    [anon_sym_L_DQUOTE] = ACTIONS(2318),
    [anon_sym_u_DQUOTE] = ACTIONS(2318),
    [anon_sym_U_DQUOTE] = ACTIONS(2318),
    [anon_sym_u8_DQUOTE] = ACTIONS(2318),
    [anon_sym_DQUOTE] = ACTIONS(2318),
    [sym_true] = ACTIONS(2316),
    [sym_false] = ACTIONS(2316),
    [anon_sym_NULL] = ACTIONS(2316),
    [anon_sym_nullptr] = ACTIONS(2316),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2316),
    [anon_sym_decltype] = ACTIONS(2316),
    [sym_virtual] = ACTIONS(2316),
    [anon_sym_explicit] = ACTIONS(2316),
    [anon_sym_typename] = ACTIONS(2316),
    [anon_sym_template] = ACTIONS(2316),
    [anon_sym_operator] = ACTIONS(2316),
    [anon_sym_try] = ACTIONS(2316),
    [anon_sym_delete] = ACTIONS(2316),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_namespace] = ACTIONS(2316),
    [anon_sym_using] = ACTIONS(2316),
    [anon_sym_static_assert] = ACTIONS(2316),
    [anon_sym_concept] = ACTIONS(2316),
    [anon_sym_co_return] = ACTIONS(2316),
    [anon_sym_co_yield] = ACTIONS(2316),
    [anon_sym_R_DQUOTE] = ACTIONS(2318),
    [anon_sym_LR_DQUOTE] = ACTIONS(2318),
    [anon_sym_uR_DQUOTE] = ACTIONS(2318),
    [anon_sym_UR_DQUOTE] = ACTIONS(2318),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2318),
    [anon_sym_co_await] = ACTIONS(2316),
    [anon_sym_new] = ACTIONS(2316),
    [anon_sym_requires] = ACTIONS(2316),
    [sym_this] = ACTIONS(2316),
    [anon_sym_discard] = ACTIONS(2316),
    [anon_sym_precise] = ACTIONS(2316),
    [anon_sym_shared] = ACTIONS(2316),
    [anon_sym_groupshared] = ACTIONS(2316),
    [anon_sym_uniform] = ACTIONS(2316),
    [anon_sym_row_major] = ACTIONS(2316),
    [anon_sym_column_major] = ACTIONS(2316),
    [anon_sym_globallycoherent] = ACTIONS(2316),
    [anon_sym_centroid] = ACTIONS(2316),
    [anon_sym_noperspective] = ACTIONS(2316),
    [anon_sym_nointerpolation] = ACTIONS(2316),
    [anon_sym_sample] = ACTIONS(2316),
    [anon_sym_linear] = ACTIONS(2316),
    [anon_sym_snorm] = ACTIONS(2316),
    [anon_sym_unorm] = ACTIONS(2316),
    [anon_sym_point] = ACTIONS(2316),
    [anon_sym_line] = ACTIONS(2316),
    [anon_sym_triangleadj] = ACTIONS(2316),
    [anon_sym_lineadj] = ACTIONS(2316),
    [anon_sym_triangle] = ACTIONS(2316),
    [anon_sym_cbuffer] = ACTIONS(2316),
  },
  [239] = {
    [sym_identifier] = ACTIONS(1949),
    [aux_sym_preproc_include_token1] = ACTIONS(1949),
    [aux_sym_preproc_def_token1] = ACTIONS(1949),
    [aux_sym_preproc_if_token1] = ACTIONS(1949),
    [aux_sym_preproc_if_token2] = ACTIONS(1949),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1949),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1949),
    [sym_preproc_directive] = ACTIONS(1949),
    [anon_sym_LPAREN2] = ACTIONS(1951),
    [anon_sym_BANG] = ACTIONS(1951),
    [anon_sym_TILDE] = ACTIONS(1951),
    [anon_sym_DASH] = ACTIONS(1949),
    [anon_sym_PLUS] = ACTIONS(1949),
    [anon_sym_STAR] = ACTIONS(1951),
    [anon_sym_AMP_AMP] = ACTIONS(1951),
    [anon_sym_AMP] = ACTIONS(1949),
    [anon_sym_COLON] = ACTIONS(1949),
    [anon_sym_SEMI] = ACTIONS(1951),
    [anon_sym___extension__] = ACTIONS(1949),
    [anon_sym_typedef] = ACTIONS(1949),
    [anon_sym_in] = ACTIONS(1949),
    [anon_sym_out] = ACTIONS(1949),
    [anon_sym_inout] = ACTIONS(1949),
    [anon_sym_extern] = ACTIONS(1949),
    [anon_sym___attribute__] = ACTIONS(1949),
    [anon_sym_COLON_COLON] = ACTIONS(1951),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1951),
    [anon_sym___declspec] = ACTIONS(1949),
    [anon_sym___based] = ACTIONS(1949),
    [anon_sym___cdecl] = ACTIONS(1949),
    [anon_sym___clrcall] = ACTIONS(1949),
    [anon_sym___stdcall] = ACTIONS(1949),
    [anon_sym___fastcall] = ACTIONS(1949),
    [anon_sym___thiscall] = ACTIONS(1949),
    [anon_sym___vectorcall] = ACTIONS(1949),
    [anon_sym_LBRACE] = ACTIONS(1951),
    [anon_sym_signed] = ACTIONS(1949),
    [anon_sym_unsigned] = ACTIONS(1949),
    [anon_sym_long] = ACTIONS(1949),
    [anon_sym_short] = ACTIONS(1949),
    [anon_sym_LBRACK] = ACTIONS(1949),
    [anon_sym_static] = ACTIONS(1949),
    [anon_sym_register] = ACTIONS(1949),
    [anon_sym_inline] = ACTIONS(1949),
    [anon_sym___inline] = ACTIONS(1949),
    [anon_sym___inline__] = ACTIONS(1949),
    [anon_sym___forceinline] = ACTIONS(1949),
    [anon_sym_thread_local] = ACTIONS(1949),
    [anon_sym___thread] = ACTIONS(1949),
    [anon_sym_const] = ACTIONS(1949),
    [anon_sym_constexpr] = ACTIONS(1949),
    [anon_sym_volatile] = ACTIONS(1949),
    [anon_sym_restrict] = ACTIONS(1949),
    [anon_sym___restrict__] = ACTIONS(1949),
    [anon_sym__Atomic] = ACTIONS(1949),
    [anon_sym__Noreturn] = ACTIONS(1949),
    [anon_sym_noreturn] = ACTIONS(1949),
    [anon_sym_mutable] = ACTIONS(1949),
    [anon_sym_constinit] = ACTIONS(1949),
    [anon_sym_consteval] = ACTIONS(1949),
    [anon_sym_alignas] = ACTIONS(1949),
    [anon_sym__Alignas] = ACTIONS(1949),
    [sym_primitive_type] = ACTIONS(1949),
    [anon_sym_enum] = ACTIONS(1949),
    [anon_sym_class] = ACTIONS(1949),
    [anon_sym_struct] = ACTIONS(1949),
    [anon_sym_union] = ACTIONS(1949),
    [anon_sym_if] = ACTIONS(1949),
    [anon_sym_else] = ACTIONS(1949),
    [anon_sym_switch] = ACTIONS(1949),
    [anon_sym_case] = ACTIONS(1949),
    [anon_sym_default] = ACTIONS(1949),
    [anon_sym_while] = ACTIONS(1949),
    [anon_sym_do] = ACTIONS(1949),
    [anon_sym_for] = ACTIONS(1949),
    [anon_sym_return] = ACTIONS(1949),
    [anon_sym_break] = ACTIONS(1949),
    [anon_sym_continue] = ACTIONS(1949),
    [anon_sym_goto] = ACTIONS(1949),
    [anon_sym___try] = ACTIONS(1949),
    [anon_sym___leave] = ACTIONS(1949),
    [anon_sym_not] = ACTIONS(1949),
    [anon_sym_compl] = ACTIONS(1949),
    [anon_sym_DASH_DASH] = ACTIONS(1951),
    [anon_sym_PLUS_PLUS] = ACTIONS(1951),
    [anon_sym_sizeof] = ACTIONS(1949),
    [anon_sym___alignof__] = ACTIONS(1949),
    [anon_sym___alignof] = ACTIONS(1949),
    [anon_sym__alignof] = ACTIONS(1949),
    [anon_sym_alignof] = ACTIONS(1949),
    [anon_sym__Alignof] = ACTIONS(1949),
    [anon_sym_offsetof] = ACTIONS(1949),
    [anon_sym__Generic] = ACTIONS(1949),
    [anon_sym_asm] = ACTIONS(1949),
    [anon_sym___asm__] = ACTIONS(1949),
    [sym_number_literal] = ACTIONS(1951),
    [anon_sym_L_SQUOTE] = ACTIONS(1951),
    [anon_sym_u_SQUOTE] = ACTIONS(1951),
    [anon_sym_U_SQUOTE] = ACTIONS(1951),
    [anon_sym_u8_SQUOTE] = ACTIONS(1951),
    [anon_sym_SQUOTE] = ACTIONS(1951),
    [anon_sym_L_DQUOTE] = ACTIONS(1951),
    [anon_sym_u_DQUOTE] = ACTIONS(1951),
    [anon_sym_U_DQUOTE] = ACTIONS(1951),
    [anon_sym_u8_DQUOTE] = ACTIONS(1951),
    [anon_sym_DQUOTE] = ACTIONS(1951),
    [sym_true] = ACTIONS(1949),
    [sym_false] = ACTIONS(1949),
    [anon_sym_NULL] = ACTIONS(1949),
    [anon_sym_nullptr] = ACTIONS(1949),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1949),
    [anon_sym_decltype] = ACTIONS(1949),
    [anon_sym_final] = ACTIONS(1949),
    [anon_sym_override] = ACTIONS(1949),
    [sym_virtual] = ACTIONS(1949),
    [anon_sym_explicit] = ACTIONS(1949),
    [anon_sym_typename] = ACTIONS(1949),
    [anon_sym_template] = ACTIONS(1949),
    [anon_sym_operator] = ACTIONS(1949),
    [anon_sym_try] = ACTIONS(1949),
    [anon_sym_delete] = ACTIONS(1949),
    [anon_sym_throw] = ACTIONS(1949),
    [anon_sym_namespace] = ACTIONS(1949),
    [anon_sym_using] = ACTIONS(1949),
    [anon_sym_static_assert] = ACTIONS(1949),
    [anon_sym_concept] = ACTIONS(1949),
    [anon_sym_co_return] = ACTIONS(1949),
    [anon_sym_co_yield] = ACTIONS(1949),
    [anon_sym_R_DQUOTE] = ACTIONS(1951),
    [anon_sym_LR_DQUOTE] = ACTIONS(1951),
    [anon_sym_uR_DQUOTE] = ACTIONS(1951),
    [anon_sym_UR_DQUOTE] = ACTIONS(1951),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1951),
    [anon_sym_co_await] = ACTIONS(1949),
    [anon_sym_new] = ACTIONS(1949),
    [anon_sym_requires] = ACTIONS(1949),
    [sym_this] = ACTIONS(1949),
    [anon_sym_discard] = ACTIONS(1949),
    [anon_sym_precise] = ACTIONS(1949),
    [anon_sym_shared] = ACTIONS(1949),
    [anon_sym_groupshared] = ACTIONS(1949),
    [anon_sym_uniform] = ACTIONS(1949),
    [anon_sym_row_major] = ACTIONS(1949),
    [anon_sym_column_major] = ACTIONS(1949),
    [anon_sym_globallycoherent] = ACTIONS(1949),
    [anon_sym_centroid] = ACTIONS(1949),
    [anon_sym_noperspective] = ACTIONS(1949),
    [anon_sym_nointerpolation] = ACTIONS(1949),
    [anon_sym_sample] = ACTIONS(1949),
    [anon_sym_linear] = ACTIONS(1949),
    [anon_sym_snorm] = ACTIONS(1949),
    [anon_sym_unorm] = ACTIONS(1949),
    [anon_sym_point] = ACTIONS(1949),
    [anon_sym_line] = ACTIONS(1949),
    [anon_sym_triangleadj] = ACTIONS(1949),
    [anon_sym_lineadj] = ACTIONS(1949),
    [anon_sym_triangle] = ACTIONS(1949),
    [anon_sym_cbuffer] = ACTIONS(1949),
  },
  [240] = {
    [sym_identifier] = ACTIONS(2320),
    [aux_sym_preproc_include_token1] = ACTIONS(2320),
    [aux_sym_preproc_def_token1] = ACTIONS(2320),
    [aux_sym_preproc_if_token1] = ACTIONS(2320),
    [aux_sym_preproc_if_token2] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2320),
    [aux_sym_preproc_else_token1] = ACTIONS(2320),
    [aux_sym_preproc_elif_token1] = ACTIONS(2320),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2320),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2320),
    [sym_preproc_directive] = ACTIONS(2320),
    [anon_sym_LPAREN2] = ACTIONS(2322),
    [anon_sym_BANG] = ACTIONS(2322),
    [anon_sym_TILDE] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2322),
    [anon_sym_AMP_AMP] = ACTIONS(2322),
    [anon_sym_AMP] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym___extension__] = ACTIONS(2320),
    [anon_sym_typedef] = ACTIONS(2320),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_out] = ACTIONS(2320),
    [anon_sym_inout] = ACTIONS(2320),
    [anon_sym_extern] = ACTIONS(2320),
    [anon_sym___attribute__] = ACTIONS(2320),
    [anon_sym_COLON_COLON] = ACTIONS(2322),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2322),
    [anon_sym___declspec] = ACTIONS(2320),
    [anon_sym___based] = ACTIONS(2320),
    [anon_sym___cdecl] = ACTIONS(2320),
    [anon_sym___clrcall] = ACTIONS(2320),
    [anon_sym___stdcall] = ACTIONS(2320),
    [anon_sym___fastcall] = ACTIONS(2320),
    [anon_sym___thiscall] = ACTIONS(2320),
    [anon_sym___vectorcall] = ACTIONS(2320),
    [anon_sym_LBRACE] = ACTIONS(2322),
    [anon_sym_signed] = ACTIONS(2320),
    [anon_sym_unsigned] = ACTIONS(2320),
    [anon_sym_long] = ACTIONS(2320),
    [anon_sym_short] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2320),
    [anon_sym_static] = ACTIONS(2320),
    [anon_sym_register] = ACTIONS(2320),
    [anon_sym_inline] = ACTIONS(2320),
    [anon_sym___inline] = ACTIONS(2320),
    [anon_sym___inline__] = ACTIONS(2320),
    [anon_sym___forceinline] = ACTIONS(2320),
    [anon_sym_thread_local] = ACTIONS(2320),
    [anon_sym___thread] = ACTIONS(2320),
    [anon_sym_const] = ACTIONS(2320),
    [anon_sym_constexpr] = ACTIONS(2320),
    [anon_sym_volatile] = ACTIONS(2320),
    [anon_sym_restrict] = ACTIONS(2320),
    [anon_sym___restrict__] = ACTIONS(2320),
    [anon_sym__Atomic] = ACTIONS(2320),
    [anon_sym__Noreturn] = ACTIONS(2320),
    [anon_sym_noreturn] = ACTIONS(2320),
    [anon_sym_mutable] = ACTIONS(2320),
    [anon_sym_constinit] = ACTIONS(2320),
    [anon_sym_consteval] = ACTIONS(2320),
    [anon_sym_alignas] = ACTIONS(2320),
    [anon_sym__Alignas] = ACTIONS(2320),
    [sym_primitive_type] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_class] = ACTIONS(2320),
    [anon_sym_struct] = ACTIONS(2320),
    [anon_sym_union] = ACTIONS(2320),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_switch] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_default] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_do] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_return] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_goto] = ACTIONS(2320),
    [anon_sym___try] = ACTIONS(2320),
    [anon_sym___leave] = ACTIONS(2320),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_compl] = ACTIONS(2320),
    [anon_sym_DASH_DASH] = ACTIONS(2322),
    [anon_sym_PLUS_PLUS] = ACTIONS(2322),
    [anon_sym_sizeof] = ACTIONS(2320),
    [anon_sym___alignof__] = ACTIONS(2320),
    [anon_sym___alignof] = ACTIONS(2320),
    [anon_sym__alignof] = ACTIONS(2320),
    [anon_sym_alignof] = ACTIONS(2320),
    [anon_sym__Alignof] = ACTIONS(2320),
    [anon_sym_offsetof] = ACTIONS(2320),
    [anon_sym__Generic] = ACTIONS(2320),
    [anon_sym_asm] = ACTIONS(2320),
    [anon_sym___asm__] = ACTIONS(2320),
    [sym_number_literal] = ACTIONS(2322),
    [anon_sym_L_SQUOTE] = ACTIONS(2322),
    [anon_sym_u_SQUOTE] = ACTIONS(2322),
    [anon_sym_U_SQUOTE] = ACTIONS(2322),
    [anon_sym_u8_SQUOTE] = ACTIONS(2322),
    [anon_sym_SQUOTE] = ACTIONS(2322),
    [anon_sym_L_DQUOTE] = ACTIONS(2322),
    [anon_sym_u_DQUOTE] = ACTIONS(2322),
    [anon_sym_U_DQUOTE] = ACTIONS(2322),
    [anon_sym_u8_DQUOTE] = ACTIONS(2322),
    [anon_sym_DQUOTE] = ACTIONS(2322),
    [sym_true] = ACTIONS(2320),
    [sym_false] = ACTIONS(2320),
    [anon_sym_NULL] = ACTIONS(2320),
    [anon_sym_nullptr] = ACTIONS(2320),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2320),
    [anon_sym_decltype] = ACTIONS(2320),
    [sym_virtual] = ACTIONS(2320),
    [anon_sym_explicit] = ACTIONS(2320),
    [anon_sym_typename] = ACTIONS(2320),
    [anon_sym_template] = ACTIONS(2320),
    [anon_sym_operator] = ACTIONS(2320),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_delete] = ACTIONS(2320),
    [anon_sym_throw] = ACTIONS(2320),
    [anon_sym_namespace] = ACTIONS(2320),
    [anon_sym_using] = ACTIONS(2320),
    [anon_sym_static_assert] = ACTIONS(2320),
    [anon_sym_concept] = ACTIONS(2320),
    [anon_sym_co_return] = ACTIONS(2320),
    [anon_sym_co_yield] = ACTIONS(2320),
    [anon_sym_R_DQUOTE] = ACTIONS(2322),
    [anon_sym_LR_DQUOTE] = ACTIONS(2322),
    [anon_sym_uR_DQUOTE] = ACTIONS(2322),
    [anon_sym_UR_DQUOTE] = ACTIONS(2322),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2322),
    [anon_sym_co_await] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(2320),
    [anon_sym_requires] = ACTIONS(2320),
    [sym_this] = ACTIONS(2320),
    [anon_sym_discard] = ACTIONS(2320),
    [anon_sym_precise] = ACTIONS(2320),
    [anon_sym_shared] = ACTIONS(2320),
    [anon_sym_groupshared] = ACTIONS(2320),
    [anon_sym_uniform] = ACTIONS(2320),
    [anon_sym_row_major] = ACTIONS(2320),
    [anon_sym_column_major] = ACTIONS(2320),
    [anon_sym_globallycoherent] = ACTIONS(2320),
    [anon_sym_centroid] = ACTIONS(2320),
    [anon_sym_noperspective] = ACTIONS(2320),
    [anon_sym_nointerpolation] = ACTIONS(2320),
    [anon_sym_sample] = ACTIONS(2320),
    [anon_sym_linear] = ACTIONS(2320),
    [anon_sym_snorm] = ACTIONS(2320),
    [anon_sym_unorm] = ACTIONS(2320),
    [anon_sym_point] = ACTIONS(2320),
    [anon_sym_line] = ACTIONS(2320),
    [anon_sym_triangleadj] = ACTIONS(2320),
    [anon_sym_lineadj] = ACTIONS(2320),
    [anon_sym_triangle] = ACTIONS(2320),
    [anon_sym_cbuffer] = ACTIONS(2320),
  },
  [241] = {
    [sym_identifier] = ACTIONS(1953),
    [aux_sym_preproc_include_token1] = ACTIONS(1953),
    [aux_sym_preproc_def_token1] = ACTIONS(1953),
    [aux_sym_preproc_if_token1] = ACTIONS(1953),
    [aux_sym_preproc_if_token2] = ACTIONS(1953),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1953),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1953),
    [sym_preproc_directive] = ACTIONS(1953),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_BANG] = ACTIONS(1955),
    [anon_sym_TILDE] = ACTIONS(1955),
    [anon_sym_DASH] = ACTIONS(1953),
    [anon_sym_PLUS] = ACTIONS(1953),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym_COLON] = ACTIONS(1953),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym_typedef] = ACTIONS(1953),
    [anon_sym_in] = ACTIONS(1953),
    [anon_sym_out] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1953),
    [anon_sym_extern] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1955),
    [anon_sym___declspec] = ACTIONS(1953),
    [anon_sym___based] = ACTIONS(1953),
    [anon_sym___cdecl] = ACTIONS(1953),
    [anon_sym___clrcall] = ACTIONS(1953),
    [anon_sym___stdcall] = ACTIONS(1953),
    [anon_sym___fastcall] = ACTIONS(1953),
    [anon_sym___thiscall] = ACTIONS(1953),
    [anon_sym___vectorcall] = ACTIONS(1953),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_signed] = ACTIONS(1953),
    [anon_sym_unsigned] = ACTIONS(1953),
    [anon_sym_long] = ACTIONS(1953),
    [anon_sym_short] = ACTIONS(1953),
    [anon_sym_LBRACK] = ACTIONS(1953),
    [anon_sym_static] = ACTIONS(1953),
    [anon_sym_register] = ACTIONS(1953),
    [anon_sym_inline] = ACTIONS(1953),
    [anon_sym___inline] = ACTIONS(1953),
    [anon_sym___inline__] = ACTIONS(1953),
    [anon_sym___forceinline] = ACTIONS(1953),
    [anon_sym_thread_local] = ACTIONS(1953),
    [anon_sym___thread] = ACTIONS(1953),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [sym_primitive_type] = ACTIONS(1953),
    [anon_sym_enum] = ACTIONS(1953),
    [anon_sym_class] = ACTIONS(1953),
    [anon_sym_struct] = ACTIONS(1953),
    [anon_sym_union] = ACTIONS(1953),
    [anon_sym_if] = ACTIONS(1953),
    [anon_sym_else] = ACTIONS(1953),
    [anon_sym_switch] = ACTIONS(1953),
    [anon_sym_case] = ACTIONS(1953),
    [anon_sym_default] = ACTIONS(1953),
    [anon_sym_while] = ACTIONS(1953),
    [anon_sym_do] = ACTIONS(1953),
    [anon_sym_for] = ACTIONS(1953),
    [anon_sym_return] = ACTIONS(1953),
    [anon_sym_break] = ACTIONS(1953),
    [anon_sym_continue] = ACTIONS(1953),
    [anon_sym_goto] = ACTIONS(1953),
    [anon_sym___try] = ACTIONS(1953),
    [anon_sym___leave] = ACTIONS(1953),
    [anon_sym_not] = ACTIONS(1953),
    [anon_sym_compl] = ACTIONS(1953),
    [anon_sym_DASH_DASH] = ACTIONS(1955),
    [anon_sym_PLUS_PLUS] = ACTIONS(1955),
    [anon_sym_sizeof] = ACTIONS(1953),
    [anon_sym___alignof__] = ACTIONS(1953),
    [anon_sym___alignof] = ACTIONS(1953),
    [anon_sym__alignof] = ACTIONS(1953),
    [anon_sym_alignof] = ACTIONS(1953),
    [anon_sym__Alignof] = ACTIONS(1953),
    [anon_sym_offsetof] = ACTIONS(1953),
    [anon_sym__Generic] = ACTIONS(1953),
    [anon_sym_asm] = ACTIONS(1953),
    [anon_sym___asm__] = ACTIONS(1953),
    [sym_number_literal] = ACTIONS(1955),
    [anon_sym_L_SQUOTE] = ACTIONS(1955),
    [anon_sym_u_SQUOTE] = ACTIONS(1955),
    [anon_sym_U_SQUOTE] = ACTIONS(1955),
    [anon_sym_u8_SQUOTE] = ACTIONS(1955),
    [anon_sym_SQUOTE] = ACTIONS(1955),
    [anon_sym_L_DQUOTE] = ACTIONS(1955),
    [anon_sym_u_DQUOTE] = ACTIONS(1955),
    [anon_sym_U_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8_DQUOTE] = ACTIONS(1955),
    [anon_sym_DQUOTE] = ACTIONS(1955),
    [sym_true] = ACTIONS(1953),
    [sym_false] = ACTIONS(1953),
    [anon_sym_NULL] = ACTIONS(1953),
    [anon_sym_nullptr] = ACTIONS(1953),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
    [sym_virtual] = ACTIONS(1953),
    [anon_sym_explicit] = ACTIONS(1953),
    [anon_sym_typename] = ACTIONS(1953),
    [anon_sym_template] = ACTIONS(1953),
    [anon_sym_operator] = ACTIONS(1953),
    [anon_sym_try] = ACTIONS(1953),
    [anon_sym_delete] = ACTIONS(1953),
    [anon_sym_throw] = ACTIONS(1953),
    [anon_sym_namespace] = ACTIONS(1953),
    [anon_sym_using] = ACTIONS(1953),
    [anon_sym_static_assert] = ACTIONS(1953),
    [anon_sym_concept] = ACTIONS(1953),
    [anon_sym_co_return] = ACTIONS(1953),
    [anon_sym_co_yield] = ACTIONS(1953),
    [anon_sym_R_DQUOTE] = ACTIONS(1955),
    [anon_sym_LR_DQUOTE] = ACTIONS(1955),
    [anon_sym_uR_DQUOTE] = ACTIONS(1955),
    [anon_sym_UR_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1955),
    [anon_sym_co_await] = ACTIONS(1953),
    [anon_sym_new] = ACTIONS(1953),
    [anon_sym_requires] = ACTIONS(1953),
    [sym_this] = ACTIONS(1953),
    [anon_sym_discard] = ACTIONS(1953),
    [anon_sym_precise] = ACTIONS(1953),
    [anon_sym_shared] = ACTIONS(1953),
    [anon_sym_groupshared] = ACTIONS(1953),
    [anon_sym_uniform] = ACTIONS(1953),
    [anon_sym_row_major] = ACTIONS(1953),
    [anon_sym_column_major] = ACTIONS(1953),
    [anon_sym_globallycoherent] = ACTIONS(1953),
    [anon_sym_centroid] = ACTIONS(1953),
    [anon_sym_noperspective] = ACTIONS(1953),
    [anon_sym_nointerpolation] = ACTIONS(1953),
    [anon_sym_sample] = ACTIONS(1953),
    [anon_sym_linear] = ACTIONS(1953),
    [anon_sym_snorm] = ACTIONS(1953),
    [anon_sym_unorm] = ACTIONS(1953),
    [anon_sym_point] = ACTIONS(1953),
    [anon_sym_line] = ACTIONS(1953),
    [anon_sym_triangleadj] = ACTIONS(1953),
    [anon_sym_lineadj] = ACTIONS(1953),
    [anon_sym_triangle] = ACTIONS(1953),
    [anon_sym_cbuffer] = ACTIONS(1953),
  },
  [242] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_include_token1] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token2] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [aux_sym_preproc_else_token1] = ACTIONS(2324),
    [aux_sym_preproc_elif_token1] = ACTIONS(2324),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_BANG] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_DASH] = ACTIONS(2324),
    [anon_sym_PLUS] = ACTIONS(2324),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym_SEMI] = ACTIONS(2326),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym___cdecl] = ACTIONS(2324),
    [anon_sym___clrcall] = ACTIONS(2324),
    [anon_sym___stdcall] = ACTIONS(2324),
    [anon_sym___fastcall] = ACTIONS(2324),
    [anon_sym___thiscall] = ACTIONS(2324),
    [anon_sym___vectorcall] = ACTIONS(2324),
    [anon_sym_LBRACE] = ACTIONS(2326),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [anon_sym_if] = ACTIONS(2324),
    [anon_sym_switch] = ACTIONS(2324),
    [anon_sym_case] = ACTIONS(2324),
    [anon_sym_default] = ACTIONS(2324),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_do] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2324),
    [anon_sym_return] = ACTIONS(2324),
    [anon_sym_break] = ACTIONS(2324),
    [anon_sym_continue] = ACTIONS(2324),
    [anon_sym_goto] = ACTIONS(2324),
    [anon_sym___try] = ACTIONS(2324),
    [anon_sym___leave] = ACTIONS(2324),
    [anon_sym_not] = ACTIONS(2324),
    [anon_sym_compl] = ACTIONS(2324),
    [anon_sym_DASH_DASH] = ACTIONS(2326),
    [anon_sym_PLUS_PLUS] = ACTIONS(2326),
    [anon_sym_sizeof] = ACTIONS(2324),
    [anon_sym___alignof__] = ACTIONS(2324),
    [anon_sym___alignof] = ACTIONS(2324),
    [anon_sym__alignof] = ACTIONS(2324),
    [anon_sym_alignof] = ACTIONS(2324),
    [anon_sym__Alignof] = ACTIONS(2324),
    [anon_sym_offsetof] = ACTIONS(2324),
    [anon_sym__Generic] = ACTIONS(2324),
    [anon_sym_asm] = ACTIONS(2324),
    [anon_sym___asm__] = ACTIONS(2324),
    [sym_number_literal] = ACTIONS(2326),
    [anon_sym_L_SQUOTE] = ACTIONS(2326),
    [anon_sym_u_SQUOTE] = ACTIONS(2326),
    [anon_sym_U_SQUOTE] = ACTIONS(2326),
    [anon_sym_u8_SQUOTE] = ACTIONS(2326),
    [anon_sym_SQUOTE] = ACTIONS(2326),
    [anon_sym_L_DQUOTE] = ACTIONS(2326),
    [anon_sym_u_DQUOTE] = ACTIONS(2326),
    [anon_sym_U_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8_DQUOTE] = ACTIONS(2326),
    [anon_sym_DQUOTE] = ACTIONS(2326),
    [sym_true] = ACTIONS(2324),
    [sym_false] = ACTIONS(2324),
    [anon_sym_NULL] = ACTIONS(2324),
    [anon_sym_nullptr] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_try] = ACTIONS(2324),
    [anon_sym_delete] = ACTIONS(2324),
    [anon_sym_throw] = ACTIONS(2324),
    [anon_sym_namespace] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_concept] = ACTIONS(2324),
    [anon_sym_co_return] = ACTIONS(2324),
    [anon_sym_co_yield] = ACTIONS(2324),
    [anon_sym_R_DQUOTE] = ACTIONS(2326),
    [anon_sym_LR_DQUOTE] = ACTIONS(2326),
    [anon_sym_uR_DQUOTE] = ACTIONS(2326),
    [anon_sym_UR_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2326),
    [anon_sym_co_await] = ACTIONS(2324),
    [anon_sym_new] = ACTIONS(2324),
    [anon_sym_requires] = ACTIONS(2324),
    [sym_this] = ACTIONS(2324),
    [anon_sym_discard] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
    [anon_sym_cbuffer] = ACTIONS(2324),
  },
  [243] = {
    [sym_identifier] = ACTIONS(1969),
    [aux_sym_preproc_include_token1] = ACTIONS(1969),
    [aux_sym_preproc_def_token1] = ACTIONS(1969),
    [aux_sym_preproc_if_token1] = ACTIONS(1969),
    [aux_sym_preproc_if_token2] = ACTIONS(1969),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1969),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1969),
    [sym_preproc_directive] = ACTIONS(1969),
    [anon_sym_LPAREN2] = ACTIONS(1971),
    [anon_sym_BANG] = ACTIONS(1971),
    [anon_sym_TILDE] = ACTIONS(1971),
    [anon_sym_DASH] = ACTIONS(1969),
    [anon_sym_PLUS] = ACTIONS(1969),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_AMP_AMP] = ACTIONS(1971),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_COLON] = ACTIONS(1969),
    [anon_sym_SEMI] = ACTIONS(1971),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym_typedef] = ACTIONS(1969),
    [anon_sym_in] = ACTIONS(1969),
    [anon_sym_out] = ACTIONS(1969),
    [anon_sym_inout] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1971),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym___cdecl] = ACTIONS(1969),
    [anon_sym___clrcall] = ACTIONS(1969),
    [anon_sym___stdcall] = ACTIONS(1969),
    [anon_sym___fastcall] = ACTIONS(1969),
    [anon_sym___thiscall] = ACTIONS(1969),
    [anon_sym___vectorcall] = ACTIONS(1969),
    [anon_sym_LBRACE] = ACTIONS(1971),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1969),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [anon_sym_if] = ACTIONS(1969),
    [anon_sym_else] = ACTIONS(1969),
    [anon_sym_switch] = ACTIONS(1969),
    [anon_sym_case] = ACTIONS(1969),
    [anon_sym_default] = ACTIONS(1969),
    [anon_sym_while] = ACTIONS(1969),
    [anon_sym_do] = ACTIONS(1969),
    [anon_sym_for] = ACTIONS(1969),
    [anon_sym_return] = ACTIONS(1969),
    [anon_sym_break] = ACTIONS(1969),
    [anon_sym_continue] = ACTIONS(1969),
    [anon_sym_goto] = ACTIONS(1969),
    [anon_sym___try] = ACTIONS(1969),
    [anon_sym___leave] = ACTIONS(1969),
    [anon_sym_not] = ACTIONS(1969),
    [anon_sym_compl] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1971),
    [anon_sym_PLUS_PLUS] = ACTIONS(1971),
    [anon_sym_sizeof] = ACTIONS(1969),
    [anon_sym___alignof__] = ACTIONS(1969),
    [anon_sym___alignof] = ACTIONS(1969),
    [anon_sym__alignof] = ACTIONS(1969),
    [anon_sym_alignof] = ACTIONS(1969),
    [anon_sym__Alignof] = ACTIONS(1969),
    [anon_sym_offsetof] = ACTIONS(1969),
    [anon_sym__Generic] = ACTIONS(1969),
    [anon_sym_asm] = ACTIONS(1969),
    [anon_sym___asm__] = ACTIONS(1969),
    [sym_number_literal] = ACTIONS(1971),
    [anon_sym_L_SQUOTE] = ACTIONS(1971),
    [anon_sym_u_SQUOTE] = ACTIONS(1971),
    [anon_sym_U_SQUOTE] = ACTIONS(1971),
    [anon_sym_u8_SQUOTE] = ACTIONS(1971),
    [anon_sym_SQUOTE] = ACTIONS(1971),
    [anon_sym_L_DQUOTE] = ACTIONS(1971),
    [anon_sym_u_DQUOTE] = ACTIONS(1971),
    [anon_sym_U_DQUOTE] = ACTIONS(1971),
    [anon_sym_u8_DQUOTE] = ACTIONS(1971),
    [anon_sym_DQUOTE] = ACTIONS(1971),
    [sym_true] = ACTIONS(1969),
    [sym_false] = ACTIONS(1969),
    [anon_sym_NULL] = ACTIONS(1969),
    [anon_sym_nullptr] = ACTIONS(1969),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_final] = ACTIONS(1969),
    [anon_sym_override] = ACTIONS(1969),
    [sym_virtual] = ACTIONS(1969),
    [anon_sym_explicit] = ACTIONS(1969),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1969),
    [anon_sym_operator] = ACTIONS(1969),
    [anon_sym_try] = ACTIONS(1969),
    [anon_sym_delete] = ACTIONS(1969),
    [anon_sym_throw] = ACTIONS(1969),
    [anon_sym_namespace] = ACTIONS(1969),
    [anon_sym_using] = ACTIONS(1969),
    [anon_sym_static_assert] = ACTIONS(1969),
    [anon_sym_concept] = ACTIONS(1969),
    [anon_sym_co_return] = ACTIONS(1969),
    [anon_sym_co_yield] = ACTIONS(1969),
    [anon_sym_R_DQUOTE] = ACTIONS(1971),
    [anon_sym_LR_DQUOTE] = ACTIONS(1971),
    [anon_sym_uR_DQUOTE] = ACTIONS(1971),
    [anon_sym_UR_DQUOTE] = ACTIONS(1971),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1971),
    [anon_sym_co_await] = ACTIONS(1969),
    [anon_sym_new] = ACTIONS(1969),
    [anon_sym_requires] = ACTIONS(1969),
    [sym_this] = ACTIONS(1969),
    [anon_sym_discard] = ACTIONS(1969),
    [anon_sym_precise] = ACTIONS(1969),
    [anon_sym_shared] = ACTIONS(1969),
    [anon_sym_groupshared] = ACTIONS(1969),
    [anon_sym_uniform] = ACTIONS(1969),
    [anon_sym_row_major] = ACTIONS(1969),
    [anon_sym_column_major] = ACTIONS(1969),
    [anon_sym_globallycoherent] = ACTIONS(1969),
    [anon_sym_centroid] = ACTIONS(1969),
    [anon_sym_noperspective] = ACTIONS(1969),
    [anon_sym_nointerpolation] = ACTIONS(1969),
    [anon_sym_sample] = ACTIONS(1969),
    [anon_sym_linear] = ACTIONS(1969),
    [anon_sym_snorm] = ACTIONS(1969),
    [anon_sym_unorm] = ACTIONS(1969),
    [anon_sym_point] = ACTIONS(1969),
    [anon_sym_line] = ACTIONS(1969),
    [anon_sym_triangleadj] = ACTIONS(1969),
    [anon_sym_lineadj] = ACTIONS(1969),
    [anon_sym_triangle] = ACTIONS(1969),
    [anon_sym_cbuffer] = ACTIONS(1969),
  },
  [244] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_include_token1] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token2] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [aux_sym_preproc_else_token1] = ACTIONS(2324),
    [aux_sym_preproc_elif_token1] = ACTIONS(2324),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_BANG] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_DASH] = ACTIONS(2324),
    [anon_sym_PLUS] = ACTIONS(2324),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym_SEMI] = ACTIONS(2326),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym___cdecl] = ACTIONS(2324),
    [anon_sym___clrcall] = ACTIONS(2324),
    [anon_sym___stdcall] = ACTIONS(2324),
    [anon_sym___fastcall] = ACTIONS(2324),
    [anon_sym___thiscall] = ACTIONS(2324),
    [anon_sym___vectorcall] = ACTIONS(2324),
    [anon_sym_LBRACE] = ACTIONS(2326),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [anon_sym_if] = ACTIONS(2324),
    [anon_sym_switch] = ACTIONS(2324),
    [anon_sym_case] = ACTIONS(2324),
    [anon_sym_default] = ACTIONS(2324),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_do] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2324),
    [anon_sym_return] = ACTIONS(2324),
    [anon_sym_break] = ACTIONS(2324),
    [anon_sym_continue] = ACTIONS(2324),
    [anon_sym_goto] = ACTIONS(2324),
    [anon_sym___try] = ACTIONS(2324),
    [anon_sym___leave] = ACTIONS(2324),
    [anon_sym_not] = ACTIONS(2324),
    [anon_sym_compl] = ACTIONS(2324),
    [anon_sym_DASH_DASH] = ACTIONS(2326),
    [anon_sym_PLUS_PLUS] = ACTIONS(2326),
    [anon_sym_sizeof] = ACTIONS(2324),
    [anon_sym___alignof__] = ACTIONS(2324),
    [anon_sym___alignof] = ACTIONS(2324),
    [anon_sym__alignof] = ACTIONS(2324),
    [anon_sym_alignof] = ACTIONS(2324),
    [anon_sym__Alignof] = ACTIONS(2324),
    [anon_sym_offsetof] = ACTIONS(2324),
    [anon_sym__Generic] = ACTIONS(2324),
    [anon_sym_asm] = ACTIONS(2324),
    [anon_sym___asm__] = ACTIONS(2324),
    [sym_number_literal] = ACTIONS(2326),
    [anon_sym_L_SQUOTE] = ACTIONS(2326),
    [anon_sym_u_SQUOTE] = ACTIONS(2326),
    [anon_sym_U_SQUOTE] = ACTIONS(2326),
    [anon_sym_u8_SQUOTE] = ACTIONS(2326),
    [anon_sym_SQUOTE] = ACTIONS(2326),
    [anon_sym_L_DQUOTE] = ACTIONS(2326),
    [anon_sym_u_DQUOTE] = ACTIONS(2326),
    [anon_sym_U_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8_DQUOTE] = ACTIONS(2326),
    [anon_sym_DQUOTE] = ACTIONS(2326),
    [sym_true] = ACTIONS(2324),
    [sym_false] = ACTIONS(2324),
    [anon_sym_NULL] = ACTIONS(2324),
    [anon_sym_nullptr] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_try] = ACTIONS(2324),
    [anon_sym_delete] = ACTIONS(2324),
    [anon_sym_throw] = ACTIONS(2324),
    [anon_sym_namespace] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_concept] = ACTIONS(2324),
    [anon_sym_co_return] = ACTIONS(2324),
    [anon_sym_co_yield] = ACTIONS(2324),
    [anon_sym_R_DQUOTE] = ACTIONS(2326),
    [anon_sym_LR_DQUOTE] = ACTIONS(2326),
    [anon_sym_uR_DQUOTE] = ACTIONS(2326),
    [anon_sym_UR_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2326),
    [anon_sym_co_await] = ACTIONS(2324),
    [anon_sym_new] = ACTIONS(2324),
    [anon_sym_requires] = ACTIONS(2324),
    [sym_this] = ACTIONS(2324),
    [anon_sym_discard] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
    [anon_sym_cbuffer] = ACTIONS(2324),
  },
  [245] = {
    [sym_identifier] = ACTIONS(2328),
    [aux_sym_preproc_include_token1] = ACTIONS(2328),
    [aux_sym_preproc_def_token1] = ACTIONS(2328),
    [aux_sym_preproc_if_token1] = ACTIONS(2328),
    [aux_sym_preproc_if_token2] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2328),
    [aux_sym_preproc_else_token1] = ACTIONS(2328),
    [aux_sym_preproc_elif_token1] = ACTIONS(2328),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2328),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2328),
    [sym_preproc_directive] = ACTIONS(2328),
    [anon_sym_LPAREN2] = ACTIONS(2330),
    [anon_sym_BANG] = ACTIONS(2330),
    [anon_sym_TILDE] = ACTIONS(2330),
    [anon_sym_DASH] = ACTIONS(2328),
    [anon_sym_PLUS] = ACTIONS(2328),
    [anon_sym_STAR] = ACTIONS(2330),
    [anon_sym_AMP_AMP] = ACTIONS(2330),
    [anon_sym_AMP] = ACTIONS(2328),
    [anon_sym_SEMI] = ACTIONS(2330),
    [anon_sym___extension__] = ACTIONS(2328),
    [anon_sym_typedef] = ACTIONS(2328),
    [anon_sym_in] = ACTIONS(2328),
    [anon_sym_out] = ACTIONS(2328),
    [anon_sym_inout] = ACTIONS(2328),
    [anon_sym_extern] = ACTIONS(2328),
    [anon_sym___attribute__] = ACTIONS(2328),
    [anon_sym_COLON_COLON] = ACTIONS(2330),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2330),
    [anon_sym___declspec] = ACTIONS(2328),
    [anon_sym___based] = ACTIONS(2328),
    [anon_sym___cdecl] = ACTIONS(2328),
    [anon_sym___clrcall] = ACTIONS(2328),
    [anon_sym___stdcall] = ACTIONS(2328),
    [anon_sym___fastcall] = ACTIONS(2328),
    [anon_sym___thiscall] = ACTIONS(2328),
    [anon_sym___vectorcall] = ACTIONS(2328),
    [anon_sym_LBRACE] = ACTIONS(2330),
    [anon_sym_signed] = ACTIONS(2328),
    [anon_sym_unsigned] = ACTIONS(2328),
    [anon_sym_long] = ACTIONS(2328),
    [anon_sym_short] = ACTIONS(2328),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_static] = ACTIONS(2328),
    [anon_sym_register] = ACTIONS(2328),
    [anon_sym_inline] = ACTIONS(2328),
    [anon_sym___inline] = ACTIONS(2328),
    [anon_sym___inline__] = ACTIONS(2328),
    [anon_sym___forceinline] = ACTIONS(2328),
    [anon_sym_thread_local] = ACTIONS(2328),
    [anon_sym___thread] = ACTIONS(2328),
    [anon_sym_const] = ACTIONS(2328),
    [anon_sym_constexpr] = ACTIONS(2328),
    [anon_sym_volatile] = ACTIONS(2328),
    [anon_sym_restrict] = ACTIONS(2328),
    [anon_sym___restrict__] = ACTIONS(2328),
    [anon_sym__Atomic] = ACTIONS(2328),
    [anon_sym__Noreturn] = ACTIONS(2328),
    [anon_sym_noreturn] = ACTIONS(2328),
    [anon_sym_mutable] = ACTIONS(2328),
    [anon_sym_constinit] = ACTIONS(2328),
    [anon_sym_consteval] = ACTIONS(2328),
    [anon_sym_alignas] = ACTIONS(2328),
    [anon_sym__Alignas] = ACTIONS(2328),
    [sym_primitive_type] = ACTIONS(2328),
    [anon_sym_enum] = ACTIONS(2328),
    [anon_sym_class] = ACTIONS(2328),
    [anon_sym_struct] = ACTIONS(2328),
    [anon_sym_union] = ACTIONS(2328),
    [anon_sym_if] = ACTIONS(2328),
    [anon_sym_switch] = ACTIONS(2328),
    [anon_sym_case] = ACTIONS(2328),
    [anon_sym_default] = ACTIONS(2328),
    [anon_sym_while] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(2328),
    [anon_sym_for] = ACTIONS(2328),
    [anon_sym_return] = ACTIONS(2328),
    [anon_sym_break] = ACTIONS(2328),
    [anon_sym_continue] = ACTIONS(2328),
    [anon_sym_goto] = ACTIONS(2328),
    [anon_sym___try] = ACTIONS(2328),
    [anon_sym___leave] = ACTIONS(2328),
    [anon_sym_not] = ACTIONS(2328),
    [anon_sym_compl] = ACTIONS(2328),
    [anon_sym_DASH_DASH] = ACTIONS(2330),
    [anon_sym_PLUS_PLUS] = ACTIONS(2330),
    [anon_sym_sizeof] = ACTIONS(2328),
    [anon_sym___alignof__] = ACTIONS(2328),
    [anon_sym___alignof] = ACTIONS(2328),
    [anon_sym__alignof] = ACTIONS(2328),
    [anon_sym_alignof] = ACTIONS(2328),
    [anon_sym__Alignof] = ACTIONS(2328),
    [anon_sym_offsetof] = ACTIONS(2328),
    [anon_sym__Generic] = ACTIONS(2328),
    [anon_sym_asm] = ACTIONS(2328),
    [anon_sym___asm__] = ACTIONS(2328),
    [sym_number_literal] = ACTIONS(2330),
    [anon_sym_L_SQUOTE] = ACTIONS(2330),
    [anon_sym_u_SQUOTE] = ACTIONS(2330),
    [anon_sym_U_SQUOTE] = ACTIONS(2330),
    [anon_sym_u8_SQUOTE] = ACTIONS(2330),
    [anon_sym_SQUOTE] = ACTIONS(2330),
    [anon_sym_L_DQUOTE] = ACTIONS(2330),
    [anon_sym_u_DQUOTE] = ACTIONS(2330),
    [anon_sym_U_DQUOTE] = ACTIONS(2330),
    [anon_sym_u8_DQUOTE] = ACTIONS(2330),
    [anon_sym_DQUOTE] = ACTIONS(2330),
    [sym_true] = ACTIONS(2328),
    [sym_false] = ACTIONS(2328),
    [anon_sym_NULL] = ACTIONS(2328),
    [anon_sym_nullptr] = ACTIONS(2328),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2328),
    [anon_sym_decltype] = ACTIONS(2328),
    [sym_virtual] = ACTIONS(2328),
    [anon_sym_explicit] = ACTIONS(2328),
    [anon_sym_typename] = ACTIONS(2328),
    [anon_sym_template] = ACTIONS(2328),
    [anon_sym_operator] = ACTIONS(2328),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_delete] = ACTIONS(2328),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_namespace] = ACTIONS(2328),
    [anon_sym_using] = ACTIONS(2328),
    [anon_sym_static_assert] = ACTIONS(2328),
    [anon_sym_concept] = ACTIONS(2328),
    [anon_sym_co_return] = ACTIONS(2328),
    [anon_sym_co_yield] = ACTIONS(2328),
    [anon_sym_R_DQUOTE] = ACTIONS(2330),
    [anon_sym_LR_DQUOTE] = ACTIONS(2330),
    [anon_sym_uR_DQUOTE] = ACTIONS(2330),
    [anon_sym_UR_DQUOTE] = ACTIONS(2330),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2330),
    [anon_sym_co_await] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(2328),
    [anon_sym_requires] = ACTIONS(2328),
    [sym_this] = ACTIONS(2328),
    [anon_sym_discard] = ACTIONS(2328),
    [anon_sym_precise] = ACTIONS(2328),
    [anon_sym_shared] = ACTIONS(2328),
    [anon_sym_groupshared] = ACTIONS(2328),
    [anon_sym_uniform] = ACTIONS(2328),
    [anon_sym_row_major] = ACTIONS(2328),
    [anon_sym_column_major] = ACTIONS(2328),
    [anon_sym_globallycoherent] = ACTIONS(2328),
    [anon_sym_centroid] = ACTIONS(2328),
    [anon_sym_noperspective] = ACTIONS(2328),
    [anon_sym_nointerpolation] = ACTIONS(2328),
    [anon_sym_sample] = ACTIONS(2328),
    [anon_sym_linear] = ACTIONS(2328),
    [anon_sym_snorm] = ACTIONS(2328),
    [anon_sym_unorm] = ACTIONS(2328),
    [anon_sym_point] = ACTIONS(2328),
    [anon_sym_line] = ACTIONS(2328),
    [anon_sym_triangleadj] = ACTIONS(2328),
    [anon_sym_lineadj] = ACTIONS(2328),
    [anon_sym_triangle] = ACTIONS(2328),
    [anon_sym_cbuffer] = ACTIONS(2328),
  },
  [246] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_include_token1] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token2] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [aux_sym_preproc_else_token1] = ACTIONS(2332),
    [aux_sym_preproc_elif_token1] = ACTIONS(2332),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_BANG] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_DASH] = ACTIONS(2332),
    [anon_sym_PLUS] = ACTIONS(2332),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym_SEMI] = ACTIONS(2334),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym___cdecl] = ACTIONS(2332),
    [anon_sym___clrcall] = ACTIONS(2332),
    [anon_sym___stdcall] = ACTIONS(2332),
    [anon_sym___fastcall] = ACTIONS(2332),
    [anon_sym___thiscall] = ACTIONS(2332),
    [anon_sym___vectorcall] = ACTIONS(2332),
    [anon_sym_LBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_switch] = ACTIONS(2332),
    [anon_sym_case] = ACTIONS(2332),
    [anon_sym_default] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2332),
    [anon_sym_do] = ACTIONS(2332),
    [anon_sym_for] = ACTIONS(2332),
    [anon_sym_return] = ACTIONS(2332),
    [anon_sym_break] = ACTIONS(2332),
    [anon_sym_continue] = ACTIONS(2332),
    [anon_sym_goto] = ACTIONS(2332),
    [anon_sym___try] = ACTIONS(2332),
    [anon_sym___leave] = ACTIONS(2332),
    [anon_sym_not] = ACTIONS(2332),
    [anon_sym_compl] = ACTIONS(2332),
    [anon_sym_DASH_DASH] = ACTIONS(2334),
    [anon_sym_PLUS_PLUS] = ACTIONS(2334),
    [anon_sym_sizeof] = ACTIONS(2332),
    [anon_sym___alignof__] = ACTIONS(2332),
    [anon_sym___alignof] = ACTIONS(2332),
    [anon_sym__alignof] = ACTIONS(2332),
    [anon_sym_alignof] = ACTIONS(2332),
    [anon_sym__Alignof] = ACTIONS(2332),
    [anon_sym_offsetof] = ACTIONS(2332),
    [anon_sym__Generic] = ACTIONS(2332),
    [anon_sym_asm] = ACTIONS(2332),
    [anon_sym___asm__] = ACTIONS(2332),
    [sym_number_literal] = ACTIONS(2334),
    [anon_sym_L_SQUOTE] = ACTIONS(2334),
    [anon_sym_u_SQUOTE] = ACTIONS(2334),
    [anon_sym_U_SQUOTE] = ACTIONS(2334),
    [anon_sym_u8_SQUOTE] = ACTIONS(2334),
    [anon_sym_SQUOTE] = ACTIONS(2334),
    [anon_sym_L_DQUOTE] = ACTIONS(2334),
    [anon_sym_u_DQUOTE] = ACTIONS(2334),
    [anon_sym_U_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8_DQUOTE] = ACTIONS(2334),
    [anon_sym_DQUOTE] = ACTIONS(2334),
    [sym_true] = ACTIONS(2332),
    [sym_false] = ACTIONS(2332),
    [anon_sym_NULL] = ACTIONS(2332),
    [anon_sym_nullptr] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_try] = ACTIONS(2332),
    [anon_sym_delete] = ACTIONS(2332),
    [anon_sym_throw] = ACTIONS(2332),
    [anon_sym_namespace] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_concept] = ACTIONS(2332),
    [anon_sym_co_return] = ACTIONS(2332),
    [anon_sym_co_yield] = ACTIONS(2332),
    [anon_sym_R_DQUOTE] = ACTIONS(2334),
    [anon_sym_LR_DQUOTE] = ACTIONS(2334),
    [anon_sym_uR_DQUOTE] = ACTIONS(2334),
    [anon_sym_UR_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2334),
    [anon_sym_co_await] = ACTIONS(2332),
    [anon_sym_new] = ACTIONS(2332),
    [anon_sym_requires] = ACTIONS(2332),
    [sym_this] = ACTIONS(2332),
    [anon_sym_discard] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
    [anon_sym_cbuffer] = ACTIONS(2332),
  },
  [247] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_include_token1] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token2] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [aux_sym_preproc_else_token1] = ACTIONS(2324),
    [aux_sym_preproc_elif_token1] = ACTIONS(2324),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_BANG] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_DASH] = ACTIONS(2324),
    [anon_sym_PLUS] = ACTIONS(2324),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym_SEMI] = ACTIONS(2326),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym___cdecl] = ACTIONS(2324),
    [anon_sym___clrcall] = ACTIONS(2324),
    [anon_sym___stdcall] = ACTIONS(2324),
    [anon_sym___fastcall] = ACTIONS(2324),
    [anon_sym___thiscall] = ACTIONS(2324),
    [anon_sym___vectorcall] = ACTIONS(2324),
    [anon_sym_LBRACE] = ACTIONS(2326),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [anon_sym_if] = ACTIONS(2324),
    [anon_sym_switch] = ACTIONS(2324),
    [anon_sym_case] = ACTIONS(2324),
    [anon_sym_default] = ACTIONS(2324),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_do] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2324),
    [anon_sym_return] = ACTIONS(2324),
    [anon_sym_break] = ACTIONS(2324),
    [anon_sym_continue] = ACTIONS(2324),
    [anon_sym_goto] = ACTIONS(2324),
    [anon_sym___try] = ACTIONS(2324),
    [anon_sym___leave] = ACTIONS(2324),
    [anon_sym_not] = ACTIONS(2324),
    [anon_sym_compl] = ACTIONS(2324),
    [anon_sym_DASH_DASH] = ACTIONS(2326),
    [anon_sym_PLUS_PLUS] = ACTIONS(2326),
    [anon_sym_sizeof] = ACTIONS(2324),
    [anon_sym___alignof__] = ACTIONS(2324),
    [anon_sym___alignof] = ACTIONS(2324),
    [anon_sym__alignof] = ACTIONS(2324),
    [anon_sym_alignof] = ACTIONS(2324),
    [anon_sym__Alignof] = ACTIONS(2324),
    [anon_sym_offsetof] = ACTIONS(2324),
    [anon_sym__Generic] = ACTIONS(2324),
    [anon_sym_asm] = ACTIONS(2324),
    [anon_sym___asm__] = ACTIONS(2324),
    [sym_number_literal] = ACTIONS(2326),
    [anon_sym_L_SQUOTE] = ACTIONS(2326),
    [anon_sym_u_SQUOTE] = ACTIONS(2326),
    [anon_sym_U_SQUOTE] = ACTIONS(2326),
    [anon_sym_u8_SQUOTE] = ACTIONS(2326),
    [anon_sym_SQUOTE] = ACTIONS(2326),
    [anon_sym_L_DQUOTE] = ACTIONS(2326),
    [anon_sym_u_DQUOTE] = ACTIONS(2326),
    [anon_sym_U_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8_DQUOTE] = ACTIONS(2326),
    [anon_sym_DQUOTE] = ACTIONS(2326),
    [sym_true] = ACTIONS(2324),
    [sym_false] = ACTIONS(2324),
    [anon_sym_NULL] = ACTIONS(2324),
    [anon_sym_nullptr] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_try] = ACTIONS(2324),
    [anon_sym_delete] = ACTIONS(2324),
    [anon_sym_throw] = ACTIONS(2324),
    [anon_sym_namespace] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_concept] = ACTIONS(2324),
    [anon_sym_co_return] = ACTIONS(2324),
    [anon_sym_co_yield] = ACTIONS(2324),
    [anon_sym_R_DQUOTE] = ACTIONS(2326),
    [anon_sym_LR_DQUOTE] = ACTIONS(2326),
    [anon_sym_uR_DQUOTE] = ACTIONS(2326),
    [anon_sym_UR_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2326),
    [anon_sym_co_await] = ACTIONS(2324),
    [anon_sym_new] = ACTIONS(2324),
    [anon_sym_requires] = ACTIONS(2324),
    [sym_this] = ACTIONS(2324),
    [anon_sym_discard] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
    [anon_sym_cbuffer] = ACTIONS(2324),
  },
  [248] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_include_token1] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token2] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [aux_sym_preproc_else_token1] = ACTIONS(2324),
    [aux_sym_preproc_elif_token1] = ACTIONS(2324),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_BANG] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_DASH] = ACTIONS(2324),
    [anon_sym_PLUS] = ACTIONS(2324),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym_SEMI] = ACTIONS(2326),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym___cdecl] = ACTIONS(2324),
    [anon_sym___clrcall] = ACTIONS(2324),
    [anon_sym___stdcall] = ACTIONS(2324),
    [anon_sym___fastcall] = ACTIONS(2324),
    [anon_sym___thiscall] = ACTIONS(2324),
    [anon_sym___vectorcall] = ACTIONS(2324),
    [anon_sym_LBRACE] = ACTIONS(2326),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [anon_sym_if] = ACTIONS(2324),
    [anon_sym_switch] = ACTIONS(2324),
    [anon_sym_case] = ACTIONS(2324),
    [anon_sym_default] = ACTIONS(2324),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_do] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2324),
    [anon_sym_return] = ACTIONS(2324),
    [anon_sym_break] = ACTIONS(2324),
    [anon_sym_continue] = ACTIONS(2324),
    [anon_sym_goto] = ACTIONS(2324),
    [anon_sym___try] = ACTIONS(2324),
    [anon_sym___leave] = ACTIONS(2324),
    [anon_sym_not] = ACTIONS(2324),
    [anon_sym_compl] = ACTIONS(2324),
    [anon_sym_DASH_DASH] = ACTIONS(2326),
    [anon_sym_PLUS_PLUS] = ACTIONS(2326),
    [anon_sym_sizeof] = ACTIONS(2324),
    [anon_sym___alignof__] = ACTIONS(2324),
    [anon_sym___alignof] = ACTIONS(2324),
    [anon_sym__alignof] = ACTIONS(2324),
    [anon_sym_alignof] = ACTIONS(2324),
    [anon_sym__Alignof] = ACTIONS(2324),
    [anon_sym_offsetof] = ACTIONS(2324),
    [anon_sym__Generic] = ACTIONS(2324),
    [anon_sym_asm] = ACTIONS(2324),
    [anon_sym___asm__] = ACTIONS(2324),
    [sym_number_literal] = ACTIONS(2326),
    [anon_sym_L_SQUOTE] = ACTIONS(2326),
    [anon_sym_u_SQUOTE] = ACTIONS(2326),
    [anon_sym_U_SQUOTE] = ACTIONS(2326),
    [anon_sym_u8_SQUOTE] = ACTIONS(2326),
    [anon_sym_SQUOTE] = ACTIONS(2326),
    [anon_sym_L_DQUOTE] = ACTIONS(2326),
    [anon_sym_u_DQUOTE] = ACTIONS(2326),
    [anon_sym_U_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8_DQUOTE] = ACTIONS(2326),
    [anon_sym_DQUOTE] = ACTIONS(2326),
    [sym_true] = ACTIONS(2324),
    [sym_false] = ACTIONS(2324),
    [anon_sym_NULL] = ACTIONS(2324),
    [anon_sym_nullptr] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_try] = ACTIONS(2324),
    [anon_sym_delete] = ACTIONS(2324),
    [anon_sym_throw] = ACTIONS(2324),
    [anon_sym_namespace] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_concept] = ACTIONS(2324),
    [anon_sym_co_return] = ACTIONS(2324),
    [anon_sym_co_yield] = ACTIONS(2324),
    [anon_sym_R_DQUOTE] = ACTIONS(2326),
    [anon_sym_LR_DQUOTE] = ACTIONS(2326),
    [anon_sym_uR_DQUOTE] = ACTIONS(2326),
    [anon_sym_UR_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2326),
    [anon_sym_co_await] = ACTIONS(2324),
    [anon_sym_new] = ACTIONS(2324),
    [anon_sym_requires] = ACTIONS(2324),
    [sym_this] = ACTIONS(2324),
    [anon_sym_discard] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
    [anon_sym_cbuffer] = ACTIONS(2324),
  },
  [249] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_include_token1] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token2] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [aux_sym_preproc_else_token1] = ACTIONS(2332),
    [aux_sym_preproc_elif_token1] = ACTIONS(2332),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_BANG] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_DASH] = ACTIONS(2332),
    [anon_sym_PLUS] = ACTIONS(2332),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym_SEMI] = ACTIONS(2334),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym___cdecl] = ACTIONS(2332),
    [anon_sym___clrcall] = ACTIONS(2332),
    [anon_sym___stdcall] = ACTIONS(2332),
    [anon_sym___fastcall] = ACTIONS(2332),
    [anon_sym___thiscall] = ACTIONS(2332),
    [anon_sym___vectorcall] = ACTIONS(2332),
    [anon_sym_LBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_switch] = ACTIONS(2332),
    [anon_sym_case] = ACTIONS(2332),
    [anon_sym_default] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2332),
    [anon_sym_do] = ACTIONS(2332),
    [anon_sym_for] = ACTIONS(2332),
    [anon_sym_return] = ACTIONS(2332),
    [anon_sym_break] = ACTIONS(2332),
    [anon_sym_continue] = ACTIONS(2332),
    [anon_sym_goto] = ACTIONS(2332),
    [anon_sym___try] = ACTIONS(2332),
    [anon_sym___leave] = ACTIONS(2332),
    [anon_sym_not] = ACTIONS(2332),
    [anon_sym_compl] = ACTIONS(2332),
    [anon_sym_DASH_DASH] = ACTIONS(2334),
    [anon_sym_PLUS_PLUS] = ACTIONS(2334),
    [anon_sym_sizeof] = ACTIONS(2332),
    [anon_sym___alignof__] = ACTIONS(2332),
    [anon_sym___alignof] = ACTIONS(2332),
    [anon_sym__alignof] = ACTIONS(2332),
    [anon_sym_alignof] = ACTIONS(2332),
    [anon_sym__Alignof] = ACTIONS(2332),
    [anon_sym_offsetof] = ACTIONS(2332),
    [anon_sym__Generic] = ACTIONS(2332),
    [anon_sym_asm] = ACTIONS(2332),
    [anon_sym___asm__] = ACTIONS(2332),
    [sym_number_literal] = ACTIONS(2334),
    [anon_sym_L_SQUOTE] = ACTIONS(2334),
    [anon_sym_u_SQUOTE] = ACTIONS(2334),
    [anon_sym_U_SQUOTE] = ACTIONS(2334),
    [anon_sym_u8_SQUOTE] = ACTIONS(2334),
    [anon_sym_SQUOTE] = ACTIONS(2334),
    [anon_sym_L_DQUOTE] = ACTIONS(2334),
    [anon_sym_u_DQUOTE] = ACTIONS(2334),
    [anon_sym_U_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8_DQUOTE] = ACTIONS(2334),
    [anon_sym_DQUOTE] = ACTIONS(2334),
    [sym_true] = ACTIONS(2332),
    [sym_false] = ACTIONS(2332),
    [anon_sym_NULL] = ACTIONS(2332),
    [anon_sym_nullptr] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_try] = ACTIONS(2332),
    [anon_sym_delete] = ACTIONS(2332),
    [anon_sym_throw] = ACTIONS(2332),
    [anon_sym_namespace] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_concept] = ACTIONS(2332),
    [anon_sym_co_return] = ACTIONS(2332),
    [anon_sym_co_yield] = ACTIONS(2332),
    [anon_sym_R_DQUOTE] = ACTIONS(2334),
    [anon_sym_LR_DQUOTE] = ACTIONS(2334),
    [anon_sym_uR_DQUOTE] = ACTIONS(2334),
    [anon_sym_UR_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2334),
    [anon_sym_co_await] = ACTIONS(2332),
    [anon_sym_new] = ACTIONS(2332),
    [anon_sym_requires] = ACTIONS(2332),
    [sym_this] = ACTIONS(2332),
    [anon_sym_discard] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
    [anon_sym_cbuffer] = ACTIONS(2332),
  },
  [250] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_include_token1] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token2] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [aux_sym_preproc_else_token1] = ACTIONS(2332),
    [aux_sym_preproc_elif_token1] = ACTIONS(2332),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_BANG] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_DASH] = ACTIONS(2332),
    [anon_sym_PLUS] = ACTIONS(2332),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym_SEMI] = ACTIONS(2334),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym___cdecl] = ACTIONS(2332),
    [anon_sym___clrcall] = ACTIONS(2332),
    [anon_sym___stdcall] = ACTIONS(2332),
    [anon_sym___fastcall] = ACTIONS(2332),
    [anon_sym___thiscall] = ACTIONS(2332),
    [anon_sym___vectorcall] = ACTIONS(2332),
    [anon_sym_LBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_switch] = ACTIONS(2332),
    [anon_sym_case] = ACTIONS(2332),
    [anon_sym_default] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2332),
    [anon_sym_do] = ACTIONS(2332),
    [anon_sym_for] = ACTIONS(2332),
    [anon_sym_return] = ACTIONS(2332),
    [anon_sym_break] = ACTIONS(2332),
    [anon_sym_continue] = ACTIONS(2332),
    [anon_sym_goto] = ACTIONS(2332),
    [anon_sym___try] = ACTIONS(2332),
    [anon_sym___leave] = ACTIONS(2332),
    [anon_sym_not] = ACTIONS(2332),
    [anon_sym_compl] = ACTIONS(2332),
    [anon_sym_DASH_DASH] = ACTIONS(2334),
    [anon_sym_PLUS_PLUS] = ACTIONS(2334),
    [anon_sym_sizeof] = ACTIONS(2332),
    [anon_sym___alignof__] = ACTIONS(2332),
    [anon_sym___alignof] = ACTIONS(2332),
    [anon_sym__alignof] = ACTIONS(2332),
    [anon_sym_alignof] = ACTIONS(2332),
    [anon_sym__Alignof] = ACTIONS(2332),
    [anon_sym_offsetof] = ACTIONS(2332),
    [anon_sym__Generic] = ACTIONS(2332),
    [anon_sym_asm] = ACTIONS(2332),
    [anon_sym___asm__] = ACTIONS(2332),
    [sym_number_literal] = ACTIONS(2334),
    [anon_sym_L_SQUOTE] = ACTIONS(2334),
    [anon_sym_u_SQUOTE] = ACTIONS(2334),
    [anon_sym_U_SQUOTE] = ACTIONS(2334),
    [anon_sym_u8_SQUOTE] = ACTIONS(2334),
    [anon_sym_SQUOTE] = ACTIONS(2334),
    [anon_sym_L_DQUOTE] = ACTIONS(2334),
    [anon_sym_u_DQUOTE] = ACTIONS(2334),
    [anon_sym_U_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8_DQUOTE] = ACTIONS(2334),
    [anon_sym_DQUOTE] = ACTIONS(2334),
    [sym_true] = ACTIONS(2332),
    [sym_false] = ACTIONS(2332),
    [anon_sym_NULL] = ACTIONS(2332),
    [anon_sym_nullptr] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_try] = ACTIONS(2332),
    [anon_sym_delete] = ACTIONS(2332),
    [anon_sym_throw] = ACTIONS(2332),
    [anon_sym_namespace] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_concept] = ACTIONS(2332),
    [anon_sym_co_return] = ACTIONS(2332),
    [anon_sym_co_yield] = ACTIONS(2332),
    [anon_sym_R_DQUOTE] = ACTIONS(2334),
    [anon_sym_LR_DQUOTE] = ACTIONS(2334),
    [anon_sym_uR_DQUOTE] = ACTIONS(2334),
    [anon_sym_UR_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2334),
    [anon_sym_co_await] = ACTIONS(2332),
    [anon_sym_new] = ACTIONS(2332),
    [anon_sym_requires] = ACTIONS(2332),
    [sym_this] = ACTIONS(2332),
    [anon_sym_discard] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
    [anon_sym_cbuffer] = ACTIONS(2332),
  },
  [251] = {
    [sym_identifier] = ACTIONS(2336),
    [aux_sym_preproc_include_token1] = ACTIONS(2336),
    [aux_sym_preproc_def_token1] = ACTIONS(2336),
    [aux_sym_preproc_if_token1] = ACTIONS(2336),
    [aux_sym_preproc_if_token2] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2336),
    [aux_sym_preproc_else_token1] = ACTIONS(2336),
    [aux_sym_preproc_elif_token1] = ACTIONS(2336),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2336),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2336),
    [sym_preproc_directive] = ACTIONS(2336),
    [anon_sym_LPAREN2] = ACTIONS(2338),
    [anon_sym_BANG] = ACTIONS(2338),
    [anon_sym_TILDE] = ACTIONS(2338),
    [anon_sym_DASH] = ACTIONS(2336),
    [anon_sym_PLUS] = ACTIONS(2336),
    [anon_sym_STAR] = ACTIONS(2338),
    [anon_sym_AMP_AMP] = ACTIONS(2338),
    [anon_sym_AMP] = ACTIONS(2336),
    [anon_sym_SEMI] = ACTIONS(2338),
    [anon_sym___extension__] = ACTIONS(2336),
    [anon_sym_typedef] = ACTIONS(2336),
    [anon_sym_in] = ACTIONS(2336),
    [anon_sym_out] = ACTIONS(2336),
    [anon_sym_inout] = ACTIONS(2336),
    [anon_sym_extern] = ACTIONS(2336),
    [anon_sym___attribute__] = ACTIONS(2336),
    [anon_sym_COLON_COLON] = ACTIONS(2338),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2338),
    [anon_sym___declspec] = ACTIONS(2336),
    [anon_sym___based] = ACTIONS(2336),
    [anon_sym___cdecl] = ACTIONS(2336),
    [anon_sym___clrcall] = ACTIONS(2336),
    [anon_sym___stdcall] = ACTIONS(2336),
    [anon_sym___fastcall] = ACTIONS(2336),
    [anon_sym___thiscall] = ACTIONS(2336),
    [anon_sym___vectorcall] = ACTIONS(2336),
    [anon_sym_LBRACE] = ACTIONS(2338),
    [anon_sym_signed] = ACTIONS(2336),
    [anon_sym_unsigned] = ACTIONS(2336),
    [anon_sym_long] = ACTIONS(2336),
    [anon_sym_short] = ACTIONS(2336),
    [anon_sym_LBRACK] = ACTIONS(2336),
    [anon_sym_static] = ACTIONS(2336),
    [anon_sym_register] = ACTIONS(2336),
    [anon_sym_inline] = ACTIONS(2336),
    [anon_sym___inline] = ACTIONS(2336),
    [anon_sym___inline__] = ACTIONS(2336),
    [anon_sym___forceinline] = ACTIONS(2336),
    [anon_sym_thread_local] = ACTIONS(2336),
    [anon_sym___thread] = ACTIONS(2336),
    [anon_sym_const] = ACTIONS(2336),
    [anon_sym_constexpr] = ACTIONS(2336),
    [anon_sym_volatile] = ACTIONS(2336),
    [anon_sym_restrict] = ACTIONS(2336),
    [anon_sym___restrict__] = ACTIONS(2336),
    [anon_sym__Atomic] = ACTIONS(2336),
    [anon_sym__Noreturn] = ACTIONS(2336),
    [anon_sym_noreturn] = ACTIONS(2336),
    [anon_sym_mutable] = ACTIONS(2336),
    [anon_sym_constinit] = ACTIONS(2336),
    [anon_sym_consteval] = ACTIONS(2336),
    [anon_sym_alignas] = ACTIONS(2336),
    [anon_sym__Alignas] = ACTIONS(2336),
    [sym_primitive_type] = ACTIONS(2336),
    [anon_sym_enum] = ACTIONS(2336),
    [anon_sym_class] = ACTIONS(2336),
    [anon_sym_struct] = ACTIONS(2336),
    [anon_sym_union] = ACTIONS(2336),
    [anon_sym_if] = ACTIONS(2336),
    [anon_sym_switch] = ACTIONS(2336),
    [anon_sym_case] = ACTIONS(2336),
    [anon_sym_default] = ACTIONS(2336),
    [anon_sym_while] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(2336),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_return] = ACTIONS(2336),
    [anon_sym_break] = ACTIONS(2336),
    [anon_sym_continue] = ACTIONS(2336),
    [anon_sym_goto] = ACTIONS(2336),
    [anon_sym___try] = ACTIONS(2336),
    [anon_sym___leave] = ACTIONS(2336),
    [anon_sym_not] = ACTIONS(2336),
    [anon_sym_compl] = ACTIONS(2336),
    [anon_sym_DASH_DASH] = ACTIONS(2338),
    [anon_sym_PLUS_PLUS] = ACTIONS(2338),
    [anon_sym_sizeof] = ACTIONS(2336),
    [anon_sym___alignof__] = ACTIONS(2336),
    [anon_sym___alignof] = ACTIONS(2336),
    [anon_sym__alignof] = ACTIONS(2336),
    [anon_sym_alignof] = ACTIONS(2336),
    [anon_sym__Alignof] = ACTIONS(2336),
    [anon_sym_offsetof] = ACTIONS(2336),
    [anon_sym__Generic] = ACTIONS(2336),
    [anon_sym_asm] = ACTIONS(2336),
    [anon_sym___asm__] = ACTIONS(2336),
    [sym_number_literal] = ACTIONS(2338),
    [anon_sym_L_SQUOTE] = ACTIONS(2338),
    [anon_sym_u_SQUOTE] = ACTIONS(2338),
    [anon_sym_U_SQUOTE] = ACTIONS(2338),
    [anon_sym_u8_SQUOTE] = ACTIONS(2338),
    [anon_sym_SQUOTE] = ACTIONS(2338),
    [anon_sym_L_DQUOTE] = ACTIONS(2338),
    [anon_sym_u_DQUOTE] = ACTIONS(2338),
    [anon_sym_U_DQUOTE] = ACTIONS(2338),
    [anon_sym_u8_DQUOTE] = ACTIONS(2338),
    [anon_sym_DQUOTE] = ACTIONS(2338),
    [sym_true] = ACTIONS(2336),
    [sym_false] = ACTIONS(2336),
    [anon_sym_NULL] = ACTIONS(2336),
    [anon_sym_nullptr] = ACTIONS(2336),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2336),
    [anon_sym_decltype] = ACTIONS(2336),
    [sym_virtual] = ACTIONS(2336),
    [anon_sym_explicit] = ACTIONS(2336),
    [anon_sym_typename] = ACTIONS(2336),
    [anon_sym_template] = ACTIONS(2336),
    [anon_sym_operator] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2336),
    [anon_sym_delete] = ACTIONS(2336),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_namespace] = ACTIONS(2336),
    [anon_sym_using] = ACTIONS(2336),
    [anon_sym_static_assert] = ACTIONS(2336),
    [anon_sym_concept] = ACTIONS(2336),
    [anon_sym_co_return] = ACTIONS(2336),
    [anon_sym_co_yield] = ACTIONS(2336),
    [anon_sym_R_DQUOTE] = ACTIONS(2338),
    [anon_sym_LR_DQUOTE] = ACTIONS(2338),
    [anon_sym_uR_DQUOTE] = ACTIONS(2338),
    [anon_sym_UR_DQUOTE] = ACTIONS(2338),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2338),
    [anon_sym_co_await] = ACTIONS(2336),
    [anon_sym_new] = ACTIONS(2336),
    [anon_sym_requires] = ACTIONS(2336),
    [sym_this] = ACTIONS(2336),
    [anon_sym_discard] = ACTIONS(2336),
    [anon_sym_precise] = ACTIONS(2336),
    [anon_sym_shared] = ACTIONS(2336),
    [anon_sym_groupshared] = ACTIONS(2336),
    [anon_sym_uniform] = ACTIONS(2336),
    [anon_sym_row_major] = ACTIONS(2336),
    [anon_sym_column_major] = ACTIONS(2336),
    [anon_sym_globallycoherent] = ACTIONS(2336),
    [anon_sym_centroid] = ACTIONS(2336),
    [anon_sym_noperspective] = ACTIONS(2336),
    [anon_sym_nointerpolation] = ACTIONS(2336),
    [anon_sym_sample] = ACTIONS(2336),
    [anon_sym_linear] = ACTIONS(2336),
    [anon_sym_snorm] = ACTIONS(2336),
    [anon_sym_unorm] = ACTIONS(2336),
    [anon_sym_point] = ACTIONS(2336),
    [anon_sym_line] = ACTIONS(2336),
    [anon_sym_triangleadj] = ACTIONS(2336),
    [anon_sym_lineadj] = ACTIONS(2336),
    [anon_sym_triangle] = ACTIONS(2336),
    [anon_sym_cbuffer] = ACTIONS(2336),
  },
  [252] = {
    [sym_identifier] = ACTIONS(1953),
    [aux_sym_preproc_include_token1] = ACTIONS(1953),
    [aux_sym_preproc_def_token1] = ACTIONS(1953),
    [aux_sym_preproc_if_token1] = ACTIONS(1953),
    [aux_sym_preproc_if_token2] = ACTIONS(1953),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1953),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1953),
    [sym_preproc_directive] = ACTIONS(1953),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_BANG] = ACTIONS(1955),
    [anon_sym_TILDE] = ACTIONS(1955),
    [anon_sym_DASH] = ACTIONS(1953),
    [anon_sym_PLUS] = ACTIONS(1953),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym_COLON] = ACTIONS(1953),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym_typedef] = ACTIONS(1953),
    [anon_sym_in] = ACTIONS(1953),
    [anon_sym_out] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1953),
    [anon_sym_extern] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1955),
    [anon_sym___declspec] = ACTIONS(1953),
    [anon_sym___based] = ACTIONS(1953),
    [anon_sym___cdecl] = ACTIONS(1953),
    [anon_sym___clrcall] = ACTIONS(1953),
    [anon_sym___stdcall] = ACTIONS(1953),
    [anon_sym___fastcall] = ACTIONS(1953),
    [anon_sym___thiscall] = ACTIONS(1953),
    [anon_sym___vectorcall] = ACTIONS(1953),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_signed] = ACTIONS(1953),
    [anon_sym_unsigned] = ACTIONS(1953),
    [anon_sym_long] = ACTIONS(1953),
    [anon_sym_short] = ACTIONS(1953),
    [anon_sym_LBRACK] = ACTIONS(1953),
    [anon_sym_static] = ACTIONS(1953),
    [anon_sym_register] = ACTIONS(1953),
    [anon_sym_inline] = ACTIONS(1953),
    [anon_sym___inline] = ACTIONS(1953),
    [anon_sym___inline__] = ACTIONS(1953),
    [anon_sym___forceinline] = ACTIONS(1953),
    [anon_sym_thread_local] = ACTIONS(1953),
    [anon_sym___thread] = ACTIONS(1953),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [sym_primitive_type] = ACTIONS(1953),
    [anon_sym_enum] = ACTIONS(1953),
    [anon_sym_class] = ACTIONS(1953),
    [anon_sym_struct] = ACTIONS(1953),
    [anon_sym_union] = ACTIONS(1953),
    [anon_sym_if] = ACTIONS(1953),
    [anon_sym_else] = ACTIONS(1953),
    [anon_sym_switch] = ACTIONS(1953),
    [anon_sym_case] = ACTIONS(1953),
    [anon_sym_default] = ACTIONS(1953),
    [anon_sym_while] = ACTIONS(1953),
    [anon_sym_do] = ACTIONS(1953),
    [anon_sym_for] = ACTIONS(1953),
    [anon_sym_return] = ACTIONS(1953),
    [anon_sym_break] = ACTIONS(1953),
    [anon_sym_continue] = ACTIONS(1953),
    [anon_sym_goto] = ACTIONS(1953),
    [anon_sym___try] = ACTIONS(1953),
    [anon_sym___leave] = ACTIONS(1953),
    [anon_sym_not] = ACTIONS(1953),
    [anon_sym_compl] = ACTIONS(1953),
    [anon_sym_DASH_DASH] = ACTIONS(1955),
    [anon_sym_PLUS_PLUS] = ACTIONS(1955),
    [anon_sym_sizeof] = ACTIONS(1953),
    [anon_sym___alignof__] = ACTIONS(1953),
    [anon_sym___alignof] = ACTIONS(1953),
    [anon_sym__alignof] = ACTIONS(1953),
    [anon_sym_alignof] = ACTIONS(1953),
    [anon_sym__Alignof] = ACTIONS(1953),
    [anon_sym_offsetof] = ACTIONS(1953),
    [anon_sym__Generic] = ACTIONS(1953),
    [anon_sym_asm] = ACTIONS(1953),
    [anon_sym___asm__] = ACTIONS(1953),
    [sym_number_literal] = ACTIONS(1955),
    [anon_sym_L_SQUOTE] = ACTIONS(1955),
    [anon_sym_u_SQUOTE] = ACTIONS(1955),
    [anon_sym_U_SQUOTE] = ACTIONS(1955),
    [anon_sym_u8_SQUOTE] = ACTIONS(1955),
    [anon_sym_SQUOTE] = ACTIONS(1955),
    [anon_sym_L_DQUOTE] = ACTIONS(1955),
    [anon_sym_u_DQUOTE] = ACTIONS(1955),
    [anon_sym_U_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8_DQUOTE] = ACTIONS(1955),
    [anon_sym_DQUOTE] = ACTIONS(1955),
    [sym_true] = ACTIONS(1953),
    [sym_false] = ACTIONS(1953),
    [anon_sym_NULL] = ACTIONS(1953),
    [anon_sym_nullptr] = ACTIONS(1953),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
    [sym_virtual] = ACTIONS(1953),
    [anon_sym_explicit] = ACTIONS(1953),
    [anon_sym_typename] = ACTIONS(1953),
    [anon_sym_template] = ACTIONS(1953),
    [anon_sym_operator] = ACTIONS(1953),
    [anon_sym_try] = ACTIONS(1953),
    [anon_sym_delete] = ACTIONS(1953),
    [anon_sym_throw] = ACTIONS(1953),
    [anon_sym_namespace] = ACTIONS(1953),
    [anon_sym_using] = ACTIONS(1953),
    [anon_sym_static_assert] = ACTIONS(1953),
    [anon_sym_concept] = ACTIONS(1953),
    [anon_sym_co_return] = ACTIONS(1953),
    [anon_sym_co_yield] = ACTIONS(1953),
    [anon_sym_R_DQUOTE] = ACTIONS(1955),
    [anon_sym_LR_DQUOTE] = ACTIONS(1955),
    [anon_sym_uR_DQUOTE] = ACTIONS(1955),
    [anon_sym_UR_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1955),
    [anon_sym_co_await] = ACTIONS(1953),
    [anon_sym_new] = ACTIONS(1953),
    [anon_sym_requires] = ACTIONS(1953),
    [sym_this] = ACTIONS(1953),
    [anon_sym_discard] = ACTIONS(1953),
    [anon_sym_precise] = ACTIONS(1953),
    [anon_sym_shared] = ACTIONS(1953),
    [anon_sym_groupshared] = ACTIONS(1953),
    [anon_sym_uniform] = ACTIONS(1953),
    [anon_sym_row_major] = ACTIONS(1953),
    [anon_sym_column_major] = ACTIONS(1953),
    [anon_sym_globallycoherent] = ACTIONS(1953),
    [anon_sym_centroid] = ACTIONS(1953),
    [anon_sym_noperspective] = ACTIONS(1953),
    [anon_sym_nointerpolation] = ACTIONS(1953),
    [anon_sym_sample] = ACTIONS(1953),
    [anon_sym_linear] = ACTIONS(1953),
    [anon_sym_snorm] = ACTIONS(1953),
    [anon_sym_unorm] = ACTIONS(1953),
    [anon_sym_point] = ACTIONS(1953),
    [anon_sym_line] = ACTIONS(1953),
    [anon_sym_triangleadj] = ACTIONS(1953),
    [anon_sym_lineadj] = ACTIONS(1953),
    [anon_sym_triangle] = ACTIONS(1953),
    [anon_sym_cbuffer] = ACTIONS(1953),
  },
  [253] = {
    [sym_identifier] = ACTIONS(2336),
    [aux_sym_preproc_include_token1] = ACTIONS(2336),
    [aux_sym_preproc_def_token1] = ACTIONS(2336),
    [aux_sym_preproc_if_token1] = ACTIONS(2336),
    [aux_sym_preproc_if_token2] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2336),
    [aux_sym_preproc_else_token1] = ACTIONS(2336),
    [aux_sym_preproc_elif_token1] = ACTIONS(2336),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2336),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2336),
    [sym_preproc_directive] = ACTIONS(2336),
    [anon_sym_LPAREN2] = ACTIONS(2338),
    [anon_sym_BANG] = ACTIONS(2338),
    [anon_sym_TILDE] = ACTIONS(2338),
    [anon_sym_DASH] = ACTIONS(2336),
    [anon_sym_PLUS] = ACTIONS(2336),
    [anon_sym_STAR] = ACTIONS(2338),
    [anon_sym_AMP_AMP] = ACTIONS(2338),
    [anon_sym_AMP] = ACTIONS(2336),
    [anon_sym_SEMI] = ACTIONS(2338),
    [anon_sym___extension__] = ACTIONS(2336),
    [anon_sym_typedef] = ACTIONS(2336),
    [anon_sym_in] = ACTIONS(2336),
    [anon_sym_out] = ACTIONS(2336),
    [anon_sym_inout] = ACTIONS(2336),
    [anon_sym_extern] = ACTIONS(2336),
    [anon_sym___attribute__] = ACTIONS(2336),
    [anon_sym_COLON_COLON] = ACTIONS(2338),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2338),
    [anon_sym___declspec] = ACTIONS(2336),
    [anon_sym___based] = ACTIONS(2336),
    [anon_sym___cdecl] = ACTIONS(2336),
    [anon_sym___clrcall] = ACTIONS(2336),
    [anon_sym___stdcall] = ACTIONS(2336),
    [anon_sym___fastcall] = ACTIONS(2336),
    [anon_sym___thiscall] = ACTIONS(2336),
    [anon_sym___vectorcall] = ACTIONS(2336),
    [anon_sym_LBRACE] = ACTIONS(2338),
    [anon_sym_signed] = ACTIONS(2336),
    [anon_sym_unsigned] = ACTIONS(2336),
    [anon_sym_long] = ACTIONS(2336),
    [anon_sym_short] = ACTIONS(2336),
    [anon_sym_LBRACK] = ACTIONS(2336),
    [anon_sym_static] = ACTIONS(2336),
    [anon_sym_register] = ACTIONS(2336),
    [anon_sym_inline] = ACTIONS(2336),
    [anon_sym___inline] = ACTIONS(2336),
    [anon_sym___inline__] = ACTIONS(2336),
    [anon_sym___forceinline] = ACTIONS(2336),
    [anon_sym_thread_local] = ACTIONS(2336),
    [anon_sym___thread] = ACTIONS(2336),
    [anon_sym_const] = ACTIONS(2336),
    [anon_sym_constexpr] = ACTIONS(2336),
    [anon_sym_volatile] = ACTIONS(2336),
    [anon_sym_restrict] = ACTIONS(2336),
    [anon_sym___restrict__] = ACTIONS(2336),
    [anon_sym__Atomic] = ACTIONS(2336),
    [anon_sym__Noreturn] = ACTIONS(2336),
    [anon_sym_noreturn] = ACTIONS(2336),
    [anon_sym_mutable] = ACTIONS(2336),
    [anon_sym_constinit] = ACTIONS(2336),
    [anon_sym_consteval] = ACTIONS(2336),
    [anon_sym_alignas] = ACTIONS(2336),
    [anon_sym__Alignas] = ACTIONS(2336),
    [sym_primitive_type] = ACTIONS(2336),
    [anon_sym_enum] = ACTIONS(2336),
    [anon_sym_class] = ACTIONS(2336),
    [anon_sym_struct] = ACTIONS(2336),
    [anon_sym_union] = ACTIONS(2336),
    [anon_sym_if] = ACTIONS(2336),
    [anon_sym_switch] = ACTIONS(2336),
    [anon_sym_case] = ACTIONS(2336),
    [anon_sym_default] = ACTIONS(2336),
    [anon_sym_while] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(2336),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_return] = ACTIONS(2336),
    [anon_sym_break] = ACTIONS(2336),
    [anon_sym_continue] = ACTIONS(2336),
    [anon_sym_goto] = ACTIONS(2336),
    [anon_sym___try] = ACTIONS(2336),
    [anon_sym___leave] = ACTIONS(2336),
    [anon_sym_not] = ACTIONS(2336),
    [anon_sym_compl] = ACTIONS(2336),
    [anon_sym_DASH_DASH] = ACTIONS(2338),
    [anon_sym_PLUS_PLUS] = ACTIONS(2338),
    [anon_sym_sizeof] = ACTIONS(2336),
    [anon_sym___alignof__] = ACTIONS(2336),
    [anon_sym___alignof] = ACTIONS(2336),
    [anon_sym__alignof] = ACTIONS(2336),
    [anon_sym_alignof] = ACTIONS(2336),
    [anon_sym__Alignof] = ACTIONS(2336),
    [anon_sym_offsetof] = ACTIONS(2336),
    [anon_sym__Generic] = ACTIONS(2336),
    [anon_sym_asm] = ACTIONS(2336),
    [anon_sym___asm__] = ACTIONS(2336),
    [sym_number_literal] = ACTIONS(2338),
    [anon_sym_L_SQUOTE] = ACTIONS(2338),
    [anon_sym_u_SQUOTE] = ACTIONS(2338),
    [anon_sym_U_SQUOTE] = ACTIONS(2338),
    [anon_sym_u8_SQUOTE] = ACTIONS(2338),
    [anon_sym_SQUOTE] = ACTIONS(2338),
    [anon_sym_L_DQUOTE] = ACTIONS(2338),
    [anon_sym_u_DQUOTE] = ACTIONS(2338),
    [anon_sym_U_DQUOTE] = ACTIONS(2338),
    [anon_sym_u8_DQUOTE] = ACTIONS(2338),
    [anon_sym_DQUOTE] = ACTIONS(2338),
    [sym_true] = ACTIONS(2336),
    [sym_false] = ACTIONS(2336),
    [anon_sym_NULL] = ACTIONS(2336),
    [anon_sym_nullptr] = ACTIONS(2336),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2336),
    [anon_sym_decltype] = ACTIONS(2336),
    [sym_virtual] = ACTIONS(2336),
    [anon_sym_explicit] = ACTIONS(2336),
    [anon_sym_typename] = ACTIONS(2336),
    [anon_sym_template] = ACTIONS(2336),
    [anon_sym_operator] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2336),
    [anon_sym_delete] = ACTIONS(2336),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_namespace] = ACTIONS(2336),
    [anon_sym_using] = ACTIONS(2336),
    [anon_sym_static_assert] = ACTIONS(2336),
    [anon_sym_concept] = ACTIONS(2336),
    [anon_sym_co_return] = ACTIONS(2336),
    [anon_sym_co_yield] = ACTIONS(2336),
    [anon_sym_R_DQUOTE] = ACTIONS(2338),
    [anon_sym_LR_DQUOTE] = ACTIONS(2338),
    [anon_sym_uR_DQUOTE] = ACTIONS(2338),
    [anon_sym_UR_DQUOTE] = ACTIONS(2338),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2338),
    [anon_sym_co_await] = ACTIONS(2336),
    [anon_sym_new] = ACTIONS(2336),
    [anon_sym_requires] = ACTIONS(2336),
    [sym_this] = ACTIONS(2336),
    [anon_sym_discard] = ACTIONS(2336),
    [anon_sym_precise] = ACTIONS(2336),
    [anon_sym_shared] = ACTIONS(2336),
    [anon_sym_groupshared] = ACTIONS(2336),
    [anon_sym_uniform] = ACTIONS(2336),
    [anon_sym_row_major] = ACTIONS(2336),
    [anon_sym_column_major] = ACTIONS(2336),
    [anon_sym_globallycoherent] = ACTIONS(2336),
    [anon_sym_centroid] = ACTIONS(2336),
    [anon_sym_noperspective] = ACTIONS(2336),
    [anon_sym_nointerpolation] = ACTIONS(2336),
    [anon_sym_sample] = ACTIONS(2336),
    [anon_sym_linear] = ACTIONS(2336),
    [anon_sym_snorm] = ACTIONS(2336),
    [anon_sym_unorm] = ACTIONS(2336),
    [anon_sym_point] = ACTIONS(2336),
    [anon_sym_line] = ACTIONS(2336),
    [anon_sym_triangleadj] = ACTIONS(2336),
    [anon_sym_lineadj] = ACTIONS(2336),
    [anon_sym_triangle] = ACTIONS(2336),
    [anon_sym_cbuffer] = ACTIONS(2336),
  },
  [254] = {
    [sym_identifier] = ACTIONS(2340),
    [aux_sym_preproc_include_token1] = ACTIONS(2340),
    [aux_sym_preproc_def_token1] = ACTIONS(2340),
    [aux_sym_preproc_if_token1] = ACTIONS(2340),
    [aux_sym_preproc_if_token2] = ACTIONS(2340),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2340),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2340),
    [aux_sym_preproc_else_token1] = ACTIONS(2340),
    [aux_sym_preproc_elif_token1] = ACTIONS(2340),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2340),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2340),
    [sym_preproc_directive] = ACTIONS(2340),
    [anon_sym_LPAREN2] = ACTIONS(2342),
    [anon_sym_BANG] = ACTIONS(2342),
    [anon_sym_TILDE] = ACTIONS(2342),
    [anon_sym_DASH] = ACTIONS(2340),
    [anon_sym_PLUS] = ACTIONS(2340),
    [anon_sym_STAR] = ACTIONS(2342),
    [anon_sym_AMP_AMP] = ACTIONS(2342),
    [anon_sym_AMP] = ACTIONS(2340),
    [anon_sym_SEMI] = ACTIONS(2342),
    [anon_sym___extension__] = ACTIONS(2340),
    [anon_sym_typedef] = ACTIONS(2340),
    [anon_sym_in] = ACTIONS(2340),
    [anon_sym_out] = ACTIONS(2340),
    [anon_sym_inout] = ACTIONS(2340),
    [anon_sym_extern] = ACTIONS(2340),
    [anon_sym___attribute__] = ACTIONS(2340),
    [anon_sym_COLON_COLON] = ACTIONS(2342),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2342),
    [anon_sym___declspec] = ACTIONS(2340),
    [anon_sym___based] = ACTIONS(2340),
    [anon_sym___cdecl] = ACTIONS(2340),
    [anon_sym___clrcall] = ACTIONS(2340),
    [anon_sym___stdcall] = ACTIONS(2340),
    [anon_sym___fastcall] = ACTIONS(2340),
    [anon_sym___thiscall] = ACTIONS(2340),
    [anon_sym___vectorcall] = ACTIONS(2340),
    [anon_sym_LBRACE] = ACTIONS(2342),
    [anon_sym_signed] = ACTIONS(2340),
    [anon_sym_unsigned] = ACTIONS(2340),
    [anon_sym_long] = ACTIONS(2340),
    [anon_sym_short] = ACTIONS(2340),
    [anon_sym_LBRACK] = ACTIONS(2340),
    [anon_sym_static] = ACTIONS(2340),
    [anon_sym_register] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(2340),
    [anon_sym___inline] = ACTIONS(2340),
    [anon_sym___inline__] = ACTIONS(2340),
    [anon_sym___forceinline] = ACTIONS(2340),
    [anon_sym_thread_local] = ACTIONS(2340),
    [anon_sym___thread] = ACTIONS(2340),
    [anon_sym_const] = ACTIONS(2340),
    [anon_sym_constexpr] = ACTIONS(2340),
    [anon_sym_volatile] = ACTIONS(2340),
    [anon_sym_restrict] = ACTIONS(2340),
    [anon_sym___restrict__] = ACTIONS(2340),
    [anon_sym__Atomic] = ACTIONS(2340),
    [anon_sym__Noreturn] = ACTIONS(2340),
    [anon_sym_noreturn] = ACTIONS(2340),
    [anon_sym_mutable] = ACTIONS(2340),
    [anon_sym_constinit] = ACTIONS(2340),
    [anon_sym_consteval] = ACTIONS(2340),
    [anon_sym_alignas] = ACTIONS(2340),
    [anon_sym__Alignas] = ACTIONS(2340),
    [sym_primitive_type] = ACTIONS(2340),
    [anon_sym_enum] = ACTIONS(2340),
    [anon_sym_class] = ACTIONS(2340),
    [anon_sym_struct] = ACTIONS(2340),
    [anon_sym_union] = ACTIONS(2340),
    [anon_sym_if] = ACTIONS(2340),
    [anon_sym_switch] = ACTIONS(2340),
    [anon_sym_case] = ACTIONS(2340),
    [anon_sym_default] = ACTIONS(2340),
    [anon_sym_while] = ACTIONS(2340),
    [anon_sym_do] = ACTIONS(2340),
    [anon_sym_for] = ACTIONS(2340),
    [anon_sym_return] = ACTIONS(2340),
    [anon_sym_break] = ACTIONS(2340),
    [anon_sym_continue] = ACTIONS(2340),
    [anon_sym_goto] = ACTIONS(2340),
    [anon_sym___try] = ACTIONS(2340),
    [anon_sym___leave] = ACTIONS(2340),
    [anon_sym_not] = ACTIONS(2340),
    [anon_sym_compl] = ACTIONS(2340),
    [anon_sym_DASH_DASH] = ACTIONS(2342),
    [anon_sym_PLUS_PLUS] = ACTIONS(2342),
    [anon_sym_sizeof] = ACTIONS(2340),
    [anon_sym___alignof__] = ACTIONS(2340),
    [anon_sym___alignof] = ACTIONS(2340),
    [anon_sym__alignof] = ACTIONS(2340),
    [anon_sym_alignof] = ACTIONS(2340),
    [anon_sym__Alignof] = ACTIONS(2340),
    [anon_sym_offsetof] = ACTIONS(2340),
    [anon_sym__Generic] = ACTIONS(2340),
    [anon_sym_asm] = ACTIONS(2340),
    [anon_sym___asm__] = ACTIONS(2340),
    [sym_number_literal] = ACTIONS(2342),
    [anon_sym_L_SQUOTE] = ACTIONS(2342),
    [anon_sym_u_SQUOTE] = ACTIONS(2342),
    [anon_sym_U_SQUOTE] = ACTIONS(2342),
    [anon_sym_u8_SQUOTE] = ACTIONS(2342),
    [anon_sym_SQUOTE] = ACTIONS(2342),
    [anon_sym_L_DQUOTE] = ACTIONS(2342),
    [anon_sym_u_DQUOTE] = ACTIONS(2342),
    [anon_sym_U_DQUOTE] = ACTIONS(2342),
    [anon_sym_u8_DQUOTE] = ACTIONS(2342),
    [anon_sym_DQUOTE] = ACTIONS(2342),
    [sym_true] = ACTIONS(2340),
    [sym_false] = ACTIONS(2340),
    [anon_sym_NULL] = ACTIONS(2340),
    [anon_sym_nullptr] = ACTIONS(2340),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2340),
    [anon_sym_decltype] = ACTIONS(2340),
    [sym_virtual] = ACTIONS(2340),
    [anon_sym_explicit] = ACTIONS(2340),
    [anon_sym_typename] = ACTIONS(2340),
    [anon_sym_template] = ACTIONS(2340),
    [anon_sym_operator] = ACTIONS(2340),
    [anon_sym_try] = ACTIONS(2340),
    [anon_sym_delete] = ACTIONS(2340),
    [anon_sym_throw] = ACTIONS(2340),
    [anon_sym_namespace] = ACTIONS(2340),
    [anon_sym_using] = ACTIONS(2340),
    [anon_sym_static_assert] = ACTIONS(2340),
    [anon_sym_concept] = ACTIONS(2340),
    [anon_sym_co_return] = ACTIONS(2340),
    [anon_sym_co_yield] = ACTIONS(2340),
    [anon_sym_R_DQUOTE] = ACTIONS(2342),
    [anon_sym_LR_DQUOTE] = ACTIONS(2342),
    [anon_sym_uR_DQUOTE] = ACTIONS(2342),
    [anon_sym_UR_DQUOTE] = ACTIONS(2342),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2342),
    [anon_sym_co_await] = ACTIONS(2340),
    [anon_sym_new] = ACTIONS(2340),
    [anon_sym_requires] = ACTIONS(2340),
    [sym_this] = ACTIONS(2340),
    [anon_sym_discard] = ACTIONS(2340),
    [anon_sym_precise] = ACTIONS(2340),
    [anon_sym_shared] = ACTIONS(2340),
    [anon_sym_groupshared] = ACTIONS(2340),
    [anon_sym_uniform] = ACTIONS(2340),
    [anon_sym_row_major] = ACTIONS(2340),
    [anon_sym_column_major] = ACTIONS(2340),
    [anon_sym_globallycoherent] = ACTIONS(2340),
    [anon_sym_centroid] = ACTIONS(2340),
    [anon_sym_noperspective] = ACTIONS(2340),
    [anon_sym_nointerpolation] = ACTIONS(2340),
    [anon_sym_sample] = ACTIONS(2340),
    [anon_sym_linear] = ACTIONS(2340),
    [anon_sym_snorm] = ACTIONS(2340),
    [anon_sym_unorm] = ACTIONS(2340),
    [anon_sym_point] = ACTIONS(2340),
    [anon_sym_line] = ACTIONS(2340),
    [anon_sym_triangleadj] = ACTIONS(2340),
    [anon_sym_lineadj] = ACTIONS(2340),
    [anon_sym_triangle] = ACTIONS(2340),
    [anon_sym_cbuffer] = ACTIONS(2340),
  },
  [255] = {
    [sym_identifier] = ACTIONS(2344),
    [aux_sym_preproc_include_token1] = ACTIONS(2344),
    [aux_sym_preproc_def_token1] = ACTIONS(2344),
    [aux_sym_preproc_if_token1] = ACTIONS(2344),
    [aux_sym_preproc_if_token2] = ACTIONS(2344),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2344),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2344),
    [aux_sym_preproc_else_token1] = ACTIONS(2344),
    [aux_sym_preproc_elif_token1] = ACTIONS(2344),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2344),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2344),
    [sym_preproc_directive] = ACTIONS(2344),
    [anon_sym_LPAREN2] = ACTIONS(2346),
    [anon_sym_BANG] = ACTIONS(2346),
    [anon_sym_TILDE] = ACTIONS(2346),
    [anon_sym_DASH] = ACTIONS(2344),
    [anon_sym_PLUS] = ACTIONS(2344),
    [anon_sym_STAR] = ACTIONS(2346),
    [anon_sym_AMP_AMP] = ACTIONS(2346),
    [anon_sym_AMP] = ACTIONS(2344),
    [anon_sym_SEMI] = ACTIONS(2346),
    [anon_sym___extension__] = ACTIONS(2344),
    [anon_sym_typedef] = ACTIONS(2344),
    [anon_sym_in] = ACTIONS(2344),
    [anon_sym_out] = ACTIONS(2344),
    [anon_sym_inout] = ACTIONS(2344),
    [anon_sym_extern] = ACTIONS(2344),
    [anon_sym___attribute__] = ACTIONS(2344),
    [anon_sym_COLON_COLON] = ACTIONS(2346),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2346),
    [anon_sym___declspec] = ACTIONS(2344),
    [anon_sym___based] = ACTIONS(2344),
    [anon_sym___cdecl] = ACTIONS(2344),
    [anon_sym___clrcall] = ACTIONS(2344),
    [anon_sym___stdcall] = ACTIONS(2344),
    [anon_sym___fastcall] = ACTIONS(2344),
    [anon_sym___thiscall] = ACTIONS(2344),
    [anon_sym___vectorcall] = ACTIONS(2344),
    [anon_sym_LBRACE] = ACTIONS(2346),
    [anon_sym_signed] = ACTIONS(2344),
    [anon_sym_unsigned] = ACTIONS(2344),
    [anon_sym_long] = ACTIONS(2344),
    [anon_sym_short] = ACTIONS(2344),
    [anon_sym_LBRACK] = ACTIONS(2344),
    [anon_sym_static] = ACTIONS(2344),
    [anon_sym_register] = ACTIONS(2344),
    [anon_sym_inline] = ACTIONS(2344),
    [anon_sym___inline] = ACTIONS(2344),
    [anon_sym___inline__] = ACTIONS(2344),
    [anon_sym___forceinline] = ACTIONS(2344),
    [anon_sym_thread_local] = ACTIONS(2344),
    [anon_sym___thread] = ACTIONS(2344),
    [anon_sym_const] = ACTIONS(2344),
    [anon_sym_constexpr] = ACTIONS(2344),
    [anon_sym_volatile] = ACTIONS(2344),
    [anon_sym_restrict] = ACTIONS(2344),
    [anon_sym___restrict__] = ACTIONS(2344),
    [anon_sym__Atomic] = ACTIONS(2344),
    [anon_sym__Noreturn] = ACTIONS(2344),
    [anon_sym_noreturn] = ACTIONS(2344),
    [anon_sym_mutable] = ACTIONS(2344),
    [anon_sym_constinit] = ACTIONS(2344),
    [anon_sym_consteval] = ACTIONS(2344),
    [anon_sym_alignas] = ACTIONS(2344),
    [anon_sym__Alignas] = ACTIONS(2344),
    [sym_primitive_type] = ACTIONS(2344),
    [anon_sym_enum] = ACTIONS(2344),
    [anon_sym_class] = ACTIONS(2344),
    [anon_sym_struct] = ACTIONS(2344),
    [anon_sym_union] = ACTIONS(2344),
    [anon_sym_if] = ACTIONS(2344),
    [anon_sym_switch] = ACTIONS(2344),
    [anon_sym_case] = ACTIONS(2344),
    [anon_sym_default] = ACTIONS(2344),
    [anon_sym_while] = ACTIONS(2344),
    [anon_sym_do] = ACTIONS(2344),
    [anon_sym_for] = ACTIONS(2344),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_break] = ACTIONS(2344),
    [anon_sym_continue] = ACTIONS(2344),
    [anon_sym_goto] = ACTIONS(2344),
    [anon_sym___try] = ACTIONS(2344),
    [anon_sym___leave] = ACTIONS(2344),
    [anon_sym_not] = ACTIONS(2344),
    [anon_sym_compl] = ACTIONS(2344),
    [anon_sym_DASH_DASH] = ACTIONS(2346),
    [anon_sym_PLUS_PLUS] = ACTIONS(2346),
    [anon_sym_sizeof] = ACTIONS(2344),
    [anon_sym___alignof__] = ACTIONS(2344),
    [anon_sym___alignof] = ACTIONS(2344),
    [anon_sym__alignof] = ACTIONS(2344),
    [anon_sym_alignof] = ACTIONS(2344),
    [anon_sym__Alignof] = ACTIONS(2344),
    [anon_sym_offsetof] = ACTIONS(2344),
    [anon_sym__Generic] = ACTIONS(2344),
    [anon_sym_asm] = ACTIONS(2344),
    [anon_sym___asm__] = ACTIONS(2344),
    [sym_number_literal] = ACTIONS(2346),
    [anon_sym_L_SQUOTE] = ACTIONS(2346),
    [anon_sym_u_SQUOTE] = ACTIONS(2346),
    [anon_sym_U_SQUOTE] = ACTIONS(2346),
    [anon_sym_u8_SQUOTE] = ACTIONS(2346),
    [anon_sym_SQUOTE] = ACTIONS(2346),
    [anon_sym_L_DQUOTE] = ACTIONS(2346),
    [anon_sym_u_DQUOTE] = ACTIONS(2346),
    [anon_sym_U_DQUOTE] = ACTIONS(2346),
    [anon_sym_u8_DQUOTE] = ACTIONS(2346),
    [anon_sym_DQUOTE] = ACTIONS(2346),
    [sym_true] = ACTIONS(2344),
    [sym_false] = ACTIONS(2344),
    [anon_sym_NULL] = ACTIONS(2344),
    [anon_sym_nullptr] = ACTIONS(2344),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2344),
    [anon_sym_decltype] = ACTIONS(2344),
    [sym_virtual] = ACTIONS(2344),
    [anon_sym_explicit] = ACTIONS(2344),
    [anon_sym_typename] = ACTIONS(2344),
    [anon_sym_template] = ACTIONS(2344),
    [anon_sym_operator] = ACTIONS(2344),
    [anon_sym_try] = ACTIONS(2344),
    [anon_sym_delete] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2344),
    [anon_sym_namespace] = ACTIONS(2344),
    [anon_sym_using] = ACTIONS(2344),
    [anon_sym_static_assert] = ACTIONS(2344),
    [anon_sym_concept] = ACTIONS(2344),
    [anon_sym_co_return] = ACTIONS(2344),
    [anon_sym_co_yield] = ACTIONS(2344),
    [anon_sym_R_DQUOTE] = ACTIONS(2346),
    [anon_sym_LR_DQUOTE] = ACTIONS(2346),
    [anon_sym_uR_DQUOTE] = ACTIONS(2346),
    [anon_sym_UR_DQUOTE] = ACTIONS(2346),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2346),
    [anon_sym_co_await] = ACTIONS(2344),
    [anon_sym_new] = ACTIONS(2344),
    [anon_sym_requires] = ACTIONS(2344),
    [sym_this] = ACTIONS(2344),
    [anon_sym_discard] = ACTIONS(2344),
    [anon_sym_precise] = ACTIONS(2344),
    [anon_sym_shared] = ACTIONS(2344),
    [anon_sym_groupshared] = ACTIONS(2344),
    [anon_sym_uniform] = ACTIONS(2344),
    [anon_sym_row_major] = ACTIONS(2344),
    [anon_sym_column_major] = ACTIONS(2344),
    [anon_sym_globallycoherent] = ACTIONS(2344),
    [anon_sym_centroid] = ACTIONS(2344),
    [anon_sym_noperspective] = ACTIONS(2344),
    [anon_sym_nointerpolation] = ACTIONS(2344),
    [anon_sym_sample] = ACTIONS(2344),
    [anon_sym_linear] = ACTIONS(2344),
    [anon_sym_snorm] = ACTIONS(2344),
    [anon_sym_unorm] = ACTIONS(2344),
    [anon_sym_point] = ACTIONS(2344),
    [anon_sym_line] = ACTIONS(2344),
    [anon_sym_triangleadj] = ACTIONS(2344),
    [anon_sym_lineadj] = ACTIONS(2344),
    [anon_sym_triangle] = ACTIONS(2344),
    [anon_sym_cbuffer] = ACTIONS(2344),
  },
  [256] = {
    [sym_identifier] = ACTIONS(2348),
    [aux_sym_preproc_include_token1] = ACTIONS(2348),
    [aux_sym_preproc_def_token1] = ACTIONS(2348),
    [aux_sym_preproc_if_token1] = ACTIONS(2348),
    [aux_sym_preproc_if_token2] = ACTIONS(2348),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2348),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2348),
    [aux_sym_preproc_else_token1] = ACTIONS(2348),
    [aux_sym_preproc_elif_token1] = ACTIONS(2348),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2348),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2348),
    [sym_preproc_directive] = ACTIONS(2348),
    [anon_sym_LPAREN2] = ACTIONS(2350),
    [anon_sym_BANG] = ACTIONS(2350),
    [anon_sym_TILDE] = ACTIONS(2350),
    [anon_sym_DASH] = ACTIONS(2348),
    [anon_sym_PLUS] = ACTIONS(2348),
    [anon_sym_STAR] = ACTIONS(2350),
    [anon_sym_AMP_AMP] = ACTIONS(2350),
    [anon_sym_AMP] = ACTIONS(2348),
    [anon_sym_SEMI] = ACTIONS(2350),
    [anon_sym___extension__] = ACTIONS(2348),
    [anon_sym_typedef] = ACTIONS(2348),
    [anon_sym_in] = ACTIONS(2348),
    [anon_sym_out] = ACTIONS(2348),
    [anon_sym_inout] = ACTIONS(2348),
    [anon_sym_extern] = ACTIONS(2348),
    [anon_sym___attribute__] = ACTIONS(2348),
    [anon_sym_COLON_COLON] = ACTIONS(2350),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2350),
    [anon_sym___declspec] = ACTIONS(2348),
    [anon_sym___based] = ACTIONS(2348),
    [anon_sym___cdecl] = ACTIONS(2348),
    [anon_sym___clrcall] = ACTIONS(2348),
    [anon_sym___stdcall] = ACTIONS(2348),
    [anon_sym___fastcall] = ACTIONS(2348),
    [anon_sym___thiscall] = ACTIONS(2348),
    [anon_sym___vectorcall] = ACTIONS(2348),
    [anon_sym_LBRACE] = ACTIONS(2350),
    [anon_sym_signed] = ACTIONS(2348),
    [anon_sym_unsigned] = ACTIONS(2348),
    [anon_sym_long] = ACTIONS(2348),
    [anon_sym_short] = ACTIONS(2348),
    [anon_sym_LBRACK] = ACTIONS(2348),
    [anon_sym_static] = ACTIONS(2348),
    [anon_sym_register] = ACTIONS(2348),
    [anon_sym_inline] = ACTIONS(2348),
    [anon_sym___inline] = ACTIONS(2348),
    [anon_sym___inline__] = ACTIONS(2348),
    [anon_sym___forceinline] = ACTIONS(2348),
    [anon_sym_thread_local] = ACTIONS(2348),
    [anon_sym___thread] = ACTIONS(2348),
    [anon_sym_const] = ACTIONS(2348),
    [anon_sym_constexpr] = ACTIONS(2348),
    [anon_sym_volatile] = ACTIONS(2348),
    [anon_sym_restrict] = ACTIONS(2348),
    [anon_sym___restrict__] = ACTIONS(2348),
    [anon_sym__Atomic] = ACTIONS(2348),
    [anon_sym__Noreturn] = ACTIONS(2348),
    [anon_sym_noreturn] = ACTIONS(2348),
    [anon_sym_mutable] = ACTIONS(2348),
    [anon_sym_constinit] = ACTIONS(2348),
    [anon_sym_consteval] = ACTIONS(2348),
    [anon_sym_alignas] = ACTIONS(2348),
    [anon_sym__Alignas] = ACTIONS(2348),
    [sym_primitive_type] = ACTIONS(2348),
    [anon_sym_enum] = ACTIONS(2348),
    [anon_sym_class] = ACTIONS(2348),
    [anon_sym_struct] = ACTIONS(2348),
    [anon_sym_union] = ACTIONS(2348),
    [anon_sym_if] = ACTIONS(2348),
    [anon_sym_switch] = ACTIONS(2348),
    [anon_sym_case] = ACTIONS(2348),
    [anon_sym_default] = ACTIONS(2348),
    [anon_sym_while] = ACTIONS(2348),
    [anon_sym_do] = ACTIONS(2348),
    [anon_sym_for] = ACTIONS(2348),
    [anon_sym_return] = ACTIONS(2348),
    [anon_sym_break] = ACTIONS(2348),
    [anon_sym_continue] = ACTIONS(2348),
    [anon_sym_goto] = ACTIONS(2348),
    [anon_sym___try] = ACTIONS(2348),
    [anon_sym___leave] = ACTIONS(2348),
    [anon_sym_not] = ACTIONS(2348),
    [anon_sym_compl] = ACTIONS(2348),
    [anon_sym_DASH_DASH] = ACTIONS(2350),
    [anon_sym_PLUS_PLUS] = ACTIONS(2350),
    [anon_sym_sizeof] = ACTIONS(2348),
    [anon_sym___alignof__] = ACTIONS(2348),
    [anon_sym___alignof] = ACTIONS(2348),
    [anon_sym__alignof] = ACTIONS(2348),
    [anon_sym_alignof] = ACTIONS(2348),
    [anon_sym__Alignof] = ACTIONS(2348),
    [anon_sym_offsetof] = ACTIONS(2348),
    [anon_sym__Generic] = ACTIONS(2348),
    [anon_sym_asm] = ACTIONS(2348),
    [anon_sym___asm__] = ACTIONS(2348),
    [sym_number_literal] = ACTIONS(2350),
    [anon_sym_L_SQUOTE] = ACTIONS(2350),
    [anon_sym_u_SQUOTE] = ACTIONS(2350),
    [anon_sym_U_SQUOTE] = ACTIONS(2350),
    [anon_sym_u8_SQUOTE] = ACTIONS(2350),
    [anon_sym_SQUOTE] = ACTIONS(2350),
    [anon_sym_L_DQUOTE] = ACTIONS(2350),
    [anon_sym_u_DQUOTE] = ACTIONS(2350),
    [anon_sym_U_DQUOTE] = ACTIONS(2350),
    [anon_sym_u8_DQUOTE] = ACTIONS(2350),
    [anon_sym_DQUOTE] = ACTIONS(2350),
    [sym_true] = ACTIONS(2348),
    [sym_false] = ACTIONS(2348),
    [anon_sym_NULL] = ACTIONS(2348),
    [anon_sym_nullptr] = ACTIONS(2348),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2348),
    [anon_sym_decltype] = ACTIONS(2348),
    [sym_virtual] = ACTIONS(2348),
    [anon_sym_explicit] = ACTIONS(2348),
    [anon_sym_typename] = ACTIONS(2348),
    [anon_sym_template] = ACTIONS(2348),
    [anon_sym_operator] = ACTIONS(2348),
    [anon_sym_try] = ACTIONS(2348),
    [anon_sym_delete] = ACTIONS(2348),
    [anon_sym_throw] = ACTIONS(2348),
    [anon_sym_namespace] = ACTIONS(2348),
    [anon_sym_using] = ACTIONS(2348),
    [anon_sym_static_assert] = ACTIONS(2348),
    [anon_sym_concept] = ACTIONS(2348),
    [anon_sym_co_return] = ACTIONS(2348),
    [anon_sym_co_yield] = ACTIONS(2348),
    [anon_sym_R_DQUOTE] = ACTIONS(2350),
    [anon_sym_LR_DQUOTE] = ACTIONS(2350),
    [anon_sym_uR_DQUOTE] = ACTIONS(2350),
    [anon_sym_UR_DQUOTE] = ACTIONS(2350),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2350),
    [anon_sym_co_await] = ACTIONS(2348),
    [anon_sym_new] = ACTIONS(2348),
    [anon_sym_requires] = ACTIONS(2348),
    [sym_this] = ACTIONS(2348),
    [anon_sym_discard] = ACTIONS(2348),
    [anon_sym_precise] = ACTIONS(2348),
    [anon_sym_shared] = ACTIONS(2348),
    [anon_sym_groupshared] = ACTIONS(2348),
    [anon_sym_uniform] = ACTIONS(2348),
    [anon_sym_row_major] = ACTIONS(2348),
    [anon_sym_column_major] = ACTIONS(2348),
    [anon_sym_globallycoherent] = ACTIONS(2348),
    [anon_sym_centroid] = ACTIONS(2348),
    [anon_sym_noperspective] = ACTIONS(2348),
    [anon_sym_nointerpolation] = ACTIONS(2348),
    [anon_sym_sample] = ACTIONS(2348),
    [anon_sym_linear] = ACTIONS(2348),
    [anon_sym_snorm] = ACTIONS(2348),
    [anon_sym_unorm] = ACTIONS(2348),
    [anon_sym_point] = ACTIONS(2348),
    [anon_sym_line] = ACTIONS(2348),
    [anon_sym_triangleadj] = ACTIONS(2348),
    [anon_sym_lineadj] = ACTIONS(2348),
    [anon_sym_triangle] = ACTIONS(2348),
    [anon_sym_cbuffer] = ACTIONS(2348),
  },
  [257] = {
    [sym_identifier] = ACTIONS(2352),
    [aux_sym_preproc_include_token1] = ACTIONS(2352),
    [aux_sym_preproc_def_token1] = ACTIONS(2352),
    [aux_sym_preproc_if_token1] = ACTIONS(2352),
    [aux_sym_preproc_if_token2] = ACTIONS(2352),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2352),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2352),
    [aux_sym_preproc_else_token1] = ACTIONS(2352),
    [aux_sym_preproc_elif_token1] = ACTIONS(2352),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2352),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2352),
    [sym_preproc_directive] = ACTIONS(2352),
    [anon_sym_LPAREN2] = ACTIONS(2354),
    [anon_sym_BANG] = ACTIONS(2354),
    [anon_sym_TILDE] = ACTIONS(2354),
    [anon_sym_DASH] = ACTIONS(2352),
    [anon_sym_PLUS] = ACTIONS(2352),
    [anon_sym_STAR] = ACTIONS(2354),
    [anon_sym_AMP_AMP] = ACTIONS(2354),
    [anon_sym_AMP] = ACTIONS(2352),
    [anon_sym_SEMI] = ACTIONS(2354),
    [anon_sym___extension__] = ACTIONS(2352),
    [anon_sym_typedef] = ACTIONS(2352),
    [anon_sym_in] = ACTIONS(2352),
    [anon_sym_out] = ACTIONS(2352),
    [anon_sym_inout] = ACTIONS(2352),
    [anon_sym_extern] = ACTIONS(2352),
    [anon_sym___attribute__] = ACTIONS(2352),
    [anon_sym_COLON_COLON] = ACTIONS(2354),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2354),
    [anon_sym___declspec] = ACTIONS(2352),
    [anon_sym___based] = ACTIONS(2352),
    [anon_sym___cdecl] = ACTIONS(2352),
    [anon_sym___clrcall] = ACTIONS(2352),
    [anon_sym___stdcall] = ACTIONS(2352),
    [anon_sym___fastcall] = ACTIONS(2352),
    [anon_sym___thiscall] = ACTIONS(2352),
    [anon_sym___vectorcall] = ACTIONS(2352),
    [anon_sym_LBRACE] = ACTIONS(2354),
    [anon_sym_signed] = ACTIONS(2352),
    [anon_sym_unsigned] = ACTIONS(2352),
    [anon_sym_long] = ACTIONS(2352),
    [anon_sym_short] = ACTIONS(2352),
    [anon_sym_LBRACK] = ACTIONS(2352),
    [anon_sym_static] = ACTIONS(2352),
    [anon_sym_register] = ACTIONS(2352),
    [anon_sym_inline] = ACTIONS(2352),
    [anon_sym___inline] = ACTIONS(2352),
    [anon_sym___inline__] = ACTIONS(2352),
    [anon_sym___forceinline] = ACTIONS(2352),
    [anon_sym_thread_local] = ACTIONS(2352),
    [anon_sym___thread] = ACTIONS(2352),
    [anon_sym_const] = ACTIONS(2352),
    [anon_sym_constexpr] = ACTIONS(2352),
    [anon_sym_volatile] = ACTIONS(2352),
    [anon_sym_restrict] = ACTIONS(2352),
    [anon_sym___restrict__] = ACTIONS(2352),
    [anon_sym__Atomic] = ACTIONS(2352),
    [anon_sym__Noreturn] = ACTIONS(2352),
    [anon_sym_noreturn] = ACTIONS(2352),
    [anon_sym_mutable] = ACTIONS(2352),
    [anon_sym_constinit] = ACTIONS(2352),
    [anon_sym_consteval] = ACTIONS(2352),
    [anon_sym_alignas] = ACTIONS(2352),
    [anon_sym__Alignas] = ACTIONS(2352),
    [sym_primitive_type] = ACTIONS(2352),
    [anon_sym_enum] = ACTIONS(2352),
    [anon_sym_class] = ACTIONS(2352),
    [anon_sym_struct] = ACTIONS(2352),
    [anon_sym_union] = ACTIONS(2352),
    [anon_sym_if] = ACTIONS(2352),
    [anon_sym_switch] = ACTIONS(2352),
    [anon_sym_case] = ACTIONS(2352),
    [anon_sym_default] = ACTIONS(2352),
    [anon_sym_while] = ACTIONS(2352),
    [anon_sym_do] = ACTIONS(2352),
    [anon_sym_for] = ACTIONS(2352),
    [anon_sym_return] = ACTIONS(2352),
    [anon_sym_break] = ACTIONS(2352),
    [anon_sym_continue] = ACTIONS(2352),
    [anon_sym_goto] = ACTIONS(2352),
    [anon_sym___try] = ACTIONS(2352),
    [anon_sym___leave] = ACTIONS(2352),
    [anon_sym_not] = ACTIONS(2352),
    [anon_sym_compl] = ACTIONS(2352),
    [anon_sym_DASH_DASH] = ACTIONS(2354),
    [anon_sym_PLUS_PLUS] = ACTIONS(2354),
    [anon_sym_sizeof] = ACTIONS(2352),
    [anon_sym___alignof__] = ACTIONS(2352),
    [anon_sym___alignof] = ACTIONS(2352),
    [anon_sym__alignof] = ACTIONS(2352),
    [anon_sym_alignof] = ACTIONS(2352),
    [anon_sym__Alignof] = ACTIONS(2352),
    [anon_sym_offsetof] = ACTIONS(2352),
    [anon_sym__Generic] = ACTIONS(2352),
    [anon_sym_asm] = ACTIONS(2352),
    [anon_sym___asm__] = ACTIONS(2352),
    [sym_number_literal] = ACTIONS(2354),
    [anon_sym_L_SQUOTE] = ACTIONS(2354),
    [anon_sym_u_SQUOTE] = ACTIONS(2354),
    [anon_sym_U_SQUOTE] = ACTIONS(2354),
    [anon_sym_u8_SQUOTE] = ACTIONS(2354),
    [anon_sym_SQUOTE] = ACTIONS(2354),
    [anon_sym_L_DQUOTE] = ACTIONS(2354),
    [anon_sym_u_DQUOTE] = ACTIONS(2354),
    [anon_sym_U_DQUOTE] = ACTIONS(2354),
    [anon_sym_u8_DQUOTE] = ACTIONS(2354),
    [anon_sym_DQUOTE] = ACTIONS(2354),
    [sym_true] = ACTIONS(2352),
    [sym_false] = ACTIONS(2352),
    [anon_sym_NULL] = ACTIONS(2352),
    [anon_sym_nullptr] = ACTIONS(2352),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2352),
    [anon_sym_decltype] = ACTIONS(2352),
    [sym_virtual] = ACTIONS(2352),
    [anon_sym_explicit] = ACTIONS(2352),
    [anon_sym_typename] = ACTIONS(2352),
    [anon_sym_template] = ACTIONS(2352),
    [anon_sym_operator] = ACTIONS(2352),
    [anon_sym_try] = ACTIONS(2352),
    [anon_sym_delete] = ACTIONS(2352),
    [anon_sym_throw] = ACTIONS(2352),
    [anon_sym_namespace] = ACTIONS(2352),
    [anon_sym_using] = ACTIONS(2352),
    [anon_sym_static_assert] = ACTIONS(2352),
    [anon_sym_concept] = ACTIONS(2352),
    [anon_sym_co_return] = ACTIONS(2352),
    [anon_sym_co_yield] = ACTIONS(2352),
    [anon_sym_R_DQUOTE] = ACTIONS(2354),
    [anon_sym_LR_DQUOTE] = ACTIONS(2354),
    [anon_sym_uR_DQUOTE] = ACTIONS(2354),
    [anon_sym_UR_DQUOTE] = ACTIONS(2354),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2354),
    [anon_sym_co_await] = ACTIONS(2352),
    [anon_sym_new] = ACTIONS(2352),
    [anon_sym_requires] = ACTIONS(2352),
    [sym_this] = ACTIONS(2352),
    [anon_sym_discard] = ACTIONS(2352),
    [anon_sym_precise] = ACTIONS(2352),
    [anon_sym_shared] = ACTIONS(2352),
    [anon_sym_groupshared] = ACTIONS(2352),
    [anon_sym_uniform] = ACTIONS(2352),
    [anon_sym_row_major] = ACTIONS(2352),
    [anon_sym_column_major] = ACTIONS(2352),
    [anon_sym_globallycoherent] = ACTIONS(2352),
    [anon_sym_centroid] = ACTIONS(2352),
    [anon_sym_noperspective] = ACTIONS(2352),
    [anon_sym_nointerpolation] = ACTIONS(2352),
    [anon_sym_sample] = ACTIONS(2352),
    [anon_sym_linear] = ACTIONS(2352),
    [anon_sym_snorm] = ACTIONS(2352),
    [anon_sym_unorm] = ACTIONS(2352),
    [anon_sym_point] = ACTIONS(2352),
    [anon_sym_line] = ACTIONS(2352),
    [anon_sym_triangleadj] = ACTIONS(2352),
    [anon_sym_lineadj] = ACTIONS(2352),
    [anon_sym_triangle] = ACTIONS(2352),
    [anon_sym_cbuffer] = ACTIONS(2352),
  },
  [258] = {
    [sym_identifier] = ACTIONS(1895),
    [aux_sym_preproc_include_token1] = ACTIONS(1895),
    [aux_sym_preproc_def_token1] = ACTIONS(1895),
    [aux_sym_preproc_if_token1] = ACTIONS(1895),
    [aux_sym_preproc_if_token2] = ACTIONS(1895),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1895),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1895),
    [sym_preproc_directive] = ACTIONS(1895),
    [anon_sym_LPAREN2] = ACTIONS(1897),
    [anon_sym_BANG] = ACTIONS(1897),
    [anon_sym_TILDE] = ACTIONS(1897),
    [anon_sym_DASH] = ACTIONS(1895),
    [anon_sym_PLUS] = ACTIONS(1895),
    [anon_sym_STAR] = ACTIONS(1897),
    [anon_sym_AMP_AMP] = ACTIONS(1897),
    [anon_sym_AMP] = ACTIONS(1895),
    [anon_sym_COLON] = ACTIONS(1895),
    [anon_sym_SEMI] = ACTIONS(1897),
    [anon_sym___extension__] = ACTIONS(1895),
    [anon_sym_typedef] = ACTIONS(1895),
    [anon_sym_in] = ACTIONS(1895),
    [anon_sym_out] = ACTIONS(1895),
    [anon_sym_inout] = ACTIONS(1895),
    [anon_sym_extern] = ACTIONS(1895),
    [anon_sym___attribute__] = ACTIONS(1895),
    [anon_sym_COLON_COLON] = ACTIONS(1897),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1897),
    [anon_sym___declspec] = ACTIONS(1895),
    [anon_sym___based] = ACTIONS(1895),
    [anon_sym___cdecl] = ACTIONS(1895),
    [anon_sym___clrcall] = ACTIONS(1895),
    [anon_sym___stdcall] = ACTIONS(1895),
    [anon_sym___fastcall] = ACTIONS(1895),
    [anon_sym___thiscall] = ACTIONS(1895),
    [anon_sym___vectorcall] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1897),
    [anon_sym_signed] = ACTIONS(1895),
    [anon_sym_unsigned] = ACTIONS(1895),
    [anon_sym_long] = ACTIONS(1895),
    [anon_sym_short] = ACTIONS(1895),
    [anon_sym_LBRACK] = ACTIONS(1895),
    [anon_sym_static] = ACTIONS(1895),
    [anon_sym_register] = ACTIONS(1895),
    [anon_sym_inline] = ACTIONS(1895),
    [anon_sym___inline] = ACTIONS(1895),
    [anon_sym___inline__] = ACTIONS(1895),
    [anon_sym___forceinline] = ACTIONS(1895),
    [anon_sym_thread_local] = ACTIONS(1895),
    [anon_sym___thread] = ACTIONS(1895),
    [anon_sym_const] = ACTIONS(1895),
    [anon_sym_constexpr] = ACTIONS(1895),
    [anon_sym_volatile] = ACTIONS(1895),
    [anon_sym_restrict] = ACTIONS(1895),
    [anon_sym___restrict__] = ACTIONS(1895),
    [anon_sym__Atomic] = ACTIONS(1895),
    [anon_sym__Noreturn] = ACTIONS(1895),
    [anon_sym_noreturn] = ACTIONS(1895),
    [anon_sym_mutable] = ACTIONS(1895),
    [anon_sym_constinit] = ACTIONS(1895),
    [anon_sym_consteval] = ACTIONS(1895),
    [anon_sym_alignas] = ACTIONS(1895),
    [anon_sym__Alignas] = ACTIONS(1895),
    [sym_primitive_type] = ACTIONS(1895),
    [anon_sym_enum] = ACTIONS(1895),
    [anon_sym_class] = ACTIONS(1895),
    [anon_sym_struct] = ACTIONS(1895),
    [anon_sym_union] = ACTIONS(1895),
    [anon_sym_if] = ACTIONS(1895),
    [anon_sym_else] = ACTIONS(1895),
    [anon_sym_switch] = ACTIONS(1895),
    [anon_sym_case] = ACTIONS(1895),
    [anon_sym_default] = ACTIONS(1895),
    [anon_sym_while] = ACTIONS(1895),
    [anon_sym_do] = ACTIONS(1895),
    [anon_sym_for] = ACTIONS(1895),
    [anon_sym_return] = ACTIONS(1895),
    [anon_sym_break] = ACTIONS(1895),
    [anon_sym_continue] = ACTIONS(1895),
    [anon_sym_goto] = ACTIONS(1895),
    [anon_sym___try] = ACTIONS(1895),
    [anon_sym___leave] = ACTIONS(1895),
    [anon_sym_not] = ACTIONS(1895),
    [anon_sym_compl] = ACTIONS(1895),
    [anon_sym_DASH_DASH] = ACTIONS(1897),
    [anon_sym_PLUS_PLUS] = ACTIONS(1897),
    [anon_sym_sizeof] = ACTIONS(1895),
    [anon_sym___alignof__] = ACTIONS(1895),
    [anon_sym___alignof] = ACTIONS(1895),
    [anon_sym__alignof] = ACTIONS(1895),
    [anon_sym_alignof] = ACTIONS(1895),
    [anon_sym__Alignof] = ACTIONS(1895),
    [anon_sym_offsetof] = ACTIONS(1895),
    [anon_sym__Generic] = ACTIONS(1895),
    [anon_sym_asm] = ACTIONS(1895),
    [anon_sym___asm__] = ACTIONS(1895),
    [sym_number_literal] = ACTIONS(1897),
    [anon_sym_L_SQUOTE] = ACTIONS(1897),
    [anon_sym_u_SQUOTE] = ACTIONS(1897),
    [anon_sym_U_SQUOTE] = ACTIONS(1897),
    [anon_sym_u8_SQUOTE] = ACTIONS(1897),
    [anon_sym_SQUOTE] = ACTIONS(1897),
    [anon_sym_L_DQUOTE] = ACTIONS(1897),
    [anon_sym_u_DQUOTE] = ACTIONS(1897),
    [anon_sym_U_DQUOTE] = ACTIONS(1897),
    [anon_sym_u8_DQUOTE] = ACTIONS(1897),
    [anon_sym_DQUOTE] = ACTIONS(1897),
    [sym_true] = ACTIONS(1895),
    [sym_false] = ACTIONS(1895),
    [anon_sym_NULL] = ACTIONS(1895),
    [anon_sym_nullptr] = ACTIONS(1895),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1895),
    [anon_sym_decltype] = ACTIONS(1895),
    [anon_sym_final] = ACTIONS(1895),
    [anon_sym_override] = ACTIONS(1895),
    [sym_virtual] = ACTIONS(1895),
    [anon_sym_explicit] = ACTIONS(1895),
    [anon_sym_typename] = ACTIONS(1895),
    [anon_sym_template] = ACTIONS(1895),
    [anon_sym_operator] = ACTIONS(1895),
    [anon_sym_try] = ACTIONS(1895),
    [anon_sym_delete] = ACTIONS(1895),
    [anon_sym_throw] = ACTIONS(1895),
    [anon_sym_namespace] = ACTIONS(1895),
    [anon_sym_using] = ACTIONS(1895),
    [anon_sym_static_assert] = ACTIONS(1895),
    [anon_sym_concept] = ACTIONS(1895),
    [anon_sym_co_return] = ACTIONS(1895),
    [anon_sym_co_yield] = ACTIONS(1895),
    [anon_sym_R_DQUOTE] = ACTIONS(1897),
    [anon_sym_LR_DQUOTE] = ACTIONS(1897),
    [anon_sym_uR_DQUOTE] = ACTIONS(1897),
    [anon_sym_UR_DQUOTE] = ACTIONS(1897),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1897),
    [anon_sym_co_await] = ACTIONS(1895),
    [anon_sym_new] = ACTIONS(1895),
    [anon_sym_requires] = ACTIONS(1895),
    [sym_this] = ACTIONS(1895),
    [anon_sym_discard] = ACTIONS(1895),
    [anon_sym_precise] = ACTIONS(1895),
    [anon_sym_shared] = ACTIONS(1895),
    [anon_sym_groupshared] = ACTIONS(1895),
    [anon_sym_uniform] = ACTIONS(1895),
    [anon_sym_row_major] = ACTIONS(1895),
    [anon_sym_column_major] = ACTIONS(1895),
    [anon_sym_globallycoherent] = ACTIONS(1895),
    [anon_sym_centroid] = ACTIONS(1895),
    [anon_sym_noperspective] = ACTIONS(1895),
    [anon_sym_nointerpolation] = ACTIONS(1895),
    [anon_sym_sample] = ACTIONS(1895),
    [anon_sym_linear] = ACTIONS(1895),
    [anon_sym_snorm] = ACTIONS(1895),
    [anon_sym_unorm] = ACTIONS(1895),
    [anon_sym_point] = ACTIONS(1895),
    [anon_sym_line] = ACTIONS(1895),
    [anon_sym_triangleadj] = ACTIONS(1895),
    [anon_sym_lineadj] = ACTIONS(1895),
    [anon_sym_triangle] = ACTIONS(1895),
    [anon_sym_cbuffer] = ACTIONS(1895),
  },
  [259] = {
    [sym_identifier] = ACTIONS(2356),
    [aux_sym_preproc_include_token1] = ACTIONS(2356),
    [aux_sym_preproc_def_token1] = ACTIONS(2356),
    [aux_sym_preproc_if_token1] = ACTIONS(2356),
    [aux_sym_preproc_if_token2] = ACTIONS(2356),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2356),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2356),
    [aux_sym_preproc_else_token1] = ACTIONS(2356),
    [aux_sym_preproc_elif_token1] = ACTIONS(2356),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2356),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2356),
    [sym_preproc_directive] = ACTIONS(2356),
    [anon_sym_LPAREN2] = ACTIONS(2358),
    [anon_sym_BANG] = ACTIONS(2358),
    [anon_sym_TILDE] = ACTIONS(2358),
    [anon_sym_DASH] = ACTIONS(2356),
    [anon_sym_PLUS] = ACTIONS(2356),
    [anon_sym_STAR] = ACTIONS(2358),
    [anon_sym_AMP_AMP] = ACTIONS(2358),
    [anon_sym_AMP] = ACTIONS(2356),
    [anon_sym_SEMI] = ACTIONS(2358),
    [anon_sym___extension__] = ACTIONS(2356),
    [anon_sym_typedef] = ACTIONS(2356),
    [anon_sym_in] = ACTIONS(2356),
    [anon_sym_out] = ACTIONS(2356),
    [anon_sym_inout] = ACTIONS(2356),
    [anon_sym_extern] = ACTIONS(2356),
    [anon_sym___attribute__] = ACTIONS(2356),
    [anon_sym_COLON_COLON] = ACTIONS(2358),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2358),
    [anon_sym___declspec] = ACTIONS(2356),
    [anon_sym___based] = ACTIONS(2356),
    [anon_sym___cdecl] = ACTIONS(2356),
    [anon_sym___clrcall] = ACTIONS(2356),
    [anon_sym___stdcall] = ACTIONS(2356),
    [anon_sym___fastcall] = ACTIONS(2356),
    [anon_sym___thiscall] = ACTIONS(2356),
    [anon_sym___vectorcall] = ACTIONS(2356),
    [anon_sym_LBRACE] = ACTIONS(2358),
    [anon_sym_signed] = ACTIONS(2356),
    [anon_sym_unsigned] = ACTIONS(2356),
    [anon_sym_long] = ACTIONS(2356),
    [anon_sym_short] = ACTIONS(2356),
    [anon_sym_LBRACK] = ACTIONS(2356),
    [anon_sym_static] = ACTIONS(2356),
    [anon_sym_register] = ACTIONS(2356),
    [anon_sym_inline] = ACTIONS(2356),
    [anon_sym___inline] = ACTIONS(2356),
    [anon_sym___inline__] = ACTIONS(2356),
    [anon_sym___forceinline] = ACTIONS(2356),
    [anon_sym_thread_local] = ACTIONS(2356),
    [anon_sym___thread] = ACTIONS(2356),
    [anon_sym_const] = ACTIONS(2356),
    [anon_sym_constexpr] = ACTIONS(2356),
    [anon_sym_volatile] = ACTIONS(2356),
    [anon_sym_restrict] = ACTIONS(2356),
    [anon_sym___restrict__] = ACTIONS(2356),
    [anon_sym__Atomic] = ACTIONS(2356),
    [anon_sym__Noreturn] = ACTIONS(2356),
    [anon_sym_noreturn] = ACTIONS(2356),
    [anon_sym_mutable] = ACTIONS(2356),
    [anon_sym_constinit] = ACTIONS(2356),
    [anon_sym_consteval] = ACTIONS(2356),
    [anon_sym_alignas] = ACTIONS(2356),
    [anon_sym__Alignas] = ACTIONS(2356),
    [sym_primitive_type] = ACTIONS(2356),
    [anon_sym_enum] = ACTIONS(2356),
    [anon_sym_class] = ACTIONS(2356),
    [anon_sym_struct] = ACTIONS(2356),
    [anon_sym_union] = ACTIONS(2356),
    [anon_sym_if] = ACTIONS(2356),
    [anon_sym_switch] = ACTIONS(2356),
    [anon_sym_case] = ACTIONS(2356),
    [anon_sym_default] = ACTIONS(2356),
    [anon_sym_while] = ACTIONS(2356),
    [anon_sym_do] = ACTIONS(2356),
    [anon_sym_for] = ACTIONS(2356),
    [anon_sym_return] = ACTIONS(2356),
    [anon_sym_break] = ACTIONS(2356),
    [anon_sym_continue] = ACTIONS(2356),
    [anon_sym_goto] = ACTIONS(2356),
    [anon_sym___try] = ACTIONS(2356),
    [anon_sym___leave] = ACTIONS(2356),
    [anon_sym_not] = ACTIONS(2356),
    [anon_sym_compl] = ACTIONS(2356),
    [anon_sym_DASH_DASH] = ACTIONS(2358),
    [anon_sym_PLUS_PLUS] = ACTIONS(2358),
    [anon_sym_sizeof] = ACTIONS(2356),
    [anon_sym___alignof__] = ACTIONS(2356),
    [anon_sym___alignof] = ACTIONS(2356),
    [anon_sym__alignof] = ACTIONS(2356),
    [anon_sym_alignof] = ACTIONS(2356),
    [anon_sym__Alignof] = ACTIONS(2356),
    [anon_sym_offsetof] = ACTIONS(2356),
    [anon_sym__Generic] = ACTIONS(2356),
    [anon_sym_asm] = ACTIONS(2356),
    [anon_sym___asm__] = ACTIONS(2356),
    [sym_number_literal] = ACTIONS(2358),
    [anon_sym_L_SQUOTE] = ACTIONS(2358),
    [anon_sym_u_SQUOTE] = ACTIONS(2358),
    [anon_sym_U_SQUOTE] = ACTIONS(2358),
    [anon_sym_u8_SQUOTE] = ACTIONS(2358),
    [anon_sym_SQUOTE] = ACTIONS(2358),
    [anon_sym_L_DQUOTE] = ACTIONS(2358),
    [anon_sym_u_DQUOTE] = ACTIONS(2358),
    [anon_sym_U_DQUOTE] = ACTIONS(2358),
    [anon_sym_u8_DQUOTE] = ACTIONS(2358),
    [anon_sym_DQUOTE] = ACTIONS(2358),
    [sym_true] = ACTIONS(2356),
    [sym_false] = ACTIONS(2356),
    [anon_sym_NULL] = ACTIONS(2356),
    [anon_sym_nullptr] = ACTIONS(2356),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2356),
    [anon_sym_decltype] = ACTIONS(2356),
    [sym_virtual] = ACTIONS(2356),
    [anon_sym_explicit] = ACTIONS(2356),
    [anon_sym_typename] = ACTIONS(2356),
    [anon_sym_template] = ACTIONS(2356),
    [anon_sym_operator] = ACTIONS(2356),
    [anon_sym_try] = ACTIONS(2356),
    [anon_sym_delete] = ACTIONS(2356),
    [anon_sym_throw] = ACTIONS(2356),
    [anon_sym_namespace] = ACTIONS(2356),
    [anon_sym_using] = ACTIONS(2356),
    [anon_sym_static_assert] = ACTIONS(2356),
    [anon_sym_concept] = ACTIONS(2356),
    [anon_sym_co_return] = ACTIONS(2356),
    [anon_sym_co_yield] = ACTIONS(2356),
    [anon_sym_R_DQUOTE] = ACTIONS(2358),
    [anon_sym_LR_DQUOTE] = ACTIONS(2358),
    [anon_sym_uR_DQUOTE] = ACTIONS(2358),
    [anon_sym_UR_DQUOTE] = ACTIONS(2358),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2358),
    [anon_sym_co_await] = ACTIONS(2356),
    [anon_sym_new] = ACTIONS(2356),
    [anon_sym_requires] = ACTIONS(2356),
    [sym_this] = ACTIONS(2356),
    [anon_sym_discard] = ACTIONS(2356),
    [anon_sym_precise] = ACTIONS(2356),
    [anon_sym_shared] = ACTIONS(2356),
    [anon_sym_groupshared] = ACTIONS(2356),
    [anon_sym_uniform] = ACTIONS(2356),
    [anon_sym_row_major] = ACTIONS(2356),
    [anon_sym_column_major] = ACTIONS(2356),
    [anon_sym_globallycoherent] = ACTIONS(2356),
    [anon_sym_centroid] = ACTIONS(2356),
    [anon_sym_noperspective] = ACTIONS(2356),
    [anon_sym_nointerpolation] = ACTIONS(2356),
    [anon_sym_sample] = ACTIONS(2356),
    [anon_sym_linear] = ACTIONS(2356),
    [anon_sym_snorm] = ACTIONS(2356),
    [anon_sym_unorm] = ACTIONS(2356),
    [anon_sym_point] = ACTIONS(2356),
    [anon_sym_line] = ACTIONS(2356),
    [anon_sym_triangleadj] = ACTIONS(2356),
    [anon_sym_lineadj] = ACTIONS(2356),
    [anon_sym_triangle] = ACTIONS(2356),
    [anon_sym_cbuffer] = ACTIONS(2356),
  },
  [260] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_include_token1] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token2] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [aux_sym_preproc_else_token1] = ACTIONS(2332),
    [aux_sym_preproc_elif_token1] = ACTIONS(2332),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_BANG] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_DASH] = ACTIONS(2332),
    [anon_sym_PLUS] = ACTIONS(2332),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym_SEMI] = ACTIONS(2334),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym___cdecl] = ACTIONS(2332),
    [anon_sym___clrcall] = ACTIONS(2332),
    [anon_sym___stdcall] = ACTIONS(2332),
    [anon_sym___fastcall] = ACTIONS(2332),
    [anon_sym___thiscall] = ACTIONS(2332),
    [anon_sym___vectorcall] = ACTIONS(2332),
    [anon_sym_LBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_switch] = ACTIONS(2332),
    [anon_sym_case] = ACTIONS(2332),
    [anon_sym_default] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2332),
    [anon_sym_do] = ACTIONS(2332),
    [anon_sym_for] = ACTIONS(2332),
    [anon_sym_return] = ACTIONS(2332),
    [anon_sym_break] = ACTIONS(2332),
    [anon_sym_continue] = ACTIONS(2332),
    [anon_sym_goto] = ACTIONS(2332),
    [anon_sym___try] = ACTIONS(2332),
    [anon_sym___leave] = ACTIONS(2332),
    [anon_sym_not] = ACTIONS(2332),
    [anon_sym_compl] = ACTIONS(2332),
    [anon_sym_DASH_DASH] = ACTIONS(2334),
    [anon_sym_PLUS_PLUS] = ACTIONS(2334),
    [anon_sym_sizeof] = ACTIONS(2332),
    [anon_sym___alignof__] = ACTIONS(2332),
    [anon_sym___alignof] = ACTIONS(2332),
    [anon_sym__alignof] = ACTIONS(2332),
    [anon_sym_alignof] = ACTIONS(2332),
    [anon_sym__Alignof] = ACTIONS(2332),
    [anon_sym_offsetof] = ACTIONS(2332),
    [anon_sym__Generic] = ACTIONS(2332),
    [anon_sym_asm] = ACTIONS(2332),
    [anon_sym___asm__] = ACTIONS(2332),
    [sym_number_literal] = ACTIONS(2334),
    [anon_sym_L_SQUOTE] = ACTIONS(2334),
    [anon_sym_u_SQUOTE] = ACTIONS(2334),
    [anon_sym_U_SQUOTE] = ACTIONS(2334),
    [anon_sym_u8_SQUOTE] = ACTIONS(2334),
    [anon_sym_SQUOTE] = ACTIONS(2334),
    [anon_sym_L_DQUOTE] = ACTIONS(2334),
    [anon_sym_u_DQUOTE] = ACTIONS(2334),
    [anon_sym_U_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8_DQUOTE] = ACTIONS(2334),
    [anon_sym_DQUOTE] = ACTIONS(2334),
    [sym_true] = ACTIONS(2332),
    [sym_false] = ACTIONS(2332),
    [anon_sym_NULL] = ACTIONS(2332),
    [anon_sym_nullptr] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_try] = ACTIONS(2332),
    [anon_sym_delete] = ACTIONS(2332),
    [anon_sym_throw] = ACTIONS(2332),
    [anon_sym_namespace] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_concept] = ACTIONS(2332),
    [anon_sym_co_return] = ACTIONS(2332),
    [anon_sym_co_yield] = ACTIONS(2332),
    [anon_sym_R_DQUOTE] = ACTIONS(2334),
    [anon_sym_LR_DQUOTE] = ACTIONS(2334),
    [anon_sym_uR_DQUOTE] = ACTIONS(2334),
    [anon_sym_UR_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2334),
    [anon_sym_co_await] = ACTIONS(2332),
    [anon_sym_new] = ACTIONS(2332),
    [anon_sym_requires] = ACTIONS(2332),
    [sym_this] = ACTIONS(2332),
    [anon_sym_discard] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
    [anon_sym_cbuffer] = ACTIONS(2332),
  },
  [261] = {
    [sym_identifier] = ACTIONS(1903),
    [aux_sym_preproc_include_token1] = ACTIONS(1903),
    [aux_sym_preproc_def_token1] = ACTIONS(1903),
    [aux_sym_preproc_if_token1] = ACTIONS(1903),
    [aux_sym_preproc_if_token2] = ACTIONS(1903),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1903),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1903),
    [sym_preproc_directive] = ACTIONS(1903),
    [anon_sym_LPAREN2] = ACTIONS(1905),
    [anon_sym_BANG] = ACTIONS(1905),
    [anon_sym_TILDE] = ACTIONS(1905),
    [anon_sym_DASH] = ACTIONS(1903),
    [anon_sym_PLUS] = ACTIONS(1903),
    [anon_sym_STAR] = ACTIONS(1905),
    [anon_sym_AMP_AMP] = ACTIONS(1905),
    [anon_sym_AMP] = ACTIONS(1903),
    [anon_sym_COLON] = ACTIONS(1903),
    [anon_sym_SEMI] = ACTIONS(1905),
    [anon_sym___extension__] = ACTIONS(1903),
    [anon_sym_typedef] = ACTIONS(1903),
    [anon_sym_in] = ACTIONS(1903),
    [anon_sym_out] = ACTIONS(1903),
    [anon_sym_inout] = ACTIONS(1903),
    [anon_sym_extern] = ACTIONS(1903),
    [anon_sym___attribute__] = ACTIONS(1903),
    [anon_sym_COLON_COLON] = ACTIONS(1905),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1905),
    [anon_sym___declspec] = ACTIONS(1903),
    [anon_sym___based] = ACTIONS(1903),
    [anon_sym___cdecl] = ACTIONS(1903),
    [anon_sym___clrcall] = ACTIONS(1903),
    [anon_sym___stdcall] = ACTIONS(1903),
    [anon_sym___fastcall] = ACTIONS(1903),
    [anon_sym___thiscall] = ACTIONS(1903),
    [anon_sym___vectorcall] = ACTIONS(1903),
    [anon_sym_LBRACE] = ACTIONS(1905),
    [anon_sym_signed] = ACTIONS(1903),
    [anon_sym_unsigned] = ACTIONS(1903),
    [anon_sym_long] = ACTIONS(1903),
    [anon_sym_short] = ACTIONS(1903),
    [anon_sym_LBRACK] = ACTIONS(1903),
    [anon_sym_static] = ACTIONS(1903),
    [anon_sym_register] = ACTIONS(1903),
    [anon_sym_inline] = ACTIONS(1903),
    [anon_sym___inline] = ACTIONS(1903),
    [anon_sym___inline__] = ACTIONS(1903),
    [anon_sym___forceinline] = ACTIONS(1903),
    [anon_sym_thread_local] = ACTIONS(1903),
    [anon_sym___thread] = ACTIONS(1903),
    [anon_sym_const] = ACTIONS(1903),
    [anon_sym_constexpr] = ACTIONS(1903),
    [anon_sym_volatile] = ACTIONS(1903),
    [anon_sym_restrict] = ACTIONS(1903),
    [anon_sym___restrict__] = ACTIONS(1903),
    [anon_sym__Atomic] = ACTIONS(1903),
    [anon_sym__Noreturn] = ACTIONS(1903),
    [anon_sym_noreturn] = ACTIONS(1903),
    [anon_sym_mutable] = ACTIONS(1903),
    [anon_sym_constinit] = ACTIONS(1903),
    [anon_sym_consteval] = ACTIONS(1903),
    [anon_sym_alignas] = ACTIONS(1903),
    [anon_sym__Alignas] = ACTIONS(1903),
    [sym_primitive_type] = ACTIONS(1903),
    [anon_sym_enum] = ACTIONS(1903),
    [anon_sym_class] = ACTIONS(1903),
    [anon_sym_struct] = ACTIONS(1903),
    [anon_sym_union] = ACTIONS(1903),
    [anon_sym_if] = ACTIONS(1903),
    [anon_sym_else] = ACTIONS(1903),
    [anon_sym_switch] = ACTIONS(1903),
    [anon_sym_case] = ACTIONS(1903),
    [anon_sym_default] = ACTIONS(1903),
    [anon_sym_while] = ACTIONS(1903),
    [anon_sym_do] = ACTIONS(1903),
    [anon_sym_for] = ACTIONS(1903),
    [anon_sym_return] = ACTIONS(1903),
    [anon_sym_break] = ACTIONS(1903),
    [anon_sym_continue] = ACTIONS(1903),
    [anon_sym_goto] = ACTIONS(1903),
    [anon_sym___try] = ACTIONS(1903),
    [anon_sym___leave] = ACTIONS(1903),
    [anon_sym_not] = ACTIONS(1903),
    [anon_sym_compl] = ACTIONS(1903),
    [anon_sym_DASH_DASH] = ACTIONS(1905),
    [anon_sym_PLUS_PLUS] = ACTIONS(1905),
    [anon_sym_sizeof] = ACTIONS(1903),
    [anon_sym___alignof__] = ACTIONS(1903),
    [anon_sym___alignof] = ACTIONS(1903),
    [anon_sym__alignof] = ACTIONS(1903),
    [anon_sym_alignof] = ACTIONS(1903),
    [anon_sym__Alignof] = ACTIONS(1903),
    [anon_sym_offsetof] = ACTIONS(1903),
    [anon_sym__Generic] = ACTIONS(1903),
    [anon_sym_asm] = ACTIONS(1903),
    [anon_sym___asm__] = ACTIONS(1903),
    [sym_number_literal] = ACTIONS(1905),
    [anon_sym_L_SQUOTE] = ACTIONS(1905),
    [anon_sym_u_SQUOTE] = ACTIONS(1905),
    [anon_sym_U_SQUOTE] = ACTIONS(1905),
    [anon_sym_u8_SQUOTE] = ACTIONS(1905),
    [anon_sym_SQUOTE] = ACTIONS(1905),
    [anon_sym_L_DQUOTE] = ACTIONS(1905),
    [anon_sym_u_DQUOTE] = ACTIONS(1905),
    [anon_sym_U_DQUOTE] = ACTIONS(1905),
    [anon_sym_u8_DQUOTE] = ACTIONS(1905),
    [anon_sym_DQUOTE] = ACTIONS(1905),
    [sym_true] = ACTIONS(1903),
    [sym_false] = ACTIONS(1903),
    [anon_sym_NULL] = ACTIONS(1903),
    [anon_sym_nullptr] = ACTIONS(1903),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1903),
    [anon_sym_decltype] = ACTIONS(1903),
    [anon_sym_final] = ACTIONS(1903),
    [anon_sym_override] = ACTIONS(1903),
    [sym_virtual] = ACTIONS(1903),
    [anon_sym_explicit] = ACTIONS(1903),
    [anon_sym_typename] = ACTIONS(1903),
    [anon_sym_template] = ACTIONS(1903),
    [anon_sym_operator] = ACTIONS(1903),
    [anon_sym_try] = ACTIONS(1903),
    [anon_sym_delete] = ACTIONS(1903),
    [anon_sym_throw] = ACTIONS(1903),
    [anon_sym_namespace] = ACTIONS(1903),
    [anon_sym_using] = ACTIONS(1903),
    [anon_sym_static_assert] = ACTIONS(1903),
    [anon_sym_concept] = ACTIONS(1903),
    [anon_sym_co_return] = ACTIONS(1903),
    [anon_sym_co_yield] = ACTIONS(1903),
    [anon_sym_R_DQUOTE] = ACTIONS(1905),
    [anon_sym_LR_DQUOTE] = ACTIONS(1905),
    [anon_sym_uR_DQUOTE] = ACTIONS(1905),
    [anon_sym_UR_DQUOTE] = ACTIONS(1905),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1905),
    [anon_sym_co_await] = ACTIONS(1903),
    [anon_sym_new] = ACTIONS(1903),
    [anon_sym_requires] = ACTIONS(1903),
    [sym_this] = ACTIONS(1903),
    [anon_sym_discard] = ACTIONS(1903),
    [anon_sym_precise] = ACTIONS(1903),
    [anon_sym_shared] = ACTIONS(1903),
    [anon_sym_groupshared] = ACTIONS(1903),
    [anon_sym_uniform] = ACTIONS(1903),
    [anon_sym_row_major] = ACTIONS(1903),
    [anon_sym_column_major] = ACTIONS(1903),
    [anon_sym_globallycoherent] = ACTIONS(1903),
    [anon_sym_centroid] = ACTIONS(1903),
    [anon_sym_noperspective] = ACTIONS(1903),
    [anon_sym_nointerpolation] = ACTIONS(1903),
    [anon_sym_sample] = ACTIONS(1903),
    [anon_sym_linear] = ACTIONS(1903),
    [anon_sym_snorm] = ACTIONS(1903),
    [anon_sym_unorm] = ACTIONS(1903),
    [anon_sym_point] = ACTIONS(1903),
    [anon_sym_line] = ACTIONS(1903),
    [anon_sym_triangleadj] = ACTIONS(1903),
    [anon_sym_lineadj] = ACTIONS(1903),
    [anon_sym_triangle] = ACTIONS(1903),
    [anon_sym_cbuffer] = ACTIONS(1903),
  },
  [262] = {
    [sym_identifier] = ACTIONS(2360),
    [aux_sym_preproc_include_token1] = ACTIONS(2360),
    [aux_sym_preproc_def_token1] = ACTIONS(2360),
    [aux_sym_preproc_if_token1] = ACTIONS(2360),
    [aux_sym_preproc_if_token2] = ACTIONS(2360),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2360),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2360),
    [aux_sym_preproc_else_token1] = ACTIONS(2360),
    [aux_sym_preproc_elif_token1] = ACTIONS(2360),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2360),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2360),
    [sym_preproc_directive] = ACTIONS(2360),
    [anon_sym_LPAREN2] = ACTIONS(2362),
    [anon_sym_BANG] = ACTIONS(2362),
    [anon_sym_TILDE] = ACTIONS(2362),
    [anon_sym_DASH] = ACTIONS(2360),
    [anon_sym_PLUS] = ACTIONS(2360),
    [anon_sym_STAR] = ACTIONS(2362),
    [anon_sym_AMP_AMP] = ACTIONS(2362),
    [anon_sym_AMP] = ACTIONS(2360),
    [anon_sym_SEMI] = ACTIONS(2362),
    [anon_sym___extension__] = ACTIONS(2360),
    [anon_sym_typedef] = ACTIONS(2360),
    [anon_sym_in] = ACTIONS(2360),
    [anon_sym_out] = ACTIONS(2360),
    [anon_sym_inout] = ACTIONS(2360),
    [anon_sym_extern] = ACTIONS(2360),
    [anon_sym___attribute__] = ACTIONS(2360),
    [anon_sym_COLON_COLON] = ACTIONS(2362),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2362),
    [anon_sym___declspec] = ACTIONS(2360),
    [anon_sym___based] = ACTIONS(2360),
    [anon_sym___cdecl] = ACTIONS(2360),
    [anon_sym___clrcall] = ACTIONS(2360),
    [anon_sym___stdcall] = ACTIONS(2360),
    [anon_sym___fastcall] = ACTIONS(2360),
    [anon_sym___thiscall] = ACTIONS(2360),
    [anon_sym___vectorcall] = ACTIONS(2360),
    [anon_sym_LBRACE] = ACTIONS(2362),
    [anon_sym_signed] = ACTIONS(2360),
    [anon_sym_unsigned] = ACTIONS(2360),
    [anon_sym_long] = ACTIONS(2360),
    [anon_sym_short] = ACTIONS(2360),
    [anon_sym_LBRACK] = ACTIONS(2360),
    [anon_sym_static] = ACTIONS(2360),
    [anon_sym_register] = ACTIONS(2360),
    [anon_sym_inline] = ACTIONS(2360),
    [anon_sym___inline] = ACTIONS(2360),
    [anon_sym___inline__] = ACTIONS(2360),
    [anon_sym___forceinline] = ACTIONS(2360),
    [anon_sym_thread_local] = ACTIONS(2360),
    [anon_sym___thread] = ACTIONS(2360),
    [anon_sym_const] = ACTIONS(2360),
    [anon_sym_constexpr] = ACTIONS(2360),
    [anon_sym_volatile] = ACTIONS(2360),
    [anon_sym_restrict] = ACTIONS(2360),
    [anon_sym___restrict__] = ACTIONS(2360),
    [anon_sym__Atomic] = ACTIONS(2360),
    [anon_sym__Noreturn] = ACTIONS(2360),
    [anon_sym_noreturn] = ACTIONS(2360),
    [anon_sym_mutable] = ACTIONS(2360),
    [anon_sym_constinit] = ACTIONS(2360),
    [anon_sym_consteval] = ACTIONS(2360),
    [anon_sym_alignas] = ACTIONS(2360),
    [anon_sym__Alignas] = ACTIONS(2360),
    [sym_primitive_type] = ACTIONS(2360),
    [anon_sym_enum] = ACTIONS(2360),
    [anon_sym_class] = ACTIONS(2360),
    [anon_sym_struct] = ACTIONS(2360),
    [anon_sym_union] = ACTIONS(2360),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_switch] = ACTIONS(2360),
    [anon_sym_case] = ACTIONS(2360),
    [anon_sym_default] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2360),
    [anon_sym_do] = ACTIONS(2360),
    [anon_sym_for] = ACTIONS(2360),
    [anon_sym_return] = ACTIONS(2360),
    [anon_sym_break] = ACTIONS(2360),
    [anon_sym_continue] = ACTIONS(2360),
    [anon_sym_goto] = ACTIONS(2360),
    [anon_sym___try] = ACTIONS(2360),
    [anon_sym___leave] = ACTIONS(2360),
    [anon_sym_not] = ACTIONS(2360),
    [anon_sym_compl] = ACTIONS(2360),
    [anon_sym_DASH_DASH] = ACTIONS(2362),
    [anon_sym_PLUS_PLUS] = ACTIONS(2362),
    [anon_sym_sizeof] = ACTIONS(2360),
    [anon_sym___alignof__] = ACTIONS(2360),
    [anon_sym___alignof] = ACTIONS(2360),
    [anon_sym__alignof] = ACTIONS(2360),
    [anon_sym_alignof] = ACTIONS(2360),
    [anon_sym__Alignof] = ACTIONS(2360),
    [anon_sym_offsetof] = ACTIONS(2360),
    [anon_sym__Generic] = ACTIONS(2360),
    [anon_sym_asm] = ACTIONS(2360),
    [anon_sym___asm__] = ACTIONS(2360),
    [sym_number_literal] = ACTIONS(2362),
    [anon_sym_L_SQUOTE] = ACTIONS(2362),
    [anon_sym_u_SQUOTE] = ACTIONS(2362),
    [anon_sym_U_SQUOTE] = ACTIONS(2362),
    [anon_sym_u8_SQUOTE] = ACTIONS(2362),
    [anon_sym_SQUOTE] = ACTIONS(2362),
    [anon_sym_L_DQUOTE] = ACTIONS(2362),
    [anon_sym_u_DQUOTE] = ACTIONS(2362),
    [anon_sym_U_DQUOTE] = ACTIONS(2362),
    [anon_sym_u8_DQUOTE] = ACTIONS(2362),
    [anon_sym_DQUOTE] = ACTIONS(2362),
    [sym_true] = ACTIONS(2360),
    [sym_false] = ACTIONS(2360),
    [anon_sym_NULL] = ACTIONS(2360),
    [anon_sym_nullptr] = ACTIONS(2360),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2360),
    [anon_sym_decltype] = ACTIONS(2360),
    [sym_virtual] = ACTIONS(2360),
    [anon_sym_explicit] = ACTIONS(2360),
    [anon_sym_typename] = ACTIONS(2360),
    [anon_sym_template] = ACTIONS(2360),
    [anon_sym_operator] = ACTIONS(2360),
    [anon_sym_try] = ACTIONS(2360),
    [anon_sym_delete] = ACTIONS(2360),
    [anon_sym_throw] = ACTIONS(2360),
    [anon_sym_namespace] = ACTIONS(2360),
    [anon_sym_using] = ACTIONS(2360),
    [anon_sym_static_assert] = ACTIONS(2360),
    [anon_sym_concept] = ACTIONS(2360),
    [anon_sym_co_return] = ACTIONS(2360),
    [anon_sym_co_yield] = ACTIONS(2360),
    [anon_sym_R_DQUOTE] = ACTIONS(2362),
    [anon_sym_LR_DQUOTE] = ACTIONS(2362),
    [anon_sym_uR_DQUOTE] = ACTIONS(2362),
    [anon_sym_UR_DQUOTE] = ACTIONS(2362),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2362),
    [anon_sym_co_await] = ACTIONS(2360),
    [anon_sym_new] = ACTIONS(2360),
    [anon_sym_requires] = ACTIONS(2360),
    [sym_this] = ACTIONS(2360),
    [anon_sym_discard] = ACTIONS(2360),
    [anon_sym_precise] = ACTIONS(2360),
    [anon_sym_shared] = ACTIONS(2360),
    [anon_sym_groupshared] = ACTIONS(2360),
    [anon_sym_uniform] = ACTIONS(2360),
    [anon_sym_row_major] = ACTIONS(2360),
    [anon_sym_column_major] = ACTIONS(2360),
    [anon_sym_globallycoherent] = ACTIONS(2360),
    [anon_sym_centroid] = ACTIONS(2360),
    [anon_sym_noperspective] = ACTIONS(2360),
    [anon_sym_nointerpolation] = ACTIONS(2360),
    [anon_sym_sample] = ACTIONS(2360),
    [anon_sym_linear] = ACTIONS(2360),
    [anon_sym_snorm] = ACTIONS(2360),
    [anon_sym_unorm] = ACTIONS(2360),
    [anon_sym_point] = ACTIONS(2360),
    [anon_sym_line] = ACTIONS(2360),
    [anon_sym_triangleadj] = ACTIONS(2360),
    [anon_sym_lineadj] = ACTIONS(2360),
    [anon_sym_triangle] = ACTIONS(2360),
    [anon_sym_cbuffer] = ACTIONS(2360),
  },
  [263] = {
    [sym_identifier] = ACTIONS(1899),
    [aux_sym_preproc_include_token1] = ACTIONS(1899),
    [aux_sym_preproc_def_token1] = ACTIONS(1899),
    [aux_sym_preproc_if_token1] = ACTIONS(1899),
    [aux_sym_preproc_if_token2] = ACTIONS(1899),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1899),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1899),
    [sym_preproc_directive] = ACTIONS(1899),
    [anon_sym_LPAREN2] = ACTIONS(1901),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1901),
    [anon_sym_AMP_AMP] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1899),
    [anon_sym_COLON] = ACTIONS(1899),
    [anon_sym_SEMI] = ACTIONS(1901),
    [anon_sym___extension__] = ACTIONS(1899),
    [anon_sym_typedef] = ACTIONS(1899),
    [anon_sym_in] = ACTIONS(1899),
    [anon_sym_out] = ACTIONS(1899),
    [anon_sym_inout] = ACTIONS(1899),
    [anon_sym_extern] = ACTIONS(1899),
    [anon_sym___attribute__] = ACTIONS(1899),
    [anon_sym_COLON_COLON] = ACTIONS(1901),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1901),
    [anon_sym___declspec] = ACTIONS(1899),
    [anon_sym___based] = ACTIONS(1899),
    [anon_sym___cdecl] = ACTIONS(1899),
    [anon_sym___clrcall] = ACTIONS(1899),
    [anon_sym___stdcall] = ACTIONS(1899),
    [anon_sym___fastcall] = ACTIONS(1899),
    [anon_sym___thiscall] = ACTIONS(1899),
    [anon_sym___vectorcall] = ACTIONS(1899),
    [anon_sym_LBRACE] = ACTIONS(1901),
    [anon_sym_signed] = ACTIONS(1899),
    [anon_sym_unsigned] = ACTIONS(1899),
    [anon_sym_long] = ACTIONS(1899),
    [anon_sym_short] = ACTIONS(1899),
    [anon_sym_LBRACK] = ACTIONS(1899),
    [anon_sym_static] = ACTIONS(1899),
    [anon_sym_register] = ACTIONS(1899),
    [anon_sym_inline] = ACTIONS(1899),
    [anon_sym___inline] = ACTIONS(1899),
    [anon_sym___inline__] = ACTIONS(1899),
    [anon_sym___forceinline] = ACTIONS(1899),
    [anon_sym_thread_local] = ACTIONS(1899),
    [anon_sym___thread] = ACTIONS(1899),
    [anon_sym_const] = ACTIONS(1899),
    [anon_sym_constexpr] = ACTIONS(1899),
    [anon_sym_volatile] = ACTIONS(1899),
    [anon_sym_restrict] = ACTIONS(1899),
    [anon_sym___restrict__] = ACTIONS(1899),
    [anon_sym__Atomic] = ACTIONS(1899),
    [anon_sym__Noreturn] = ACTIONS(1899),
    [anon_sym_noreturn] = ACTIONS(1899),
    [anon_sym_mutable] = ACTIONS(1899),
    [anon_sym_constinit] = ACTIONS(1899),
    [anon_sym_consteval] = ACTIONS(1899),
    [anon_sym_alignas] = ACTIONS(1899),
    [anon_sym__Alignas] = ACTIONS(1899),
    [sym_primitive_type] = ACTIONS(1899),
    [anon_sym_enum] = ACTIONS(1899),
    [anon_sym_class] = ACTIONS(1899),
    [anon_sym_struct] = ACTIONS(1899),
    [anon_sym_union] = ACTIONS(1899),
    [anon_sym_if] = ACTIONS(1899),
    [anon_sym_else] = ACTIONS(1899),
    [anon_sym_switch] = ACTIONS(1899),
    [anon_sym_case] = ACTIONS(1899),
    [anon_sym_default] = ACTIONS(1899),
    [anon_sym_while] = ACTIONS(1899),
    [anon_sym_do] = ACTIONS(1899),
    [anon_sym_for] = ACTIONS(1899),
    [anon_sym_return] = ACTIONS(1899),
    [anon_sym_break] = ACTIONS(1899),
    [anon_sym_continue] = ACTIONS(1899),
    [anon_sym_goto] = ACTIONS(1899),
    [anon_sym___try] = ACTIONS(1899),
    [anon_sym___leave] = ACTIONS(1899),
    [anon_sym_not] = ACTIONS(1899),
    [anon_sym_compl] = ACTIONS(1899),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_sizeof] = ACTIONS(1899),
    [anon_sym___alignof__] = ACTIONS(1899),
    [anon_sym___alignof] = ACTIONS(1899),
    [anon_sym__alignof] = ACTIONS(1899),
    [anon_sym_alignof] = ACTIONS(1899),
    [anon_sym__Alignof] = ACTIONS(1899),
    [anon_sym_offsetof] = ACTIONS(1899),
    [anon_sym__Generic] = ACTIONS(1899),
    [anon_sym_asm] = ACTIONS(1899),
    [anon_sym___asm__] = ACTIONS(1899),
    [sym_number_literal] = ACTIONS(1901),
    [anon_sym_L_SQUOTE] = ACTIONS(1901),
    [anon_sym_u_SQUOTE] = ACTIONS(1901),
    [anon_sym_U_SQUOTE] = ACTIONS(1901),
    [anon_sym_u8_SQUOTE] = ACTIONS(1901),
    [anon_sym_SQUOTE] = ACTIONS(1901),
    [anon_sym_L_DQUOTE] = ACTIONS(1901),
    [anon_sym_u_DQUOTE] = ACTIONS(1901),
    [anon_sym_U_DQUOTE] = ACTIONS(1901),
    [anon_sym_u8_DQUOTE] = ACTIONS(1901),
    [anon_sym_DQUOTE] = ACTIONS(1901),
    [sym_true] = ACTIONS(1899),
    [sym_false] = ACTIONS(1899),
    [anon_sym_NULL] = ACTIONS(1899),
    [anon_sym_nullptr] = ACTIONS(1899),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1899),
    [anon_sym_decltype] = ACTIONS(1899),
    [anon_sym_final] = ACTIONS(1899),
    [anon_sym_override] = ACTIONS(1899),
    [sym_virtual] = ACTIONS(1899),
    [anon_sym_explicit] = ACTIONS(1899),
    [anon_sym_typename] = ACTIONS(1899),
    [anon_sym_template] = ACTIONS(1899),
    [anon_sym_operator] = ACTIONS(1899),
    [anon_sym_try] = ACTIONS(1899),
    [anon_sym_delete] = ACTIONS(1899),
    [anon_sym_throw] = ACTIONS(1899),
    [anon_sym_namespace] = ACTIONS(1899),
    [anon_sym_using] = ACTIONS(1899),
    [anon_sym_static_assert] = ACTIONS(1899),
    [anon_sym_concept] = ACTIONS(1899),
    [anon_sym_co_return] = ACTIONS(1899),
    [anon_sym_co_yield] = ACTIONS(1899),
    [anon_sym_R_DQUOTE] = ACTIONS(1901),
    [anon_sym_LR_DQUOTE] = ACTIONS(1901),
    [anon_sym_uR_DQUOTE] = ACTIONS(1901),
    [anon_sym_UR_DQUOTE] = ACTIONS(1901),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1901),
    [anon_sym_co_await] = ACTIONS(1899),
    [anon_sym_new] = ACTIONS(1899),
    [anon_sym_requires] = ACTIONS(1899),
    [sym_this] = ACTIONS(1899),
    [anon_sym_discard] = ACTIONS(1899),
    [anon_sym_precise] = ACTIONS(1899),
    [anon_sym_shared] = ACTIONS(1899),
    [anon_sym_groupshared] = ACTIONS(1899),
    [anon_sym_uniform] = ACTIONS(1899),
    [anon_sym_row_major] = ACTIONS(1899),
    [anon_sym_column_major] = ACTIONS(1899),
    [anon_sym_globallycoherent] = ACTIONS(1899),
    [anon_sym_centroid] = ACTIONS(1899),
    [anon_sym_noperspective] = ACTIONS(1899),
    [anon_sym_nointerpolation] = ACTIONS(1899),
    [anon_sym_sample] = ACTIONS(1899),
    [anon_sym_linear] = ACTIONS(1899),
    [anon_sym_snorm] = ACTIONS(1899),
    [anon_sym_unorm] = ACTIONS(1899),
    [anon_sym_point] = ACTIONS(1899),
    [anon_sym_line] = ACTIONS(1899),
    [anon_sym_triangleadj] = ACTIONS(1899),
    [anon_sym_lineadj] = ACTIONS(1899),
    [anon_sym_triangle] = ACTIONS(1899),
    [anon_sym_cbuffer] = ACTIONS(1899),
  },
  [264] = {
    [sym_identifier] = ACTIONS(2364),
    [aux_sym_preproc_include_token1] = ACTIONS(2364),
    [aux_sym_preproc_def_token1] = ACTIONS(2364),
    [aux_sym_preproc_if_token1] = ACTIONS(2364),
    [aux_sym_preproc_if_token2] = ACTIONS(2364),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2364),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2364),
    [aux_sym_preproc_else_token1] = ACTIONS(2364),
    [aux_sym_preproc_elif_token1] = ACTIONS(2364),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2364),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2364),
    [sym_preproc_directive] = ACTIONS(2364),
    [anon_sym_LPAREN2] = ACTIONS(2366),
    [anon_sym_BANG] = ACTIONS(2366),
    [anon_sym_TILDE] = ACTIONS(2366),
    [anon_sym_DASH] = ACTIONS(2364),
    [anon_sym_PLUS] = ACTIONS(2364),
    [anon_sym_STAR] = ACTIONS(2366),
    [anon_sym_AMP_AMP] = ACTIONS(2366),
    [anon_sym_AMP] = ACTIONS(2364),
    [anon_sym_SEMI] = ACTIONS(2366),
    [anon_sym___extension__] = ACTIONS(2364),
    [anon_sym_typedef] = ACTIONS(2364),
    [anon_sym_in] = ACTIONS(2364),
    [anon_sym_out] = ACTIONS(2364),
    [anon_sym_inout] = ACTIONS(2364),
    [anon_sym_extern] = ACTIONS(2364),
    [anon_sym___attribute__] = ACTIONS(2364),
    [anon_sym_COLON_COLON] = ACTIONS(2366),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2366),
    [anon_sym___declspec] = ACTIONS(2364),
    [anon_sym___based] = ACTIONS(2364),
    [anon_sym___cdecl] = ACTIONS(2364),
    [anon_sym___clrcall] = ACTIONS(2364),
    [anon_sym___stdcall] = ACTIONS(2364),
    [anon_sym___fastcall] = ACTIONS(2364),
    [anon_sym___thiscall] = ACTIONS(2364),
    [anon_sym___vectorcall] = ACTIONS(2364),
    [anon_sym_LBRACE] = ACTIONS(2366),
    [anon_sym_signed] = ACTIONS(2364),
    [anon_sym_unsigned] = ACTIONS(2364),
    [anon_sym_long] = ACTIONS(2364),
    [anon_sym_short] = ACTIONS(2364),
    [anon_sym_LBRACK] = ACTIONS(2364),
    [anon_sym_static] = ACTIONS(2364),
    [anon_sym_register] = ACTIONS(2364),
    [anon_sym_inline] = ACTIONS(2364),
    [anon_sym___inline] = ACTIONS(2364),
    [anon_sym___inline__] = ACTIONS(2364),
    [anon_sym___forceinline] = ACTIONS(2364),
    [anon_sym_thread_local] = ACTIONS(2364),
    [anon_sym___thread] = ACTIONS(2364),
    [anon_sym_const] = ACTIONS(2364),
    [anon_sym_constexpr] = ACTIONS(2364),
    [anon_sym_volatile] = ACTIONS(2364),
    [anon_sym_restrict] = ACTIONS(2364),
    [anon_sym___restrict__] = ACTIONS(2364),
    [anon_sym__Atomic] = ACTIONS(2364),
    [anon_sym__Noreturn] = ACTIONS(2364),
    [anon_sym_noreturn] = ACTIONS(2364),
    [anon_sym_mutable] = ACTIONS(2364),
    [anon_sym_constinit] = ACTIONS(2364),
    [anon_sym_consteval] = ACTIONS(2364),
    [anon_sym_alignas] = ACTIONS(2364),
    [anon_sym__Alignas] = ACTIONS(2364),
    [sym_primitive_type] = ACTIONS(2364),
    [anon_sym_enum] = ACTIONS(2364),
    [anon_sym_class] = ACTIONS(2364),
    [anon_sym_struct] = ACTIONS(2364),
    [anon_sym_union] = ACTIONS(2364),
    [anon_sym_if] = ACTIONS(2364),
    [anon_sym_switch] = ACTIONS(2364),
    [anon_sym_case] = ACTIONS(2364),
    [anon_sym_default] = ACTIONS(2364),
    [anon_sym_while] = ACTIONS(2364),
    [anon_sym_do] = ACTIONS(2364),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_return] = ACTIONS(2364),
    [anon_sym_break] = ACTIONS(2364),
    [anon_sym_continue] = ACTIONS(2364),
    [anon_sym_goto] = ACTIONS(2364),
    [anon_sym___try] = ACTIONS(2364),
    [anon_sym___leave] = ACTIONS(2364),
    [anon_sym_not] = ACTIONS(2364),
    [anon_sym_compl] = ACTIONS(2364),
    [anon_sym_DASH_DASH] = ACTIONS(2366),
    [anon_sym_PLUS_PLUS] = ACTIONS(2366),
    [anon_sym_sizeof] = ACTIONS(2364),
    [anon_sym___alignof__] = ACTIONS(2364),
    [anon_sym___alignof] = ACTIONS(2364),
    [anon_sym__alignof] = ACTIONS(2364),
    [anon_sym_alignof] = ACTIONS(2364),
    [anon_sym__Alignof] = ACTIONS(2364),
    [anon_sym_offsetof] = ACTIONS(2364),
    [anon_sym__Generic] = ACTIONS(2364),
    [anon_sym_asm] = ACTIONS(2364),
    [anon_sym___asm__] = ACTIONS(2364),
    [sym_number_literal] = ACTIONS(2366),
    [anon_sym_L_SQUOTE] = ACTIONS(2366),
    [anon_sym_u_SQUOTE] = ACTIONS(2366),
    [anon_sym_U_SQUOTE] = ACTIONS(2366),
    [anon_sym_u8_SQUOTE] = ACTIONS(2366),
    [anon_sym_SQUOTE] = ACTIONS(2366),
    [anon_sym_L_DQUOTE] = ACTIONS(2366),
    [anon_sym_u_DQUOTE] = ACTIONS(2366),
    [anon_sym_U_DQUOTE] = ACTIONS(2366),
    [anon_sym_u8_DQUOTE] = ACTIONS(2366),
    [anon_sym_DQUOTE] = ACTIONS(2366),
    [sym_true] = ACTIONS(2364),
    [sym_false] = ACTIONS(2364),
    [anon_sym_NULL] = ACTIONS(2364),
    [anon_sym_nullptr] = ACTIONS(2364),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2364),
    [anon_sym_decltype] = ACTIONS(2364),
    [sym_virtual] = ACTIONS(2364),
    [anon_sym_explicit] = ACTIONS(2364),
    [anon_sym_typename] = ACTIONS(2364),
    [anon_sym_template] = ACTIONS(2364),
    [anon_sym_operator] = ACTIONS(2364),
    [anon_sym_try] = ACTIONS(2364),
    [anon_sym_delete] = ACTIONS(2364),
    [anon_sym_throw] = ACTIONS(2364),
    [anon_sym_namespace] = ACTIONS(2364),
    [anon_sym_using] = ACTIONS(2364),
    [anon_sym_static_assert] = ACTIONS(2364),
    [anon_sym_concept] = ACTIONS(2364),
    [anon_sym_co_return] = ACTIONS(2364),
    [anon_sym_co_yield] = ACTIONS(2364),
    [anon_sym_R_DQUOTE] = ACTIONS(2366),
    [anon_sym_LR_DQUOTE] = ACTIONS(2366),
    [anon_sym_uR_DQUOTE] = ACTIONS(2366),
    [anon_sym_UR_DQUOTE] = ACTIONS(2366),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2366),
    [anon_sym_co_await] = ACTIONS(2364),
    [anon_sym_new] = ACTIONS(2364),
    [anon_sym_requires] = ACTIONS(2364),
    [sym_this] = ACTIONS(2364),
    [anon_sym_discard] = ACTIONS(2364),
    [anon_sym_precise] = ACTIONS(2364),
    [anon_sym_shared] = ACTIONS(2364),
    [anon_sym_groupshared] = ACTIONS(2364),
    [anon_sym_uniform] = ACTIONS(2364),
    [anon_sym_row_major] = ACTIONS(2364),
    [anon_sym_column_major] = ACTIONS(2364),
    [anon_sym_globallycoherent] = ACTIONS(2364),
    [anon_sym_centroid] = ACTIONS(2364),
    [anon_sym_noperspective] = ACTIONS(2364),
    [anon_sym_nointerpolation] = ACTIONS(2364),
    [anon_sym_sample] = ACTIONS(2364),
    [anon_sym_linear] = ACTIONS(2364),
    [anon_sym_snorm] = ACTIONS(2364),
    [anon_sym_unorm] = ACTIONS(2364),
    [anon_sym_point] = ACTIONS(2364),
    [anon_sym_line] = ACTIONS(2364),
    [anon_sym_triangleadj] = ACTIONS(2364),
    [anon_sym_lineadj] = ACTIONS(2364),
    [anon_sym_triangle] = ACTIONS(2364),
    [anon_sym_cbuffer] = ACTIONS(2364),
  },
  [265] = {
    [sym_catch_clause] = STATE(265),
    [aux_sym_constructor_try_statement_repeat1] = STATE(265),
    [sym_identifier] = ACTIONS(1973),
    [aux_sym_preproc_include_token1] = ACTIONS(1973),
    [aux_sym_preproc_def_token1] = ACTIONS(1973),
    [aux_sym_preproc_if_token1] = ACTIONS(1973),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1973),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1973),
    [sym_preproc_directive] = ACTIONS(1973),
    [anon_sym_LPAREN2] = ACTIONS(1975),
    [anon_sym_BANG] = ACTIONS(1975),
    [anon_sym_TILDE] = ACTIONS(1975),
    [anon_sym_DASH] = ACTIONS(1973),
    [anon_sym_PLUS] = ACTIONS(1973),
    [anon_sym_STAR] = ACTIONS(1975),
    [anon_sym_AMP_AMP] = ACTIONS(1975),
    [anon_sym_AMP] = ACTIONS(1973),
    [anon_sym_SEMI] = ACTIONS(1975),
    [anon_sym___extension__] = ACTIONS(1973),
    [anon_sym_typedef] = ACTIONS(1973),
    [anon_sym_in] = ACTIONS(1973),
    [anon_sym_out] = ACTIONS(1973),
    [anon_sym_inout] = ACTIONS(1973),
    [anon_sym_extern] = ACTIONS(1973),
    [anon_sym___attribute__] = ACTIONS(1973),
    [anon_sym_COLON_COLON] = ACTIONS(1975),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1975),
    [anon_sym___declspec] = ACTIONS(1973),
    [anon_sym___based] = ACTIONS(1973),
    [anon_sym___cdecl] = ACTIONS(1973),
    [anon_sym___clrcall] = ACTIONS(1973),
    [anon_sym___stdcall] = ACTIONS(1973),
    [anon_sym___fastcall] = ACTIONS(1973),
    [anon_sym___thiscall] = ACTIONS(1973),
    [anon_sym___vectorcall] = ACTIONS(1973),
    [anon_sym_LBRACE] = ACTIONS(1975),
    [anon_sym_RBRACE] = ACTIONS(1975),
    [anon_sym_signed] = ACTIONS(1973),
    [anon_sym_unsigned] = ACTIONS(1973),
    [anon_sym_long] = ACTIONS(1973),
    [anon_sym_short] = ACTIONS(1973),
    [anon_sym_LBRACK] = ACTIONS(1973),
    [anon_sym_static] = ACTIONS(1973),
    [anon_sym_register] = ACTIONS(1973),
    [anon_sym_inline] = ACTIONS(1973),
    [anon_sym___inline] = ACTIONS(1973),
    [anon_sym___inline__] = ACTIONS(1973),
    [anon_sym___forceinline] = ACTIONS(1973),
    [anon_sym_thread_local] = ACTIONS(1973),
    [anon_sym___thread] = ACTIONS(1973),
    [anon_sym_const] = ACTIONS(1973),
    [anon_sym_constexpr] = ACTIONS(1973),
    [anon_sym_volatile] = ACTIONS(1973),
    [anon_sym_restrict] = ACTIONS(1973),
    [anon_sym___restrict__] = ACTIONS(1973),
    [anon_sym__Atomic] = ACTIONS(1973),
    [anon_sym__Noreturn] = ACTIONS(1973),
    [anon_sym_noreturn] = ACTIONS(1973),
    [anon_sym_mutable] = ACTIONS(1973),
    [anon_sym_constinit] = ACTIONS(1973),
    [anon_sym_consteval] = ACTIONS(1973),
    [anon_sym_alignas] = ACTIONS(1973),
    [anon_sym__Alignas] = ACTIONS(1973),
    [sym_primitive_type] = ACTIONS(1973),
    [anon_sym_enum] = ACTIONS(1973),
    [anon_sym_class] = ACTIONS(1973),
    [anon_sym_struct] = ACTIONS(1973),
    [anon_sym_union] = ACTIONS(1973),
    [anon_sym_if] = ACTIONS(1973),
    [anon_sym_else] = ACTIONS(1973),
    [anon_sym_switch] = ACTIONS(1973),
    [anon_sym_case] = ACTIONS(1973),
    [anon_sym_default] = ACTIONS(1973),
    [anon_sym_while] = ACTIONS(1973),
    [anon_sym_do] = ACTIONS(1973),
    [anon_sym_for] = ACTIONS(1973),
    [anon_sym_return] = ACTIONS(1973),
    [anon_sym_break] = ACTIONS(1973),
    [anon_sym_continue] = ACTIONS(1973),
    [anon_sym_goto] = ACTIONS(1973),
    [anon_sym___try] = ACTIONS(1973),
    [anon_sym___leave] = ACTIONS(1973),
    [anon_sym_not] = ACTIONS(1973),
    [anon_sym_compl] = ACTIONS(1973),
    [anon_sym_DASH_DASH] = ACTIONS(1975),
    [anon_sym_PLUS_PLUS] = ACTIONS(1975),
    [anon_sym_sizeof] = ACTIONS(1973),
    [anon_sym___alignof__] = ACTIONS(1973),
    [anon_sym___alignof] = ACTIONS(1973),
    [anon_sym__alignof] = ACTIONS(1973),
    [anon_sym_alignof] = ACTIONS(1973),
    [anon_sym__Alignof] = ACTIONS(1973),
    [anon_sym_offsetof] = ACTIONS(1973),
    [anon_sym__Generic] = ACTIONS(1973),
    [anon_sym_asm] = ACTIONS(1973),
    [anon_sym___asm__] = ACTIONS(1973),
    [sym_number_literal] = ACTIONS(1975),
    [anon_sym_L_SQUOTE] = ACTIONS(1975),
    [anon_sym_u_SQUOTE] = ACTIONS(1975),
    [anon_sym_U_SQUOTE] = ACTIONS(1975),
    [anon_sym_u8_SQUOTE] = ACTIONS(1975),
    [anon_sym_SQUOTE] = ACTIONS(1975),
    [anon_sym_L_DQUOTE] = ACTIONS(1975),
    [anon_sym_u_DQUOTE] = ACTIONS(1975),
    [anon_sym_U_DQUOTE] = ACTIONS(1975),
    [anon_sym_u8_DQUOTE] = ACTIONS(1975),
    [anon_sym_DQUOTE] = ACTIONS(1975),
    [sym_true] = ACTIONS(1973),
    [sym_false] = ACTIONS(1973),
    [anon_sym_NULL] = ACTIONS(1973),
    [anon_sym_nullptr] = ACTIONS(1973),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1973),
    [anon_sym_decltype] = ACTIONS(1973),
    [sym_virtual] = ACTIONS(1973),
    [anon_sym_explicit] = ACTIONS(1973),
    [anon_sym_typename] = ACTIONS(1973),
    [anon_sym_template] = ACTIONS(1973),
    [anon_sym_operator] = ACTIONS(1973),
    [anon_sym_try] = ACTIONS(1973),
    [anon_sym_delete] = ACTIONS(1973),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_namespace] = ACTIONS(1973),
    [anon_sym_using] = ACTIONS(1973),
    [anon_sym_static_assert] = ACTIONS(1973),
    [anon_sym_concept] = ACTIONS(1973),
    [anon_sym_co_return] = ACTIONS(1973),
    [anon_sym_co_yield] = ACTIONS(1973),
    [anon_sym_catch] = ACTIONS(2368),
    [anon_sym_R_DQUOTE] = ACTIONS(1975),
    [anon_sym_LR_DQUOTE] = ACTIONS(1975),
    [anon_sym_uR_DQUOTE] = ACTIONS(1975),
    [anon_sym_UR_DQUOTE] = ACTIONS(1975),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1975),
    [anon_sym_co_await] = ACTIONS(1973),
    [anon_sym_new] = ACTIONS(1973),
    [anon_sym_requires] = ACTIONS(1973),
    [sym_this] = ACTIONS(1973),
    [anon_sym_discard] = ACTIONS(1973),
    [anon_sym_precise] = ACTIONS(1973),
    [anon_sym_shared] = ACTIONS(1973),
    [anon_sym_groupshared] = ACTIONS(1973),
    [anon_sym_uniform] = ACTIONS(1973),
    [anon_sym_row_major] = ACTIONS(1973),
    [anon_sym_column_major] = ACTIONS(1973),
    [anon_sym_globallycoherent] = ACTIONS(1973),
    [anon_sym_centroid] = ACTIONS(1973),
    [anon_sym_noperspective] = ACTIONS(1973),
    [anon_sym_nointerpolation] = ACTIONS(1973),
    [anon_sym_sample] = ACTIONS(1973),
    [anon_sym_linear] = ACTIONS(1973),
    [anon_sym_snorm] = ACTIONS(1973),
    [anon_sym_unorm] = ACTIONS(1973),
    [anon_sym_point] = ACTIONS(1973),
    [anon_sym_line] = ACTIONS(1973),
    [anon_sym_triangleadj] = ACTIONS(1973),
    [anon_sym_lineadj] = ACTIONS(1973),
    [anon_sym_triangle] = ACTIONS(1973),
    [anon_sym_cbuffer] = ACTIONS(1973),
  },
  [266] = {
    [sym_identifier] = ACTIONS(2371),
    [aux_sym_preproc_include_token1] = ACTIONS(2371),
    [aux_sym_preproc_def_token1] = ACTIONS(2371),
    [aux_sym_preproc_if_token1] = ACTIONS(2371),
    [aux_sym_preproc_if_token2] = ACTIONS(2371),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2371),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2371),
    [aux_sym_preproc_else_token1] = ACTIONS(2371),
    [aux_sym_preproc_elif_token1] = ACTIONS(2371),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2371),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2371),
    [sym_preproc_directive] = ACTIONS(2371),
    [anon_sym_LPAREN2] = ACTIONS(2373),
    [anon_sym_BANG] = ACTIONS(2373),
    [anon_sym_TILDE] = ACTIONS(2373),
    [anon_sym_DASH] = ACTIONS(2371),
    [anon_sym_PLUS] = ACTIONS(2371),
    [anon_sym_STAR] = ACTIONS(2373),
    [anon_sym_AMP_AMP] = ACTIONS(2373),
    [anon_sym_AMP] = ACTIONS(2371),
    [anon_sym_SEMI] = ACTIONS(2373),
    [anon_sym___extension__] = ACTIONS(2371),
    [anon_sym_typedef] = ACTIONS(2371),
    [anon_sym_in] = ACTIONS(2371),
    [anon_sym_out] = ACTIONS(2371),
    [anon_sym_inout] = ACTIONS(2371),
    [anon_sym_extern] = ACTIONS(2371),
    [anon_sym___attribute__] = ACTIONS(2371),
    [anon_sym_COLON_COLON] = ACTIONS(2373),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2373),
    [anon_sym___declspec] = ACTIONS(2371),
    [anon_sym___based] = ACTIONS(2371),
    [anon_sym___cdecl] = ACTIONS(2371),
    [anon_sym___clrcall] = ACTIONS(2371),
    [anon_sym___stdcall] = ACTIONS(2371),
    [anon_sym___fastcall] = ACTIONS(2371),
    [anon_sym___thiscall] = ACTIONS(2371),
    [anon_sym___vectorcall] = ACTIONS(2371),
    [anon_sym_LBRACE] = ACTIONS(2373),
    [anon_sym_signed] = ACTIONS(2371),
    [anon_sym_unsigned] = ACTIONS(2371),
    [anon_sym_long] = ACTIONS(2371),
    [anon_sym_short] = ACTIONS(2371),
    [anon_sym_LBRACK] = ACTIONS(2371),
    [anon_sym_static] = ACTIONS(2371),
    [anon_sym_register] = ACTIONS(2371),
    [anon_sym_inline] = ACTIONS(2371),
    [anon_sym___inline] = ACTIONS(2371),
    [anon_sym___inline__] = ACTIONS(2371),
    [anon_sym___forceinline] = ACTIONS(2371),
    [anon_sym_thread_local] = ACTIONS(2371),
    [anon_sym___thread] = ACTIONS(2371),
    [anon_sym_const] = ACTIONS(2371),
    [anon_sym_constexpr] = ACTIONS(2371),
    [anon_sym_volatile] = ACTIONS(2371),
    [anon_sym_restrict] = ACTIONS(2371),
    [anon_sym___restrict__] = ACTIONS(2371),
    [anon_sym__Atomic] = ACTIONS(2371),
    [anon_sym__Noreturn] = ACTIONS(2371),
    [anon_sym_noreturn] = ACTIONS(2371),
    [anon_sym_mutable] = ACTIONS(2371),
    [anon_sym_constinit] = ACTIONS(2371),
    [anon_sym_consteval] = ACTIONS(2371),
    [anon_sym_alignas] = ACTIONS(2371),
    [anon_sym__Alignas] = ACTIONS(2371),
    [sym_primitive_type] = ACTIONS(2371),
    [anon_sym_enum] = ACTIONS(2371),
    [anon_sym_class] = ACTIONS(2371),
    [anon_sym_struct] = ACTIONS(2371),
    [anon_sym_union] = ACTIONS(2371),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_switch] = ACTIONS(2371),
    [anon_sym_case] = ACTIONS(2371),
    [anon_sym_default] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(2371),
    [anon_sym_do] = ACTIONS(2371),
    [anon_sym_for] = ACTIONS(2371),
    [anon_sym_return] = ACTIONS(2371),
    [anon_sym_break] = ACTIONS(2371),
    [anon_sym_continue] = ACTIONS(2371),
    [anon_sym_goto] = ACTIONS(2371),
    [anon_sym___try] = ACTIONS(2371),
    [anon_sym___leave] = ACTIONS(2371),
    [anon_sym_not] = ACTIONS(2371),
    [anon_sym_compl] = ACTIONS(2371),
    [anon_sym_DASH_DASH] = ACTIONS(2373),
    [anon_sym_PLUS_PLUS] = ACTIONS(2373),
    [anon_sym_sizeof] = ACTIONS(2371),
    [anon_sym___alignof__] = ACTIONS(2371),
    [anon_sym___alignof] = ACTIONS(2371),
    [anon_sym__alignof] = ACTIONS(2371),
    [anon_sym_alignof] = ACTIONS(2371),
    [anon_sym__Alignof] = ACTIONS(2371),
    [anon_sym_offsetof] = ACTIONS(2371),
    [anon_sym__Generic] = ACTIONS(2371),
    [anon_sym_asm] = ACTIONS(2371),
    [anon_sym___asm__] = ACTIONS(2371),
    [sym_number_literal] = ACTIONS(2373),
    [anon_sym_L_SQUOTE] = ACTIONS(2373),
    [anon_sym_u_SQUOTE] = ACTIONS(2373),
    [anon_sym_U_SQUOTE] = ACTIONS(2373),
    [anon_sym_u8_SQUOTE] = ACTIONS(2373),
    [anon_sym_SQUOTE] = ACTIONS(2373),
    [anon_sym_L_DQUOTE] = ACTIONS(2373),
    [anon_sym_u_DQUOTE] = ACTIONS(2373),
    [anon_sym_U_DQUOTE] = ACTIONS(2373),
    [anon_sym_u8_DQUOTE] = ACTIONS(2373),
    [anon_sym_DQUOTE] = ACTIONS(2373),
    [sym_true] = ACTIONS(2371),
    [sym_false] = ACTIONS(2371),
    [anon_sym_NULL] = ACTIONS(2371),
    [anon_sym_nullptr] = ACTIONS(2371),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2371),
    [anon_sym_decltype] = ACTIONS(2371),
    [sym_virtual] = ACTIONS(2371),
    [anon_sym_explicit] = ACTIONS(2371),
    [anon_sym_typename] = ACTIONS(2371),
    [anon_sym_template] = ACTIONS(2371),
    [anon_sym_operator] = ACTIONS(2371),
    [anon_sym_try] = ACTIONS(2371),
    [anon_sym_delete] = ACTIONS(2371),
    [anon_sym_throw] = ACTIONS(2371),
    [anon_sym_namespace] = ACTIONS(2371),
    [anon_sym_using] = ACTIONS(2371),
    [anon_sym_static_assert] = ACTIONS(2371),
    [anon_sym_concept] = ACTIONS(2371),
    [anon_sym_co_return] = ACTIONS(2371),
    [anon_sym_co_yield] = ACTIONS(2371),
    [anon_sym_R_DQUOTE] = ACTIONS(2373),
    [anon_sym_LR_DQUOTE] = ACTIONS(2373),
    [anon_sym_uR_DQUOTE] = ACTIONS(2373),
    [anon_sym_UR_DQUOTE] = ACTIONS(2373),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2373),
    [anon_sym_co_await] = ACTIONS(2371),
    [anon_sym_new] = ACTIONS(2371),
    [anon_sym_requires] = ACTIONS(2371),
    [sym_this] = ACTIONS(2371),
    [anon_sym_discard] = ACTIONS(2371),
    [anon_sym_precise] = ACTIONS(2371),
    [anon_sym_shared] = ACTIONS(2371),
    [anon_sym_groupshared] = ACTIONS(2371),
    [anon_sym_uniform] = ACTIONS(2371),
    [anon_sym_row_major] = ACTIONS(2371),
    [anon_sym_column_major] = ACTIONS(2371),
    [anon_sym_globallycoherent] = ACTIONS(2371),
    [anon_sym_centroid] = ACTIONS(2371),
    [anon_sym_noperspective] = ACTIONS(2371),
    [anon_sym_nointerpolation] = ACTIONS(2371),
    [anon_sym_sample] = ACTIONS(2371),
    [anon_sym_linear] = ACTIONS(2371),
    [anon_sym_snorm] = ACTIONS(2371),
    [anon_sym_unorm] = ACTIONS(2371),
    [anon_sym_point] = ACTIONS(2371),
    [anon_sym_line] = ACTIONS(2371),
    [anon_sym_triangleadj] = ACTIONS(2371),
    [anon_sym_lineadj] = ACTIONS(2371),
    [anon_sym_triangle] = ACTIONS(2371),
    [anon_sym_cbuffer] = ACTIONS(2371),
  },
  [267] = {
    [sym_identifier] = ACTIONS(2375),
    [aux_sym_preproc_include_token1] = ACTIONS(2375),
    [aux_sym_preproc_def_token1] = ACTIONS(2375),
    [aux_sym_preproc_if_token1] = ACTIONS(2375),
    [aux_sym_preproc_if_token2] = ACTIONS(2375),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2375),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2375),
    [aux_sym_preproc_else_token1] = ACTIONS(2375),
    [aux_sym_preproc_elif_token1] = ACTIONS(2375),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2375),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2375),
    [sym_preproc_directive] = ACTIONS(2375),
    [anon_sym_LPAREN2] = ACTIONS(2377),
    [anon_sym_BANG] = ACTIONS(2377),
    [anon_sym_TILDE] = ACTIONS(2377),
    [anon_sym_DASH] = ACTIONS(2375),
    [anon_sym_PLUS] = ACTIONS(2375),
    [anon_sym_STAR] = ACTIONS(2377),
    [anon_sym_AMP_AMP] = ACTIONS(2377),
    [anon_sym_AMP] = ACTIONS(2375),
    [anon_sym_SEMI] = ACTIONS(2377),
    [anon_sym___extension__] = ACTIONS(2375),
    [anon_sym_typedef] = ACTIONS(2375),
    [anon_sym_in] = ACTIONS(2375),
    [anon_sym_out] = ACTIONS(2375),
    [anon_sym_inout] = ACTIONS(2375),
    [anon_sym_extern] = ACTIONS(2375),
    [anon_sym___attribute__] = ACTIONS(2375),
    [anon_sym_COLON_COLON] = ACTIONS(2377),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2377),
    [anon_sym___declspec] = ACTIONS(2375),
    [anon_sym___based] = ACTIONS(2375),
    [anon_sym___cdecl] = ACTIONS(2375),
    [anon_sym___clrcall] = ACTIONS(2375),
    [anon_sym___stdcall] = ACTIONS(2375),
    [anon_sym___fastcall] = ACTIONS(2375),
    [anon_sym___thiscall] = ACTIONS(2375),
    [anon_sym___vectorcall] = ACTIONS(2375),
    [anon_sym_LBRACE] = ACTIONS(2377),
    [anon_sym_signed] = ACTIONS(2375),
    [anon_sym_unsigned] = ACTIONS(2375),
    [anon_sym_long] = ACTIONS(2375),
    [anon_sym_short] = ACTIONS(2375),
    [anon_sym_LBRACK] = ACTIONS(2375),
    [anon_sym_static] = ACTIONS(2375),
    [anon_sym_register] = ACTIONS(2375),
    [anon_sym_inline] = ACTIONS(2375),
    [anon_sym___inline] = ACTIONS(2375),
    [anon_sym___inline__] = ACTIONS(2375),
    [anon_sym___forceinline] = ACTIONS(2375),
    [anon_sym_thread_local] = ACTIONS(2375),
    [anon_sym___thread] = ACTIONS(2375),
    [anon_sym_const] = ACTIONS(2375),
    [anon_sym_constexpr] = ACTIONS(2375),
    [anon_sym_volatile] = ACTIONS(2375),
    [anon_sym_restrict] = ACTIONS(2375),
    [anon_sym___restrict__] = ACTIONS(2375),
    [anon_sym__Atomic] = ACTIONS(2375),
    [anon_sym__Noreturn] = ACTIONS(2375),
    [anon_sym_noreturn] = ACTIONS(2375),
    [anon_sym_mutable] = ACTIONS(2375),
    [anon_sym_constinit] = ACTIONS(2375),
    [anon_sym_consteval] = ACTIONS(2375),
    [anon_sym_alignas] = ACTIONS(2375),
    [anon_sym__Alignas] = ACTIONS(2375),
    [sym_primitive_type] = ACTIONS(2375),
    [anon_sym_enum] = ACTIONS(2375),
    [anon_sym_class] = ACTIONS(2375),
    [anon_sym_struct] = ACTIONS(2375),
    [anon_sym_union] = ACTIONS(2375),
    [anon_sym_if] = ACTIONS(2375),
    [anon_sym_switch] = ACTIONS(2375),
    [anon_sym_case] = ACTIONS(2375),
    [anon_sym_default] = ACTIONS(2375),
    [anon_sym_while] = ACTIONS(2375),
    [anon_sym_do] = ACTIONS(2375),
    [anon_sym_for] = ACTIONS(2375),
    [anon_sym_return] = ACTIONS(2375),
    [anon_sym_break] = ACTIONS(2375),
    [anon_sym_continue] = ACTIONS(2375),
    [anon_sym_goto] = ACTIONS(2375),
    [anon_sym___try] = ACTIONS(2375),
    [anon_sym___leave] = ACTIONS(2375),
    [anon_sym_not] = ACTIONS(2375),
    [anon_sym_compl] = ACTIONS(2375),
    [anon_sym_DASH_DASH] = ACTIONS(2377),
    [anon_sym_PLUS_PLUS] = ACTIONS(2377),
    [anon_sym_sizeof] = ACTIONS(2375),
    [anon_sym___alignof__] = ACTIONS(2375),
    [anon_sym___alignof] = ACTIONS(2375),
    [anon_sym__alignof] = ACTIONS(2375),
    [anon_sym_alignof] = ACTIONS(2375),
    [anon_sym__Alignof] = ACTIONS(2375),
    [anon_sym_offsetof] = ACTIONS(2375),
    [anon_sym__Generic] = ACTIONS(2375),
    [anon_sym_asm] = ACTIONS(2375),
    [anon_sym___asm__] = ACTIONS(2375),
    [sym_number_literal] = ACTIONS(2377),
    [anon_sym_L_SQUOTE] = ACTIONS(2377),
    [anon_sym_u_SQUOTE] = ACTIONS(2377),
    [anon_sym_U_SQUOTE] = ACTIONS(2377),
    [anon_sym_u8_SQUOTE] = ACTIONS(2377),
    [anon_sym_SQUOTE] = ACTIONS(2377),
    [anon_sym_L_DQUOTE] = ACTIONS(2377),
    [anon_sym_u_DQUOTE] = ACTIONS(2377),
    [anon_sym_U_DQUOTE] = ACTIONS(2377),
    [anon_sym_u8_DQUOTE] = ACTIONS(2377),
    [anon_sym_DQUOTE] = ACTIONS(2377),
    [sym_true] = ACTIONS(2375),
    [sym_false] = ACTIONS(2375),
    [anon_sym_NULL] = ACTIONS(2375),
    [anon_sym_nullptr] = ACTIONS(2375),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2375),
    [anon_sym_decltype] = ACTIONS(2375),
    [sym_virtual] = ACTIONS(2375),
    [anon_sym_explicit] = ACTIONS(2375),
    [anon_sym_typename] = ACTIONS(2375),
    [anon_sym_template] = ACTIONS(2375),
    [anon_sym_operator] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_delete] = ACTIONS(2375),
    [anon_sym_throw] = ACTIONS(2375),
    [anon_sym_namespace] = ACTIONS(2375),
    [anon_sym_using] = ACTIONS(2375),
    [anon_sym_static_assert] = ACTIONS(2375),
    [anon_sym_concept] = ACTIONS(2375),
    [anon_sym_co_return] = ACTIONS(2375),
    [anon_sym_co_yield] = ACTIONS(2375),
    [anon_sym_R_DQUOTE] = ACTIONS(2377),
    [anon_sym_LR_DQUOTE] = ACTIONS(2377),
    [anon_sym_uR_DQUOTE] = ACTIONS(2377),
    [anon_sym_UR_DQUOTE] = ACTIONS(2377),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2377),
    [anon_sym_co_await] = ACTIONS(2375),
    [anon_sym_new] = ACTIONS(2375),
    [anon_sym_requires] = ACTIONS(2375),
    [sym_this] = ACTIONS(2375),
    [anon_sym_discard] = ACTIONS(2375),
    [anon_sym_precise] = ACTIONS(2375),
    [anon_sym_shared] = ACTIONS(2375),
    [anon_sym_groupshared] = ACTIONS(2375),
    [anon_sym_uniform] = ACTIONS(2375),
    [anon_sym_row_major] = ACTIONS(2375),
    [anon_sym_column_major] = ACTIONS(2375),
    [anon_sym_globallycoherent] = ACTIONS(2375),
    [anon_sym_centroid] = ACTIONS(2375),
    [anon_sym_noperspective] = ACTIONS(2375),
    [anon_sym_nointerpolation] = ACTIONS(2375),
    [anon_sym_sample] = ACTIONS(2375),
    [anon_sym_linear] = ACTIONS(2375),
    [anon_sym_snorm] = ACTIONS(2375),
    [anon_sym_unorm] = ACTIONS(2375),
    [anon_sym_point] = ACTIONS(2375),
    [anon_sym_line] = ACTIONS(2375),
    [anon_sym_triangleadj] = ACTIONS(2375),
    [anon_sym_lineadj] = ACTIONS(2375),
    [anon_sym_triangle] = ACTIONS(2375),
    [anon_sym_cbuffer] = ACTIONS(2375),
  },
  [268] = {
    [sym_identifier] = ACTIONS(2379),
    [aux_sym_preproc_include_token1] = ACTIONS(2379),
    [aux_sym_preproc_def_token1] = ACTIONS(2379),
    [aux_sym_preproc_if_token1] = ACTIONS(2379),
    [aux_sym_preproc_if_token2] = ACTIONS(2379),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2379),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2379),
    [aux_sym_preproc_else_token1] = ACTIONS(2379),
    [aux_sym_preproc_elif_token1] = ACTIONS(2379),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2379),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2379),
    [sym_preproc_directive] = ACTIONS(2379),
    [anon_sym_LPAREN2] = ACTIONS(2381),
    [anon_sym_BANG] = ACTIONS(2381),
    [anon_sym_TILDE] = ACTIONS(2381),
    [anon_sym_DASH] = ACTIONS(2379),
    [anon_sym_PLUS] = ACTIONS(2379),
    [anon_sym_STAR] = ACTIONS(2381),
    [anon_sym_AMP_AMP] = ACTIONS(2381),
    [anon_sym_AMP] = ACTIONS(2379),
    [anon_sym_SEMI] = ACTIONS(2381),
    [anon_sym___extension__] = ACTIONS(2379),
    [anon_sym_typedef] = ACTIONS(2379),
    [anon_sym_in] = ACTIONS(2379),
    [anon_sym_out] = ACTIONS(2379),
    [anon_sym_inout] = ACTIONS(2379),
    [anon_sym_extern] = ACTIONS(2379),
    [anon_sym___attribute__] = ACTIONS(2379),
    [anon_sym_COLON_COLON] = ACTIONS(2381),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2381),
    [anon_sym___declspec] = ACTIONS(2379),
    [anon_sym___based] = ACTIONS(2379),
    [anon_sym___cdecl] = ACTIONS(2379),
    [anon_sym___clrcall] = ACTIONS(2379),
    [anon_sym___stdcall] = ACTIONS(2379),
    [anon_sym___fastcall] = ACTIONS(2379),
    [anon_sym___thiscall] = ACTIONS(2379),
    [anon_sym___vectorcall] = ACTIONS(2379),
    [anon_sym_LBRACE] = ACTIONS(2381),
    [anon_sym_signed] = ACTIONS(2379),
    [anon_sym_unsigned] = ACTIONS(2379),
    [anon_sym_long] = ACTIONS(2379),
    [anon_sym_short] = ACTIONS(2379),
    [anon_sym_LBRACK] = ACTIONS(2379),
    [anon_sym_static] = ACTIONS(2379),
    [anon_sym_register] = ACTIONS(2379),
    [anon_sym_inline] = ACTIONS(2379),
    [anon_sym___inline] = ACTIONS(2379),
    [anon_sym___inline__] = ACTIONS(2379),
    [anon_sym___forceinline] = ACTIONS(2379),
    [anon_sym_thread_local] = ACTIONS(2379),
    [anon_sym___thread] = ACTIONS(2379),
    [anon_sym_const] = ACTIONS(2379),
    [anon_sym_constexpr] = ACTIONS(2379),
    [anon_sym_volatile] = ACTIONS(2379),
    [anon_sym_restrict] = ACTIONS(2379),
    [anon_sym___restrict__] = ACTIONS(2379),
    [anon_sym__Atomic] = ACTIONS(2379),
    [anon_sym__Noreturn] = ACTIONS(2379),
    [anon_sym_noreturn] = ACTIONS(2379),
    [anon_sym_mutable] = ACTIONS(2379),
    [anon_sym_constinit] = ACTIONS(2379),
    [anon_sym_consteval] = ACTIONS(2379),
    [anon_sym_alignas] = ACTIONS(2379),
    [anon_sym__Alignas] = ACTIONS(2379),
    [sym_primitive_type] = ACTIONS(2379),
    [anon_sym_enum] = ACTIONS(2379),
    [anon_sym_class] = ACTIONS(2379),
    [anon_sym_struct] = ACTIONS(2379),
    [anon_sym_union] = ACTIONS(2379),
    [anon_sym_if] = ACTIONS(2379),
    [anon_sym_switch] = ACTIONS(2379),
    [anon_sym_case] = ACTIONS(2379),
    [anon_sym_default] = ACTIONS(2379),
    [anon_sym_while] = ACTIONS(2379),
    [anon_sym_do] = ACTIONS(2379),
    [anon_sym_for] = ACTIONS(2379),
    [anon_sym_return] = ACTIONS(2379),
    [anon_sym_break] = ACTIONS(2379),
    [anon_sym_continue] = ACTIONS(2379),
    [anon_sym_goto] = ACTIONS(2379),
    [anon_sym___try] = ACTIONS(2379),
    [anon_sym___leave] = ACTIONS(2379),
    [anon_sym_not] = ACTIONS(2379),
    [anon_sym_compl] = ACTIONS(2379),
    [anon_sym_DASH_DASH] = ACTIONS(2381),
    [anon_sym_PLUS_PLUS] = ACTIONS(2381),
    [anon_sym_sizeof] = ACTIONS(2379),
    [anon_sym___alignof__] = ACTIONS(2379),
    [anon_sym___alignof] = ACTIONS(2379),
    [anon_sym__alignof] = ACTIONS(2379),
    [anon_sym_alignof] = ACTIONS(2379),
    [anon_sym__Alignof] = ACTIONS(2379),
    [anon_sym_offsetof] = ACTIONS(2379),
    [anon_sym__Generic] = ACTIONS(2379),
    [anon_sym_asm] = ACTIONS(2379),
    [anon_sym___asm__] = ACTIONS(2379),
    [sym_number_literal] = ACTIONS(2381),
    [anon_sym_L_SQUOTE] = ACTIONS(2381),
    [anon_sym_u_SQUOTE] = ACTIONS(2381),
    [anon_sym_U_SQUOTE] = ACTIONS(2381),
    [anon_sym_u8_SQUOTE] = ACTIONS(2381),
    [anon_sym_SQUOTE] = ACTIONS(2381),
    [anon_sym_L_DQUOTE] = ACTIONS(2381),
    [anon_sym_u_DQUOTE] = ACTIONS(2381),
    [anon_sym_U_DQUOTE] = ACTIONS(2381),
    [anon_sym_u8_DQUOTE] = ACTIONS(2381),
    [anon_sym_DQUOTE] = ACTIONS(2381),
    [sym_true] = ACTIONS(2379),
    [sym_false] = ACTIONS(2379),
    [anon_sym_NULL] = ACTIONS(2379),
    [anon_sym_nullptr] = ACTIONS(2379),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2379),
    [anon_sym_decltype] = ACTIONS(2379),
    [sym_virtual] = ACTIONS(2379),
    [anon_sym_explicit] = ACTIONS(2379),
    [anon_sym_typename] = ACTIONS(2379),
    [anon_sym_template] = ACTIONS(2379),
    [anon_sym_operator] = ACTIONS(2379),
    [anon_sym_try] = ACTIONS(2379),
    [anon_sym_delete] = ACTIONS(2379),
    [anon_sym_throw] = ACTIONS(2379),
    [anon_sym_namespace] = ACTIONS(2379),
    [anon_sym_using] = ACTIONS(2379),
    [anon_sym_static_assert] = ACTIONS(2379),
    [anon_sym_concept] = ACTIONS(2379),
    [anon_sym_co_return] = ACTIONS(2379),
    [anon_sym_co_yield] = ACTIONS(2379),
    [anon_sym_R_DQUOTE] = ACTIONS(2381),
    [anon_sym_LR_DQUOTE] = ACTIONS(2381),
    [anon_sym_uR_DQUOTE] = ACTIONS(2381),
    [anon_sym_UR_DQUOTE] = ACTIONS(2381),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2381),
    [anon_sym_co_await] = ACTIONS(2379),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_requires] = ACTIONS(2379),
    [sym_this] = ACTIONS(2379),
    [anon_sym_discard] = ACTIONS(2379),
    [anon_sym_precise] = ACTIONS(2379),
    [anon_sym_shared] = ACTIONS(2379),
    [anon_sym_groupshared] = ACTIONS(2379),
    [anon_sym_uniform] = ACTIONS(2379),
    [anon_sym_row_major] = ACTIONS(2379),
    [anon_sym_column_major] = ACTIONS(2379),
    [anon_sym_globallycoherent] = ACTIONS(2379),
    [anon_sym_centroid] = ACTIONS(2379),
    [anon_sym_noperspective] = ACTIONS(2379),
    [anon_sym_nointerpolation] = ACTIONS(2379),
    [anon_sym_sample] = ACTIONS(2379),
    [anon_sym_linear] = ACTIONS(2379),
    [anon_sym_snorm] = ACTIONS(2379),
    [anon_sym_unorm] = ACTIONS(2379),
    [anon_sym_point] = ACTIONS(2379),
    [anon_sym_line] = ACTIONS(2379),
    [anon_sym_triangleadj] = ACTIONS(2379),
    [anon_sym_lineadj] = ACTIONS(2379),
    [anon_sym_triangle] = ACTIONS(2379),
    [anon_sym_cbuffer] = ACTIONS(2379),
  },
  [269] = {
    [sym_identifier] = ACTIONS(1925),
    [aux_sym_preproc_include_token1] = ACTIONS(1925),
    [aux_sym_preproc_def_token1] = ACTIONS(1925),
    [aux_sym_preproc_if_token1] = ACTIONS(1925),
    [aux_sym_preproc_if_token2] = ACTIONS(1925),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1925),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1925),
    [sym_preproc_directive] = ACTIONS(1925),
    [anon_sym_LPAREN2] = ACTIONS(1927),
    [anon_sym_BANG] = ACTIONS(1927),
    [anon_sym_TILDE] = ACTIONS(1927),
    [anon_sym_DASH] = ACTIONS(1925),
    [anon_sym_PLUS] = ACTIONS(1925),
    [anon_sym_STAR] = ACTIONS(1927),
    [anon_sym_AMP_AMP] = ACTIONS(1927),
    [anon_sym_AMP] = ACTIONS(1925),
    [anon_sym_COLON] = ACTIONS(1925),
    [anon_sym_SEMI] = ACTIONS(1927),
    [anon_sym___extension__] = ACTIONS(1925),
    [anon_sym_typedef] = ACTIONS(1925),
    [anon_sym_in] = ACTIONS(1925),
    [anon_sym_out] = ACTIONS(1925),
    [anon_sym_inout] = ACTIONS(1925),
    [anon_sym_extern] = ACTIONS(1925),
    [anon_sym___attribute__] = ACTIONS(1925),
    [anon_sym_COLON_COLON] = ACTIONS(1927),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1927),
    [anon_sym___declspec] = ACTIONS(1925),
    [anon_sym___based] = ACTIONS(1925),
    [anon_sym___cdecl] = ACTIONS(1925),
    [anon_sym___clrcall] = ACTIONS(1925),
    [anon_sym___stdcall] = ACTIONS(1925),
    [anon_sym___fastcall] = ACTIONS(1925),
    [anon_sym___thiscall] = ACTIONS(1925),
    [anon_sym___vectorcall] = ACTIONS(1925),
    [anon_sym_LBRACE] = ACTIONS(1927),
    [anon_sym_signed] = ACTIONS(1925),
    [anon_sym_unsigned] = ACTIONS(1925),
    [anon_sym_long] = ACTIONS(1925),
    [anon_sym_short] = ACTIONS(1925),
    [anon_sym_LBRACK] = ACTIONS(1925),
    [anon_sym_static] = ACTIONS(1925),
    [anon_sym_register] = ACTIONS(1925),
    [anon_sym_inline] = ACTIONS(1925),
    [anon_sym___inline] = ACTIONS(1925),
    [anon_sym___inline__] = ACTIONS(1925),
    [anon_sym___forceinline] = ACTIONS(1925),
    [anon_sym_thread_local] = ACTIONS(1925),
    [anon_sym___thread] = ACTIONS(1925),
    [anon_sym_const] = ACTIONS(1925),
    [anon_sym_constexpr] = ACTIONS(1925),
    [anon_sym_volatile] = ACTIONS(1925),
    [anon_sym_restrict] = ACTIONS(1925),
    [anon_sym___restrict__] = ACTIONS(1925),
    [anon_sym__Atomic] = ACTIONS(1925),
    [anon_sym__Noreturn] = ACTIONS(1925),
    [anon_sym_noreturn] = ACTIONS(1925),
    [anon_sym_mutable] = ACTIONS(1925),
    [anon_sym_constinit] = ACTIONS(1925),
    [anon_sym_consteval] = ACTIONS(1925),
    [anon_sym_alignas] = ACTIONS(1925),
    [anon_sym__Alignas] = ACTIONS(1925),
    [sym_primitive_type] = ACTIONS(1925),
    [anon_sym_enum] = ACTIONS(1925),
    [anon_sym_class] = ACTIONS(1925),
    [anon_sym_struct] = ACTIONS(1925),
    [anon_sym_union] = ACTIONS(1925),
    [anon_sym_if] = ACTIONS(1925),
    [anon_sym_else] = ACTIONS(1925),
    [anon_sym_switch] = ACTIONS(1925),
    [anon_sym_case] = ACTIONS(1925),
    [anon_sym_default] = ACTIONS(1925),
    [anon_sym_while] = ACTIONS(1925),
    [anon_sym_do] = ACTIONS(1925),
    [anon_sym_for] = ACTIONS(1925),
    [anon_sym_return] = ACTIONS(1925),
    [anon_sym_break] = ACTIONS(1925),
    [anon_sym_continue] = ACTIONS(1925),
    [anon_sym_goto] = ACTIONS(1925),
    [anon_sym___try] = ACTIONS(1925),
    [anon_sym___leave] = ACTIONS(1925),
    [anon_sym_not] = ACTIONS(1925),
    [anon_sym_compl] = ACTIONS(1925),
    [anon_sym_DASH_DASH] = ACTIONS(1927),
    [anon_sym_PLUS_PLUS] = ACTIONS(1927),
    [anon_sym_sizeof] = ACTIONS(1925),
    [anon_sym___alignof__] = ACTIONS(1925),
    [anon_sym___alignof] = ACTIONS(1925),
    [anon_sym__alignof] = ACTIONS(1925),
    [anon_sym_alignof] = ACTIONS(1925),
    [anon_sym__Alignof] = ACTIONS(1925),
    [anon_sym_offsetof] = ACTIONS(1925),
    [anon_sym__Generic] = ACTIONS(1925),
    [anon_sym_asm] = ACTIONS(1925),
    [anon_sym___asm__] = ACTIONS(1925),
    [sym_number_literal] = ACTIONS(1927),
    [anon_sym_L_SQUOTE] = ACTIONS(1927),
    [anon_sym_u_SQUOTE] = ACTIONS(1927),
    [anon_sym_U_SQUOTE] = ACTIONS(1927),
    [anon_sym_u8_SQUOTE] = ACTIONS(1927),
    [anon_sym_SQUOTE] = ACTIONS(1927),
    [anon_sym_L_DQUOTE] = ACTIONS(1927),
    [anon_sym_u_DQUOTE] = ACTIONS(1927),
    [anon_sym_U_DQUOTE] = ACTIONS(1927),
    [anon_sym_u8_DQUOTE] = ACTIONS(1927),
    [anon_sym_DQUOTE] = ACTIONS(1927),
    [sym_true] = ACTIONS(1925),
    [sym_false] = ACTIONS(1925),
    [anon_sym_NULL] = ACTIONS(1925),
    [anon_sym_nullptr] = ACTIONS(1925),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1925),
    [anon_sym_decltype] = ACTIONS(1925),
    [anon_sym_final] = ACTIONS(1925),
    [anon_sym_override] = ACTIONS(1925),
    [sym_virtual] = ACTIONS(1925),
    [anon_sym_explicit] = ACTIONS(1925),
    [anon_sym_typename] = ACTIONS(1925),
    [anon_sym_template] = ACTIONS(1925),
    [anon_sym_operator] = ACTIONS(1925),
    [anon_sym_try] = ACTIONS(1925),
    [anon_sym_delete] = ACTIONS(1925),
    [anon_sym_throw] = ACTIONS(1925),
    [anon_sym_namespace] = ACTIONS(1925),
    [anon_sym_using] = ACTIONS(1925),
    [anon_sym_static_assert] = ACTIONS(1925),
    [anon_sym_concept] = ACTIONS(1925),
    [anon_sym_co_return] = ACTIONS(1925),
    [anon_sym_co_yield] = ACTIONS(1925),
    [anon_sym_R_DQUOTE] = ACTIONS(1927),
    [anon_sym_LR_DQUOTE] = ACTIONS(1927),
    [anon_sym_uR_DQUOTE] = ACTIONS(1927),
    [anon_sym_UR_DQUOTE] = ACTIONS(1927),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1927),
    [anon_sym_co_await] = ACTIONS(1925),
    [anon_sym_new] = ACTIONS(1925),
    [anon_sym_requires] = ACTIONS(1925),
    [sym_this] = ACTIONS(1925),
    [anon_sym_discard] = ACTIONS(1925),
    [anon_sym_precise] = ACTIONS(1925),
    [anon_sym_shared] = ACTIONS(1925),
    [anon_sym_groupshared] = ACTIONS(1925),
    [anon_sym_uniform] = ACTIONS(1925),
    [anon_sym_row_major] = ACTIONS(1925),
    [anon_sym_column_major] = ACTIONS(1925),
    [anon_sym_globallycoherent] = ACTIONS(1925),
    [anon_sym_centroid] = ACTIONS(1925),
    [anon_sym_noperspective] = ACTIONS(1925),
    [anon_sym_nointerpolation] = ACTIONS(1925),
    [anon_sym_sample] = ACTIONS(1925),
    [anon_sym_linear] = ACTIONS(1925),
    [anon_sym_snorm] = ACTIONS(1925),
    [anon_sym_unorm] = ACTIONS(1925),
    [anon_sym_point] = ACTIONS(1925),
    [anon_sym_line] = ACTIONS(1925),
    [anon_sym_triangleadj] = ACTIONS(1925),
    [anon_sym_lineadj] = ACTIONS(1925),
    [anon_sym_triangle] = ACTIONS(1925),
    [anon_sym_cbuffer] = ACTIONS(1925),
  },
  [270] = {
    [sym_identifier] = ACTIONS(1891),
    [aux_sym_preproc_include_token1] = ACTIONS(1891),
    [aux_sym_preproc_def_token1] = ACTIONS(1891),
    [aux_sym_preproc_if_token1] = ACTIONS(1891),
    [aux_sym_preproc_if_token2] = ACTIONS(1891),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1891),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1891),
    [sym_preproc_directive] = ACTIONS(1891),
    [anon_sym_LPAREN2] = ACTIONS(1893),
    [anon_sym_BANG] = ACTIONS(1893),
    [anon_sym_TILDE] = ACTIONS(1893),
    [anon_sym_DASH] = ACTIONS(1891),
    [anon_sym_PLUS] = ACTIONS(1891),
    [anon_sym_STAR] = ACTIONS(1893),
    [anon_sym_AMP_AMP] = ACTIONS(1893),
    [anon_sym_AMP] = ACTIONS(1891),
    [anon_sym_COLON] = ACTIONS(1891),
    [anon_sym_SEMI] = ACTIONS(1893),
    [anon_sym___extension__] = ACTIONS(1891),
    [anon_sym_typedef] = ACTIONS(1891),
    [anon_sym_in] = ACTIONS(1891),
    [anon_sym_out] = ACTIONS(1891),
    [anon_sym_inout] = ACTIONS(1891),
    [anon_sym_extern] = ACTIONS(1891),
    [anon_sym___attribute__] = ACTIONS(1891),
    [anon_sym_COLON_COLON] = ACTIONS(1893),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1893),
    [anon_sym___declspec] = ACTIONS(1891),
    [anon_sym___based] = ACTIONS(1891),
    [anon_sym___cdecl] = ACTIONS(1891),
    [anon_sym___clrcall] = ACTIONS(1891),
    [anon_sym___stdcall] = ACTIONS(1891),
    [anon_sym___fastcall] = ACTIONS(1891),
    [anon_sym___thiscall] = ACTIONS(1891),
    [anon_sym___vectorcall] = ACTIONS(1891),
    [anon_sym_LBRACE] = ACTIONS(1893),
    [anon_sym_signed] = ACTIONS(1891),
    [anon_sym_unsigned] = ACTIONS(1891),
    [anon_sym_long] = ACTIONS(1891),
    [anon_sym_short] = ACTIONS(1891),
    [anon_sym_LBRACK] = ACTIONS(1891),
    [anon_sym_static] = ACTIONS(1891),
    [anon_sym_register] = ACTIONS(1891),
    [anon_sym_inline] = ACTIONS(1891),
    [anon_sym___inline] = ACTIONS(1891),
    [anon_sym___inline__] = ACTIONS(1891),
    [anon_sym___forceinline] = ACTIONS(1891),
    [anon_sym_thread_local] = ACTIONS(1891),
    [anon_sym___thread] = ACTIONS(1891),
    [anon_sym_const] = ACTIONS(1891),
    [anon_sym_constexpr] = ACTIONS(1891),
    [anon_sym_volatile] = ACTIONS(1891),
    [anon_sym_restrict] = ACTIONS(1891),
    [anon_sym___restrict__] = ACTIONS(1891),
    [anon_sym__Atomic] = ACTIONS(1891),
    [anon_sym__Noreturn] = ACTIONS(1891),
    [anon_sym_noreturn] = ACTIONS(1891),
    [anon_sym_mutable] = ACTIONS(1891),
    [anon_sym_constinit] = ACTIONS(1891),
    [anon_sym_consteval] = ACTIONS(1891),
    [anon_sym_alignas] = ACTIONS(1891),
    [anon_sym__Alignas] = ACTIONS(1891),
    [sym_primitive_type] = ACTIONS(1891),
    [anon_sym_enum] = ACTIONS(1891),
    [anon_sym_class] = ACTIONS(1891),
    [anon_sym_struct] = ACTIONS(1891),
    [anon_sym_union] = ACTIONS(1891),
    [anon_sym_if] = ACTIONS(1891),
    [anon_sym_else] = ACTIONS(1891),
    [anon_sym_switch] = ACTIONS(1891),
    [anon_sym_case] = ACTIONS(1891),
    [anon_sym_default] = ACTIONS(1891),
    [anon_sym_while] = ACTIONS(1891),
    [anon_sym_do] = ACTIONS(1891),
    [anon_sym_for] = ACTIONS(1891),
    [anon_sym_return] = ACTIONS(1891),
    [anon_sym_break] = ACTIONS(1891),
    [anon_sym_continue] = ACTIONS(1891),
    [anon_sym_goto] = ACTIONS(1891),
    [anon_sym___try] = ACTIONS(1891),
    [anon_sym___leave] = ACTIONS(1891),
    [anon_sym_not] = ACTIONS(1891),
    [anon_sym_compl] = ACTIONS(1891),
    [anon_sym_DASH_DASH] = ACTIONS(1893),
    [anon_sym_PLUS_PLUS] = ACTIONS(1893),
    [anon_sym_sizeof] = ACTIONS(1891),
    [anon_sym___alignof__] = ACTIONS(1891),
    [anon_sym___alignof] = ACTIONS(1891),
    [anon_sym__alignof] = ACTIONS(1891),
    [anon_sym_alignof] = ACTIONS(1891),
    [anon_sym__Alignof] = ACTIONS(1891),
    [anon_sym_offsetof] = ACTIONS(1891),
    [anon_sym__Generic] = ACTIONS(1891),
    [anon_sym_asm] = ACTIONS(1891),
    [anon_sym___asm__] = ACTIONS(1891),
    [sym_number_literal] = ACTIONS(1893),
    [anon_sym_L_SQUOTE] = ACTIONS(1893),
    [anon_sym_u_SQUOTE] = ACTIONS(1893),
    [anon_sym_U_SQUOTE] = ACTIONS(1893),
    [anon_sym_u8_SQUOTE] = ACTIONS(1893),
    [anon_sym_SQUOTE] = ACTIONS(1893),
    [anon_sym_L_DQUOTE] = ACTIONS(1893),
    [anon_sym_u_DQUOTE] = ACTIONS(1893),
    [anon_sym_U_DQUOTE] = ACTIONS(1893),
    [anon_sym_u8_DQUOTE] = ACTIONS(1893),
    [anon_sym_DQUOTE] = ACTIONS(1893),
    [sym_true] = ACTIONS(1891),
    [sym_false] = ACTIONS(1891),
    [anon_sym_NULL] = ACTIONS(1891),
    [anon_sym_nullptr] = ACTIONS(1891),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1891),
    [anon_sym_decltype] = ACTIONS(1891),
    [anon_sym_final] = ACTIONS(1891),
    [anon_sym_override] = ACTIONS(1891),
    [sym_virtual] = ACTIONS(1891),
    [anon_sym_explicit] = ACTIONS(1891),
    [anon_sym_typename] = ACTIONS(1891),
    [anon_sym_template] = ACTIONS(1891),
    [anon_sym_operator] = ACTIONS(1891),
    [anon_sym_try] = ACTIONS(1891),
    [anon_sym_delete] = ACTIONS(1891),
    [anon_sym_throw] = ACTIONS(1891),
    [anon_sym_namespace] = ACTIONS(1891),
    [anon_sym_using] = ACTIONS(1891),
    [anon_sym_static_assert] = ACTIONS(1891),
    [anon_sym_concept] = ACTIONS(1891),
    [anon_sym_co_return] = ACTIONS(1891),
    [anon_sym_co_yield] = ACTIONS(1891),
    [anon_sym_R_DQUOTE] = ACTIONS(1893),
    [anon_sym_LR_DQUOTE] = ACTIONS(1893),
    [anon_sym_uR_DQUOTE] = ACTIONS(1893),
    [anon_sym_UR_DQUOTE] = ACTIONS(1893),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1893),
    [anon_sym_co_await] = ACTIONS(1891),
    [anon_sym_new] = ACTIONS(1891),
    [anon_sym_requires] = ACTIONS(1891),
    [sym_this] = ACTIONS(1891),
    [anon_sym_discard] = ACTIONS(1891),
    [anon_sym_precise] = ACTIONS(1891),
    [anon_sym_shared] = ACTIONS(1891),
    [anon_sym_groupshared] = ACTIONS(1891),
    [anon_sym_uniform] = ACTIONS(1891),
    [anon_sym_row_major] = ACTIONS(1891),
    [anon_sym_column_major] = ACTIONS(1891),
    [anon_sym_globallycoherent] = ACTIONS(1891),
    [anon_sym_centroid] = ACTIONS(1891),
    [anon_sym_noperspective] = ACTIONS(1891),
    [anon_sym_nointerpolation] = ACTIONS(1891),
    [anon_sym_sample] = ACTIONS(1891),
    [anon_sym_linear] = ACTIONS(1891),
    [anon_sym_snorm] = ACTIONS(1891),
    [anon_sym_unorm] = ACTIONS(1891),
    [anon_sym_point] = ACTIONS(1891),
    [anon_sym_line] = ACTIONS(1891),
    [anon_sym_triangleadj] = ACTIONS(1891),
    [anon_sym_lineadj] = ACTIONS(1891),
    [anon_sym_triangle] = ACTIONS(1891),
    [anon_sym_cbuffer] = ACTIONS(1891),
  },
  [271] = {
    [sym_identifier] = ACTIONS(1887),
    [aux_sym_preproc_include_token1] = ACTIONS(1887),
    [aux_sym_preproc_def_token1] = ACTIONS(1887),
    [aux_sym_preproc_if_token1] = ACTIONS(1887),
    [aux_sym_preproc_if_token2] = ACTIONS(1887),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1887),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1887),
    [sym_preproc_directive] = ACTIONS(1887),
    [anon_sym_LPAREN2] = ACTIONS(1889),
    [anon_sym_BANG] = ACTIONS(1889),
    [anon_sym_TILDE] = ACTIONS(1889),
    [anon_sym_DASH] = ACTIONS(1887),
    [anon_sym_PLUS] = ACTIONS(1887),
    [anon_sym_STAR] = ACTIONS(1889),
    [anon_sym_AMP_AMP] = ACTIONS(1889),
    [anon_sym_AMP] = ACTIONS(1887),
    [anon_sym_COLON] = ACTIONS(1887),
    [anon_sym_SEMI] = ACTIONS(1889),
    [anon_sym___extension__] = ACTIONS(1887),
    [anon_sym_typedef] = ACTIONS(1887),
    [anon_sym_in] = ACTIONS(1887),
    [anon_sym_out] = ACTIONS(1887),
    [anon_sym_inout] = ACTIONS(1887),
    [anon_sym_extern] = ACTIONS(1887),
    [anon_sym___attribute__] = ACTIONS(1887),
    [anon_sym_COLON_COLON] = ACTIONS(1889),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1889),
    [anon_sym___declspec] = ACTIONS(1887),
    [anon_sym___based] = ACTIONS(1887),
    [anon_sym___cdecl] = ACTIONS(1887),
    [anon_sym___clrcall] = ACTIONS(1887),
    [anon_sym___stdcall] = ACTIONS(1887),
    [anon_sym___fastcall] = ACTIONS(1887),
    [anon_sym___thiscall] = ACTIONS(1887),
    [anon_sym___vectorcall] = ACTIONS(1887),
    [anon_sym_LBRACE] = ACTIONS(1889),
    [anon_sym_signed] = ACTIONS(1887),
    [anon_sym_unsigned] = ACTIONS(1887),
    [anon_sym_long] = ACTIONS(1887),
    [anon_sym_short] = ACTIONS(1887),
    [anon_sym_LBRACK] = ACTIONS(1887),
    [anon_sym_static] = ACTIONS(1887),
    [anon_sym_register] = ACTIONS(1887),
    [anon_sym_inline] = ACTIONS(1887),
    [anon_sym___inline] = ACTIONS(1887),
    [anon_sym___inline__] = ACTIONS(1887),
    [anon_sym___forceinline] = ACTIONS(1887),
    [anon_sym_thread_local] = ACTIONS(1887),
    [anon_sym___thread] = ACTIONS(1887),
    [anon_sym_const] = ACTIONS(1887),
    [anon_sym_constexpr] = ACTIONS(1887),
    [anon_sym_volatile] = ACTIONS(1887),
    [anon_sym_restrict] = ACTIONS(1887),
    [anon_sym___restrict__] = ACTIONS(1887),
    [anon_sym__Atomic] = ACTIONS(1887),
    [anon_sym__Noreturn] = ACTIONS(1887),
    [anon_sym_noreturn] = ACTIONS(1887),
    [anon_sym_mutable] = ACTIONS(1887),
    [anon_sym_constinit] = ACTIONS(1887),
    [anon_sym_consteval] = ACTIONS(1887),
    [anon_sym_alignas] = ACTIONS(1887),
    [anon_sym__Alignas] = ACTIONS(1887),
    [sym_primitive_type] = ACTIONS(1887),
    [anon_sym_enum] = ACTIONS(1887),
    [anon_sym_class] = ACTIONS(1887),
    [anon_sym_struct] = ACTIONS(1887),
    [anon_sym_union] = ACTIONS(1887),
    [anon_sym_if] = ACTIONS(1887),
    [anon_sym_else] = ACTIONS(1887),
    [anon_sym_switch] = ACTIONS(1887),
    [anon_sym_case] = ACTIONS(1887),
    [anon_sym_default] = ACTIONS(1887),
    [anon_sym_while] = ACTIONS(1887),
    [anon_sym_do] = ACTIONS(1887),
    [anon_sym_for] = ACTIONS(1887),
    [anon_sym_return] = ACTIONS(1887),
    [anon_sym_break] = ACTIONS(1887),
    [anon_sym_continue] = ACTIONS(1887),
    [anon_sym_goto] = ACTIONS(1887),
    [anon_sym___try] = ACTIONS(1887),
    [anon_sym___leave] = ACTIONS(1887),
    [anon_sym_not] = ACTIONS(1887),
    [anon_sym_compl] = ACTIONS(1887),
    [anon_sym_DASH_DASH] = ACTIONS(1889),
    [anon_sym_PLUS_PLUS] = ACTIONS(1889),
    [anon_sym_sizeof] = ACTIONS(1887),
    [anon_sym___alignof__] = ACTIONS(1887),
    [anon_sym___alignof] = ACTIONS(1887),
    [anon_sym__alignof] = ACTIONS(1887),
    [anon_sym_alignof] = ACTIONS(1887),
    [anon_sym__Alignof] = ACTIONS(1887),
    [anon_sym_offsetof] = ACTIONS(1887),
    [anon_sym__Generic] = ACTIONS(1887),
    [anon_sym_asm] = ACTIONS(1887),
    [anon_sym___asm__] = ACTIONS(1887),
    [sym_number_literal] = ACTIONS(1889),
    [anon_sym_L_SQUOTE] = ACTIONS(1889),
    [anon_sym_u_SQUOTE] = ACTIONS(1889),
    [anon_sym_U_SQUOTE] = ACTIONS(1889),
    [anon_sym_u8_SQUOTE] = ACTIONS(1889),
    [anon_sym_SQUOTE] = ACTIONS(1889),
    [anon_sym_L_DQUOTE] = ACTIONS(1889),
    [anon_sym_u_DQUOTE] = ACTIONS(1889),
    [anon_sym_U_DQUOTE] = ACTIONS(1889),
    [anon_sym_u8_DQUOTE] = ACTIONS(1889),
    [anon_sym_DQUOTE] = ACTIONS(1889),
    [sym_true] = ACTIONS(1887),
    [sym_false] = ACTIONS(1887),
    [anon_sym_NULL] = ACTIONS(1887),
    [anon_sym_nullptr] = ACTIONS(1887),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1887),
    [anon_sym_decltype] = ACTIONS(1887),
    [anon_sym_final] = ACTIONS(1887),
    [anon_sym_override] = ACTIONS(1887),
    [sym_virtual] = ACTIONS(1887),
    [anon_sym_explicit] = ACTIONS(1887),
    [anon_sym_typename] = ACTIONS(1887),
    [anon_sym_template] = ACTIONS(1887),
    [anon_sym_operator] = ACTIONS(1887),
    [anon_sym_try] = ACTIONS(1887),
    [anon_sym_delete] = ACTIONS(1887),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_namespace] = ACTIONS(1887),
    [anon_sym_using] = ACTIONS(1887),
    [anon_sym_static_assert] = ACTIONS(1887),
    [anon_sym_concept] = ACTIONS(1887),
    [anon_sym_co_return] = ACTIONS(1887),
    [anon_sym_co_yield] = ACTIONS(1887),
    [anon_sym_R_DQUOTE] = ACTIONS(1889),
    [anon_sym_LR_DQUOTE] = ACTIONS(1889),
    [anon_sym_uR_DQUOTE] = ACTIONS(1889),
    [anon_sym_UR_DQUOTE] = ACTIONS(1889),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1889),
    [anon_sym_co_await] = ACTIONS(1887),
    [anon_sym_new] = ACTIONS(1887),
    [anon_sym_requires] = ACTIONS(1887),
    [sym_this] = ACTIONS(1887),
    [anon_sym_discard] = ACTIONS(1887),
    [anon_sym_precise] = ACTIONS(1887),
    [anon_sym_shared] = ACTIONS(1887),
    [anon_sym_groupshared] = ACTIONS(1887),
    [anon_sym_uniform] = ACTIONS(1887),
    [anon_sym_row_major] = ACTIONS(1887),
    [anon_sym_column_major] = ACTIONS(1887),
    [anon_sym_globallycoherent] = ACTIONS(1887),
    [anon_sym_centroid] = ACTIONS(1887),
    [anon_sym_noperspective] = ACTIONS(1887),
    [anon_sym_nointerpolation] = ACTIONS(1887),
    [anon_sym_sample] = ACTIONS(1887),
    [anon_sym_linear] = ACTIONS(1887),
    [anon_sym_snorm] = ACTIONS(1887),
    [anon_sym_unorm] = ACTIONS(1887),
    [anon_sym_point] = ACTIONS(1887),
    [anon_sym_line] = ACTIONS(1887),
    [anon_sym_triangleadj] = ACTIONS(1887),
    [anon_sym_lineadj] = ACTIONS(1887),
    [anon_sym_triangle] = ACTIONS(1887),
    [anon_sym_cbuffer] = ACTIONS(1887),
  },
  [272] = {
    [sym_identifier] = ACTIONS(1917),
    [aux_sym_preproc_include_token1] = ACTIONS(1917),
    [aux_sym_preproc_def_token1] = ACTIONS(1917),
    [aux_sym_preproc_if_token1] = ACTIONS(1917),
    [aux_sym_preproc_if_token2] = ACTIONS(1917),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1917),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1917),
    [sym_preproc_directive] = ACTIONS(1917),
    [anon_sym_LPAREN2] = ACTIONS(1919),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1919),
    [anon_sym_AMP_AMP] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1917),
    [anon_sym_COLON] = ACTIONS(1917),
    [anon_sym_SEMI] = ACTIONS(1919),
    [anon_sym___extension__] = ACTIONS(1917),
    [anon_sym_typedef] = ACTIONS(1917),
    [anon_sym_in] = ACTIONS(1917),
    [anon_sym_out] = ACTIONS(1917),
    [anon_sym_inout] = ACTIONS(1917),
    [anon_sym_extern] = ACTIONS(1917),
    [anon_sym___attribute__] = ACTIONS(1917),
    [anon_sym_COLON_COLON] = ACTIONS(1919),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1919),
    [anon_sym___declspec] = ACTIONS(1917),
    [anon_sym___based] = ACTIONS(1917),
    [anon_sym___cdecl] = ACTIONS(1917),
    [anon_sym___clrcall] = ACTIONS(1917),
    [anon_sym___stdcall] = ACTIONS(1917),
    [anon_sym___fastcall] = ACTIONS(1917),
    [anon_sym___thiscall] = ACTIONS(1917),
    [anon_sym___vectorcall] = ACTIONS(1917),
    [anon_sym_LBRACE] = ACTIONS(1919),
    [anon_sym_signed] = ACTIONS(1917),
    [anon_sym_unsigned] = ACTIONS(1917),
    [anon_sym_long] = ACTIONS(1917),
    [anon_sym_short] = ACTIONS(1917),
    [anon_sym_LBRACK] = ACTIONS(1917),
    [anon_sym_static] = ACTIONS(1917),
    [anon_sym_register] = ACTIONS(1917),
    [anon_sym_inline] = ACTIONS(1917),
    [anon_sym___inline] = ACTIONS(1917),
    [anon_sym___inline__] = ACTIONS(1917),
    [anon_sym___forceinline] = ACTIONS(1917),
    [anon_sym_thread_local] = ACTIONS(1917),
    [anon_sym___thread] = ACTIONS(1917),
    [anon_sym_const] = ACTIONS(1917),
    [anon_sym_constexpr] = ACTIONS(1917),
    [anon_sym_volatile] = ACTIONS(1917),
    [anon_sym_restrict] = ACTIONS(1917),
    [anon_sym___restrict__] = ACTIONS(1917),
    [anon_sym__Atomic] = ACTIONS(1917),
    [anon_sym__Noreturn] = ACTIONS(1917),
    [anon_sym_noreturn] = ACTIONS(1917),
    [anon_sym_mutable] = ACTIONS(1917),
    [anon_sym_constinit] = ACTIONS(1917),
    [anon_sym_consteval] = ACTIONS(1917),
    [anon_sym_alignas] = ACTIONS(1917),
    [anon_sym__Alignas] = ACTIONS(1917),
    [sym_primitive_type] = ACTIONS(1917),
    [anon_sym_enum] = ACTIONS(1917),
    [anon_sym_class] = ACTIONS(1917),
    [anon_sym_struct] = ACTIONS(1917),
    [anon_sym_union] = ACTIONS(1917),
    [anon_sym_if] = ACTIONS(1917),
    [anon_sym_else] = ACTIONS(1917),
    [anon_sym_switch] = ACTIONS(1917),
    [anon_sym_case] = ACTIONS(1917),
    [anon_sym_default] = ACTIONS(1917),
    [anon_sym_while] = ACTIONS(1917),
    [anon_sym_do] = ACTIONS(1917),
    [anon_sym_for] = ACTIONS(1917),
    [anon_sym_return] = ACTIONS(1917),
    [anon_sym_break] = ACTIONS(1917),
    [anon_sym_continue] = ACTIONS(1917),
    [anon_sym_goto] = ACTIONS(1917),
    [anon_sym___try] = ACTIONS(1917),
    [anon_sym___leave] = ACTIONS(1917),
    [anon_sym_not] = ACTIONS(1917),
    [anon_sym_compl] = ACTIONS(1917),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_sizeof] = ACTIONS(1917),
    [anon_sym___alignof__] = ACTIONS(1917),
    [anon_sym___alignof] = ACTIONS(1917),
    [anon_sym__alignof] = ACTIONS(1917),
    [anon_sym_alignof] = ACTIONS(1917),
    [anon_sym__Alignof] = ACTIONS(1917),
    [anon_sym_offsetof] = ACTIONS(1917),
    [anon_sym__Generic] = ACTIONS(1917),
    [anon_sym_asm] = ACTIONS(1917),
    [anon_sym___asm__] = ACTIONS(1917),
    [sym_number_literal] = ACTIONS(1919),
    [anon_sym_L_SQUOTE] = ACTIONS(1919),
    [anon_sym_u_SQUOTE] = ACTIONS(1919),
    [anon_sym_U_SQUOTE] = ACTIONS(1919),
    [anon_sym_u8_SQUOTE] = ACTIONS(1919),
    [anon_sym_SQUOTE] = ACTIONS(1919),
    [anon_sym_L_DQUOTE] = ACTIONS(1919),
    [anon_sym_u_DQUOTE] = ACTIONS(1919),
    [anon_sym_U_DQUOTE] = ACTIONS(1919),
    [anon_sym_u8_DQUOTE] = ACTIONS(1919),
    [anon_sym_DQUOTE] = ACTIONS(1919),
    [sym_true] = ACTIONS(1917),
    [sym_false] = ACTIONS(1917),
    [anon_sym_NULL] = ACTIONS(1917),
    [anon_sym_nullptr] = ACTIONS(1917),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1917),
    [anon_sym_decltype] = ACTIONS(1917),
    [anon_sym_final] = ACTIONS(1917),
    [anon_sym_override] = ACTIONS(1917),
    [sym_virtual] = ACTIONS(1917),
    [anon_sym_explicit] = ACTIONS(1917),
    [anon_sym_typename] = ACTIONS(1917),
    [anon_sym_template] = ACTIONS(1917),
    [anon_sym_operator] = ACTIONS(1917),
    [anon_sym_try] = ACTIONS(1917),
    [anon_sym_delete] = ACTIONS(1917),
    [anon_sym_throw] = ACTIONS(1917),
    [anon_sym_namespace] = ACTIONS(1917),
    [anon_sym_using] = ACTIONS(1917),
    [anon_sym_static_assert] = ACTIONS(1917),
    [anon_sym_concept] = ACTIONS(1917),
    [anon_sym_co_return] = ACTIONS(1917),
    [anon_sym_co_yield] = ACTIONS(1917),
    [anon_sym_R_DQUOTE] = ACTIONS(1919),
    [anon_sym_LR_DQUOTE] = ACTIONS(1919),
    [anon_sym_uR_DQUOTE] = ACTIONS(1919),
    [anon_sym_UR_DQUOTE] = ACTIONS(1919),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1919),
    [anon_sym_co_await] = ACTIONS(1917),
    [anon_sym_new] = ACTIONS(1917),
    [anon_sym_requires] = ACTIONS(1917),
    [sym_this] = ACTIONS(1917),
    [anon_sym_discard] = ACTIONS(1917),
    [anon_sym_precise] = ACTIONS(1917),
    [anon_sym_shared] = ACTIONS(1917),
    [anon_sym_groupshared] = ACTIONS(1917),
    [anon_sym_uniform] = ACTIONS(1917),
    [anon_sym_row_major] = ACTIONS(1917),
    [anon_sym_column_major] = ACTIONS(1917),
    [anon_sym_globallycoherent] = ACTIONS(1917),
    [anon_sym_centroid] = ACTIONS(1917),
    [anon_sym_noperspective] = ACTIONS(1917),
    [anon_sym_nointerpolation] = ACTIONS(1917),
    [anon_sym_sample] = ACTIONS(1917),
    [anon_sym_linear] = ACTIONS(1917),
    [anon_sym_snorm] = ACTIONS(1917),
    [anon_sym_unorm] = ACTIONS(1917),
    [anon_sym_point] = ACTIONS(1917),
    [anon_sym_line] = ACTIONS(1917),
    [anon_sym_triangleadj] = ACTIONS(1917),
    [anon_sym_lineadj] = ACTIONS(1917),
    [anon_sym_triangle] = ACTIONS(1917),
    [anon_sym_cbuffer] = ACTIONS(1917),
  },
  [273] = {
    [sym_identifier] = ACTIONS(2383),
    [aux_sym_preproc_include_token1] = ACTIONS(2383),
    [aux_sym_preproc_def_token1] = ACTIONS(2383),
    [aux_sym_preproc_if_token1] = ACTIONS(2383),
    [aux_sym_preproc_if_token2] = ACTIONS(2383),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2383),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2383),
    [aux_sym_preproc_else_token1] = ACTIONS(2383),
    [aux_sym_preproc_elif_token1] = ACTIONS(2383),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2383),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2383),
    [sym_preproc_directive] = ACTIONS(2383),
    [anon_sym_LPAREN2] = ACTIONS(2386),
    [anon_sym_BANG] = ACTIONS(2386),
    [anon_sym_TILDE] = ACTIONS(2386),
    [anon_sym_DASH] = ACTIONS(2383),
    [anon_sym_PLUS] = ACTIONS(2383),
    [anon_sym_STAR] = ACTIONS(2386),
    [anon_sym_AMP_AMP] = ACTIONS(2386),
    [anon_sym_AMP] = ACTIONS(2383),
    [anon_sym_SEMI] = ACTIONS(2386),
    [anon_sym___extension__] = ACTIONS(2383),
    [anon_sym_typedef] = ACTIONS(2383),
    [anon_sym_in] = ACTIONS(2383),
    [anon_sym_out] = ACTIONS(2383),
    [anon_sym_inout] = ACTIONS(2383),
    [anon_sym_extern] = ACTIONS(2383),
    [anon_sym___attribute__] = ACTIONS(2383),
    [anon_sym_COLON_COLON] = ACTIONS(2386),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2386),
    [anon_sym___declspec] = ACTIONS(2383),
    [anon_sym___based] = ACTIONS(2383),
    [anon_sym___cdecl] = ACTIONS(2383),
    [anon_sym___clrcall] = ACTIONS(2383),
    [anon_sym___stdcall] = ACTIONS(2383),
    [anon_sym___fastcall] = ACTIONS(2383),
    [anon_sym___thiscall] = ACTIONS(2383),
    [anon_sym___vectorcall] = ACTIONS(2383),
    [anon_sym_LBRACE] = ACTIONS(2386),
    [anon_sym_signed] = ACTIONS(2383),
    [anon_sym_unsigned] = ACTIONS(2383),
    [anon_sym_long] = ACTIONS(2383),
    [anon_sym_short] = ACTIONS(2383),
    [anon_sym_LBRACK] = ACTIONS(2383),
    [anon_sym_static] = ACTIONS(2383),
    [anon_sym_register] = ACTIONS(2383),
    [anon_sym_inline] = ACTIONS(2383),
    [anon_sym___inline] = ACTIONS(2383),
    [anon_sym___inline__] = ACTIONS(2383),
    [anon_sym___forceinline] = ACTIONS(2383),
    [anon_sym_thread_local] = ACTIONS(2383),
    [anon_sym___thread] = ACTIONS(2383),
    [anon_sym_const] = ACTIONS(2383),
    [anon_sym_constexpr] = ACTIONS(2383),
    [anon_sym_volatile] = ACTIONS(2383),
    [anon_sym_restrict] = ACTIONS(2383),
    [anon_sym___restrict__] = ACTIONS(2383),
    [anon_sym__Atomic] = ACTIONS(2383),
    [anon_sym__Noreturn] = ACTIONS(2383),
    [anon_sym_noreturn] = ACTIONS(2383),
    [anon_sym_mutable] = ACTIONS(2383),
    [anon_sym_constinit] = ACTIONS(2383),
    [anon_sym_consteval] = ACTIONS(2383),
    [anon_sym_alignas] = ACTIONS(2383),
    [anon_sym__Alignas] = ACTIONS(2383),
    [sym_primitive_type] = ACTIONS(2383),
    [anon_sym_enum] = ACTIONS(2383),
    [anon_sym_class] = ACTIONS(2383),
    [anon_sym_struct] = ACTIONS(2383),
    [anon_sym_union] = ACTIONS(2383),
    [anon_sym_if] = ACTIONS(2383),
    [anon_sym_switch] = ACTIONS(2383),
    [anon_sym_case] = ACTIONS(2383),
    [anon_sym_default] = ACTIONS(2383),
    [anon_sym_while] = ACTIONS(2383),
    [anon_sym_do] = ACTIONS(2383),
    [anon_sym_for] = ACTIONS(2383),
    [anon_sym_return] = ACTIONS(2383),
    [anon_sym_break] = ACTIONS(2383),
    [anon_sym_continue] = ACTIONS(2383),
    [anon_sym_goto] = ACTIONS(2383),
    [anon_sym___try] = ACTIONS(2383),
    [anon_sym___leave] = ACTIONS(2383),
    [anon_sym_not] = ACTIONS(2383),
    [anon_sym_compl] = ACTIONS(2383),
    [anon_sym_DASH_DASH] = ACTIONS(2386),
    [anon_sym_PLUS_PLUS] = ACTIONS(2386),
    [anon_sym_sizeof] = ACTIONS(2383),
    [anon_sym___alignof__] = ACTIONS(2383),
    [anon_sym___alignof] = ACTIONS(2383),
    [anon_sym__alignof] = ACTIONS(2383),
    [anon_sym_alignof] = ACTIONS(2383),
    [anon_sym__Alignof] = ACTIONS(2383),
    [anon_sym_offsetof] = ACTIONS(2383),
    [anon_sym__Generic] = ACTIONS(2383),
    [anon_sym_asm] = ACTIONS(2383),
    [anon_sym___asm__] = ACTIONS(2383),
    [sym_number_literal] = ACTIONS(2386),
    [anon_sym_L_SQUOTE] = ACTIONS(2386),
    [anon_sym_u_SQUOTE] = ACTIONS(2386),
    [anon_sym_U_SQUOTE] = ACTIONS(2386),
    [anon_sym_u8_SQUOTE] = ACTIONS(2386),
    [anon_sym_SQUOTE] = ACTIONS(2386),
    [anon_sym_L_DQUOTE] = ACTIONS(2386),
    [anon_sym_u_DQUOTE] = ACTIONS(2386),
    [anon_sym_U_DQUOTE] = ACTIONS(2386),
    [anon_sym_u8_DQUOTE] = ACTIONS(2386),
    [anon_sym_DQUOTE] = ACTIONS(2386),
    [sym_true] = ACTIONS(2383),
    [sym_false] = ACTIONS(2383),
    [anon_sym_NULL] = ACTIONS(2383),
    [anon_sym_nullptr] = ACTIONS(2383),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2383),
    [anon_sym_decltype] = ACTIONS(2383),
    [sym_virtual] = ACTIONS(2383),
    [anon_sym_explicit] = ACTIONS(2383),
    [anon_sym_typename] = ACTIONS(2383),
    [anon_sym_template] = ACTIONS(2383),
    [anon_sym_operator] = ACTIONS(2383),
    [anon_sym_try] = ACTIONS(2383),
    [anon_sym_delete] = ACTIONS(2383),
    [anon_sym_throw] = ACTIONS(2383),
    [anon_sym_namespace] = ACTIONS(2383),
    [anon_sym_using] = ACTIONS(2383),
    [anon_sym_static_assert] = ACTIONS(2383),
    [anon_sym_concept] = ACTIONS(2383),
    [anon_sym_co_return] = ACTIONS(2383),
    [anon_sym_co_yield] = ACTIONS(2383),
    [anon_sym_R_DQUOTE] = ACTIONS(2386),
    [anon_sym_LR_DQUOTE] = ACTIONS(2386),
    [anon_sym_uR_DQUOTE] = ACTIONS(2386),
    [anon_sym_UR_DQUOTE] = ACTIONS(2386),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2386),
    [anon_sym_co_await] = ACTIONS(2383),
    [anon_sym_new] = ACTIONS(2383),
    [anon_sym_requires] = ACTIONS(2383),
    [sym_this] = ACTIONS(2383),
    [anon_sym_discard] = ACTIONS(2383),
    [anon_sym_precise] = ACTIONS(2383),
    [anon_sym_shared] = ACTIONS(2383),
    [anon_sym_groupshared] = ACTIONS(2383),
    [anon_sym_uniform] = ACTIONS(2383),
    [anon_sym_row_major] = ACTIONS(2383),
    [anon_sym_column_major] = ACTIONS(2383),
    [anon_sym_globallycoherent] = ACTIONS(2383),
    [anon_sym_centroid] = ACTIONS(2383),
    [anon_sym_noperspective] = ACTIONS(2383),
    [anon_sym_nointerpolation] = ACTIONS(2383),
    [anon_sym_sample] = ACTIONS(2383),
    [anon_sym_linear] = ACTIONS(2383),
    [anon_sym_snorm] = ACTIONS(2383),
    [anon_sym_unorm] = ACTIONS(2383),
    [anon_sym_point] = ACTIONS(2383),
    [anon_sym_line] = ACTIONS(2383),
    [anon_sym_triangleadj] = ACTIONS(2383),
    [anon_sym_lineadj] = ACTIONS(2383),
    [anon_sym_triangle] = ACTIONS(2383),
    [anon_sym_cbuffer] = ACTIONS(2383),
  },
  [274] = {
    [sym_identifier] = ACTIONS(2389),
    [aux_sym_preproc_include_token1] = ACTIONS(2389),
    [aux_sym_preproc_def_token1] = ACTIONS(2389),
    [aux_sym_preproc_if_token1] = ACTIONS(2389),
    [aux_sym_preproc_if_token2] = ACTIONS(2389),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2389),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2389),
    [aux_sym_preproc_else_token1] = ACTIONS(2389),
    [aux_sym_preproc_elif_token1] = ACTIONS(2389),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2389),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2389),
    [sym_preproc_directive] = ACTIONS(2389),
    [anon_sym_LPAREN2] = ACTIONS(2391),
    [anon_sym_BANG] = ACTIONS(2391),
    [anon_sym_TILDE] = ACTIONS(2391),
    [anon_sym_DASH] = ACTIONS(2389),
    [anon_sym_PLUS] = ACTIONS(2389),
    [anon_sym_STAR] = ACTIONS(2391),
    [anon_sym_AMP_AMP] = ACTIONS(2391),
    [anon_sym_AMP] = ACTIONS(2389),
    [anon_sym_SEMI] = ACTIONS(2391),
    [anon_sym___extension__] = ACTIONS(2389),
    [anon_sym_typedef] = ACTIONS(2389),
    [anon_sym_in] = ACTIONS(2389),
    [anon_sym_out] = ACTIONS(2389),
    [anon_sym_inout] = ACTIONS(2389),
    [anon_sym_extern] = ACTIONS(2389),
    [anon_sym___attribute__] = ACTIONS(2389),
    [anon_sym_COLON_COLON] = ACTIONS(2391),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2391),
    [anon_sym___declspec] = ACTIONS(2389),
    [anon_sym___based] = ACTIONS(2389),
    [anon_sym___cdecl] = ACTIONS(2389),
    [anon_sym___clrcall] = ACTIONS(2389),
    [anon_sym___stdcall] = ACTIONS(2389),
    [anon_sym___fastcall] = ACTIONS(2389),
    [anon_sym___thiscall] = ACTIONS(2389),
    [anon_sym___vectorcall] = ACTIONS(2389),
    [anon_sym_LBRACE] = ACTIONS(2391),
    [anon_sym_signed] = ACTIONS(2389),
    [anon_sym_unsigned] = ACTIONS(2389),
    [anon_sym_long] = ACTIONS(2389),
    [anon_sym_short] = ACTIONS(2389),
    [anon_sym_LBRACK] = ACTIONS(2389),
    [anon_sym_static] = ACTIONS(2389),
    [anon_sym_register] = ACTIONS(2389),
    [anon_sym_inline] = ACTIONS(2389),
    [anon_sym___inline] = ACTIONS(2389),
    [anon_sym___inline__] = ACTIONS(2389),
    [anon_sym___forceinline] = ACTIONS(2389),
    [anon_sym_thread_local] = ACTIONS(2389),
    [anon_sym___thread] = ACTIONS(2389),
    [anon_sym_const] = ACTIONS(2389),
    [anon_sym_constexpr] = ACTIONS(2389),
    [anon_sym_volatile] = ACTIONS(2389),
    [anon_sym_restrict] = ACTIONS(2389),
    [anon_sym___restrict__] = ACTIONS(2389),
    [anon_sym__Atomic] = ACTIONS(2389),
    [anon_sym__Noreturn] = ACTIONS(2389),
    [anon_sym_noreturn] = ACTIONS(2389),
    [anon_sym_mutable] = ACTIONS(2389),
    [anon_sym_constinit] = ACTIONS(2389),
    [anon_sym_consteval] = ACTIONS(2389),
    [anon_sym_alignas] = ACTIONS(2389),
    [anon_sym__Alignas] = ACTIONS(2389),
    [sym_primitive_type] = ACTIONS(2389),
    [anon_sym_enum] = ACTIONS(2389),
    [anon_sym_class] = ACTIONS(2389),
    [anon_sym_struct] = ACTIONS(2389),
    [anon_sym_union] = ACTIONS(2389),
    [anon_sym_if] = ACTIONS(2389),
    [anon_sym_switch] = ACTIONS(2389),
    [anon_sym_case] = ACTIONS(2389),
    [anon_sym_default] = ACTIONS(2389),
    [anon_sym_while] = ACTIONS(2389),
    [anon_sym_do] = ACTIONS(2389),
    [anon_sym_for] = ACTIONS(2389),
    [anon_sym_return] = ACTIONS(2389),
    [anon_sym_break] = ACTIONS(2389),
    [anon_sym_continue] = ACTIONS(2389),
    [anon_sym_goto] = ACTIONS(2389),
    [anon_sym___try] = ACTIONS(2389),
    [anon_sym___leave] = ACTIONS(2389),
    [anon_sym_not] = ACTIONS(2389),
    [anon_sym_compl] = ACTIONS(2389),
    [anon_sym_DASH_DASH] = ACTIONS(2391),
    [anon_sym_PLUS_PLUS] = ACTIONS(2391),
    [anon_sym_sizeof] = ACTIONS(2389),
    [anon_sym___alignof__] = ACTIONS(2389),
    [anon_sym___alignof] = ACTIONS(2389),
    [anon_sym__alignof] = ACTIONS(2389),
    [anon_sym_alignof] = ACTIONS(2389),
    [anon_sym__Alignof] = ACTIONS(2389),
    [anon_sym_offsetof] = ACTIONS(2389),
    [anon_sym__Generic] = ACTIONS(2389),
    [anon_sym_asm] = ACTIONS(2389),
    [anon_sym___asm__] = ACTIONS(2389),
    [sym_number_literal] = ACTIONS(2391),
    [anon_sym_L_SQUOTE] = ACTIONS(2391),
    [anon_sym_u_SQUOTE] = ACTIONS(2391),
    [anon_sym_U_SQUOTE] = ACTIONS(2391),
    [anon_sym_u8_SQUOTE] = ACTIONS(2391),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_L_DQUOTE] = ACTIONS(2391),
    [anon_sym_u_DQUOTE] = ACTIONS(2391),
    [anon_sym_U_DQUOTE] = ACTIONS(2391),
    [anon_sym_u8_DQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2391),
    [sym_true] = ACTIONS(2389),
    [sym_false] = ACTIONS(2389),
    [anon_sym_NULL] = ACTIONS(2389),
    [anon_sym_nullptr] = ACTIONS(2389),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2389),
    [anon_sym_decltype] = ACTIONS(2389),
    [sym_virtual] = ACTIONS(2389),
    [anon_sym_explicit] = ACTIONS(2389),
    [anon_sym_typename] = ACTIONS(2389),
    [anon_sym_template] = ACTIONS(2389),
    [anon_sym_operator] = ACTIONS(2389),
    [anon_sym_try] = ACTIONS(2389),
    [anon_sym_delete] = ACTIONS(2389),
    [anon_sym_throw] = ACTIONS(2389),
    [anon_sym_namespace] = ACTIONS(2389),
    [anon_sym_using] = ACTIONS(2389),
    [anon_sym_static_assert] = ACTIONS(2389),
    [anon_sym_concept] = ACTIONS(2389),
    [anon_sym_co_return] = ACTIONS(2389),
    [anon_sym_co_yield] = ACTIONS(2389),
    [anon_sym_R_DQUOTE] = ACTIONS(2391),
    [anon_sym_LR_DQUOTE] = ACTIONS(2391),
    [anon_sym_uR_DQUOTE] = ACTIONS(2391),
    [anon_sym_UR_DQUOTE] = ACTIONS(2391),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2391),
    [anon_sym_co_await] = ACTIONS(2389),
    [anon_sym_new] = ACTIONS(2389),
    [anon_sym_requires] = ACTIONS(2389),
    [sym_this] = ACTIONS(2389),
    [anon_sym_discard] = ACTIONS(2389),
    [anon_sym_precise] = ACTIONS(2389),
    [anon_sym_shared] = ACTIONS(2389),
    [anon_sym_groupshared] = ACTIONS(2389),
    [anon_sym_uniform] = ACTIONS(2389),
    [anon_sym_row_major] = ACTIONS(2389),
    [anon_sym_column_major] = ACTIONS(2389),
    [anon_sym_globallycoherent] = ACTIONS(2389),
    [anon_sym_centroid] = ACTIONS(2389),
    [anon_sym_noperspective] = ACTIONS(2389),
    [anon_sym_nointerpolation] = ACTIONS(2389),
    [anon_sym_sample] = ACTIONS(2389),
    [anon_sym_linear] = ACTIONS(2389),
    [anon_sym_snorm] = ACTIONS(2389),
    [anon_sym_unorm] = ACTIONS(2389),
    [anon_sym_point] = ACTIONS(2389),
    [anon_sym_line] = ACTIONS(2389),
    [anon_sym_triangleadj] = ACTIONS(2389),
    [anon_sym_lineadj] = ACTIONS(2389),
    [anon_sym_triangle] = ACTIONS(2389),
    [anon_sym_cbuffer] = ACTIONS(2389),
  },
  [275] = {
    [sym_identifier] = ACTIONS(2393),
    [aux_sym_preproc_include_token1] = ACTIONS(2393),
    [aux_sym_preproc_def_token1] = ACTIONS(2393),
    [aux_sym_preproc_if_token1] = ACTIONS(2393),
    [aux_sym_preproc_if_token2] = ACTIONS(2393),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2393),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2393),
    [aux_sym_preproc_else_token1] = ACTIONS(2393),
    [aux_sym_preproc_elif_token1] = ACTIONS(2393),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2393),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2393),
    [sym_preproc_directive] = ACTIONS(2393),
    [anon_sym_LPAREN2] = ACTIONS(2395),
    [anon_sym_BANG] = ACTIONS(2395),
    [anon_sym_TILDE] = ACTIONS(2395),
    [anon_sym_DASH] = ACTIONS(2393),
    [anon_sym_PLUS] = ACTIONS(2393),
    [anon_sym_STAR] = ACTIONS(2395),
    [anon_sym_AMP_AMP] = ACTIONS(2395),
    [anon_sym_AMP] = ACTIONS(2393),
    [anon_sym_SEMI] = ACTIONS(2395),
    [anon_sym___extension__] = ACTIONS(2393),
    [anon_sym_typedef] = ACTIONS(2393),
    [anon_sym_in] = ACTIONS(2393),
    [anon_sym_out] = ACTIONS(2393),
    [anon_sym_inout] = ACTIONS(2393),
    [anon_sym_extern] = ACTIONS(2393),
    [anon_sym___attribute__] = ACTIONS(2393),
    [anon_sym_COLON_COLON] = ACTIONS(2395),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2395),
    [anon_sym___declspec] = ACTIONS(2393),
    [anon_sym___based] = ACTIONS(2393),
    [anon_sym___cdecl] = ACTIONS(2393),
    [anon_sym___clrcall] = ACTIONS(2393),
    [anon_sym___stdcall] = ACTIONS(2393),
    [anon_sym___fastcall] = ACTIONS(2393),
    [anon_sym___thiscall] = ACTIONS(2393),
    [anon_sym___vectorcall] = ACTIONS(2393),
    [anon_sym_LBRACE] = ACTIONS(2395),
    [anon_sym_signed] = ACTIONS(2393),
    [anon_sym_unsigned] = ACTIONS(2393),
    [anon_sym_long] = ACTIONS(2393),
    [anon_sym_short] = ACTIONS(2393),
    [anon_sym_LBRACK] = ACTIONS(2393),
    [anon_sym_static] = ACTIONS(2393),
    [anon_sym_register] = ACTIONS(2393),
    [anon_sym_inline] = ACTIONS(2393),
    [anon_sym___inline] = ACTIONS(2393),
    [anon_sym___inline__] = ACTIONS(2393),
    [anon_sym___forceinline] = ACTIONS(2393),
    [anon_sym_thread_local] = ACTIONS(2393),
    [anon_sym___thread] = ACTIONS(2393),
    [anon_sym_const] = ACTIONS(2393),
    [anon_sym_constexpr] = ACTIONS(2393),
    [anon_sym_volatile] = ACTIONS(2393),
    [anon_sym_restrict] = ACTIONS(2393),
    [anon_sym___restrict__] = ACTIONS(2393),
    [anon_sym__Atomic] = ACTIONS(2393),
    [anon_sym__Noreturn] = ACTIONS(2393),
    [anon_sym_noreturn] = ACTIONS(2393),
    [anon_sym_mutable] = ACTIONS(2393),
    [anon_sym_constinit] = ACTIONS(2393),
    [anon_sym_consteval] = ACTIONS(2393),
    [anon_sym_alignas] = ACTIONS(2393),
    [anon_sym__Alignas] = ACTIONS(2393),
    [sym_primitive_type] = ACTIONS(2393),
    [anon_sym_enum] = ACTIONS(2393),
    [anon_sym_class] = ACTIONS(2393),
    [anon_sym_struct] = ACTIONS(2393),
    [anon_sym_union] = ACTIONS(2393),
    [anon_sym_if] = ACTIONS(2393),
    [anon_sym_switch] = ACTIONS(2393),
    [anon_sym_case] = ACTIONS(2393),
    [anon_sym_default] = ACTIONS(2393),
    [anon_sym_while] = ACTIONS(2393),
    [anon_sym_do] = ACTIONS(2393),
    [anon_sym_for] = ACTIONS(2393),
    [anon_sym_return] = ACTIONS(2393),
    [anon_sym_break] = ACTIONS(2393),
    [anon_sym_continue] = ACTIONS(2393),
    [anon_sym_goto] = ACTIONS(2393),
    [anon_sym___try] = ACTIONS(2393),
    [anon_sym___leave] = ACTIONS(2393),
    [anon_sym_not] = ACTIONS(2393),
    [anon_sym_compl] = ACTIONS(2393),
    [anon_sym_DASH_DASH] = ACTIONS(2395),
    [anon_sym_PLUS_PLUS] = ACTIONS(2395),
    [anon_sym_sizeof] = ACTIONS(2393),
    [anon_sym___alignof__] = ACTIONS(2393),
    [anon_sym___alignof] = ACTIONS(2393),
    [anon_sym__alignof] = ACTIONS(2393),
    [anon_sym_alignof] = ACTIONS(2393),
    [anon_sym__Alignof] = ACTIONS(2393),
    [anon_sym_offsetof] = ACTIONS(2393),
    [anon_sym__Generic] = ACTIONS(2393),
    [anon_sym_asm] = ACTIONS(2393),
    [anon_sym___asm__] = ACTIONS(2393),
    [sym_number_literal] = ACTIONS(2395),
    [anon_sym_L_SQUOTE] = ACTIONS(2395),
    [anon_sym_u_SQUOTE] = ACTIONS(2395),
    [anon_sym_U_SQUOTE] = ACTIONS(2395),
    [anon_sym_u8_SQUOTE] = ACTIONS(2395),
    [anon_sym_SQUOTE] = ACTIONS(2395),
    [anon_sym_L_DQUOTE] = ACTIONS(2395),
    [anon_sym_u_DQUOTE] = ACTIONS(2395),
    [anon_sym_U_DQUOTE] = ACTIONS(2395),
    [anon_sym_u8_DQUOTE] = ACTIONS(2395),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_true] = ACTIONS(2393),
    [sym_false] = ACTIONS(2393),
    [anon_sym_NULL] = ACTIONS(2393),
    [anon_sym_nullptr] = ACTIONS(2393),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2393),
    [anon_sym_decltype] = ACTIONS(2393),
    [sym_virtual] = ACTIONS(2393),
    [anon_sym_explicit] = ACTIONS(2393),
    [anon_sym_typename] = ACTIONS(2393),
    [anon_sym_template] = ACTIONS(2393),
    [anon_sym_operator] = ACTIONS(2393),
    [anon_sym_try] = ACTIONS(2393),
    [anon_sym_delete] = ACTIONS(2393),
    [anon_sym_throw] = ACTIONS(2393),
    [anon_sym_namespace] = ACTIONS(2393),
    [anon_sym_using] = ACTIONS(2393),
    [anon_sym_static_assert] = ACTIONS(2393),
    [anon_sym_concept] = ACTIONS(2393),
    [anon_sym_co_return] = ACTIONS(2393),
    [anon_sym_co_yield] = ACTIONS(2393),
    [anon_sym_R_DQUOTE] = ACTIONS(2395),
    [anon_sym_LR_DQUOTE] = ACTIONS(2395),
    [anon_sym_uR_DQUOTE] = ACTIONS(2395),
    [anon_sym_UR_DQUOTE] = ACTIONS(2395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2395),
    [anon_sym_co_await] = ACTIONS(2393),
    [anon_sym_new] = ACTIONS(2393),
    [anon_sym_requires] = ACTIONS(2393),
    [sym_this] = ACTIONS(2393),
    [anon_sym_discard] = ACTIONS(2393),
    [anon_sym_precise] = ACTIONS(2393),
    [anon_sym_shared] = ACTIONS(2393),
    [anon_sym_groupshared] = ACTIONS(2393),
    [anon_sym_uniform] = ACTIONS(2393),
    [anon_sym_row_major] = ACTIONS(2393),
    [anon_sym_column_major] = ACTIONS(2393),
    [anon_sym_globallycoherent] = ACTIONS(2393),
    [anon_sym_centroid] = ACTIONS(2393),
    [anon_sym_noperspective] = ACTIONS(2393),
    [anon_sym_nointerpolation] = ACTIONS(2393),
    [anon_sym_sample] = ACTIONS(2393),
    [anon_sym_linear] = ACTIONS(2393),
    [anon_sym_snorm] = ACTIONS(2393),
    [anon_sym_unorm] = ACTIONS(2393),
    [anon_sym_point] = ACTIONS(2393),
    [anon_sym_line] = ACTIONS(2393),
    [anon_sym_triangleadj] = ACTIONS(2393),
    [anon_sym_lineadj] = ACTIONS(2393),
    [anon_sym_triangle] = ACTIONS(2393),
    [anon_sym_cbuffer] = ACTIONS(2393),
  },
  [276] = {
    [sym_catch_clause] = STATE(276),
    [aux_sym_constructor_try_statement_repeat1] = STATE(276),
    [ts_builtin_sym_end] = ACTIONS(1975),
    [sym_identifier] = ACTIONS(1973),
    [aux_sym_preproc_include_token1] = ACTIONS(1973),
    [aux_sym_preproc_def_token1] = ACTIONS(1973),
    [aux_sym_preproc_if_token1] = ACTIONS(1973),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1973),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1973),
    [sym_preproc_directive] = ACTIONS(1973),
    [anon_sym_LPAREN2] = ACTIONS(1975),
    [anon_sym_BANG] = ACTIONS(1975),
    [anon_sym_TILDE] = ACTIONS(1975),
    [anon_sym_DASH] = ACTIONS(1973),
    [anon_sym_PLUS] = ACTIONS(1973),
    [anon_sym_STAR] = ACTIONS(1975),
    [anon_sym_AMP_AMP] = ACTIONS(1975),
    [anon_sym_AMP] = ACTIONS(1973),
    [anon_sym_SEMI] = ACTIONS(1975),
    [anon_sym___extension__] = ACTIONS(1973),
    [anon_sym_typedef] = ACTIONS(1973),
    [anon_sym_in] = ACTIONS(1973),
    [anon_sym_out] = ACTIONS(1973),
    [anon_sym_inout] = ACTIONS(1973),
    [anon_sym_extern] = ACTIONS(1973),
    [anon_sym___attribute__] = ACTIONS(1973),
    [anon_sym_COLON_COLON] = ACTIONS(1975),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1975),
    [anon_sym___declspec] = ACTIONS(1973),
    [anon_sym___based] = ACTIONS(1973),
    [anon_sym___cdecl] = ACTIONS(1973),
    [anon_sym___clrcall] = ACTIONS(1973),
    [anon_sym___stdcall] = ACTIONS(1973),
    [anon_sym___fastcall] = ACTIONS(1973),
    [anon_sym___thiscall] = ACTIONS(1973),
    [anon_sym___vectorcall] = ACTIONS(1973),
    [anon_sym_LBRACE] = ACTIONS(1975),
    [anon_sym_signed] = ACTIONS(1973),
    [anon_sym_unsigned] = ACTIONS(1973),
    [anon_sym_long] = ACTIONS(1973),
    [anon_sym_short] = ACTIONS(1973),
    [anon_sym_LBRACK] = ACTIONS(1973),
    [anon_sym_static] = ACTIONS(1973),
    [anon_sym_register] = ACTIONS(1973),
    [anon_sym_inline] = ACTIONS(1973),
    [anon_sym___inline] = ACTIONS(1973),
    [anon_sym___inline__] = ACTIONS(1973),
    [anon_sym___forceinline] = ACTIONS(1973),
    [anon_sym_thread_local] = ACTIONS(1973),
    [anon_sym___thread] = ACTIONS(1973),
    [anon_sym_const] = ACTIONS(1973),
    [anon_sym_constexpr] = ACTIONS(1973),
    [anon_sym_volatile] = ACTIONS(1973),
    [anon_sym_restrict] = ACTIONS(1973),
    [anon_sym___restrict__] = ACTIONS(1973),
    [anon_sym__Atomic] = ACTIONS(1973),
    [anon_sym__Noreturn] = ACTIONS(1973),
    [anon_sym_noreturn] = ACTIONS(1973),
    [anon_sym_mutable] = ACTIONS(1973),
    [anon_sym_constinit] = ACTIONS(1973),
    [anon_sym_consteval] = ACTIONS(1973),
    [anon_sym_alignas] = ACTIONS(1973),
    [anon_sym__Alignas] = ACTIONS(1973),
    [sym_primitive_type] = ACTIONS(1973),
    [anon_sym_enum] = ACTIONS(1973),
    [anon_sym_class] = ACTIONS(1973),
    [anon_sym_struct] = ACTIONS(1973),
    [anon_sym_union] = ACTIONS(1973),
    [anon_sym_if] = ACTIONS(1973),
    [anon_sym_else] = ACTIONS(1973),
    [anon_sym_switch] = ACTIONS(1973),
    [anon_sym_case] = ACTIONS(1973),
    [anon_sym_default] = ACTIONS(1973),
    [anon_sym_while] = ACTIONS(1973),
    [anon_sym_do] = ACTIONS(1973),
    [anon_sym_for] = ACTIONS(1973),
    [anon_sym_return] = ACTIONS(1973),
    [anon_sym_break] = ACTIONS(1973),
    [anon_sym_continue] = ACTIONS(1973),
    [anon_sym_goto] = ACTIONS(1973),
    [anon_sym___try] = ACTIONS(1973),
    [anon_sym___leave] = ACTIONS(1973),
    [anon_sym_not] = ACTIONS(1973),
    [anon_sym_compl] = ACTIONS(1973),
    [anon_sym_DASH_DASH] = ACTIONS(1975),
    [anon_sym_PLUS_PLUS] = ACTIONS(1975),
    [anon_sym_sizeof] = ACTIONS(1973),
    [anon_sym___alignof__] = ACTIONS(1973),
    [anon_sym___alignof] = ACTIONS(1973),
    [anon_sym__alignof] = ACTIONS(1973),
    [anon_sym_alignof] = ACTIONS(1973),
    [anon_sym__Alignof] = ACTIONS(1973),
    [anon_sym_offsetof] = ACTIONS(1973),
    [anon_sym__Generic] = ACTIONS(1973),
    [anon_sym_asm] = ACTIONS(1973),
    [anon_sym___asm__] = ACTIONS(1973),
    [sym_number_literal] = ACTIONS(1975),
    [anon_sym_L_SQUOTE] = ACTIONS(1975),
    [anon_sym_u_SQUOTE] = ACTIONS(1975),
    [anon_sym_U_SQUOTE] = ACTIONS(1975),
    [anon_sym_u8_SQUOTE] = ACTIONS(1975),
    [anon_sym_SQUOTE] = ACTIONS(1975),
    [anon_sym_L_DQUOTE] = ACTIONS(1975),
    [anon_sym_u_DQUOTE] = ACTIONS(1975),
    [anon_sym_U_DQUOTE] = ACTIONS(1975),
    [anon_sym_u8_DQUOTE] = ACTIONS(1975),
    [anon_sym_DQUOTE] = ACTIONS(1975),
    [sym_true] = ACTIONS(1973),
    [sym_false] = ACTIONS(1973),
    [anon_sym_NULL] = ACTIONS(1973),
    [anon_sym_nullptr] = ACTIONS(1973),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1973),
    [anon_sym_decltype] = ACTIONS(1973),
    [sym_virtual] = ACTIONS(1973),
    [anon_sym_explicit] = ACTIONS(1973),
    [anon_sym_typename] = ACTIONS(1973),
    [anon_sym_template] = ACTIONS(1973),
    [anon_sym_operator] = ACTIONS(1973),
    [anon_sym_try] = ACTIONS(1973),
    [anon_sym_delete] = ACTIONS(1973),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_namespace] = ACTIONS(1973),
    [anon_sym_using] = ACTIONS(1973),
    [anon_sym_static_assert] = ACTIONS(1973),
    [anon_sym_concept] = ACTIONS(1973),
    [anon_sym_co_return] = ACTIONS(1973),
    [anon_sym_co_yield] = ACTIONS(1973),
    [anon_sym_catch] = ACTIONS(2397),
    [anon_sym_R_DQUOTE] = ACTIONS(1975),
    [anon_sym_LR_DQUOTE] = ACTIONS(1975),
    [anon_sym_uR_DQUOTE] = ACTIONS(1975),
    [anon_sym_UR_DQUOTE] = ACTIONS(1975),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1975),
    [anon_sym_co_await] = ACTIONS(1973),
    [anon_sym_new] = ACTIONS(1973),
    [anon_sym_requires] = ACTIONS(1973),
    [sym_this] = ACTIONS(1973),
    [anon_sym_discard] = ACTIONS(1973),
    [anon_sym_precise] = ACTIONS(1973),
    [anon_sym_shared] = ACTIONS(1973),
    [anon_sym_groupshared] = ACTIONS(1973),
    [anon_sym_uniform] = ACTIONS(1973),
    [anon_sym_row_major] = ACTIONS(1973),
    [anon_sym_column_major] = ACTIONS(1973),
    [anon_sym_globallycoherent] = ACTIONS(1973),
    [anon_sym_centroid] = ACTIONS(1973),
    [anon_sym_noperspective] = ACTIONS(1973),
    [anon_sym_nointerpolation] = ACTIONS(1973),
    [anon_sym_sample] = ACTIONS(1973),
    [anon_sym_linear] = ACTIONS(1973),
    [anon_sym_snorm] = ACTIONS(1973),
    [anon_sym_unorm] = ACTIONS(1973),
    [anon_sym_point] = ACTIONS(1973),
    [anon_sym_line] = ACTIONS(1973),
    [anon_sym_triangleadj] = ACTIONS(1973),
    [anon_sym_lineadj] = ACTIONS(1973),
    [anon_sym_triangle] = ACTIONS(1973),
    [anon_sym_cbuffer] = ACTIONS(1973),
  },
  [277] = {
    [sym_identifier] = ACTIONS(1953),
    [aux_sym_preproc_include_token1] = ACTIONS(1953),
    [aux_sym_preproc_def_token1] = ACTIONS(1953),
    [aux_sym_preproc_if_token1] = ACTIONS(1953),
    [aux_sym_preproc_if_token2] = ACTIONS(1953),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1953),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1953),
    [sym_preproc_directive] = ACTIONS(1953),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_BANG] = ACTIONS(1955),
    [anon_sym_TILDE] = ACTIONS(1955),
    [anon_sym_DASH] = ACTIONS(1953),
    [anon_sym_PLUS] = ACTIONS(1953),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym_COLON] = ACTIONS(1953),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym_typedef] = ACTIONS(1953),
    [anon_sym_in] = ACTIONS(1953),
    [anon_sym_out] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1953),
    [anon_sym_extern] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1955),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1955),
    [anon_sym___declspec] = ACTIONS(1953),
    [anon_sym___based] = ACTIONS(1953),
    [anon_sym___cdecl] = ACTIONS(1953),
    [anon_sym___clrcall] = ACTIONS(1953),
    [anon_sym___stdcall] = ACTIONS(1953),
    [anon_sym___fastcall] = ACTIONS(1953),
    [anon_sym___thiscall] = ACTIONS(1953),
    [anon_sym___vectorcall] = ACTIONS(1953),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_signed] = ACTIONS(1953),
    [anon_sym_unsigned] = ACTIONS(1953),
    [anon_sym_long] = ACTIONS(1953),
    [anon_sym_short] = ACTIONS(1953),
    [anon_sym_LBRACK] = ACTIONS(1953),
    [anon_sym_static] = ACTIONS(1953),
    [anon_sym_register] = ACTIONS(1953),
    [anon_sym_inline] = ACTIONS(1953),
    [anon_sym___inline] = ACTIONS(1953),
    [anon_sym___inline__] = ACTIONS(1953),
    [anon_sym___forceinline] = ACTIONS(1953),
    [anon_sym_thread_local] = ACTIONS(1953),
    [anon_sym___thread] = ACTIONS(1953),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [sym_primitive_type] = ACTIONS(1953),
    [anon_sym_enum] = ACTIONS(1953),
    [anon_sym_class] = ACTIONS(1953),
    [anon_sym_struct] = ACTIONS(1953),
    [anon_sym_union] = ACTIONS(1953),
    [anon_sym_if] = ACTIONS(1953),
    [anon_sym_else] = ACTIONS(1953),
    [anon_sym_switch] = ACTIONS(1953),
    [anon_sym_case] = ACTIONS(1953),
    [anon_sym_default] = ACTIONS(1953),
    [anon_sym_while] = ACTIONS(1953),
    [anon_sym_do] = ACTIONS(1953),
    [anon_sym_for] = ACTIONS(1953),
    [anon_sym_return] = ACTIONS(1953),
    [anon_sym_break] = ACTIONS(1953),
    [anon_sym_continue] = ACTIONS(1953),
    [anon_sym_goto] = ACTIONS(1953),
    [anon_sym___try] = ACTIONS(1953),
    [anon_sym___leave] = ACTIONS(1953),
    [anon_sym_not] = ACTIONS(1953),
    [anon_sym_compl] = ACTIONS(1953),
    [anon_sym_DASH_DASH] = ACTIONS(1955),
    [anon_sym_PLUS_PLUS] = ACTIONS(1955),
    [anon_sym_sizeof] = ACTIONS(1953),
    [anon_sym___alignof__] = ACTIONS(1953),
    [anon_sym___alignof] = ACTIONS(1953),
    [anon_sym__alignof] = ACTIONS(1953),
    [anon_sym_alignof] = ACTIONS(1953),
    [anon_sym__Alignof] = ACTIONS(1953),
    [anon_sym_offsetof] = ACTIONS(1953),
    [anon_sym__Generic] = ACTIONS(1953),
    [anon_sym_asm] = ACTIONS(1953),
    [anon_sym___asm__] = ACTIONS(1953),
    [sym_number_literal] = ACTIONS(1955),
    [anon_sym_L_SQUOTE] = ACTIONS(1955),
    [anon_sym_u_SQUOTE] = ACTIONS(1955),
    [anon_sym_U_SQUOTE] = ACTIONS(1955),
    [anon_sym_u8_SQUOTE] = ACTIONS(1955),
    [anon_sym_SQUOTE] = ACTIONS(1955),
    [anon_sym_L_DQUOTE] = ACTIONS(1955),
    [anon_sym_u_DQUOTE] = ACTIONS(1955),
    [anon_sym_U_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8_DQUOTE] = ACTIONS(1955),
    [anon_sym_DQUOTE] = ACTIONS(1955),
    [sym_true] = ACTIONS(1953),
    [sym_false] = ACTIONS(1953),
    [anon_sym_NULL] = ACTIONS(1953),
    [anon_sym_nullptr] = ACTIONS(1953),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
    [sym_virtual] = ACTIONS(1953),
    [anon_sym_explicit] = ACTIONS(1953),
    [anon_sym_typename] = ACTIONS(1953),
    [anon_sym_template] = ACTIONS(1953),
    [anon_sym_operator] = ACTIONS(1953),
    [anon_sym_try] = ACTIONS(1953),
    [anon_sym_delete] = ACTIONS(1953),
    [anon_sym_throw] = ACTIONS(1953),
    [anon_sym_namespace] = ACTIONS(1953),
    [anon_sym_using] = ACTIONS(1953),
    [anon_sym_static_assert] = ACTIONS(1953),
    [anon_sym_concept] = ACTIONS(1953),
    [anon_sym_co_return] = ACTIONS(1953),
    [anon_sym_co_yield] = ACTIONS(1953),
    [anon_sym_R_DQUOTE] = ACTIONS(1955),
    [anon_sym_LR_DQUOTE] = ACTIONS(1955),
    [anon_sym_uR_DQUOTE] = ACTIONS(1955),
    [anon_sym_UR_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1955),
    [anon_sym_co_await] = ACTIONS(1953),
    [anon_sym_new] = ACTIONS(1953),
    [anon_sym_requires] = ACTIONS(1953),
    [sym_this] = ACTIONS(1953),
    [anon_sym_discard] = ACTIONS(1953),
    [anon_sym_precise] = ACTIONS(1953),
    [anon_sym_shared] = ACTIONS(1953),
    [anon_sym_groupshared] = ACTIONS(1953),
    [anon_sym_uniform] = ACTIONS(1953),
    [anon_sym_row_major] = ACTIONS(1953),
    [anon_sym_column_major] = ACTIONS(1953),
    [anon_sym_globallycoherent] = ACTIONS(1953),
    [anon_sym_centroid] = ACTIONS(1953),
    [anon_sym_noperspective] = ACTIONS(1953),
    [anon_sym_nointerpolation] = ACTIONS(1953),
    [anon_sym_sample] = ACTIONS(1953),
    [anon_sym_linear] = ACTIONS(1953),
    [anon_sym_snorm] = ACTIONS(1953),
    [anon_sym_unorm] = ACTIONS(1953),
    [anon_sym_point] = ACTIONS(1953),
    [anon_sym_line] = ACTIONS(1953),
    [anon_sym_triangleadj] = ACTIONS(1953),
    [anon_sym_lineadj] = ACTIONS(1953),
    [anon_sym_triangle] = ACTIONS(1953),
    [anon_sym_cbuffer] = ACTIONS(1953),
  },
  [278] = {
    [sym_identifier] = ACTIONS(2400),
    [aux_sym_preproc_include_token1] = ACTIONS(2400),
    [aux_sym_preproc_def_token1] = ACTIONS(2400),
    [aux_sym_preproc_if_token1] = ACTIONS(2400),
    [aux_sym_preproc_if_token2] = ACTIONS(2400),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2400),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2400),
    [aux_sym_preproc_else_token1] = ACTIONS(2400),
    [aux_sym_preproc_elif_token1] = ACTIONS(2400),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2400),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2400),
    [sym_preproc_directive] = ACTIONS(2400),
    [anon_sym_LPAREN2] = ACTIONS(2402),
    [anon_sym_BANG] = ACTIONS(2402),
    [anon_sym_TILDE] = ACTIONS(2402),
    [anon_sym_DASH] = ACTIONS(2400),
    [anon_sym_PLUS] = ACTIONS(2400),
    [anon_sym_STAR] = ACTIONS(2402),
    [anon_sym_AMP_AMP] = ACTIONS(2402),
    [anon_sym_AMP] = ACTIONS(2400),
    [anon_sym_SEMI] = ACTIONS(2402),
    [anon_sym___extension__] = ACTIONS(2400),
    [anon_sym_typedef] = ACTIONS(2400),
    [anon_sym_in] = ACTIONS(2400),
    [anon_sym_out] = ACTIONS(2400),
    [anon_sym_inout] = ACTIONS(2400),
    [anon_sym_extern] = ACTIONS(2400),
    [anon_sym___attribute__] = ACTIONS(2400),
    [anon_sym_COLON_COLON] = ACTIONS(2402),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2402),
    [anon_sym___declspec] = ACTIONS(2400),
    [anon_sym___based] = ACTIONS(2400),
    [anon_sym___cdecl] = ACTIONS(2400),
    [anon_sym___clrcall] = ACTIONS(2400),
    [anon_sym___stdcall] = ACTIONS(2400),
    [anon_sym___fastcall] = ACTIONS(2400),
    [anon_sym___thiscall] = ACTIONS(2400),
    [anon_sym___vectorcall] = ACTIONS(2400),
    [anon_sym_LBRACE] = ACTIONS(2402),
    [anon_sym_signed] = ACTIONS(2400),
    [anon_sym_unsigned] = ACTIONS(2400),
    [anon_sym_long] = ACTIONS(2400),
    [anon_sym_short] = ACTIONS(2400),
    [anon_sym_LBRACK] = ACTIONS(2400),
    [anon_sym_static] = ACTIONS(2400),
    [anon_sym_register] = ACTIONS(2400),
    [anon_sym_inline] = ACTIONS(2400),
    [anon_sym___inline] = ACTIONS(2400),
    [anon_sym___inline__] = ACTIONS(2400),
    [anon_sym___forceinline] = ACTIONS(2400),
    [anon_sym_thread_local] = ACTIONS(2400),
    [anon_sym___thread] = ACTIONS(2400),
    [anon_sym_const] = ACTIONS(2400),
    [anon_sym_constexpr] = ACTIONS(2400),
    [anon_sym_volatile] = ACTIONS(2400),
    [anon_sym_restrict] = ACTIONS(2400),
    [anon_sym___restrict__] = ACTIONS(2400),
    [anon_sym__Atomic] = ACTIONS(2400),
    [anon_sym__Noreturn] = ACTIONS(2400),
    [anon_sym_noreturn] = ACTIONS(2400),
    [anon_sym_mutable] = ACTIONS(2400),
    [anon_sym_constinit] = ACTIONS(2400),
    [anon_sym_consteval] = ACTIONS(2400),
    [anon_sym_alignas] = ACTIONS(2400),
    [anon_sym__Alignas] = ACTIONS(2400),
    [sym_primitive_type] = ACTIONS(2400),
    [anon_sym_enum] = ACTIONS(2400),
    [anon_sym_class] = ACTIONS(2400),
    [anon_sym_struct] = ACTIONS(2400),
    [anon_sym_union] = ACTIONS(2400),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_switch] = ACTIONS(2400),
    [anon_sym_case] = ACTIONS(2400),
    [anon_sym_default] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(2400),
    [anon_sym_do] = ACTIONS(2400),
    [anon_sym_for] = ACTIONS(2400),
    [anon_sym_return] = ACTIONS(2400),
    [anon_sym_break] = ACTIONS(2400),
    [anon_sym_continue] = ACTIONS(2400),
    [anon_sym_goto] = ACTIONS(2400),
    [anon_sym___try] = ACTIONS(2400),
    [anon_sym___leave] = ACTIONS(2400),
    [anon_sym_not] = ACTIONS(2400),
    [anon_sym_compl] = ACTIONS(2400),
    [anon_sym_DASH_DASH] = ACTIONS(2402),
    [anon_sym_PLUS_PLUS] = ACTIONS(2402),
    [anon_sym_sizeof] = ACTIONS(2400),
    [anon_sym___alignof__] = ACTIONS(2400),
    [anon_sym___alignof] = ACTIONS(2400),
    [anon_sym__alignof] = ACTIONS(2400),
    [anon_sym_alignof] = ACTIONS(2400),
    [anon_sym__Alignof] = ACTIONS(2400),
    [anon_sym_offsetof] = ACTIONS(2400),
    [anon_sym__Generic] = ACTIONS(2400),
    [anon_sym_asm] = ACTIONS(2400),
    [anon_sym___asm__] = ACTIONS(2400),
    [sym_number_literal] = ACTIONS(2402),
    [anon_sym_L_SQUOTE] = ACTIONS(2402),
    [anon_sym_u_SQUOTE] = ACTIONS(2402),
    [anon_sym_U_SQUOTE] = ACTIONS(2402),
    [anon_sym_u8_SQUOTE] = ACTIONS(2402),
    [anon_sym_SQUOTE] = ACTIONS(2402),
    [anon_sym_L_DQUOTE] = ACTIONS(2402),
    [anon_sym_u_DQUOTE] = ACTIONS(2402),
    [anon_sym_U_DQUOTE] = ACTIONS(2402),
    [anon_sym_u8_DQUOTE] = ACTIONS(2402),
    [anon_sym_DQUOTE] = ACTIONS(2402),
    [sym_true] = ACTIONS(2400),
    [sym_false] = ACTIONS(2400),
    [anon_sym_NULL] = ACTIONS(2400),
    [anon_sym_nullptr] = ACTIONS(2400),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2400),
    [anon_sym_decltype] = ACTIONS(2400),
    [sym_virtual] = ACTIONS(2400),
    [anon_sym_explicit] = ACTIONS(2400),
    [anon_sym_typename] = ACTIONS(2400),
    [anon_sym_template] = ACTIONS(2400),
    [anon_sym_operator] = ACTIONS(2400),
    [anon_sym_try] = ACTIONS(2400),
    [anon_sym_delete] = ACTIONS(2400),
    [anon_sym_throw] = ACTIONS(2400),
    [anon_sym_namespace] = ACTIONS(2400),
    [anon_sym_using] = ACTIONS(2400),
    [anon_sym_static_assert] = ACTIONS(2400),
    [anon_sym_concept] = ACTIONS(2400),
    [anon_sym_co_return] = ACTIONS(2400),
    [anon_sym_co_yield] = ACTIONS(2400),
    [anon_sym_R_DQUOTE] = ACTIONS(2402),
    [anon_sym_LR_DQUOTE] = ACTIONS(2402),
    [anon_sym_uR_DQUOTE] = ACTIONS(2402),
    [anon_sym_UR_DQUOTE] = ACTIONS(2402),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2402),
    [anon_sym_co_await] = ACTIONS(2400),
    [anon_sym_new] = ACTIONS(2400),
    [anon_sym_requires] = ACTIONS(2400),
    [sym_this] = ACTIONS(2400),
    [anon_sym_discard] = ACTIONS(2400),
    [anon_sym_precise] = ACTIONS(2400),
    [anon_sym_shared] = ACTIONS(2400),
    [anon_sym_groupshared] = ACTIONS(2400),
    [anon_sym_uniform] = ACTIONS(2400),
    [anon_sym_row_major] = ACTIONS(2400),
    [anon_sym_column_major] = ACTIONS(2400),
    [anon_sym_globallycoherent] = ACTIONS(2400),
    [anon_sym_centroid] = ACTIONS(2400),
    [anon_sym_noperspective] = ACTIONS(2400),
    [anon_sym_nointerpolation] = ACTIONS(2400),
    [anon_sym_sample] = ACTIONS(2400),
    [anon_sym_linear] = ACTIONS(2400),
    [anon_sym_snorm] = ACTIONS(2400),
    [anon_sym_unorm] = ACTIONS(2400),
    [anon_sym_point] = ACTIONS(2400),
    [anon_sym_line] = ACTIONS(2400),
    [anon_sym_triangleadj] = ACTIONS(2400),
    [anon_sym_lineadj] = ACTIONS(2400),
    [anon_sym_triangle] = ACTIONS(2400),
    [anon_sym_cbuffer] = ACTIONS(2400),
  },
  [279] = {
    [sym_identifier] = ACTIONS(2404),
    [aux_sym_preproc_include_token1] = ACTIONS(2404),
    [aux_sym_preproc_def_token1] = ACTIONS(2404),
    [aux_sym_preproc_if_token1] = ACTIONS(2404),
    [aux_sym_preproc_if_token2] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2404),
    [aux_sym_preproc_else_token1] = ACTIONS(2404),
    [aux_sym_preproc_elif_token1] = ACTIONS(2404),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2404),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2404),
    [sym_preproc_directive] = ACTIONS(2404),
    [anon_sym_LPAREN2] = ACTIONS(2406),
    [anon_sym_BANG] = ACTIONS(2406),
    [anon_sym_TILDE] = ACTIONS(2406),
    [anon_sym_DASH] = ACTIONS(2404),
    [anon_sym_PLUS] = ACTIONS(2404),
    [anon_sym_STAR] = ACTIONS(2406),
    [anon_sym_AMP_AMP] = ACTIONS(2406),
    [anon_sym_AMP] = ACTIONS(2404),
    [anon_sym_SEMI] = ACTIONS(2406),
    [anon_sym___extension__] = ACTIONS(2404),
    [anon_sym_typedef] = ACTIONS(2404),
    [anon_sym_in] = ACTIONS(2404),
    [anon_sym_out] = ACTIONS(2404),
    [anon_sym_inout] = ACTIONS(2404),
    [anon_sym_extern] = ACTIONS(2404),
    [anon_sym___attribute__] = ACTIONS(2404),
    [anon_sym_COLON_COLON] = ACTIONS(2406),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2406),
    [anon_sym___declspec] = ACTIONS(2404),
    [anon_sym___based] = ACTIONS(2404),
    [anon_sym___cdecl] = ACTIONS(2404),
    [anon_sym___clrcall] = ACTIONS(2404),
    [anon_sym___stdcall] = ACTIONS(2404),
    [anon_sym___fastcall] = ACTIONS(2404),
    [anon_sym___thiscall] = ACTIONS(2404),
    [anon_sym___vectorcall] = ACTIONS(2404),
    [anon_sym_LBRACE] = ACTIONS(2406),
    [anon_sym_signed] = ACTIONS(2404),
    [anon_sym_unsigned] = ACTIONS(2404),
    [anon_sym_long] = ACTIONS(2404),
    [anon_sym_short] = ACTIONS(2404),
    [anon_sym_LBRACK] = ACTIONS(2404),
    [anon_sym_static] = ACTIONS(2404),
    [anon_sym_register] = ACTIONS(2404),
    [anon_sym_inline] = ACTIONS(2404),
    [anon_sym___inline] = ACTIONS(2404),
    [anon_sym___inline__] = ACTIONS(2404),
    [anon_sym___forceinline] = ACTIONS(2404),
    [anon_sym_thread_local] = ACTIONS(2404),
    [anon_sym___thread] = ACTIONS(2404),
    [anon_sym_const] = ACTIONS(2404),
    [anon_sym_constexpr] = ACTIONS(2404),
    [anon_sym_volatile] = ACTIONS(2404),
    [anon_sym_restrict] = ACTIONS(2404),
    [anon_sym___restrict__] = ACTIONS(2404),
    [anon_sym__Atomic] = ACTIONS(2404),
    [anon_sym__Noreturn] = ACTIONS(2404),
    [anon_sym_noreturn] = ACTIONS(2404),
    [anon_sym_mutable] = ACTIONS(2404),
    [anon_sym_constinit] = ACTIONS(2404),
    [anon_sym_consteval] = ACTIONS(2404),
    [anon_sym_alignas] = ACTIONS(2404),
    [anon_sym__Alignas] = ACTIONS(2404),
    [sym_primitive_type] = ACTIONS(2404),
    [anon_sym_enum] = ACTIONS(2404),
    [anon_sym_class] = ACTIONS(2404),
    [anon_sym_struct] = ACTIONS(2404),
    [anon_sym_union] = ACTIONS(2404),
    [anon_sym_if] = ACTIONS(2404),
    [anon_sym_switch] = ACTIONS(2404),
    [anon_sym_case] = ACTIONS(2404),
    [anon_sym_default] = ACTIONS(2404),
    [anon_sym_while] = ACTIONS(2404),
    [anon_sym_do] = ACTIONS(2404),
    [anon_sym_for] = ACTIONS(2404),
    [anon_sym_return] = ACTIONS(2404),
    [anon_sym_break] = ACTIONS(2404),
    [anon_sym_continue] = ACTIONS(2404),
    [anon_sym_goto] = ACTIONS(2404),
    [anon_sym___try] = ACTIONS(2404),
    [anon_sym___leave] = ACTIONS(2404),
    [anon_sym_not] = ACTIONS(2404),
    [anon_sym_compl] = ACTIONS(2404),
    [anon_sym_DASH_DASH] = ACTIONS(2406),
    [anon_sym_PLUS_PLUS] = ACTIONS(2406),
    [anon_sym_sizeof] = ACTIONS(2404),
    [anon_sym___alignof__] = ACTIONS(2404),
    [anon_sym___alignof] = ACTIONS(2404),
    [anon_sym__alignof] = ACTIONS(2404),
    [anon_sym_alignof] = ACTIONS(2404),
    [anon_sym__Alignof] = ACTIONS(2404),
    [anon_sym_offsetof] = ACTIONS(2404),
    [anon_sym__Generic] = ACTIONS(2404),
    [anon_sym_asm] = ACTIONS(2404),
    [anon_sym___asm__] = ACTIONS(2404),
    [sym_number_literal] = ACTIONS(2406),
    [anon_sym_L_SQUOTE] = ACTIONS(2406),
    [anon_sym_u_SQUOTE] = ACTIONS(2406),
    [anon_sym_U_SQUOTE] = ACTIONS(2406),
    [anon_sym_u8_SQUOTE] = ACTIONS(2406),
    [anon_sym_SQUOTE] = ACTIONS(2406),
    [anon_sym_L_DQUOTE] = ACTIONS(2406),
    [anon_sym_u_DQUOTE] = ACTIONS(2406),
    [anon_sym_U_DQUOTE] = ACTIONS(2406),
    [anon_sym_u8_DQUOTE] = ACTIONS(2406),
    [anon_sym_DQUOTE] = ACTIONS(2406),
    [sym_true] = ACTIONS(2404),
    [sym_false] = ACTIONS(2404),
    [anon_sym_NULL] = ACTIONS(2404),
    [anon_sym_nullptr] = ACTIONS(2404),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2404),
    [anon_sym_decltype] = ACTIONS(2404),
    [sym_virtual] = ACTIONS(2404),
    [anon_sym_explicit] = ACTIONS(2404),
    [anon_sym_typename] = ACTIONS(2404),
    [anon_sym_template] = ACTIONS(2404),
    [anon_sym_operator] = ACTIONS(2404),
    [anon_sym_try] = ACTIONS(2404),
    [anon_sym_delete] = ACTIONS(2404),
    [anon_sym_throw] = ACTIONS(2404),
    [anon_sym_namespace] = ACTIONS(2404),
    [anon_sym_using] = ACTIONS(2404),
    [anon_sym_static_assert] = ACTIONS(2404),
    [anon_sym_concept] = ACTIONS(2404),
    [anon_sym_co_return] = ACTIONS(2404),
    [anon_sym_co_yield] = ACTIONS(2404),
    [anon_sym_R_DQUOTE] = ACTIONS(2406),
    [anon_sym_LR_DQUOTE] = ACTIONS(2406),
    [anon_sym_uR_DQUOTE] = ACTIONS(2406),
    [anon_sym_UR_DQUOTE] = ACTIONS(2406),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2406),
    [anon_sym_co_await] = ACTIONS(2404),
    [anon_sym_new] = ACTIONS(2404),
    [anon_sym_requires] = ACTIONS(2404),
    [sym_this] = ACTIONS(2404),
    [anon_sym_discard] = ACTIONS(2404),
    [anon_sym_precise] = ACTIONS(2404),
    [anon_sym_shared] = ACTIONS(2404),
    [anon_sym_groupshared] = ACTIONS(2404),
    [anon_sym_uniform] = ACTIONS(2404),
    [anon_sym_row_major] = ACTIONS(2404),
    [anon_sym_column_major] = ACTIONS(2404),
    [anon_sym_globallycoherent] = ACTIONS(2404),
    [anon_sym_centroid] = ACTIONS(2404),
    [anon_sym_noperspective] = ACTIONS(2404),
    [anon_sym_nointerpolation] = ACTIONS(2404),
    [anon_sym_sample] = ACTIONS(2404),
    [anon_sym_linear] = ACTIONS(2404),
    [anon_sym_snorm] = ACTIONS(2404),
    [anon_sym_unorm] = ACTIONS(2404),
    [anon_sym_point] = ACTIONS(2404),
    [anon_sym_line] = ACTIONS(2404),
    [anon_sym_triangleadj] = ACTIONS(2404),
    [anon_sym_lineadj] = ACTIONS(2404),
    [anon_sym_triangle] = ACTIONS(2404),
    [anon_sym_cbuffer] = ACTIONS(2404),
  },
  [280] = {
    [sym_identifier] = ACTIONS(2408),
    [aux_sym_preproc_include_token1] = ACTIONS(2408),
    [aux_sym_preproc_def_token1] = ACTIONS(2408),
    [aux_sym_preproc_if_token1] = ACTIONS(2408),
    [aux_sym_preproc_if_token2] = ACTIONS(2408),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2408),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2408),
    [aux_sym_preproc_else_token1] = ACTIONS(2408),
    [aux_sym_preproc_elif_token1] = ACTIONS(2408),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2408),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2408),
    [sym_preproc_directive] = ACTIONS(2408),
    [anon_sym_LPAREN2] = ACTIONS(2410),
    [anon_sym_BANG] = ACTIONS(2410),
    [anon_sym_TILDE] = ACTIONS(2410),
    [anon_sym_DASH] = ACTIONS(2408),
    [anon_sym_PLUS] = ACTIONS(2408),
    [anon_sym_STAR] = ACTIONS(2410),
    [anon_sym_AMP_AMP] = ACTIONS(2410),
    [anon_sym_AMP] = ACTIONS(2408),
    [anon_sym_SEMI] = ACTIONS(2410),
    [anon_sym___extension__] = ACTIONS(2408),
    [anon_sym_typedef] = ACTIONS(2408),
    [anon_sym_in] = ACTIONS(2408),
    [anon_sym_out] = ACTIONS(2408),
    [anon_sym_inout] = ACTIONS(2408),
    [anon_sym_extern] = ACTIONS(2408),
    [anon_sym___attribute__] = ACTIONS(2408),
    [anon_sym_COLON_COLON] = ACTIONS(2410),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2410),
    [anon_sym___declspec] = ACTIONS(2408),
    [anon_sym___based] = ACTIONS(2408),
    [anon_sym___cdecl] = ACTIONS(2408),
    [anon_sym___clrcall] = ACTIONS(2408),
    [anon_sym___stdcall] = ACTIONS(2408),
    [anon_sym___fastcall] = ACTIONS(2408),
    [anon_sym___thiscall] = ACTIONS(2408),
    [anon_sym___vectorcall] = ACTIONS(2408),
    [anon_sym_LBRACE] = ACTIONS(2410),
    [anon_sym_signed] = ACTIONS(2408),
    [anon_sym_unsigned] = ACTIONS(2408),
    [anon_sym_long] = ACTIONS(2408),
    [anon_sym_short] = ACTIONS(2408),
    [anon_sym_LBRACK] = ACTIONS(2408),
    [anon_sym_static] = ACTIONS(2408),
    [anon_sym_register] = ACTIONS(2408),
    [anon_sym_inline] = ACTIONS(2408),
    [anon_sym___inline] = ACTIONS(2408),
    [anon_sym___inline__] = ACTIONS(2408),
    [anon_sym___forceinline] = ACTIONS(2408),
    [anon_sym_thread_local] = ACTIONS(2408),
    [anon_sym___thread] = ACTIONS(2408),
    [anon_sym_const] = ACTIONS(2408),
    [anon_sym_constexpr] = ACTIONS(2408),
    [anon_sym_volatile] = ACTIONS(2408),
    [anon_sym_restrict] = ACTIONS(2408),
    [anon_sym___restrict__] = ACTIONS(2408),
    [anon_sym__Atomic] = ACTIONS(2408),
    [anon_sym__Noreturn] = ACTIONS(2408),
    [anon_sym_noreturn] = ACTIONS(2408),
    [anon_sym_mutable] = ACTIONS(2408),
    [anon_sym_constinit] = ACTIONS(2408),
    [anon_sym_consteval] = ACTIONS(2408),
    [anon_sym_alignas] = ACTIONS(2408),
    [anon_sym__Alignas] = ACTIONS(2408),
    [sym_primitive_type] = ACTIONS(2408),
    [anon_sym_enum] = ACTIONS(2408),
    [anon_sym_class] = ACTIONS(2408),
    [anon_sym_struct] = ACTIONS(2408),
    [anon_sym_union] = ACTIONS(2408),
    [anon_sym_if] = ACTIONS(2408),
    [anon_sym_switch] = ACTIONS(2408),
    [anon_sym_case] = ACTIONS(2408),
    [anon_sym_default] = ACTIONS(2408),
    [anon_sym_while] = ACTIONS(2408),
    [anon_sym_do] = ACTIONS(2408),
    [anon_sym_for] = ACTIONS(2408),
    [anon_sym_return] = ACTIONS(2408),
    [anon_sym_break] = ACTIONS(2408),
    [anon_sym_continue] = ACTIONS(2408),
    [anon_sym_goto] = ACTIONS(2408),
    [anon_sym___try] = ACTIONS(2408),
    [anon_sym___leave] = ACTIONS(2408),
    [anon_sym_not] = ACTIONS(2408),
    [anon_sym_compl] = ACTIONS(2408),
    [anon_sym_DASH_DASH] = ACTIONS(2410),
    [anon_sym_PLUS_PLUS] = ACTIONS(2410),
    [anon_sym_sizeof] = ACTIONS(2408),
    [anon_sym___alignof__] = ACTIONS(2408),
    [anon_sym___alignof] = ACTIONS(2408),
    [anon_sym__alignof] = ACTIONS(2408),
    [anon_sym_alignof] = ACTIONS(2408),
    [anon_sym__Alignof] = ACTIONS(2408),
    [anon_sym_offsetof] = ACTIONS(2408),
    [anon_sym__Generic] = ACTIONS(2408),
    [anon_sym_asm] = ACTIONS(2408),
    [anon_sym___asm__] = ACTIONS(2408),
    [sym_number_literal] = ACTIONS(2410),
    [anon_sym_L_SQUOTE] = ACTIONS(2410),
    [anon_sym_u_SQUOTE] = ACTIONS(2410),
    [anon_sym_U_SQUOTE] = ACTIONS(2410),
    [anon_sym_u8_SQUOTE] = ACTIONS(2410),
    [anon_sym_SQUOTE] = ACTIONS(2410),
    [anon_sym_L_DQUOTE] = ACTIONS(2410),
    [anon_sym_u_DQUOTE] = ACTIONS(2410),
    [anon_sym_U_DQUOTE] = ACTIONS(2410),
    [anon_sym_u8_DQUOTE] = ACTIONS(2410),
    [anon_sym_DQUOTE] = ACTIONS(2410),
    [sym_true] = ACTIONS(2408),
    [sym_false] = ACTIONS(2408),
    [anon_sym_NULL] = ACTIONS(2408),
    [anon_sym_nullptr] = ACTIONS(2408),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2408),
    [anon_sym_decltype] = ACTIONS(2408),
    [sym_virtual] = ACTIONS(2408),
    [anon_sym_explicit] = ACTIONS(2408),
    [anon_sym_typename] = ACTIONS(2408),
    [anon_sym_template] = ACTIONS(2408),
    [anon_sym_operator] = ACTIONS(2408),
    [anon_sym_try] = ACTIONS(2408),
    [anon_sym_delete] = ACTIONS(2408),
    [anon_sym_throw] = ACTIONS(2408),
    [anon_sym_namespace] = ACTIONS(2408),
    [anon_sym_using] = ACTIONS(2408),
    [anon_sym_static_assert] = ACTIONS(2408),
    [anon_sym_concept] = ACTIONS(2408),
    [anon_sym_co_return] = ACTIONS(2408),
    [anon_sym_co_yield] = ACTIONS(2408),
    [anon_sym_R_DQUOTE] = ACTIONS(2410),
    [anon_sym_LR_DQUOTE] = ACTIONS(2410),
    [anon_sym_uR_DQUOTE] = ACTIONS(2410),
    [anon_sym_UR_DQUOTE] = ACTIONS(2410),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2410),
    [anon_sym_co_await] = ACTIONS(2408),
    [anon_sym_new] = ACTIONS(2408),
    [anon_sym_requires] = ACTIONS(2408),
    [sym_this] = ACTIONS(2408),
    [anon_sym_discard] = ACTIONS(2408),
    [anon_sym_precise] = ACTIONS(2408),
    [anon_sym_shared] = ACTIONS(2408),
    [anon_sym_groupshared] = ACTIONS(2408),
    [anon_sym_uniform] = ACTIONS(2408),
    [anon_sym_row_major] = ACTIONS(2408),
    [anon_sym_column_major] = ACTIONS(2408),
    [anon_sym_globallycoherent] = ACTIONS(2408),
    [anon_sym_centroid] = ACTIONS(2408),
    [anon_sym_noperspective] = ACTIONS(2408),
    [anon_sym_nointerpolation] = ACTIONS(2408),
    [anon_sym_sample] = ACTIONS(2408),
    [anon_sym_linear] = ACTIONS(2408),
    [anon_sym_snorm] = ACTIONS(2408),
    [anon_sym_unorm] = ACTIONS(2408),
    [anon_sym_point] = ACTIONS(2408),
    [anon_sym_line] = ACTIONS(2408),
    [anon_sym_triangleadj] = ACTIONS(2408),
    [anon_sym_lineadj] = ACTIONS(2408),
    [anon_sym_triangle] = ACTIONS(2408),
    [anon_sym_cbuffer] = ACTIONS(2408),
  },
  [281] = {
    [sym_identifier] = ACTIONS(2412),
    [aux_sym_preproc_include_token1] = ACTIONS(2412),
    [aux_sym_preproc_def_token1] = ACTIONS(2412),
    [aux_sym_preproc_if_token1] = ACTIONS(2412),
    [aux_sym_preproc_if_token2] = ACTIONS(2412),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2412),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2412),
    [aux_sym_preproc_else_token1] = ACTIONS(2412),
    [aux_sym_preproc_elif_token1] = ACTIONS(2412),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2412),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2412),
    [sym_preproc_directive] = ACTIONS(2412),
    [anon_sym_LPAREN2] = ACTIONS(2414),
    [anon_sym_BANG] = ACTIONS(2414),
    [anon_sym_TILDE] = ACTIONS(2414),
    [anon_sym_DASH] = ACTIONS(2412),
    [anon_sym_PLUS] = ACTIONS(2412),
    [anon_sym_STAR] = ACTIONS(2414),
    [anon_sym_AMP_AMP] = ACTIONS(2414),
    [anon_sym_AMP] = ACTIONS(2412),
    [anon_sym_SEMI] = ACTIONS(2414),
    [anon_sym___extension__] = ACTIONS(2412),
    [anon_sym_typedef] = ACTIONS(2412),
    [anon_sym_in] = ACTIONS(2412),
    [anon_sym_out] = ACTIONS(2412),
    [anon_sym_inout] = ACTIONS(2412),
    [anon_sym_extern] = ACTIONS(2412),
    [anon_sym___attribute__] = ACTIONS(2412),
    [anon_sym_COLON_COLON] = ACTIONS(2414),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2414),
    [anon_sym___declspec] = ACTIONS(2412),
    [anon_sym___based] = ACTIONS(2412),
    [anon_sym___cdecl] = ACTIONS(2412),
    [anon_sym___clrcall] = ACTIONS(2412),
    [anon_sym___stdcall] = ACTIONS(2412),
    [anon_sym___fastcall] = ACTIONS(2412),
    [anon_sym___thiscall] = ACTIONS(2412),
    [anon_sym___vectorcall] = ACTIONS(2412),
    [anon_sym_LBRACE] = ACTIONS(2414),
    [anon_sym_signed] = ACTIONS(2412),
    [anon_sym_unsigned] = ACTIONS(2412),
    [anon_sym_long] = ACTIONS(2412),
    [anon_sym_short] = ACTIONS(2412),
    [anon_sym_LBRACK] = ACTIONS(2412),
    [anon_sym_static] = ACTIONS(2412),
    [anon_sym_register] = ACTIONS(2412),
    [anon_sym_inline] = ACTIONS(2412),
    [anon_sym___inline] = ACTIONS(2412),
    [anon_sym___inline__] = ACTIONS(2412),
    [anon_sym___forceinline] = ACTIONS(2412),
    [anon_sym_thread_local] = ACTIONS(2412),
    [anon_sym___thread] = ACTIONS(2412),
    [anon_sym_const] = ACTIONS(2412),
    [anon_sym_constexpr] = ACTIONS(2412),
    [anon_sym_volatile] = ACTIONS(2412),
    [anon_sym_restrict] = ACTIONS(2412),
    [anon_sym___restrict__] = ACTIONS(2412),
    [anon_sym__Atomic] = ACTIONS(2412),
    [anon_sym__Noreturn] = ACTIONS(2412),
    [anon_sym_noreturn] = ACTIONS(2412),
    [anon_sym_mutable] = ACTIONS(2412),
    [anon_sym_constinit] = ACTIONS(2412),
    [anon_sym_consteval] = ACTIONS(2412),
    [anon_sym_alignas] = ACTIONS(2412),
    [anon_sym__Alignas] = ACTIONS(2412),
    [sym_primitive_type] = ACTIONS(2412),
    [anon_sym_enum] = ACTIONS(2412),
    [anon_sym_class] = ACTIONS(2412),
    [anon_sym_struct] = ACTIONS(2412),
    [anon_sym_union] = ACTIONS(2412),
    [anon_sym_if] = ACTIONS(2412),
    [anon_sym_switch] = ACTIONS(2412),
    [anon_sym_case] = ACTIONS(2412),
    [anon_sym_default] = ACTIONS(2412),
    [anon_sym_while] = ACTIONS(2412),
    [anon_sym_do] = ACTIONS(2412),
    [anon_sym_for] = ACTIONS(2412),
    [anon_sym_return] = ACTIONS(2412),
    [anon_sym_break] = ACTIONS(2412),
    [anon_sym_continue] = ACTIONS(2412),
    [anon_sym_goto] = ACTIONS(2412),
    [anon_sym___try] = ACTIONS(2412),
    [anon_sym___leave] = ACTIONS(2412),
    [anon_sym_not] = ACTIONS(2412),
    [anon_sym_compl] = ACTIONS(2412),
    [anon_sym_DASH_DASH] = ACTIONS(2414),
    [anon_sym_PLUS_PLUS] = ACTIONS(2414),
    [anon_sym_sizeof] = ACTIONS(2412),
    [anon_sym___alignof__] = ACTIONS(2412),
    [anon_sym___alignof] = ACTIONS(2412),
    [anon_sym__alignof] = ACTIONS(2412),
    [anon_sym_alignof] = ACTIONS(2412),
    [anon_sym__Alignof] = ACTIONS(2412),
    [anon_sym_offsetof] = ACTIONS(2412),
    [anon_sym__Generic] = ACTIONS(2412),
    [anon_sym_asm] = ACTIONS(2412),
    [anon_sym___asm__] = ACTIONS(2412),
    [sym_number_literal] = ACTIONS(2414),
    [anon_sym_L_SQUOTE] = ACTIONS(2414),
    [anon_sym_u_SQUOTE] = ACTIONS(2414),
    [anon_sym_U_SQUOTE] = ACTIONS(2414),
    [anon_sym_u8_SQUOTE] = ACTIONS(2414),
    [anon_sym_SQUOTE] = ACTIONS(2414),
    [anon_sym_L_DQUOTE] = ACTIONS(2414),
    [anon_sym_u_DQUOTE] = ACTIONS(2414),
    [anon_sym_U_DQUOTE] = ACTIONS(2414),
    [anon_sym_u8_DQUOTE] = ACTIONS(2414),
    [anon_sym_DQUOTE] = ACTIONS(2414),
    [sym_true] = ACTIONS(2412),
    [sym_false] = ACTIONS(2412),
    [anon_sym_NULL] = ACTIONS(2412),
    [anon_sym_nullptr] = ACTIONS(2412),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2412),
    [anon_sym_decltype] = ACTIONS(2412),
    [sym_virtual] = ACTIONS(2412),
    [anon_sym_explicit] = ACTIONS(2412),
    [anon_sym_typename] = ACTIONS(2412),
    [anon_sym_template] = ACTIONS(2412),
    [anon_sym_operator] = ACTIONS(2412),
    [anon_sym_try] = ACTIONS(2412),
    [anon_sym_delete] = ACTIONS(2412),
    [anon_sym_throw] = ACTIONS(2412),
    [anon_sym_namespace] = ACTIONS(2412),
    [anon_sym_using] = ACTIONS(2412),
    [anon_sym_static_assert] = ACTIONS(2412),
    [anon_sym_concept] = ACTIONS(2412),
    [anon_sym_co_return] = ACTIONS(2412),
    [anon_sym_co_yield] = ACTIONS(2412),
    [anon_sym_R_DQUOTE] = ACTIONS(2414),
    [anon_sym_LR_DQUOTE] = ACTIONS(2414),
    [anon_sym_uR_DQUOTE] = ACTIONS(2414),
    [anon_sym_UR_DQUOTE] = ACTIONS(2414),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2414),
    [anon_sym_co_await] = ACTIONS(2412),
    [anon_sym_new] = ACTIONS(2412),
    [anon_sym_requires] = ACTIONS(2412),
    [sym_this] = ACTIONS(2412),
    [anon_sym_discard] = ACTIONS(2412),
    [anon_sym_precise] = ACTIONS(2412),
    [anon_sym_shared] = ACTIONS(2412),
    [anon_sym_groupshared] = ACTIONS(2412),
    [anon_sym_uniform] = ACTIONS(2412),
    [anon_sym_row_major] = ACTIONS(2412),
    [anon_sym_column_major] = ACTIONS(2412),
    [anon_sym_globallycoherent] = ACTIONS(2412),
    [anon_sym_centroid] = ACTIONS(2412),
    [anon_sym_noperspective] = ACTIONS(2412),
    [anon_sym_nointerpolation] = ACTIONS(2412),
    [anon_sym_sample] = ACTIONS(2412),
    [anon_sym_linear] = ACTIONS(2412),
    [anon_sym_snorm] = ACTIONS(2412),
    [anon_sym_unorm] = ACTIONS(2412),
    [anon_sym_point] = ACTIONS(2412),
    [anon_sym_line] = ACTIONS(2412),
    [anon_sym_triangleadj] = ACTIONS(2412),
    [anon_sym_lineadj] = ACTIONS(2412),
    [anon_sym_triangle] = ACTIONS(2412),
    [anon_sym_cbuffer] = ACTIONS(2412),
  },
  [282] = {
    [sym_identifier] = ACTIONS(2416),
    [aux_sym_preproc_include_token1] = ACTIONS(2416),
    [aux_sym_preproc_def_token1] = ACTIONS(2416),
    [aux_sym_preproc_if_token1] = ACTIONS(2416),
    [aux_sym_preproc_if_token2] = ACTIONS(2416),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2416),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2416),
    [aux_sym_preproc_else_token1] = ACTIONS(2416),
    [aux_sym_preproc_elif_token1] = ACTIONS(2416),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2416),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2416),
    [sym_preproc_directive] = ACTIONS(2416),
    [anon_sym_LPAREN2] = ACTIONS(2418),
    [anon_sym_BANG] = ACTIONS(2418),
    [anon_sym_TILDE] = ACTIONS(2418),
    [anon_sym_DASH] = ACTIONS(2416),
    [anon_sym_PLUS] = ACTIONS(2416),
    [anon_sym_STAR] = ACTIONS(2418),
    [anon_sym_AMP_AMP] = ACTIONS(2418),
    [anon_sym_AMP] = ACTIONS(2416),
    [anon_sym_SEMI] = ACTIONS(2418),
    [anon_sym___extension__] = ACTIONS(2416),
    [anon_sym_typedef] = ACTIONS(2416),
    [anon_sym_in] = ACTIONS(2416),
    [anon_sym_out] = ACTIONS(2416),
    [anon_sym_inout] = ACTIONS(2416),
    [anon_sym_extern] = ACTIONS(2416),
    [anon_sym___attribute__] = ACTIONS(2416),
    [anon_sym_COLON_COLON] = ACTIONS(2418),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2418),
    [anon_sym___declspec] = ACTIONS(2416),
    [anon_sym___based] = ACTIONS(2416),
    [anon_sym___cdecl] = ACTIONS(2416),
    [anon_sym___clrcall] = ACTIONS(2416),
    [anon_sym___stdcall] = ACTIONS(2416),
    [anon_sym___fastcall] = ACTIONS(2416),
    [anon_sym___thiscall] = ACTIONS(2416),
    [anon_sym___vectorcall] = ACTIONS(2416),
    [anon_sym_LBRACE] = ACTIONS(2418),
    [anon_sym_signed] = ACTIONS(2416),
    [anon_sym_unsigned] = ACTIONS(2416),
    [anon_sym_long] = ACTIONS(2416),
    [anon_sym_short] = ACTIONS(2416),
    [anon_sym_LBRACK] = ACTIONS(2416),
    [anon_sym_static] = ACTIONS(2416),
    [anon_sym_register] = ACTIONS(2416),
    [anon_sym_inline] = ACTIONS(2416),
    [anon_sym___inline] = ACTIONS(2416),
    [anon_sym___inline__] = ACTIONS(2416),
    [anon_sym___forceinline] = ACTIONS(2416),
    [anon_sym_thread_local] = ACTIONS(2416),
    [anon_sym___thread] = ACTIONS(2416),
    [anon_sym_const] = ACTIONS(2416),
    [anon_sym_constexpr] = ACTIONS(2416),
    [anon_sym_volatile] = ACTIONS(2416),
    [anon_sym_restrict] = ACTIONS(2416),
    [anon_sym___restrict__] = ACTIONS(2416),
    [anon_sym__Atomic] = ACTIONS(2416),
    [anon_sym__Noreturn] = ACTIONS(2416),
    [anon_sym_noreturn] = ACTIONS(2416),
    [anon_sym_mutable] = ACTIONS(2416),
    [anon_sym_constinit] = ACTIONS(2416),
    [anon_sym_consteval] = ACTIONS(2416),
    [anon_sym_alignas] = ACTIONS(2416),
    [anon_sym__Alignas] = ACTIONS(2416),
    [sym_primitive_type] = ACTIONS(2416),
    [anon_sym_enum] = ACTIONS(2416),
    [anon_sym_class] = ACTIONS(2416),
    [anon_sym_struct] = ACTIONS(2416),
    [anon_sym_union] = ACTIONS(2416),
    [anon_sym_if] = ACTIONS(2416),
    [anon_sym_switch] = ACTIONS(2416),
    [anon_sym_case] = ACTIONS(2416),
    [anon_sym_default] = ACTIONS(2416),
    [anon_sym_while] = ACTIONS(2416),
    [anon_sym_do] = ACTIONS(2416),
    [anon_sym_for] = ACTIONS(2416),
    [anon_sym_return] = ACTIONS(2416),
    [anon_sym_break] = ACTIONS(2416),
    [anon_sym_continue] = ACTIONS(2416),
    [anon_sym_goto] = ACTIONS(2416),
    [anon_sym___try] = ACTIONS(2416),
    [anon_sym___leave] = ACTIONS(2416),
    [anon_sym_not] = ACTIONS(2416),
    [anon_sym_compl] = ACTIONS(2416),
    [anon_sym_DASH_DASH] = ACTIONS(2418),
    [anon_sym_PLUS_PLUS] = ACTIONS(2418),
    [anon_sym_sizeof] = ACTIONS(2416),
    [anon_sym___alignof__] = ACTIONS(2416),
    [anon_sym___alignof] = ACTIONS(2416),
    [anon_sym__alignof] = ACTIONS(2416),
    [anon_sym_alignof] = ACTIONS(2416),
    [anon_sym__Alignof] = ACTIONS(2416),
    [anon_sym_offsetof] = ACTIONS(2416),
    [anon_sym__Generic] = ACTIONS(2416),
    [anon_sym_asm] = ACTIONS(2416),
    [anon_sym___asm__] = ACTIONS(2416),
    [sym_number_literal] = ACTIONS(2418),
    [anon_sym_L_SQUOTE] = ACTIONS(2418),
    [anon_sym_u_SQUOTE] = ACTIONS(2418),
    [anon_sym_U_SQUOTE] = ACTIONS(2418),
    [anon_sym_u8_SQUOTE] = ACTIONS(2418),
    [anon_sym_SQUOTE] = ACTIONS(2418),
    [anon_sym_L_DQUOTE] = ACTIONS(2418),
    [anon_sym_u_DQUOTE] = ACTIONS(2418),
    [anon_sym_U_DQUOTE] = ACTIONS(2418),
    [anon_sym_u8_DQUOTE] = ACTIONS(2418),
    [anon_sym_DQUOTE] = ACTIONS(2418),
    [sym_true] = ACTIONS(2416),
    [sym_false] = ACTIONS(2416),
    [anon_sym_NULL] = ACTIONS(2416),
    [anon_sym_nullptr] = ACTIONS(2416),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2416),
    [anon_sym_decltype] = ACTIONS(2416),
    [sym_virtual] = ACTIONS(2416),
    [anon_sym_explicit] = ACTIONS(2416),
    [anon_sym_typename] = ACTIONS(2416),
    [anon_sym_template] = ACTIONS(2416),
    [anon_sym_operator] = ACTIONS(2416),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_delete] = ACTIONS(2416),
    [anon_sym_throw] = ACTIONS(2416),
    [anon_sym_namespace] = ACTIONS(2416),
    [anon_sym_using] = ACTIONS(2416),
    [anon_sym_static_assert] = ACTIONS(2416),
    [anon_sym_concept] = ACTIONS(2416),
    [anon_sym_co_return] = ACTIONS(2416),
    [anon_sym_co_yield] = ACTIONS(2416),
    [anon_sym_R_DQUOTE] = ACTIONS(2418),
    [anon_sym_LR_DQUOTE] = ACTIONS(2418),
    [anon_sym_uR_DQUOTE] = ACTIONS(2418),
    [anon_sym_UR_DQUOTE] = ACTIONS(2418),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2418),
    [anon_sym_co_await] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(2416),
    [anon_sym_requires] = ACTIONS(2416),
    [sym_this] = ACTIONS(2416),
    [anon_sym_discard] = ACTIONS(2416),
    [anon_sym_precise] = ACTIONS(2416),
    [anon_sym_shared] = ACTIONS(2416),
    [anon_sym_groupshared] = ACTIONS(2416),
    [anon_sym_uniform] = ACTIONS(2416),
    [anon_sym_row_major] = ACTIONS(2416),
    [anon_sym_column_major] = ACTIONS(2416),
    [anon_sym_globallycoherent] = ACTIONS(2416),
    [anon_sym_centroid] = ACTIONS(2416),
    [anon_sym_noperspective] = ACTIONS(2416),
    [anon_sym_nointerpolation] = ACTIONS(2416),
    [anon_sym_sample] = ACTIONS(2416),
    [anon_sym_linear] = ACTIONS(2416),
    [anon_sym_snorm] = ACTIONS(2416),
    [anon_sym_unorm] = ACTIONS(2416),
    [anon_sym_point] = ACTIONS(2416),
    [anon_sym_line] = ACTIONS(2416),
    [anon_sym_triangleadj] = ACTIONS(2416),
    [anon_sym_lineadj] = ACTIONS(2416),
    [anon_sym_triangle] = ACTIONS(2416),
    [anon_sym_cbuffer] = ACTIONS(2416),
  },
  [283] = {
    [sym_identifier] = ACTIONS(2420),
    [aux_sym_preproc_include_token1] = ACTIONS(2420),
    [aux_sym_preproc_def_token1] = ACTIONS(2420),
    [aux_sym_preproc_if_token1] = ACTIONS(2420),
    [aux_sym_preproc_if_token2] = ACTIONS(2420),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2420),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2420),
    [aux_sym_preproc_else_token1] = ACTIONS(2420),
    [aux_sym_preproc_elif_token1] = ACTIONS(2420),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2420),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2420),
    [sym_preproc_directive] = ACTIONS(2420),
    [anon_sym_LPAREN2] = ACTIONS(2422),
    [anon_sym_BANG] = ACTIONS(2422),
    [anon_sym_TILDE] = ACTIONS(2422),
    [anon_sym_DASH] = ACTIONS(2420),
    [anon_sym_PLUS] = ACTIONS(2420),
    [anon_sym_STAR] = ACTIONS(2422),
    [anon_sym_AMP_AMP] = ACTIONS(2422),
    [anon_sym_AMP] = ACTIONS(2420),
    [anon_sym_SEMI] = ACTIONS(2422),
    [anon_sym___extension__] = ACTIONS(2420),
    [anon_sym_typedef] = ACTIONS(2420),
    [anon_sym_in] = ACTIONS(2420),
    [anon_sym_out] = ACTIONS(2420),
    [anon_sym_inout] = ACTIONS(2420),
    [anon_sym_extern] = ACTIONS(2420),
    [anon_sym___attribute__] = ACTIONS(2420),
    [anon_sym_COLON_COLON] = ACTIONS(2422),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2422),
    [anon_sym___declspec] = ACTIONS(2420),
    [anon_sym___based] = ACTIONS(2420),
    [anon_sym___cdecl] = ACTIONS(2420),
    [anon_sym___clrcall] = ACTIONS(2420),
    [anon_sym___stdcall] = ACTIONS(2420),
    [anon_sym___fastcall] = ACTIONS(2420),
    [anon_sym___thiscall] = ACTIONS(2420),
    [anon_sym___vectorcall] = ACTIONS(2420),
    [anon_sym_LBRACE] = ACTIONS(2422),
    [anon_sym_signed] = ACTIONS(2420),
    [anon_sym_unsigned] = ACTIONS(2420),
    [anon_sym_long] = ACTIONS(2420),
    [anon_sym_short] = ACTIONS(2420),
    [anon_sym_LBRACK] = ACTIONS(2420),
    [anon_sym_static] = ACTIONS(2420),
    [anon_sym_register] = ACTIONS(2420),
    [anon_sym_inline] = ACTIONS(2420),
    [anon_sym___inline] = ACTIONS(2420),
    [anon_sym___inline__] = ACTIONS(2420),
    [anon_sym___forceinline] = ACTIONS(2420),
    [anon_sym_thread_local] = ACTIONS(2420),
    [anon_sym___thread] = ACTIONS(2420),
    [anon_sym_const] = ACTIONS(2420),
    [anon_sym_constexpr] = ACTIONS(2420),
    [anon_sym_volatile] = ACTIONS(2420),
    [anon_sym_restrict] = ACTIONS(2420),
    [anon_sym___restrict__] = ACTIONS(2420),
    [anon_sym__Atomic] = ACTIONS(2420),
    [anon_sym__Noreturn] = ACTIONS(2420),
    [anon_sym_noreturn] = ACTIONS(2420),
    [anon_sym_mutable] = ACTIONS(2420),
    [anon_sym_constinit] = ACTIONS(2420),
    [anon_sym_consteval] = ACTIONS(2420),
    [anon_sym_alignas] = ACTIONS(2420),
    [anon_sym__Alignas] = ACTIONS(2420),
    [sym_primitive_type] = ACTIONS(2420),
    [anon_sym_enum] = ACTIONS(2420),
    [anon_sym_class] = ACTIONS(2420),
    [anon_sym_struct] = ACTIONS(2420),
    [anon_sym_union] = ACTIONS(2420),
    [anon_sym_if] = ACTIONS(2420),
    [anon_sym_switch] = ACTIONS(2420),
    [anon_sym_case] = ACTIONS(2420),
    [anon_sym_default] = ACTIONS(2420),
    [anon_sym_while] = ACTIONS(2420),
    [anon_sym_do] = ACTIONS(2420),
    [anon_sym_for] = ACTIONS(2420),
    [anon_sym_return] = ACTIONS(2420),
    [anon_sym_break] = ACTIONS(2420),
    [anon_sym_continue] = ACTIONS(2420),
    [anon_sym_goto] = ACTIONS(2420),
    [anon_sym___try] = ACTIONS(2420),
    [anon_sym___leave] = ACTIONS(2420),
    [anon_sym_not] = ACTIONS(2420),
    [anon_sym_compl] = ACTIONS(2420),
    [anon_sym_DASH_DASH] = ACTIONS(2422),
    [anon_sym_PLUS_PLUS] = ACTIONS(2422),
    [anon_sym_sizeof] = ACTIONS(2420),
    [anon_sym___alignof__] = ACTIONS(2420),
    [anon_sym___alignof] = ACTIONS(2420),
    [anon_sym__alignof] = ACTIONS(2420),
    [anon_sym_alignof] = ACTIONS(2420),
    [anon_sym__Alignof] = ACTIONS(2420),
    [anon_sym_offsetof] = ACTIONS(2420),
    [anon_sym__Generic] = ACTIONS(2420),
    [anon_sym_asm] = ACTIONS(2420),
    [anon_sym___asm__] = ACTIONS(2420),
    [sym_number_literal] = ACTIONS(2422),
    [anon_sym_L_SQUOTE] = ACTIONS(2422),
    [anon_sym_u_SQUOTE] = ACTIONS(2422),
    [anon_sym_U_SQUOTE] = ACTIONS(2422),
    [anon_sym_u8_SQUOTE] = ACTIONS(2422),
    [anon_sym_SQUOTE] = ACTIONS(2422),
    [anon_sym_L_DQUOTE] = ACTIONS(2422),
    [anon_sym_u_DQUOTE] = ACTIONS(2422),
    [anon_sym_U_DQUOTE] = ACTIONS(2422),
    [anon_sym_u8_DQUOTE] = ACTIONS(2422),
    [anon_sym_DQUOTE] = ACTIONS(2422),
    [sym_true] = ACTIONS(2420),
    [sym_false] = ACTIONS(2420),
    [anon_sym_NULL] = ACTIONS(2420),
    [anon_sym_nullptr] = ACTIONS(2420),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2420),
    [anon_sym_decltype] = ACTIONS(2420),
    [sym_virtual] = ACTIONS(2420),
    [anon_sym_explicit] = ACTIONS(2420),
    [anon_sym_typename] = ACTIONS(2420),
    [anon_sym_template] = ACTIONS(2420),
    [anon_sym_operator] = ACTIONS(2420),
    [anon_sym_try] = ACTIONS(2420),
    [anon_sym_delete] = ACTIONS(2420),
    [anon_sym_throw] = ACTIONS(2420),
    [anon_sym_namespace] = ACTIONS(2420),
    [anon_sym_using] = ACTIONS(2420),
    [anon_sym_static_assert] = ACTIONS(2420),
    [anon_sym_concept] = ACTIONS(2420),
    [anon_sym_co_return] = ACTIONS(2420),
    [anon_sym_co_yield] = ACTIONS(2420),
    [anon_sym_R_DQUOTE] = ACTIONS(2422),
    [anon_sym_LR_DQUOTE] = ACTIONS(2422),
    [anon_sym_uR_DQUOTE] = ACTIONS(2422),
    [anon_sym_UR_DQUOTE] = ACTIONS(2422),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2422),
    [anon_sym_co_await] = ACTIONS(2420),
    [anon_sym_new] = ACTIONS(2420),
    [anon_sym_requires] = ACTIONS(2420),
    [sym_this] = ACTIONS(2420),
    [anon_sym_discard] = ACTIONS(2420),
    [anon_sym_precise] = ACTIONS(2420),
    [anon_sym_shared] = ACTIONS(2420),
    [anon_sym_groupshared] = ACTIONS(2420),
    [anon_sym_uniform] = ACTIONS(2420),
    [anon_sym_row_major] = ACTIONS(2420),
    [anon_sym_column_major] = ACTIONS(2420),
    [anon_sym_globallycoherent] = ACTIONS(2420),
    [anon_sym_centroid] = ACTIONS(2420),
    [anon_sym_noperspective] = ACTIONS(2420),
    [anon_sym_nointerpolation] = ACTIONS(2420),
    [anon_sym_sample] = ACTIONS(2420),
    [anon_sym_linear] = ACTIONS(2420),
    [anon_sym_snorm] = ACTIONS(2420),
    [anon_sym_unorm] = ACTIONS(2420),
    [anon_sym_point] = ACTIONS(2420),
    [anon_sym_line] = ACTIONS(2420),
    [anon_sym_triangleadj] = ACTIONS(2420),
    [anon_sym_lineadj] = ACTIONS(2420),
    [anon_sym_triangle] = ACTIONS(2420),
    [anon_sym_cbuffer] = ACTIONS(2420),
  },
  [284] = {
    [sym_identifier] = ACTIONS(1969),
    [aux_sym_preproc_include_token1] = ACTIONS(1969),
    [aux_sym_preproc_def_token1] = ACTIONS(1969),
    [aux_sym_preproc_if_token1] = ACTIONS(1969),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1969),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1969),
    [sym_preproc_directive] = ACTIONS(1969),
    [anon_sym_LPAREN2] = ACTIONS(1971),
    [anon_sym_BANG] = ACTIONS(1971),
    [anon_sym_TILDE] = ACTIONS(1971),
    [anon_sym_DASH] = ACTIONS(1969),
    [anon_sym_PLUS] = ACTIONS(1969),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_AMP_AMP] = ACTIONS(1971),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_COLON] = ACTIONS(1969),
    [anon_sym_SEMI] = ACTIONS(1971),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym_typedef] = ACTIONS(1969),
    [anon_sym_in] = ACTIONS(1969),
    [anon_sym_out] = ACTIONS(1969),
    [anon_sym_inout] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1971),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym___cdecl] = ACTIONS(1969),
    [anon_sym___clrcall] = ACTIONS(1969),
    [anon_sym___stdcall] = ACTIONS(1969),
    [anon_sym___fastcall] = ACTIONS(1969),
    [anon_sym___thiscall] = ACTIONS(1969),
    [anon_sym___vectorcall] = ACTIONS(1969),
    [anon_sym_LBRACE] = ACTIONS(1971),
    [anon_sym_RBRACE] = ACTIONS(1971),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1969),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [anon_sym_if] = ACTIONS(1969),
    [anon_sym_else] = ACTIONS(1969),
    [anon_sym_switch] = ACTIONS(1969),
    [anon_sym_case] = ACTIONS(1969),
    [anon_sym_default] = ACTIONS(1969),
    [anon_sym_while] = ACTIONS(1969),
    [anon_sym_do] = ACTIONS(1969),
    [anon_sym_for] = ACTIONS(1969),
    [anon_sym_return] = ACTIONS(1969),
    [anon_sym_break] = ACTIONS(1969),
    [anon_sym_continue] = ACTIONS(1969),
    [anon_sym_goto] = ACTIONS(1969),
    [anon_sym___try] = ACTIONS(1969),
    [anon_sym___leave] = ACTIONS(1969),
    [anon_sym_not] = ACTIONS(1969),
    [anon_sym_compl] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1971),
    [anon_sym_PLUS_PLUS] = ACTIONS(1971),
    [anon_sym_sizeof] = ACTIONS(1969),
    [anon_sym___alignof__] = ACTIONS(1969),
    [anon_sym___alignof] = ACTIONS(1969),
    [anon_sym__alignof] = ACTIONS(1969),
    [anon_sym_alignof] = ACTIONS(1969),
    [anon_sym__Alignof] = ACTIONS(1969),
    [anon_sym_offsetof] = ACTIONS(1969),
    [anon_sym__Generic] = ACTIONS(1969),
    [anon_sym_asm] = ACTIONS(1969),
    [anon_sym___asm__] = ACTIONS(1969),
    [sym_number_literal] = ACTIONS(1971),
    [anon_sym_L_SQUOTE] = ACTIONS(1971),
    [anon_sym_u_SQUOTE] = ACTIONS(1971),
    [anon_sym_U_SQUOTE] = ACTIONS(1971),
    [anon_sym_u8_SQUOTE] = ACTIONS(1971),
    [anon_sym_SQUOTE] = ACTIONS(1971),
    [anon_sym_L_DQUOTE] = ACTIONS(1971),
    [anon_sym_u_DQUOTE] = ACTIONS(1971),
    [anon_sym_U_DQUOTE] = ACTIONS(1971),
    [anon_sym_u8_DQUOTE] = ACTIONS(1971),
    [anon_sym_DQUOTE] = ACTIONS(1971),
    [sym_true] = ACTIONS(1969),
    [sym_false] = ACTIONS(1969),
    [anon_sym_NULL] = ACTIONS(1969),
    [anon_sym_nullptr] = ACTIONS(1969),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_final] = ACTIONS(1969),
    [anon_sym_override] = ACTIONS(1969),
    [sym_virtual] = ACTIONS(1969),
    [anon_sym_explicit] = ACTIONS(1969),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1969),
    [anon_sym_operator] = ACTIONS(1969),
    [anon_sym_try] = ACTIONS(1969),
    [anon_sym_delete] = ACTIONS(1969),
    [anon_sym_throw] = ACTIONS(1969),
    [anon_sym_namespace] = ACTIONS(1969),
    [anon_sym_using] = ACTIONS(1969),
    [anon_sym_static_assert] = ACTIONS(1969),
    [anon_sym_concept] = ACTIONS(1969),
    [anon_sym_co_return] = ACTIONS(1969),
    [anon_sym_co_yield] = ACTIONS(1969),
    [anon_sym_R_DQUOTE] = ACTIONS(1971),
    [anon_sym_LR_DQUOTE] = ACTIONS(1971),
    [anon_sym_uR_DQUOTE] = ACTIONS(1971),
    [anon_sym_UR_DQUOTE] = ACTIONS(1971),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1971),
    [anon_sym_co_await] = ACTIONS(1969),
    [anon_sym_new] = ACTIONS(1969),
    [anon_sym_requires] = ACTIONS(1969),
    [sym_this] = ACTIONS(1969),
    [anon_sym_discard] = ACTIONS(1969),
    [anon_sym_precise] = ACTIONS(1969),
    [anon_sym_shared] = ACTIONS(1969),
    [anon_sym_groupshared] = ACTIONS(1969),
    [anon_sym_uniform] = ACTIONS(1969),
    [anon_sym_row_major] = ACTIONS(1969),
    [anon_sym_column_major] = ACTIONS(1969),
    [anon_sym_globallycoherent] = ACTIONS(1969),
    [anon_sym_centroid] = ACTIONS(1969),
    [anon_sym_noperspective] = ACTIONS(1969),
    [anon_sym_nointerpolation] = ACTIONS(1969),
    [anon_sym_sample] = ACTIONS(1969),
    [anon_sym_linear] = ACTIONS(1969),
    [anon_sym_snorm] = ACTIONS(1969),
    [anon_sym_unorm] = ACTIONS(1969),
    [anon_sym_point] = ACTIONS(1969),
    [anon_sym_line] = ACTIONS(1969),
    [anon_sym_triangleadj] = ACTIONS(1969),
    [anon_sym_lineadj] = ACTIONS(1969),
    [anon_sym_triangle] = ACTIONS(1969),
    [anon_sym_cbuffer] = ACTIONS(1969),
  },
  [285] = {
    [sym_identifier] = ACTIONS(2424),
    [aux_sym_preproc_include_token1] = ACTIONS(2424),
    [aux_sym_preproc_def_token1] = ACTIONS(2424),
    [aux_sym_preproc_if_token1] = ACTIONS(2424),
    [aux_sym_preproc_if_token2] = ACTIONS(2424),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2424),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2424),
    [aux_sym_preproc_else_token1] = ACTIONS(2424),
    [aux_sym_preproc_elif_token1] = ACTIONS(2424),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2424),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2424),
    [sym_preproc_directive] = ACTIONS(2424),
    [anon_sym_LPAREN2] = ACTIONS(2426),
    [anon_sym_BANG] = ACTIONS(2426),
    [anon_sym_TILDE] = ACTIONS(2426),
    [anon_sym_DASH] = ACTIONS(2424),
    [anon_sym_PLUS] = ACTIONS(2424),
    [anon_sym_STAR] = ACTIONS(2426),
    [anon_sym_AMP_AMP] = ACTIONS(2426),
    [anon_sym_AMP] = ACTIONS(2424),
    [anon_sym_SEMI] = ACTIONS(2426),
    [anon_sym___extension__] = ACTIONS(2424),
    [anon_sym_typedef] = ACTIONS(2424),
    [anon_sym_in] = ACTIONS(2424),
    [anon_sym_out] = ACTIONS(2424),
    [anon_sym_inout] = ACTIONS(2424),
    [anon_sym_extern] = ACTIONS(2424),
    [anon_sym___attribute__] = ACTIONS(2424),
    [anon_sym_COLON_COLON] = ACTIONS(2426),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2426),
    [anon_sym___declspec] = ACTIONS(2424),
    [anon_sym___based] = ACTIONS(2424),
    [anon_sym___cdecl] = ACTIONS(2424),
    [anon_sym___clrcall] = ACTIONS(2424),
    [anon_sym___stdcall] = ACTIONS(2424),
    [anon_sym___fastcall] = ACTIONS(2424),
    [anon_sym___thiscall] = ACTIONS(2424),
    [anon_sym___vectorcall] = ACTIONS(2424),
    [anon_sym_LBRACE] = ACTIONS(2426),
    [anon_sym_signed] = ACTIONS(2424),
    [anon_sym_unsigned] = ACTIONS(2424),
    [anon_sym_long] = ACTIONS(2424),
    [anon_sym_short] = ACTIONS(2424),
    [anon_sym_LBRACK] = ACTIONS(2424),
    [anon_sym_static] = ACTIONS(2424),
    [anon_sym_register] = ACTIONS(2424),
    [anon_sym_inline] = ACTIONS(2424),
    [anon_sym___inline] = ACTIONS(2424),
    [anon_sym___inline__] = ACTIONS(2424),
    [anon_sym___forceinline] = ACTIONS(2424),
    [anon_sym_thread_local] = ACTIONS(2424),
    [anon_sym___thread] = ACTIONS(2424),
    [anon_sym_const] = ACTIONS(2424),
    [anon_sym_constexpr] = ACTIONS(2424),
    [anon_sym_volatile] = ACTIONS(2424),
    [anon_sym_restrict] = ACTIONS(2424),
    [anon_sym___restrict__] = ACTIONS(2424),
    [anon_sym__Atomic] = ACTIONS(2424),
    [anon_sym__Noreturn] = ACTIONS(2424),
    [anon_sym_noreturn] = ACTIONS(2424),
    [anon_sym_mutable] = ACTIONS(2424),
    [anon_sym_constinit] = ACTIONS(2424),
    [anon_sym_consteval] = ACTIONS(2424),
    [anon_sym_alignas] = ACTIONS(2424),
    [anon_sym__Alignas] = ACTIONS(2424),
    [sym_primitive_type] = ACTIONS(2424),
    [anon_sym_enum] = ACTIONS(2424),
    [anon_sym_class] = ACTIONS(2424),
    [anon_sym_struct] = ACTIONS(2424),
    [anon_sym_union] = ACTIONS(2424),
    [anon_sym_if] = ACTIONS(2424),
    [anon_sym_switch] = ACTIONS(2424),
    [anon_sym_case] = ACTIONS(2424),
    [anon_sym_default] = ACTIONS(2424),
    [anon_sym_while] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(2424),
    [anon_sym_for] = ACTIONS(2424),
    [anon_sym_return] = ACTIONS(2424),
    [anon_sym_break] = ACTIONS(2424),
    [anon_sym_continue] = ACTIONS(2424),
    [anon_sym_goto] = ACTIONS(2424),
    [anon_sym___try] = ACTIONS(2424),
    [anon_sym___leave] = ACTIONS(2424),
    [anon_sym_not] = ACTIONS(2424),
    [anon_sym_compl] = ACTIONS(2424),
    [anon_sym_DASH_DASH] = ACTIONS(2426),
    [anon_sym_PLUS_PLUS] = ACTIONS(2426),
    [anon_sym_sizeof] = ACTIONS(2424),
    [anon_sym___alignof__] = ACTIONS(2424),
    [anon_sym___alignof] = ACTIONS(2424),
    [anon_sym__alignof] = ACTIONS(2424),
    [anon_sym_alignof] = ACTIONS(2424),
    [anon_sym__Alignof] = ACTIONS(2424),
    [anon_sym_offsetof] = ACTIONS(2424),
    [anon_sym__Generic] = ACTIONS(2424),
    [anon_sym_asm] = ACTIONS(2424),
    [anon_sym___asm__] = ACTIONS(2424),
    [sym_number_literal] = ACTIONS(2426),
    [anon_sym_L_SQUOTE] = ACTIONS(2426),
    [anon_sym_u_SQUOTE] = ACTIONS(2426),
    [anon_sym_U_SQUOTE] = ACTIONS(2426),
    [anon_sym_u8_SQUOTE] = ACTIONS(2426),
    [anon_sym_SQUOTE] = ACTIONS(2426),
    [anon_sym_L_DQUOTE] = ACTIONS(2426),
    [anon_sym_u_DQUOTE] = ACTIONS(2426),
    [anon_sym_U_DQUOTE] = ACTIONS(2426),
    [anon_sym_u8_DQUOTE] = ACTIONS(2426),
    [anon_sym_DQUOTE] = ACTIONS(2426),
    [sym_true] = ACTIONS(2424),
    [sym_false] = ACTIONS(2424),
    [anon_sym_NULL] = ACTIONS(2424),
    [anon_sym_nullptr] = ACTIONS(2424),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2424),
    [anon_sym_decltype] = ACTIONS(2424),
    [sym_virtual] = ACTIONS(2424),
    [anon_sym_explicit] = ACTIONS(2424),
    [anon_sym_typename] = ACTIONS(2424),
    [anon_sym_template] = ACTIONS(2424),
    [anon_sym_operator] = ACTIONS(2424),
    [anon_sym_try] = ACTIONS(2424),
    [anon_sym_delete] = ACTIONS(2424),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_namespace] = ACTIONS(2424),
    [anon_sym_using] = ACTIONS(2424),
    [anon_sym_static_assert] = ACTIONS(2424),
    [anon_sym_concept] = ACTIONS(2424),
    [anon_sym_co_return] = ACTIONS(2424),
    [anon_sym_co_yield] = ACTIONS(2424),
    [anon_sym_R_DQUOTE] = ACTIONS(2426),
    [anon_sym_LR_DQUOTE] = ACTIONS(2426),
    [anon_sym_uR_DQUOTE] = ACTIONS(2426),
    [anon_sym_UR_DQUOTE] = ACTIONS(2426),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2426),
    [anon_sym_co_await] = ACTIONS(2424),
    [anon_sym_new] = ACTIONS(2424),
    [anon_sym_requires] = ACTIONS(2424),
    [sym_this] = ACTIONS(2424),
    [anon_sym_discard] = ACTIONS(2424),
    [anon_sym_precise] = ACTIONS(2424),
    [anon_sym_shared] = ACTIONS(2424),
    [anon_sym_groupshared] = ACTIONS(2424),
    [anon_sym_uniform] = ACTIONS(2424),
    [anon_sym_row_major] = ACTIONS(2424),
    [anon_sym_column_major] = ACTIONS(2424),
    [anon_sym_globallycoherent] = ACTIONS(2424),
    [anon_sym_centroid] = ACTIONS(2424),
    [anon_sym_noperspective] = ACTIONS(2424),
    [anon_sym_nointerpolation] = ACTIONS(2424),
    [anon_sym_sample] = ACTIONS(2424),
    [anon_sym_linear] = ACTIONS(2424),
    [anon_sym_snorm] = ACTIONS(2424),
    [anon_sym_unorm] = ACTIONS(2424),
    [anon_sym_point] = ACTIONS(2424),
    [anon_sym_line] = ACTIONS(2424),
    [anon_sym_triangleadj] = ACTIONS(2424),
    [anon_sym_lineadj] = ACTIONS(2424),
    [anon_sym_triangle] = ACTIONS(2424),
    [anon_sym_cbuffer] = ACTIONS(2424),
  },
  [286] = {
    [sym_identifier] = ACTIONS(2428),
    [aux_sym_preproc_include_token1] = ACTIONS(2428),
    [aux_sym_preproc_def_token1] = ACTIONS(2428),
    [aux_sym_preproc_if_token1] = ACTIONS(2428),
    [aux_sym_preproc_if_token2] = ACTIONS(2428),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2428),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2428),
    [aux_sym_preproc_else_token1] = ACTIONS(2428),
    [aux_sym_preproc_elif_token1] = ACTIONS(2428),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2428),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2428),
    [sym_preproc_directive] = ACTIONS(2428),
    [anon_sym_LPAREN2] = ACTIONS(2430),
    [anon_sym_BANG] = ACTIONS(2430),
    [anon_sym_TILDE] = ACTIONS(2430),
    [anon_sym_DASH] = ACTIONS(2428),
    [anon_sym_PLUS] = ACTIONS(2428),
    [anon_sym_STAR] = ACTIONS(2430),
    [anon_sym_AMP_AMP] = ACTIONS(2430),
    [anon_sym_AMP] = ACTIONS(2428),
    [anon_sym_SEMI] = ACTIONS(2430),
    [anon_sym___extension__] = ACTIONS(2428),
    [anon_sym_typedef] = ACTIONS(2428),
    [anon_sym_in] = ACTIONS(2428),
    [anon_sym_out] = ACTIONS(2428),
    [anon_sym_inout] = ACTIONS(2428),
    [anon_sym_extern] = ACTIONS(2428),
    [anon_sym___attribute__] = ACTIONS(2428),
    [anon_sym_COLON_COLON] = ACTIONS(2430),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2430),
    [anon_sym___declspec] = ACTIONS(2428),
    [anon_sym___based] = ACTIONS(2428),
    [anon_sym___cdecl] = ACTIONS(2428),
    [anon_sym___clrcall] = ACTIONS(2428),
    [anon_sym___stdcall] = ACTIONS(2428),
    [anon_sym___fastcall] = ACTIONS(2428),
    [anon_sym___thiscall] = ACTIONS(2428),
    [anon_sym___vectorcall] = ACTIONS(2428),
    [anon_sym_LBRACE] = ACTIONS(2430),
    [anon_sym_signed] = ACTIONS(2428),
    [anon_sym_unsigned] = ACTIONS(2428),
    [anon_sym_long] = ACTIONS(2428),
    [anon_sym_short] = ACTIONS(2428),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [anon_sym_static] = ACTIONS(2428),
    [anon_sym_register] = ACTIONS(2428),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym___inline] = ACTIONS(2428),
    [anon_sym___inline__] = ACTIONS(2428),
    [anon_sym___forceinline] = ACTIONS(2428),
    [anon_sym_thread_local] = ACTIONS(2428),
    [anon_sym___thread] = ACTIONS(2428),
    [anon_sym_const] = ACTIONS(2428),
    [anon_sym_constexpr] = ACTIONS(2428),
    [anon_sym_volatile] = ACTIONS(2428),
    [anon_sym_restrict] = ACTIONS(2428),
    [anon_sym___restrict__] = ACTIONS(2428),
    [anon_sym__Atomic] = ACTIONS(2428),
    [anon_sym__Noreturn] = ACTIONS(2428),
    [anon_sym_noreturn] = ACTIONS(2428),
    [anon_sym_mutable] = ACTIONS(2428),
    [anon_sym_constinit] = ACTIONS(2428),
    [anon_sym_consteval] = ACTIONS(2428),
    [anon_sym_alignas] = ACTIONS(2428),
    [anon_sym__Alignas] = ACTIONS(2428),
    [sym_primitive_type] = ACTIONS(2428),
    [anon_sym_enum] = ACTIONS(2428),
    [anon_sym_class] = ACTIONS(2428),
    [anon_sym_struct] = ACTIONS(2428),
    [anon_sym_union] = ACTIONS(2428),
    [anon_sym_if] = ACTIONS(2428),
    [anon_sym_switch] = ACTIONS(2428),
    [anon_sym_case] = ACTIONS(2428),
    [anon_sym_default] = ACTIONS(2428),
    [anon_sym_while] = ACTIONS(2428),
    [anon_sym_do] = ACTIONS(2428),
    [anon_sym_for] = ACTIONS(2428),
    [anon_sym_return] = ACTIONS(2428),
    [anon_sym_break] = ACTIONS(2428),
    [anon_sym_continue] = ACTIONS(2428),
    [anon_sym_goto] = ACTIONS(2428),
    [anon_sym___try] = ACTIONS(2428),
    [anon_sym___leave] = ACTIONS(2428),
    [anon_sym_not] = ACTIONS(2428),
    [anon_sym_compl] = ACTIONS(2428),
    [anon_sym_DASH_DASH] = ACTIONS(2430),
    [anon_sym_PLUS_PLUS] = ACTIONS(2430),
    [anon_sym_sizeof] = ACTIONS(2428),
    [anon_sym___alignof__] = ACTIONS(2428),
    [anon_sym___alignof] = ACTIONS(2428),
    [anon_sym__alignof] = ACTIONS(2428),
    [anon_sym_alignof] = ACTIONS(2428),
    [anon_sym__Alignof] = ACTIONS(2428),
    [anon_sym_offsetof] = ACTIONS(2428),
    [anon_sym__Generic] = ACTIONS(2428),
    [anon_sym_asm] = ACTIONS(2428),
    [anon_sym___asm__] = ACTIONS(2428),
    [sym_number_literal] = ACTIONS(2430),
    [anon_sym_L_SQUOTE] = ACTIONS(2430),
    [anon_sym_u_SQUOTE] = ACTIONS(2430),
    [anon_sym_U_SQUOTE] = ACTIONS(2430),
    [anon_sym_u8_SQUOTE] = ACTIONS(2430),
    [anon_sym_SQUOTE] = ACTIONS(2430),
    [anon_sym_L_DQUOTE] = ACTIONS(2430),
    [anon_sym_u_DQUOTE] = ACTIONS(2430),
    [anon_sym_U_DQUOTE] = ACTIONS(2430),
    [anon_sym_u8_DQUOTE] = ACTIONS(2430),
    [anon_sym_DQUOTE] = ACTIONS(2430),
    [sym_true] = ACTIONS(2428),
    [sym_false] = ACTIONS(2428),
    [anon_sym_NULL] = ACTIONS(2428),
    [anon_sym_nullptr] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2428),
    [anon_sym_decltype] = ACTIONS(2428),
    [sym_virtual] = ACTIONS(2428),
    [anon_sym_explicit] = ACTIONS(2428),
    [anon_sym_typename] = ACTIONS(2428),
    [anon_sym_template] = ACTIONS(2428),
    [anon_sym_operator] = ACTIONS(2428),
    [anon_sym_try] = ACTIONS(2428),
    [anon_sym_delete] = ACTIONS(2428),
    [anon_sym_throw] = ACTIONS(2428),
    [anon_sym_namespace] = ACTIONS(2428),
    [anon_sym_using] = ACTIONS(2428),
    [anon_sym_static_assert] = ACTIONS(2428),
    [anon_sym_concept] = ACTIONS(2428),
    [anon_sym_co_return] = ACTIONS(2428),
    [anon_sym_co_yield] = ACTIONS(2428),
    [anon_sym_R_DQUOTE] = ACTIONS(2430),
    [anon_sym_LR_DQUOTE] = ACTIONS(2430),
    [anon_sym_uR_DQUOTE] = ACTIONS(2430),
    [anon_sym_UR_DQUOTE] = ACTIONS(2430),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2430),
    [anon_sym_co_await] = ACTIONS(2428),
    [anon_sym_new] = ACTIONS(2428),
    [anon_sym_requires] = ACTIONS(2428),
    [sym_this] = ACTIONS(2428),
    [anon_sym_discard] = ACTIONS(2428),
    [anon_sym_precise] = ACTIONS(2428),
    [anon_sym_shared] = ACTIONS(2428),
    [anon_sym_groupshared] = ACTIONS(2428),
    [anon_sym_uniform] = ACTIONS(2428),
    [anon_sym_row_major] = ACTIONS(2428),
    [anon_sym_column_major] = ACTIONS(2428),
    [anon_sym_globallycoherent] = ACTIONS(2428),
    [anon_sym_centroid] = ACTIONS(2428),
    [anon_sym_noperspective] = ACTIONS(2428),
    [anon_sym_nointerpolation] = ACTIONS(2428),
    [anon_sym_sample] = ACTIONS(2428),
    [anon_sym_linear] = ACTIONS(2428),
    [anon_sym_snorm] = ACTIONS(2428),
    [anon_sym_unorm] = ACTIONS(2428),
    [anon_sym_point] = ACTIONS(2428),
    [anon_sym_line] = ACTIONS(2428),
    [anon_sym_triangleadj] = ACTIONS(2428),
    [anon_sym_lineadj] = ACTIONS(2428),
    [anon_sym_triangle] = ACTIONS(2428),
    [anon_sym_cbuffer] = ACTIONS(2428),
  },
  [287] = {
    [sym_identifier] = ACTIONS(2432),
    [aux_sym_preproc_include_token1] = ACTIONS(2432),
    [aux_sym_preproc_def_token1] = ACTIONS(2432),
    [aux_sym_preproc_if_token1] = ACTIONS(2432),
    [aux_sym_preproc_if_token2] = ACTIONS(2432),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2432),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2432),
    [aux_sym_preproc_else_token1] = ACTIONS(2432),
    [aux_sym_preproc_elif_token1] = ACTIONS(2432),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2432),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2432),
    [sym_preproc_directive] = ACTIONS(2432),
    [anon_sym_LPAREN2] = ACTIONS(2434),
    [anon_sym_BANG] = ACTIONS(2434),
    [anon_sym_TILDE] = ACTIONS(2434),
    [anon_sym_DASH] = ACTIONS(2432),
    [anon_sym_PLUS] = ACTIONS(2432),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_AMP_AMP] = ACTIONS(2434),
    [anon_sym_AMP] = ACTIONS(2432),
    [anon_sym_SEMI] = ACTIONS(2434),
    [anon_sym___extension__] = ACTIONS(2432),
    [anon_sym_typedef] = ACTIONS(2432),
    [anon_sym_in] = ACTIONS(2432),
    [anon_sym_out] = ACTIONS(2432),
    [anon_sym_inout] = ACTIONS(2432),
    [anon_sym_extern] = ACTIONS(2432),
    [anon_sym___attribute__] = ACTIONS(2432),
    [anon_sym_COLON_COLON] = ACTIONS(2434),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2434),
    [anon_sym___declspec] = ACTIONS(2432),
    [anon_sym___based] = ACTIONS(2432),
    [anon_sym___cdecl] = ACTIONS(2432),
    [anon_sym___clrcall] = ACTIONS(2432),
    [anon_sym___stdcall] = ACTIONS(2432),
    [anon_sym___fastcall] = ACTIONS(2432),
    [anon_sym___thiscall] = ACTIONS(2432),
    [anon_sym___vectorcall] = ACTIONS(2432),
    [anon_sym_LBRACE] = ACTIONS(2434),
    [anon_sym_signed] = ACTIONS(2432),
    [anon_sym_unsigned] = ACTIONS(2432),
    [anon_sym_long] = ACTIONS(2432),
    [anon_sym_short] = ACTIONS(2432),
    [anon_sym_LBRACK] = ACTIONS(2432),
    [anon_sym_static] = ACTIONS(2432),
    [anon_sym_register] = ACTIONS(2432),
    [anon_sym_inline] = ACTIONS(2432),
    [anon_sym___inline] = ACTIONS(2432),
    [anon_sym___inline__] = ACTIONS(2432),
    [anon_sym___forceinline] = ACTIONS(2432),
    [anon_sym_thread_local] = ACTIONS(2432),
    [anon_sym___thread] = ACTIONS(2432),
    [anon_sym_const] = ACTIONS(2432),
    [anon_sym_constexpr] = ACTIONS(2432),
    [anon_sym_volatile] = ACTIONS(2432),
    [anon_sym_restrict] = ACTIONS(2432),
    [anon_sym___restrict__] = ACTIONS(2432),
    [anon_sym__Atomic] = ACTIONS(2432),
    [anon_sym__Noreturn] = ACTIONS(2432),
    [anon_sym_noreturn] = ACTIONS(2432),
    [anon_sym_mutable] = ACTIONS(2432),
    [anon_sym_constinit] = ACTIONS(2432),
    [anon_sym_consteval] = ACTIONS(2432),
    [anon_sym_alignas] = ACTIONS(2432),
    [anon_sym__Alignas] = ACTIONS(2432),
    [sym_primitive_type] = ACTIONS(2432),
    [anon_sym_enum] = ACTIONS(2432),
    [anon_sym_class] = ACTIONS(2432),
    [anon_sym_struct] = ACTIONS(2432),
    [anon_sym_union] = ACTIONS(2432),
    [anon_sym_if] = ACTIONS(2432),
    [anon_sym_switch] = ACTIONS(2432),
    [anon_sym_case] = ACTIONS(2432),
    [anon_sym_default] = ACTIONS(2432),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_do] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2432),
    [anon_sym_return] = ACTIONS(2432),
    [anon_sym_break] = ACTIONS(2432),
    [anon_sym_continue] = ACTIONS(2432),
    [anon_sym_goto] = ACTIONS(2432),
    [anon_sym___try] = ACTIONS(2432),
    [anon_sym___leave] = ACTIONS(2432),
    [anon_sym_not] = ACTIONS(2432),
    [anon_sym_compl] = ACTIONS(2432),
    [anon_sym_DASH_DASH] = ACTIONS(2434),
    [anon_sym_PLUS_PLUS] = ACTIONS(2434),
    [anon_sym_sizeof] = ACTIONS(2432),
    [anon_sym___alignof__] = ACTIONS(2432),
    [anon_sym___alignof] = ACTIONS(2432),
    [anon_sym__alignof] = ACTIONS(2432),
    [anon_sym_alignof] = ACTIONS(2432),
    [anon_sym__Alignof] = ACTIONS(2432),
    [anon_sym_offsetof] = ACTIONS(2432),
    [anon_sym__Generic] = ACTIONS(2432),
    [anon_sym_asm] = ACTIONS(2432),
    [anon_sym___asm__] = ACTIONS(2432),
    [sym_number_literal] = ACTIONS(2434),
    [anon_sym_L_SQUOTE] = ACTIONS(2434),
    [anon_sym_u_SQUOTE] = ACTIONS(2434),
    [anon_sym_U_SQUOTE] = ACTIONS(2434),
    [anon_sym_u8_SQUOTE] = ACTIONS(2434),
    [anon_sym_SQUOTE] = ACTIONS(2434),
    [anon_sym_L_DQUOTE] = ACTIONS(2434),
    [anon_sym_u_DQUOTE] = ACTIONS(2434),
    [anon_sym_U_DQUOTE] = ACTIONS(2434),
    [anon_sym_u8_DQUOTE] = ACTIONS(2434),
    [anon_sym_DQUOTE] = ACTIONS(2434),
    [sym_true] = ACTIONS(2432),
    [sym_false] = ACTIONS(2432),
    [anon_sym_NULL] = ACTIONS(2432),
    [anon_sym_nullptr] = ACTIONS(2432),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2432),
    [anon_sym_decltype] = ACTIONS(2432),
    [sym_virtual] = ACTIONS(2432),
    [anon_sym_explicit] = ACTIONS(2432),
    [anon_sym_typename] = ACTIONS(2432),
    [anon_sym_template] = ACTIONS(2432),
    [anon_sym_operator] = ACTIONS(2432),
    [anon_sym_try] = ACTIONS(2432),
    [anon_sym_delete] = ACTIONS(2432),
    [anon_sym_throw] = ACTIONS(2432),
    [anon_sym_namespace] = ACTIONS(2432),
    [anon_sym_using] = ACTIONS(2432),
    [anon_sym_static_assert] = ACTIONS(2432),
    [anon_sym_concept] = ACTIONS(2432),
    [anon_sym_co_return] = ACTIONS(2432),
    [anon_sym_co_yield] = ACTIONS(2432),
    [anon_sym_R_DQUOTE] = ACTIONS(2434),
    [anon_sym_LR_DQUOTE] = ACTIONS(2434),
    [anon_sym_uR_DQUOTE] = ACTIONS(2434),
    [anon_sym_UR_DQUOTE] = ACTIONS(2434),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2434),
    [anon_sym_co_await] = ACTIONS(2432),
    [anon_sym_new] = ACTIONS(2432),
    [anon_sym_requires] = ACTIONS(2432),
    [sym_this] = ACTIONS(2432),
    [anon_sym_discard] = ACTIONS(2432),
    [anon_sym_precise] = ACTIONS(2432),
    [anon_sym_shared] = ACTIONS(2432),
    [anon_sym_groupshared] = ACTIONS(2432),
    [anon_sym_uniform] = ACTIONS(2432),
    [anon_sym_row_major] = ACTIONS(2432),
    [anon_sym_column_major] = ACTIONS(2432),
    [anon_sym_globallycoherent] = ACTIONS(2432),
    [anon_sym_centroid] = ACTIONS(2432),
    [anon_sym_noperspective] = ACTIONS(2432),
    [anon_sym_nointerpolation] = ACTIONS(2432),
    [anon_sym_sample] = ACTIONS(2432),
    [anon_sym_linear] = ACTIONS(2432),
    [anon_sym_snorm] = ACTIONS(2432),
    [anon_sym_unorm] = ACTIONS(2432),
    [anon_sym_point] = ACTIONS(2432),
    [anon_sym_line] = ACTIONS(2432),
    [anon_sym_triangleadj] = ACTIONS(2432),
    [anon_sym_lineadj] = ACTIONS(2432),
    [anon_sym_triangle] = ACTIONS(2432),
    [anon_sym_cbuffer] = ACTIONS(2432),
  },
  [288] = {
    [sym_identifier] = ACTIONS(2436),
    [aux_sym_preproc_include_token1] = ACTIONS(2436),
    [aux_sym_preproc_def_token1] = ACTIONS(2436),
    [aux_sym_preproc_if_token1] = ACTIONS(2436),
    [aux_sym_preproc_if_token2] = ACTIONS(2436),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2436),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2436),
    [aux_sym_preproc_else_token1] = ACTIONS(2436),
    [aux_sym_preproc_elif_token1] = ACTIONS(2436),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2436),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2436),
    [sym_preproc_directive] = ACTIONS(2436),
    [anon_sym_LPAREN2] = ACTIONS(2438),
    [anon_sym_BANG] = ACTIONS(2438),
    [anon_sym_TILDE] = ACTIONS(2438),
    [anon_sym_DASH] = ACTIONS(2436),
    [anon_sym_PLUS] = ACTIONS(2436),
    [anon_sym_STAR] = ACTIONS(2438),
    [anon_sym_AMP_AMP] = ACTIONS(2438),
    [anon_sym_AMP] = ACTIONS(2436),
    [anon_sym_SEMI] = ACTIONS(2438),
    [anon_sym___extension__] = ACTIONS(2436),
    [anon_sym_typedef] = ACTIONS(2436),
    [anon_sym_in] = ACTIONS(2436),
    [anon_sym_out] = ACTIONS(2436),
    [anon_sym_inout] = ACTIONS(2436),
    [anon_sym_extern] = ACTIONS(2436),
    [anon_sym___attribute__] = ACTIONS(2436),
    [anon_sym_COLON_COLON] = ACTIONS(2438),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2438),
    [anon_sym___declspec] = ACTIONS(2436),
    [anon_sym___based] = ACTIONS(2436),
    [anon_sym___cdecl] = ACTIONS(2436),
    [anon_sym___clrcall] = ACTIONS(2436),
    [anon_sym___stdcall] = ACTIONS(2436),
    [anon_sym___fastcall] = ACTIONS(2436),
    [anon_sym___thiscall] = ACTIONS(2436),
    [anon_sym___vectorcall] = ACTIONS(2436),
    [anon_sym_LBRACE] = ACTIONS(2438),
    [anon_sym_signed] = ACTIONS(2436),
    [anon_sym_unsigned] = ACTIONS(2436),
    [anon_sym_long] = ACTIONS(2436),
    [anon_sym_short] = ACTIONS(2436),
    [anon_sym_LBRACK] = ACTIONS(2436),
    [anon_sym_static] = ACTIONS(2436),
    [anon_sym_register] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2436),
    [anon_sym___inline] = ACTIONS(2436),
    [anon_sym___inline__] = ACTIONS(2436),
    [anon_sym___forceinline] = ACTIONS(2436),
    [anon_sym_thread_local] = ACTIONS(2436),
    [anon_sym___thread] = ACTIONS(2436),
    [anon_sym_const] = ACTIONS(2436),
    [anon_sym_constexpr] = ACTIONS(2436),
    [anon_sym_volatile] = ACTIONS(2436),
    [anon_sym_restrict] = ACTIONS(2436),
    [anon_sym___restrict__] = ACTIONS(2436),
    [anon_sym__Atomic] = ACTIONS(2436),
    [anon_sym__Noreturn] = ACTIONS(2436),
    [anon_sym_noreturn] = ACTIONS(2436),
    [anon_sym_mutable] = ACTIONS(2436),
    [anon_sym_constinit] = ACTIONS(2436),
    [anon_sym_consteval] = ACTIONS(2436),
    [anon_sym_alignas] = ACTIONS(2436),
    [anon_sym__Alignas] = ACTIONS(2436),
    [sym_primitive_type] = ACTIONS(2436),
    [anon_sym_enum] = ACTIONS(2436),
    [anon_sym_class] = ACTIONS(2436),
    [anon_sym_struct] = ACTIONS(2436),
    [anon_sym_union] = ACTIONS(2436),
    [anon_sym_if] = ACTIONS(2436),
    [anon_sym_switch] = ACTIONS(2436),
    [anon_sym_case] = ACTIONS(2436),
    [anon_sym_default] = ACTIONS(2436),
    [anon_sym_while] = ACTIONS(2436),
    [anon_sym_do] = ACTIONS(2436),
    [anon_sym_for] = ACTIONS(2436),
    [anon_sym_return] = ACTIONS(2436),
    [anon_sym_break] = ACTIONS(2436),
    [anon_sym_continue] = ACTIONS(2436),
    [anon_sym_goto] = ACTIONS(2436),
    [anon_sym___try] = ACTIONS(2436),
    [anon_sym___leave] = ACTIONS(2436),
    [anon_sym_not] = ACTIONS(2436),
    [anon_sym_compl] = ACTIONS(2436),
    [anon_sym_DASH_DASH] = ACTIONS(2438),
    [anon_sym_PLUS_PLUS] = ACTIONS(2438),
    [anon_sym_sizeof] = ACTIONS(2436),
    [anon_sym___alignof__] = ACTIONS(2436),
    [anon_sym___alignof] = ACTIONS(2436),
    [anon_sym__alignof] = ACTIONS(2436),
    [anon_sym_alignof] = ACTIONS(2436),
    [anon_sym__Alignof] = ACTIONS(2436),
    [anon_sym_offsetof] = ACTIONS(2436),
    [anon_sym__Generic] = ACTIONS(2436),
    [anon_sym_asm] = ACTIONS(2436),
    [anon_sym___asm__] = ACTIONS(2436),
    [sym_number_literal] = ACTIONS(2438),
    [anon_sym_L_SQUOTE] = ACTIONS(2438),
    [anon_sym_u_SQUOTE] = ACTIONS(2438),
    [anon_sym_U_SQUOTE] = ACTIONS(2438),
    [anon_sym_u8_SQUOTE] = ACTIONS(2438),
    [anon_sym_SQUOTE] = ACTIONS(2438),
    [anon_sym_L_DQUOTE] = ACTIONS(2438),
    [anon_sym_u_DQUOTE] = ACTIONS(2438),
    [anon_sym_U_DQUOTE] = ACTIONS(2438),
    [anon_sym_u8_DQUOTE] = ACTIONS(2438),
    [anon_sym_DQUOTE] = ACTIONS(2438),
    [sym_true] = ACTIONS(2436),
    [sym_false] = ACTIONS(2436),
    [anon_sym_NULL] = ACTIONS(2436),
    [anon_sym_nullptr] = ACTIONS(2436),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2436),
    [anon_sym_decltype] = ACTIONS(2436),
    [sym_virtual] = ACTIONS(2436),
    [anon_sym_explicit] = ACTIONS(2436),
    [anon_sym_typename] = ACTIONS(2436),
    [anon_sym_template] = ACTIONS(2436),
    [anon_sym_operator] = ACTIONS(2436),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_delete] = ACTIONS(2436),
    [anon_sym_throw] = ACTIONS(2436),
    [anon_sym_namespace] = ACTIONS(2436),
    [anon_sym_using] = ACTIONS(2436),
    [anon_sym_static_assert] = ACTIONS(2436),
    [anon_sym_concept] = ACTIONS(2436),
    [anon_sym_co_return] = ACTIONS(2436),
    [anon_sym_co_yield] = ACTIONS(2436),
    [anon_sym_R_DQUOTE] = ACTIONS(2438),
    [anon_sym_LR_DQUOTE] = ACTIONS(2438),
    [anon_sym_uR_DQUOTE] = ACTIONS(2438),
    [anon_sym_UR_DQUOTE] = ACTIONS(2438),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2438),
    [anon_sym_co_await] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(2436),
    [anon_sym_requires] = ACTIONS(2436),
    [sym_this] = ACTIONS(2436),
    [anon_sym_discard] = ACTIONS(2436),
    [anon_sym_precise] = ACTIONS(2436),
    [anon_sym_shared] = ACTIONS(2436),
    [anon_sym_groupshared] = ACTIONS(2436),
    [anon_sym_uniform] = ACTIONS(2436),
    [anon_sym_row_major] = ACTIONS(2436),
    [anon_sym_column_major] = ACTIONS(2436),
    [anon_sym_globallycoherent] = ACTIONS(2436),
    [anon_sym_centroid] = ACTIONS(2436),
    [anon_sym_noperspective] = ACTIONS(2436),
    [anon_sym_nointerpolation] = ACTIONS(2436),
    [anon_sym_sample] = ACTIONS(2436),
    [anon_sym_linear] = ACTIONS(2436),
    [anon_sym_snorm] = ACTIONS(2436),
    [anon_sym_unorm] = ACTIONS(2436),
    [anon_sym_point] = ACTIONS(2436),
    [anon_sym_line] = ACTIONS(2436),
    [anon_sym_triangleadj] = ACTIONS(2436),
    [anon_sym_lineadj] = ACTIONS(2436),
    [anon_sym_triangle] = ACTIONS(2436),
    [anon_sym_cbuffer] = ACTIONS(2436),
  },
  [289] = {
    [sym_identifier] = ACTIONS(2404),
    [aux_sym_preproc_include_token1] = ACTIONS(2404),
    [aux_sym_preproc_def_token1] = ACTIONS(2404),
    [aux_sym_preproc_if_token1] = ACTIONS(2404),
    [aux_sym_preproc_if_token2] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2404),
    [aux_sym_preproc_else_token1] = ACTIONS(2404),
    [aux_sym_preproc_elif_token1] = ACTIONS(2404),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2404),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2404),
    [sym_preproc_directive] = ACTIONS(2404),
    [anon_sym_LPAREN2] = ACTIONS(2406),
    [anon_sym_BANG] = ACTIONS(2406),
    [anon_sym_TILDE] = ACTIONS(2406),
    [anon_sym_DASH] = ACTIONS(2404),
    [anon_sym_PLUS] = ACTIONS(2404),
    [anon_sym_STAR] = ACTIONS(2406),
    [anon_sym_AMP_AMP] = ACTIONS(2406),
    [anon_sym_AMP] = ACTIONS(2404),
    [anon_sym_SEMI] = ACTIONS(2406),
    [anon_sym___extension__] = ACTIONS(2404),
    [anon_sym_typedef] = ACTIONS(2404),
    [anon_sym_in] = ACTIONS(2404),
    [anon_sym_out] = ACTIONS(2404),
    [anon_sym_inout] = ACTIONS(2404),
    [anon_sym_extern] = ACTIONS(2404),
    [anon_sym___attribute__] = ACTIONS(2404),
    [anon_sym_COLON_COLON] = ACTIONS(2406),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2406),
    [anon_sym___declspec] = ACTIONS(2404),
    [anon_sym___based] = ACTIONS(2404),
    [anon_sym___cdecl] = ACTIONS(2404),
    [anon_sym___clrcall] = ACTIONS(2404),
    [anon_sym___stdcall] = ACTIONS(2404),
    [anon_sym___fastcall] = ACTIONS(2404),
    [anon_sym___thiscall] = ACTIONS(2404),
    [anon_sym___vectorcall] = ACTIONS(2404),
    [anon_sym_LBRACE] = ACTIONS(2406),
    [anon_sym_signed] = ACTIONS(2404),
    [anon_sym_unsigned] = ACTIONS(2404),
    [anon_sym_long] = ACTIONS(2404),
    [anon_sym_short] = ACTIONS(2404),
    [anon_sym_LBRACK] = ACTIONS(2404),
    [anon_sym_static] = ACTIONS(2404),
    [anon_sym_register] = ACTIONS(2404),
    [anon_sym_inline] = ACTIONS(2404),
    [anon_sym___inline] = ACTIONS(2404),
    [anon_sym___inline__] = ACTIONS(2404),
    [anon_sym___forceinline] = ACTIONS(2404),
    [anon_sym_thread_local] = ACTIONS(2404),
    [anon_sym___thread] = ACTIONS(2404),
    [anon_sym_const] = ACTIONS(2404),
    [anon_sym_constexpr] = ACTIONS(2404),
    [anon_sym_volatile] = ACTIONS(2404),
    [anon_sym_restrict] = ACTIONS(2404),
    [anon_sym___restrict__] = ACTIONS(2404),
    [anon_sym__Atomic] = ACTIONS(2404),
    [anon_sym__Noreturn] = ACTIONS(2404),
    [anon_sym_noreturn] = ACTIONS(2404),
    [anon_sym_mutable] = ACTIONS(2404),
    [anon_sym_constinit] = ACTIONS(2404),
    [anon_sym_consteval] = ACTIONS(2404),
    [anon_sym_alignas] = ACTIONS(2404),
    [anon_sym__Alignas] = ACTIONS(2404),
    [sym_primitive_type] = ACTIONS(2404),
    [anon_sym_enum] = ACTIONS(2404),
    [anon_sym_class] = ACTIONS(2404),
    [anon_sym_struct] = ACTIONS(2404),
    [anon_sym_union] = ACTIONS(2404),
    [anon_sym_if] = ACTIONS(2404),
    [anon_sym_switch] = ACTIONS(2404),
    [anon_sym_case] = ACTIONS(2404),
    [anon_sym_default] = ACTIONS(2404),
    [anon_sym_while] = ACTIONS(2404),
    [anon_sym_do] = ACTIONS(2404),
    [anon_sym_for] = ACTIONS(2404),
    [anon_sym_return] = ACTIONS(2404),
    [anon_sym_break] = ACTIONS(2404),
    [anon_sym_continue] = ACTIONS(2404),
    [anon_sym_goto] = ACTIONS(2404),
    [anon_sym___try] = ACTIONS(2404),
    [anon_sym___leave] = ACTIONS(2404),
    [anon_sym_not] = ACTIONS(2404),
    [anon_sym_compl] = ACTIONS(2404),
    [anon_sym_DASH_DASH] = ACTIONS(2406),
    [anon_sym_PLUS_PLUS] = ACTIONS(2406),
    [anon_sym_sizeof] = ACTIONS(2404),
    [anon_sym___alignof__] = ACTIONS(2404),
    [anon_sym___alignof] = ACTIONS(2404),
    [anon_sym__alignof] = ACTIONS(2404),
    [anon_sym_alignof] = ACTIONS(2404),
    [anon_sym__Alignof] = ACTIONS(2404),
    [anon_sym_offsetof] = ACTIONS(2404),
    [anon_sym__Generic] = ACTIONS(2404),
    [anon_sym_asm] = ACTIONS(2404),
    [anon_sym___asm__] = ACTIONS(2404),
    [sym_number_literal] = ACTIONS(2406),
    [anon_sym_L_SQUOTE] = ACTIONS(2406),
    [anon_sym_u_SQUOTE] = ACTIONS(2406),
    [anon_sym_U_SQUOTE] = ACTIONS(2406),
    [anon_sym_u8_SQUOTE] = ACTIONS(2406),
    [anon_sym_SQUOTE] = ACTIONS(2406),
    [anon_sym_L_DQUOTE] = ACTIONS(2406),
    [anon_sym_u_DQUOTE] = ACTIONS(2406),
    [anon_sym_U_DQUOTE] = ACTIONS(2406),
    [anon_sym_u8_DQUOTE] = ACTIONS(2406),
    [anon_sym_DQUOTE] = ACTIONS(2406),
    [sym_true] = ACTIONS(2404),
    [sym_false] = ACTIONS(2404),
    [anon_sym_NULL] = ACTIONS(2404),
    [anon_sym_nullptr] = ACTIONS(2404),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2404),
    [anon_sym_decltype] = ACTIONS(2404),
    [sym_virtual] = ACTIONS(2404),
    [anon_sym_explicit] = ACTIONS(2404),
    [anon_sym_typename] = ACTIONS(2404),
    [anon_sym_template] = ACTIONS(2404),
    [anon_sym_operator] = ACTIONS(2404),
    [anon_sym_try] = ACTIONS(2404),
    [anon_sym_delete] = ACTIONS(2404),
    [anon_sym_throw] = ACTIONS(2404),
    [anon_sym_namespace] = ACTIONS(2404),
    [anon_sym_using] = ACTIONS(2404),
    [anon_sym_static_assert] = ACTIONS(2404),
    [anon_sym_concept] = ACTIONS(2404),
    [anon_sym_co_return] = ACTIONS(2404),
    [anon_sym_co_yield] = ACTIONS(2404),
    [anon_sym_R_DQUOTE] = ACTIONS(2406),
    [anon_sym_LR_DQUOTE] = ACTIONS(2406),
    [anon_sym_uR_DQUOTE] = ACTIONS(2406),
    [anon_sym_UR_DQUOTE] = ACTIONS(2406),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2406),
    [anon_sym_co_await] = ACTIONS(2404),
    [anon_sym_new] = ACTIONS(2404),
    [anon_sym_requires] = ACTIONS(2404),
    [sym_this] = ACTIONS(2404),
    [anon_sym_discard] = ACTIONS(2404),
    [anon_sym_precise] = ACTIONS(2404),
    [anon_sym_shared] = ACTIONS(2404),
    [anon_sym_groupshared] = ACTIONS(2404),
    [anon_sym_uniform] = ACTIONS(2404),
    [anon_sym_row_major] = ACTIONS(2404),
    [anon_sym_column_major] = ACTIONS(2404),
    [anon_sym_globallycoherent] = ACTIONS(2404),
    [anon_sym_centroid] = ACTIONS(2404),
    [anon_sym_noperspective] = ACTIONS(2404),
    [anon_sym_nointerpolation] = ACTIONS(2404),
    [anon_sym_sample] = ACTIONS(2404),
    [anon_sym_linear] = ACTIONS(2404),
    [anon_sym_snorm] = ACTIONS(2404),
    [anon_sym_unorm] = ACTIONS(2404),
    [anon_sym_point] = ACTIONS(2404),
    [anon_sym_line] = ACTIONS(2404),
    [anon_sym_triangleadj] = ACTIONS(2404),
    [anon_sym_lineadj] = ACTIONS(2404),
    [anon_sym_triangle] = ACTIONS(2404),
    [anon_sym_cbuffer] = ACTIONS(2404),
  },
  [290] = {
    [sym_identifier] = ACTIONS(2440),
    [aux_sym_preproc_include_token1] = ACTIONS(2440),
    [aux_sym_preproc_def_token1] = ACTIONS(2440),
    [aux_sym_preproc_if_token1] = ACTIONS(2440),
    [aux_sym_preproc_if_token2] = ACTIONS(2440),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2440),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2440),
    [aux_sym_preproc_else_token1] = ACTIONS(2440),
    [aux_sym_preproc_elif_token1] = ACTIONS(2440),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2440),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2440),
    [sym_preproc_directive] = ACTIONS(2440),
    [anon_sym_LPAREN2] = ACTIONS(2442),
    [anon_sym_BANG] = ACTIONS(2442),
    [anon_sym_TILDE] = ACTIONS(2442),
    [anon_sym_DASH] = ACTIONS(2440),
    [anon_sym_PLUS] = ACTIONS(2440),
    [anon_sym_STAR] = ACTIONS(2442),
    [anon_sym_AMP_AMP] = ACTIONS(2442),
    [anon_sym_AMP] = ACTIONS(2440),
    [anon_sym_SEMI] = ACTIONS(2442),
    [anon_sym___extension__] = ACTIONS(2440),
    [anon_sym_typedef] = ACTIONS(2440),
    [anon_sym_in] = ACTIONS(2440),
    [anon_sym_out] = ACTIONS(2440),
    [anon_sym_inout] = ACTIONS(2440),
    [anon_sym_extern] = ACTIONS(2440),
    [anon_sym___attribute__] = ACTIONS(2440),
    [anon_sym_COLON_COLON] = ACTIONS(2442),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2442),
    [anon_sym___declspec] = ACTIONS(2440),
    [anon_sym___based] = ACTIONS(2440),
    [anon_sym___cdecl] = ACTIONS(2440),
    [anon_sym___clrcall] = ACTIONS(2440),
    [anon_sym___stdcall] = ACTIONS(2440),
    [anon_sym___fastcall] = ACTIONS(2440),
    [anon_sym___thiscall] = ACTIONS(2440),
    [anon_sym___vectorcall] = ACTIONS(2440),
    [anon_sym_LBRACE] = ACTIONS(2442),
    [anon_sym_signed] = ACTIONS(2440),
    [anon_sym_unsigned] = ACTIONS(2440),
    [anon_sym_long] = ACTIONS(2440),
    [anon_sym_short] = ACTIONS(2440),
    [anon_sym_LBRACK] = ACTIONS(2440),
    [anon_sym_static] = ACTIONS(2440),
    [anon_sym_register] = ACTIONS(2440),
    [anon_sym_inline] = ACTIONS(2440),
    [anon_sym___inline] = ACTIONS(2440),
    [anon_sym___inline__] = ACTIONS(2440),
    [anon_sym___forceinline] = ACTIONS(2440),
    [anon_sym_thread_local] = ACTIONS(2440),
    [anon_sym___thread] = ACTIONS(2440),
    [anon_sym_const] = ACTIONS(2440),
    [anon_sym_constexpr] = ACTIONS(2440),
    [anon_sym_volatile] = ACTIONS(2440),
    [anon_sym_restrict] = ACTIONS(2440),
    [anon_sym___restrict__] = ACTIONS(2440),
    [anon_sym__Atomic] = ACTIONS(2440),
    [anon_sym__Noreturn] = ACTIONS(2440),
    [anon_sym_noreturn] = ACTIONS(2440),
    [anon_sym_mutable] = ACTIONS(2440),
    [anon_sym_constinit] = ACTIONS(2440),
    [anon_sym_consteval] = ACTIONS(2440),
    [anon_sym_alignas] = ACTIONS(2440),
    [anon_sym__Alignas] = ACTIONS(2440),
    [sym_primitive_type] = ACTIONS(2440),
    [anon_sym_enum] = ACTIONS(2440),
    [anon_sym_class] = ACTIONS(2440),
    [anon_sym_struct] = ACTIONS(2440),
    [anon_sym_union] = ACTIONS(2440),
    [anon_sym_if] = ACTIONS(2440),
    [anon_sym_switch] = ACTIONS(2440),
    [anon_sym_case] = ACTIONS(2440),
    [anon_sym_default] = ACTIONS(2440),
    [anon_sym_while] = ACTIONS(2440),
    [anon_sym_do] = ACTIONS(2440),
    [anon_sym_for] = ACTIONS(2440),
    [anon_sym_return] = ACTIONS(2440),
    [anon_sym_break] = ACTIONS(2440),
    [anon_sym_continue] = ACTIONS(2440),
    [anon_sym_goto] = ACTIONS(2440),
    [anon_sym___try] = ACTIONS(2440),
    [anon_sym___leave] = ACTIONS(2440),
    [anon_sym_not] = ACTIONS(2440),
    [anon_sym_compl] = ACTIONS(2440),
    [anon_sym_DASH_DASH] = ACTIONS(2442),
    [anon_sym_PLUS_PLUS] = ACTIONS(2442),
    [anon_sym_sizeof] = ACTIONS(2440),
    [anon_sym___alignof__] = ACTIONS(2440),
    [anon_sym___alignof] = ACTIONS(2440),
    [anon_sym__alignof] = ACTIONS(2440),
    [anon_sym_alignof] = ACTIONS(2440),
    [anon_sym__Alignof] = ACTIONS(2440),
    [anon_sym_offsetof] = ACTIONS(2440),
    [anon_sym__Generic] = ACTIONS(2440),
    [anon_sym_asm] = ACTIONS(2440),
    [anon_sym___asm__] = ACTIONS(2440),
    [sym_number_literal] = ACTIONS(2442),
    [anon_sym_L_SQUOTE] = ACTIONS(2442),
    [anon_sym_u_SQUOTE] = ACTIONS(2442),
    [anon_sym_U_SQUOTE] = ACTIONS(2442),
    [anon_sym_u8_SQUOTE] = ACTIONS(2442),
    [anon_sym_SQUOTE] = ACTIONS(2442),
    [anon_sym_L_DQUOTE] = ACTIONS(2442),
    [anon_sym_u_DQUOTE] = ACTIONS(2442),
    [anon_sym_U_DQUOTE] = ACTIONS(2442),
    [anon_sym_u8_DQUOTE] = ACTIONS(2442),
    [anon_sym_DQUOTE] = ACTIONS(2442),
    [sym_true] = ACTIONS(2440),
    [sym_false] = ACTIONS(2440),
    [anon_sym_NULL] = ACTIONS(2440),
    [anon_sym_nullptr] = ACTIONS(2440),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2440),
    [anon_sym_decltype] = ACTIONS(2440),
    [sym_virtual] = ACTIONS(2440),
    [anon_sym_explicit] = ACTIONS(2440),
    [anon_sym_typename] = ACTIONS(2440),
    [anon_sym_template] = ACTIONS(2440),
    [anon_sym_operator] = ACTIONS(2440),
    [anon_sym_try] = ACTIONS(2440),
    [anon_sym_delete] = ACTIONS(2440),
    [anon_sym_throw] = ACTIONS(2440),
    [anon_sym_namespace] = ACTIONS(2440),
    [anon_sym_using] = ACTIONS(2440),
    [anon_sym_static_assert] = ACTIONS(2440),
    [anon_sym_concept] = ACTIONS(2440),
    [anon_sym_co_return] = ACTIONS(2440),
    [anon_sym_co_yield] = ACTIONS(2440),
    [anon_sym_R_DQUOTE] = ACTIONS(2442),
    [anon_sym_LR_DQUOTE] = ACTIONS(2442),
    [anon_sym_uR_DQUOTE] = ACTIONS(2442),
    [anon_sym_UR_DQUOTE] = ACTIONS(2442),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2442),
    [anon_sym_co_await] = ACTIONS(2440),
    [anon_sym_new] = ACTIONS(2440),
    [anon_sym_requires] = ACTIONS(2440),
    [sym_this] = ACTIONS(2440),
    [anon_sym_discard] = ACTIONS(2440),
    [anon_sym_precise] = ACTIONS(2440),
    [anon_sym_shared] = ACTIONS(2440),
    [anon_sym_groupshared] = ACTIONS(2440),
    [anon_sym_uniform] = ACTIONS(2440),
    [anon_sym_row_major] = ACTIONS(2440),
    [anon_sym_column_major] = ACTIONS(2440),
    [anon_sym_globallycoherent] = ACTIONS(2440),
    [anon_sym_centroid] = ACTIONS(2440),
    [anon_sym_noperspective] = ACTIONS(2440),
    [anon_sym_nointerpolation] = ACTIONS(2440),
    [anon_sym_sample] = ACTIONS(2440),
    [anon_sym_linear] = ACTIONS(2440),
    [anon_sym_snorm] = ACTIONS(2440),
    [anon_sym_unorm] = ACTIONS(2440),
    [anon_sym_point] = ACTIONS(2440),
    [anon_sym_line] = ACTIONS(2440),
    [anon_sym_triangleadj] = ACTIONS(2440),
    [anon_sym_lineadj] = ACTIONS(2440),
    [anon_sym_triangle] = ACTIONS(2440),
    [anon_sym_cbuffer] = ACTIONS(2440),
  },
  [291] = {
    [sym_identifier] = ACTIONS(2444),
    [aux_sym_preproc_include_token1] = ACTIONS(2444),
    [aux_sym_preproc_def_token1] = ACTIONS(2444),
    [aux_sym_preproc_if_token1] = ACTIONS(2444),
    [aux_sym_preproc_if_token2] = ACTIONS(2444),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2444),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2444),
    [aux_sym_preproc_else_token1] = ACTIONS(2444),
    [aux_sym_preproc_elif_token1] = ACTIONS(2444),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2444),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2444),
    [sym_preproc_directive] = ACTIONS(2444),
    [anon_sym_LPAREN2] = ACTIONS(2446),
    [anon_sym_BANG] = ACTIONS(2446),
    [anon_sym_TILDE] = ACTIONS(2446),
    [anon_sym_DASH] = ACTIONS(2444),
    [anon_sym_PLUS] = ACTIONS(2444),
    [anon_sym_STAR] = ACTIONS(2446),
    [anon_sym_AMP_AMP] = ACTIONS(2446),
    [anon_sym_AMP] = ACTIONS(2444),
    [anon_sym_SEMI] = ACTIONS(2446),
    [anon_sym___extension__] = ACTIONS(2444),
    [anon_sym_typedef] = ACTIONS(2444),
    [anon_sym_in] = ACTIONS(2444),
    [anon_sym_out] = ACTIONS(2444),
    [anon_sym_inout] = ACTIONS(2444),
    [anon_sym_extern] = ACTIONS(2444),
    [anon_sym___attribute__] = ACTIONS(2444),
    [anon_sym_COLON_COLON] = ACTIONS(2446),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2446),
    [anon_sym___declspec] = ACTIONS(2444),
    [anon_sym___based] = ACTIONS(2444),
    [anon_sym___cdecl] = ACTIONS(2444),
    [anon_sym___clrcall] = ACTIONS(2444),
    [anon_sym___stdcall] = ACTIONS(2444),
    [anon_sym___fastcall] = ACTIONS(2444),
    [anon_sym___thiscall] = ACTIONS(2444),
    [anon_sym___vectorcall] = ACTIONS(2444),
    [anon_sym_LBRACE] = ACTIONS(2446),
    [anon_sym_signed] = ACTIONS(2444),
    [anon_sym_unsigned] = ACTIONS(2444),
    [anon_sym_long] = ACTIONS(2444),
    [anon_sym_short] = ACTIONS(2444),
    [anon_sym_LBRACK] = ACTIONS(2444),
    [anon_sym_static] = ACTIONS(2444),
    [anon_sym_register] = ACTIONS(2444),
    [anon_sym_inline] = ACTIONS(2444),
    [anon_sym___inline] = ACTIONS(2444),
    [anon_sym___inline__] = ACTIONS(2444),
    [anon_sym___forceinline] = ACTIONS(2444),
    [anon_sym_thread_local] = ACTIONS(2444),
    [anon_sym___thread] = ACTIONS(2444),
    [anon_sym_const] = ACTIONS(2444),
    [anon_sym_constexpr] = ACTIONS(2444),
    [anon_sym_volatile] = ACTIONS(2444),
    [anon_sym_restrict] = ACTIONS(2444),
    [anon_sym___restrict__] = ACTIONS(2444),
    [anon_sym__Atomic] = ACTIONS(2444),
    [anon_sym__Noreturn] = ACTIONS(2444),
    [anon_sym_noreturn] = ACTIONS(2444),
    [anon_sym_mutable] = ACTIONS(2444),
    [anon_sym_constinit] = ACTIONS(2444),
    [anon_sym_consteval] = ACTIONS(2444),
    [anon_sym_alignas] = ACTIONS(2444),
    [anon_sym__Alignas] = ACTIONS(2444),
    [sym_primitive_type] = ACTIONS(2444),
    [anon_sym_enum] = ACTIONS(2444),
    [anon_sym_class] = ACTIONS(2444),
    [anon_sym_struct] = ACTIONS(2444),
    [anon_sym_union] = ACTIONS(2444),
    [anon_sym_if] = ACTIONS(2444),
    [anon_sym_switch] = ACTIONS(2444),
    [anon_sym_case] = ACTIONS(2444),
    [anon_sym_default] = ACTIONS(2444),
    [anon_sym_while] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(2444),
    [anon_sym_for] = ACTIONS(2444),
    [anon_sym_return] = ACTIONS(2444),
    [anon_sym_break] = ACTIONS(2444),
    [anon_sym_continue] = ACTIONS(2444),
    [anon_sym_goto] = ACTIONS(2444),
    [anon_sym___try] = ACTIONS(2444),
    [anon_sym___leave] = ACTIONS(2444),
    [anon_sym_not] = ACTIONS(2444),
    [anon_sym_compl] = ACTIONS(2444),
    [anon_sym_DASH_DASH] = ACTIONS(2446),
    [anon_sym_PLUS_PLUS] = ACTIONS(2446),
    [anon_sym_sizeof] = ACTIONS(2444),
    [anon_sym___alignof__] = ACTIONS(2444),
    [anon_sym___alignof] = ACTIONS(2444),
    [anon_sym__alignof] = ACTIONS(2444),
    [anon_sym_alignof] = ACTIONS(2444),
    [anon_sym__Alignof] = ACTIONS(2444),
    [anon_sym_offsetof] = ACTIONS(2444),
    [anon_sym__Generic] = ACTIONS(2444),
    [anon_sym_asm] = ACTIONS(2444),
    [anon_sym___asm__] = ACTIONS(2444),
    [sym_number_literal] = ACTIONS(2446),
    [anon_sym_L_SQUOTE] = ACTIONS(2446),
    [anon_sym_u_SQUOTE] = ACTIONS(2446),
    [anon_sym_U_SQUOTE] = ACTIONS(2446),
    [anon_sym_u8_SQUOTE] = ACTIONS(2446),
    [anon_sym_SQUOTE] = ACTIONS(2446),
    [anon_sym_L_DQUOTE] = ACTIONS(2446),
    [anon_sym_u_DQUOTE] = ACTIONS(2446),
    [anon_sym_U_DQUOTE] = ACTIONS(2446),
    [anon_sym_u8_DQUOTE] = ACTIONS(2446),
    [anon_sym_DQUOTE] = ACTIONS(2446),
    [sym_true] = ACTIONS(2444),
    [sym_false] = ACTIONS(2444),
    [anon_sym_NULL] = ACTIONS(2444),
    [anon_sym_nullptr] = ACTIONS(2444),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2444),
    [anon_sym_decltype] = ACTIONS(2444),
    [sym_virtual] = ACTIONS(2444),
    [anon_sym_explicit] = ACTIONS(2444),
    [anon_sym_typename] = ACTIONS(2444),
    [anon_sym_template] = ACTIONS(2444),
    [anon_sym_operator] = ACTIONS(2444),
    [anon_sym_try] = ACTIONS(2444),
    [anon_sym_delete] = ACTIONS(2444),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_namespace] = ACTIONS(2444),
    [anon_sym_using] = ACTIONS(2444),
    [anon_sym_static_assert] = ACTIONS(2444),
    [anon_sym_concept] = ACTIONS(2444),
    [anon_sym_co_return] = ACTIONS(2444),
    [anon_sym_co_yield] = ACTIONS(2444),
    [anon_sym_R_DQUOTE] = ACTIONS(2446),
    [anon_sym_LR_DQUOTE] = ACTIONS(2446),
    [anon_sym_uR_DQUOTE] = ACTIONS(2446),
    [anon_sym_UR_DQUOTE] = ACTIONS(2446),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2446),
    [anon_sym_co_await] = ACTIONS(2444),
    [anon_sym_new] = ACTIONS(2444),
    [anon_sym_requires] = ACTIONS(2444),
    [sym_this] = ACTIONS(2444),
    [anon_sym_discard] = ACTIONS(2444),
    [anon_sym_precise] = ACTIONS(2444),
    [anon_sym_shared] = ACTIONS(2444),
    [anon_sym_groupshared] = ACTIONS(2444),
    [anon_sym_uniform] = ACTIONS(2444),
    [anon_sym_row_major] = ACTIONS(2444),
    [anon_sym_column_major] = ACTIONS(2444),
    [anon_sym_globallycoherent] = ACTIONS(2444),
    [anon_sym_centroid] = ACTIONS(2444),
    [anon_sym_noperspective] = ACTIONS(2444),
    [anon_sym_nointerpolation] = ACTIONS(2444),
    [anon_sym_sample] = ACTIONS(2444),
    [anon_sym_linear] = ACTIONS(2444),
    [anon_sym_snorm] = ACTIONS(2444),
    [anon_sym_unorm] = ACTIONS(2444),
    [anon_sym_point] = ACTIONS(2444),
    [anon_sym_line] = ACTIONS(2444),
    [anon_sym_triangleadj] = ACTIONS(2444),
    [anon_sym_lineadj] = ACTIONS(2444),
    [anon_sym_triangle] = ACTIONS(2444),
    [anon_sym_cbuffer] = ACTIONS(2444),
  },
  [292] = {
    [sym_identifier] = ACTIONS(2448),
    [aux_sym_preproc_include_token1] = ACTIONS(2448),
    [aux_sym_preproc_def_token1] = ACTIONS(2448),
    [aux_sym_preproc_if_token1] = ACTIONS(2448),
    [aux_sym_preproc_if_token2] = ACTIONS(2448),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2448),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2448),
    [aux_sym_preproc_else_token1] = ACTIONS(2448),
    [aux_sym_preproc_elif_token1] = ACTIONS(2448),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2448),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2448),
    [sym_preproc_directive] = ACTIONS(2448),
    [anon_sym_LPAREN2] = ACTIONS(2450),
    [anon_sym_BANG] = ACTIONS(2450),
    [anon_sym_TILDE] = ACTIONS(2450),
    [anon_sym_DASH] = ACTIONS(2448),
    [anon_sym_PLUS] = ACTIONS(2448),
    [anon_sym_STAR] = ACTIONS(2450),
    [anon_sym_AMP_AMP] = ACTIONS(2450),
    [anon_sym_AMP] = ACTIONS(2448),
    [anon_sym_SEMI] = ACTIONS(2450),
    [anon_sym___extension__] = ACTIONS(2448),
    [anon_sym_typedef] = ACTIONS(2448),
    [anon_sym_in] = ACTIONS(2448),
    [anon_sym_out] = ACTIONS(2448),
    [anon_sym_inout] = ACTIONS(2448),
    [anon_sym_extern] = ACTIONS(2448),
    [anon_sym___attribute__] = ACTIONS(2448),
    [anon_sym_COLON_COLON] = ACTIONS(2450),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2450),
    [anon_sym___declspec] = ACTIONS(2448),
    [anon_sym___based] = ACTIONS(2448),
    [anon_sym___cdecl] = ACTIONS(2448),
    [anon_sym___clrcall] = ACTIONS(2448),
    [anon_sym___stdcall] = ACTIONS(2448),
    [anon_sym___fastcall] = ACTIONS(2448),
    [anon_sym___thiscall] = ACTIONS(2448),
    [anon_sym___vectorcall] = ACTIONS(2448),
    [anon_sym_LBRACE] = ACTIONS(2450),
    [anon_sym_signed] = ACTIONS(2448),
    [anon_sym_unsigned] = ACTIONS(2448),
    [anon_sym_long] = ACTIONS(2448),
    [anon_sym_short] = ACTIONS(2448),
    [anon_sym_LBRACK] = ACTIONS(2448),
    [anon_sym_static] = ACTIONS(2448),
    [anon_sym_register] = ACTIONS(2448),
    [anon_sym_inline] = ACTIONS(2448),
    [anon_sym___inline] = ACTIONS(2448),
    [anon_sym___inline__] = ACTIONS(2448),
    [anon_sym___forceinline] = ACTIONS(2448),
    [anon_sym_thread_local] = ACTIONS(2448),
    [anon_sym___thread] = ACTIONS(2448),
    [anon_sym_const] = ACTIONS(2448),
    [anon_sym_constexpr] = ACTIONS(2448),
    [anon_sym_volatile] = ACTIONS(2448),
    [anon_sym_restrict] = ACTIONS(2448),
    [anon_sym___restrict__] = ACTIONS(2448),
    [anon_sym__Atomic] = ACTIONS(2448),
    [anon_sym__Noreturn] = ACTIONS(2448),
    [anon_sym_noreturn] = ACTIONS(2448),
    [anon_sym_mutable] = ACTIONS(2448),
    [anon_sym_constinit] = ACTIONS(2448),
    [anon_sym_consteval] = ACTIONS(2448),
    [anon_sym_alignas] = ACTIONS(2448),
    [anon_sym__Alignas] = ACTIONS(2448),
    [sym_primitive_type] = ACTIONS(2448),
    [anon_sym_enum] = ACTIONS(2448),
    [anon_sym_class] = ACTIONS(2448),
    [anon_sym_struct] = ACTIONS(2448),
    [anon_sym_union] = ACTIONS(2448),
    [anon_sym_if] = ACTIONS(2448),
    [anon_sym_switch] = ACTIONS(2448),
    [anon_sym_case] = ACTIONS(2448),
    [anon_sym_default] = ACTIONS(2448),
    [anon_sym_while] = ACTIONS(2448),
    [anon_sym_do] = ACTIONS(2448),
    [anon_sym_for] = ACTIONS(2448),
    [anon_sym_return] = ACTIONS(2448),
    [anon_sym_break] = ACTIONS(2448),
    [anon_sym_continue] = ACTIONS(2448),
    [anon_sym_goto] = ACTIONS(2448),
    [anon_sym___try] = ACTIONS(2448),
    [anon_sym___leave] = ACTIONS(2448),
    [anon_sym_not] = ACTIONS(2448),
    [anon_sym_compl] = ACTIONS(2448),
    [anon_sym_DASH_DASH] = ACTIONS(2450),
    [anon_sym_PLUS_PLUS] = ACTIONS(2450),
    [anon_sym_sizeof] = ACTIONS(2448),
    [anon_sym___alignof__] = ACTIONS(2448),
    [anon_sym___alignof] = ACTIONS(2448),
    [anon_sym__alignof] = ACTIONS(2448),
    [anon_sym_alignof] = ACTIONS(2448),
    [anon_sym__Alignof] = ACTIONS(2448),
    [anon_sym_offsetof] = ACTIONS(2448),
    [anon_sym__Generic] = ACTIONS(2448),
    [anon_sym_asm] = ACTIONS(2448),
    [anon_sym___asm__] = ACTIONS(2448),
    [sym_number_literal] = ACTIONS(2450),
    [anon_sym_L_SQUOTE] = ACTIONS(2450),
    [anon_sym_u_SQUOTE] = ACTIONS(2450),
    [anon_sym_U_SQUOTE] = ACTIONS(2450),
    [anon_sym_u8_SQUOTE] = ACTIONS(2450),
    [anon_sym_SQUOTE] = ACTIONS(2450),
    [anon_sym_L_DQUOTE] = ACTIONS(2450),
    [anon_sym_u_DQUOTE] = ACTIONS(2450),
    [anon_sym_U_DQUOTE] = ACTIONS(2450),
    [anon_sym_u8_DQUOTE] = ACTIONS(2450),
    [anon_sym_DQUOTE] = ACTIONS(2450),
    [sym_true] = ACTIONS(2448),
    [sym_false] = ACTIONS(2448),
    [anon_sym_NULL] = ACTIONS(2448),
    [anon_sym_nullptr] = ACTIONS(2448),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2448),
    [anon_sym_decltype] = ACTIONS(2448),
    [sym_virtual] = ACTIONS(2448),
    [anon_sym_explicit] = ACTIONS(2448),
    [anon_sym_typename] = ACTIONS(2448),
    [anon_sym_template] = ACTIONS(2448),
    [anon_sym_operator] = ACTIONS(2448),
    [anon_sym_try] = ACTIONS(2448),
    [anon_sym_delete] = ACTIONS(2448),
    [anon_sym_throw] = ACTIONS(2448),
    [anon_sym_namespace] = ACTIONS(2448),
    [anon_sym_using] = ACTIONS(2448),
    [anon_sym_static_assert] = ACTIONS(2448),
    [anon_sym_concept] = ACTIONS(2448),
    [anon_sym_co_return] = ACTIONS(2448),
    [anon_sym_co_yield] = ACTIONS(2448),
    [anon_sym_R_DQUOTE] = ACTIONS(2450),
    [anon_sym_LR_DQUOTE] = ACTIONS(2450),
    [anon_sym_uR_DQUOTE] = ACTIONS(2450),
    [anon_sym_UR_DQUOTE] = ACTIONS(2450),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2450),
    [anon_sym_co_await] = ACTIONS(2448),
    [anon_sym_new] = ACTIONS(2448),
    [anon_sym_requires] = ACTIONS(2448),
    [sym_this] = ACTIONS(2448),
    [anon_sym_discard] = ACTIONS(2448),
    [anon_sym_precise] = ACTIONS(2448),
    [anon_sym_shared] = ACTIONS(2448),
    [anon_sym_groupshared] = ACTIONS(2448),
    [anon_sym_uniform] = ACTIONS(2448),
    [anon_sym_row_major] = ACTIONS(2448),
    [anon_sym_column_major] = ACTIONS(2448),
    [anon_sym_globallycoherent] = ACTIONS(2448),
    [anon_sym_centroid] = ACTIONS(2448),
    [anon_sym_noperspective] = ACTIONS(2448),
    [anon_sym_nointerpolation] = ACTIONS(2448),
    [anon_sym_sample] = ACTIONS(2448),
    [anon_sym_linear] = ACTIONS(2448),
    [anon_sym_snorm] = ACTIONS(2448),
    [anon_sym_unorm] = ACTIONS(2448),
    [anon_sym_point] = ACTIONS(2448),
    [anon_sym_line] = ACTIONS(2448),
    [anon_sym_triangleadj] = ACTIONS(2448),
    [anon_sym_lineadj] = ACTIONS(2448),
    [anon_sym_triangle] = ACTIONS(2448),
    [anon_sym_cbuffer] = ACTIONS(2448),
  },
  [293] = {
    [sym_identifier] = ACTIONS(1959),
    [aux_sym_preproc_include_token1] = ACTIONS(1959),
    [aux_sym_preproc_def_token1] = ACTIONS(1959),
    [aux_sym_preproc_if_token1] = ACTIONS(1959),
    [aux_sym_preproc_if_token2] = ACTIONS(1959),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1959),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1959),
    [sym_preproc_directive] = ACTIONS(1959),
    [anon_sym_LPAREN2] = ACTIONS(1961),
    [anon_sym_BANG] = ACTIONS(1961),
    [anon_sym_TILDE] = ACTIONS(1961),
    [anon_sym_DASH] = ACTIONS(1959),
    [anon_sym_PLUS] = ACTIONS(1959),
    [anon_sym_STAR] = ACTIONS(1961),
    [anon_sym_AMP_AMP] = ACTIONS(1961),
    [anon_sym_AMP] = ACTIONS(1959),
    [anon_sym_COLON] = ACTIONS(1959),
    [anon_sym_SEMI] = ACTIONS(1961),
    [anon_sym___extension__] = ACTIONS(1959),
    [anon_sym_typedef] = ACTIONS(1959),
    [anon_sym_in] = ACTIONS(1959),
    [anon_sym_out] = ACTIONS(1959),
    [anon_sym_inout] = ACTIONS(1959),
    [anon_sym_extern] = ACTIONS(1959),
    [anon_sym___attribute__] = ACTIONS(1959),
    [anon_sym_COLON_COLON] = ACTIONS(1961),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1961),
    [anon_sym___declspec] = ACTIONS(1959),
    [anon_sym___based] = ACTIONS(1959),
    [anon_sym___cdecl] = ACTIONS(1959),
    [anon_sym___clrcall] = ACTIONS(1959),
    [anon_sym___stdcall] = ACTIONS(1959),
    [anon_sym___fastcall] = ACTIONS(1959),
    [anon_sym___thiscall] = ACTIONS(1959),
    [anon_sym___vectorcall] = ACTIONS(1959),
    [anon_sym_LBRACE] = ACTIONS(1961),
    [anon_sym_signed] = ACTIONS(1959),
    [anon_sym_unsigned] = ACTIONS(1959),
    [anon_sym_long] = ACTIONS(1959),
    [anon_sym_short] = ACTIONS(1959),
    [anon_sym_LBRACK] = ACTIONS(1959),
    [anon_sym_static] = ACTIONS(1959),
    [anon_sym_register] = ACTIONS(1959),
    [anon_sym_inline] = ACTIONS(1959),
    [anon_sym___inline] = ACTIONS(1959),
    [anon_sym___inline__] = ACTIONS(1959),
    [anon_sym___forceinline] = ACTIONS(1959),
    [anon_sym_thread_local] = ACTIONS(1959),
    [anon_sym___thread] = ACTIONS(1959),
    [anon_sym_const] = ACTIONS(1959),
    [anon_sym_constexpr] = ACTIONS(1959),
    [anon_sym_volatile] = ACTIONS(1959),
    [anon_sym_restrict] = ACTIONS(1959),
    [anon_sym___restrict__] = ACTIONS(1959),
    [anon_sym__Atomic] = ACTIONS(1959),
    [anon_sym__Noreturn] = ACTIONS(1959),
    [anon_sym_noreturn] = ACTIONS(1959),
    [anon_sym_mutable] = ACTIONS(1959),
    [anon_sym_constinit] = ACTIONS(1959),
    [anon_sym_consteval] = ACTIONS(1959),
    [anon_sym_alignas] = ACTIONS(1959),
    [anon_sym__Alignas] = ACTIONS(1959),
    [sym_primitive_type] = ACTIONS(1959),
    [anon_sym_enum] = ACTIONS(1959),
    [anon_sym_class] = ACTIONS(1959),
    [anon_sym_struct] = ACTIONS(1959),
    [anon_sym_union] = ACTIONS(1959),
    [anon_sym_if] = ACTIONS(1959),
    [anon_sym_else] = ACTIONS(1959),
    [anon_sym_switch] = ACTIONS(1959),
    [anon_sym_case] = ACTIONS(1959),
    [anon_sym_default] = ACTIONS(1959),
    [anon_sym_while] = ACTIONS(1959),
    [anon_sym_do] = ACTIONS(1959),
    [anon_sym_for] = ACTIONS(1959),
    [anon_sym_return] = ACTIONS(1959),
    [anon_sym_break] = ACTIONS(1959),
    [anon_sym_continue] = ACTIONS(1959),
    [anon_sym_goto] = ACTIONS(1959),
    [anon_sym___try] = ACTIONS(1959),
    [anon_sym___leave] = ACTIONS(1959),
    [anon_sym_not] = ACTIONS(1959),
    [anon_sym_compl] = ACTIONS(1959),
    [anon_sym_DASH_DASH] = ACTIONS(1961),
    [anon_sym_PLUS_PLUS] = ACTIONS(1961),
    [anon_sym_sizeof] = ACTIONS(1959),
    [anon_sym___alignof__] = ACTIONS(1959),
    [anon_sym___alignof] = ACTIONS(1959),
    [anon_sym__alignof] = ACTIONS(1959),
    [anon_sym_alignof] = ACTIONS(1959),
    [anon_sym__Alignof] = ACTIONS(1959),
    [anon_sym_offsetof] = ACTIONS(1959),
    [anon_sym__Generic] = ACTIONS(1959),
    [anon_sym_asm] = ACTIONS(1959),
    [anon_sym___asm__] = ACTIONS(1959),
    [sym_number_literal] = ACTIONS(1961),
    [anon_sym_L_SQUOTE] = ACTIONS(1961),
    [anon_sym_u_SQUOTE] = ACTIONS(1961),
    [anon_sym_U_SQUOTE] = ACTIONS(1961),
    [anon_sym_u8_SQUOTE] = ACTIONS(1961),
    [anon_sym_SQUOTE] = ACTIONS(1961),
    [anon_sym_L_DQUOTE] = ACTIONS(1961),
    [anon_sym_u_DQUOTE] = ACTIONS(1961),
    [anon_sym_U_DQUOTE] = ACTIONS(1961),
    [anon_sym_u8_DQUOTE] = ACTIONS(1961),
    [anon_sym_DQUOTE] = ACTIONS(1961),
    [sym_true] = ACTIONS(1959),
    [sym_false] = ACTIONS(1959),
    [anon_sym_NULL] = ACTIONS(1959),
    [anon_sym_nullptr] = ACTIONS(1959),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1959),
    [anon_sym_decltype] = ACTIONS(1959),
    [anon_sym_final] = ACTIONS(1959),
    [anon_sym_override] = ACTIONS(1959),
    [sym_virtual] = ACTIONS(1959),
    [anon_sym_explicit] = ACTIONS(1959),
    [anon_sym_typename] = ACTIONS(1959),
    [anon_sym_template] = ACTIONS(1959),
    [anon_sym_operator] = ACTIONS(1959),
    [anon_sym_try] = ACTIONS(1959),
    [anon_sym_delete] = ACTIONS(1959),
    [anon_sym_throw] = ACTIONS(1959),
    [anon_sym_namespace] = ACTIONS(1959),
    [anon_sym_using] = ACTIONS(1959),
    [anon_sym_static_assert] = ACTIONS(1959),
    [anon_sym_concept] = ACTIONS(1959),
    [anon_sym_co_return] = ACTIONS(1959),
    [anon_sym_co_yield] = ACTIONS(1959),
    [anon_sym_R_DQUOTE] = ACTIONS(1961),
    [anon_sym_LR_DQUOTE] = ACTIONS(1961),
    [anon_sym_uR_DQUOTE] = ACTIONS(1961),
    [anon_sym_UR_DQUOTE] = ACTIONS(1961),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1961),
    [anon_sym_co_await] = ACTIONS(1959),
    [anon_sym_new] = ACTIONS(1959),
    [anon_sym_requires] = ACTIONS(1959),
    [sym_this] = ACTIONS(1959),
    [anon_sym_discard] = ACTIONS(1959),
    [anon_sym_precise] = ACTIONS(1959),
    [anon_sym_shared] = ACTIONS(1959),
    [anon_sym_groupshared] = ACTIONS(1959),
    [anon_sym_uniform] = ACTIONS(1959),
    [anon_sym_row_major] = ACTIONS(1959),
    [anon_sym_column_major] = ACTIONS(1959),
    [anon_sym_globallycoherent] = ACTIONS(1959),
    [anon_sym_centroid] = ACTIONS(1959),
    [anon_sym_noperspective] = ACTIONS(1959),
    [anon_sym_nointerpolation] = ACTIONS(1959),
    [anon_sym_sample] = ACTIONS(1959),
    [anon_sym_linear] = ACTIONS(1959),
    [anon_sym_snorm] = ACTIONS(1959),
    [anon_sym_unorm] = ACTIONS(1959),
    [anon_sym_point] = ACTIONS(1959),
    [anon_sym_line] = ACTIONS(1959),
    [anon_sym_triangleadj] = ACTIONS(1959),
    [anon_sym_lineadj] = ACTIONS(1959),
    [anon_sym_triangle] = ACTIONS(1959),
    [anon_sym_cbuffer] = ACTIONS(1959),
  },
  [294] = {
    [sym_catch_clause] = STATE(338),
    [aux_sym_constructor_try_statement_repeat1] = STATE(338),
    [sym_identifier] = ACTIONS(1963),
    [aux_sym_preproc_include_token1] = ACTIONS(1963),
    [aux_sym_preproc_def_token1] = ACTIONS(1963),
    [aux_sym_preproc_if_token1] = ACTIONS(1963),
    [aux_sym_preproc_if_token2] = ACTIONS(1963),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1963),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1963),
    [sym_preproc_directive] = ACTIONS(1963),
    [anon_sym_LPAREN2] = ACTIONS(1965),
    [anon_sym_BANG] = ACTIONS(1965),
    [anon_sym_TILDE] = ACTIONS(1965),
    [anon_sym_DASH] = ACTIONS(1963),
    [anon_sym_PLUS] = ACTIONS(1963),
    [anon_sym_STAR] = ACTIONS(1965),
    [anon_sym_AMP_AMP] = ACTIONS(1965),
    [anon_sym_AMP] = ACTIONS(1963),
    [anon_sym_SEMI] = ACTIONS(1965),
    [anon_sym___extension__] = ACTIONS(1963),
    [anon_sym_typedef] = ACTIONS(1963),
    [anon_sym_in] = ACTIONS(1963),
    [anon_sym_out] = ACTIONS(1963),
    [anon_sym_inout] = ACTIONS(1963),
    [anon_sym_extern] = ACTIONS(1963),
    [anon_sym___attribute__] = ACTIONS(1963),
    [anon_sym_COLON_COLON] = ACTIONS(1965),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1965),
    [anon_sym___declspec] = ACTIONS(1963),
    [anon_sym___based] = ACTIONS(1963),
    [anon_sym___cdecl] = ACTIONS(1963),
    [anon_sym___clrcall] = ACTIONS(1963),
    [anon_sym___stdcall] = ACTIONS(1963),
    [anon_sym___fastcall] = ACTIONS(1963),
    [anon_sym___thiscall] = ACTIONS(1963),
    [anon_sym___vectorcall] = ACTIONS(1963),
    [anon_sym_LBRACE] = ACTIONS(1965),
    [anon_sym_signed] = ACTIONS(1963),
    [anon_sym_unsigned] = ACTIONS(1963),
    [anon_sym_long] = ACTIONS(1963),
    [anon_sym_short] = ACTIONS(1963),
    [anon_sym_LBRACK] = ACTIONS(1963),
    [anon_sym_static] = ACTIONS(1963),
    [anon_sym_register] = ACTIONS(1963),
    [anon_sym_inline] = ACTIONS(1963),
    [anon_sym___inline] = ACTIONS(1963),
    [anon_sym___inline__] = ACTIONS(1963),
    [anon_sym___forceinline] = ACTIONS(1963),
    [anon_sym_thread_local] = ACTIONS(1963),
    [anon_sym___thread] = ACTIONS(1963),
    [anon_sym_const] = ACTIONS(1963),
    [anon_sym_constexpr] = ACTIONS(1963),
    [anon_sym_volatile] = ACTIONS(1963),
    [anon_sym_restrict] = ACTIONS(1963),
    [anon_sym___restrict__] = ACTIONS(1963),
    [anon_sym__Atomic] = ACTIONS(1963),
    [anon_sym__Noreturn] = ACTIONS(1963),
    [anon_sym_noreturn] = ACTIONS(1963),
    [anon_sym_mutable] = ACTIONS(1963),
    [anon_sym_constinit] = ACTIONS(1963),
    [anon_sym_consteval] = ACTIONS(1963),
    [anon_sym_alignas] = ACTIONS(1963),
    [anon_sym__Alignas] = ACTIONS(1963),
    [sym_primitive_type] = ACTIONS(1963),
    [anon_sym_enum] = ACTIONS(1963),
    [anon_sym_class] = ACTIONS(1963),
    [anon_sym_struct] = ACTIONS(1963),
    [anon_sym_union] = ACTIONS(1963),
    [anon_sym_if] = ACTIONS(1963),
    [anon_sym_else] = ACTIONS(1963),
    [anon_sym_switch] = ACTIONS(1963),
    [anon_sym_case] = ACTIONS(1963),
    [anon_sym_default] = ACTIONS(1963),
    [anon_sym_while] = ACTIONS(1963),
    [anon_sym_do] = ACTIONS(1963),
    [anon_sym_for] = ACTIONS(1963),
    [anon_sym_return] = ACTIONS(1963),
    [anon_sym_break] = ACTIONS(1963),
    [anon_sym_continue] = ACTIONS(1963),
    [anon_sym_goto] = ACTIONS(1963),
    [anon_sym___try] = ACTIONS(1963),
    [anon_sym___leave] = ACTIONS(1963),
    [anon_sym_not] = ACTIONS(1963),
    [anon_sym_compl] = ACTIONS(1963),
    [anon_sym_DASH_DASH] = ACTIONS(1965),
    [anon_sym_PLUS_PLUS] = ACTIONS(1965),
    [anon_sym_sizeof] = ACTIONS(1963),
    [anon_sym___alignof__] = ACTIONS(1963),
    [anon_sym___alignof] = ACTIONS(1963),
    [anon_sym__alignof] = ACTIONS(1963),
    [anon_sym_alignof] = ACTIONS(1963),
    [anon_sym__Alignof] = ACTIONS(1963),
    [anon_sym_offsetof] = ACTIONS(1963),
    [anon_sym__Generic] = ACTIONS(1963),
    [anon_sym_asm] = ACTIONS(1963),
    [anon_sym___asm__] = ACTIONS(1963),
    [sym_number_literal] = ACTIONS(1965),
    [anon_sym_L_SQUOTE] = ACTIONS(1965),
    [anon_sym_u_SQUOTE] = ACTIONS(1965),
    [anon_sym_U_SQUOTE] = ACTIONS(1965),
    [anon_sym_u8_SQUOTE] = ACTIONS(1965),
    [anon_sym_SQUOTE] = ACTIONS(1965),
    [anon_sym_L_DQUOTE] = ACTIONS(1965),
    [anon_sym_u_DQUOTE] = ACTIONS(1965),
    [anon_sym_U_DQUOTE] = ACTIONS(1965),
    [anon_sym_u8_DQUOTE] = ACTIONS(1965),
    [anon_sym_DQUOTE] = ACTIONS(1965),
    [sym_true] = ACTIONS(1963),
    [sym_false] = ACTIONS(1963),
    [anon_sym_NULL] = ACTIONS(1963),
    [anon_sym_nullptr] = ACTIONS(1963),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1963),
    [anon_sym_decltype] = ACTIONS(1963),
    [sym_virtual] = ACTIONS(1963),
    [anon_sym_explicit] = ACTIONS(1963),
    [anon_sym_typename] = ACTIONS(1963),
    [anon_sym_template] = ACTIONS(1963),
    [anon_sym_operator] = ACTIONS(1963),
    [anon_sym_try] = ACTIONS(1963),
    [anon_sym_delete] = ACTIONS(1963),
    [anon_sym_throw] = ACTIONS(1963),
    [anon_sym_namespace] = ACTIONS(1963),
    [anon_sym_using] = ACTIONS(1963),
    [anon_sym_static_assert] = ACTIONS(1963),
    [anon_sym_concept] = ACTIONS(1963),
    [anon_sym_co_return] = ACTIONS(1963),
    [anon_sym_co_yield] = ACTIONS(1963),
    [anon_sym_catch] = ACTIONS(2452),
    [anon_sym_R_DQUOTE] = ACTIONS(1965),
    [anon_sym_LR_DQUOTE] = ACTIONS(1965),
    [anon_sym_uR_DQUOTE] = ACTIONS(1965),
    [anon_sym_UR_DQUOTE] = ACTIONS(1965),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1965),
    [anon_sym_co_await] = ACTIONS(1963),
    [anon_sym_new] = ACTIONS(1963),
    [anon_sym_requires] = ACTIONS(1963),
    [sym_this] = ACTIONS(1963),
    [anon_sym_discard] = ACTIONS(1963),
    [anon_sym_precise] = ACTIONS(1963),
    [anon_sym_shared] = ACTIONS(1963),
    [anon_sym_groupshared] = ACTIONS(1963),
    [anon_sym_uniform] = ACTIONS(1963),
    [anon_sym_row_major] = ACTIONS(1963),
    [anon_sym_column_major] = ACTIONS(1963),
    [anon_sym_globallycoherent] = ACTIONS(1963),
    [anon_sym_centroid] = ACTIONS(1963),
    [anon_sym_noperspective] = ACTIONS(1963),
    [anon_sym_nointerpolation] = ACTIONS(1963),
    [anon_sym_sample] = ACTIONS(1963),
    [anon_sym_linear] = ACTIONS(1963),
    [anon_sym_snorm] = ACTIONS(1963),
    [anon_sym_unorm] = ACTIONS(1963),
    [anon_sym_point] = ACTIONS(1963),
    [anon_sym_line] = ACTIONS(1963),
    [anon_sym_triangleadj] = ACTIONS(1963),
    [anon_sym_lineadj] = ACTIONS(1963),
    [anon_sym_triangle] = ACTIONS(1963),
    [anon_sym_cbuffer] = ACTIONS(1963),
  },
  [295] = {
    [sym_identifier] = ACTIONS(2454),
    [aux_sym_preproc_include_token1] = ACTIONS(2454),
    [aux_sym_preproc_def_token1] = ACTIONS(2454),
    [aux_sym_preproc_if_token1] = ACTIONS(2454),
    [aux_sym_preproc_if_token2] = ACTIONS(2454),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2454),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2454),
    [aux_sym_preproc_else_token1] = ACTIONS(2454),
    [aux_sym_preproc_elif_token1] = ACTIONS(2454),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2454),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2454),
    [sym_preproc_directive] = ACTIONS(2454),
    [anon_sym_LPAREN2] = ACTIONS(2456),
    [anon_sym_BANG] = ACTIONS(2456),
    [anon_sym_TILDE] = ACTIONS(2456),
    [anon_sym_DASH] = ACTIONS(2454),
    [anon_sym_PLUS] = ACTIONS(2454),
    [anon_sym_STAR] = ACTIONS(2456),
    [anon_sym_AMP_AMP] = ACTIONS(2456),
    [anon_sym_AMP] = ACTIONS(2454),
    [anon_sym_SEMI] = ACTIONS(2456),
    [anon_sym___extension__] = ACTIONS(2454),
    [anon_sym_typedef] = ACTIONS(2454),
    [anon_sym_in] = ACTIONS(2454),
    [anon_sym_out] = ACTIONS(2454),
    [anon_sym_inout] = ACTIONS(2454),
    [anon_sym_extern] = ACTIONS(2454),
    [anon_sym___attribute__] = ACTIONS(2454),
    [anon_sym_COLON_COLON] = ACTIONS(2456),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2456),
    [anon_sym___declspec] = ACTIONS(2454),
    [anon_sym___based] = ACTIONS(2454),
    [anon_sym___cdecl] = ACTIONS(2454),
    [anon_sym___clrcall] = ACTIONS(2454),
    [anon_sym___stdcall] = ACTIONS(2454),
    [anon_sym___fastcall] = ACTIONS(2454),
    [anon_sym___thiscall] = ACTIONS(2454),
    [anon_sym___vectorcall] = ACTIONS(2454),
    [anon_sym_LBRACE] = ACTIONS(2456),
    [anon_sym_signed] = ACTIONS(2454),
    [anon_sym_unsigned] = ACTIONS(2454),
    [anon_sym_long] = ACTIONS(2454),
    [anon_sym_short] = ACTIONS(2454),
    [anon_sym_LBRACK] = ACTIONS(2454),
    [anon_sym_static] = ACTIONS(2454),
    [anon_sym_register] = ACTIONS(2454),
    [anon_sym_inline] = ACTIONS(2454),
    [anon_sym___inline] = ACTIONS(2454),
    [anon_sym___inline__] = ACTIONS(2454),
    [anon_sym___forceinline] = ACTIONS(2454),
    [anon_sym_thread_local] = ACTIONS(2454),
    [anon_sym___thread] = ACTIONS(2454),
    [anon_sym_const] = ACTIONS(2454),
    [anon_sym_constexpr] = ACTIONS(2454),
    [anon_sym_volatile] = ACTIONS(2454),
    [anon_sym_restrict] = ACTIONS(2454),
    [anon_sym___restrict__] = ACTIONS(2454),
    [anon_sym__Atomic] = ACTIONS(2454),
    [anon_sym__Noreturn] = ACTIONS(2454),
    [anon_sym_noreturn] = ACTIONS(2454),
    [anon_sym_mutable] = ACTIONS(2454),
    [anon_sym_constinit] = ACTIONS(2454),
    [anon_sym_consteval] = ACTIONS(2454),
    [anon_sym_alignas] = ACTIONS(2454),
    [anon_sym__Alignas] = ACTIONS(2454),
    [sym_primitive_type] = ACTIONS(2454),
    [anon_sym_enum] = ACTIONS(2454),
    [anon_sym_class] = ACTIONS(2454),
    [anon_sym_struct] = ACTIONS(2454),
    [anon_sym_union] = ACTIONS(2454),
    [anon_sym_if] = ACTIONS(2454),
    [anon_sym_switch] = ACTIONS(2454),
    [anon_sym_case] = ACTIONS(2454),
    [anon_sym_default] = ACTIONS(2454),
    [anon_sym_while] = ACTIONS(2454),
    [anon_sym_do] = ACTIONS(2454),
    [anon_sym_for] = ACTIONS(2454),
    [anon_sym_return] = ACTIONS(2454),
    [anon_sym_break] = ACTIONS(2454),
    [anon_sym_continue] = ACTIONS(2454),
    [anon_sym_goto] = ACTIONS(2454),
    [anon_sym___try] = ACTIONS(2454),
    [anon_sym___leave] = ACTIONS(2454),
    [anon_sym_not] = ACTIONS(2454),
    [anon_sym_compl] = ACTIONS(2454),
    [anon_sym_DASH_DASH] = ACTIONS(2456),
    [anon_sym_PLUS_PLUS] = ACTIONS(2456),
    [anon_sym_sizeof] = ACTIONS(2454),
    [anon_sym___alignof__] = ACTIONS(2454),
    [anon_sym___alignof] = ACTIONS(2454),
    [anon_sym__alignof] = ACTIONS(2454),
    [anon_sym_alignof] = ACTIONS(2454),
    [anon_sym__Alignof] = ACTIONS(2454),
    [anon_sym_offsetof] = ACTIONS(2454),
    [anon_sym__Generic] = ACTIONS(2454),
    [anon_sym_asm] = ACTIONS(2454),
    [anon_sym___asm__] = ACTIONS(2454),
    [sym_number_literal] = ACTIONS(2456),
    [anon_sym_L_SQUOTE] = ACTIONS(2456),
    [anon_sym_u_SQUOTE] = ACTIONS(2456),
    [anon_sym_U_SQUOTE] = ACTIONS(2456),
    [anon_sym_u8_SQUOTE] = ACTIONS(2456),
    [anon_sym_SQUOTE] = ACTIONS(2456),
    [anon_sym_L_DQUOTE] = ACTIONS(2456),
    [anon_sym_u_DQUOTE] = ACTIONS(2456),
    [anon_sym_U_DQUOTE] = ACTIONS(2456),
    [anon_sym_u8_DQUOTE] = ACTIONS(2456),
    [anon_sym_DQUOTE] = ACTIONS(2456),
    [sym_true] = ACTIONS(2454),
    [sym_false] = ACTIONS(2454),
    [anon_sym_NULL] = ACTIONS(2454),
    [anon_sym_nullptr] = ACTIONS(2454),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2454),
    [anon_sym_decltype] = ACTIONS(2454),
    [sym_virtual] = ACTIONS(2454),
    [anon_sym_explicit] = ACTIONS(2454),
    [anon_sym_typename] = ACTIONS(2454),
    [anon_sym_template] = ACTIONS(2454),
    [anon_sym_operator] = ACTIONS(2454),
    [anon_sym_try] = ACTIONS(2454),
    [anon_sym_delete] = ACTIONS(2454),
    [anon_sym_throw] = ACTIONS(2454),
    [anon_sym_namespace] = ACTIONS(2454),
    [anon_sym_using] = ACTIONS(2454),
    [anon_sym_static_assert] = ACTIONS(2454),
    [anon_sym_concept] = ACTIONS(2454),
    [anon_sym_co_return] = ACTIONS(2454),
    [anon_sym_co_yield] = ACTIONS(2454),
    [anon_sym_R_DQUOTE] = ACTIONS(2456),
    [anon_sym_LR_DQUOTE] = ACTIONS(2456),
    [anon_sym_uR_DQUOTE] = ACTIONS(2456),
    [anon_sym_UR_DQUOTE] = ACTIONS(2456),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2456),
    [anon_sym_co_await] = ACTIONS(2454),
    [anon_sym_new] = ACTIONS(2454),
    [anon_sym_requires] = ACTIONS(2454),
    [sym_this] = ACTIONS(2454),
    [anon_sym_discard] = ACTIONS(2454),
    [anon_sym_precise] = ACTIONS(2454),
    [anon_sym_shared] = ACTIONS(2454),
    [anon_sym_groupshared] = ACTIONS(2454),
    [anon_sym_uniform] = ACTIONS(2454),
    [anon_sym_row_major] = ACTIONS(2454),
    [anon_sym_column_major] = ACTIONS(2454),
    [anon_sym_globallycoherent] = ACTIONS(2454),
    [anon_sym_centroid] = ACTIONS(2454),
    [anon_sym_noperspective] = ACTIONS(2454),
    [anon_sym_nointerpolation] = ACTIONS(2454),
    [anon_sym_sample] = ACTIONS(2454),
    [anon_sym_linear] = ACTIONS(2454),
    [anon_sym_snorm] = ACTIONS(2454),
    [anon_sym_unorm] = ACTIONS(2454),
    [anon_sym_point] = ACTIONS(2454),
    [anon_sym_line] = ACTIONS(2454),
    [anon_sym_triangleadj] = ACTIONS(2454),
    [anon_sym_lineadj] = ACTIONS(2454),
    [anon_sym_triangle] = ACTIONS(2454),
    [anon_sym_cbuffer] = ACTIONS(2454),
  },
  [296] = {
    [sym_identifier] = ACTIONS(2458),
    [aux_sym_preproc_include_token1] = ACTIONS(2458),
    [aux_sym_preproc_def_token1] = ACTIONS(2458),
    [aux_sym_preproc_if_token1] = ACTIONS(2458),
    [aux_sym_preproc_if_token2] = ACTIONS(2458),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2458),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2458),
    [aux_sym_preproc_else_token1] = ACTIONS(2458),
    [aux_sym_preproc_elif_token1] = ACTIONS(2458),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2458),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2458),
    [sym_preproc_directive] = ACTIONS(2458),
    [anon_sym_LPAREN2] = ACTIONS(2460),
    [anon_sym_BANG] = ACTIONS(2460),
    [anon_sym_TILDE] = ACTIONS(2460),
    [anon_sym_DASH] = ACTIONS(2458),
    [anon_sym_PLUS] = ACTIONS(2458),
    [anon_sym_STAR] = ACTIONS(2460),
    [anon_sym_AMP_AMP] = ACTIONS(2460),
    [anon_sym_AMP] = ACTIONS(2458),
    [anon_sym_SEMI] = ACTIONS(2460),
    [anon_sym___extension__] = ACTIONS(2458),
    [anon_sym_typedef] = ACTIONS(2458),
    [anon_sym_in] = ACTIONS(2458),
    [anon_sym_out] = ACTIONS(2458),
    [anon_sym_inout] = ACTIONS(2458),
    [anon_sym_extern] = ACTIONS(2458),
    [anon_sym___attribute__] = ACTIONS(2458),
    [anon_sym_COLON_COLON] = ACTIONS(2460),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2460),
    [anon_sym___declspec] = ACTIONS(2458),
    [anon_sym___based] = ACTIONS(2458),
    [anon_sym___cdecl] = ACTIONS(2458),
    [anon_sym___clrcall] = ACTIONS(2458),
    [anon_sym___stdcall] = ACTIONS(2458),
    [anon_sym___fastcall] = ACTIONS(2458),
    [anon_sym___thiscall] = ACTIONS(2458),
    [anon_sym___vectorcall] = ACTIONS(2458),
    [anon_sym_LBRACE] = ACTIONS(2460),
    [anon_sym_signed] = ACTIONS(2458),
    [anon_sym_unsigned] = ACTIONS(2458),
    [anon_sym_long] = ACTIONS(2458),
    [anon_sym_short] = ACTIONS(2458),
    [anon_sym_LBRACK] = ACTIONS(2458),
    [anon_sym_static] = ACTIONS(2458),
    [anon_sym_register] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(2458),
    [anon_sym___inline] = ACTIONS(2458),
    [anon_sym___inline__] = ACTIONS(2458),
    [anon_sym___forceinline] = ACTIONS(2458),
    [anon_sym_thread_local] = ACTIONS(2458),
    [anon_sym___thread] = ACTIONS(2458),
    [anon_sym_const] = ACTIONS(2458),
    [anon_sym_constexpr] = ACTIONS(2458),
    [anon_sym_volatile] = ACTIONS(2458),
    [anon_sym_restrict] = ACTIONS(2458),
    [anon_sym___restrict__] = ACTIONS(2458),
    [anon_sym__Atomic] = ACTIONS(2458),
    [anon_sym__Noreturn] = ACTIONS(2458),
    [anon_sym_noreturn] = ACTIONS(2458),
    [anon_sym_mutable] = ACTIONS(2458),
    [anon_sym_constinit] = ACTIONS(2458),
    [anon_sym_consteval] = ACTIONS(2458),
    [anon_sym_alignas] = ACTIONS(2458),
    [anon_sym__Alignas] = ACTIONS(2458),
    [sym_primitive_type] = ACTIONS(2458),
    [anon_sym_enum] = ACTIONS(2458),
    [anon_sym_class] = ACTIONS(2458),
    [anon_sym_struct] = ACTIONS(2458),
    [anon_sym_union] = ACTIONS(2458),
    [anon_sym_if] = ACTIONS(2458),
    [anon_sym_switch] = ACTIONS(2458),
    [anon_sym_case] = ACTIONS(2458),
    [anon_sym_default] = ACTIONS(2458),
    [anon_sym_while] = ACTIONS(2458),
    [anon_sym_do] = ACTIONS(2458),
    [anon_sym_for] = ACTIONS(2458),
    [anon_sym_return] = ACTIONS(2458),
    [anon_sym_break] = ACTIONS(2458),
    [anon_sym_continue] = ACTIONS(2458),
    [anon_sym_goto] = ACTIONS(2458),
    [anon_sym___try] = ACTIONS(2458),
    [anon_sym___leave] = ACTIONS(2458),
    [anon_sym_not] = ACTIONS(2458),
    [anon_sym_compl] = ACTIONS(2458),
    [anon_sym_DASH_DASH] = ACTIONS(2460),
    [anon_sym_PLUS_PLUS] = ACTIONS(2460),
    [anon_sym_sizeof] = ACTIONS(2458),
    [anon_sym___alignof__] = ACTIONS(2458),
    [anon_sym___alignof] = ACTIONS(2458),
    [anon_sym__alignof] = ACTIONS(2458),
    [anon_sym_alignof] = ACTIONS(2458),
    [anon_sym__Alignof] = ACTIONS(2458),
    [anon_sym_offsetof] = ACTIONS(2458),
    [anon_sym__Generic] = ACTIONS(2458),
    [anon_sym_asm] = ACTIONS(2458),
    [anon_sym___asm__] = ACTIONS(2458),
    [sym_number_literal] = ACTIONS(2460),
    [anon_sym_L_SQUOTE] = ACTIONS(2460),
    [anon_sym_u_SQUOTE] = ACTIONS(2460),
    [anon_sym_U_SQUOTE] = ACTIONS(2460),
    [anon_sym_u8_SQUOTE] = ACTIONS(2460),
    [anon_sym_SQUOTE] = ACTIONS(2460),
    [anon_sym_L_DQUOTE] = ACTIONS(2460),
    [anon_sym_u_DQUOTE] = ACTIONS(2460),
    [anon_sym_U_DQUOTE] = ACTIONS(2460),
    [anon_sym_u8_DQUOTE] = ACTIONS(2460),
    [anon_sym_DQUOTE] = ACTIONS(2460),
    [sym_true] = ACTIONS(2458),
    [sym_false] = ACTIONS(2458),
    [anon_sym_NULL] = ACTIONS(2458),
    [anon_sym_nullptr] = ACTIONS(2458),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2458),
    [anon_sym_decltype] = ACTIONS(2458),
    [sym_virtual] = ACTIONS(2458),
    [anon_sym_explicit] = ACTIONS(2458),
    [anon_sym_typename] = ACTIONS(2458),
    [anon_sym_template] = ACTIONS(2458),
    [anon_sym_operator] = ACTIONS(2458),
    [anon_sym_try] = ACTIONS(2458),
    [anon_sym_delete] = ACTIONS(2458),
    [anon_sym_throw] = ACTIONS(2458),
    [anon_sym_namespace] = ACTIONS(2458),
    [anon_sym_using] = ACTIONS(2458),
    [anon_sym_static_assert] = ACTIONS(2458),
    [anon_sym_concept] = ACTIONS(2458),
    [anon_sym_co_return] = ACTIONS(2458),
    [anon_sym_co_yield] = ACTIONS(2458),
    [anon_sym_R_DQUOTE] = ACTIONS(2460),
    [anon_sym_LR_DQUOTE] = ACTIONS(2460),
    [anon_sym_uR_DQUOTE] = ACTIONS(2460),
    [anon_sym_UR_DQUOTE] = ACTIONS(2460),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2460),
    [anon_sym_co_await] = ACTIONS(2458),
    [anon_sym_new] = ACTIONS(2458),
    [anon_sym_requires] = ACTIONS(2458),
    [sym_this] = ACTIONS(2458),
    [anon_sym_discard] = ACTIONS(2458),
    [anon_sym_precise] = ACTIONS(2458),
    [anon_sym_shared] = ACTIONS(2458),
    [anon_sym_groupshared] = ACTIONS(2458),
    [anon_sym_uniform] = ACTIONS(2458),
    [anon_sym_row_major] = ACTIONS(2458),
    [anon_sym_column_major] = ACTIONS(2458),
    [anon_sym_globallycoherent] = ACTIONS(2458),
    [anon_sym_centroid] = ACTIONS(2458),
    [anon_sym_noperspective] = ACTIONS(2458),
    [anon_sym_nointerpolation] = ACTIONS(2458),
    [anon_sym_sample] = ACTIONS(2458),
    [anon_sym_linear] = ACTIONS(2458),
    [anon_sym_snorm] = ACTIONS(2458),
    [anon_sym_unorm] = ACTIONS(2458),
    [anon_sym_point] = ACTIONS(2458),
    [anon_sym_line] = ACTIONS(2458),
    [anon_sym_triangleadj] = ACTIONS(2458),
    [anon_sym_lineadj] = ACTIONS(2458),
    [anon_sym_triangle] = ACTIONS(2458),
    [anon_sym_cbuffer] = ACTIONS(2458),
  },
  [297] = {
    [sym_identifier] = ACTIONS(2462),
    [aux_sym_preproc_include_token1] = ACTIONS(2462),
    [aux_sym_preproc_def_token1] = ACTIONS(2462),
    [aux_sym_preproc_if_token1] = ACTIONS(2462),
    [aux_sym_preproc_if_token2] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2462),
    [aux_sym_preproc_else_token1] = ACTIONS(2462),
    [aux_sym_preproc_elif_token1] = ACTIONS(2462),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2462),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2462),
    [sym_preproc_directive] = ACTIONS(2462),
    [anon_sym_LPAREN2] = ACTIONS(2464),
    [anon_sym_BANG] = ACTIONS(2464),
    [anon_sym_TILDE] = ACTIONS(2464),
    [anon_sym_DASH] = ACTIONS(2462),
    [anon_sym_PLUS] = ACTIONS(2462),
    [anon_sym_STAR] = ACTIONS(2464),
    [anon_sym_AMP_AMP] = ACTIONS(2464),
    [anon_sym_AMP] = ACTIONS(2462),
    [anon_sym_SEMI] = ACTIONS(2464),
    [anon_sym___extension__] = ACTIONS(2462),
    [anon_sym_typedef] = ACTIONS(2462),
    [anon_sym_in] = ACTIONS(2462),
    [anon_sym_out] = ACTIONS(2462),
    [anon_sym_inout] = ACTIONS(2462),
    [anon_sym_extern] = ACTIONS(2462),
    [anon_sym___attribute__] = ACTIONS(2462),
    [anon_sym_COLON_COLON] = ACTIONS(2464),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2464),
    [anon_sym___declspec] = ACTIONS(2462),
    [anon_sym___based] = ACTIONS(2462),
    [anon_sym___cdecl] = ACTIONS(2462),
    [anon_sym___clrcall] = ACTIONS(2462),
    [anon_sym___stdcall] = ACTIONS(2462),
    [anon_sym___fastcall] = ACTIONS(2462),
    [anon_sym___thiscall] = ACTIONS(2462),
    [anon_sym___vectorcall] = ACTIONS(2462),
    [anon_sym_LBRACE] = ACTIONS(2464),
    [anon_sym_signed] = ACTIONS(2462),
    [anon_sym_unsigned] = ACTIONS(2462),
    [anon_sym_long] = ACTIONS(2462),
    [anon_sym_short] = ACTIONS(2462),
    [anon_sym_LBRACK] = ACTIONS(2462),
    [anon_sym_static] = ACTIONS(2462),
    [anon_sym_register] = ACTIONS(2462),
    [anon_sym_inline] = ACTIONS(2462),
    [anon_sym___inline] = ACTIONS(2462),
    [anon_sym___inline__] = ACTIONS(2462),
    [anon_sym___forceinline] = ACTIONS(2462),
    [anon_sym_thread_local] = ACTIONS(2462),
    [anon_sym___thread] = ACTIONS(2462),
    [anon_sym_const] = ACTIONS(2462),
    [anon_sym_constexpr] = ACTIONS(2462),
    [anon_sym_volatile] = ACTIONS(2462),
    [anon_sym_restrict] = ACTIONS(2462),
    [anon_sym___restrict__] = ACTIONS(2462),
    [anon_sym__Atomic] = ACTIONS(2462),
    [anon_sym__Noreturn] = ACTIONS(2462),
    [anon_sym_noreturn] = ACTIONS(2462),
    [anon_sym_mutable] = ACTIONS(2462),
    [anon_sym_constinit] = ACTIONS(2462),
    [anon_sym_consteval] = ACTIONS(2462),
    [anon_sym_alignas] = ACTIONS(2462),
    [anon_sym__Alignas] = ACTIONS(2462),
    [sym_primitive_type] = ACTIONS(2462),
    [anon_sym_enum] = ACTIONS(2462),
    [anon_sym_class] = ACTIONS(2462),
    [anon_sym_struct] = ACTIONS(2462),
    [anon_sym_union] = ACTIONS(2462),
    [anon_sym_if] = ACTIONS(2462),
    [anon_sym_switch] = ACTIONS(2462),
    [anon_sym_case] = ACTIONS(2462),
    [anon_sym_default] = ACTIONS(2462),
    [anon_sym_while] = ACTIONS(2462),
    [anon_sym_do] = ACTIONS(2462),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_break] = ACTIONS(2462),
    [anon_sym_continue] = ACTIONS(2462),
    [anon_sym_goto] = ACTIONS(2462),
    [anon_sym___try] = ACTIONS(2462),
    [anon_sym___leave] = ACTIONS(2462),
    [anon_sym_not] = ACTIONS(2462),
    [anon_sym_compl] = ACTIONS(2462),
    [anon_sym_DASH_DASH] = ACTIONS(2464),
    [anon_sym_PLUS_PLUS] = ACTIONS(2464),
    [anon_sym_sizeof] = ACTIONS(2462),
    [anon_sym___alignof__] = ACTIONS(2462),
    [anon_sym___alignof] = ACTIONS(2462),
    [anon_sym__alignof] = ACTIONS(2462),
    [anon_sym_alignof] = ACTIONS(2462),
    [anon_sym__Alignof] = ACTIONS(2462),
    [anon_sym_offsetof] = ACTIONS(2462),
    [anon_sym__Generic] = ACTIONS(2462),
    [anon_sym_asm] = ACTIONS(2462),
    [anon_sym___asm__] = ACTIONS(2462),
    [sym_number_literal] = ACTIONS(2464),
    [anon_sym_L_SQUOTE] = ACTIONS(2464),
    [anon_sym_u_SQUOTE] = ACTIONS(2464),
    [anon_sym_U_SQUOTE] = ACTIONS(2464),
    [anon_sym_u8_SQUOTE] = ACTIONS(2464),
    [anon_sym_SQUOTE] = ACTIONS(2464),
    [anon_sym_L_DQUOTE] = ACTIONS(2464),
    [anon_sym_u_DQUOTE] = ACTIONS(2464),
    [anon_sym_U_DQUOTE] = ACTIONS(2464),
    [anon_sym_u8_DQUOTE] = ACTIONS(2464),
    [anon_sym_DQUOTE] = ACTIONS(2464),
    [sym_true] = ACTIONS(2462),
    [sym_false] = ACTIONS(2462),
    [anon_sym_NULL] = ACTIONS(2462),
    [anon_sym_nullptr] = ACTIONS(2462),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2462),
    [anon_sym_decltype] = ACTIONS(2462),
    [sym_virtual] = ACTIONS(2462),
    [anon_sym_explicit] = ACTIONS(2462),
    [anon_sym_typename] = ACTIONS(2462),
    [anon_sym_template] = ACTIONS(2462),
    [anon_sym_operator] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2462),
    [anon_sym_delete] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2462),
    [anon_sym_namespace] = ACTIONS(2462),
    [anon_sym_using] = ACTIONS(2462),
    [anon_sym_static_assert] = ACTIONS(2462),
    [anon_sym_concept] = ACTIONS(2462),
    [anon_sym_co_return] = ACTIONS(2462),
    [anon_sym_co_yield] = ACTIONS(2462),
    [anon_sym_R_DQUOTE] = ACTIONS(2464),
    [anon_sym_LR_DQUOTE] = ACTIONS(2464),
    [anon_sym_uR_DQUOTE] = ACTIONS(2464),
    [anon_sym_UR_DQUOTE] = ACTIONS(2464),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2464),
    [anon_sym_co_await] = ACTIONS(2462),
    [anon_sym_new] = ACTIONS(2462),
    [anon_sym_requires] = ACTIONS(2462),
    [sym_this] = ACTIONS(2462),
    [anon_sym_discard] = ACTIONS(2462),
    [anon_sym_precise] = ACTIONS(2462),
    [anon_sym_shared] = ACTIONS(2462),
    [anon_sym_groupshared] = ACTIONS(2462),
    [anon_sym_uniform] = ACTIONS(2462),
    [anon_sym_row_major] = ACTIONS(2462),
    [anon_sym_column_major] = ACTIONS(2462),
    [anon_sym_globallycoherent] = ACTIONS(2462),
    [anon_sym_centroid] = ACTIONS(2462),
    [anon_sym_noperspective] = ACTIONS(2462),
    [anon_sym_nointerpolation] = ACTIONS(2462),
    [anon_sym_sample] = ACTIONS(2462),
    [anon_sym_linear] = ACTIONS(2462),
    [anon_sym_snorm] = ACTIONS(2462),
    [anon_sym_unorm] = ACTIONS(2462),
    [anon_sym_point] = ACTIONS(2462),
    [anon_sym_line] = ACTIONS(2462),
    [anon_sym_triangleadj] = ACTIONS(2462),
    [anon_sym_lineadj] = ACTIONS(2462),
    [anon_sym_triangle] = ACTIONS(2462),
    [anon_sym_cbuffer] = ACTIONS(2462),
  },
  [298] = {
    [sym_identifier] = ACTIONS(2462),
    [aux_sym_preproc_include_token1] = ACTIONS(2462),
    [aux_sym_preproc_def_token1] = ACTIONS(2462),
    [aux_sym_preproc_if_token1] = ACTIONS(2462),
    [aux_sym_preproc_if_token2] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2462),
    [aux_sym_preproc_else_token1] = ACTIONS(2462),
    [aux_sym_preproc_elif_token1] = ACTIONS(2462),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2462),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2462),
    [sym_preproc_directive] = ACTIONS(2462),
    [anon_sym_LPAREN2] = ACTIONS(2464),
    [anon_sym_BANG] = ACTIONS(2464),
    [anon_sym_TILDE] = ACTIONS(2464),
    [anon_sym_DASH] = ACTIONS(2462),
    [anon_sym_PLUS] = ACTIONS(2462),
    [anon_sym_STAR] = ACTIONS(2464),
    [anon_sym_AMP_AMP] = ACTIONS(2464),
    [anon_sym_AMP] = ACTIONS(2462),
    [anon_sym_SEMI] = ACTIONS(2464),
    [anon_sym___extension__] = ACTIONS(2462),
    [anon_sym_typedef] = ACTIONS(2462),
    [anon_sym_in] = ACTIONS(2462),
    [anon_sym_out] = ACTIONS(2462),
    [anon_sym_inout] = ACTIONS(2462),
    [anon_sym_extern] = ACTIONS(2462),
    [anon_sym___attribute__] = ACTIONS(2462),
    [anon_sym_COLON_COLON] = ACTIONS(2464),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2464),
    [anon_sym___declspec] = ACTIONS(2462),
    [anon_sym___based] = ACTIONS(2462),
    [anon_sym___cdecl] = ACTIONS(2462),
    [anon_sym___clrcall] = ACTIONS(2462),
    [anon_sym___stdcall] = ACTIONS(2462),
    [anon_sym___fastcall] = ACTIONS(2462),
    [anon_sym___thiscall] = ACTIONS(2462),
    [anon_sym___vectorcall] = ACTIONS(2462),
    [anon_sym_LBRACE] = ACTIONS(2464),
    [anon_sym_signed] = ACTIONS(2462),
    [anon_sym_unsigned] = ACTIONS(2462),
    [anon_sym_long] = ACTIONS(2462),
    [anon_sym_short] = ACTIONS(2462),
    [anon_sym_LBRACK] = ACTIONS(2462),
    [anon_sym_static] = ACTIONS(2462),
    [anon_sym_register] = ACTIONS(2462),
    [anon_sym_inline] = ACTIONS(2462),
    [anon_sym___inline] = ACTIONS(2462),
    [anon_sym___inline__] = ACTIONS(2462),
    [anon_sym___forceinline] = ACTIONS(2462),
    [anon_sym_thread_local] = ACTIONS(2462),
    [anon_sym___thread] = ACTIONS(2462),
    [anon_sym_const] = ACTIONS(2462),
    [anon_sym_constexpr] = ACTIONS(2462),
    [anon_sym_volatile] = ACTIONS(2462),
    [anon_sym_restrict] = ACTIONS(2462),
    [anon_sym___restrict__] = ACTIONS(2462),
    [anon_sym__Atomic] = ACTIONS(2462),
    [anon_sym__Noreturn] = ACTIONS(2462),
    [anon_sym_noreturn] = ACTIONS(2462),
    [anon_sym_mutable] = ACTIONS(2462),
    [anon_sym_constinit] = ACTIONS(2462),
    [anon_sym_consteval] = ACTIONS(2462),
    [anon_sym_alignas] = ACTIONS(2462),
    [anon_sym__Alignas] = ACTIONS(2462),
    [sym_primitive_type] = ACTIONS(2462),
    [anon_sym_enum] = ACTIONS(2462),
    [anon_sym_class] = ACTIONS(2462),
    [anon_sym_struct] = ACTIONS(2462),
    [anon_sym_union] = ACTIONS(2462),
    [anon_sym_if] = ACTIONS(2462),
    [anon_sym_switch] = ACTIONS(2462),
    [anon_sym_case] = ACTIONS(2462),
    [anon_sym_default] = ACTIONS(2462),
    [anon_sym_while] = ACTIONS(2462),
    [anon_sym_do] = ACTIONS(2462),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_break] = ACTIONS(2462),
    [anon_sym_continue] = ACTIONS(2462),
    [anon_sym_goto] = ACTIONS(2462),
    [anon_sym___try] = ACTIONS(2462),
    [anon_sym___leave] = ACTIONS(2462),
    [anon_sym_not] = ACTIONS(2462),
    [anon_sym_compl] = ACTIONS(2462),
    [anon_sym_DASH_DASH] = ACTIONS(2464),
    [anon_sym_PLUS_PLUS] = ACTIONS(2464),
    [anon_sym_sizeof] = ACTIONS(2462),
    [anon_sym___alignof__] = ACTIONS(2462),
    [anon_sym___alignof] = ACTIONS(2462),
    [anon_sym__alignof] = ACTIONS(2462),
    [anon_sym_alignof] = ACTIONS(2462),
    [anon_sym__Alignof] = ACTIONS(2462),
    [anon_sym_offsetof] = ACTIONS(2462),
    [anon_sym__Generic] = ACTIONS(2462),
    [anon_sym_asm] = ACTIONS(2462),
    [anon_sym___asm__] = ACTIONS(2462),
    [sym_number_literal] = ACTIONS(2464),
    [anon_sym_L_SQUOTE] = ACTIONS(2464),
    [anon_sym_u_SQUOTE] = ACTIONS(2464),
    [anon_sym_U_SQUOTE] = ACTIONS(2464),
    [anon_sym_u8_SQUOTE] = ACTIONS(2464),
    [anon_sym_SQUOTE] = ACTIONS(2464),
    [anon_sym_L_DQUOTE] = ACTIONS(2464),
    [anon_sym_u_DQUOTE] = ACTIONS(2464),
    [anon_sym_U_DQUOTE] = ACTIONS(2464),
    [anon_sym_u8_DQUOTE] = ACTIONS(2464),
    [anon_sym_DQUOTE] = ACTIONS(2464),
    [sym_true] = ACTIONS(2462),
    [sym_false] = ACTIONS(2462),
    [anon_sym_NULL] = ACTIONS(2462),
    [anon_sym_nullptr] = ACTIONS(2462),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2462),
    [anon_sym_decltype] = ACTIONS(2462),
    [sym_virtual] = ACTIONS(2462),
    [anon_sym_explicit] = ACTIONS(2462),
    [anon_sym_typename] = ACTIONS(2462),
    [anon_sym_template] = ACTIONS(2462),
    [anon_sym_operator] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2462),
    [anon_sym_delete] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2462),
    [anon_sym_namespace] = ACTIONS(2462),
    [anon_sym_using] = ACTIONS(2462),
    [anon_sym_static_assert] = ACTIONS(2462),
    [anon_sym_concept] = ACTIONS(2462),
    [anon_sym_co_return] = ACTIONS(2462),
    [anon_sym_co_yield] = ACTIONS(2462),
    [anon_sym_R_DQUOTE] = ACTIONS(2464),
    [anon_sym_LR_DQUOTE] = ACTIONS(2464),
    [anon_sym_uR_DQUOTE] = ACTIONS(2464),
    [anon_sym_UR_DQUOTE] = ACTIONS(2464),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2464),
    [anon_sym_co_await] = ACTIONS(2462),
    [anon_sym_new] = ACTIONS(2462),
    [anon_sym_requires] = ACTIONS(2462),
    [sym_this] = ACTIONS(2462),
    [anon_sym_discard] = ACTIONS(2462),
    [anon_sym_precise] = ACTIONS(2462),
    [anon_sym_shared] = ACTIONS(2462),
    [anon_sym_groupshared] = ACTIONS(2462),
    [anon_sym_uniform] = ACTIONS(2462),
    [anon_sym_row_major] = ACTIONS(2462),
    [anon_sym_column_major] = ACTIONS(2462),
    [anon_sym_globallycoherent] = ACTIONS(2462),
    [anon_sym_centroid] = ACTIONS(2462),
    [anon_sym_noperspective] = ACTIONS(2462),
    [anon_sym_nointerpolation] = ACTIONS(2462),
    [anon_sym_sample] = ACTIONS(2462),
    [anon_sym_linear] = ACTIONS(2462),
    [anon_sym_snorm] = ACTIONS(2462),
    [anon_sym_unorm] = ACTIONS(2462),
    [anon_sym_point] = ACTIONS(2462),
    [anon_sym_line] = ACTIONS(2462),
    [anon_sym_triangleadj] = ACTIONS(2462),
    [anon_sym_lineadj] = ACTIONS(2462),
    [anon_sym_triangle] = ACTIONS(2462),
    [anon_sym_cbuffer] = ACTIONS(2462),
  },
  [299] = {
    [sym_identifier] = ACTIONS(2466),
    [aux_sym_preproc_include_token1] = ACTIONS(2466),
    [aux_sym_preproc_def_token1] = ACTIONS(2466),
    [aux_sym_preproc_if_token1] = ACTIONS(2466),
    [aux_sym_preproc_if_token2] = ACTIONS(2466),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2466),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2466),
    [aux_sym_preproc_else_token1] = ACTIONS(2466),
    [aux_sym_preproc_elif_token1] = ACTIONS(2466),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2466),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2466),
    [sym_preproc_directive] = ACTIONS(2466),
    [anon_sym_LPAREN2] = ACTIONS(2468),
    [anon_sym_BANG] = ACTIONS(2468),
    [anon_sym_TILDE] = ACTIONS(2468),
    [anon_sym_DASH] = ACTIONS(2466),
    [anon_sym_PLUS] = ACTIONS(2466),
    [anon_sym_STAR] = ACTIONS(2468),
    [anon_sym_AMP_AMP] = ACTIONS(2468),
    [anon_sym_AMP] = ACTIONS(2466),
    [anon_sym_SEMI] = ACTIONS(2468),
    [anon_sym___extension__] = ACTIONS(2466),
    [anon_sym_typedef] = ACTIONS(2466),
    [anon_sym_in] = ACTIONS(2466),
    [anon_sym_out] = ACTIONS(2466),
    [anon_sym_inout] = ACTIONS(2466),
    [anon_sym_extern] = ACTIONS(2466),
    [anon_sym___attribute__] = ACTIONS(2466),
    [anon_sym_COLON_COLON] = ACTIONS(2468),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2468),
    [anon_sym___declspec] = ACTIONS(2466),
    [anon_sym___based] = ACTIONS(2466),
    [anon_sym___cdecl] = ACTIONS(2466),
    [anon_sym___clrcall] = ACTIONS(2466),
    [anon_sym___stdcall] = ACTIONS(2466),
    [anon_sym___fastcall] = ACTIONS(2466),
    [anon_sym___thiscall] = ACTIONS(2466),
    [anon_sym___vectorcall] = ACTIONS(2466),
    [anon_sym_LBRACE] = ACTIONS(2468),
    [anon_sym_signed] = ACTIONS(2466),
    [anon_sym_unsigned] = ACTIONS(2466),
    [anon_sym_long] = ACTIONS(2466),
    [anon_sym_short] = ACTIONS(2466),
    [anon_sym_LBRACK] = ACTIONS(2466),
    [anon_sym_static] = ACTIONS(2466),
    [anon_sym_register] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2466),
    [anon_sym___inline] = ACTIONS(2466),
    [anon_sym___inline__] = ACTIONS(2466),
    [anon_sym___forceinline] = ACTIONS(2466),
    [anon_sym_thread_local] = ACTIONS(2466),
    [anon_sym___thread] = ACTIONS(2466),
    [anon_sym_const] = ACTIONS(2466),
    [anon_sym_constexpr] = ACTIONS(2466),
    [anon_sym_volatile] = ACTIONS(2466),
    [anon_sym_restrict] = ACTIONS(2466),
    [anon_sym___restrict__] = ACTIONS(2466),
    [anon_sym__Atomic] = ACTIONS(2466),
    [anon_sym__Noreturn] = ACTIONS(2466),
    [anon_sym_noreturn] = ACTIONS(2466),
    [anon_sym_mutable] = ACTIONS(2466),
    [anon_sym_constinit] = ACTIONS(2466),
    [anon_sym_consteval] = ACTIONS(2466),
    [anon_sym_alignas] = ACTIONS(2466),
    [anon_sym__Alignas] = ACTIONS(2466),
    [sym_primitive_type] = ACTIONS(2466),
    [anon_sym_enum] = ACTIONS(2466),
    [anon_sym_class] = ACTIONS(2466),
    [anon_sym_struct] = ACTIONS(2466),
    [anon_sym_union] = ACTIONS(2466),
    [anon_sym_if] = ACTIONS(2466),
    [anon_sym_switch] = ACTIONS(2466),
    [anon_sym_case] = ACTIONS(2466),
    [anon_sym_default] = ACTIONS(2466),
    [anon_sym_while] = ACTIONS(2466),
    [anon_sym_do] = ACTIONS(2466),
    [anon_sym_for] = ACTIONS(2466),
    [anon_sym_return] = ACTIONS(2466),
    [anon_sym_break] = ACTIONS(2466),
    [anon_sym_continue] = ACTIONS(2466),
    [anon_sym_goto] = ACTIONS(2466),
    [anon_sym___try] = ACTIONS(2466),
    [anon_sym___leave] = ACTIONS(2466),
    [anon_sym_not] = ACTIONS(2466),
    [anon_sym_compl] = ACTIONS(2466),
    [anon_sym_DASH_DASH] = ACTIONS(2468),
    [anon_sym_PLUS_PLUS] = ACTIONS(2468),
    [anon_sym_sizeof] = ACTIONS(2466),
    [anon_sym___alignof__] = ACTIONS(2466),
    [anon_sym___alignof] = ACTIONS(2466),
    [anon_sym__alignof] = ACTIONS(2466),
    [anon_sym_alignof] = ACTIONS(2466),
    [anon_sym__Alignof] = ACTIONS(2466),
    [anon_sym_offsetof] = ACTIONS(2466),
    [anon_sym__Generic] = ACTIONS(2466),
    [anon_sym_asm] = ACTIONS(2466),
    [anon_sym___asm__] = ACTIONS(2466),
    [sym_number_literal] = ACTIONS(2468),
    [anon_sym_L_SQUOTE] = ACTIONS(2468),
    [anon_sym_u_SQUOTE] = ACTIONS(2468),
    [anon_sym_U_SQUOTE] = ACTIONS(2468),
    [anon_sym_u8_SQUOTE] = ACTIONS(2468),
    [anon_sym_SQUOTE] = ACTIONS(2468),
    [anon_sym_L_DQUOTE] = ACTIONS(2468),
    [anon_sym_u_DQUOTE] = ACTIONS(2468),
    [anon_sym_U_DQUOTE] = ACTIONS(2468),
    [anon_sym_u8_DQUOTE] = ACTIONS(2468),
    [anon_sym_DQUOTE] = ACTIONS(2468),
    [sym_true] = ACTIONS(2466),
    [sym_false] = ACTIONS(2466),
    [anon_sym_NULL] = ACTIONS(2466),
    [anon_sym_nullptr] = ACTIONS(2466),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2466),
    [anon_sym_decltype] = ACTIONS(2466),
    [sym_virtual] = ACTIONS(2466),
    [anon_sym_explicit] = ACTIONS(2466),
    [anon_sym_typename] = ACTIONS(2466),
    [anon_sym_template] = ACTIONS(2466),
    [anon_sym_operator] = ACTIONS(2466),
    [anon_sym_try] = ACTIONS(2466),
    [anon_sym_delete] = ACTIONS(2466),
    [anon_sym_throw] = ACTIONS(2466),
    [anon_sym_namespace] = ACTIONS(2466),
    [anon_sym_using] = ACTIONS(2466),
    [anon_sym_static_assert] = ACTIONS(2466),
    [anon_sym_concept] = ACTIONS(2466),
    [anon_sym_co_return] = ACTIONS(2466),
    [anon_sym_co_yield] = ACTIONS(2466),
    [anon_sym_R_DQUOTE] = ACTIONS(2468),
    [anon_sym_LR_DQUOTE] = ACTIONS(2468),
    [anon_sym_uR_DQUOTE] = ACTIONS(2468),
    [anon_sym_UR_DQUOTE] = ACTIONS(2468),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2468),
    [anon_sym_co_await] = ACTIONS(2466),
    [anon_sym_new] = ACTIONS(2466),
    [anon_sym_requires] = ACTIONS(2466),
    [sym_this] = ACTIONS(2466),
    [anon_sym_discard] = ACTIONS(2466),
    [anon_sym_precise] = ACTIONS(2466),
    [anon_sym_shared] = ACTIONS(2466),
    [anon_sym_groupshared] = ACTIONS(2466),
    [anon_sym_uniform] = ACTIONS(2466),
    [anon_sym_row_major] = ACTIONS(2466),
    [anon_sym_column_major] = ACTIONS(2466),
    [anon_sym_globallycoherent] = ACTIONS(2466),
    [anon_sym_centroid] = ACTIONS(2466),
    [anon_sym_noperspective] = ACTIONS(2466),
    [anon_sym_nointerpolation] = ACTIONS(2466),
    [anon_sym_sample] = ACTIONS(2466),
    [anon_sym_linear] = ACTIONS(2466),
    [anon_sym_snorm] = ACTIONS(2466),
    [anon_sym_unorm] = ACTIONS(2466),
    [anon_sym_point] = ACTIONS(2466),
    [anon_sym_line] = ACTIONS(2466),
    [anon_sym_triangleadj] = ACTIONS(2466),
    [anon_sym_lineadj] = ACTIONS(2466),
    [anon_sym_triangle] = ACTIONS(2466),
    [anon_sym_cbuffer] = ACTIONS(2466),
  },
  [300] = {
    [ts_builtin_sym_end] = ACTIONS(1889),
    [sym_identifier] = ACTIONS(1887),
    [aux_sym_preproc_include_token1] = ACTIONS(1887),
    [aux_sym_preproc_def_token1] = ACTIONS(1887),
    [aux_sym_preproc_if_token1] = ACTIONS(1887),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1887),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1887),
    [sym_preproc_directive] = ACTIONS(1887),
    [anon_sym_LPAREN2] = ACTIONS(1889),
    [anon_sym_BANG] = ACTIONS(1889),
    [anon_sym_TILDE] = ACTIONS(1889),
    [anon_sym_DASH] = ACTIONS(1887),
    [anon_sym_PLUS] = ACTIONS(1887),
    [anon_sym_STAR] = ACTIONS(1889),
    [anon_sym_AMP_AMP] = ACTIONS(1889),
    [anon_sym_AMP] = ACTIONS(1887),
    [anon_sym_COLON] = ACTIONS(1887),
    [anon_sym_SEMI] = ACTIONS(1889),
    [anon_sym___extension__] = ACTIONS(1887),
    [anon_sym_typedef] = ACTIONS(1887),
    [anon_sym_in] = ACTIONS(1887),
    [anon_sym_out] = ACTIONS(1887),
    [anon_sym_inout] = ACTIONS(1887),
    [anon_sym_extern] = ACTIONS(1887),
    [anon_sym___attribute__] = ACTIONS(1887),
    [anon_sym_COLON_COLON] = ACTIONS(1889),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1889),
    [anon_sym___declspec] = ACTIONS(1887),
    [anon_sym___based] = ACTIONS(1887),
    [anon_sym___cdecl] = ACTIONS(1887),
    [anon_sym___clrcall] = ACTIONS(1887),
    [anon_sym___stdcall] = ACTIONS(1887),
    [anon_sym___fastcall] = ACTIONS(1887),
    [anon_sym___thiscall] = ACTIONS(1887),
    [anon_sym___vectorcall] = ACTIONS(1887),
    [anon_sym_LBRACE] = ACTIONS(1889),
    [anon_sym_signed] = ACTIONS(1887),
    [anon_sym_unsigned] = ACTIONS(1887),
    [anon_sym_long] = ACTIONS(1887),
    [anon_sym_short] = ACTIONS(1887),
    [anon_sym_LBRACK] = ACTIONS(1887),
    [anon_sym_static] = ACTIONS(1887),
    [anon_sym_register] = ACTIONS(1887),
    [anon_sym_inline] = ACTIONS(1887),
    [anon_sym___inline] = ACTIONS(1887),
    [anon_sym___inline__] = ACTIONS(1887),
    [anon_sym___forceinline] = ACTIONS(1887),
    [anon_sym_thread_local] = ACTIONS(1887),
    [anon_sym___thread] = ACTIONS(1887),
    [anon_sym_const] = ACTIONS(1887),
    [anon_sym_constexpr] = ACTIONS(1887),
    [anon_sym_volatile] = ACTIONS(1887),
    [anon_sym_restrict] = ACTIONS(1887),
    [anon_sym___restrict__] = ACTIONS(1887),
    [anon_sym__Atomic] = ACTIONS(1887),
    [anon_sym__Noreturn] = ACTIONS(1887),
    [anon_sym_noreturn] = ACTIONS(1887),
    [anon_sym_mutable] = ACTIONS(1887),
    [anon_sym_constinit] = ACTIONS(1887),
    [anon_sym_consteval] = ACTIONS(1887),
    [anon_sym_alignas] = ACTIONS(1887),
    [anon_sym__Alignas] = ACTIONS(1887),
    [sym_primitive_type] = ACTIONS(1887),
    [anon_sym_enum] = ACTIONS(1887),
    [anon_sym_class] = ACTIONS(1887),
    [anon_sym_struct] = ACTIONS(1887),
    [anon_sym_union] = ACTIONS(1887),
    [anon_sym_if] = ACTIONS(1887),
    [anon_sym_else] = ACTIONS(1887),
    [anon_sym_switch] = ACTIONS(1887),
    [anon_sym_case] = ACTIONS(1887),
    [anon_sym_default] = ACTIONS(1887),
    [anon_sym_while] = ACTIONS(1887),
    [anon_sym_do] = ACTIONS(1887),
    [anon_sym_for] = ACTIONS(1887),
    [anon_sym_return] = ACTIONS(1887),
    [anon_sym_break] = ACTIONS(1887),
    [anon_sym_continue] = ACTIONS(1887),
    [anon_sym_goto] = ACTIONS(1887),
    [anon_sym___try] = ACTIONS(1887),
    [anon_sym___leave] = ACTIONS(1887),
    [anon_sym_not] = ACTIONS(1887),
    [anon_sym_compl] = ACTIONS(1887),
    [anon_sym_DASH_DASH] = ACTIONS(1889),
    [anon_sym_PLUS_PLUS] = ACTIONS(1889),
    [anon_sym_sizeof] = ACTIONS(1887),
    [anon_sym___alignof__] = ACTIONS(1887),
    [anon_sym___alignof] = ACTIONS(1887),
    [anon_sym__alignof] = ACTIONS(1887),
    [anon_sym_alignof] = ACTIONS(1887),
    [anon_sym__Alignof] = ACTIONS(1887),
    [anon_sym_offsetof] = ACTIONS(1887),
    [anon_sym__Generic] = ACTIONS(1887),
    [anon_sym_asm] = ACTIONS(1887),
    [anon_sym___asm__] = ACTIONS(1887),
    [sym_number_literal] = ACTIONS(1889),
    [anon_sym_L_SQUOTE] = ACTIONS(1889),
    [anon_sym_u_SQUOTE] = ACTIONS(1889),
    [anon_sym_U_SQUOTE] = ACTIONS(1889),
    [anon_sym_u8_SQUOTE] = ACTIONS(1889),
    [anon_sym_SQUOTE] = ACTIONS(1889),
    [anon_sym_L_DQUOTE] = ACTIONS(1889),
    [anon_sym_u_DQUOTE] = ACTIONS(1889),
    [anon_sym_U_DQUOTE] = ACTIONS(1889),
    [anon_sym_u8_DQUOTE] = ACTIONS(1889),
    [anon_sym_DQUOTE] = ACTIONS(1889),
    [sym_true] = ACTIONS(1887),
    [sym_false] = ACTIONS(1887),
    [anon_sym_NULL] = ACTIONS(1887),
    [anon_sym_nullptr] = ACTIONS(1887),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1887),
    [anon_sym_decltype] = ACTIONS(1887),
    [anon_sym_final] = ACTIONS(1887),
    [anon_sym_override] = ACTIONS(1887),
    [sym_virtual] = ACTIONS(1887),
    [anon_sym_explicit] = ACTIONS(1887),
    [anon_sym_typename] = ACTIONS(1887),
    [anon_sym_template] = ACTIONS(1887),
    [anon_sym_operator] = ACTIONS(1887),
    [anon_sym_try] = ACTIONS(1887),
    [anon_sym_delete] = ACTIONS(1887),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_namespace] = ACTIONS(1887),
    [anon_sym_using] = ACTIONS(1887),
    [anon_sym_static_assert] = ACTIONS(1887),
    [anon_sym_concept] = ACTIONS(1887),
    [anon_sym_co_return] = ACTIONS(1887),
    [anon_sym_co_yield] = ACTIONS(1887),
    [anon_sym_R_DQUOTE] = ACTIONS(1889),
    [anon_sym_LR_DQUOTE] = ACTIONS(1889),
    [anon_sym_uR_DQUOTE] = ACTIONS(1889),
    [anon_sym_UR_DQUOTE] = ACTIONS(1889),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1889),
    [anon_sym_co_await] = ACTIONS(1887),
    [anon_sym_new] = ACTIONS(1887),
    [anon_sym_requires] = ACTIONS(1887),
    [sym_this] = ACTIONS(1887),
    [anon_sym_discard] = ACTIONS(1887),
    [anon_sym_precise] = ACTIONS(1887),
    [anon_sym_shared] = ACTIONS(1887),
    [anon_sym_groupshared] = ACTIONS(1887),
    [anon_sym_uniform] = ACTIONS(1887),
    [anon_sym_row_major] = ACTIONS(1887),
    [anon_sym_column_major] = ACTIONS(1887),
    [anon_sym_globallycoherent] = ACTIONS(1887),
    [anon_sym_centroid] = ACTIONS(1887),
    [anon_sym_noperspective] = ACTIONS(1887),
    [anon_sym_nointerpolation] = ACTIONS(1887),
    [anon_sym_sample] = ACTIONS(1887),
    [anon_sym_linear] = ACTIONS(1887),
    [anon_sym_snorm] = ACTIONS(1887),
    [anon_sym_unorm] = ACTIONS(1887),
    [anon_sym_point] = ACTIONS(1887),
    [anon_sym_line] = ACTIONS(1887),
    [anon_sym_triangleadj] = ACTIONS(1887),
    [anon_sym_lineadj] = ACTIONS(1887),
    [anon_sym_triangle] = ACTIONS(1887),
    [anon_sym_cbuffer] = ACTIONS(1887),
  },
  [301] = {
    [ts_builtin_sym_end] = ACTIONS(1893),
    [sym_identifier] = ACTIONS(1891),
    [aux_sym_preproc_include_token1] = ACTIONS(1891),
    [aux_sym_preproc_def_token1] = ACTIONS(1891),
    [aux_sym_preproc_if_token1] = ACTIONS(1891),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1891),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1891),
    [sym_preproc_directive] = ACTIONS(1891),
    [anon_sym_LPAREN2] = ACTIONS(1893),
    [anon_sym_BANG] = ACTIONS(1893),
    [anon_sym_TILDE] = ACTIONS(1893),
    [anon_sym_DASH] = ACTIONS(1891),
    [anon_sym_PLUS] = ACTIONS(1891),
    [anon_sym_STAR] = ACTIONS(1893),
    [anon_sym_AMP_AMP] = ACTIONS(1893),
    [anon_sym_AMP] = ACTIONS(1891),
    [anon_sym_COLON] = ACTIONS(1891),
    [anon_sym_SEMI] = ACTIONS(1893),
    [anon_sym___extension__] = ACTIONS(1891),
    [anon_sym_typedef] = ACTIONS(1891),
    [anon_sym_in] = ACTIONS(1891),
    [anon_sym_out] = ACTIONS(1891),
    [anon_sym_inout] = ACTIONS(1891),
    [anon_sym_extern] = ACTIONS(1891),
    [anon_sym___attribute__] = ACTIONS(1891),
    [anon_sym_COLON_COLON] = ACTIONS(1893),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1893),
    [anon_sym___declspec] = ACTIONS(1891),
    [anon_sym___based] = ACTIONS(1891),
    [anon_sym___cdecl] = ACTIONS(1891),
    [anon_sym___clrcall] = ACTIONS(1891),
    [anon_sym___stdcall] = ACTIONS(1891),
    [anon_sym___fastcall] = ACTIONS(1891),
    [anon_sym___thiscall] = ACTIONS(1891),
    [anon_sym___vectorcall] = ACTIONS(1891),
    [anon_sym_LBRACE] = ACTIONS(1893),
    [anon_sym_signed] = ACTIONS(1891),
    [anon_sym_unsigned] = ACTIONS(1891),
    [anon_sym_long] = ACTIONS(1891),
    [anon_sym_short] = ACTIONS(1891),
    [anon_sym_LBRACK] = ACTIONS(1891),
    [anon_sym_static] = ACTIONS(1891),
    [anon_sym_register] = ACTIONS(1891),
    [anon_sym_inline] = ACTIONS(1891),
    [anon_sym___inline] = ACTIONS(1891),
    [anon_sym___inline__] = ACTIONS(1891),
    [anon_sym___forceinline] = ACTIONS(1891),
    [anon_sym_thread_local] = ACTIONS(1891),
    [anon_sym___thread] = ACTIONS(1891),
    [anon_sym_const] = ACTIONS(1891),
    [anon_sym_constexpr] = ACTIONS(1891),
    [anon_sym_volatile] = ACTIONS(1891),
    [anon_sym_restrict] = ACTIONS(1891),
    [anon_sym___restrict__] = ACTIONS(1891),
    [anon_sym__Atomic] = ACTIONS(1891),
    [anon_sym__Noreturn] = ACTIONS(1891),
    [anon_sym_noreturn] = ACTIONS(1891),
    [anon_sym_mutable] = ACTIONS(1891),
    [anon_sym_constinit] = ACTIONS(1891),
    [anon_sym_consteval] = ACTIONS(1891),
    [anon_sym_alignas] = ACTIONS(1891),
    [anon_sym__Alignas] = ACTIONS(1891),
    [sym_primitive_type] = ACTIONS(1891),
    [anon_sym_enum] = ACTIONS(1891),
    [anon_sym_class] = ACTIONS(1891),
    [anon_sym_struct] = ACTIONS(1891),
    [anon_sym_union] = ACTIONS(1891),
    [anon_sym_if] = ACTIONS(1891),
    [anon_sym_else] = ACTIONS(1891),
    [anon_sym_switch] = ACTIONS(1891),
    [anon_sym_case] = ACTIONS(1891),
    [anon_sym_default] = ACTIONS(1891),
    [anon_sym_while] = ACTIONS(1891),
    [anon_sym_do] = ACTIONS(1891),
    [anon_sym_for] = ACTIONS(1891),
    [anon_sym_return] = ACTIONS(1891),
    [anon_sym_break] = ACTIONS(1891),
    [anon_sym_continue] = ACTIONS(1891),
    [anon_sym_goto] = ACTIONS(1891),
    [anon_sym___try] = ACTIONS(1891),
    [anon_sym___leave] = ACTIONS(1891),
    [anon_sym_not] = ACTIONS(1891),
    [anon_sym_compl] = ACTIONS(1891),
    [anon_sym_DASH_DASH] = ACTIONS(1893),
    [anon_sym_PLUS_PLUS] = ACTIONS(1893),
    [anon_sym_sizeof] = ACTIONS(1891),
    [anon_sym___alignof__] = ACTIONS(1891),
    [anon_sym___alignof] = ACTIONS(1891),
    [anon_sym__alignof] = ACTIONS(1891),
    [anon_sym_alignof] = ACTIONS(1891),
    [anon_sym__Alignof] = ACTIONS(1891),
    [anon_sym_offsetof] = ACTIONS(1891),
    [anon_sym__Generic] = ACTIONS(1891),
    [anon_sym_asm] = ACTIONS(1891),
    [anon_sym___asm__] = ACTIONS(1891),
    [sym_number_literal] = ACTIONS(1893),
    [anon_sym_L_SQUOTE] = ACTIONS(1893),
    [anon_sym_u_SQUOTE] = ACTIONS(1893),
    [anon_sym_U_SQUOTE] = ACTIONS(1893),
    [anon_sym_u8_SQUOTE] = ACTIONS(1893),
    [anon_sym_SQUOTE] = ACTIONS(1893),
    [anon_sym_L_DQUOTE] = ACTIONS(1893),
    [anon_sym_u_DQUOTE] = ACTIONS(1893),
    [anon_sym_U_DQUOTE] = ACTIONS(1893),
    [anon_sym_u8_DQUOTE] = ACTIONS(1893),
    [anon_sym_DQUOTE] = ACTIONS(1893),
    [sym_true] = ACTIONS(1891),
    [sym_false] = ACTIONS(1891),
    [anon_sym_NULL] = ACTIONS(1891),
    [anon_sym_nullptr] = ACTIONS(1891),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1891),
    [anon_sym_decltype] = ACTIONS(1891),
    [anon_sym_final] = ACTIONS(1891),
    [anon_sym_override] = ACTIONS(1891),
    [sym_virtual] = ACTIONS(1891),
    [anon_sym_explicit] = ACTIONS(1891),
    [anon_sym_typename] = ACTIONS(1891),
    [anon_sym_template] = ACTIONS(1891),
    [anon_sym_operator] = ACTIONS(1891),
    [anon_sym_try] = ACTIONS(1891),
    [anon_sym_delete] = ACTIONS(1891),
    [anon_sym_throw] = ACTIONS(1891),
    [anon_sym_namespace] = ACTIONS(1891),
    [anon_sym_using] = ACTIONS(1891),
    [anon_sym_static_assert] = ACTIONS(1891),
    [anon_sym_concept] = ACTIONS(1891),
    [anon_sym_co_return] = ACTIONS(1891),
    [anon_sym_co_yield] = ACTIONS(1891),
    [anon_sym_R_DQUOTE] = ACTIONS(1893),
    [anon_sym_LR_DQUOTE] = ACTIONS(1893),
    [anon_sym_uR_DQUOTE] = ACTIONS(1893),
    [anon_sym_UR_DQUOTE] = ACTIONS(1893),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1893),
    [anon_sym_co_await] = ACTIONS(1891),
    [anon_sym_new] = ACTIONS(1891),
    [anon_sym_requires] = ACTIONS(1891),
    [sym_this] = ACTIONS(1891),
    [anon_sym_discard] = ACTIONS(1891),
    [anon_sym_precise] = ACTIONS(1891),
    [anon_sym_shared] = ACTIONS(1891),
    [anon_sym_groupshared] = ACTIONS(1891),
    [anon_sym_uniform] = ACTIONS(1891),
    [anon_sym_row_major] = ACTIONS(1891),
    [anon_sym_column_major] = ACTIONS(1891),
    [anon_sym_globallycoherent] = ACTIONS(1891),
    [anon_sym_centroid] = ACTIONS(1891),
    [anon_sym_noperspective] = ACTIONS(1891),
    [anon_sym_nointerpolation] = ACTIONS(1891),
    [anon_sym_sample] = ACTIONS(1891),
    [anon_sym_linear] = ACTIONS(1891),
    [anon_sym_snorm] = ACTIONS(1891),
    [anon_sym_unorm] = ACTIONS(1891),
    [anon_sym_point] = ACTIONS(1891),
    [anon_sym_line] = ACTIONS(1891),
    [anon_sym_triangleadj] = ACTIONS(1891),
    [anon_sym_lineadj] = ACTIONS(1891),
    [anon_sym_triangle] = ACTIONS(1891),
    [anon_sym_cbuffer] = ACTIONS(1891),
  },
  [302] = {
    [ts_builtin_sym_end] = ACTIONS(1955),
    [sym_identifier] = ACTIONS(1953),
    [aux_sym_preproc_include_token1] = ACTIONS(1953),
    [aux_sym_preproc_def_token1] = ACTIONS(1953),
    [aux_sym_preproc_if_token1] = ACTIONS(1953),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1953),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1953),
    [sym_preproc_directive] = ACTIONS(1953),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_BANG] = ACTIONS(1955),
    [anon_sym_TILDE] = ACTIONS(1955),
    [anon_sym_DASH] = ACTIONS(1953),
    [anon_sym_PLUS] = ACTIONS(1953),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym_COLON] = ACTIONS(1953),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym_typedef] = ACTIONS(1953),
    [anon_sym_in] = ACTIONS(1953),
    [anon_sym_out] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1953),
    [anon_sym_extern] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1955),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1955),
    [anon_sym___declspec] = ACTIONS(1953),
    [anon_sym___based] = ACTIONS(1953),
    [anon_sym___cdecl] = ACTIONS(1953),
    [anon_sym___clrcall] = ACTIONS(1953),
    [anon_sym___stdcall] = ACTIONS(1953),
    [anon_sym___fastcall] = ACTIONS(1953),
    [anon_sym___thiscall] = ACTIONS(1953),
    [anon_sym___vectorcall] = ACTIONS(1953),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_signed] = ACTIONS(1953),
    [anon_sym_unsigned] = ACTIONS(1953),
    [anon_sym_long] = ACTIONS(1953),
    [anon_sym_short] = ACTIONS(1953),
    [anon_sym_LBRACK] = ACTIONS(1953),
    [anon_sym_static] = ACTIONS(1953),
    [anon_sym_register] = ACTIONS(1953),
    [anon_sym_inline] = ACTIONS(1953),
    [anon_sym___inline] = ACTIONS(1953),
    [anon_sym___inline__] = ACTIONS(1953),
    [anon_sym___forceinline] = ACTIONS(1953),
    [anon_sym_thread_local] = ACTIONS(1953),
    [anon_sym___thread] = ACTIONS(1953),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [sym_primitive_type] = ACTIONS(1953),
    [anon_sym_enum] = ACTIONS(1953),
    [anon_sym_class] = ACTIONS(1953),
    [anon_sym_struct] = ACTIONS(1953),
    [anon_sym_union] = ACTIONS(1953),
    [anon_sym_if] = ACTIONS(1953),
    [anon_sym_else] = ACTIONS(1953),
    [anon_sym_switch] = ACTIONS(1953),
    [anon_sym_case] = ACTIONS(1953),
    [anon_sym_default] = ACTIONS(1953),
    [anon_sym_while] = ACTIONS(1953),
    [anon_sym_do] = ACTIONS(1953),
    [anon_sym_for] = ACTIONS(1953),
    [anon_sym_return] = ACTIONS(1953),
    [anon_sym_break] = ACTIONS(1953),
    [anon_sym_continue] = ACTIONS(1953),
    [anon_sym_goto] = ACTIONS(1953),
    [anon_sym___try] = ACTIONS(1953),
    [anon_sym___leave] = ACTIONS(1953),
    [anon_sym_not] = ACTIONS(1953),
    [anon_sym_compl] = ACTIONS(1953),
    [anon_sym_DASH_DASH] = ACTIONS(1955),
    [anon_sym_PLUS_PLUS] = ACTIONS(1955),
    [anon_sym_sizeof] = ACTIONS(1953),
    [anon_sym___alignof__] = ACTIONS(1953),
    [anon_sym___alignof] = ACTIONS(1953),
    [anon_sym__alignof] = ACTIONS(1953),
    [anon_sym_alignof] = ACTIONS(1953),
    [anon_sym__Alignof] = ACTIONS(1953),
    [anon_sym_offsetof] = ACTIONS(1953),
    [anon_sym__Generic] = ACTIONS(1953),
    [anon_sym_asm] = ACTIONS(1953),
    [anon_sym___asm__] = ACTIONS(1953),
    [sym_number_literal] = ACTIONS(1955),
    [anon_sym_L_SQUOTE] = ACTIONS(1955),
    [anon_sym_u_SQUOTE] = ACTIONS(1955),
    [anon_sym_U_SQUOTE] = ACTIONS(1955),
    [anon_sym_u8_SQUOTE] = ACTIONS(1955),
    [anon_sym_SQUOTE] = ACTIONS(1955),
    [anon_sym_L_DQUOTE] = ACTIONS(1955),
    [anon_sym_u_DQUOTE] = ACTIONS(1955),
    [anon_sym_U_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8_DQUOTE] = ACTIONS(1955),
    [anon_sym_DQUOTE] = ACTIONS(1955),
    [sym_true] = ACTIONS(1953),
    [sym_false] = ACTIONS(1953),
    [anon_sym_NULL] = ACTIONS(1953),
    [anon_sym_nullptr] = ACTIONS(1953),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
    [sym_virtual] = ACTIONS(1953),
    [anon_sym_explicit] = ACTIONS(1953),
    [anon_sym_typename] = ACTIONS(1953),
    [anon_sym_template] = ACTIONS(1953),
    [anon_sym_operator] = ACTIONS(1953),
    [anon_sym_try] = ACTIONS(1953),
    [anon_sym_delete] = ACTIONS(1953),
    [anon_sym_throw] = ACTIONS(1953),
    [anon_sym_namespace] = ACTIONS(1953),
    [anon_sym_using] = ACTIONS(1953),
    [anon_sym_static_assert] = ACTIONS(1953),
    [anon_sym_concept] = ACTIONS(1953),
    [anon_sym_co_return] = ACTIONS(1953),
    [anon_sym_co_yield] = ACTIONS(1953),
    [anon_sym_R_DQUOTE] = ACTIONS(1955),
    [anon_sym_LR_DQUOTE] = ACTIONS(1955),
    [anon_sym_uR_DQUOTE] = ACTIONS(1955),
    [anon_sym_UR_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1955),
    [anon_sym_co_await] = ACTIONS(1953),
    [anon_sym_new] = ACTIONS(1953),
    [anon_sym_requires] = ACTIONS(1953),
    [sym_this] = ACTIONS(1953),
    [anon_sym_discard] = ACTIONS(1953),
    [anon_sym_precise] = ACTIONS(1953),
    [anon_sym_shared] = ACTIONS(1953),
    [anon_sym_groupshared] = ACTIONS(1953),
    [anon_sym_uniform] = ACTIONS(1953),
    [anon_sym_row_major] = ACTIONS(1953),
    [anon_sym_column_major] = ACTIONS(1953),
    [anon_sym_globallycoherent] = ACTIONS(1953),
    [anon_sym_centroid] = ACTIONS(1953),
    [anon_sym_noperspective] = ACTIONS(1953),
    [anon_sym_nointerpolation] = ACTIONS(1953),
    [anon_sym_sample] = ACTIONS(1953),
    [anon_sym_linear] = ACTIONS(1953),
    [anon_sym_snorm] = ACTIONS(1953),
    [anon_sym_unorm] = ACTIONS(1953),
    [anon_sym_point] = ACTIONS(1953),
    [anon_sym_line] = ACTIONS(1953),
    [anon_sym_triangleadj] = ACTIONS(1953),
    [anon_sym_lineadj] = ACTIONS(1953),
    [anon_sym_triangle] = ACTIONS(1953),
    [anon_sym_cbuffer] = ACTIONS(1953),
  },
  [303] = {
    [sym_identifier] = ACTIONS(2470),
    [aux_sym_preproc_include_token1] = ACTIONS(2470),
    [aux_sym_preproc_def_token1] = ACTIONS(2470),
    [aux_sym_preproc_if_token1] = ACTIONS(2470),
    [aux_sym_preproc_if_token2] = ACTIONS(2470),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2470),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2470),
    [aux_sym_preproc_else_token1] = ACTIONS(2470),
    [aux_sym_preproc_elif_token1] = ACTIONS(2470),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2470),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2470),
    [sym_preproc_directive] = ACTIONS(2470),
    [anon_sym_LPAREN2] = ACTIONS(2472),
    [anon_sym_BANG] = ACTIONS(2472),
    [anon_sym_TILDE] = ACTIONS(2472),
    [anon_sym_DASH] = ACTIONS(2470),
    [anon_sym_PLUS] = ACTIONS(2470),
    [anon_sym_STAR] = ACTIONS(2472),
    [anon_sym_AMP_AMP] = ACTIONS(2472),
    [anon_sym_AMP] = ACTIONS(2470),
    [anon_sym_SEMI] = ACTIONS(2472),
    [anon_sym___extension__] = ACTIONS(2470),
    [anon_sym_typedef] = ACTIONS(2470),
    [anon_sym_in] = ACTIONS(2470),
    [anon_sym_out] = ACTIONS(2470),
    [anon_sym_inout] = ACTIONS(2470),
    [anon_sym_extern] = ACTIONS(2470),
    [anon_sym___attribute__] = ACTIONS(2470),
    [anon_sym_COLON_COLON] = ACTIONS(2472),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2472),
    [anon_sym___declspec] = ACTIONS(2470),
    [anon_sym___based] = ACTIONS(2470),
    [anon_sym___cdecl] = ACTIONS(2470),
    [anon_sym___clrcall] = ACTIONS(2470),
    [anon_sym___stdcall] = ACTIONS(2470),
    [anon_sym___fastcall] = ACTIONS(2470),
    [anon_sym___thiscall] = ACTIONS(2470),
    [anon_sym___vectorcall] = ACTIONS(2470),
    [anon_sym_LBRACE] = ACTIONS(2472),
    [anon_sym_signed] = ACTIONS(2470),
    [anon_sym_unsigned] = ACTIONS(2470),
    [anon_sym_long] = ACTIONS(2470),
    [anon_sym_short] = ACTIONS(2470),
    [anon_sym_LBRACK] = ACTIONS(2470),
    [anon_sym_static] = ACTIONS(2470),
    [anon_sym_register] = ACTIONS(2470),
    [anon_sym_inline] = ACTIONS(2470),
    [anon_sym___inline] = ACTIONS(2470),
    [anon_sym___inline__] = ACTIONS(2470),
    [anon_sym___forceinline] = ACTIONS(2470),
    [anon_sym_thread_local] = ACTIONS(2470),
    [anon_sym___thread] = ACTIONS(2470),
    [anon_sym_const] = ACTIONS(2470),
    [anon_sym_constexpr] = ACTIONS(2470),
    [anon_sym_volatile] = ACTIONS(2470),
    [anon_sym_restrict] = ACTIONS(2470),
    [anon_sym___restrict__] = ACTIONS(2470),
    [anon_sym__Atomic] = ACTIONS(2470),
    [anon_sym__Noreturn] = ACTIONS(2470),
    [anon_sym_noreturn] = ACTIONS(2470),
    [anon_sym_mutable] = ACTIONS(2470),
    [anon_sym_constinit] = ACTIONS(2470),
    [anon_sym_consteval] = ACTIONS(2470),
    [anon_sym_alignas] = ACTIONS(2470),
    [anon_sym__Alignas] = ACTIONS(2470),
    [sym_primitive_type] = ACTIONS(2470),
    [anon_sym_enum] = ACTIONS(2470),
    [anon_sym_class] = ACTIONS(2470),
    [anon_sym_struct] = ACTIONS(2470),
    [anon_sym_union] = ACTIONS(2470),
    [anon_sym_if] = ACTIONS(2470),
    [anon_sym_switch] = ACTIONS(2470),
    [anon_sym_case] = ACTIONS(2470),
    [anon_sym_default] = ACTIONS(2470),
    [anon_sym_while] = ACTIONS(2470),
    [anon_sym_do] = ACTIONS(2470),
    [anon_sym_for] = ACTIONS(2470),
    [anon_sym_return] = ACTIONS(2470),
    [anon_sym_break] = ACTIONS(2470),
    [anon_sym_continue] = ACTIONS(2470),
    [anon_sym_goto] = ACTIONS(2470),
    [anon_sym___try] = ACTIONS(2470),
    [anon_sym___leave] = ACTIONS(2470),
    [anon_sym_not] = ACTIONS(2470),
    [anon_sym_compl] = ACTIONS(2470),
    [anon_sym_DASH_DASH] = ACTIONS(2472),
    [anon_sym_PLUS_PLUS] = ACTIONS(2472),
    [anon_sym_sizeof] = ACTIONS(2470),
    [anon_sym___alignof__] = ACTIONS(2470),
    [anon_sym___alignof] = ACTIONS(2470),
    [anon_sym__alignof] = ACTIONS(2470),
    [anon_sym_alignof] = ACTIONS(2470),
    [anon_sym__Alignof] = ACTIONS(2470),
    [anon_sym_offsetof] = ACTIONS(2470),
    [anon_sym__Generic] = ACTIONS(2470),
    [anon_sym_asm] = ACTIONS(2470),
    [anon_sym___asm__] = ACTIONS(2470),
    [sym_number_literal] = ACTIONS(2472),
    [anon_sym_L_SQUOTE] = ACTIONS(2472),
    [anon_sym_u_SQUOTE] = ACTIONS(2472),
    [anon_sym_U_SQUOTE] = ACTIONS(2472),
    [anon_sym_u8_SQUOTE] = ACTIONS(2472),
    [anon_sym_SQUOTE] = ACTIONS(2472),
    [anon_sym_L_DQUOTE] = ACTIONS(2472),
    [anon_sym_u_DQUOTE] = ACTIONS(2472),
    [anon_sym_U_DQUOTE] = ACTIONS(2472),
    [anon_sym_u8_DQUOTE] = ACTIONS(2472),
    [anon_sym_DQUOTE] = ACTIONS(2472),
    [sym_true] = ACTIONS(2470),
    [sym_false] = ACTIONS(2470),
    [anon_sym_NULL] = ACTIONS(2470),
    [anon_sym_nullptr] = ACTIONS(2470),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2470),
    [anon_sym_decltype] = ACTIONS(2470),
    [sym_virtual] = ACTIONS(2470),
    [anon_sym_explicit] = ACTIONS(2470),
    [anon_sym_typename] = ACTIONS(2470),
    [anon_sym_template] = ACTIONS(2470),
    [anon_sym_operator] = ACTIONS(2470),
    [anon_sym_try] = ACTIONS(2470),
    [anon_sym_delete] = ACTIONS(2470),
    [anon_sym_throw] = ACTIONS(2470),
    [anon_sym_namespace] = ACTIONS(2470),
    [anon_sym_using] = ACTIONS(2470),
    [anon_sym_static_assert] = ACTIONS(2470),
    [anon_sym_concept] = ACTIONS(2470),
    [anon_sym_co_return] = ACTIONS(2470),
    [anon_sym_co_yield] = ACTIONS(2470),
    [anon_sym_R_DQUOTE] = ACTIONS(2472),
    [anon_sym_LR_DQUOTE] = ACTIONS(2472),
    [anon_sym_uR_DQUOTE] = ACTIONS(2472),
    [anon_sym_UR_DQUOTE] = ACTIONS(2472),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2472),
    [anon_sym_co_await] = ACTIONS(2470),
    [anon_sym_new] = ACTIONS(2470),
    [anon_sym_requires] = ACTIONS(2470),
    [sym_this] = ACTIONS(2470),
    [anon_sym_discard] = ACTIONS(2470),
    [anon_sym_precise] = ACTIONS(2470),
    [anon_sym_shared] = ACTIONS(2470),
    [anon_sym_groupshared] = ACTIONS(2470),
    [anon_sym_uniform] = ACTIONS(2470),
    [anon_sym_row_major] = ACTIONS(2470),
    [anon_sym_column_major] = ACTIONS(2470),
    [anon_sym_globallycoherent] = ACTIONS(2470),
    [anon_sym_centroid] = ACTIONS(2470),
    [anon_sym_noperspective] = ACTIONS(2470),
    [anon_sym_nointerpolation] = ACTIONS(2470),
    [anon_sym_sample] = ACTIONS(2470),
    [anon_sym_linear] = ACTIONS(2470),
    [anon_sym_snorm] = ACTIONS(2470),
    [anon_sym_unorm] = ACTIONS(2470),
    [anon_sym_point] = ACTIONS(2470),
    [anon_sym_line] = ACTIONS(2470),
    [anon_sym_triangleadj] = ACTIONS(2470),
    [anon_sym_lineadj] = ACTIONS(2470),
    [anon_sym_triangle] = ACTIONS(2470),
    [anon_sym_cbuffer] = ACTIONS(2470),
  },
  [304] = {
    [sym_identifier] = ACTIONS(2474),
    [aux_sym_preproc_include_token1] = ACTIONS(2474),
    [aux_sym_preproc_def_token1] = ACTIONS(2474),
    [aux_sym_preproc_if_token1] = ACTIONS(2474),
    [aux_sym_preproc_if_token2] = ACTIONS(2474),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2474),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2474),
    [aux_sym_preproc_else_token1] = ACTIONS(2474),
    [aux_sym_preproc_elif_token1] = ACTIONS(2474),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2474),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2474),
    [sym_preproc_directive] = ACTIONS(2474),
    [anon_sym_LPAREN2] = ACTIONS(2476),
    [anon_sym_BANG] = ACTIONS(2476),
    [anon_sym_TILDE] = ACTIONS(2476),
    [anon_sym_DASH] = ACTIONS(2474),
    [anon_sym_PLUS] = ACTIONS(2474),
    [anon_sym_STAR] = ACTIONS(2476),
    [anon_sym_AMP_AMP] = ACTIONS(2476),
    [anon_sym_AMP] = ACTIONS(2474),
    [anon_sym_SEMI] = ACTIONS(2476),
    [anon_sym___extension__] = ACTIONS(2474),
    [anon_sym_typedef] = ACTIONS(2474),
    [anon_sym_in] = ACTIONS(2474),
    [anon_sym_out] = ACTIONS(2474),
    [anon_sym_inout] = ACTIONS(2474),
    [anon_sym_extern] = ACTIONS(2474),
    [anon_sym___attribute__] = ACTIONS(2474),
    [anon_sym_COLON_COLON] = ACTIONS(2476),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2476),
    [anon_sym___declspec] = ACTIONS(2474),
    [anon_sym___based] = ACTIONS(2474),
    [anon_sym___cdecl] = ACTIONS(2474),
    [anon_sym___clrcall] = ACTIONS(2474),
    [anon_sym___stdcall] = ACTIONS(2474),
    [anon_sym___fastcall] = ACTIONS(2474),
    [anon_sym___thiscall] = ACTIONS(2474),
    [anon_sym___vectorcall] = ACTIONS(2474),
    [anon_sym_LBRACE] = ACTIONS(2476),
    [anon_sym_signed] = ACTIONS(2474),
    [anon_sym_unsigned] = ACTIONS(2474),
    [anon_sym_long] = ACTIONS(2474),
    [anon_sym_short] = ACTIONS(2474),
    [anon_sym_LBRACK] = ACTIONS(2474),
    [anon_sym_static] = ACTIONS(2474),
    [anon_sym_register] = ACTIONS(2474),
    [anon_sym_inline] = ACTIONS(2474),
    [anon_sym___inline] = ACTIONS(2474),
    [anon_sym___inline__] = ACTIONS(2474),
    [anon_sym___forceinline] = ACTIONS(2474),
    [anon_sym_thread_local] = ACTIONS(2474),
    [anon_sym___thread] = ACTIONS(2474),
    [anon_sym_const] = ACTIONS(2474),
    [anon_sym_constexpr] = ACTIONS(2474),
    [anon_sym_volatile] = ACTIONS(2474),
    [anon_sym_restrict] = ACTIONS(2474),
    [anon_sym___restrict__] = ACTIONS(2474),
    [anon_sym__Atomic] = ACTIONS(2474),
    [anon_sym__Noreturn] = ACTIONS(2474),
    [anon_sym_noreturn] = ACTIONS(2474),
    [anon_sym_mutable] = ACTIONS(2474),
    [anon_sym_constinit] = ACTIONS(2474),
    [anon_sym_consteval] = ACTIONS(2474),
    [anon_sym_alignas] = ACTIONS(2474),
    [anon_sym__Alignas] = ACTIONS(2474),
    [sym_primitive_type] = ACTIONS(2474),
    [anon_sym_enum] = ACTIONS(2474),
    [anon_sym_class] = ACTIONS(2474),
    [anon_sym_struct] = ACTIONS(2474),
    [anon_sym_union] = ACTIONS(2474),
    [anon_sym_if] = ACTIONS(2474),
    [anon_sym_switch] = ACTIONS(2474),
    [anon_sym_case] = ACTIONS(2474),
    [anon_sym_default] = ACTIONS(2474),
    [anon_sym_while] = ACTIONS(2474),
    [anon_sym_do] = ACTIONS(2474),
    [anon_sym_for] = ACTIONS(2474),
    [anon_sym_return] = ACTIONS(2474),
    [anon_sym_break] = ACTIONS(2474),
    [anon_sym_continue] = ACTIONS(2474),
    [anon_sym_goto] = ACTIONS(2474),
    [anon_sym___try] = ACTIONS(2474),
    [anon_sym___leave] = ACTIONS(2474),
    [anon_sym_not] = ACTIONS(2474),
    [anon_sym_compl] = ACTIONS(2474),
    [anon_sym_DASH_DASH] = ACTIONS(2476),
    [anon_sym_PLUS_PLUS] = ACTIONS(2476),
    [anon_sym_sizeof] = ACTIONS(2474),
    [anon_sym___alignof__] = ACTIONS(2474),
    [anon_sym___alignof] = ACTIONS(2474),
    [anon_sym__alignof] = ACTIONS(2474),
    [anon_sym_alignof] = ACTIONS(2474),
    [anon_sym__Alignof] = ACTIONS(2474),
    [anon_sym_offsetof] = ACTIONS(2474),
    [anon_sym__Generic] = ACTIONS(2474),
    [anon_sym_asm] = ACTIONS(2474),
    [anon_sym___asm__] = ACTIONS(2474),
    [sym_number_literal] = ACTIONS(2476),
    [anon_sym_L_SQUOTE] = ACTIONS(2476),
    [anon_sym_u_SQUOTE] = ACTIONS(2476),
    [anon_sym_U_SQUOTE] = ACTIONS(2476),
    [anon_sym_u8_SQUOTE] = ACTIONS(2476),
    [anon_sym_SQUOTE] = ACTIONS(2476),
    [anon_sym_L_DQUOTE] = ACTIONS(2476),
    [anon_sym_u_DQUOTE] = ACTIONS(2476),
    [anon_sym_U_DQUOTE] = ACTIONS(2476),
    [anon_sym_u8_DQUOTE] = ACTIONS(2476),
    [anon_sym_DQUOTE] = ACTIONS(2476),
    [sym_true] = ACTIONS(2474),
    [sym_false] = ACTIONS(2474),
    [anon_sym_NULL] = ACTIONS(2474),
    [anon_sym_nullptr] = ACTIONS(2474),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2474),
    [anon_sym_decltype] = ACTIONS(2474),
    [sym_virtual] = ACTIONS(2474),
    [anon_sym_explicit] = ACTIONS(2474),
    [anon_sym_typename] = ACTIONS(2474),
    [anon_sym_template] = ACTIONS(2474),
    [anon_sym_operator] = ACTIONS(2474),
    [anon_sym_try] = ACTIONS(2474),
    [anon_sym_delete] = ACTIONS(2474),
    [anon_sym_throw] = ACTIONS(2474),
    [anon_sym_namespace] = ACTIONS(2474),
    [anon_sym_using] = ACTIONS(2474),
    [anon_sym_static_assert] = ACTIONS(2474),
    [anon_sym_concept] = ACTIONS(2474),
    [anon_sym_co_return] = ACTIONS(2474),
    [anon_sym_co_yield] = ACTIONS(2474),
    [anon_sym_R_DQUOTE] = ACTIONS(2476),
    [anon_sym_LR_DQUOTE] = ACTIONS(2476),
    [anon_sym_uR_DQUOTE] = ACTIONS(2476),
    [anon_sym_UR_DQUOTE] = ACTIONS(2476),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2476),
    [anon_sym_co_await] = ACTIONS(2474),
    [anon_sym_new] = ACTIONS(2474),
    [anon_sym_requires] = ACTIONS(2474),
    [sym_this] = ACTIONS(2474),
    [anon_sym_discard] = ACTIONS(2474),
    [anon_sym_precise] = ACTIONS(2474),
    [anon_sym_shared] = ACTIONS(2474),
    [anon_sym_groupshared] = ACTIONS(2474),
    [anon_sym_uniform] = ACTIONS(2474),
    [anon_sym_row_major] = ACTIONS(2474),
    [anon_sym_column_major] = ACTIONS(2474),
    [anon_sym_globallycoherent] = ACTIONS(2474),
    [anon_sym_centroid] = ACTIONS(2474),
    [anon_sym_noperspective] = ACTIONS(2474),
    [anon_sym_nointerpolation] = ACTIONS(2474),
    [anon_sym_sample] = ACTIONS(2474),
    [anon_sym_linear] = ACTIONS(2474),
    [anon_sym_snorm] = ACTIONS(2474),
    [anon_sym_unorm] = ACTIONS(2474),
    [anon_sym_point] = ACTIONS(2474),
    [anon_sym_line] = ACTIONS(2474),
    [anon_sym_triangleadj] = ACTIONS(2474),
    [anon_sym_lineadj] = ACTIONS(2474),
    [anon_sym_triangle] = ACTIONS(2474),
    [anon_sym_cbuffer] = ACTIONS(2474),
  },
  [305] = {
    [ts_builtin_sym_end] = ACTIONS(1971),
    [sym_identifier] = ACTIONS(1969),
    [aux_sym_preproc_include_token1] = ACTIONS(1969),
    [aux_sym_preproc_def_token1] = ACTIONS(1969),
    [aux_sym_preproc_if_token1] = ACTIONS(1969),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1969),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1969),
    [sym_preproc_directive] = ACTIONS(1969),
    [anon_sym_LPAREN2] = ACTIONS(1971),
    [anon_sym_BANG] = ACTIONS(1971),
    [anon_sym_TILDE] = ACTIONS(1971),
    [anon_sym_DASH] = ACTIONS(1969),
    [anon_sym_PLUS] = ACTIONS(1969),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_AMP_AMP] = ACTIONS(1971),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_COLON] = ACTIONS(1969),
    [anon_sym_SEMI] = ACTIONS(1971),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym_typedef] = ACTIONS(1969),
    [anon_sym_in] = ACTIONS(1969),
    [anon_sym_out] = ACTIONS(1969),
    [anon_sym_inout] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1971),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym___cdecl] = ACTIONS(1969),
    [anon_sym___clrcall] = ACTIONS(1969),
    [anon_sym___stdcall] = ACTIONS(1969),
    [anon_sym___fastcall] = ACTIONS(1969),
    [anon_sym___thiscall] = ACTIONS(1969),
    [anon_sym___vectorcall] = ACTIONS(1969),
    [anon_sym_LBRACE] = ACTIONS(1971),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1969),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [anon_sym_if] = ACTIONS(1969),
    [anon_sym_else] = ACTIONS(1969),
    [anon_sym_switch] = ACTIONS(1969),
    [anon_sym_case] = ACTIONS(1969),
    [anon_sym_default] = ACTIONS(1969),
    [anon_sym_while] = ACTIONS(1969),
    [anon_sym_do] = ACTIONS(1969),
    [anon_sym_for] = ACTIONS(1969),
    [anon_sym_return] = ACTIONS(1969),
    [anon_sym_break] = ACTIONS(1969),
    [anon_sym_continue] = ACTIONS(1969),
    [anon_sym_goto] = ACTIONS(1969),
    [anon_sym___try] = ACTIONS(1969),
    [anon_sym___leave] = ACTIONS(1969),
    [anon_sym_not] = ACTIONS(1969),
    [anon_sym_compl] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1971),
    [anon_sym_PLUS_PLUS] = ACTIONS(1971),
    [anon_sym_sizeof] = ACTIONS(1969),
    [anon_sym___alignof__] = ACTIONS(1969),
    [anon_sym___alignof] = ACTIONS(1969),
    [anon_sym__alignof] = ACTIONS(1969),
    [anon_sym_alignof] = ACTIONS(1969),
    [anon_sym__Alignof] = ACTIONS(1969),
    [anon_sym_offsetof] = ACTIONS(1969),
    [anon_sym__Generic] = ACTIONS(1969),
    [anon_sym_asm] = ACTIONS(1969),
    [anon_sym___asm__] = ACTIONS(1969),
    [sym_number_literal] = ACTIONS(1971),
    [anon_sym_L_SQUOTE] = ACTIONS(1971),
    [anon_sym_u_SQUOTE] = ACTIONS(1971),
    [anon_sym_U_SQUOTE] = ACTIONS(1971),
    [anon_sym_u8_SQUOTE] = ACTIONS(1971),
    [anon_sym_SQUOTE] = ACTIONS(1971),
    [anon_sym_L_DQUOTE] = ACTIONS(1971),
    [anon_sym_u_DQUOTE] = ACTIONS(1971),
    [anon_sym_U_DQUOTE] = ACTIONS(1971),
    [anon_sym_u8_DQUOTE] = ACTIONS(1971),
    [anon_sym_DQUOTE] = ACTIONS(1971),
    [sym_true] = ACTIONS(1969),
    [sym_false] = ACTIONS(1969),
    [anon_sym_NULL] = ACTIONS(1969),
    [anon_sym_nullptr] = ACTIONS(1969),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_final] = ACTIONS(1969),
    [anon_sym_override] = ACTIONS(1969),
    [sym_virtual] = ACTIONS(1969),
    [anon_sym_explicit] = ACTIONS(1969),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1969),
    [anon_sym_operator] = ACTIONS(1969),
    [anon_sym_try] = ACTIONS(1969),
    [anon_sym_delete] = ACTIONS(1969),
    [anon_sym_throw] = ACTIONS(1969),
    [anon_sym_namespace] = ACTIONS(1969),
    [anon_sym_using] = ACTIONS(1969),
    [anon_sym_static_assert] = ACTIONS(1969),
    [anon_sym_concept] = ACTIONS(1969),
    [anon_sym_co_return] = ACTIONS(1969),
    [anon_sym_co_yield] = ACTIONS(1969),
    [anon_sym_R_DQUOTE] = ACTIONS(1971),
    [anon_sym_LR_DQUOTE] = ACTIONS(1971),
    [anon_sym_uR_DQUOTE] = ACTIONS(1971),
    [anon_sym_UR_DQUOTE] = ACTIONS(1971),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1971),
    [anon_sym_co_await] = ACTIONS(1969),
    [anon_sym_new] = ACTIONS(1969),
    [anon_sym_requires] = ACTIONS(1969),
    [sym_this] = ACTIONS(1969),
    [anon_sym_discard] = ACTIONS(1969),
    [anon_sym_precise] = ACTIONS(1969),
    [anon_sym_shared] = ACTIONS(1969),
    [anon_sym_groupshared] = ACTIONS(1969),
    [anon_sym_uniform] = ACTIONS(1969),
    [anon_sym_row_major] = ACTIONS(1969),
    [anon_sym_column_major] = ACTIONS(1969),
    [anon_sym_globallycoherent] = ACTIONS(1969),
    [anon_sym_centroid] = ACTIONS(1969),
    [anon_sym_noperspective] = ACTIONS(1969),
    [anon_sym_nointerpolation] = ACTIONS(1969),
    [anon_sym_sample] = ACTIONS(1969),
    [anon_sym_linear] = ACTIONS(1969),
    [anon_sym_snorm] = ACTIONS(1969),
    [anon_sym_unorm] = ACTIONS(1969),
    [anon_sym_point] = ACTIONS(1969),
    [anon_sym_line] = ACTIONS(1969),
    [anon_sym_triangleadj] = ACTIONS(1969),
    [anon_sym_lineadj] = ACTIONS(1969),
    [anon_sym_triangle] = ACTIONS(1969),
    [anon_sym_cbuffer] = ACTIONS(1969),
  },
  [306] = {
    [sym_identifier] = ACTIONS(2478),
    [aux_sym_preproc_include_token1] = ACTIONS(2478),
    [aux_sym_preproc_def_token1] = ACTIONS(2478),
    [aux_sym_preproc_if_token1] = ACTIONS(2478),
    [aux_sym_preproc_if_token2] = ACTIONS(2478),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2478),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2478),
    [aux_sym_preproc_else_token1] = ACTIONS(2478),
    [aux_sym_preproc_elif_token1] = ACTIONS(2478),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2478),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2478),
    [sym_preproc_directive] = ACTIONS(2478),
    [anon_sym_LPAREN2] = ACTIONS(2480),
    [anon_sym_BANG] = ACTIONS(2480),
    [anon_sym_TILDE] = ACTIONS(2480),
    [anon_sym_DASH] = ACTIONS(2478),
    [anon_sym_PLUS] = ACTIONS(2478),
    [anon_sym_STAR] = ACTIONS(2480),
    [anon_sym_AMP_AMP] = ACTIONS(2480),
    [anon_sym_AMP] = ACTIONS(2478),
    [anon_sym_SEMI] = ACTIONS(2480),
    [anon_sym___extension__] = ACTIONS(2478),
    [anon_sym_typedef] = ACTIONS(2478),
    [anon_sym_in] = ACTIONS(2478),
    [anon_sym_out] = ACTIONS(2478),
    [anon_sym_inout] = ACTIONS(2478),
    [anon_sym_extern] = ACTIONS(2478),
    [anon_sym___attribute__] = ACTIONS(2478),
    [anon_sym_COLON_COLON] = ACTIONS(2480),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2480),
    [anon_sym___declspec] = ACTIONS(2478),
    [anon_sym___based] = ACTIONS(2478),
    [anon_sym___cdecl] = ACTIONS(2478),
    [anon_sym___clrcall] = ACTIONS(2478),
    [anon_sym___stdcall] = ACTIONS(2478),
    [anon_sym___fastcall] = ACTIONS(2478),
    [anon_sym___thiscall] = ACTIONS(2478),
    [anon_sym___vectorcall] = ACTIONS(2478),
    [anon_sym_LBRACE] = ACTIONS(2480),
    [anon_sym_signed] = ACTIONS(2478),
    [anon_sym_unsigned] = ACTIONS(2478),
    [anon_sym_long] = ACTIONS(2478),
    [anon_sym_short] = ACTIONS(2478),
    [anon_sym_LBRACK] = ACTIONS(2478),
    [anon_sym_static] = ACTIONS(2478),
    [anon_sym_register] = ACTIONS(2478),
    [anon_sym_inline] = ACTIONS(2478),
    [anon_sym___inline] = ACTIONS(2478),
    [anon_sym___inline__] = ACTIONS(2478),
    [anon_sym___forceinline] = ACTIONS(2478),
    [anon_sym_thread_local] = ACTIONS(2478),
    [anon_sym___thread] = ACTIONS(2478),
    [anon_sym_const] = ACTIONS(2478),
    [anon_sym_constexpr] = ACTIONS(2478),
    [anon_sym_volatile] = ACTIONS(2478),
    [anon_sym_restrict] = ACTIONS(2478),
    [anon_sym___restrict__] = ACTIONS(2478),
    [anon_sym__Atomic] = ACTIONS(2478),
    [anon_sym__Noreturn] = ACTIONS(2478),
    [anon_sym_noreturn] = ACTIONS(2478),
    [anon_sym_mutable] = ACTIONS(2478),
    [anon_sym_constinit] = ACTIONS(2478),
    [anon_sym_consteval] = ACTIONS(2478),
    [anon_sym_alignas] = ACTIONS(2478),
    [anon_sym__Alignas] = ACTIONS(2478),
    [sym_primitive_type] = ACTIONS(2478),
    [anon_sym_enum] = ACTIONS(2478),
    [anon_sym_class] = ACTIONS(2478),
    [anon_sym_struct] = ACTIONS(2478),
    [anon_sym_union] = ACTIONS(2478),
    [anon_sym_if] = ACTIONS(2478),
    [anon_sym_switch] = ACTIONS(2478),
    [anon_sym_case] = ACTIONS(2478),
    [anon_sym_default] = ACTIONS(2478),
    [anon_sym_while] = ACTIONS(2478),
    [anon_sym_do] = ACTIONS(2478),
    [anon_sym_for] = ACTIONS(2478),
    [anon_sym_return] = ACTIONS(2478),
    [anon_sym_break] = ACTIONS(2478),
    [anon_sym_continue] = ACTIONS(2478),
    [anon_sym_goto] = ACTIONS(2478),
    [anon_sym___try] = ACTIONS(2478),
    [anon_sym___leave] = ACTIONS(2478),
    [anon_sym_not] = ACTIONS(2478),
    [anon_sym_compl] = ACTIONS(2478),
    [anon_sym_DASH_DASH] = ACTIONS(2480),
    [anon_sym_PLUS_PLUS] = ACTIONS(2480),
    [anon_sym_sizeof] = ACTIONS(2478),
    [anon_sym___alignof__] = ACTIONS(2478),
    [anon_sym___alignof] = ACTIONS(2478),
    [anon_sym__alignof] = ACTIONS(2478),
    [anon_sym_alignof] = ACTIONS(2478),
    [anon_sym__Alignof] = ACTIONS(2478),
    [anon_sym_offsetof] = ACTIONS(2478),
    [anon_sym__Generic] = ACTIONS(2478),
    [anon_sym_asm] = ACTIONS(2478),
    [anon_sym___asm__] = ACTIONS(2478),
    [sym_number_literal] = ACTIONS(2480),
    [anon_sym_L_SQUOTE] = ACTIONS(2480),
    [anon_sym_u_SQUOTE] = ACTIONS(2480),
    [anon_sym_U_SQUOTE] = ACTIONS(2480),
    [anon_sym_u8_SQUOTE] = ACTIONS(2480),
    [anon_sym_SQUOTE] = ACTIONS(2480),
    [anon_sym_L_DQUOTE] = ACTIONS(2480),
    [anon_sym_u_DQUOTE] = ACTIONS(2480),
    [anon_sym_U_DQUOTE] = ACTIONS(2480),
    [anon_sym_u8_DQUOTE] = ACTIONS(2480),
    [anon_sym_DQUOTE] = ACTIONS(2480),
    [sym_true] = ACTIONS(2478),
    [sym_false] = ACTIONS(2478),
    [anon_sym_NULL] = ACTIONS(2478),
    [anon_sym_nullptr] = ACTIONS(2478),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2478),
    [anon_sym_decltype] = ACTIONS(2478),
    [sym_virtual] = ACTIONS(2478),
    [anon_sym_explicit] = ACTIONS(2478),
    [anon_sym_typename] = ACTIONS(2478),
    [anon_sym_template] = ACTIONS(2478),
    [anon_sym_operator] = ACTIONS(2478),
    [anon_sym_try] = ACTIONS(2478),
    [anon_sym_delete] = ACTIONS(2478),
    [anon_sym_throw] = ACTIONS(2478),
    [anon_sym_namespace] = ACTIONS(2478),
    [anon_sym_using] = ACTIONS(2478),
    [anon_sym_static_assert] = ACTIONS(2478),
    [anon_sym_concept] = ACTIONS(2478),
    [anon_sym_co_return] = ACTIONS(2478),
    [anon_sym_co_yield] = ACTIONS(2478),
    [anon_sym_R_DQUOTE] = ACTIONS(2480),
    [anon_sym_LR_DQUOTE] = ACTIONS(2480),
    [anon_sym_uR_DQUOTE] = ACTIONS(2480),
    [anon_sym_UR_DQUOTE] = ACTIONS(2480),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2480),
    [anon_sym_co_await] = ACTIONS(2478),
    [anon_sym_new] = ACTIONS(2478),
    [anon_sym_requires] = ACTIONS(2478),
    [sym_this] = ACTIONS(2478),
    [anon_sym_discard] = ACTIONS(2478),
    [anon_sym_precise] = ACTIONS(2478),
    [anon_sym_shared] = ACTIONS(2478),
    [anon_sym_groupshared] = ACTIONS(2478),
    [anon_sym_uniform] = ACTIONS(2478),
    [anon_sym_row_major] = ACTIONS(2478),
    [anon_sym_column_major] = ACTIONS(2478),
    [anon_sym_globallycoherent] = ACTIONS(2478),
    [anon_sym_centroid] = ACTIONS(2478),
    [anon_sym_noperspective] = ACTIONS(2478),
    [anon_sym_nointerpolation] = ACTIONS(2478),
    [anon_sym_sample] = ACTIONS(2478),
    [anon_sym_linear] = ACTIONS(2478),
    [anon_sym_snorm] = ACTIONS(2478),
    [anon_sym_unorm] = ACTIONS(2478),
    [anon_sym_point] = ACTIONS(2478),
    [anon_sym_line] = ACTIONS(2478),
    [anon_sym_triangleadj] = ACTIONS(2478),
    [anon_sym_lineadj] = ACTIONS(2478),
    [anon_sym_triangle] = ACTIONS(2478),
    [anon_sym_cbuffer] = ACTIONS(2478),
  },
  [307] = {
    [sym_identifier] = ACTIONS(1953),
    [aux_sym_preproc_include_token1] = ACTIONS(1953),
    [aux_sym_preproc_def_token1] = ACTIONS(1953),
    [aux_sym_preproc_if_token1] = ACTIONS(1953),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1953),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1953),
    [sym_preproc_directive] = ACTIONS(1953),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_BANG] = ACTIONS(1955),
    [anon_sym_TILDE] = ACTIONS(1955),
    [anon_sym_DASH] = ACTIONS(1953),
    [anon_sym_PLUS] = ACTIONS(1953),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym_COLON] = ACTIONS(1953),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym_typedef] = ACTIONS(1953),
    [anon_sym_in] = ACTIONS(1953),
    [anon_sym_out] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1953),
    [anon_sym_extern] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1955),
    [anon_sym___declspec] = ACTIONS(1953),
    [anon_sym___based] = ACTIONS(1953),
    [anon_sym___cdecl] = ACTIONS(1953),
    [anon_sym___clrcall] = ACTIONS(1953),
    [anon_sym___stdcall] = ACTIONS(1953),
    [anon_sym___fastcall] = ACTIONS(1953),
    [anon_sym___thiscall] = ACTIONS(1953),
    [anon_sym___vectorcall] = ACTIONS(1953),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_RBRACE] = ACTIONS(1955),
    [anon_sym_signed] = ACTIONS(1953),
    [anon_sym_unsigned] = ACTIONS(1953),
    [anon_sym_long] = ACTIONS(1953),
    [anon_sym_short] = ACTIONS(1953),
    [anon_sym_LBRACK] = ACTIONS(1953),
    [anon_sym_static] = ACTIONS(1953),
    [anon_sym_register] = ACTIONS(1953),
    [anon_sym_inline] = ACTIONS(1953),
    [anon_sym___inline] = ACTIONS(1953),
    [anon_sym___inline__] = ACTIONS(1953),
    [anon_sym___forceinline] = ACTIONS(1953),
    [anon_sym_thread_local] = ACTIONS(1953),
    [anon_sym___thread] = ACTIONS(1953),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [sym_primitive_type] = ACTIONS(1953),
    [anon_sym_enum] = ACTIONS(1953),
    [anon_sym_class] = ACTIONS(1953),
    [anon_sym_struct] = ACTIONS(1953),
    [anon_sym_union] = ACTIONS(1953),
    [anon_sym_if] = ACTIONS(1953),
    [anon_sym_else] = ACTIONS(1953),
    [anon_sym_switch] = ACTIONS(1953),
    [anon_sym_case] = ACTIONS(1953),
    [anon_sym_default] = ACTIONS(1953),
    [anon_sym_while] = ACTIONS(1953),
    [anon_sym_do] = ACTIONS(1953),
    [anon_sym_for] = ACTIONS(1953),
    [anon_sym_return] = ACTIONS(1953),
    [anon_sym_break] = ACTIONS(1953),
    [anon_sym_continue] = ACTIONS(1953),
    [anon_sym_goto] = ACTIONS(1953),
    [anon_sym___try] = ACTIONS(1953),
    [anon_sym___leave] = ACTIONS(1953),
    [anon_sym_not] = ACTIONS(1953),
    [anon_sym_compl] = ACTIONS(1953),
    [anon_sym_DASH_DASH] = ACTIONS(1955),
    [anon_sym_PLUS_PLUS] = ACTIONS(1955),
    [anon_sym_sizeof] = ACTIONS(1953),
    [anon_sym___alignof__] = ACTIONS(1953),
    [anon_sym___alignof] = ACTIONS(1953),
    [anon_sym__alignof] = ACTIONS(1953),
    [anon_sym_alignof] = ACTIONS(1953),
    [anon_sym__Alignof] = ACTIONS(1953),
    [anon_sym_offsetof] = ACTIONS(1953),
    [anon_sym__Generic] = ACTIONS(1953),
    [anon_sym_asm] = ACTIONS(1953),
    [anon_sym___asm__] = ACTIONS(1953),
    [sym_number_literal] = ACTIONS(1955),
    [anon_sym_L_SQUOTE] = ACTIONS(1955),
    [anon_sym_u_SQUOTE] = ACTIONS(1955),
    [anon_sym_U_SQUOTE] = ACTIONS(1955),
    [anon_sym_u8_SQUOTE] = ACTIONS(1955),
    [anon_sym_SQUOTE] = ACTIONS(1955),
    [anon_sym_L_DQUOTE] = ACTIONS(1955),
    [anon_sym_u_DQUOTE] = ACTIONS(1955),
    [anon_sym_U_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8_DQUOTE] = ACTIONS(1955),
    [anon_sym_DQUOTE] = ACTIONS(1955),
    [sym_true] = ACTIONS(1953),
    [sym_false] = ACTIONS(1953),
    [anon_sym_NULL] = ACTIONS(1953),
    [anon_sym_nullptr] = ACTIONS(1953),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
    [sym_virtual] = ACTIONS(1953),
    [anon_sym_explicit] = ACTIONS(1953),
    [anon_sym_typename] = ACTIONS(1953),
    [anon_sym_template] = ACTIONS(1953),
    [anon_sym_operator] = ACTIONS(1953),
    [anon_sym_try] = ACTIONS(1953),
    [anon_sym_delete] = ACTIONS(1953),
    [anon_sym_throw] = ACTIONS(1953),
    [anon_sym_namespace] = ACTIONS(1953),
    [anon_sym_using] = ACTIONS(1953),
    [anon_sym_static_assert] = ACTIONS(1953),
    [anon_sym_concept] = ACTIONS(1953),
    [anon_sym_co_return] = ACTIONS(1953),
    [anon_sym_co_yield] = ACTIONS(1953),
    [anon_sym_R_DQUOTE] = ACTIONS(1955),
    [anon_sym_LR_DQUOTE] = ACTIONS(1955),
    [anon_sym_uR_DQUOTE] = ACTIONS(1955),
    [anon_sym_UR_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1955),
    [anon_sym_co_await] = ACTIONS(1953),
    [anon_sym_new] = ACTIONS(1953),
    [anon_sym_requires] = ACTIONS(1953),
    [sym_this] = ACTIONS(1953),
    [anon_sym_discard] = ACTIONS(1953),
    [anon_sym_precise] = ACTIONS(1953),
    [anon_sym_shared] = ACTIONS(1953),
    [anon_sym_groupshared] = ACTIONS(1953),
    [anon_sym_uniform] = ACTIONS(1953),
    [anon_sym_row_major] = ACTIONS(1953),
    [anon_sym_column_major] = ACTIONS(1953),
    [anon_sym_globallycoherent] = ACTIONS(1953),
    [anon_sym_centroid] = ACTIONS(1953),
    [anon_sym_noperspective] = ACTIONS(1953),
    [anon_sym_nointerpolation] = ACTIONS(1953),
    [anon_sym_sample] = ACTIONS(1953),
    [anon_sym_linear] = ACTIONS(1953),
    [anon_sym_snorm] = ACTIONS(1953),
    [anon_sym_unorm] = ACTIONS(1953),
    [anon_sym_point] = ACTIONS(1953),
    [anon_sym_line] = ACTIONS(1953),
    [anon_sym_triangleadj] = ACTIONS(1953),
    [anon_sym_lineadj] = ACTIONS(1953),
    [anon_sym_triangle] = ACTIONS(1953),
    [anon_sym_cbuffer] = ACTIONS(1953),
  },
  [308] = {
    [ts_builtin_sym_end] = ACTIONS(1919),
    [sym_identifier] = ACTIONS(1917),
    [aux_sym_preproc_include_token1] = ACTIONS(1917),
    [aux_sym_preproc_def_token1] = ACTIONS(1917),
    [aux_sym_preproc_if_token1] = ACTIONS(1917),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1917),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1917),
    [sym_preproc_directive] = ACTIONS(1917),
    [anon_sym_LPAREN2] = ACTIONS(1919),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1919),
    [anon_sym_AMP_AMP] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1917),
    [anon_sym_COLON] = ACTIONS(1917),
    [anon_sym_SEMI] = ACTIONS(1919),
    [anon_sym___extension__] = ACTIONS(1917),
    [anon_sym_typedef] = ACTIONS(1917),
    [anon_sym_in] = ACTIONS(1917),
    [anon_sym_out] = ACTIONS(1917),
    [anon_sym_inout] = ACTIONS(1917),
    [anon_sym_extern] = ACTIONS(1917),
    [anon_sym___attribute__] = ACTIONS(1917),
    [anon_sym_COLON_COLON] = ACTIONS(1919),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1919),
    [anon_sym___declspec] = ACTIONS(1917),
    [anon_sym___based] = ACTIONS(1917),
    [anon_sym___cdecl] = ACTIONS(1917),
    [anon_sym___clrcall] = ACTIONS(1917),
    [anon_sym___stdcall] = ACTIONS(1917),
    [anon_sym___fastcall] = ACTIONS(1917),
    [anon_sym___thiscall] = ACTIONS(1917),
    [anon_sym___vectorcall] = ACTIONS(1917),
    [anon_sym_LBRACE] = ACTIONS(1919),
    [anon_sym_signed] = ACTIONS(1917),
    [anon_sym_unsigned] = ACTIONS(1917),
    [anon_sym_long] = ACTIONS(1917),
    [anon_sym_short] = ACTIONS(1917),
    [anon_sym_LBRACK] = ACTIONS(1917),
    [anon_sym_static] = ACTIONS(1917),
    [anon_sym_register] = ACTIONS(1917),
    [anon_sym_inline] = ACTIONS(1917),
    [anon_sym___inline] = ACTIONS(1917),
    [anon_sym___inline__] = ACTIONS(1917),
    [anon_sym___forceinline] = ACTIONS(1917),
    [anon_sym_thread_local] = ACTIONS(1917),
    [anon_sym___thread] = ACTIONS(1917),
    [anon_sym_const] = ACTIONS(1917),
    [anon_sym_constexpr] = ACTIONS(1917),
    [anon_sym_volatile] = ACTIONS(1917),
    [anon_sym_restrict] = ACTIONS(1917),
    [anon_sym___restrict__] = ACTIONS(1917),
    [anon_sym__Atomic] = ACTIONS(1917),
    [anon_sym__Noreturn] = ACTIONS(1917),
    [anon_sym_noreturn] = ACTIONS(1917),
    [anon_sym_mutable] = ACTIONS(1917),
    [anon_sym_constinit] = ACTIONS(1917),
    [anon_sym_consteval] = ACTIONS(1917),
    [anon_sym_alignas] = ACTIONS(1917),
    [anon_sym__Alignas] = ACTIONS(1917),
    [sym_primitive_type] = ACTIONS(1917),
    [anon_sym_enum] = ACTIONS(1917),
    [anon_sym_class] = ACTIONS(1917),
    [anon_sym_struct] = ACTIONS(1917),
    [anon_sym_union] = ACTIONS(1917),
    [anon_sym_if] = ACTIONS(1917),
    [anon_sym_else] = ACTIONS(1917),
    [anon_sym_switch] = ACTIONS(1917),
    [anon_sym_case] = ACTIONS(1917),
    [anon_sym_default] = ACTIONS(1917),
    [anon_sym_while] = ACTIONS(1917),
    [anon_sym_do] = ACTIONS(1917),
    [anon_sym_for] = ACTIONS(1917),
    [anon_sym_return] = ACTIONS(1917),
    [anon_sym_break] = ACTIONS(1917),
    [anon_sym_continue] = ACTIONS(1917),
    [anon_sym_goto] = ACTIONS(1917),
    [anon_sym___try] = ACTIONS(1917),
    [anon_sym___leave] = ACTIONS(1917),
    [anon_sym_not] = ACTIONS(1917),
    [anon_sym_compl] = ACTIONS(1917),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_sizeof] = ACTIONS(1917),
    [anon_sym___alignof__] = ACTIONS(1917),
    [anon_sym___alignof] = ACTIONS(1917),
    [anon_sym__alignof] = ACTIONS(1917),
    [anon_sym_alignof] = ACTIONS(1917),
    [anon_sym__Alignof] = ACTIONS(1917),
    [anon_sym_offsetof] = ACTIONS(1917),
    [anon_sym__Generic] = ACTIONS(1917),
    [anon_sym_asm] = ACTIONS(1917),
    [anon_sym___asm__] = ACTIONS(1917),
    [sym_number_literal] = ACTIONS(1919),
    [anon_sym_L_SQUOTE] = ACTIONS(1919),
    [anon_sym_u_SQUOTE] = ACTIONS(1919),
    [anon_sym_U_SQUOTE] = ACTIONS(1919),
    [anon_sym_u8_SQUOTE] = ACTIONS(1919),
    [anon_sym_SQUOTE] = ACTIONS(1919),
    [anon_sym_L_DQUOTE] = ACTIONS(1919),
    [anon_sym_u_DQUOTE] = ACTIONS(1919),
    [anon_sym_U_DQUOTE] = ACTIONS(1919),
    [anon_sym_u8_DQUOTE] = ACTIONS(1919),
    [anon_sym_DQUOTE] = ACTIONS(1919),
    [sym_true] = ACTIONS(1917),
    [sym_false] = ACTIONS(1917),
    [anon_sym_NULL] = ACTIONS(1917),
    [anon_sym_nullptr] = ACTIONS(1917),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1917),
    [anon_sym_decltype] = ACTIONS(1917),
    [anon_sym_final] = ACTIONS(1917),
    [anon_sym_override] = ACTIONS(1917),
    [sym_virtual] = ACTIONS(1917),
    [anon_sym_explicit] = ACTIONS(1917),
    [anon_sym_typename] = ACTIONS(1917),
    [anon_sym_template] = ACTIONS(1917),
    [anon_sym_operator] = ACTIONS(1917),
    [anon_sym_try] = ACTIONS(1917),
    [anon_sym_delete] = ACTIONS(1917),
    [anon_sym_throw] = ACTIONS(1917),
    [anon_sym_namespace] = ACTIONS(1917),
    [anon_sym_using] = ACTIONS(1917),
    [anon_sym_static_assert] = ACTIONS(1917),
    [anon_sym_concept] = ACTIONS(1917),
    [anon_sym_co_return] = ACTIONS(1917),
    [anon_sym_co_yield] = ACTIONS(1917),
    [anon_sym_R_DQUOTE] = ACTIONS(1919),
    [anon_sym_LR_DQUOTE] = ACTIONS(1919),
    [anon_sym_uR_DQUOTE] = ACTIONS(1919),
    [anon_sym_UR_DQUOTE] = ACTIONS(1919),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1919),
    [anon_sym_co_await] = ACTIONS(1917),
    [anon_sym_new] = ACTIONS(1917),
    [anon_sym_requires] = ACTIONS(1917),
    [sym_this] = ACTIONS(1917),
    [anon_sym_discard] = ACTIONS(1917),
    [anon_sym_precise] = ACTIONS(1917),
    [anon_sym_shared] = ACTIONS(1917),
    [anon_sym_groupshared] = ACTIONS(1917),
    [anon_sym_uniform] = ACTIONS(1917),
    [anon_sym_row_major] = ACTIONS(1917),
    [anon_sym_column_major] = ACTIONS(1917),
    [anon_sym_globallycoherent] = ACTIONS(1917),
    [anon_sym_centroid] = ACTIONS(1917),
    [anon_sym_noperspective] = ACTIONS(1917),
    [anon_sym_nointerpolation] = ACTIONS(1917),
    [anon_sym_sample] = ACTIONS(1917),
    [anon_sym_linear] = ACTIONS(1917),
    [anon_sym_snorm] = ACTIONS(1917),
    [anon_sym_unorm] = ACTIONS(1917),
    [anon_sym_point] = ACTIONS(1917),
    [anon_sym_line] = ACTIONS(1917),
    [anon_sym_triangleadj] = ACTIONS(1917),
    [anon_sym_lineadj] = ACTIONS(1917),
    [anon_sym_triangle] = ACTIONS(1917),
    [anon_sym_cbuffer] = ACTIONS(1917),
  },
  [309] = {
    [ts_builtin_sym_end] = ACTIONS(1927),
    [sym_identifier] = ACTIONS(1925),
    [aux_sym_preproc_include_token1] = ACTIONS(1925),
    [aux_sym_preproc_def_token1] = ACTIONS(1925),
    [aux_sym_preproc_if_token1] = ACTIONS(1925),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1925),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1925),
    [sym_preproc_directive] = ACTIONS(1925),
    [anon_sym_LPAREN2] = ACTIONS(1927),
    [anon_sym_BANG] = ACTIONS(1927),
    [anon_sym_TILDE] = ACTIONS(1927),
    [anon_sym_DASH] = ACTIONS(1925),
    [anon_sym_PLUS] = ACTIONS(1925),
    [anon_sym_STAR] = ACTIONS(1927),
    [anon_sym_AMP_AMP] = ACTIONS(1927),
    [anon_sym_AMP] = ACTIONS(1925),
    [anon_sym_COLON] = ACTIONS(1925),
    [anon_sym_SEMI] = ACTIONS(1927),
    [anon_sym___extension__] = ACTIONS(1925),
    [anon_sym_typedef] = ACTIONS(1925),
    [anon_sym_in] = ACTIONS(1925),
    [anon_sym_out] = ACTIONS(1925),
    [anon_sym_inout] = ACTIONS(1925),
    [anon_sym_extern] = ACTIONS(1925),
    [anon_sym___attribute__] = ACTIONS(1925),
    [anon_sym_COLON_COLON] = ACTIONS(1927),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1927),
    [anon_sym___declspec] = ACTIONS(1925),
    [anon_sym___based] = ACTIONS(1925),
    [anon_sym___cdecl] = ACTIONS(1925),
    [anon_sym___clrcall] = ACTIONS(1925),
    [anon_sym___stdcall] = ACTIONS(1925),
    [anon_sym___fastcall] = ACTIONS(1925),
    [anon_sym___thiscall] = ACTIONS(1925),
    [anon_sym___vectorcall] = ACTIONS(1925),
    [anon_sym_LBRACE] = ACTIONS(1927),
    [anon_sym_signed] = ACTIONS(1925),
    [anon_sym_unsigned] = ACTIONS(1925),
    [anon_sym_long] = ACTIONS(1925),
    [anon_sym_short] = ACTIONS(1925),
    [anon_sym_LBRACK] = ACTIONS(1925),
    [anon_sym_static] = ACTIONS(1925),
    [anon_sym_register] = ACTIONS(1925),
    [anon_sym_inline] = ACTIONS(1925),
    [anon_sym___inline] = ACTIONS(1925),
    [anon_sym___inline__] = ACTIONS(1925),
    [anon_sym___forceinline] = ACTIONS(1925),
    [anon_sym_thread_local] = ACTIONS(1925),
    [anon_sym___thread] = ACTIONS(1925),
    [anon_sym_const] = ACTIONS(1925),
    [anon_sym_constexpr] = ACTIONS(1925),
    [anon_sym_volatile] = ACTIONS(1925),
    [anon_sym_restrict] = ACTIONS(1925),
    [anon_sym___restrict__] = ACTIONS(1925),
    [anon_sym__Atomic] = ACTIONS(1925),
    [anon_sym__Noreturn] = ACTIONS(1925),
    [anon_sym_noreturn] = ACTIONS(1925),
    [anon_sym_mutable] = ACTIONS(1925),
    [anon_sym_constinit] = ACTIONS(1925),
    [anon_sym_consteval] = ACTIONS(1925),
    [anon_sym_alignas] = ACTIONS(1925),
    [anon_sym__Alignas] = ACTIONS(1925),
    [sym_primitive_type] = ACTIONS(1925),
    [anon_sym_enum] = ACTIONS(1925),
    [anon_sym_class] = ACTIONS(1925),
    [anon_sym_struct] = ACTIONS(1925),
    [anon_sym_union] = ACTIONS(1925),
    [anon_sym_if] = ACTIONS(1925),
    [anon_sym_else] = ACTIONS(1925),
    [anon_sym_switch] = ACTIONS(1925),
    [anon_sym_case] = ACTIONS(1925),
    [anon_sym_default] = ACTIONS(1925),
    [anon_sym_while] = ACTIONS(1925),
    [anon_sym_do] = ACTIONS(1925),
    [anon_sym_for] = ACTIONS(1925),
    [anon_sym_return] = ACTIONS(1925),
    [anon_sym_break] = ACTIONS(1925),
    [anon_sym_continue] = ACTIONS(1925),
    [anon_sym_goto] = ACTIONS(1925),
    [anon_sym___try] = ACTIONS(1925),
    [anon_sym___leave] = ACTIONS(1925),
    [anon_sym_not] = ACTIONS(1925),
    [anon_sym_compl] = ACTIONS(1925),
    [anon_sym_DASH_DASH] = ACTIONS(1927),
    [anon_sym_PLUS_PLUS] = ACTIONS(1927),
    [anon_sym_sizeof] = ACTIONS(1925),
    [anon_sym___alignof__] = ACTIONS(1925),
    [anon_sym___alignof] = ACTIONS(1925),
    [anon_sym__alignof] = ACTIONS(1925),
    [anon_sym_alignof] = ACTIONS(1925),
    [anon_sym__Alignof] = ACTIONS(1925),
    [anon_sym_offsetof] = ACTIONS(1925),
    [anon_sym__Generic] = ACTIONS(1925),
    [anon_sym_asm] = ACTIONS(1925),
    [anon_sym___asm__] = ACTIONS(1925),
    [sym_number_literal] = ACTIONS(1927),
    [anon_sym_L_SQUOTE] = ACTIONS(1927),
    [anon_sym_u_SQUOTE] = ACTIONS(1927),
    [anon_sym_U_SQUOTE] = ACTIONS(1927),
    [anon_sym_u8_SQUOTE] = ACTIONS(1927),
    [anon_sym_SQUOTE] = ACTIONS(1927),
    [anon_sym_L_DQUOTE] = ACTIONS(1927),
    [anon_sym_u_DQUOTE] = ACTIONS(1927),
    [anon_sym_U_DQUOTE] = ACTIONS(1927),
    [anon_sym_u8_DQUOTE] = ACTIONS(1927),
    [anon_sym_DQUOTE] = ACTIONS(1927),
    [sym_true] = ACTIONS(1925),
    [sym_false] = ACTIONS(1925),
    [anon_sym_NULL] = ACTIONS(1925),
    [anon_sym_nullptr] = ACTIONS(1925),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1925),
    [anon_sym_decltype] = ACTIONS(1925),
    [anon_sym_final] = ACTIONS(1925),
    [anon_sym_override] = ACTIONS(1925),
    [sym_virtual] = ACTIONS(1925),
    [anon_sym_explicit] = ACTIONS(1925),
    [anon_sym_typename] = ACTIONS(1925),
    [anon_sym_template] = ACTIONS(1925),
    [anon_sym_operator] = ACTIONS(1925),
    [anon_sym_try] = ACTIONS(1925),
    [anon_sym_delete] = ACTIONS(1925),
    [anon_sym_throw] = ACTIONS(1925),
    [anon_sym_namespace] = ACTIONS(1925),
    [anon_sym_using] = ACTIONS(1925),
    [anon_sym_static_assert] = ACTIONS(1925),
    [anon_sym_concept] = ACTIONS(1925),
    [anon_sym_co_return] = ACTIONS(1925),
    [anon_sym_co_yield] = ACTIONS(1925),
    [anon_sym_R_DQUOTE] = ACTIONS(1927),
    [anon_sym_LR_DQUOTE] = ACTIONS(1927),
    [anon_sym_uR_DQUOTE] = ACTIONS(1927),
    [anon_sym_UR_DQUOTE] = ACTIONS(1927),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1927),
    [anon_sym_co_await] = ACTIONS(1925),
    [anon_sym_new] = ACTIONS(1925),
    [anon_sym_requires] = ACTIONS(1925),
    [sym_this] = ACTIONS(1925),
    [anon_sym_discard] = ACTIONS(1925),
    [anon_sym_precise] = ACTIONS(1925),
    [anon_sym_shared] = ACTIONS(1925),
    [anon_sym_groupshared] = ACTIONS(1925),
    [anon_sym_uniform] = ACTIONS(1925),
    [anon_sym_row_major] = ACTIONS(1925),
    [anon_sym_column_major] = ACTIONS(1925),
    [anon_sym_globallycoherent] = ACTIONS(1925),
    [anon_sym_centroid] = ACTIONS(1925),
    [anon_sym_noperspective] = ACTIONS(1925),
    [anon_sym_nointerpolation] = ACTIONS(1925),
    [anon_sym_sample] = ACTIONS(1925),
    [anon_sym_linear] = ACTIONS(1925),
    [anon_sym_snorm] = ACTIONS(1925),
    [anon_sym_unorm] = ACTIONS(1925),
    [anon_sym_point] = ACTIONS(1925),
    [anon_sym_line] = ACTIONS(1925),
    [anon_sym_triangleadj] = ACTIONS(1925),
    [anon_sym_lineadj] = ACTIONS(1925),
    [anon_sym_triangle] = ACTIONS(1925),
    [anon_sym_cbuffer] = ACTIONS(1925),
  },
  [310] = {
    [sym_identifier] = ACTIONS(2482),
    [aux_sym_preproc_include_token1] = ACTIONS(2482),
    [aux_sym_preproc_def_token1] = ACTIONS(2482),
    [aux_sym_preproc_if_token1] = ACTIONS(2482),
    [aux_sym_preproc_if_token2] = ACTIONS(2482),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2482),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2482),
    [aux_sym_preproc_else_token1] = ACTIONS(2482),
    [aux_sym_preproc_elif_token1] = ACTIONS(2482),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2482),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2482),
    [sym_preproc_directive] = ACTIONS(2482),
    [anon_sym_LPAREN2] = ACTIONS(2484),
    [anon_sym_BANG] = ACTIONS(2484),
    [anon_sym_TILDE] = ACTIONS(2484),
    [anon_sym_DASH] = ACTIONS(2482),
    [anon_sym_PLUS] = ACTIONS(2482),
    [anon_sym_STAR] = ACTIONS(2484),
    [anon_sym_AMP_AMP] = ACTIONS(2484),
    [anon_sym_AMP] = ACTIONS(2482),
    [anon_sym_SEMI] = ACTIONS(2484),
    [anon_sym___extension__] = ACTIONS(2482),
    [anon_sym_typedef] = ACTIONS(2482),
    [anon_sym_in] = ACTIONS(2482),
    [anon_sym_out] = ACTIONS(2482),
    [anon_sym_inout] = ACTIONS(2482),
    [anon_sym_extern] = ACTIONS(2482),
    [anon_sym___attribute__] = ACTIONS(2482),
    [anon_sym_COLON_COLON] = ACTIONS(2484),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2484),
    [anon_sym___declspec] = ACTIONS(2482),
    [anon_sym___based] = ACTIONS(2482),
    [anon_sym___cdecl] = ACTIONS(2482),
    [anon_sym___clrcall] = ACTIONS(2482),
    [anon_sym___stdcall] = ACTIONS(2482),
    [anon_sym___fastcall] = ACTIONS(2482),
    [anon_sym___thiscall] = ACTIONS(2482),
    [anon_sym___vectorcall] = ACTIONS(2482),
    [anon_sym_LBRACE] = ACTIONS(2484),
    [anon_sym_signed] = ACTIONS(2482),
    [anon_sym_unsigned] = ACTIONS(2482),
    [anon_sym_long] = ACTIONS(2482),
    [anon_sym_short] = ACTIONS(2482),
    [anon_sym_LBRACK] = ACTIONS(2482),
    [anon_sym_static] = ACTIONS(2482),
    [anon_sym_register] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(2482),
    [anon_sym___inline] = ACTIONS(2482),
    [anon_sym___inline__] = ACTIONS(2482),
    [anon_sym___forceinline] = ACTIONS(2482),
    [anon_sym_thread_local] = ACTIONS(2482),
    [anon_sym___thread] = ACTIONS(2482),
    [anon_sym_const] = ACTIONS(2482),
    [anon_sym_constexpr] = ACTIONS(2482),
    [anon_sym_volatile] = ACTIONS(2482),
    [anon_sym_restrict] = ACTIONS(2482),
    [anon_sym___restrict__] = ACTIONS(2482),
    [anon_sym__Atomic] = ACTIONS(2482),
    [anon_sym__Noreturn] = ACTIONS(2482),
    [anon_sym_noreturn] = ACTIONS(2482),
    [anon_sym_mutable] = ACTIONS(2482),
    [anon_sym_constinit] = ACTIONS(2482),
    [anon_sym_consteval] = ACTIONS(2482),
    [anon_sym_alignas] = ACTIONS(2482),
    [anon_sym__Alignas] = ACTIONS(2482),
    [sym_primitive_type] = ACTIONS(2482),
    [anon_sym_enum] = ACTIONS(2482),
    [anon_sym_class] = ACTIONS(2482),
    [anon_sym_struct] = ACTIONS(2482),
    [anon_sym_union] = ACTIONS(2482),
    [anon_sym_if] = ACTIONS(2482),
    [anon_sym_switch] = ACTIONS(2482),
    [anon_sym_case] = ACTIONS(2482),
    [anon_sym_default] = ACTIONS(2482),
    [anon_sym_while] = ACTIONS(2482),
    [anon_sym_do] = ACTIONS(2482),
    [anon_sym_for] = ACTIONS(2482),
    [anon_sym_return] = ACTIONS(2482),
    [anon_sym_break] = ACTIONS(2482),
    [anon_sym_continue] = ACTIONS(2482),
    [anon_sym_goto] = ACTIONS(2482),
    [anon_sym___try] = ACTIONS(2482),
    [anon_sym___leave] = ACTIONS(2482),
    [anon_sym_not] = ACTIONS(2482),
    [anon_sym_compl] = ACTIONS(2482),
    [anon_sym_DASH_DASH] = ACTIONS(2484),
    [anon_sym_PLUS_PLUS] = ACTIONS(2484),
    [anon_sym_sizeof] = ACTIONS(2482),
    [anon_sym___alignof__] = ACTIONS(2482),
    [anon_sym___alignof] = ACTIONS(2482),
    [anon_sym__alignof] = ACTIONS(2482),
    [anon_sym_alignof] = ACTIONS(2482),
    [anon_sym__Alignof] = ACTIONS(2482),
    [anon_sym_offsetof] = ACTIONS(2482),
    [anon_sym__Generic] = ACTIONS(2482),
    [anon_sym_asm] = ACTIONS(2482),
    [anon_sym___asm__] = ACTIONS(2482),
    [sym_number_literal] = ACTIONS(2484),
    [anon_sym_L_SQUOTE] = ACTIONS(2484),
    [anon_sym_u_SQUOTE] = ACTIONS(2484),
    [anon_sym_U_SQUOTE] = ACTIONS(2484),
    [anon_sym_u8_SQUOTE] = ACTIONS(2484),
    [anon_sym_SQUOTE] = ACTIONS(2484),
    [anon_sym_L_DQUOTE] = ACTIONS(2484),
    [anon_sym_u_DQUOTE] = ACTIONS(2484),
    [anon_sym_U_DQUOTE] = ACTIONS(2484),
    [anon_sym_u8_DQUOTE] = ACTIONS(2484),
    [anon_sym_DQUOTE] = ACTIONS(2484),
    [sym_true] = ACTIONS(2482),
    [sym_false] = ACTIONS(2482),
    [anon_sym_NULL] = ACTIONS(2482),
    [anon_sym_nullptr] = ACTIONS(2482),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2482),
    [anon_sym_decltype] = ACTIONS(2482),
    [sym_virtual] = ACTIONS(2482),
    [anon_sym_explicit] = ACTIONS(2482),
    [anon_sym_typename] = ACTIONS(2482),
    [anon_sym_template] = ACTIONS(2482),
    [anon_sym_operator] = ACTIONS(2482),
    [anon_sym_try] = ACTIONS(2482),
    [anon_sym_delete] = ACTIONS(2482),
    [anon_sym_throw] = ACTIONS(2482),
    [anon_sym_namespace] = ACTIONS(2482),
    [anon_sym_using] = ACTIONS(2482),
    [anon_sym_static_assert] = ACTIONS(2482),
    [anon_sym_concept] = ACTIONS(2482),
    [anon_sym_co_return] = ACTIONS(2482),
    [anon_sym_co_yield] = ACTIONS(2482),
    [anon_sym_R_DQUOTE] = ACTIONS(2484),
    [anon_sym_LR_DQUOTE] = ACTIONS(2484),
    [anon_sym_uR_DQUOTE] = ACTIONS(2484),
    [anon_sym_UR_DQUOTE] = ACTIONS(2484),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2484),
    [anon_sym_co_await] = ACTIONS(2482),
    [anon_sym_new] = ACTIONS(2482),
    [anon_sym_requires] = ACTIONS(2482),
    [sym_this] = ACTIONS(2482),
    [anon_sym_discard] = ACTIONS(2482),
    [anon_sym_precise] = ACTIONS(2482),
    [anon_sym_shared] = ACTIONS(2482),
    [anon_sym_groupshared] = ACTIONS(2482),
    [anon_sym_uniform] = ACTIONS(2482),
    [anon_sym_row_major] = ACTIONS(2482),
    [anon_sym_column_major] = ACTIONS(2482),
    [anon_sym_globallycoherent] = ACTIONS(2482),
    [anon_sym_centroid] = ACTIONS(2482),
    [anon_sym_noperspective] = ACTIONS(2482),
    [anon_sym_nointerpolation] = ACTIONS(2482),
    [anon_sym_sample] = ACTIONS(2482),
    [anon_sym_linear] = ACTIONS(2482),
    [anon_sym_snorm] = ACTIONS(2482),
    [anon_sym_unorm] = ACTIONS(2482),
    [anon_sym_point] = ACTIONS(2482),
    [anon_sym_line] = ACTIONS(2482),
    [anon_sym_triangleadj] = ACTIONS(2482),
    [anon_sym_lineadj] = ACTIONS(2482),
    [anon_sym_triangle] = ACTIONS(2482),
    [anon_sym_cbuffer] = ACTIONS(2482),
  },
  [311] = {
    [ts_builtin_sym_end] = ACTIONS(1955),
    [sym_identifier] = ACTIONS(1953),
    [aux_sym_preproc_include_token1] = ACTIONS(1953),
    [aux_sym_preproc_def_token1] = ACTIONS(1953),
    [aux_sym_preproc_if_token1] = ACTIONS(1953),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1953),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1953),
    [sym_preproc_directive] = ACTIONS(1953),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_BANG] = ACTIONS(1955),
    [anon_sym_TILDE] = ACTIONS(1955),
    [anon_sym_DASH] = ACTIONS(1953),
    [anon_sym_PLUS] = ACTIONS(1953),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym_COLON] = ACTIONS(1953),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym_typedef] = ACTIONS(1953),
    [anon_sym_in] = ACTIONS(1953),
    [anon_sym_out] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1953),
    [anon_sym_extern] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1955),
    [anon_sym___declspec] = ACTIONS(1953),
    [anon_sym___based] = ACTIONS(1953),
    [anon_sym___cdecl] = ACTIONS(1953),
    [anon_sym___clrcall] = ACTIONS(1953),
    [anon_sym___stdcall] = ACTIONS(1953),
    [anon_sym___fastcall] = ACTIONS(1953),
    [anon_sym___thiscall] = ACTIONS(1953),
    [anon_sym___vectorcall] = ACTIONS(1953),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_signed] = ACTIONS(1953),
    [anon_sym_unsigned] = ACTIONS(1953),
    [anon_sym_long] = ACTIONS(1953),
    [anon_sym_short] = ACTIONS(1953),
    [anon_sym_LBRACK] = ACTIONS(1953),
    [anon_sym_static] = ACTIONS(1953),
    [anon_sym_register] = ACTIONS(1953),
    [anon_sym_inline] = ACTIONS(1953),
    [anon_sym___inline] = ACTIONS(1953),
    [anon_sym___inline__] = ACTIONS(1953),
    [anon_sym___forceinline] = ACTIONS(1953),
    [anon_sym_thread_local] = ACTIONS(1953),
    [anon_sym___thread] = ACTIONS(1953),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [sym_primitive_type] = ACTIONS(1953),
    [anon_sym_enum] = ACTIONS(1953),
    [anon_sym_class] = ACTIONS(1953),
    [anon_sym_struct] = ACTIONS(1953),
    [anon_sym_union] = ACTIONS(1953),
    [anon_sym_if] = ACTIONS(1953),
    [anon_sym_else] = ACTIONS(1953),
    [anon_sym_switch] = ACTIONS(1953),
    [anon_sym_case] = ACTIONS(1953),
    [anon_sym_default] = ACTIONS(1953),
    [anon_sym_while] = ACTIONS(1953),
    [anon_sym_do] = ACTIONS(1953),
    [anon_sym_for] = ACTIONS(1953),
    [anon_sym_return] = ACTIONS(1953),
    [anon_sym_break] = ACTIONS(1953),
    [anon_sym_continue] = ACTIONS(1953),
    [anon_sym_goto] = ACTIONS(1953),
    [anon_sym___try] = ACTIONS(1953),
    [anon_sym___leave] = ACTIONS(1953),
    [anon_sym_not] = ACTIONS(1953),
    [anon_sym_compl] = ACTIONS(1953),
    [anon_sym_DASH_DASH] = ACTIONS(1955),
    [anon_sym_PLUS_PLUS] = ACTIONS(1955),
    [anon_sym_sizeof] = ACTIONS(1953),
    [anon_sym___alignof__] = ACTIONS(1953),
    [anon_sym___alignof] = ACTIONS(1953),
    [anon_sym__alignof] = ACTIONS(1953),
    [anon_sym_alignof] = ACTIONS(1953),
    [anon_sym__Alignof] = ACTIONS(1953),
    [anon_sym_offsetof] = ACTIONS(1953),
    [anon_sym__Generic] = ACTIONS(1953),
    [anon_sym_asm] = ACTIONS(1953),
    [anon_sym___asm__] = ACTIONS(1953),
    [sym_number_literal] = ACTIONS(1955),
    [anon_sym_L_SQUOTE] = ACTIONS(1955),
    [anon_sym_u_SQUOTE] = ACTIONS(1955),
    [anon_sym_U_SQUOTE] = ACTIONS(1955),
    [anon_sym_u8_SQUOTE] = ACTIONS(1955),
    [anon_sym_SQUOTE] = ACTIONS(1955),
    [anon_sym_L_DQUOTE] = ACTIONS(1955),
    [anon_sym_u_DQUOTE] = ACTIONS(1955),
    [anon_sym_U_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8_DQUOTE] = ACTIONS(1955),
    [anon_sym_DQUOTE] = ACTIONS(1955),
    [sym_true] = ACTIONS(1953),
    [sym_false] = ACTIONS(1953),
    [anon_sym_NULL] = ACTIONS(1953),
    [anon_sym_nullptr] = ACTIONS(1953),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
    [sym_virtual] = ACTIONS(1953),
    [anon_sym_explicit] = ACTIONS(1953),
    [anon_sym_typename] = ACTIONS(1953),
    [anon_sym_template] = ACTIONS(1953),
    [anon_sym_operator] = ACTIONS(1953),
    [anon_sym_try] = ACTIONS(1953),
    [anon_sym_delete] = ACTIONS(1953),
    [anon_sym_throw] = ACTIONS(1953),
    [anon_sym_namespace] = ACTIONS(1953),
    [anon_sym_using] = ACTIONS(1953),
    [anon_sym_static_assert] = ACTIONS(1953),
    [anon_sym_concept] = ACTIONS(1953),
    [anon_sym_co_return] = ACTIONS(1953),
    [anon_sym_co_yield] = ACTIONS(1953),
    [anon_sym_R_DQUOTE] = ACTIONS(1955),
    [anon_sym_LR_DQUOTE] = ACTIONS(1955),
    [anon_sym_uR_DQUOTE] = ACTIONS(1955),
    [anon_sym_UR_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1955),
    [anon_sym_co_await] = ACTIONS(1953),
    [anon_sym_new] = ACTIONS(1953),
    [anon_sym_requires] = ACTIONS(1953),
    [sym_this] = ACTIONS(1953),
    [anon_sym_discard] = ACTIONS(1953),
    [anon_sym_precise] = ACTIONS(1953),
    [anon_sym_shared] = ACTIONS(1953),
    [anon_sym_groupshared] = ACTIONS(1953),
    [anon_sym_uniform] = ACTIONS(1953),
    [anon_sym_row_major] = ACTIONS(1953),
    [anon_sym_column_major] = ACTIONS(1953),
    [anon_sym_globallycoherent] = ACTIONS(1953),
    [anon_sym_centroid] = ACTIONS(1953),
    [anon_sym_noperspective] = ACTIONS(1953),
    [anon_sym_nointerpolation] = ACTIONS(1953),
    [anon_sym_sample] = ACTIONS(1953),
    [anon_sym_linear] = ACTIONS(1953),
    [anon_sym_snorm] = ACTIONS(1953),
    [anon_sym_unorm] = ACTIONS(1953),
    [anon_sym_point] = ACTIONS(1953),
    [anon_sym_line] = ACTIONS(1953),
    [anon_sym_triangleadj] = ACTIONS(1953),
    [anon_sym_lineadj] = ACTIONS(1953),
    [anon_sym_triangle] = ACTIONS(1953),
    [anon_sym_cbuffer] = ACTIONS(1953),
  },
  [312] = {
    [sym_identifier] = ACTIONS(2486),
    [aux_sym_preproc_include_token1] = ACTIONS(2486),
    [aux_sym_preproc_def_token1] = ACTIONS(2486),
    [aux_sym_preproc_if_token1] = ACTIONS(2486),
    [aux_sym_preproc_if_token2] = ACTIONS(2486),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2486),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2486),
    [aux_sym_preproc_else_token1] = ACTIONS(2486),
    [aux_sym_preproc_elif_token1] = ACTIONS(2486),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2486),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2486),
    [sym_preproc_directive] = ACTIONS(2486),
    [anon_sym_LPAREN2] = ACTIONS(2488),
    [anon_sym_BANG] = ACTIONS(2488),
    [anon_sym_TILDE] = ACTIONS(2488),
    [anon_sym_DASH] = ACTIONS(2486),
    [anon_sym_PLUS] = ACTIONS(2486),
    [anon_sym_STAR] = ACTIONS(2488),
    [anon_sym_AMP_AMP] = ACTIONS(2488),
    [anon_sym_AMP] = ACTIONS(2486),
    [anon_sym_SEMI] = ACTIONS(2488),
    [anon_sym___extension__] = ACTIONS(2486),
    [anon_sym_typedef] = ACTIONS(2486),
    [anon_sym_in] = ACTIONS(2486),
    [anon_sym_out] = ACTIONS(2486),
    [anon_sym_inout] = ACTIONS(2486),
    [anon_sym_extern] = ACTIONS(2486),
    [anon_sym___attribute__] = ACTIONS(2486),
    [anon_sym_COLON_COLON] = ACTIONS(2488),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2488),
    [anon_sym___declspec] = ACTIONS(2486),
    [anon_sym___based] = ACTIONS(2486),
    [anon_sym___cdecl] = ACTIONS(2486),
    [anon_sym___clrcall] = ACTIONS(2486),
    [anon_sym___stdcall] = ACTIONS(2486),
    [anon_sym___fastcall] = ACTIONS(2486),
    [anon_sym___thiscall] = ACTIONS(2486),
    [anon_sym___vectorcall] = ACTIONS(2486),
    [anon_sym_LBRACE] = ACTIONS(2488),
    [anon_sym_signed] = ACTIONS(2486),
    [anon_sym_unsigned] = ACTIONS(2486),
    [anon_sym_long] = ACTIONS(2486),
    [anon_sym_short] = ACTIONS(2486),
    [anon_sym_LBRACK] = ACTIONS(2486),
    [anon_sym_static] = ACTIONS(2486),
    [anon_sym_register] = ACTIONS(2486),
    [anon_sym_inline] = ACTIONS(2486),
    [anon_sym___inline] = ACTIONS(2486),
    [anon_sym___inline__] = ACTIONS(2486),
    [anon_sym___forceinline] = ACTIONS(2486),
    [anon_sym_thread_local] = ACTIONS(2486),
    [anon_sym___thread] = ACTIONS(2486),
    [anon_sym_const] = ACTIONS(2486),
    [anon_sym_constexpr] = ACTIONS(2486),
    [anon_sym_volatile] = ACTIONS(2486),
    [anon_sym_restrict] = ACTIONS(2486),
    [anon_sym___restrict__] = ACTIONS(2486),
    [anon_sym__Atomic] = ACTIONS(2486),
    [anon_sym__Noreturn] = ACTIONS(2486),
    [anon_sym_noreturn] = ACTIONS(2486),
    [anon_sym_mutable] = ACTIONS(2486),
    [anon_sym_constinit] = ACTIONS(2486),
    [anon_sym_consteval] = ACTIONS(2486),
    [anon_sym_alignas] = ACTIONS(2486),
    [anon_sym__Alignas] = ACTIONS(2486),
    [sym_primitive_type] = ACTIONS(2486),
    [anon_sym_enum] = ACTIONS(2486),
    [anon_sym_class] = ACTIONS(2486),
    [anon_sym_struct] = ACTIONS(2486),
    [anon_sym_union] = ACTIONS(2486),
    [anon_sym_if] = ACTIONS(2486),
    [anon_sym_switch] = ACTIONS(2486),
    [anon_sym_case] = ACTIONS(2486),
    [anon_sym_default] = ACTIONS(2486),
    [anon_sym_while] = ACTIONS(2486),
    [anon_sym_do] = ACTIONS(2486),
    [anon_sym_for] = ACTIONS(2486),
    [anon_sym_return] = ACTIONS(2486),
    [anon_sym_break] = ACTIONS(2486),
    [anon_sym_continue] = ACTIONS(2486),
    [anon_sym_goto] = ACTIONS(2486),
    [anon_sym___try] = ACTIONS(2486),
    [anon_sym___leave] = ACTIONS(2486),
    [anon_sym_not] = ACTIONS(2486),
    [anon_sym_compl] = ACTIONS(2486),
    [anon_sym_DASH_DASH] = ACTIONS(2488),
    [anon_sym_PLUS_PLUS] = ACTIONS(2488),
    [anon_sym_sizeof] = ACTIONS(2486),
    [anon_sym___alignof__] = ACTIONS(2486),
    [anon_sym___alignof] = ACTIONS(2486),
    [anon_sym__alignof] = ACTIONS(2486),
    [anon_sym_alignof] = ACTIONS(2486),
    [anon_sym__Alignof] = ACTIONS(2486),
    [anon_sym_offsetof] = ACTIONS(2486),
    [anon_sym__Generic] = ACTIONS(2486),
    [anon_sym_asm] = ACTIONS(2486),
    [anon_sym___asm__] = ACTIONS(2486),
    [sym_number_literal] = ACTIONS(2488),
    [anon_sym_L_SQUOTE] = ACTIONS(2488),
    [anon_sym_u_SQUOTE] = ACTIONS(2488),
    [anon_sym_U_SQUOTE] = ACTIONS(2488),
    [anon_sym_u8_SQUOTE] = ACTIONS(2488),
    [anon_sym_SQUOTE] = ACTIONS(2488),
    [anon_sym_L_DQUOTE] = ACTIONS(2488),
    [anon_sym_u_DQUOTE] = ACTIONS(2488),
    [anon_sym_U_DQUOTE] = ACTIONS(2488),
    [anon_sym_u8_DQUOTE] = ACTIONS(2488),
    [anon_sym_DQUOTE] = ACTIONS(2488),
    [sym_true] = ACTIONS(2486),
    [sym_false] = ACTIONS(2486),
    [anon_sym_NULL] = ACTIONS(2486),
    [anon_sym_nullptr] = ACTIONS(2486),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2486),
    [anon_sym_decltype] = ACTIONS(2486),
    [sym_virtual] = ACTIONS(2486),
    [anon_sym_explicit] = ACTIONS(2486),
    [anon_sym_typename] = ACTIONS(2486),
    [anon_sym_template] = ACTIONS(2486),
    [anon_sym_operator] = ACTIONS(2486),
    [anon_sym_try] = ACTIONS(2486),
    [anon_sym_delete] = ACTIONS(2486),
    [anon_sym_throw] = ACTIONS(2486),
    [anon_sym_namespace] = ACTIONS(2486),
    [anon_sym_using] = ACTIONS(2486),
    [anon_sym_static_assert] = ACTIONS(2486),
    [anon_sym_concept] = ACTIONS(2486),
    [anon_sym_co_return] = ACTIONS(2486),
    [anon_sym_co_yield] = ACTIONS(2486),
    [anon_sym_R_DQUOTE] = ACTIONS(2488),
    [anon_sym_LR_DQUOTE] = ACTIONS(2488),
    [anon_sym_uR_DQUOTE] = ACTIONS(2488),
    [anon_sym_UR_DQUOTE] = ACTIONS(2488),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2488),
    [anon_sym_co_await] = ACTIONS(2486),
    [anon_sym_new] = ACTIONS(2486),
    [anon_sym_requires] = ACTIONS(2486),
    [sym_this] = ACTIONS(2486),
    [anon_sym_discard] = ACTIONS(2486),
    [anon_sym_precise] = ACTIONS(2486),
    [anon_sym_shared] = ACTIONS(2486),
    [anon_sym_groupshared] = ACTIONS(2486),
    [anon_sym_uniform] = ACTIONS(2486),
    [anon_sym_row_major] = ACTIONS(2486),
    [anon_sym_column_major] = ACTIONS(2486),
    [anon_sym_globallycoherent] = ACTIONS(2486),
    [anon_sym_centroid] = ACTIONS(2486),
    [anon_sym_noperspective] = ACTIONS(2486),
    [anon_sym_nointerpolation] = ACTIONS(2486),
    [anon_sym_sample] = ACTIONS(2486),
    [anon_sym_linear] = ACTIONS(2486),
    [anon_sym_snorm] = ACTIONS(2486),
    [anon_sym_unorm] = ACTIONS(2486),
    [anon_sym_point] = ACTIONS(2486),
    [anon_sym_line] = ACTIONS(2486),
    [anon_sym_triangleadj] = ACTIONS(2486),
    [anon_sym_lineadj] = ACTIONS(2486),
    [anon_sym_triangle] = ACTIONS(2486),
    [anon_sym_cbuffer] = ACTIONS(2486),
  },
  [313] = {
    [ts_builtin_sym_end] = ACTIONS(1901),
    [sym_identifier] = ACTIONS(1899),
    [aux_sym_preproc_include_token1] = ACTIONS(1899),
    [aux_sym_preproc_def_token1] = ACTIONS(1899),
    [aux_sym_preproc_if_token1] = ACTIONS(1899),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1899),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1899),
    [sym_preproc_directive] = ACTIONS(1899),
    [anon_sym_LPAREN2] = ACTIONS(1901),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1901),
    [anon_sym_AMP_AMP] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1899),
    [anon_sym_COLON] = ACTIONS(1899),
    [anon_sym_SEMI] = ACTIONS(1901),
    [anon_sym___extension__] = ACTIONS(1899),
    [anon_sym_typedef] = ACTIONS(1899),
    [anon_sym_in] = ACTIONS(1899),
    [anon_sym_out] = ACTIONS(1899),
    [anon_sym_inout] = ACTIONS(1899),
    [anon_sym_extern] = ACTIONS(1899),
    [anon_sym___attribute__] = ACTIONS(1899),
    [anon_sym_COLON_COLON] = ACTIONS(1901),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1901),
    [anon_sym___declspec] = ACTIONS(1899),
    [anon_sym___based] = ACTIONS(1899),
    [anon_sym___cdecl] = ACTIONS(1899),
    [anon_sym___clrcall] = ACTIONS(1899),
    [anon_sym___stdcall] = ACTIONS(1899),
    [anon_sym___fastcall] = ACTIONS(1899),
    [anon_sym___thiscall] = ACTIONS(1899),
    [anon_sym___vectorcall] = ACTIONS(1899),
    [anon_sym_LBRACE] = ACTIONS(1901),
    [anon_sym_signed] = ACTIONS(1899),
    [anon_sym_unsigned] = ACTIONS(1899),
    [anon_sym_long] = ACTIONS(1899),
    [anon_sym_short] = ACTIONS(1899),
    [anon_sym_LBRACK] = ACTIONS(1899),
    [anon_sym_static] = ACTIONS(1899),
    [anon_sym_register] = ACTIONS(1899),
    [anon_sym_inline] = ACTIONS(1899),
    [anon_sym___inline] = ACTIONS(1899),
    [anon_sym___inline__] = ACTIONS(1899),
    [anon_sym___forceinline] = ACTIONS(1899),
    [anon_sym_thread_local] = ACTIONS(1899),
    [anon_sym___thread] = ACTIONS(1899),
    [anon_sym_const] = ACTIONS(1899),
    [anon_sym_constexpr] = ACTIONS(1899),
    [anon_sym_volatile] = ACTIONS(1899),
    [anon_sym_restrict] = ACTIONS(1899),
    [anon_sym___restrict__] = ACTIONS(1899),
    [anon_sym__Atomic] = ACTIONS(1899),
    [anon_sym__Noreturn] = ACTIONS(1899),
    [anon_sym_noreturn] = ACTIONS(1899),
    [anon_sym_mutable] = ACTIONS(1899),
    [anon_sym_constinit] = ACTIONS(1899),
    [anon_sym_consteval] = ACTIONS(1899),
    [anon_sym_alignas] = ACTIONS(1899),
    [anon_sym__Alignas] = ACTIONS(1899),
    [sym_primitive_type] = ACTIONS(1899),
    [anon_sym_enum] = ACTIONS(1899),
    [anon_sym_class] = ACTIONS(1899),
    [anon_sym_struct] = ACTIONS(1899),
    [anon_sym_union] = ACTIONS(1899),
    [anon_sym_if] = ACTIONS(1899),
    [anon_sym_else] = ACTIONS(1899),
    [anon_sym_switch] = ACTIONS(1899),
    [anon_sym_case] = ACTIONS(1899),
    [anon_sym_default] = ACTIONS(1899),
    [anon_sym_while] = ACTIONS(1899),
    [anon_sym_do] = ACTIONS(1899),
    [anon_sym_for] = ACTIONS(1899),
    [anon_sym_return] = ACTIONS(1899),
    [anon_sym_break] = ACTIONS(1899),
    [anon_sym_continue] = ACTIONS(1899),
    [anon_sym_goto] = ACTIONS(1899),
    [anon_sym___try] = ACTIONS(1899),
    [anon_sym___leave] = ACTIONS(1899),
    [anon_sym_not] = ACTIONS(1899),
    [anon_sym_compl] = ACTIONS(1899),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_sizeof] = ACTIONS(1899),
    [anon_sym___alignof__] = ACTIONS(1899),
    [anon_sym___alignof] = ACTIONS(1899),
    [anon_sym__alignof] = ACTIONS(1899),
    [anon_sym_alignof] = ACTIONS(1899),
    [anon_sym__Alignof] = ACTIONS(1899),
    [anon_sym_offsetof] = ACTIONS(1899),
    [anon_sym__Generic] = ACTIONS(1899),
    [anon_sym_asm] = ACTIONS(1899),
    [anon_sym___asm__] = ACTIONS(1899),
    [sym_number_literal] = ACTIONS(1901),
    [anon_sym_L_SQUOTE] = ACTIONS(1901),
    [anon_sym_u_SQUOTE] = ACTIONS(1901),
    [anon_sym_U_SQUOTE] = ACTIONS(1901),
    [anon_sym_u8_SQUOTE] = ACTIONS(1901),
    [anon_sym_SQUOTE] = ACTIONS(1901),
    [anon_sym_L_DQUOTE] = ACTIONS(1901),
    [anon_sym_u_DQUOTE] = ACTIONS(1901),
    [anon_sym_U_DQUOTE] = ACTIONS(1901),
    [anon_sym_u8_DQUOTE] = ACTIONS(1901),
    [anon_sym_DQUOTE] = ACTIONS(1901),
    [sym_true] = ACTIONS(1899),
    [sym_false] = ACTIONS(1899),
    [anon_sym_NULL] = ACTIONS(1899),
    [anon_sym_nullptr] = ACTIONS(1899),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1899),
    [anon_sym_decltype] = ACTIONS(1899),
    [anon_sym_final] = ACTIONS(1899),
    [anon_sym_override] = ACTIONS(1899),
    [sym_virtual] = ACTIONS(1899),
    [anon_sym_explicit] = ACTIONS(1899),
    [anon_sym_typename] = ACTIONS(1899),
    [anon_sym_template] = ACTIONS(1899),
    [anon_sym_operator] = ACTIONS(1899),
    [anon_sym_try] = ACTIONS(1899),
    [anon_sym_delete] = ACTIONS(1899),
    [anon_sym_throw] = ACTIONS(1899),
    [anon_sym_namespace] = ACTIONS(1899),
    [anon_sym_using] = ACTIONS(1899),
    [anon_sym_static_assert] = ACTIONS(1899),
    [anon_sym_concept] = ACTIONS(1899),
    [anon_sym_co_return] = ACTIONS(1899),
    [anon_sym_co_yield] = ACTIONS(1899),
    [anon_sym_R_DQUOTE] = ACTIONS(1901),
    [anon_sym_LR_DQUOTE] = ACTIONS(1901),
    [anon_sym_uR_DQUOTE] = ACTIONS(1901),
    [anon_sym_UR_DQUOTE] = ACTIONS(1901),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1901),
    [anon_sym_co_await] = ACTIONS(1899),
    [anon_sym_new] = ACTIONS(1899),
    [anon_sym_requires] = ACTIONS(1899),
    [sym_this] = ACTIONS(1899),
    [anon_sym_discard] = ACTIONS(1899),
    [anon_sym_precise] = ACTIONS(1899),
    [anon_sym_shared] = ACTIONS(1899),
    [anon_sym_groupshared] = ACTIONS(1899),
    [anon_sym_uniform] = ACTIONS(1899),
    [anon_sym_row_major] = ACTIONS(1899),
    [anon_sym_column_major] = ACTIONS(1899),
    [anon_sym_globallycoherent] = ACTIONS(1899),
    [anon_sym_centroid] = ACTIONS(1899),
    [anon_sym_noperspective] = ACTIONS(1899),
    [anon_sym_nointerpolation] = ACTIONS(1899),
    [anon_sym_sample] = ACTIONS(1899),
    [anon_sym_linear] = ACTIONS(1899),
    [anon_sym_snorm] = ACTIONS(1899),
    [anon_sym_unorm] = ACTIONS(1899),
    [anon_sym_point] = ACTIONS(1899),
    [anon_sym_line] = ACTIONS(1899),
    [anon_sym_triangleadj] = ACTIONS(1899),
    [anon_sym_lineadj] = ACTIONS(1899),
    [anon_sym_triangle] = ACTIONS(1899),
    [anon_sym_cbuffer] = ACTIONS(1899),
  },
  [314] = {
    [ts_builtin_sym_end] = ACTIONS(1905),
    [sym_identifier] = ACTIONS(1903),
    [aux_sym_preproc_include_token1] = ACTIONS(1903),
    [aux_sym_preproc_def_token1] = ACTIONS(1903),
    [aux_sym_preproc_if_token1] = ACTIONS(1903),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1903),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1903),
    [sym_preproc_directive] = ACTIONS(1903),
    [anon_sym_LPAREN2] = ACTIONS(1905),
    [anon_sym_BANG] = ACTIONS(1905),
    [anon_sym_TILDE] = ACTIONS(1905),
    [anon_sym_DASH] = ACTIONS(1903),
    [anon_sym_PLUS] = ACTIONS(1903),
    [anon_sym_STAR] = ACTIONS(1905),
    [anon_sym_AMP_AMP] = ACTIONS(1905),
    [anon_sym_AMP] = ACTIONS(1903),
    [anon_sym_COLON] = ACTIONS(1903),
    [anon_sym_SEMI] = ACTIONS(1905),
    [anon_sym___extension__] = ACTIONS(1903),
    [anon_sym_typedef] = ACTIONS(1903),
    [anon_sym_in] = ACTIONS(1903),
    [anon_sym_out] = ACTIONS(1903),
    [anon_sym_inout] = ACTIONS(1903),
    [anon_sym_extern] = ACTIONS(1903),
    [anon_sym___attribute__] = ACTIONS(1903),
    [anon_sym_COLON_COLON] = ACTIONS(1905),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1905),
    [anon_sym___declspec] = ACTIONS(1903),
    [anon_sym___based] = ACTIONS(1903),
    [anon_sym___cdecl] = ACTIONS(1903),
    [anon_sym___clrcall] = ACTIONS(1903),
    [anon_sym___stdcall] = ACTIONS(1903),
    [anon_sym___fastcall] = ACTIONS(1903),
    [anon_sym___thiscall] = ACTIONS(1903),
    [anon_sym___vectorcall] = ACTIONS(1903),
    [anon_sym_LBRACE] = ACTIONS(1905),
    [anon_sym_signed] = ACTIONS(1903),
    [anon_sym_unsigned] = ACTIONS(1903),
    [anon_sym_long] = ACTIONS(1903),
    [anon_sym_short] = ACTIONS(1903),
    [anon_sym_LBRACK] = ACTIONS(1903),
    [anon_sym_static] = ACTIONS(1903),
    [anon_sym_register] = ACTIONS(1903),
    [anon_sym_inline] = ACTIONS(1903),
    [anon_sym___inline] = ACTIONS(1903),
    [anon_sym___inline__] = ACTIONS(1903),
    [anon_sym___forceinline] = ACTIONS(1903),
    [anon_sym_thread_local] = ACTIONS(1903),
    [anon_sym___thread] = ACTIONS(1903),
    [anon_sym_const] = ACTIONS(1903),
    [anon_sym_constexpr] = ACTIONS(1903),
    [anon_sym_volatile] = ACTIONS(1903),
    [anon_sym_restrict] = ACTIONS(1903),
    [anon_sym___restrict__] = ACTIONS(1903),
    [anon_sym__Atomic] = ACTIONS(1903),
    [anon_sym__Noreturn] = ACTIONS(1903),
    [anon_sym_noreturn] = ACTIONS(1903),
    [anon_sym_mutable] = ACTIONS(1903),
    [anon_sym_constinit] = ACTIONS(1903),
    [anon_sym_consteval] = ACTIONS(1903),
    [anon_sym_alignas] = ACTIONS(1903),
    [anon_sym__Alignas] = ACTIONS(1903),
    [sym_primitive_type] = ACTIONS(1903),
    [anon_sym_enum] = ACTIONS(1903),
    [anon_sym_class] = ACTIONS(1903),
    [anon_sym_struct] = ACTIONS(1903),
    [anon_sym_union] = ACTIONS(1903),
    [anon_sym_if] = ACTIONS(1903),
    [anon_sym_else] = ACTIONS(1903),
    [anon_sym_switch] = ACTIONS(1903),
    [anon_sym_case] = ACTIONS(1903),
    [anon_sym_default] = ACTIONS(1903),
    [anon_sym_while] = ACTIONS(1903),
    [anon_sym_do] = ACTIONS(1903),
    [anon_sym_for] = ACTIONS(1903),
    [anon_sym_return] = ACTIONS(1903),
    [anon_sym_break] = ACTIONS(1903),
    [anon_sym_continue] = ACTIONS(1903),
    [anon_sym_goto] = ACTIONS(1903),
    [anon_sym___try] = ACTIONS(1903),
    [anon_sym___leave] = ACTIONS(1903),
    [anon_sym_not] = ACTIONS(1903),
    [anon_sym_compl] = ACTIONS(1903),
    [anon_sym_DASH_DASH] = ACTIONS(1905),
    [anon_sym_PLUS_PLUS] = ACTIONS(1905),
    [anon_sym_sizeof] = ACTIONS(1903),
    [anon_sym___alignof__] = ACTIONS(1903),
    [anon_sym___alignof] = ACTIONS(1903),
    [anon_sym__alignof] = ACTIONS(1903),
    [anon_sym_alignof] = ACTIONS(1903),
    [anon_sym__Alignof] = ACTIONS(1903),
    [anon_sym_offsetof] = ACTIONS(1903),
    [anon_sym__Generic] = ACTIONS(1903),
    [anon_sym_asm] = ACTIONS(1903),
    [anon_sym___asm__] = ACTIONS(1903),
    [sym_number_literal] = ACTIONS(1905),
    [anon_sym_L_SQUOTE] = ACTIONS(1905),
    [anon_sym_u_SQUOTE] = ACTIONS(1905),
    [anon_sym_U_SQUOTE] = ACTIONS(1905),
    [anon_sym_u8_SQUOTE] = ACTIONS(1905),
    [anon_sym_SQUOTE] = ACTIONS(1905),
    [anon_sym_L_DQUOTE] = ACTIONS(1905),
    [anon_sym_u_DQUOTE] = ACTIONS(1905),
    [anon_sym_U_DQUOTE] = ACTIONS(1905),
    [anon_sym_u8_DQUOTE] = ACTIONS(1905),
    [anon_sym_DQUOTE] = ACTIONS(1905),
    [sym_true] = ACTIONS(1903),
    [sym_false] = ACTIONS(1903),
    [anon_sym_NULL] = ACTIONS(1903),
    [anon_sym_nullptr] = ACTIONS(1903),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1903),
    [anon_sym_decltype] = ACTIONS(1903),
    [anon_sym_final] = ACTIONS(1903),
    [anon_sym_override] = ACTIONS(1903),
    [sym_virtual] = ACTIONS(1903),
    [anon_sym_explicit] = ACTIONS(1903),
    [anon_sym_typename] = ACTIONS(1903),
    [anon_sym_template] = ACTIONS(1903),
    [anon_sym_operator] = ACTIONS(1903),
    [anon_sym_try] = ACTIONS(1903),
    [anon_sym_delete] = ACTIONS(1903),
    [anon_sym_throw] = ACTIONS(1903),
    [anon_sym_namespace] = ACTIONS(1903),
    [anon_sym_using] = ACTIONS(1903),
    [anon_sym_static_assert] = ACTIONS(1903),
    [anon_sym_concept] = ACTIONS(1903),
    [anon_sym_co_return] = ACTIONS(1903),
    [anon_sym_co_yield] = ACTIONS(1903),
    [anon_sym_R_DQUOTE] = ACTIONS(1905),
    [anon_sym_LR_DQUOTE] = ACTIONS(1905),
    [anon_sym_uR_DQUOTE] = ACTIONS(1905),
    [anon_sym_UR_DQUOTE] = ACTIONS(1905),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1905),
    [anon_sym_co_await] = ACTIONS(1903),
    [anon_sym_new] = ACTIONS(1903),
    [anon_sym_requires] = ACTIONS(1903),
    [sym_this] = ACTIONS(1903),
    [anon_sym_discard] = ACTIONS(1903),
    [anon_sym_precise] = ACTIONS(1903),
    [anon_sym_shared] = ACTIONS(1903),
    [anon_sym_groupshared] = ACTIONS(1903),
    [anon_sym_uniform] = ACTIONS(1903),
    [anon_sym_row_major] = ACTIONS(1903),
    [anon_sym_column_major] = ACTIONS(1903),
    [anon_sym_globallycoherent] = ACTIONS(1903),
    [anon_sym_centroid] = ACTIONS(1903),
    [anon_sym_noperspective] = ACTIONS(1903),
    [anon_sym_nointerpolation] = ACTIONS(1903),
    [anon_sym_sample] = ACTIONS(1903),
    [anon_sym_linear] = ACTIONS(1903),
    [anon_sym_snorm] = ACTIONS(1903),
    [anon_sym_unorm] = ACTIONS(1903),
    [anon_sym_point] = ACTIONS(1903),
    [anon_sym_line] = ACTIONS(1903),
    [anon_sym_triangleadj] = ACTIONS(1903),
    [anon_sym_lineadj] = ACTIONS(1903),
    [anon_sym_triangle] = ACTIONS(1903),
    [anon_sym_cbuffer] = ACTIONS(1903),
  },
  [315] = {
    [sym_identifier] = ACTIONS(2490),
    [aux_sym_preproc_include_token1] = ACTIONS(2490),
    [aux_sym_preproc_def_token1] = ACTIONS(2490),
    [aux_sym_preproc_if_token1] = ACTIONS(2490),
    [aux_sym_preproc_if_token2] = ACTIONS(2490),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2490),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2490),
    [aux_sym_preproc_else_token1] = ACTIONS(2490),
    [aux_sym_preproc_elif_token1] = ACTIONS(2490),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2490),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2490),
    [sym_preproc_directive] = ACTIONS(2490),
    [anon_sym_LPAREN2] = ACTIONS(2492),
    [anon_sym_BANG] = ACTIONS(2492),
    [anon_sym_TILDE] = ACTIONS(2492),
    [anon_sym_DASH] = ACTIONS(2490),
    [anon_sym_PLUS] = ACTIONS(2490),
    [anon_sym_STAR] = ACTIONS(2492),
    [anon_sym_AMP_AMP] = ACTIONS(2492),
    [anon_sym_AMP] = ACTIONS(2490),
    [anon_sym_SEMI] = ACTIONS(2492),
    [anon_sym___extension__] = ACTIONS(2490),
    [anon_sym_typedef] = ACTIONS(2490),
    [anon_sym_in] = ACTIONS(2490),
    [anon_sym_out] = ACTIONS(2490),
    [anon_sym_inout] = ACTIONS(2490),
    [anon_sym_extern] = ACTIONS(2490),
    [anon_sym___attribute__] = ACTIONS(2490),
    [anon_sym_COLON_COLON] = ACTIONS(2492),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2492),
    [anon_sym___declspec] = ACTIONS(2490),
    [anon_sym___based] = ACTIONS(2490),
    [anon_sym___cdecl] = ACTIONS(2490),
    [anon_sym___clrcall] = ACTIONS(2490),
    [anon_sym___stdcall] = ACTIONS(2490),
    [anon_sym___fastcall] = ACTIONS(2490),
    [anon_sym___thiscall] = ACTIONS(2490),
    [anon_sym___vectorcall] = ACTIONS(2490),
    [anon_sym_LBRACE] = ACTIONS(2492),
    [anon_sym_signed] = ACTIONS(2490),
    [anon_sym_unsigned] = ACTIONS(2490),
    [anon_sym_long] = ACTIONS(2490),
    [anon_sym_short] = ACTIONS(2490),
    [anon_sym_LBRACK] = ACTIONS(2490),
    [anon_sym_static] = ACTIONS(2490),
    [anon_sym_register] = ACTIONS(2490),
    [anon_sym_inline] = ACTIONS(2490),
    [anon_sym___inline] = ACTIONS(2490),
    [anon_sym___inline__] = ACTIONS(2490),
    [anon_sym___forceinline] = ACTIONS(2490),
    [anon_sym_thread_local] = ACTIONS(2490),
    [anon_sym___thread] = ACTIONS(2490),
    [anon_sym_const] = ACTIONS(2490),
    [anon_sym_constexpr] = ACTIONS(2490),
    [anon_sym_volatile] = ACTIONS(2490),
    [anon_sym_restrict] = ACTIONS(2490),
    [anon_sym___restrict__] = ACTIONS(2490),
    [anon_sym__Atomic] = ACTIONS(2490),
    [anon_sym__Noreturn] = ACTIONS(2490),
    [anon_sym_noreturn] = ACTIONS(2490),
    [anon_sym_mutable] = ACTIONS(2490),
    [anon_sym_constinit] = ACTIONS(2490),
    [anon_sym_consteval] = ACTIONS(2490),
    [anon_sym_alignas] = ACTIONS(2490),
    [anon_sym__Alignas] = ACTIONS(2490),
    [sym_primitive_type] = ACTIONS(2490),
    [anon_sym_enum] = ACTIONS(2490),
    [anon_sym_class] = ACTIONS(2490),
    [anon_sym_struct] = ACTIONS(2490),
    [anon_sym_union] = ACTIONS(2490),
    [anon_sym_if] = ACTIONS(2490),
    [anon_sym_switch] = ACTIONS(2490),
    [anon_sym_case] = ACTIONS(2490),
    [anon_sym_default] = ACTIONS(2490),
    [anon_sym_while] = ACTIONS(2490),
    [anon_sym_do] = ACTIONS(2490),
    [anon_sym_for] = ACTIONS(2490),
    [anon_sym_return] = ACTIONS(2490),
    [anon_sym_break] = ACTIONS(2490),
    [anon_sym_continue] = ACTIONS(2490),
    [anon_sym_goto] = ACTIONS(2490),
    [anon_sym___try] = ACTIONS(2490),
    [anon_sym___leave] = ACTIONS(2490),
    [anon_sym_not] = ACTIONS(2490),
    [anon_sym_compl] = ACTIONS(2490),
    [anon_sym_DASH_DASH] = ACTIONS(2492),
    [anon_sym_PLUS_PLUS] = ACTIONS(2492),
    [anon_sym_sizeof] = ACTIONS(2490),
    [anon_sym___alignof__] = ACTIONS(2490),
    [anon_sym___alignof] = ACTIONS(2490),
    [anon_sym__alignof] = ACTIONS(2490),
    [anon_sym_alignof] = ACTIONS(2490),
    [anon_sym__Alignof] = ACTIONS(2490),
    [anon_sym_offsetof] = ACTIONS(2490),
    [anon_sym__Generic] = ACTIONS(2490),
    [anon_sym_asm] = ACTIONS(2490),
    [anon_sym___asm__] = ACTIONS(2490),
    [sym_number_literal] = ACTIONS(2492),
    [anon_sym_L_SQUOTE] = ACTIONS(2492),
    [anon_sym_u_SQUOTE] = ACTIONS(2492),
    [anon_sym_U_SQUOTE] = ACTIONS(2492),
    [anon_sym_u8_SQUOTE] = ACTIONS(2492),
    [anon_sym_SQUOTE] = ACTIONS(2492),
    [anon_sym_L_DQUOTE] = ACTIONS(2492),
    [anon_sym_u_DQUOTE] = ACTIONS(2492),
    [anon_sym_U_DQUOTE] = ACTIONS(2492),
    [anon_sym_u8_DQUOTE] = ACTIONS(2492),
    [anon_sym_DQUOTE] = ACTIONS(2492),
    [sym_true] = ACTIONS(2490),
    [sym_false] = ACTIONS(2490),
    [anon_sym_NULL] = ACTIONS(2490),
    [anon_sym_nullptr] = ACTIONS(2490),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2490),
    [anon_sym_decltype] = ACTIONS(2490),
    [sym_virtual] = ACTIONS(2490),
    [anon_sym_explicit] = ACTIONS(2490),
    [anon_sym_typename] = ACTIONS(2490),
    [anon_sym_template] = ACTIONS(2490),
    [anon_sym_operator] = ACTIONS(2490),
    [anon_sym_try] = ACTIONS(2490),
    [anon_sym_delete] = ACTIONS(2490),
    [anon_sym_throw] = ACTIONS(2490),
    [anon_sym_namespace] = ACTIONS(2490),
    [anon_sym_using] = ACTIONS(2490),
    [anon_sym_static_assert] = ACTIONS(2490),
    [anon_sym_concept] = ACTIONS(2490),
    [anon_sym_co_return] = ACTIONS(2490),
    [anon_sym_co_yield] = ACTIONS(2490),
    [anon_sym_R_DQUOTE] = ACTIONS(2492),
    [anon_sym_LR_DQUOTE] = ACTIONS(2492),
    [anon_sym_uR_DQUOTE] = ACTIONS(2492),
    [anon_sym_UR_DQUOTE] = ACTIONS(2492),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2492),
    [anon_sym_co_await] = ACTIONS(2490),
    [anon_sym_new] = ACTIONS(2490),
    [anon_sym_requires] = ACTIONS(2490),
    [sym_this] = ACTIONS(2490),
    [anon_sym_discard] = ACTIONS(2490),
    [anon_sym_precise] = ACTIONS(2490),
    [anon_sym_shared] = ACTIONS(2490),
    [anon_sym_groupshared] = ACTIONS(2490),
    [anon_sym_uniform] = ACTIONS(2490),
    [anon_sym_row_major] = ACTIONS(2490),
    [anon_sym_column_major] = ACTIONS(2490),
    [anon_sym_globallycoherent] = ACTIONS(2490),
    [anon_sym_centroid] = ACTIONS(2490),
    [anon_sym_noperspective] = ACTIONS(2490),
    [anon_sym_nointerpolation] = ACTIONS(2490),
    [anon_sym_sample] = ACTIONS(2490),
    [anon_sym_linear] = ACTIONS(2490),
    [anon_sym_snorm] = ACTIONS(2490),
    [anon_sym_unorm] = ACTIONS(2490),
    [anon_sym_point] = ACTIONS(2490),
    [anon_sym_line] = ACTIONS(2490),
    [anon_sym_triangleadj] = ACTIONS(2490),
    [anon_sym_lineadj] = ACTIONS(2490),
    [anon_sym_triangle] = ACTIONS(2490),
    [anon_sym_cbuffer] = ACTIONS(2490),
  },
  [316] = {
    [sym_identifier] = ACTIONS(2494),
    [aux_sym_preproc_include_token1] = ACTIONS(2494),
    [aux_sym_preproc_def_token1] = ACTIONS(2494),
    [aux_sym_preproc_if_token1] = ACTIONS(2494),
    [aux_sym_preproc_if_token2] = ACTIONS(2494),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2494),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2494),
    [aux_sym_preproc_else_token1] = ACTIONS(2494),
    [aux_sym_preproc_elif_token1] = ACTIONS(2494),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2494),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2494),
    [sym_preproc_directive] = ACTIONS(2494),
    [anon_sym_LPAREN2] = ACTIONS(2496),
    [anon_sym_BANG] = ACTIONS(2496),
    [anon_sym_TILDE] = ACTIONS(2496),
    [anon_sym_DASH] = ACTIONS(2494),
    [anon_sym_PLUS] = ACTIONS(2494),
    [anon_sym_STAR] = ACTIONS(2496),
    [anon_sym_AMP_AMP] = ACTIONS(2496),
    [anon_sym_AMP] = ACTIONS(2494),
    [anon_sym_SEMI] = ACTIONS(2496),
    [anon_sym___extension__] = ACTIONS(2494),
    [anon_sym_typedef] = ACTIONS(2494),
    [anon_sym_in] = ACTIONS(2494),
    [anon_sym_out] = ACTIONS(2494),
    [anon_sym_inout] = ACTIONS(2494),
    [anon_sym_extern] = ACTIONS(2494),
    [anon_sym___attribute__] = ACTIONS(2494),
    [anon_sym_COLON_COLON] = ACTIONS(2496),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2496),
    [anon_sym___declspec] = ACTIONS(2494),
    [anon_sym___based] = ACTIONS(2494),
    [anon_sym___cdecl] = ACTIONS(2494),
    [anon_sym___clrcall] = ACTIONS(2494),
    [anon_sym___stdcall] = ACTIONS(2494),
    [anon_sym___fastcall] = ACTIONS(2494),
    [anon_sym___thiscall] = ACTIONS(2494),
    [anon_sym___vectorcall] = ACTIONS(2494),
    [anon_sym_LBRACE] = ACTIONS(2496),
    [anon_sym_signed] = ACTIONS(2494),
    [anon_sym_unsigned] = ACTIONS(2494),
    [anon_sym_long] = ACTIONS(2494),
    [anon_sym_short] = ACTIONS(2494),
    [anon_sym_LBRACK] = ACTIONS(2494),
    [anon_sym_static] = ACTIONS(2494),
    [anon_sym_register] = ACTIONS(2494),
    [anon_sym_inline] = ACTIONS(2494),
    [anon_sym___inline] = ACTIONS(2494),
    [anon_sym___inline__] = ACTIONS(2494),
    [anon_sym___forceinline] = ACTIONS(2494),
    [anon_sym_thread_local] = ACTIONS(2494),
    [anon_sym___thread] = ACTIONS(2494),
    [anon_sym_const] = ACTIONS(2494),
    [anon_sym_constexpr] = ACTIONS(2494),
    [anon_sym_volatile] = ACTIONS(2494),
    [anon_sym_restrict] = ACTIONS(2494),
    [anon_sym___restrict__] = ACTIONS(2494),
    [anon_sym__Atomic] = ACTIONS(2494),
    [anon_sym__Noreturn] = ACTIONS(2494),
    [anon_sym_noreturn] = ACTIONS(2494),
    [anon_sym_mutable] = ACTIONS(2494),
    [anon_sym_constinit] = ACTIONS(2494),
    [anon_sym_consteval] = ACTIONS(2494),
    [anon_sym_alignas] = ACTIONS(2494),
    [anon_sym__Alignas] = ACTIONS(2494),
    [sym_primitive_type] = ACTIONS(2494),
    [anon_sym_enum] = ACTIONS(2494),
    [anon_sym_class] = ACTIONS(2494),
    [anon_sym_struct] = ACTIONS(2494),
    [anon_sym_union] = ACTIONS(2494),
    [anon_sym_if] = ACTIONS(2494),
    [anon_sym_switch] = ACTIONS(2494),
    [anon_sym_case] = ACTIONS(2494),
    [anon_sym_default] = ACTIONS(2494),
    [anon_sym_while] = ACTIONS(2494),
    [anon_sym_do] = ACTIONS(2494),
    [anon_sym_for] = ACTIONS(2494),
    [anon_sym_return] = ACTIONS(2494),
    [anon_sym_break] = ACTIONS(2494),
    [anon_sym_continue] = ACTIONS(2494),
    [anon_sym_goto] = ACTIONS(2494),
    [anon_sym___try] = ACTIONS(2494),
    [anon_sym___leave] = ACTIONS(2494),
    [anon_sym_not] = ACTIONS(2494),
    [anon_sym_compl] = ACTIONS(2494),
    [anon_sym_DASH_DASH] = ACTIONS(2496),
    [anon_sym_PLUS_PLUS] = ACTIONS(2496),
    [anon_sym_sizeof] = ACTIONS(2494),
    [anon_sym___alignof__] = ACTIONS(2494),
    [anon_sym___alignof] = ACTIONS(2494),
    [anon_sym__alignof] = ACTIONS(2494),
    [anon_sym_alignof] = ACTIONS(2494),
    [anon_sym__Alignof] = ACTIONS(2494),
    [anon_sym_offsetof] = ACTIONS(2494),
    [anon_sym__Generic] = ACTIONS(2494),
    [anon_sym_asm] = ACTIONS(2494),
    [anon_sym___asm__] = ACTIONS(2494),
    [sym_number_literal] = ACTIONS(2496),
    [anon_sym_L_SQUOTE] = ACTIONS(2496),
    [anon_sym_u_SQUOTE] = ACTIONS(2496),
    [anon_sym_U_SQUOTE] = ACTIONS(2496),
    [anon_sym_u8_SQUOTE] = ACTIONS(2496),
    [anon_sym_SQUOTE] = ACTIONS(2496),
    [anon_sym_L_DQUOTE] = ACTIONS(2496),
    [anon_sym_u_DQUOTE] = ACTIONS(2496),
    [anon_sym_U_DQUOTE] = ACTIONS(2496),
    [anon_sym_u8_DQUOTE] = ACTIONS(2496),
    [anon_sym_DQUOTE] = ACTIONS(2496),
    [sym_true] = ACTIONS(2494),
    [sym_false] = ACTIONS(2494),
    [anon_sym_NULL] = ACTIONS(2494),
    [anon_sym_nullptr] = ACTIONS(2494),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2494),
    [anon_sym_decltype] = ACTIONS(2494),
    [sym_virtual] = ACTIONS(2494),
    [anon_sym_explicit] = ACTIONS(2494),
    [anon_sym_typename] = ACTIONS(2494),
    [anon_sym_template] = ACTIONS(2494),
    [anon_sym_operator] = ACTIONS(2494),
    [anon_sym_try] = ACTIONS(2494),
    [anon_sym_delete] = ACTIONS(2494),
    [anon_sym_throw] = ACTIONS(2494),
    [anon_sym_namespace] = ACTIONS(2494),
    [anon_sym_using] = ACTIONS(2494),
    [anon_sym_static_assert] = ACTIONS(2494),
    [anon_sym_concept] = ACTIONS(2494),
    [anon_sym_co_return] = ACTIONS(2494),
    [anon_sym_co_yield] = ACTIONS(2494),
    [anon_sym_R_DQUOTE] = ACTIONS(2496),
    [anon_sym_LR_DQUOTE] = ACTIONS(2496),
    [anon_sym_uR_DQUOTE] = ACTIONS(2496),
    [anon_sym_UR_DQUOTE] = ACTIONS(2496),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2496),
    [anon_sym_co_await] = ACTIONS(2494),
    [anon_sym_new] = ACTIONS(2494),
    [anon_sym_requires] = ACTIONS(2494),
    [sym_this] = ACTIONS(2494),
    [anon_sym_discard] = ACTIONS(2494),
    [anon_sym_precise] = ACTIONS(2494),
    [anon_sym_shared] = ACTIONS(2494),
    [anon_sym_groupshared] = ACTIONS(2494),
    [anon_sym_uniform] = ACTIONS(2494),
    [anon_sym_row_major] = ACTIONS(2494),
    [anon_sym_column_major] = ACTIONS(2494),
    [anon_sym_globallycoherent] = ACTIONS(2494),
    [anon_sym_centroid] = ACTIONS(2494),
    [anon_sym_noperspective] = ACTIONS(2494),
    [anon_sym_nointerpolation] = ACTIONS(2494),
    [anon_sym_sample] = ACTIONS(2494),
    [anon_sym_linear] = ACTIONS(2494),
    [anon_sym_snorm] = ACTIONS(2494),
    [anon_sym_unorm] = ACTIONS(2494),
    [anon_sym_point] = ACTIONS(2494),
    [anon_sym_line] = ACTIONS(2494),
    [anon_sym_triangleadj] = ACTIONS(2494),
    [anon_sym_lineadj] = ACTIONS(2494),
    [anon_sym_triangle] = ACTIONS(2494),
    [anon_sym_cbuffer] = ACTIONS(2494),
  },
  [317] = {
    [sym_identifier] = ACTIONS(2498),
    [aux_sym_preproc_include_token1] = ACTIONS(2498),
    [aux_sym_preproc_def_token1] = ACTIONS(2498),
    [aux_sym_preproc_if_token1] = ACTIONS(2498),
    [aux_sym_preproc_if_token2] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2498),
    [aux_sym_preproc_else_token1] = ACTIONS(2498),
    [aux_sym_preproc_elif_token1] = ACTIONS(2498),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2498),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2498),
    [sym_preproc_directive] = ACTIONS(2498),
    [anon_sym_LPAREN2] = ACTIONS(2500),
    [anon_sym_BANG] = ACTIONS(2500),
    [anon_sym_TILDE] = ACTIONS(2500),
    [anon_sym_DASH] = ACTIONS(2498),
    [anon_sym_PLUS] = ACTIONS(2498),
    [anon_sym_STAR] = ACTIONS(2500),
    [anon_sym_AMP_AMP] = ACTIONS(2500),
    [anon_sym_AMP] = ACTIONS(2498),
    [anon_sym_SEMI] = ACTIONS(2500),
    [anon_sym___extension__] = ACTIONS(2498),
    [anon_sym_typedef] = ACTIONS(2498),
    [anon_sym_in] = ACTIONS(2498),
    [anon_sym_out] = ACTIONS(2498),
    [anon_sym_inout] = ACTIONS(2498),
    [anon_sym_extern] = ACTIONS(2498),
    [anon_sym___attribute__] = ACTIONS(2498),
    [anon_sym_COLON_COLON] = ACTIONS(2500),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2500),
    [anon_sym___declspec] = ACTIONS(2498),
    [anon_sym___based] = ACTIONS(2498),
    [anon_sym___cdecl] = ACTIONS(2498),
    [anon_sym___clrcall] = ACTIONS(2498),
    [anon_sym___stdcall] = ACTIONS(2498),
    [anon_sym___fastcall] = ACTIONS(2498),
    [anon_sym___thiscall] = ACTIONS(2498),
    [anon_sym___vectorcall] = ACTIONS(2498),
    [anon_sym_LBRACE] = ACTIONS(2500),
    [anon_sym_signed] = ACTIONS(2498),
    [anon_sym_unsigned] = ACTIONS(2498),
    [anon_sym_long] = ACTIONS(2498),
    [anon_sym_short] = ACTIONS(2498),
    [anon_sym_LBRACK] = ACTIONS(2498),
    [anon_sym_static] = ACTIONS(2498),
    [anon_sym_register] = ACTIONS(2498),
    [anon_sym_inline] = ACTIONS(2498),
    [anon_sym___inline] = ACTIONS(2498),
    [anon_sym___inline__] = ACTIONS(2498),
    [anon_sym___forceinline] = ACTIONS(2498),
    [anon_sym_thread_local] = ACTIONS(2498),
    [anon_sym___thread] = ACTIONS(2498),
    [anon_sym_const] = ACTIONS(2498),
    [anon_sym_constexpr] = ACTIONS(2498),
    [anon_sym_volatile] = ACTIONS(2498),
    [anon_sym_restrict] = ACTIONS(2498),
    [anon_sym___restrict__] = ACTIONS(2498),
    [anon_sym__Atomic] = ACTIONS(2498),
    [anon_sym__Noreturn] = ACTIONS(2498),
    [anon_sym_noreturn] = ACTIONS(2498),
    [anon_sym_mutable] = ACTIONS(2498),
    [anon_sym_constinit] = ACTIONS(2498),
    [anon_sym_consteval] = ACTIONS(2498),
    [anon_sym_alignas] = ACTIONS(2498),
    [anon_sym__Alignas] = ACTIONS(2498),
    [sym_primitive_type] = ACTIONS(2498),
    [anon_sym_enum] = ACTIONS(2498),
    [anon_sym_class] = ACTIONS(2498),
    [anon_sym_struct] = ACTIONS(2498),
    [anon_sym_union] = ACTIONS(2498),
    [anon_sym_if] = ACTIONS(2498),
    [anon_sym_switch] = ACTIONS(2498),
    [anon_sym_case] = ACTIONS(2498),
    [anon_sym_default] = ACTIONS(2498),
    [anon_sym_while] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(2498),
    [anon_sym_for] = ACTIONS(2498),
    [anon_sym_return] = ACTIONS(2498),
    [anon_sym_break] = ACTIONS(2498),
    [anon_sym_continue] = ACTIONS(2498),
    [anon_sym_goto] = ACTIONS(2498),
    [anon_sym___try] = ACTIONS(2498),
    [anon_sym___leave] = ACTIONS(2498),
    [anon_sym_not] = ACTIONS(2498),
    [anon_sym_compl] = ACTIONS(2498),
    [anon_sym_DASH_DASH] = ACTIONS(2500),
    [anon_sym_PLUS_PLUS] = ACTIONS(2500),
    [anon_sym_sizeof] = ACTIONS(2498),
    [anon_sym___alignof__] = ACTIONS(2498),
    [anon_sym___alignof] = ACTIONS(2498),
    [anon_sym__alignof] = ACTIONS(2498),
    [anon_sym_alignof] = ACTIONS(2498),
    [anon_sym__Alignof] = ACTIONS(2498),
    [anon_sym_offsetof] = ACTIONS(2498),
    [anon_sym__Generic] = ACTIONS(2498),
    [anon_sym_asm] = ACTIONS(2498),
    [anon_sym___asm__] = ACTIONS(2498),
    [sym_number_literal] = ACTIONS(2500),
    [anon_sym_L_SQUOTE] = ACTIONS(2500),
    [anon_sym_u_SQUOTE] = ACTIONS(2500),
    [anon_sym_U_SQUOTE] = ACTIONS(2500),
    [anon_sym_u8_SQUOTE] = ACTIONS(2500),
    [anon_sym_SQUOTE] = ACTIONS(2500),
    [anon_sym_L_DQUOTE] = ACTIONS(2500),
    [anon_sym_u_DQUOTE] = ACTIONS(2500),
    [anon_sym_U_DQUOTE] = ACTIONS(2500),
    [anon_sym_u8_DQUOTE] = ACTIONS(2500),
    [anon_sym_DQUOTE] = ACTIONS(2500),
    [sym_true] = ACTIONS(2498),
    [sym_false] = ACTIONS(2498),
    [anon_sym_NULL] = ACTIONS(2498),
    [anon_sym_nullptr] = ACTIONS(2498),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2498),
    [anon_sym_decltype] = ACTIONS(2498),
    [sym_virtual] = ACTIONS(2498),
    [anon_sym_explicit] = ACTIONS(2498),
    [anon_sym_typename] = ACTIONS(2498),
    [anon_sym_template] = ACTIONS(2498),
    [anon_sym_operator] = ACTIONS(2498),
    [anon_sym_try] = ACTIONS(2498),
    [anon_sym_delete] = ACTIONS(2498),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_namespace] = ACTIONS(2498),
    [anon_sym_using] = ACTIONS(2498),
    [anon_sym_static_assert] = ACTIONS(2498),
    [anon_sym_concept] = ACTIONS(2498),
    [anon_sym_co_return] = ACTIONS(2498),
    [anon_sym_co_yield] = ACTIONS(2498),
    [anon_sym_R_DQUOTE] = ACTIONS(2500),
    [anon_sym_LR_DQUOTE] = ACTIONS(2500),
    [anon_sym_uR_DQUOTE] = ACTIONS(2500),
    [anon_sym_UR_DQUOTE] = ACTIONS(2500),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2500),
    [anon_sym_co_await] = ACTIONS(2498),
    [anon_sym_new] = ACTIONS(2498),
    [anon_sym_requires] = ACTIONS(2498),
    [sym_this] = ACTIONS(2498),
    [anon_sym_discard] = ACTIONS(2498),
    [anon_sym_precise] = ACTIONS(2498),
    [anon_sym_shared] = ACTIONS(2498),
    [anon_sym_groupshared] = ACTIONS(2498),
    [anon_sym_uniform] = ACTIONS(2498),
    [anon_sym_row_major] = ACTIONS(2498),
    [anon_sym_column_major] = ACTIONS(2498),
    [anon_sym_globallycoherent] = ACTIONS(2498),
    [anon_sym_centroid] = ACTIONS(2498),
    [anon_sym_noperspective] = ACTIONS(2498),
    [anon_sym_nointerpolation] = ACTIONS(2498),
    [anon_sym_sample] = ACTIONS(2498),
    [anon_sym_linear] = ACTIONS(2498),
    [anon_sym_snorm] = ACTIONS(2498),
    [anon_sym_unorm] = ACTIONS(2498),
    [anon_sym_point] = ACTIONS(2498),
    [anon_sym_line] = ACTIONS(2498),
    [anon_sym_triangleadj] = ACTIONS(2498),
    [anon_sym_lineadj] = ACTIONS(2498),
    [anon_sym_triangle] = ACTIONS(2498),
    [anon_sym_cbuffer] = ACTIONS(2498),
  },
  [318] = {
    [sym_identifier] = ACTIONS(2498),
    [aux_sym_preproc_include_token1] = ACTIONS(2498),
    [aux_sym_preproc_def_token1] = ACTIONS(2498),
    [aux_sym_preproc_if_token1] = ACTIONS(2498),
    [aux_sym_preproc_if_token2] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2498),
    [aux_sym_preproc_else_token1] = ACTIONS(2498),
    [aux_sym_preproc_elif_token1] = ACTIONS(2498),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2498),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2498),
    [sym_preproc_directive] = ACTIONS(2498),
    [anon_sym_LPAREN2] = ACTIONS(2500),
    [anon_sym_BANG] = ACTIONS(2500),
    [anon_sym_TILDE] = ACTIONS(2500),
    [anon_sym_DASH] = ACTIONS(2498),
    [anon_sym_PLUS] = ACTIONS(2498),
    [anon_sym_STAR] = ACTIONS(2500),
    [anon_sym_AMP_AMP] = ACTIONS(2500),
    [anon_sym_AMP] = ACTIONS(2498),
    [anon_sym_SEMI] = ACTIONS(2500),
    [anon_sym___extension__] = ACTIONS(2498),
    [anon_sym_typedef] = ACTIONS(2498),
    [anon_sym_in] = ACTIONS(2498),
    [anon_sym_out] = ACTIONS(2498),
    [anon_sym_inout] = ACTIONS(2498),
    [anon_sym_extern] = ACTIONS(2498),
    [anon_sym___attribute__] = ACTIONS(2498),
    [anon_sym_COLON_COLON] = ACTIONS(2500),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2500),
    [anon_sym___declspec] = ACTIONS(2498),
    [anon_sym___based] = ACTIONS(2498),
    [anon_sym___cdecl] = ACTIONS(2498),
    [anon_sym___clrcall] = ACTIONS(2498),
    [anon_sym___stdcall] = ACTIONS(2498),
    [anon_sym___fastcall] = ACTIONS(2498),
    [anon_sym___thiscall] = ACTIONS(2498),
    [anon_sym___vectorcall] = ACTIONS(2498),
    [anon_sym_LBRACE] = ACTIONS(2500),
    [anon_sym_signed] = ACTIONS(2498),
    [anon_sym_unsigned] = ACTIONS(2498),
    [anon_sym_long] = ACTIONS(2498),
    [anon_sym_short] = ACTIONS(2498),
    [anon_sym_LBRACK] = ACTIONS(2498),
    [anon_sym_static] = ACTIONS(2498),
    [anon_sym_register] = ACTIONS(2498),
    [anon_sym_inline] = ACTIONS(2498),
    [anon_sym___inline] = ACTIONS(2498),
    [anon_sym___inline__] = ACTIONS(2498),
    [anon_sym___forceinline] = ACTIONS(2498),
    [anon_sym_thread_local] = ACTIONS(2498),
    [anon_sym___thread] = ACTIONS(2498),
    [anon_sym_const] = ACTIONS(2498),
    [anon_sym_constexpr] = ACTIONS(2498),
    [anon_sym_volatile] = ACTIONS(2498),
    [anon_sym_restrict] = ACTIONS(2498),
    [anon_sym___restrict__] = ACTIONS(2498),
    [anon_sym__Atomic] = ACTIONS(2498),
    [anon_sym__Noreturn] = ACTIONS(2498),
    [anon_sym_noreturn] = ACTIONS(2498),
    [anon_sym_mutable] = ACTIONS(2498),
    [anon_sym_constinit] = ACTIONS(2498),
    [anon_sym_consteval] = ACTIONS(2498),
    [anon_sym_alignas] = ACTIONS(2498),
    [anon_sym__Alignas] = ACTIONS(2498),
    [sym_primitive_type] = ACTIONS(2498),
    [anon_sym_enum] = ACTIONS(2498),
    [anon_sym_class] = ACTIONS(2498),
    [anon_sym_struct] = ACTIONS(2498),
    [anon_sym_union] = ACTIONS(2498),
    [anon_sym_if] = ACTIONS(2498),
    [anon_sym_switch] = ACTIONS(2498),
    [anon_sym_case] = ACTIONS(2498),
    [anon_sym_default] = ACTIONS(2498),
    [anon_sym_while] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(2498),
    [anon_sym_for] = ACTIONS(2498),
    [anon_sym_return] = ACTIONS(2498),
    [anon_sym_break] = ACTIONS(2498),
    [anon_sym_continue] = ACTIONS(2498),
    [anon_sym_goto] = ACTIONS(2498),
    [anon_sym___try] = ACTIONS(2498),
    [anon_sym___leave] = ACTIONS(2498),
    [anon_sym_not] = ACTIONS(2498),
    [anon_sym_compl] = ACTIONS(2498),
    [anon_sym_DASH_DASH] = ACTIONS(2500),
    [anon_sym_PLUS_PLUS] = ACTIONS(2500),
    [anon_sym_sizeof] = ACTIONS(2498),
    [anon_sym___alignof__] = ACTIONS(2498),
    [anon_sym___alignof] = ACTIONS(2498),
    [anon_sym__alignof] = ACTIONS(2498),
    [anon_sym_alignof] = ACTIONS(2498),
    [anon_sym__Alignof] = ACTIONS(2498),
    [anon_sym_offsetof] = ACTIONS(2498),
    [anon_sym__Generic] = ACTIONS(2498),
    [anon_sym_asm] = ACTIONS(2498),
    [anon_sym___asm__] = ACTIONS(2498),
    [sym_number_literal] = ACTIONS(2500),
    [anon_sym_L_SQUOTE] = ACTIONS(2500),
    [anon_sym_u_SQUOTE] = ACTIONS(2500),
    [anon_sym_U_SQUOTE] = ACTIONS(2500),
    [anon_sym_u8_SQUOTE] = ACTIONS(2500),
    [anon_sym_SQUOTE] = ACTIONS(2500),
    [anon_sym_L_DQUOTE] = ACTIONS(2500),
    [anon_sym_u_DQUOTE] = ACTIONS(2500),
    [anon_sym_U_DQUOTE] = ACTIONS(2500),
    [anon_sym_u8_DQUOTE] = ACTIONS(2500),
    [anon_sym_DQUOTE] = ACTIONS(2500),
    [sym_true] = ACTIONS(2498),
    [sym_false] = ACTIONS(2498),
    [anon_sym_NULL] = ACTIONS(2498),
    [anon_sym_nullptr] = ACTIONS(2498),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2498),
    [anon_sym_decltype] = ACTIONS(2498),
    [sym_virtual] = ACTIONS(2498),
    [anon_sym_explicit] = ACTIONS(2498),
    [anon_sym_typename] = ACTIONS(2498),
    [anon_sym_template] = ACTIONS(2498),
    [anon_sym_operator] = ACTIONS(2498),
    [anon_sym_try] = ACTIONS(2498),
    [anon_sym_delete] = ACTIONS(2498),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_namespace] = ACTIONS(2498),
    [anon_sym_using] = ACTIONS(2498),
    [anon_sym_static_assert] = ACTIONS(2498),
    [anon_sym_concept] = ACTIONS(2498),
    [anon_sym_co_return] = ACTIONS(2498),
    [anon_sym_co_yield] = ACTIONS(2498),
    [anon_sym_R_DQUOTE] = ACTIONS(2500),
    [anon_sym_LR_DQUOTE] = ACTIONS(2500),
    [anon_sym_uR_DQUOTE] = ACTIONS(2500),
    [anon_sym_UR_DQUOTE] = ACTIONS(2500),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2500),
    [anon_sym_co_await] = ACTIONS(2498),
    [anon_sym_new] = ACTIONS(2498),
    [anon_sym_requires] = ACTIONS(2498),
    [sym_this] = ACTIONS(2498),
    [anon_sym_discard] = ACTIONS(2498),
    [anon_sym_precise] = ACTIONS(2498),
    [anon_sym_shared] = ACTIONS(2498),
    [anon_sym_groupshared] = ACTIONS(2498),
    [anon_sym_uniform] = ACTIONS(2498),
    [anon_sym_row_major] = ACTIONS(2498),
    [anon_sym_column_major] = ACTIONS(2498),
    [anon_sym_globallycoherent] = ACTIONS(2498),
    [anon_sym_centroid] = ACTIONS(2498),
    [anon_sym_noperspective] = ACTIONS(2498),
    [anon_sym_nointerpolation] = ACTIONS(2498),
    [anon_sym_sample] = ACTIONS(2498),
    [anon_sym_linear] = ACTIONS(2498),
    [anon_sym_snorm] = ACTIONS(2498),
    [anon_sym_unorm] = ACTIONS(2498),
    [anon_sym_point] = ACTIONS(2498),
    [anon_sym_line] = ACTIONS(2498),
    [anon_sym_triangleadj] = ACTIONS(2498),
    [anon_sym_lineadj] = ACTIONS(2498),
    [anon_sym_triangle] = ACTIONS(2498),
    [anon_sym_cbuffer] = ACTIONS(2498),
  },
  [319] = {
    [ts_builtin_sym_end] = ACTIONS(1897),
    [sym_identifier] = ACTIONS(1895),
    [aux_sym_preproc_include_token1] = ACTIONS(1895),
    [aux_sym_preproc_def_token1] = ACTIONS(1895),
    [aux_sym_preproc_if_token1] = ACTIONS(1895),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1895),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1895),
    [sym_preproc_directive] = ACTIONS(1895),
    [anon_sym_LPAREN2] = ACTIONS(1897),
    [anon_sym_BANG] = ACTIONS(1897),
    [anon_sym_TILDE] = ACTIONS(1897),
    [anon_sym_DASH] = ACTIONS(1895),
    [anon_sym_PLUS] = ACTIONS(1895),
    [anon_sym_STAR] = ACTIONS(1897),
    [anon_sym_AMP_AMP] = ACTIONS(1897),
    [anon_sym_AMP] = ACTIONS(1895),
    [anon_sym_COLON] = ACTIONS(1895),
    [anon_sym_SEMI] = ACTIONS(1897),
    [anon_sym___extension__] = ACTIONS(1895),
    [anon_sym_typedef] = ACTIONS(1895),
    [anon_sym_in] = ACTIONS(1895),
    [anon_sym_out] = ACTIONS(1895),
    [anon_sym_inout] = ACTIONS(1895),
    [anon_sym_extern] = ACTIONS(1895),
    [anon_sym___attribute__] = ACTIONS(1895),
    [anon_sym_COLON_COLON] = ACTIONS(1897),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1897),
    [anon_sym___declspec] = ACTIONS(1895),
    [anon_sym___based] = ACTIONS(1895),
    [anon_sym___cdecl] = ACTIONS(1895),
    [anon_sym___clrcall] = ACTIONS(1895),
    [anon_sym___stdcall] = ACTIONS(1895),
    [anon_sym___fastcall] = ACTIONS(1895),
    [anon_sym___thiscall] = ACTIONS(1895),
    [anon_sym___vectorcall] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1897),
    [anon_sym_signed] = ACTIONS(1895),
    [anon_sym_unsigned] = ACTIONS(1895),
    [anon_sym_long] = ACTIONS(1895),
    [anon_sym_short] = ACTIONS(1895),
    [anon_sym_LBRACK] = ACTIONS(1895),
    [anon_sym_static] = ACTIONS(1895),
    [anon_sym_register] = ACTIONS(1895),
    [anon_sym_inline] = ACTIONS(1895),
    [anon_sym___inline] = ACTIONS(1895),
    [anon_sym___inline__] = ACTIONS(1895),
    [anon_sym___forceinline] = ACTIONS(1895),
    [anon_sym_thread_local] = ACTIONS(1895),
    [anon_sym___thread] = ACTIONS(1895),
    [anon_sym_const] = ACTIONS(1895),
    [anon_sym_constexpr] = ACTIONS(1895),
    [anon_sym_volatile] = ACTIONS(1895),
    [anon_sym_restrict] = ACTIONS(1895),
    [anon_sym___restrict__] = ACTIONS(1895),
    [anon_sym__Atomic] = ACTIONS(1895),
    [anon_sym__Noreturn] = ACTIONS(1895),
    [anon_sym_noreturn] = ACTIONS(1895),
    [anon_sym_mutable] = ACTIONS(1895),
    [anon_sym_constinit] = ACTIONS(1895),
    [anon_sym_consteval] = ACTIONS(1895),
    [anon_sym_alignas] = ACTIONS(1895),
    [anon_sym__Alignas] = ACTIONS(1895),
    [sym_primitive_type] = ACTIONS(1895),
    [anon_sym_enum] = ACTIONS(1895),
    [anon_sym_class] = ACTIONS(1895),
    [anon_sym_struct] = ACTIONS(1895),
    [anon_sym_union] = ACTIONS(1895),
    [anon_sym_if] = ACTIONS(1895),
    [anon_sym_else] = ACTIONS(1895),
    [anon_sym_switch] = ACTIONS(1895),
    [anon_sym_case] = ACTIONS(1895),
    [anon_sym_default] = ACTIONS(1895),
    [anon_sym_while] = ACTIONS(1895),
    [anon_sym_do] = ACTIONS(1895),
    [anon_sym_for] = ACTIONS(1895),
    [anon_sym_return] = ACTIONS(1895),
    [anon_sym_break] = ACTIONS(1895),
    [anon_sym_continue] = ACTIONS(1895),
    [anon_sym_goto] = ACTIONS(1895),
    [anon_sym___try] = ACTIONS(1895),
    [anon_sym___leave] = ACTIONS(1895),
    [anon_sym_not] = ACTIONS(1895),
    [anon_sym_compl] = ACTIONS(1895),
    [anon_sym_DASH_DASH] = ACTIONS(1897),
    [anon_sym_PLUS_PLUS] = ACTIONS(1897),
    [anon_sym_sizeof] = ACTIONS(1895),
    [anon_sym___alignof__] = ACTIONS(1895),
    [anon_sym___alignof] = ACTIONS(1895),
    [anon_sym__alignof] = ACTIONS(1895),
    [anon_sym_alignof] = ACTIONS(1895),
    [anon_sym__Alignof] = ACTIONS(1895),
    [anon_sym_offsetof] = ACTIONS(1895),
    [anon_sym__Generic] = ACTIONS(1895),
    [anon_sym_asm] = ACTIONS(1895),
    [anon_sym___asm__] = ACTIONS(1895),
    [sym_number_literal] = ACTIONS(1897),
    [anon_sym_L_SQUOTE] = ACTIONS(1897),
    [anon_sym_u_SQUOTE] = ACTIONS(1897),
    [anon_sym_U_SQUOTE] = ACTIONS(1897),
    [anon_sym_u8_SQUOTE] = ACTIONS(1897),
    [anon_sym_SQUOTE] = ACTIONS(1897),
    [anon_sym_L_DQUOTE] = ACTIONS(1897),
    [anon_sym_u_DQUOTE] = ACTIONS(1897),
    [anon_sym_U_DQUOTE] = ACTIONS(1897),
    [anon_sym_u8_DQUOTE] = ACTIONS(1897),
    [anon_sym_DQUOTE] = ACTIONS(1897),
    [sym_true] = ACTIONS(1895),
    [sym_false] = ACTIONS(1895),
    [anon_sym_NULL] = ACTIONS(1895),
    [anon_sym_nullptr] = ACTIONS(1895),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1895),
    [anon_sym_decltype] = ACTIONS(1895),
    [anon_sym_final] = ACTIONS(1895),
    [anon_sym_override] = ACTIONS(1895),
    [sym_virtual] = ACTIONS(1895),
    [anon_sym_explicit] = ACTIONS(1895),
    [anon_sym_typename] = ACTIONS(1895),
    [anon_sym_template] = ACTIONS(1895),
    [anon_sym_operator] = ACTIONS(1895),
    [anon_sym_try] = ACTIONS(1895),
    [anon_sym_delete] = ACTIONS(1895),
    [anon_sym_throw] = ACTIONS(1895),
    [anon_sym_namespace] = ACTIONS(1895),
    [anon_sym_using] = ACTIONS(1895),
    [anon_sym_static_assert] = ACTIONS(1895),
    [anon_sym_concept] = ACTIONS(1895),
    [anon_sym_co_return] = ACTIONS(1895),
    [anon_sym_co_yield] = ACTIONS(1895),
    [anon_sym_R_DQUOTE] = ACTIONS(1897),
    [anon_sym_LR_DQUOTE] = ACTIONS(1897),
    [anon_sym_uR_DQUOTE] = ACTIONS(1897),
    [anon_sym_UR_DQUOTE] = ACTIONS(1897),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1897),
    [anon_sym_co_await] = ACTIONS(1895),
    [anon_sym_new] = ACTIONS(1895),
    [anon_sym_requires] = ACTIONS(1895),
    [sym_this] = ACTIONS(1895),
    [anon_sym_discard] = ACTIONS(1895),
    [anon_sym_precise] = ACTIONS(1895),
    [anon_sym_shared] = ACTIONS(1895),
    [anon_sym_groupshared] = ACTIONS(1895),
    [anon_sym_uniform] = ACTIONS(1895),
    [anon_sym_row_major] = ACTIONS(1895),
    [anon_sym_column_major] = ACTIONS(1895),
    [anon_sym_globallycoherent] = ACTIONS(1895),
    [anon_sym_centroid] = ACTIONS(1895),
    [anon_sym_noperspective] = ACTIONS(1895),
    [anon_sym_nointerpolation] = ACTIONS(1895),
    [anon_sym_sample] = ACTIONS(1895),
    [anon_sym_linear] = ACTIONS(1895),
    [anon_sym_snorm] = ACTIONS(1895),
    [anon_sym_unorm] = ACTIONS(1895),
    [anon_sym_point] = ACTIONS(1895),
    [anon_sym_line] = ACTIONS(1895),
    [anon_sym_triangleadj] = ACTIONS(1895),
    [anon_sym_lineadj] = ACTIONS(1895),
    [anon_sym_triangle] = ACTIONS(1895),
    [anon_sym_cbuffer] = ACTIONS(1895),
  },
  [320] = {
    [sym_identifier] = ACTIONS(2502),
    [aux_sym_preproc_include_token1] = ACTIONS(2502),
    [aux_sym_preproc_def_token1] = ACTIONS(2502),
    [aux_sym_preproc_if_token1] = ACTIONS(2502),
    [aux_sym_preproc_if_token2] = ACTIONS(2502),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2502),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2502),
    [aux_sym_preproc_else_token1] = ACTIONS(2502),
    [aux_sym_preproc_elif_token1] = ACTIONS(2502),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2502),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2502),
    [sym_preproc_directive] = ACTIONS(2502),
    [anon_sym_LPAREN2] = ACTIONS(2504),
    [anon_sym_BANG] = ACTIONS(2504),
    [anon_sym_TILDE] = ACTIONS(2504),
    [anon_sym_DASH] = ACTIONS(2502),
    [anon_sym_PLUS] = ACTIONS(2502),
    [anon_sym_STAR] = ACTIONS(2504),
    [anon_sym_AMP_AMP] = ACTIONS(2504),
    [anon_sym_AMP] = ACTIONS(2502),
    [anon_sym_SEMI] = ACTIONS(2504),
    [anon_sym___extension__] = ACTIONS(2502),
    [anon_sym_typedef] = ACTIONS(2502),
    [anon_sym_in] = ACTIONS(2502),
    [anon_sym_out] = ACTIONS(2502),
    [anon_sym_inout] = ACTIONS(2502),
    [anon_sym_extern] = ACTIONS(2502),
    [anon_sym___attribute__] = ACTIONS(2502),
    [anon_sym_COLON_COLON] = ACTIONS(2504),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2504),
    [anon_sym___declspec] = ACTIONS(2502),
    [anon_sym___based] = ACTIONS(2502),
    [anon_sym___cdecl] = ACTIONS(2502),
    [anon_sym___clrcall] = ACTIONS(2502),
    [anon_sym___stdcall] = ACTIONS(2502),
    [anon_sym___fastcall] = ACTIONS(2502),
    [anon_sym___thiscall] = ACTIONS(2502),
    [anon_sym___vectorcall] = ACTIONS(2502),
    [anon_sym_LBRACE] = ACTIONS(2504),
    [anon_sym_signed] = ACTIONS(2502),
    [anon_sym_unsigned] = ACTIONS(2502),
    [anon_sym_long] = ACTIONS(2502),
    [anon_sym_short] = ACTIONS(2502),
    [anon_sym_LBRACK] = ACTIONS(2502),
    [anon_sym_static] = ACTIONS(2502),
    [anon_sym_register] = ACTIONS(2502),
    [anon_sym_inline] = ACTIONS(2502),
    [anon_sym___inline] = ACTIONS(2502),
    [anon_sym___inline__] = ACTIONS(2502),
    [anon_sym___forceinline] = ACTIONS(2502),
    [anon_sym_thread_local] = ACTIONS(2502),
    [anon_sym___thread] = ACTIONS(2502),
    [anon_sym_const] = ACTIONS(2502),
    [anon_sym_constexpr] = ACTIONS(2502),
    [anon_sym_volatile] = ACTIONS(2502),
    [anon_sym_restrict] = ACTIONS(2502),
    [anon_sym___restrict__] = ACTIONS(2502),
    [anon_sym__Atomic] = ACTIONS(2502),
    [anon_sym__Noreturn] = ACTIONS(2502),
    [anon_sym_noreturn] = ACTIONS(2502),
    [anon_sym_mutable] = ACTIONS(2502),
    [anon_sym_constinit] = ACTIONS(2502),
    [anon_sym_consteval] = ACTIONS(2502),
    [anon_sym_alignas] = ACTIONS(2502),
    [anon_sym__Alignas] = ACTIONS(2502),
    [sym_primitive_type] = ACTIONS(2502),
    [anon_sym_enum] = ACTIONS(2502),
    [anon_sym_class] = ACTIONS(2502),
    [anon_sym_struct] = ACTIONS(2502),
    [anon_sym_union] = ACTIONS(2502),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_switch] = ACTIONS(2502),
    [anon_sym_case] = ACTIONS(2502),
    [anon_sym_default] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_do] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2502),
    [anon_sym_return] = ACTIONS(2502),
    [anon_sym_break] = ACTIONS(2502),
    [anon_sym_continue] = ACTIONS(2502),
    [anon_sym_goto] = ACTIONS(2502),
    [anon_sym___try] = ACTIONS(2502),
    [anon_sym___leave] = ACTIONS(2502),
    [anon_sym_not] = ACTIONS(2502),
    [anon_sym_compl] = ACTIONS(2502),
    [anon_sym_DASH_DASH] = ACTIONS(2504),
    [anon_sym_PLUS_PLUS] = ACTIONS(2504),
    [anon_sym_sizeof] = ACTIONS(2502),
    [anon_sym___alignof__] = ACTIONS(2502),
    [anon_sym___alignof] = ACTIONS(2502),
    [anon_sym__alignof] = ACTIONS(2502),
    [anon_sym_alignof] = ACTIONS(2502),
    [anon_sym__Alignof] = ACTIONS(2502),
    [anon_sym_offsetof] = ACTIONS(2502),
    [anon_sym__Generic] = ACTIONS(2502),
    [anon_sym_asm] = ACTIONS(2502),
    [anon_sym___asm__] = ACTIONS(2502),
    [sym_number_literal] = ACTIONS(2504),
    [anon_sym_L_SQUOTE] = ACTIONS(2504),
    [anon_sym_u_SQUOTE] = ACTIONS(2504),
    [anon_sym_U_SQUOTE] = ACTIONS(2504),
    [anon_sym_u8_SQUOTE] = ACTIONS(2504),
    [anon_sym_SQUOTE] = ACTIONS(2504),
    [anon_sym_L_DQUOTE] = ACTIONS(2504),
    [anon_sym_u_DQUOTE] = ACTIONS(2504),
    [anon_sym_U_DQUOTE] = ACTIONS(2504),
    [anon_sym_u8_DQUOTE] = ACTIONS(2504),
    [anon_sym_DQUOTE] = ACTIONS(2504),
    [sym_true] = ACTIONS(2502),
    [sym_false] = ACTIONS(2502),
    [anon_sym_NULL] = ACTIONS(2502),
    [anon_sym_nullptr] = ACTIONS(2502),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2502),
    [anon_sym_decltype] = ACTIONS(2502),
    [sym_virtual] = ACTIONS(2502),
    [anon_sym_explicit] = ACTIONS(2502),
    [anon_sym_typename] = ACTIONS(2502),
    [anon_sym_template] = ACTIONS(2502),
    [anon_sym_operator] = ACTIONS(2502),
    [anon_sym_try] = ACTIONS(2502),
    [anon_sym_delete] = ACTIONS(2502),
    [anon_sym_throw] = ACTIONS(2502),
    [anon_sym_namespace] = ACTIONS(2502),
    [anon_sym_using] = ACTIONS(2502),
    [anon_sym_static_assert] = ACTIONS(2502),
    [anon_sym_concept] = ACTIONS(2502),
    [anon_sym_co_return] = ACTIONS(2502),
    [anon_sym_co_yield] = ACTIONS(2502),
    [anon_sym_R_DQUOTE] = ACTIONS(2504),
    [anon_sym_LR_DQUOTE] = ACTIONS(2504),
    [anon_sym_uR_DQUOTE] = ACTIONS(2504),
    [anon_sym_UR_DQUOTE] = ACTIONS(2504),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2504),
    [anon_sym_co_await] = ACTIONS(2502),
    [anon_sym_new] = ACTIONS(2502),
    [anon_sym_requires] = ACTIONS(2502),
    [sym_this] = ACTIONS(2502),
    [anon_sym_discard] = ACTIONS(2502),
    [anon_sym_precise] = ACTIONS(2502),
    [anon_sym_shared] = ACTIONS(2502),
    [anon_sym_groupshared] = ACTIONS(2502),
    [anon_sym_uniform] = ACTIONS(2502),
    [anon_sym_row_major] = ACTIONS(2502),
    [anon_sym_column_major] = ACTIONS(2502),
    [anon_sym_globallycoherent] = ACTIONS(2502),
    [anon_sym_centroid] = ACTIONS(2502),
    [anon_sym_noperspective] = ACTIONS(2502),
    [anon_sym_nointerpolation] = ACTIONS(2502),
    [anon_sym_sample] = ACTIONS(2502),
    [anon_sym_linear] = ACTIONS(2502),
    [anon_sym_snorm] = ACTIONS(2502),
    [anon_sym_unorm] = ACTIONS(2502),
    [anon_sym_point] = ACTIONS(2502),
    [anon_sym_line] = ACTIONS(2502),
    [anon_sym_triangleadj] = ACTIONS(2502),
    [anon_sym_lineadj] = ACTIONS(2502),
    [anon_sym_triangle] = ACTIONS(2502),
    [anon_sym_cbuffer] = ACTIONS(2502),
  },
  [321] = {
    [ts_builtin_sym_end] = ACTIONS(1955),
    [sym_identifier] = ACTIONS(1953),
    [aux_sym_preproc_include_token1] = ACTIONS(1953),
    [aux_sym_preproc_def_token1] = ACTIONS(1953),
    [aux_sym_preproc_if_token1] = ACTIONS(1953),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1953),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1953),
    [sym_preproc_directive] = ACTIONS(1953),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_BANG] = ACTIONS(1955),
    [anon_sym_TILDE] = ACTIONS(1955),
    [anon_sym_DASH] = ACTIONS(1953),
    [anon_sym_PLUS] = ACTIONS(1953),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym_COLON] = ACTIONS(1953),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym_typedef] = ACTIONS(1953),
    [anon_sym_in] = ACTIONS(1953),
    [anon_sym_out] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1953),
    [anon_sym_extern] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1955),
    [anon_sym___declspec] = ACTIONS(1953),
    [anon_sym___based] = ACTIONS(1953),
    [anon_sym___cdecl] = ACTIONS(1953),
    [anon_sym___clrcall] = ACTIONS(1953),
    [anon_sym___stdcall] = ACTIONS(1953),
    [anon_sym___fastcall] = ACTIONS(1953),
    [anon_sym___thiscall] = ACTIONS(1953),
    [anon_sym___vectorcall] = ACTIONS(1953),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_signed] = ACTIONS(1953),
    [anon_sym_unsigned] = ACTIONS(1953),
    [anon_sym_long] = ACTIONS(1953),
    [anon_sym_short] = ACTIONS(1953),
    [anon_sym_LBRACK] = ACTIONS(1953),
    [anon_sym_static] = ACTIONS(1953),
    [anon_sym_register] = ACTIONS(1953),
    [anon_sym_inline] = ACTIONS(1953),
    [anon_sym___inline] = ACTIONS(1953),
    [anon_sym___inline__] = ACTIONS(1953),
    [anon_sym___forceinline] = ACTIONS(1953),
    [anon_sym_thread_local] = ACTIONS(1953),
    [anon_sym___thread] = ACTIONS(1953),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [sym_primitive_type] = ACTIONS(1953),
    [anon_sym_enum] = ACTIONS(1953),
    [anon_sym_class] = ACTIONS(1953),
    [anon_sym_struct] = ACTIONS(1953),
    [anon_sym_union] = ACTIONS(1953),
    [anon_sym_if] = ACTIONS(1953),
    [anon_sym_else] = ACTIONS(1953),
    [anon_sym_switch] = ACTIONS(1953),
    [anon_sym_case] = ACTIONS(1953),
    [anon_sym_default] = ACTIONS(1953),
    [anon_sym_while] = ACTIONS(1953),
    [anon_sym_do] = ACTIONS(1953),
    [anon_sym_for] = ACTIONS(1953),
    [anon_sym_return] = ACTIONS(1953),
    [anon_sym_break] = ACTIONS(1953),
    [anon_sym_continue] = ACTIONS(1953),
    [anon_sym_goto] = ACTIONS(1953),
    [anon_sym___try] = ACTIONS(1953),
    [anon_sym___leave] = ACTIONS(1953),
    [anon_sym_not] = ACTIONS(1953),
    [anon_sym_compl] = ACTIONS(1953),
    [anon_sym_DASH_DASH] = ACTIONS(1955),
    [anon_sym_PLUS_PLUS] = ACTIONS(1955),
    [anon_sym_sizeof] = ACTIONS(1953),
    [anon_sym___alignof__] = ACTIONS(1953),
    [anon_sym___alignof] = ACTIONS(1953),
    [anon_sym__alignof] = ACTIONS(1953),
    [anon_sym_alignof] = ACTIONS(1953),
    [anon_sym__Alignof] = ACTIONS(1953),
    [anon_sym_offsetof] = ACTIONS(1953),
    [anon_sym__Generic] = ACTIONS(1953),
    [anon_sym_asm] = ACTIONS(1953),
    [anon_sym___asm__] = ACTIONS(1953),
    [sym_number_literal] = ACTIONS(1955),
    [anon_sym_L_SQUOTE] = ACTIONS(1955),
    [anon_sym_u_SQUOTE] = ACTIONS(1955),
    [anon_sym_U_SQUOTE] = ACTIONS(1955),
    [anon_sym_u8_SQUOTE] = ACTIONS(1955),
    [anon_sym_SQUOTE] = ACTIONS(1955),
    [anon_sym_L_DQUOTE] = ACTIONS(1955),
    [anon_sym_u_DQUOTE] = ACTIONS(1955),
    [anon_sym_U_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8_DQUOTE] = ACTIONS(1955),
    [anon_sym_DQUOTE] = ACTIONS(1955),
    [sym_true] = ACTIONS(1953),
    [sym_false] = ACTIONS(1953),
    [anon_sym_NULL] = ACTIONS(1953),
    [anon_sym_nullptr] = ACTIONS(1953),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
    [sym_virtual] = ACTIONS(1953),
    [anon_sym_explicit] = ACTIONS(1953),
    [anon_sym_typename] = ACTIONS(1953),
    [anon_sym_template] = ACTIONS(1953),
    [anon_sym_operator] = ACTIONS(1953),
    [anon_sym_try] = ACTIONS(1953),
    [anon_sym_delete] = ACTIONS(1953),
    [anon_sym_throw] = ACTIONS(1953),
    [anon_sym_namespace] = ACTIONS(1953),
    [anon_sym_using] = ACTIONS(1953),
    [anon_sym_static_assert] = ACTIONS(1953),
    [anon_sym_concept] = ACTIONS(1953),
    [anon_sym_co_return] = ACTIONS(1953),
    [anon_sym_co_yield] = ACTIONS(1953),
    [anon_sym_R_DQUOTE] = ACTIONS(1955),
    [anon_sym_LR_DQUOTE] = ACTIONS(1955),
    [anon_sym_uR_DQUOTE] = ACTIONS(1955),
    [anon_sym_UR_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1955),
    [anon_sym_co_await] = ACTIONS(1953),
    [anon_sym_new] = ACTIONS(1953),
    [anon_sym_requires] = ACTIONS(1953),
    [sym_this] = ACTIONS(1953),
    [anon_sym_discard] = ACTIONS(1953),
    [anon_sym_precise] = ACTIONS(1953),
    [anon_sym_shared] = ACTIONS(1953),
    [anon_sym_groupshared] = ACTIONS(1953),
    [anon_sym_uniform] = ACTIONS(1953),
    [anon_sym_row_major] = ACTIONS(1953),
    [anon_sym_column_major] = ACTIONS(1953),
    [anon_sym_globallycoherent] = ACTIONS(1953),
    [anon_sym_centroid] = ACTIONS(1953),
    [anon_sym_noperspective] = ACTIONS(1953),
    [anon_sym_nointerpolation] = ACTIONS(1953),
    [anon_sym_sample] = ACTIONS(1953),
    [anon_sym_linear] = ACTIONS(1953),
    [anon_sym_snorm] = ACTIONS(1953),
    [anon_sym_unorm] = ACTIONS(1953),
    [anon_sym_point] = ACTIONS(1953),
    [anon_sym_line] = ACTIONS(1953),
    [anon_sym_triangleadj] = ACTIONS(1953),
    [anon_sym_lineadj] = ACTIONS(1953),
    [anon_sym_triangle] = ACTIONS(1953),
    [anon_sym_cbuffer] = ACTIONS(1953),
  },
  [322] = {
    [ts_builtin_sym_end] = ACTIONS(1951),
    [sym_identifier] = ACTIONS(1949),
    [aux_sym_preproc_include_token1] = ACTIONS(1949),
    [aux_sym_preproc_def_token1] = ACTIONS(1949),
    [aux_sym_preproc_if_token1] = ACTIONS(1949),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1949),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1949),
    [sym_preproc_directive] = ACTIONS(1949),
    [anon_sym_LPAREN2] = ACTIONS(1951),
    [anon_sym_BANG] = ACTIONS(1951),
    [anon_sym_TILDE] = ACTIONS(1951),
    [anon_sym_DASH] = ACTIONS(1949),
    [anon_sym_PLUS] = ACTIONS(1949),
    [anon_sym_STAR] = ACTIONS(1951),
    [anon_sym_AMP_AMP] = ACTIONS(1951),
    [anon_sym_AMP] = ACTIONS(1949),
    [anon_sym_COLON] = ACTIONS(1949),
    [anon_sym_SEMI] = ACTIONS(1951),
    [anon_sym___extension__] = ACTIONS(1949),
    [anon_sym_typedef] = ACTIONS(1949),
    [anon_sym_in] = ACTIONS(1949),
    [anon_sym_out] = ACTIONS(1949),
    [anon_sym_inout] = ACTIONS(1949),
    [anon_sym_extern] = ACTIONS(1949),
    [anon_sym___attribute__] = ACTIONS(1949),
    [anon_sym_COLON_COLON] = ACTIONS(1951),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1951),
    [anon_sym___declspec] = ACTIONS(1949),
    [anon_sym___based] = ACTIONS(1949),
    [anon_sym___cdecl] = ACTIONS(1949),
    [anon_sym___clrcall] = ACTIONS(1949),
    [anon_sym___stdcall] = ACTIONS(1949),
    [anon_sym___fastcall] = ACTIONS(1949),
    [anon_sym___thiscall] = ACTIONS(1949),
    [anon_sym___vectorcall] = ACTIONS(1949),
    [anon_sym_LBRACE] = ACTIONS(1951),
    [anon_sym_signed] = ACTIONS(1949),
    [anon_sym_unsigned] = ACTIONS(1949),
    [anon_sym_long] = ACTIONS(1949),
    [anon_sym_short] = ACTIONS(1949),
    [anon_sym_LBRACK] = ACTIONS(1949),
    [anon_sym_static] = ACTIONS(1949),
    [anon_sym_register] = ACTIONS(1949),
    [anon_sym_inline] = ACTIONS(1949),
    [anon_sym___inline] = ACTIONS(1949),
    [anon_sym___inline__] = ACTIONS(1949),
    [anon_sym___forceinline] = ACTIONS(1949),
    [anon_sym_thread_local] = ACTIONS(1949),
    [anon_sym___thread] = ACTIONS(1949),
    [anon_sym_const] = ACTIONS(1949),
    [anon_sym_constexpr] = ACTIONS(1949),
    [anon_sym_volatile] = ACTIONS(1949),
    [anon_sym_restrict] = ACTIONS(1949),
    [anon_sym___restrict__] = ACTIONS(1949),
    [anon_sym__Atomic] = ACTIONS(1949),
    [anon_sym__Noreturn] = ACTIONS(1949),
    [anon_sym_noreturn] = ACTIONS(1949),
    [anon_sym_mutable] = ACTIONS(1949),
    [anon_sym_constinit] = ACTIONS(1949),
    [anon_sym_consteval] = ACTIONS(1949),
    [anon_sym_alignas] = ACTIONS(1949),
    [anon_sym__Alignas] = ACTIONS(1949),
    [sym_primitive_type] = ACTIONS(1949),
    [anon_sym_enum] = ACTIONS(1949),
    [anon_sym_class] = ACTIONS(1949),
    [anon_sym_struct] = ACTIONS(1949),
    [anon_sym_union] = ACTIONS(1949),
    [anon_sym_if] = ACTIONS(1949),
    [anon_sym_else] = ACTIONS(1949),
    [anon_sym_switch] = ACTIONS(1949),
    [anon_sym_case] = ACTIONS(1949),
    [anon_sym_default] = ACTIONS(1949),
    [anon_sym_while] = ACTIONS(1949),
    [anon_sym_do] = ACTIONS(1949),
    [anon_sym_for] = ACTIONS(1949),
    [anon_sym_return] = ACTIONS(1949),
    [anon_sym_break] = ACTIONS(1949),
    [anon_sym_continue] = ACTIONS(1949),
    [anon_sym_goto] = ACTIONS(1949),
    [anon_sym___try] = ACTIONS(1949),
    [anon_sym___leave] = ACTIONS(1949),
    [anon_sym_not] = ACTIONS(1949),
    [anon_sym_compl] = ACTIONS(1949),
    [anon_sym_DASH_DASH] = ACTIONS(1951),
    [anon_sym_PLUS_PLUS] = ACTIONS(1951),
    [anon_sym_sizeof] = ACTIONS(1949),
    [anon_sym___alignof__] = ACTIONS(1949),
    [anon_sym___alignof] = ACTIONS(1949),
    [anon_sym__alignof] = ACTIONS(1949),
    [anon_sym_alignof] = ACTIONS(1949),
    [anon_sym__Alignof] = ACTIONS(1949),
    [anon_sym_offsetof] = ACTIONS(1949),
    [anon_sym__Generic] = ACTIONS(1949),
    [anon_sym_asm] = ACTIONS(1949),
    [anon_sym___asm__] = ACTIONS(1949),
    [sym_number_literal] = ACTIONS(1951),
    [anon_sym_L_SQUOTE] = ACTIONS(1951),
    [anon_sym_u_SQUOTE] = ACTIONS(1951),
    [anon_sym_U_SQUOTE] = ACTIONS(1951),
    [anon_sym_u8_SQUOTE] = ACTIONS(1951),
    [anon_sym_SQUOTE] = ACTIONS(1951),
    [anon_sym_L_DQUOTE] = ACTIONS(1951),
    [anon_sym_u_DQUOTE] = ACTIONS(1951),
    [anon_sym_U_DQUOTE] = ACTIONS(1951),
    [anon_sym_u8_DQUOTE] = ACTIONS(1951),
    [anon_sym_DQUOTE] = ACTIONS(1951),
    [sym_true] = ACTIONS(1949),
    [sym_false] = ACTIONS(1949),
    [anon_sym_NULL] = ACTIONS(1949),
    [anon_sym_nullptr] = ACTIONS(1949),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1949),
    [anon_sym_decltype] = ACTIONS(1949),
    [anon_sym_final] = ACTIONS(1949),
    [anon_sym_override] = ACTIONS(1949),
    [sym_virtual] = ACTIONS(1949),
    [anon_sym_explicit] = ACTIONS(1949),
    [anon_sym_typename] = ACTIONS(1949),
    [anon_sym_template] = ACTIONS(1949),
    [anon_sym_operator] = ACTIONS(1949),
    [anon_sym_try] = ACTIONS(1949),
    [anon_sym_delete] = ACTIONS(1949),
    [anon_sym_throw] = ACTIONS(1949),
    [anon_sym_namespace] = ACTIONS(1949),
    [anon_sym_using] = ACTIONS(1949),
    [anon_sym_static_assert] = ACTIONS(1949),
    [anon_sym_concept] = ACTIONS(1949),
    [anon_sym_co_return] = ACTIONS(1949),
    [anon_sym_co_yield] = ACTIONS(1949),
    [anon_sym_R_DQUOTE] = ACTIONS(1951),
    [anon_sym_LR_DQUOTE] = ACTIONS(1951),
    [anon_sym_uR_DQUOTE] = ACTIONS(1951),
    [anon_sym_UR_DQUOTE] = ACTIONS(1951),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1951),
    [anon_sym_co_await] = ACTIONS(1949),
    [anon_sym_new] = ACTIONS(1949),
    [anon_sym_requires] = ACTIONS(1949),
    [sym_this] = ACTIONS(1949),
    [anon_sym_discard] = ACTIONS(1949),
    [anon_sym_precise] = ACTIONS(1949),
    [anon_sym_shared] = ACTIONS(1949),
    [anon_sym_groupshared] = ACTIONS(1949),
    [anon_sym_uniform] = ACTIONS(1949),
    [anon_sym_row_major] = ACTIONS(1949),
    [anon_sym_column_major] = ACTIONS(1949),
    [anon_sym_globallycoherent] = ACTIONS(1949),
    [anon_sym_centroid] = ACTIONS(1949),
    [anon_sym_noperspective] = ACTIONS(1949),
    [anon_sym_nointerpolation] = ACTIONS(1949),
    [anon_sym_sample] = ACTIONS(1949),
    [anon_sym_linear] = ACTIONS(1949),
    [anon_sym_snorm] = ACTIONS(1949),
    [anon_sym_unorm] = ACTIONS(1949),
    [anon_sym_point] = ACTIONS(1949),
    [anon_sym_line] = ACTIONS(1949),
    [anon_sym_triangleadj] = ACTIONS(1949),
    [anon_sym_lineadj] = ACTIONS(1949),
    [anon_sym_triangle] = ACTIONS(1949),
    [anon_sym_cbuffer] = ACTIONS(1949),
  },
  [323] = {
    [sym_identifier] = ACTIONS(2506),
    [aux_sym_preproc_include_token1] = ACTIONS(2506),
    [aux_sym_preproc_def_token1] = ACTIONS(2506),
    [aux_sym_preproc_if_token1] = ACTIONS(2506),
    [aux_sym_preproc_if_token2] = ACTIONS(2506),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2506),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2506),
    [aux_sym_preproc_else_token1] = ACTIONS(2506),
    [aux_sym_preproc_elif_token1] = ACTIONS(2506),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2506),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2506),
    [sym_preproc_directive] = ACTIONS(2506),
    [anon_sym_LPAREN2] = ACTIONS(2508),
    [anon_sym_BANG] = ACTIONS(2508),
    [anon_sym_TILDE] = ACTIONS(2508),
    [anon_sym_DASH] = ACTIONS(2506),
    [anon_sym_PLUS] = ACTIONS(2506),
    [anon_sym_STAR] = ACTIONS(2508),
    [anon_sym_AMP_AMP] = ACTIONS(2508),
    [anon_sym_AMP] = ACTIONS(2506),
    [anon_sym_SEMI] = ACTIONS(2508),
    [anon_sym___extension__] = ACTIONS(2506),
    [anon_sym_typedef] = ACTIONS(2506),
    [anon_sym_in] = ACTIONS(2506),
    [anon_sym_out] = ACTIONS(2506),
    [anon_sym_inout] = ACTIONS(2506),
    [anon_sym_extern] = ACTIONS(2506),
    [anon_sym___attribute__] = ACTIONS(2506),
    [anon_sym_COLON_COLON] = ACTIONS(2508),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2508),
    [anon_sym___declspec] = ACTIONS(2506),
    [anon_sym___based] = ACTIONS(2506),
    [anon_sym___cdecl] = ACTIONS(2506),
    [anon_sym___clrcall] = ACTIONS(2506),
    [anon_sym___stdcall] = ACTIONS(2506),
    [anon_sym___fastcall] = ACTIONS(2506),
    [anon_sym___thiscall] = ACTIONS(2506),
    [anon_sym___vectorcall] = ACTIONS(2506),
    [anon_sym_LBRACE] = ACTIONS(2508),
    [anon_sym_signed] = ACTIONS(2506),
    [anon_sym_unsigned] = ACTIONS(2506),
    [anon_sym_long] = ACTIONS(2506),
    [anon_sym_short] = ACTIONS(2506),
    [anon_sym_LBRACK] = ACTIONS(2506),
    [anon_sym_static] = ACTIONS(2506),
    [anon_sym_register] = ACTIONS(2506),
    [anon_sym_inline] = ACTIONS(2506),
    [anon_sym___inline] = ACTIONS(2506),
    [anon_sym___inline__] = ACTIONS(2506),
    [anon_sym___forceinline] = ACTIONS(2506),
    [anon_sym_thread_local] = ACTIONS(2506),
    [anon_sym___thread] = ACTIONS(2506),
    [anon_sym_const] = ACTIONS(2506),
    [anon_sym_constexpr] = ACTIONS(2506),
    [anon_sym_volatile] = ACTIONS(2506),
    [anon_sym_restrict] = ACTIONS(2506),
    [anon_sym___restrict__] = ACTIONS(2506),
    [anon_sym__Atomic] = ACTIONS(2506),
    [anon_sym__Noreturn] = ACTIONS(2506),
    [anon_sym_noreturn] = ACTIONS(2506),
    [anon_sym_mutable] = ACTIONS(2506),
    [anon_sym_constinit] = ACTIONS(2506),
    [anon_sym_consteval] = ACTIONS(2506),
    [anon_sym_alignas] = ACTIONS(2506),
    [anon_sym__Alignas] = ACTIONS(2506),
    [sym_primitive_type] = ACTIONS(2506),
    [anon_sym_enum] = ACTIONS(2506),
    [anon_sym_class] = ACTIONS(2506),
    [anon_sym_struct] = ACTIONS(2506),
    [anon_sym_union] = ACTIONS(2506),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_switch] = ACTIONS(2506),
    [anon_sym_case] = ACTIONS(2506),
    [anon_sym_default] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(2506),
    [anon_sym_do] = ACTIONS(2506),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_return] = ACTIONS(2506),
    [anon_sym_break] = ACTIONS(2506),
    [anon_sym_continue] = ACTIONS(2506),
    [anon_sym_goto] = ACTIONS(2506),
    [anon_sym___try] = ACTIONS(2506),
    [anon_sym___leave] = ACTIONS(2506),
    [anon_sym_not] = ACTIONS(2506),
    [anon_sym_compl] = ACTIONS(2506),
    [anon_sym_DASH_DASH] = ACTIONS(2508),
    [anon_sym_PLUS_PLUS] = ACTIONS(2508),
    [anon_sym_sizeof] = ACTIONS(2506),
    [anon_sym___alignof__] = ACTIONS(2506),
    [anon_sym___alignof] = ACTIONS(2506),
    [anon_sym__alignof] = ACTIONS(2506),
    [anon_sym_alignof] = ACTIONS(2506),
    [anon_sym__Alignof] = ACTIONS(2506),
    [anon_sym_offsetof] = ACTIONS(2506),
    [anon_sym__Generic] = ACTIONS(2506),
    [anon_sym_asm] = ACTIONS(2506),
    [anon_sym___asm__] = ACTIONS(2506),
    [sym_number_literal] = ACTIONS(2508),
    [anon_sym_L_SQUOTE] = ACTIONS(2508),
    [anon_sym_u_SQUOTE] = ACTIONS(2508),
    [anon_sym_U_SQUOTE] = ACTIONS(2508),
    [anon_sym_u8_SQUOTE] = ACTIONS(2508),
    [anon_sym_SQUOTE] = ACTIONS(2508),
    [anon_sym_L_DQUOTE] = ACTIONS(2508),
    [anon_sym_u_DQUOTE] = ACTIONS(2508),
    [anon_sym_U_DQUOTE] = ACTIONS(2508),
    [anon_sym_u8_DQUOTE] = ACTIONS(2508),
    [anon_sym_DQUOTE] = ACTIONS(2508),
    [sym_true] = ACTIONS(2506),
    [sym_false] = ACTIONS(2506),
    [anon_sym_NULL] = ACTIONS(2506),
    [anon_sym_nullptr] = ACTIONS(2506),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2506),
    [anon_sym_decltype] = ACTIONS(2506),
    [sym_virtual] = ACTIONS(2506),
    [anon_sym_explicit] = ACTIONS(2506),
    [anon_sym_typename] = ACTIONS(2506),
    [anon_sym_template] = ACTIONS(2506),
    [anon_sym_operator] = ACTIONS(2506),
    [anon_sym_try] = ACTIONS(2506),
    [anon_sym_delete] = ACTIONS(2506),
    [anon_sym_throw] = ACTIONS(2506),
    [anon_sym_namespace] = ACTIONS(2506),
    [anon_sym_using] = ACTIONS(2506),
    [anon_sym_static_assert] = ACTIONS(2506),
    [anon_sym_concept] = ACTIONS(2506),
    [anon_sym_co_return] = ACTIONS(2506),
    [anon_sym_co_yield] = ACTIONS(2506),
    [anon_sym_R_DQUOTE] = ACTIONS(2508),
    [anon_sym_LR_DQUOTE] = ACTIONS(2508),
    [anon_sym_uR_DQUOTE] = ACTIONS(2508),
    [anon_sym_UR_DQUOTE] = ACTIONS(2508),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2508),
    [anon_sym_co_await] = ACTIONS(2506),
    [anon_sym_new] = ACTIONS(2506),
    [anon_sym_requires] = ACTIONS(2506),
    [sym_this] = ACTIONS(2506),
    [anon_sym_discard] = ACTIONS(2506),
    [anon_sym_precise] = ACTIONS(2506),
    [anon_sym_shared] = ACTIONS(2506),
    [anon_sym_groupshared] = ACTIONS(2506),
    [anon_sym_uniform] = ACTIONS(2506),
    [anon_sym_row_major] = ACTIONS(2506),
    [anon_sym_column_major] = ACTIONS(2506),
    [anon_sym_globallycoherent] = ACTIONS(2506),
    [anon_sym_centroid] = ACTIONS(2506),
    [anon_sym_noperspective] = ACTIONS(2506),
    [anon_sym_nointerpolation] = ACTIONS(2506),
    [anon_sym_sample] = ACTIONS(2506),
    [anon_sym_linear] = ACTIONS(2506),
    [anon_sym_snorm] = ACTIONS(2506),
    [anon_sym_unorm] = ACTIONS(2506),
    [anon_sym_point] = ACTIONS(2506),
    [anon_sym_line] = ACTIONS(2506),
    [anon_sym_triangleadj] = ACTIONS(2506),
    [anon_sym_lineadj] = ACTIONS(2506),
    [anon_sym_triangle] = ACTIONS(2506),
    [anon_sym_cbuffer] = ACTIONS(2506),
  },
  [324] = {
    [ts_builtin_sym_end] = ACTIONS(1961),
    [sym_identifier] = ACTIONS(1959),
    [aux_sym_preproc_include_token1] = ACTIONS(1959),
    [aux_sym_preproc_def_token1] = ACTIONS(1959),
    [aux_sym_preproc_if_token1] = ACTIONS(1959),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1959),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1959),
    [sym_preproc_directive] = ACTIONS(1959),
    [anon_sym_LPAREN2] = ACTIONS(1961),
    [anon_sym_BANG] = ACTIONS(1961),
    [anon_sym_TILDE] = ACTIONS(1961),
    [anon_sym_DASH] = ACTIONS(1959),
    [anon_sym_PLUS] = ACTIONS(1959),
    [anon_sym_STAR] = ACTIONS(1961),
    [anon_sym_AMP_AMP] = ACTIONS(1961),
    [anon_sym_AMP] = ACTIONS(1959),
    [anon_sym_COLON] = ACTIONS(1959),
    [anon_sym_SEMI] = ACTIONS(1961),
    [anon_sym___extension__] = ACTIONS(1959),
    [anon_sym_typedef] = ACTIONS(1959),
    [anon_sym_in] = ACTIONS(1959),
    [anon_sym_out] = ACTIONS(1959),
    [anon_sym_inout] = ACTIONS(1959),
    [anon_sym_extern] = ACTIONS(1959),
    [anon_sym___attribute__] = ACTIONS(1959),
    [anon_sym_COLON_COLON] = ACTIONS(1961),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1961),
    [anon_sym___declspec] = ACTIONS(1959),
    [anon_sym___based] = ACTIONS(1959),
    [anon_sym___cdecl] = ACTIONS(1959),
    [anon_sym___clrcall] = ACTIONS(1959),
    [anon_sym___stdcall] = ACTIONS(1959),
    [anon_sym___fastcall] = ACTIONS(1959),
    [anon_sym___thiscall] = ACTIONS(1959),
    [anon_sym___vectorcall] = ACTIONS(1959),
    [anon_sym_LBRACE] = ACTIONS(1961),
    [anon_sym_signed] = ACTIONS(1959),
    [anon_sym_unsigned] = ACTIONS(1959),
    [anon_sym_long] = ACTIONS(1959),
    [anon_sym_short] = ACTIONS(1959),
    [anon_sym_LBRACK] = ACTIONS(1959),
    [anon_sym_static] = ACTIONS(1959),
    [anon_sym_register] = ACTIONS(1959),
    [anon_sym_inline] = ACTIONS(1959),
    [anon_sym___inline] = ACTIONS(1959),
    [anon_sym___inline__] = ACTIONS(1959),
    [anon_sym___forceinline] = ACTIONS(1959),
    [anon_sym_thread_local] = ACTIONS(1959),
    [anon_sym___thread] = ACTIONS(1959),
    [anon_sym_const] = ACTIONS(1959),
    [anon_sym_constexpr] = ACTIONS(1959),
    [anon_sym_volatile] = ACTIONS(1959),
    [anon_sym_restrict] = ACTIONS(1959),
    [anon_sym___restrict__] = ACTIONS(1959),
    [anon_sym__Atomic] = ACTIONS(1959),
    [anon_sym__Noreturn] = ACTIONS(1959),
    [anon_sym_noreturn] = ACTIONS(1959),
    [anon_sym_mutable] = ACTIONS(1959),
    [anon_sym_constinit] = ACTIONS(1959),
    [anon_sym_consteval] = ACTIONS(1959),
    [anon_sym_alignas] = ACTIONS(1959),
    [anon_sym__Alignas] = ACTIONS(1959),
    [sym_primitive_type] = ACTIONS(1959),
    [anon_sym_enum] = ACTIONS(1959),
    [anon_sym_class] = ACTIONS(1959),
    [anon_sym_struct] = ACTIONS(1959),
    [anon_sym_union] = ACTIONS(1959),
    [anon_sym_if] = ACTIONS(1959),
    [anon_sym_else] = ACTIONS(1959),
    [anon_sym_switch] = ACTIONS(1959),
    [anon_sym_case] = ACTIONS(1959),
    [anon_sym_default] = ACTIONS(1959),
    [anon_sym_while] = ACTIONS(1959),
    [anon_sym_do] = ACTIONS(1959),
    [anon_sym_for] = ACTIONS(1959),
    [anon_sym_return] = ACTIONS(1959),
    [anon_sym_break] = ACTIONS(1959),
    [anon_sym_continue] = ACTIONS(1959),
    [anon_sym_goto] = ACTIONS(1959),
    [anon_sym___try] = ACTIONS(1959),
    [anon_sym___leave] = ACTIONS(1959),
    [anon_sym_not] = ACTIONS(1959),
    [anon_sym_compl] = ACTIONS(1959),
    [anon_sym_DASH_DASH] = ACTIONS(1961),
    [anon_sym_PLUS_PLUS] = ACTIONS(1961),
    [anon_sym_sizeof] = ACTIONS(1959),
    [anon_sym___alignof__] = ACTIONS(1959),
    [anon_sym___alignof] = ACTIONS(1959),
    [anon_sym__alignof] = ACTIONS(1959),
    [anon_sym_alignof] = ACTIONS(1959),
    [anon_sym__Alignof] = ACTIONS(1959),
    [anon_sym_offsetof] = ACTIONS(1959),
    [anon_sym__Generic] = ACTIONS(1959),
    [anon_sym_asm] = ACTIONS(1959),
    [anon_sym___asm__] = ACTIONS(1959),
    [sym_number_literal] = ACTIONS(1961),
    [anon_sym_L_SQUOTE] = ACTIONS(1961),
    [anon_sym_u_SQUOTE] = ACTIONS(1961),
    [anon_sym_U_SQUOTE] = ACTIONS(1961),
    [anon_sym_u8_SQUOTE] = ACTIONS(1961),
    [anon_sym_SQUOTE] = ACTIONS(1961),
    [anon_sym_L_DQUOTE] = ACTIONS(1961),
    [anon_sym_u_DQUOTE] = ACTIONS(1961),
    [anon_sym_U_DQUOTE] = ACTIONS(1961),
    [anon_sym_u8_DQUOTE] = ACTIONS(1961),
    [anon_sym_DQUOTE] = ACTIONS(1961),
    [sym_true] = ACTIONS(1959),
    [sym_false] = ACTIONS(1959),
    [anon_sym_NULL] = ACTIONS(1959),
    [anon_sym_nullptr] = ACTIONS(1959),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1959),
    [anon_sym_decltype] = ACTIONS(1959),
    [anon_sym_final] = ACTIONS(1959),
    [anon_sym_override] = ACTIONS(1959),
    [sym_virtual] = ACTIONS(1959),
    [anon_sym_explicit] = ACTIONS(1959),
    [anon_sym_typename] = ACTIONS(1959),
    [anon_sym_template] = ACTIONS(1959),
    [anon_sym_operator] = ACTIONS(1959),
    [anon_sym_try] = ACTIONS(1959),
    [anon_sym_delete] = ACTIONS(1959),
    [anon_sym_throw] = ACTIONS(1959),
    [anon_sym_namespace] = ACTIONS(1959),
    [anon_sym_using] = ACTIONS(1959),
    [anon_sym_static_assert] = ACTIONS(1959),
    [anon_sym_concept] = ACTIONS(1959),
    [anon_sym_co_return] = ACTIONS(1959),
    [anon_sym_co_yield] = ACTIONS(1959),
    [anon_sym_R_DQUOTE] = ACTIONS(1961),
    [anon_sym_LR_DQUOTE] = ACTIONS(1961),
    [anon_sym_uR_DQUOTE] = ACTIONS(1961),
    [anon_sym_UR_DQUOTE] = ACTIONS(1961),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1961),
    [anon_sym_co_await] = ACTIONS(1959),
    [anon_sym_new] = ACTIONS(1959),
    [anon_sym_requires] = ACTIONS(1959),
    [sym_this] = ACTIONS(1959),
    [anon_sym_discard] = ACTIONS(1959),
    [anon_sym_precise] = ACTIONS(1959),
    [anon_sym_shared] = ACTIONS(1959),
    [anon_sym_groupshared] = ACTIONS(1959),
    [anon_sym_uniform] = ACTIONS(1959),
    [anon_sym_row_major] = ACTIONS(1959),
    [anon_sym_column_major] = ACTIONS(1959),
    [anon_sym_globallycoherent] = ACTIONS(1959),
    [anon_sym_centroid] = ACTIONS(1959),
    [anon_sym_noperspective] = ACTIONS(1959),
    [anon_sym_nointerpolation] = ACTIONS(1959),
    [anon_sym_sample] = ACTIONS(1959),
    [anon_sym_linear] = ACTIONS(1959),
    [anon_sym_snorm] = ACTIONS(1959),
    [anon_sym_unorm] = ACTIONS(1959),
    [anon_sym_point] = ACTIONS(1959),
    [anon_sym_line] = ACTIONS(1959),
    [anon_sym_triangleadj] = ACTIONS(1959),
    [anon_sym_lineadj] = ACTIONS(1959),
    [anon_sym_triangle] = ACTIONS(1959),
    [anon_sym_cbuffer] = ACTIONS(1959),
  },
  [325] = {
    [sym_identifier] = ACTIONS(2510),
    [aux_sym_preproc_include_token1] = ACTIONS(2510),
    [aux_sym_preproc_def_token1] = ACTIONS(2510),
    [aux_sym_preproc_if_token1] = ACTIONS(2510),
    [aux_sym_preproc_if_token2] = ACTIONS(2510),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2510),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2510),
    [aux_sym_preproc_else_token1] = ACTIONS(2510),
    [aux_sym_preproc_elif_token1] = ACTIONS(2510),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2510),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2510),
    [sym_preproc_directive] = ACTIONS(2510),
    [anon_sym_LPAREN2] = ACTIONS(2512),
    [anon_sym_BANG] = ACTIONS(2512),
    [anon_sym_TILDE] = ACTIONS(2512),
    [anon_sym_DASH] = ACTIONS(2510),
    [anon_sym_PLUS] = ACTIONS(2510),
    [anon_sym_STAR] = ACTIONS(2512),
    [anon_sym_AMP_AMP] = ACTIONS(2512),
    [anon_sym_AMP] = ACTIONS(2510),
    [anon_sym_SEMI] = ACTIONS(2512),
    [anon_sym___extension__] = ACTIONS(2510),
    [anon_sym_typedef] = ACTIONS(2510),
    [anon_sym_in] = ACTIONS(2510),
    [anon_sym_out] = ACTIONS(2510),
    [anon_sym_inout] = ACTIONS(2510),
    [anon_sym_extern] = ACTIONS(2510),
    [anon_sym___attribute__] = ACTIONS(2510),
    [anon_sym_COLON_COLON] = ACTIONS(2512),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2512),
    [anon_sym___declspec] = ACTIONS(2510),
    [anon_sym___based] = ACTIONS(2510),
    [anon_sym___cdecl] = ACTIONS(2510),
    [anon_sym___clrcall] = ACTIONS(2510),
    [anon_sym___stdcall] = ACTIONS(2510),
    [anon_sym___fastcall] = ACTIONS(2510),
    [anon_sym___thiscall] = ACTIONS(2510),
    [anon_sym___vectorcall] = ACTIONS(2510),
    [anon_sym_LBRACE] = ACTIONS(2512),
    [anon_sym_signed] = ACTIONS(2510),
    [anon_sym_unsigned] = ACTIONS(2510),
    [anon_sym_long] = ACTIONS(2510),
    [anon_sym_short] = ACTIONS(2510),
    [anon_sym_LBRACK] = ACTIONS(2510),
    [anon_sym_static] = ACTIONS(2510),
    [anon_sym_register] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(2510),
    [anon_sym___inline] = ACTIONS(2510),
    [anon_sym___inline__] = ACTIONS(2510),
    [anon_sym___forceinline] = ACTIONS(2510),
    [anon_sym_thread_local] = ACTIONS(2510),
    [anon_sym___thread] = ACTIONS(2510),
    [anon_sym_const] = ACTIONS(2510),
    [anon_sym_constexpr] = ACTIONS(2510),
    [anon_sym_volatile] = ACTIONS(2510),
    [anon_sym_restrict] = ACTIONS(2510),
    [anon_sym___restrict__] = ACTIONS(2510),
    [anon_sym__Atomic] = ACTIONS(2510),
    [anon_sym__Noreturn] = ACTIONS(2510),
    [anon_sym_noreturn] = ACTIONS(2510),
    [anon_sym_mutable] = ACTIONS(2510),
    [anon_sym_constinit] = ACTIONS(2510),
    [anon_sym_consteval] = ACTIONS(2510),
    [anon_sym_alignas] = ACTIONS(2510),
    [anon_sym__Alignas] = ACTIONS(2510),
    [sym_primitive_type] = ACTIONS(2510),
    [anon_sym_enum] = ACTIONS(2510),
    [anon_sym_class] = ACTIONS(2510),
    [anon_sym_struct] = ACTIONS(2510),
    [anon_sym_union] = ACTIONS(2510),
    [anon_sym_if] = ACTIONS(2510),
    [anon_sym_switch] = ACTIONS(2510),
    [anon_sym_case] = ACTIONS(2510),
    [anon_sym_default] = ACTIONS(2510),
    [anon_sym_while] = ACTIONS(2510),
    [anon_sym_do] = ACTIONS(2510),
    [anon_sym_for] = ACTIONS(2510),
    [anon_sym_return] = ACTIONS(2510),
    [anon_sym_break] = ACTIONS(2510),
    [anon_sym_continue] = ACTIONS(2510),
    [anon_sym_goto] = ACTIONS(2510),
    [anon_sym___try] = ACTIONS(2510),
    [anon_sym___leave] = ACTIONS(2510),
    [anon_sym_not] = ACTIONS(2510),
    [anon_sym_compl] = ACTIONS(2510),
    [anon_sym_DASH_DASH] = ACTIONS(2512),
    [anon_sym_PLUS_PLUS] = ACTIONS(2512),
    [anon_sym_sizeof] = ACTIONS(2510),
    [anon_sym___alignof__] = ACTIONS(2510),
    [anon_sym___alignof] = ACTIONS(2510),
    [anon_sym__alignof] = ACTIONS(2510),
    [anon_sym_alignof] = ACTIONS(2510),
    [anon_sym__Alignof] = ACTIONS(2510),
    [anon_sym_offsetof] = ACTIONS(2510),
    [anon_sym__Generic] = ACTIONS(2510),
    [anon_sym_asm] = ACTIONS(2510),
    [anon_sym___asm__] = ACTIONS(2510),
    [sym_number_literal] = ACTIONS(2512),
    [anon_sym_L_SQUOTE] = ACTIONS(2512),
    [anon_sym_u_SQUOTE] = ACTIONS(2512),
    [anon_sym_U_SQUOTE] = ACTIONS(2512),
    [anon_sym_u8_SQUOTE] = ACTIONS(2512),
    [anon_sym_SQUOTE] = ACTIONS(2512),
    [anon_sym_L_DQUOTE] = ACTIONS(2512),
    [anon_sym_u_DQUOTE] = ACTIONS(2512),
    [anon_sym_U_DQUOTE] = ACTIONS(2512),
    [anon_sym_u8_DQUOTE] = ACTIONS(2512),
    [anon_sym_DQUOTE] = ACTIONS(2512),
    [sym_true] = ACTIONS(2510),
    [sym_false] = ACTIONS(2510),
    [anon_sym_NULL] = ACTIONS(2510),
    [anon_sym_nullptr] = ACTIONS(2510),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2510),
    [anon_sym_decltype] = ACTIONS(2510),
    [sym_virtual] = ACTIONS(2510),
    [anon_sym_explicit] = ACTIONS(2510),
    [anon_sym_typename] = ACTIONS(2510),
    [anon_sym_template] = ACTIONS(2510),
    [anon_sym_operator] = ACTIONS(2510),
    [anon_sym_try] = ACTIONS(2510),
    [anon_sym_delete] = ACTIONS(2510),
    [anon_sym_throw] = ACTIONS(2510),
    [anon_sym_namespace] = ACTIONS(2510),
    [anon_sym_using] = ACTIONS(2510),
    [anon_sym_static_assert] = ACTIONS(2510),
    [anon_sym_concept] = ACTIONS(2510),
    [anon_sym_co_return] = ACTIONS(2510),
    [anon_sym_co_yield] = ACTIONS(2510),
    [anon_sym_R_DQUOTE] = ACTIONS(2512),
    [anon_sym_LR_DQUOTE] = ACTIONS(2512),
    [anon_sym_uR_DQUOTE] = ACTIONS(2512),
    [anon_sym_UR_DQUOTE] = ACTIONS(2512),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2512),
    [anon_sym_co_await] = ACTIONS(2510),
    [anon_sym_new] = ACTIONS(2510),
    [anon_sym_requires] = ACTIONS(2510),
    [sym_this] = ACTIONS(2510),
    [anon_sym_discard] = ACTIONS(2510),
    [anon_sym_precise] = ACTIONS(2510),
    [anon_sym_shared] = ACTIONS(2510),
    [anon_sym_groupshared] = ACTIONS(2510),
    [anon_sym_uniform] = ACTIONS(2510),
    [anon_sym_row_major] = ACTIONS(2510),
    [anon_sym_column_major] = ACTIONS(2510),
    [anon_sym_globallycoherent] = ACTIONS(2510),
    [anon_sym_centroid] = ACTIONS(2510),
    [anon_sym_noperspective] = ACTIONS(2510),
    [anon_sym_nointerpolation] = ACTIONS(2510),
    [anon_sym_sample] = ACTIONS(2510),
    [anon_sym_linear] = ACTIONS(2510),
    [anon_sym_snorm] = ACTIONS(2510),
    [anon_sym_unorm] = ACTIONS(2510),
    [anon_sym_point] = ACTIONS(2510),
    [anon_sym_line] = ACTIONS(2510),
    [anon_sym_triangleadj] = ACTIONS(2510),
    [anon_sym_lineadj] = ACTIONS(2510),
    [anon_sym_triangle] = ACTIONS(2510),
    [anon_sym_cbuffer] = ACTIONS(2510),
  },
  [326] = {
    [sym_catch_clause] = STATE(276),
    [aux_sym_constructor_try_statement_repeat1] = STATE(276),
    [ts_builtin_sym_end] = ACTIONS(1965),
    [sym_identifier] = ACTIONS(1963),
    [aux_sym_preproc_include_token1] = ACTIONS(1963),
    [aux_sym_preproc_def_token1] = ACTIONS(1963),
    [aux_sym_preproc_if_token1] = ACTIONS(1963),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1963),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1963),
    [sym_preproc_directive] = ACTIONS(1963),
    [anon_sym_LPAREN2] = ACTIONS(1965),
    [anon_sym_BANG] = ACTIONS(1965),
    [anon_sym_TILDE] = ACTIONS(1965),
    [anon_sym_DASH] = ACTIONS(1963),
    [anon_sym_PLUS] = ACTIONS(1963),
    [anon_sym_STAR] = ACTIONS(1965),
    [anon_sym_AMP_AMP] = ACTIONS(1965),
    [anon_sym_AMP] = ACTIONS(1963),
    [anon_sym_SEMI] = ACTIONS(1965),
    [anon_sym___extension__] = ACTIONS(1963),
    [anon_sym_typedef] = ACTIONS(1963),
    [anon_sym_in] = ACTIONS(1963),
    [anon_sym_out] = ACTIONS(1963),
    [anon_sym_inout] = ACTIONS(1963),
    [anon_sym_extern] = ACTIONS(1963),
    [anon_sym___attribute__] = ACTIONS(1963),
    [anon_sym_COLON_COLON] = ACTIONS(1965),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1965),
    [anon_sym___declspec] = ACTIONS(1963),
    [anon_sym___based] = ACTIONS(1963),
    [anon_sym___cdecl] = ACTIONS(1963),
    [anon_sym___clrcall] = ACTIONS(1963),
    [anon_sym___stdcall] = ACTIONS(1963),
    [anon_sym___fastcall] = ACTIONS(1963),
    [anon_sym___thiscall] = ACTIONS(1963),
    [anon_sym___vectorcall] = ACTIONS(1963),
    [anon_sym_LBRACE] = ACTIONS(1965),
    [anon_sym_signed] = ACTIONS(1963),
    [anon_sym_unsigned] = ACTIONS(1963),
    [anon_sym_long] = ACTIONS(1963),
    [anon_sym_short] = ACTIONS(1963),
    [anon_sym_LBRACK] = ACTIONS(1963),
    [anon_sym_static] = ACTIONS(1963),
    [anon_sym_register] = ACTIONS(1963),
    [anon_sym_inline] = ACTIONS(1963),
    [anon_sym___inline] = ACTIONS(1963),
    [anon_sym___inline__] = ACTIONS(1963),
    [anon_sym___forceinline] = ACTIONS(1963),
    [anon_sym_thread_local] = ACTIONS(1963),
    [anon_sym___thread] = ACTIONS(1963),
    [anon_sym_const] = ACTIONS(1963),
    [anon_sym_constexpr] = ACTIONS(1963),
    [anon_sym_volatile] = ACTIONS(1963),
    [anon_sym_restrict] = ACTIONS(1963),
    [anon_sym___restrict__] = ACTIONS(1963),
    [anon_sym__Atomic] = ACTIONS(1963),
    [anon_sym__Noreturn] = ACTIONS(1963),
    [anon_sym_noreturn] = ACTIONS(1963),
    [anon_sym_mutable] = ACTIONS(1963),
    [anon_sym_constinit] = ACTIONS(1963),
    [anon_sym_consteval] = ACTIONS(1963),
    [anon_sym_alignas] = ACTIONS(1963),
    [anon_sym__Alignas] = ACTIONS(1963),
    [sym_primitive_type] = ACTIONS(1963),
    [anon_sym_enum] = ACTIONS(1963),
    [anon_sym_class] = ACTIONS(1963),
    [anon_sym_struct] = ACTIONS(1963),
    [anon_sym_union] = ACTIONS(1963),
    [anon_sym_if] = ACTIONS(1963),
    [anon_sym_else] = ACTIONS(1963),
    [anon_sym_switch] = ACTIONS(1963),
    [anon_sym_case] = ACTIONS(1963),
    [anon_sym_default] = ACTIONS(1963),
    [anon_sym_while] = ACTIONS(1963),
    [anon_sym_do] = ACTIONS(1963),
    [anon_sym_for] = ACTIONS(1963),
    [anon_sym_return] = ACTIONS(1963),
    [anon_sym_break] = ACTIONS(1963),
    [anon_sym_continue] = ACTIONS(1963),
    [anon_sym_goto] = ACTIONS(1963),
    [anon_sym___try] = ACTIONS(1963),
    [anon_sym___leave] = ACTIONS(1963),
    [anon_sym_not] = ACTIONS(1963),
    [anon_sym_compl] = ACTIONS(1963),
    [anon_sym_DASH_DASH] = ACTIONS(1965),
    [anon_sym_PLUS_PLUS] = ACTIONS(1965),
    [anon_sym_sizeof] = ACTIONS(1963),
    [anon_sym___alignof__] = ACTIONS(1963),
    [anon_sym___alignof] = ACTIONS(1963),
    [anon_sym__alignof] = ACTIONS(1963),
    [anon_sym_alignof] = ACTIONS(1963),
    [anon_sym__Alignof] = ACTIONS(1963),
    [anon_sym_offsetof] = ACTIONS(1963),
    [anon_sym__Generic] = ACTIONS(1963),
    [anon_sym_asm] = ACTIONS(1963),
    [anon_sym___asm__] = ACTIONS(1963),
    [sym_number_literal] = ACTIONS(1965),
    [anon_sym_L_SQUOTE] = ACTIONS(1965),
    [anon_sym_u_SQUOTE] = ACTIONS(1965),
    [anon_sym_U_SQUOTE] = ACTIONS(1965),
    [anon_sym_u8_SQUOTE] = ACTIONS(1965),
    [anon_sym_SQUOTE] = ACTIONS(1965),
    [anon_sym_L_DQUOTE] = ACTIONS(1965),
    [anon_sym_u_DQUOTE] = ACTIONS(1965),
    [anon_sym_U_DQUOTE] = ACTIONS(1965),
    [anon_sym_u8_DQUOTE] = ACTIONS(1965),
    [anon_sym_DQUOTE] = ACTIONS(1965),
    [sym_true] = ACTIONS(1963),
    [sym_false] = ACTIONS(1963),
    [anon_sym_NULL] = ACTIONS(1963),
    [anon_sym_nullptr] = ACTIONS(1963),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1963),
    [anon_sym_decltype] = ACTIONS(1963),
    [sym_virtual] = ACTIONS(1963),
    [anon_sym_explicit] = ACTIONS(1963),
    [anon_sym_typename] = ACTIONS(1963),
    [anon_sym_template] = ACTIONS(1963),
    [anon_sym_operator] = ACTIONS(1963),
    [anon_sym_try] = ACTIONS(1963),
    [anon_sym_delete] = ACTIONS(1963),
    [anon_sym_throw] = ACTIONS(1963),
    [anon_sym_namespace] = ACTIONS(1963),
    [anon_sym_using] = ACTIONS(1963),
    [anon_sym_static_assert] = ACTIONS(1963),
    [anon_sym_concept] = ACTIONS(1963),
    [anon_sym_co_return] = ACTIONS(1963),
    [anon_sym_co_yield] = ACTIONS(1963),
    [anon_sym_catch] = ACTIONS(2514),
    [anon_sym_R_DQUOTE] = ACTIONS(1965),
    [anon_sym_LR_DQUOTE] = ACTIONS(1965),
    [anon_sym_uR_DQUOTE] = ACTIONS(1965),
    [anon_sym_UR_DQUOTE] = ACTIONS(1965),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1965),
    [anon_sym_co_await] = ACTIONS(1963),
    [anon_sym_new] = ACTIONS(1963),
    [anon_sym_requires] = ACTIONS(1963),
    [sym_this] = ACTIONS(1963),
    [anon_sym_discard] = ACTIONS(1963),
    [anon_sym_precise] = ACTIONS(1963),
    [anon_sym_shared] = ACTIONS(1963),
    [anon_sym_groupshared] = ACTIONS(1963),
    [anon_sym_uniform] = ACTIONS(1963),
    [anon_sym_row_major] = ACTIONS(1963),
    [anon_sym_column_major] = ACTIONS(1963),
    [anon_sym_globallycoherent] = ACTIONS(1963),
    [anon_sym_centroid] = ACTIONS(1963),
    [anon_sym_noperspective] = ACTIONS(1963),
    [anon_sym_nointerpolation] = ACTIONS(1963),
    [anon_sym_sample] = ACTIONS(1963),
    [anon_sym_linear] = ACTIONS(1963),
    [anon_sym_snorm] = ACTIONS(1963),
    [anon_sym_unorm] = ACTIONS(1963),
    [anon_sym_point] = ACTIONS(1963),
    [anon_sym_line] = ACTIONS(1963),
    [anon_sym_triangleadj] = ACTIONS(1963),
    [anon_sym_lineadj] = ACTIONS(1963),
    [anon_sym_triangle] = ACTIONS(1963),
    [anon_sym_cbuffer] = ACTIONS(1963),
  },
  [327] = {
    [sym_identifier] = ACTIONS(1953),
    [aux_sym_preproc_include_token1] = ACTIONS(1953),
    [aux_sym_preproc_def_token1] = ACTIONS(1953),
    [aux_sym_preproc_if_token1] = ACTIONS(1953),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1953),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1953),
    [sym_preproc_directive] = ACTIONS(1953),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_BANG] = ACTIONS(1955),
    [anon_sym_TILDE] = ACTIONS(1955),
    [anon_sym_DASH] = ACTIONS(1953),
    [anon_sym_PLUS] = ACTIONS(1953),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym_COLON] = ACTIONS(1953),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym_typedef] = ACTIONS(1953),
    [anon_sym_in] = ACTIONS(1953),
    [anon_sym_out] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1953),
    [anon_sym_extern] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1955),
    [anon_sym___declspec] = ACTIONS(1953),
    [anon_sym___based] = ACTIONS(1953),
    [anon_sym___cdecl] = ACTIONS(1953),
    [anon_sym___clrcall] = ACTIONS(1953),
    [anon_sym___stdcall] = ACTIONS(1953),
    [anon_sym___fastcall] = ACTIONS(1953),
    [anon_sym___thiscall] = ACTIONS(1953),
    [anon_sym___vectorcall] = ACTIONS(1953),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_RBRACE] = ACTIONS(1955),
    [anon_sym_signed] = ACTIONS(1953),
    [anon_sym_unsigned] = ACTIONS(1953),
    [anon_sym_long] = ACTIONS(1953),
    [anon_sym_short] = ACTIONS(1953),
    [anon_sym_LBRACK] = ACTIONS(1953),
    [anon_sym_static] = ACTIONS(1953),
    [anon_sym_register] = ACTIONS(1953),
    [anon_sym_inline] = ACTIONS(1953),
    [anon_sym___inline] = ACTIONS(1953),
    [anon_sym___inline__] = ACTIONS(1953),
    [anon_sym___forceinline] = ACTIONS(1953),
    [anon_sym_thread_local] = ACTIONS(1953),
    [anon_sym___thread] = ACTIONS(1953),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [sym_primitive_type] = ACTIONS(1953),
    [anon_sym_enum] = ACTIONS(1953),
    [anon_sym_class] = ACTIONS(1953),
    [anon_sym_struct] = ACTIONS(1953),
    [anon_sym_union] = ACTIONS(1953),
    [anon_sym_if] = ACTIONS(1953),
    [anon_sym_else] = ACTIONS(1953),
    [anon_sym_switch] = ACTIONS(1953),
    [anon_sym_case] = ACTIONS(1953),
    [anon_sym_default] = ACTIONS(1953),
    [anon_sym_while] = ACTIONS(1953),
    [anon_sym_do] = ACTIONS(1953),
    [anon_sym_for] = ACTIONS(1953),
    [anon_sym_return] = ACTIONS(1953),
    [anon_sym_break] = ACTIONS(1953),
    [anon_sym_continue] = ACTIONS(1953),
    [anon_sym_goto] = ACTIONS(1953),
    [anon_sym___try] = ACTIONS(1953),
    [anon_sym___leave] = ACTIONS(1953),
    [anon_sym_not] = ACTIONS(1953),
    [anon_sym_compl] = ACTIONS(1953),
    [anon_sym_DASH_DASH] = ACTIONS(1955),
    [anon_sym_PLUS_PLUS] = ACTIONS(1955),
    [anon_sym_sizeof] = ACTIONS(1953),
    [anon_sym___alignof__] = ACTIONS(1953),
    [anon_sym___alignof] = ACTIONS(1953),
    [anon_sym__alignof] = ACTIONS(1953),
    [anon_sym_alignof] = ACTIONS(1953),
    [anon_sym__Alignof] = ACTIONS(1953),
    [anon_sym_offsetof] = ACTIONS(1953),
    [anon_sym__Generic] = ACTIONS(1953),
    [anon_sym_asm] = ACTIONS(1953),
    [anon_sym___asm__] = ACTIONS(1953),
    [sym_number_literal] = ACTIONS(1955),
    [anon_sym_L_SQUOTE] = ACTIONS(1955),
    [anon_sym_u_SQUOTE] = ACTIONS(1955),
    [anon_sym_U_SQUOTE] = ACTIONS(1955),
    [anon_sym_u8_SQUOTE] = ACTIONS(1955),
    [anon_sym_SQUOTE] = ACTIONS(1955),
    [anon_sym_L_DQUOTE] = ACTIONS(1955),
    [anon_sym_u_DQUOTE] = ACTIONS(1955),
    [anon_sym_U_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8_DQUOTE] = ACTIONS(1955),
    [anon_sym_DQUOTE] = ACTIONS(1955),
    [sym_true] = ACTIONS(1953),
    [sym_false] = ACTIONS(1953),
    [anon_sym_NULL] = ACTIONS(1953),
    [anon_sym_nullptr] = ACTIONS(1953),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
    [sym_virtual] = ACTIONS(1953),
    [anon_sym_explicit] = ACTIONS(1953),
    [anon_sym_typename] = ACTIONS(1953),
    [anon_sym_template] = ACTIONS(1953),
    [anon_sym_operator] = ACTIONS(1953),
    [anon_sym_try] = ACTIONS(1953),
    [anon_sym_delete] = ACTIONS(1953),
    [anon_sym_throw] = ACTIONS(1953),
    [anon_sym_namespace] = ACTIONS(1953),
    [anon_sym_using] = ACTIONS(1953),
    [anon_sym_static_assert] = ACTIONS(1953),
    [anon_sym_concept] = ACTIONS(1953),
    [anon_sym_co_return] = ACTIONS(1953),
    [anon_sym_co_yield] = ACTIONS(1953),
    [anon_sym_R_DQUOTE] = ACTIONS(1955),
    [anon_sym_LR_DQUOTE] = ACTIONS(1955),
    [anon_sym_uR_DQUOTE] = ACTIONS(1955),
    [anon_sym_UR_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1955),
    [anon_sym_co_await] = ACTIONS(1953),
    [anon_sym_new] = ACTIONS(1953),
    [anon_sym_requires] = ACTIONS(1953),
    [sym_this] = ACTIONS(1953),
    [anon_sym_discard] = ACTIONS(1953),
    [anon_sym_precise] = ACTIONS(1953),
    [anon_sym_shared] = ACTIONS(1953),
    [anon_sym_groupshared] = ACTIONS(1953),
    [anon_sym_uniform] = ACTIONS(1953),
    [anon_sym_row_major] = ACTIONS(1953),
    [anon_sym_column_major] = ACTIONS(1953),
    [anon_sym_globallycoherent] = ACTIONS(1953),
    [anon_sym_centroid] = ACTIONS(1953),
    [anon_sym_noperspective] = ACTIONS(1953),
    [anon_sym_nointerpolation] = ACTIONS(1953),
    [anon_sym_sample] = ACTIONS(1953),
    [anon_sym_linear] = ACTIONS(1953),
    [anon_sym_snorm] = ACTIONS(1953),
    [anon_sym_unorm] = ACTIONS(1953),
    [anon_sym_point] = ACTIONS(1953),
    [anon_sym_line] = ACTIONS(1953),
    [anon_sym_triangleadj] = ACTIONS(1953),
    [anon_sym_lineadj] = ACTIONS(1953),
    [anon_sym_triangle] = ACTIONS(1953),
    [anon_sym_cbuffer] = ACTIONS(1953),
  },
  [328] = {
    [sym_identifier] = ACTIONS(2516),
    [aux_sym_preproc_include_token1] = ACTIONS(2516),
    [aux_sym_preproc_def_token1] = ACTIONS(2516),
    [aux_sym_preproc_if_token1] = ACTIONS(2516),
    [aux_sym_preproc_if_token2] = ACTIONS(2516),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2516),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2516),
    [aux_sym_preproc_else_token1] = ACTIONS(2516),
    [aux_sym_preproc_elif_token1] = ACTIONS(2516),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2516),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2516),
    [sym_preproc_directive] = ACTIONS(2516),
    [anon_sym_LPAREN2] = ACTIONS(2518),
    [anon_sym_BANG] = ACTIONS(2518),
    [anon_sym_TILDE] = ACTIONS(2518),
    [anon_sym_DASH] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(2516),
    [anon_sym_STAR] = ACTIONS(2518),
    [anon_sym_AMP_AMP] = ACTIONS(2518),
    [anon_sym_AMP] = ACTIONS(2516),
    [anon_sym_SEMI] = ACTIONS(2518),
    [anon_sym___extension__] = ACTIONS(2516),
    [anon_sym_typedef] = ACTIONS(2516),
    [anon_sym_in] = ACTIONS(2516),
    [anon_sym_out] = ACTIONS(2516),
    [anon_sym_inout] = ACTIONS(2516),
    [anon_sym_extern] = ACTIONS(2516),
    [anon_sym___attribute__] = ACTIONS(2516),
    [anon_sym_COLON_COLON] = ACTIONS(2518),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2518),
    [anon_sym___declspec] = ACTIONS(2516),
    [anon_sym___based] = ACTIONS(2516),
    [anon_sym___cdecl] = ACTIONS(2516),
    [anon_sym___clrcall] = ACTIONS(2516),
    [anon_sym___stdcall] = ACTIONS(2516),
    [anon_sym___fastcall] = ACTIONS(2516),
    [anon_sym___thiscall] = ACTIONS(2516),
    [anon_sym___vectorcall] = ACTIONS(2516),
    [anon_sym_LBRACE] = ACTIONS(2518),
    [anon_sym_signed] = ACTIONS(2516),
    [anon_sym_unsigned] = ACTIONS(2516),
    [anon_sym_long] = ACTIONS(2516),
    [anon_sym_short] = ACTIONS(2516),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_static] = ACTIONS(2516),
    [anon_sym_register] = ACTIONS(2516),
    [anon_sym_inline] = ACTIONS(2516),
    [anon_sym___inline] = ACTIONS(2516),
    [anon_sym___inline__] = ACTIONS(2516),
    [anon_sym___forceinline] = ACTIONS(2516),
    [anon_sym_thread_local] = ACTIONS(2516),
    [anon_sym___thread] = ACTIONS(2516),
    [anon_sym_const] = ACTIONS(2516),
    [anon_sym_constexpr] = ACTIONS(2516),
    [anon_sym_volatile] = ACTIONS(2516),
    [anon_sym_restrict] = ACTIONS(2516),
    [anon_sym___restrict__] = ACTIONS(2516),
    [anon_sym__Atomic] = ACTIONS(2516),
    [anon_sym__Noreturn] = ACTIONS(2516),
    [anon_sym_noreturn] = ACTIONS(2516),
    [anon_sym_mutable] = ACTIONS(2516),
    [anon_sym_constinit] = ACTIONS(2516),
    [anon_sym_consteval] = ACTIONS(2516),
    [anon_sym_alignas] = ACTIONS(2516),
    [anon_sym__Alignas] = ACTIONS(2516),
    [sym_primitive_type] = ACTIONS(2516),
    [anon_sym_enum] = ACTIONS(2516),
    [anon_sym_class] = ACTIONS(2516),
    [anon_sym_struct] = ACTIONS(2516),
    [anon_sym_union] = ACTIONS(2516),
    [anon_sym_if] = ACTIONS(2516),
    [anon_sym_switch] = ACTIONS(2516),
    [anon_sym_case] = ACTIONS(2516),
    [anon_sym_default] = ACTIONS(2516),
    [anon_sym_while] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(2516),
    [anon_sym_for] = ACTIONS(2516),
    [anon_sym_return] = ACTIONS(2516),
    [anon_sym_break] = ACTIONS(2516),
    [anon_sym_continue] = ACTIONS(2516),
    [anon_sym_goto] = ACTIONS(2516),
    [anon_sym___try] = ACTIONS(2516),
    [anon_sym___leave] = ACTIONS(2516),
    [anon_sym_not] = ACTIONS(2516),
    [anon_sym_compl] = ACTIONS(2516),
    [anon_sym_DASH_DASH] = ACTIONS(2518),
    [anon_sym_PLUS_PLUS] = ACTIONS(2518),
    [anon_sym_sizeof] = ACTIONS(2516),
    [anon_sym___alignof__] = ACTIONS(2516),
    [anon_sym___alignof] = ACTIONS(2516),
    [anon_sym__alignof] = ACTIONS(2516),
    [anon_sym_alignof] = ACTIONS(2516),
    [anon_sym__Alignof] = ACTIONS(2516),
    [anon_sym_offsetof] = ACTIONS(2516),
    [anon_sym__Generic] = ACTIONS(2516),
    [anon_sym_asm] = ACTIONS(2516),
    [anon_sym___asm__] = ACTIONS(2516),
    [sym_number_literal] = ACTIONS(2518),
    [anon_sym_L_SQUOTE] = ACTIONS(2518),
    [anon_sym_u_SQUOTE] = ACTIONS(2518),
    [anon_sym_U_SQUOTE] = ACTIONS(2518),
    [anon_sym_u8_SQUOTE] = ACTIONS(2518),
    [anon_sym_SQUOTE] = ACTIONS(2518),
    [anon_sym_L_DQUOTE] = ACTIONS(2518),
    [anon_sym_u_DQUOTE] = ACTIONS(2518),
    [anon_sym_U_DQUOTE] = ACTIONS(2518),
    [anon_sym_u8_DQUOTE] = ACTIONS(2518),
    [anon_sym_DQUOTE] = ACTIONS(2518),
    [sym_true] = ACTIONS(2516),
    [sym_false] = ACTIONS(2516),
    [anon_sym_NULL] = ACTIONS(2516),
    [anon_sym_nullptr] = ACTIONS(2516),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2516),
    [anon_sym_decltype] = ACTIONS(2516),
    [sym_virtual] = ACTIONS(2516),
    [anon_sym_explicit] = ACTIONS(2516),
    [anon_sym_typename] = ACTIONS(2516),
    [anon_sym_template] = ACTIONS(2516),
    [anon_sym_operator] = ACTIONS(2516),
    [anon_sym_try] = ACTIONS(2516),
    [anon_sym_delete] = ACTIONS(2516),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_namespace] = ACTIONS(2516),
    [anon_sym_using] = ACTIONS(2516),
    [anon_sym_static_assert] = ACTIONS(2516),
    [anon_sym_concept] = ACTIONS(2516),
    [anon_sym_co_return] = ACTIONS(2516),
    [anon_sym_co_yield] = ACTIONS(2516),
    [anon_sym_R_DQUOTE] = ACTIONS(2518),
    [anon_sym_LR_DQUOTE] = ACTIONS(2518),
    [anon_sym_uR_DQUOTE] = ACTIONS(2518),
    [anon_sym_UR_DQUOTE] = ACTIONS(2518),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2518),
    [anon_sym_co_await] = ACTIONS(2516),
    [anon_sym_new] = ACTIONS(2516),
    [anon_sym_requires] = ACTIONS(2516),
    [sym_this] = ACTIONS(2516),
    [anon_sym_discard] = ACTIONS(2516),
    [anon_sym_precise] = ACTIONS(2516),
    [anon_sym_shared] = ACTIONS(2516),
    [anon_sym_groupshared] = ACTIONS(2516),
    [anon_sym_uniform] = ACTIONS(2516),
    [anon_sym_row_major] = ACTIONS(2516),
    [anon_sym_column_major] = ACTIONS(2516),
    [anon_sym_globallycoherent] = ACTIONS(2516),
    [anon_sym_centroid] = ACTIONS(2516),
    [anon_sym_noperspective] = ACTIONS(2516),
    [anon_sym_nointerpolation] = ACTIONS(2516),
    [anon_sym_sample] = ACTIONS(2516),
    [anon_sym_linear] = ACTIONS(2516),
    [anon_sym_snorm] = ACTIONS(2516),
    [anon_sym_unorm] = ACTIONS(2516),
    [anon_sym_point] = ACTIONS(2516),
    [anon_sym_line] = ACTIONS(2516),
    [anon_sym_triangleadj] = ACTIONS(2516),
    [anon_sym_lineadj] = ACTIONS(2516),
    [anon_sym_triangle] = ACTIONS(2516),
    [anon_sym_cbuffer] = ACTIONS(2516),
  },
  [329] = {
    [sym_identifier] = ACTIONS(2520),
    [aux_sym_preproc_include_token1] = ACTIONS(2520),
    [aux_sym_preproc_def_token1] = ACTIONS(2520),
    [aux_sym_preproc_if_token1] = ACTIONS(2520),
    [aux_sym_preproc_if_token2] = ACTIONS(2520),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2520),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2520),
    [aux_sym_preproc_else_token1] = ACTIONS(2520),
    [aux_sym_preproc_elif_token1] = ACTIONS(2520),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2520),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2520),
    [sym_preproc_directive] = ACTIONS(2520),
    [anon_sym_LPAREN2] = ACTIONS(2522),
    [anon_sym_BANG] = ACTIONS(2522),
    [anon_sym_TILDE] = ACTIONS(2522),
    [anon_sym_DASH] = ACTIONS(2520),
    [anon_sym_PLUS] = ACTIONS(2520),
    [anon_sym_STAR] = ACTIONS(2522),
    [anon_sym_AMP_AMP] = ACTIONS(2522),
    [anon_sym_AMP] = ACTIONS(2520),
    [anon_sym_SEMI] = ACTIONS(2522),
    [anon_sym___extension__] = ACTIONS(2520),
    [anon_sym_typedef] = ACTIONS(2520),
    [anon_sym_in] = ACTIONS(2520),
    [anon_sym_out] = ACTIONS(2520),
    [anon_sym_inout] = ACTIONS(2520),
    [anon_sym_extern] = ACTIONS(2520),
    [anon_sym___attribute__] = ACTIONS(2520),
    [anon_sym_COLON_COLON] = ACTIONS(2522),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2522),
    [anon_sym___declspec] = ACTIONS(2520),
    [anon_sym___based] = ACTIONS(2520),
    [anon_sym___cdecl] = ACTIONS(2520),
    [anon_sym___clrcall] = ACTIONS(2520),
    [anon_sym___stdcall] = ACTIONS(2520),
    [anon_sym___fastcall] = ACTIONS(2520),
    [anon_sym___thiscall] = ACTIONS(2520),
    [anon_sym___vectorcall] = ACTIONS(2520),
    [anon_sym_LBRACE] = ACTIONS(2522),
    [anon_sym_signed] = ACTIONS(2520),
    [anon_sym_unsigned] = ACTIONS(2520),
    [anon_sym_long] = ACTIONS(2520),
    [anon_sym_short] = ACTIONS(2520),
    [anon_sym_LBRACK] = ACTIONS(2520),
    [anon_sym_static] = ACTIONS(2520),
    [anon_sym_register] = ACTIONS(2520),
    [anon_sym_inline] = ACTIONS(2520),
    [anon_sym___inline] = ACTIONS(2520),
    [anon_sym___inline__] = ACTIONS(2520),
    [anon_sym___forceinline] = ACTIONS(2520),
    [anon_sym_thread_local] = ACTIONS(2520),
    [anon_sym___thread] = ACTIONS(2520),
    [anon_sym_const] = ACTIONS(2520),
    [anon_sym_constexpr] = ACTIONS(2520),
    [anon_sym_volatile] = ACTIONS(2520),
    [anon_sym_restrict] = ACTIONS(2520),
    [anon_sym___restrict__] = ACTIONS(2520),
    [anon_sym__Atomic] = ACTIONS(2520),
    [anon_sym__Noreturn] = ACTIONS(2520),
    [anon_sym_noreturn] = ACTIONS(2520),
    [anon_sym_mutable] = ACTIONS(2520),
    [anon_sym_constinit] = ACTIONS(2520),
    [anon_sym_consteval] = ACTIONS(2520),
    [anon_sym_alignas] = ACTIONS(2520),
    [anon_sym__Alignas] = ACTIONS(2520),
    [sym_primitive_type] = ACTIONS(2520),
    [anon_sym_enum] = ACTIONS(2520),
    [anon_sym_class] = ACTIONS(2520),
    [anon_sym_struct] = ACTIONS(2520),
    [anon_sym_union] = ACTIONS(2520),
    [anon_sym_if] = ACTIONS(2520),
    [anon_sym_switch] = ACTIONS(2520),
    [anon_sym_case] = ACTIONS(2520),
    [anon_sym_default] = ACTIONS(2520),
    [anon_sym_while] = ACTIONS(2520),
    [anon_sym_do] = ACTIONS(2520),
    [anon_sym_for] = ACTIONS(2520),
    [anon_sym_return] = ACTIONS(2520),
    [anon_sym_break] = ACTIONS(2520),
    [anon_sym_continue] = ACTIONS(2520),
    [anon_sym_goto] = ACTIONS(2520),
    [anon_sym___try] = ACTIONS(2520),
    [anon_sym___leave] = ACTIONS(2520),
    [anon_sym_not] = ACTIONS(2520),
    [anon_sym_compl] = ACTIONS(2520),
    [anon_sym_DASH_DASH] = ACTIONS(2522),
    [anon_sym_PLUS_PLUS] = ACTIONS(2522),
    [anon_sym_sizeof] = ACTIONS(2520),
    [anon_sym___alignof__] = ACTIONS(2520),
    [anon_sym___alignof] = ACTIONS(2520),
    [anon_sym__alignof] = ACTIONS(2520),
    [anon_sym_alignof] = ACTIONS(2520),
    [anon_sym__Alignof] = ACTIONS(2520),
    [anon_sym_offsetof] = ACTIONS(2520),
    [anon_sym__Generic] = ACTIONS(2520),
    [anon_sym_asm] = ACTIONS(2520),
    [anon_sym___asm__] = ACTIONS(2520),
    [sym_number_literal] = ACTIONS(2522),
    [anon_sym_L_SQUOTE] = ACTIONS(2522),
    [anon_sym_u_SQUOTE] = ACTIONS(2522),
    [anon_sym_U_SQUOTE] = ACTIONS(2522),
    [anon_sym_u8_SQUOTE] = ACTIONS(2522),
    [anon_sym_SQUOTE] = ACTIONS(2522),
    [anon_sym_L_DQUOTE] = ACTIONS(2522),
    [anon_sym_u_DQUOTE] = ACTIONS(2522),
    [anon_sym_U_DQUOTE] = ACTIONS(2522),
    [anon_sym_u8_DQUOTE] = ACTIONS(2522),
    [anon_sym_DQUOTE] = ACTIONS(2522),
    [sym_true] = ACTIONS(2520),
    [sym_false] = ACTIONS(2520),
    [anon_sym_NULL] = ACTIONS(2520),
    [anon_sym_nullptr] = ACTIONS(2520),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2520),
    [anon_sym_decltype] = ACTIONS(2520),
    [sym_virtual] = ACTIONS(2520),
    [anon_sym_explicit] = ACTIONS(2520),
    [anon_sym_typename] = ACTIONS(2520),
    [anon_sym_template] = ACTIONS(2520),
    [anon_sym_operator] = ACTIONS(2520),
    [anon_sym_try] = ACTIONS(2520),
    [anon_sym_delete] = ACTIONS(2520),
    [anon_sym_throw] = ACTIONS(2520),
    [anon_sym_namespace] = ACTIONS(2520),
    [anon_sym_using] = ACTIONS(2520),
    [anon_sym_static_assert] = ACTIONS(2520),
    [anon_sym_concept] = ACTIONS(2520),
    [anon_sym_co_return] = ACTIONS(2520),
    [anon_sym_co_yield] = ACTIONS(2520),
    [anon_sym_R_DQUOTE] = ACTIONS(2522),
    [anon_sym_LR_DQUOTE] = ACTIONS(2522),
    [anon_sym_uR_DQUOTE] = ACTIONS(2522),
    [anon_sym_UR_DQUOTE] = ACTIONS(2522),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2522),
    [anon_sym_co_await] = ACTIONS(2520),
    [anon_sym_new] = ACTIONS(2520),
    [anon_sym_requires] = ACTIONS(2520),
    [sym_this] = ACTIONS(2520),
    [anon_sym_discard] = ACTIONS(2520),
    [anon_sym_precise] = ACTIONS(2520),
    [anon_sym_shared] = ACTIONS(2520),
    [anon_sym_groupshared] = ACTIONS(2520),
    [anon_sym_uniform] = ACTIONS(2520),
    [anon_sym_row_major] = ACTIONS(2520),
    [anon_sym_column_major] = ACTIONS(2520),
    [anon_sym_globallycoherent] = ACTIONS(2520),
    [anon_sym_centroid] = ACTIONS(2520),
    [anon_sym_noperspective] = ACTIONS(2520),
    [anon_sym_nointerpolation] = ACTIONS(2520),
    [anon_sym_sample] = ACTIONS(2520),
    [anon_sym_linear] = ACTIONS(2520),
    [anon_sym_snorm] = ACTIONS(2520),
    [anon_sym_unorm] = ACTIONS(2520),
    [anon_sym_point] = ACTIONS(2520),
    [anon_sym_line] = ACTIONS(2520),
    [anon_sym_triangleadj] = ACTIONS(2520),
    [anon_sym_lineadj] = ACTIONS(2520),
    [anon_sym_triangle] = ACTIONS(2520),
    [anon_sym_cbuffer] = ACTIONS(2520),
  },
  [330] = {
    [sym_identifier] = ACTIONS(1953),
    [aux_sym_preproc_include_token1] = ACTIONS(1953),
    [aux_sym_preproc_def_token1] = ACTIONS(1953),
    [aux_sym_preproc_if_token1] = ACTIONS(1953),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1953),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1953),
    [sym_preproc_directive] = ACTIONS(1953),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_BANG] = ACTIONS(1955),
    [anon_sym_TILDE] = ACTIONS(1955),
    [anon_sym_DASH] = ACTIONS(1953),
    [anon_sym_PLUS] = ACTIONS(1953),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym_COLON] = ACTIONS(1953),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym_typedef] = ACTIONS(1953),
    [anon_sym_in] = ACTIONS(1953),
    [anon_sym_out] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1953),
    [anon_sym_extern] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1955),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1955),
    [anon_sym___declspec] = ACTIONS(1953),
    [anon_sym___based] = ACTIONS(1953),
    [anon_sym___cdecl] = ACTIONS(1953),
    [anon_sym___clrcall] = ACTIONS(1953),
    [anon_sym___stdcall] = ACTIONS(1953),
    [anon_sym___fastcall] = ACTIONS(1953),
    [anon_sym___thiscall] = ACTIONS(1953),
    [anon_sym___vectorcall] = ACTIONS(1953),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_RBRACE] = ACTIONS(1955),
    [anon_sym_signed] = ACTIONS(1953),
    [anon_sym_unsigned] = ACTIONS(1953),
    [anon_sym_long] = ACTIONS(1953),
    [anon_sym_short] = ACTIONS(1953),
    [anon_sym_LBRACK] = ACTIONS(1953),
    [anon_sym_static] = ACTIONS(1953),
    [anon_sym_register] = ACTIONS(1953),
    [anon_sym_inline] = ACTIONS(1953),
    [anon_sym___inline] = ACTIONS(1953),
    [anon_sym___inline__] = ACTIONS(1953),
    [anon_sym___forceinline] = ACTIONS(1953),
    [anon_sym_thread_local] = ACTIONS(1953),
    [anon_sym___thread] = ACTIONS(1953),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [sym_primitive_type] = ACTIONS(1953),
    [anon_sym_enum] = ACTIONS(1953),
    [anon_sym_class] = ACTIONS(1953),
    [anon_sym_struct] = ACTIONS(1953),
    [anon_sym_union] = ACTIONS(1953),
    [anon_sym_if] = ACTIONS(1953),
    [anon_sym_else] = ACTIONS(1953),
    [anon_sym_switch] = ACTIONS(1953),
    [anon_sym_case] = ACTIONS(1953),
    [anon_sym_default] = ACTIONS(1953),
    [anon_sym_while] = ACTIONS(1953),
    [anon_sym_do] = ACTIONS(1953),
    [anon_sym_for] = ACTIONS(1953),
    [anon_sym_return] = ACTIONS(1953),
    [anon_sym_break] = ACTIONS(1953),
    [anon_sym_continue] = ACTIONS(1953),
    [anon_sym_goto] = ACTIONS(1953),
    [anon_sym___try] = ACTIONS(1953),
    [anon_sym___leave] = ACTIONS(1953),
    [anon_sym_not] = ACTIONS(1953),
    [anon_sym_compl] = ACTIONS(1953),
    [anon_sym_DASH_DASH] = ACTIONS(1955),
    [anon_sym_PLUS_PLUS] = ACTIONS(1955),
    [anon_sym_sizeof] = ACTIONS(1953),
    [anon_sym___alignof__] = ACTIONS(1953),
    [anon_sym___alignof] = ACTIONS(1953),
    [anon_sym__alignof] = ACTIONS(1953),
    [anon_sym_alignof] = ACTIONS(1953),
    [anon_sym__Alignof] = ACTIONS(1953),
    [anon_sym_offsetof] = ACTIONS(1953),
    [anon_sym__Generic] = ACTIONS(1953),
    [anon_sym_asm] = ACTIONS(1953),
    [anon_sym___asm__] = ACTIONS(1953),
    [sym_number_literal] = ACTIONS(1955),
    [anon_sym_L_SQUOTE] = ACTIONS(1955),
    [anon_sym_u_SQUOTE] = ACTIONS(1955),
    [anon_sym_U_SQUOTE] = ACTIONS(1955),
    [anon_sym_u8_SQUOTE] = ACTIONS(1955),
    [anon_sym_SQUOTE] = ACTIONS(1955),
    [anon_sym_L_DQUOTE] = ACTIONS(1955),
    [anon_sym_u_DQUOTE] = ACTIONS(1955),
    [anon_sym_U_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8_DQUOTE] = ACTIONS(1955),
    [anon_sym_DQUOTE] = ACTIONS(1955),
    [sym_true] = ACTIONS(1953),
    [sym_false] = ACTIONS(1953),
    [anon_sym_NULL] = ACTIONS(1953),
    [anon_sym_nullptr] = ACTIONS(1953),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
    [sym_virtual] = ACTIONS(1953),
    [anon_sym_explicit] = ACTIONS(1953),
    [anon_sym_typename] = ACTIONS(1953),
    [anon_sym_template] = ACTIONS(1953),
    [anon_sym_operator] = ACTIONS(1953),
    [anon_sym_try] = ACTIONS(1953),
    [anon_sym_delete] = ACTIONS(1953),
    [anon_sym_throw] = ACTIONS(1953),
    [anon_sym_namespace] = ACTIONS(1953),
    [anon_sym_using] = ACTIONS(1953),
    [anon_sym_static_assert] = ACTIONS(1953),
    [anon_sym_concept] = ACTIONS(1953),
    [anon_sym_co_return] = ACTIONS(1953),
    [anon_sym_co_yield] = ACTIONS(1953),
    [anon_sym_R_DQUOTE] = ACTIONS(1955),
    [anon_sym_LR_DQUOTE] = ACTIONS(1955),
    [anon_sym_uR_DQUOTE] = ACTIONS(1955),
    [anon_sym_UR_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1955),
    [anon_sym_co_await] = ACTIONS(1953),
    [anon_sym_new] = ACTIONS(1953),
    [anon_sym_requires] = ACTIONS(1953),
    [sym_this] = ACTIONS(1953),
    [anon_sym_discard] = ACTIONS(1953),
    [anon_sym_precise] = ACTIONS(1953),
    [anon_sym_shared] = ACTIONS(1953),
    [anon_sym_groupshared] = ACTIONS(1953),
    [anon_sym_uniform] = ACTIONS(1953),
    [anon_sym_row_major] = ACTIONS(1953),
    [anon_sym_column_major] = ACTIONS(1953),
    [anon_sym_globallycoherent] = ACTIONS(1953),
    [anon_sym_centroid] = ACTIONS(1953),
    [anon_sym_noperspective] = ACTIONS(1953),
    [anon_sym_nointerpolation] = ACTIONS(1953),
    [anon_sym_sample] = ACTIONS(1953),
    [anon_sym_linear] = ACTIONS(1953),
    [anon_sym_snorm] = ACTIONS(1953),
    [anon_sym_unorm] = ACTIONS(1953),
    [anon_sym_point] = ACTIONS(1953),
    [anon_sym_line] = ACTIONS(1953),
    [anon_sym_triangleadj] = ACTIONS(1953),
    [anon_sym_lineadj] = ACTIONS(1953),
    [anon_sym_triangle] = ACTIONS(1953),
    [anon_sym_cbuffer] = ACTIONS(1953),
  },
  [331] = {
    [sym_identifier] = ACTIONS(1949),
    [aux_sym_preproc_include_token1] = ACTIONS(1949),
    [aux_sym_preproc_def_token1] = ACTIONS(1949),
    [aux_sym_preproc_if_token1] = ACTIONS(1949),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1949),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1949),
    [sym_preproc_directive] = ACTIONS(1949),
    [anon_sym_LPAREN2] = ACTIONS(1951),
    [anon_sym_BANG] = ACTIONS(1951),
    [anon_sym_TILDE] = ACTIONS(1951),
    [anon_sym_DASH] = ACTIONS(1949),
    [anon_sym_PLUS] = ACTIONS(1949),
    [anon_sym_STAR] = ACTIONS(1951),
    [anon_sym_AMP_AMP] = ACTIONS(1951),
    [anon_sym_AMP] = ACTIONS(1949),
    [anon_sym_COLON] = ACTIONS(1949),
    [anon_sym_SEMI] = ACTIONS(1951),
    [anon_sym___extension__] = ACTIONS(1949),
    [anon_sym_typedef] = ACTIONS(1949),
    [anon_sym_in] = ACTIONS(1949),
    [anon_sym_out] = ACTIONS(1949),
    [anon_sym_inout] = ACTIONS(1949),
    [anon_sym_extern] = ACTIONS(1949),
    [anon_sym___attribute__] = ACTIONS(1949),
    [anon_sym_COLON_COLON] = ACTIONS(1951),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1951),
    [anon_sym___declspec] = ACTIONS(1949),
    [anon_sym___based] = ACTIONS(1949),
    [anon_sym___cdecl] = ACTIONS(1949),
    [anon_sym___clrcall] = ACTIONS(1949),
    [anon_sym___stdcall] = ACTIONS(1949),
    [anon_sym___fastcall] = ACTIONS(1949),
    [anon_sym___thiscall] = ACTIONS(1949),
    [anon_sym___vectorcall] = ACTIONS(1949),
    [anon_sym_LBRACE] = ACTIONS(1951),
    [anon_sym_RBRACE] = ACTIONS(1951),
    [anon_sym_signed] = ACTIONS(1949),
    [anon_sym_unsigned] = ACTIONS(1949),
    [anon_sym_long] = ACTIONS(1949),
    [anon_sym_short] = ACTIONS(1949),
    [anon_sym_LBRACK] = ACTIONS(1949),
    [anon_sym_static] = ACTIONS(1949),
    [anon_sym_register] = ACTIONS(1949),
    [anon_sym_inline] = ACTIONS(1949),
    [anon_sym___inline] = ACTIONS(1949),
    [anon_sym___inline__] = ACTIONS(1949),
    [anon_sym___forceinline] = ACTIONS(1949),
    [anon_sym_thread_local] = ACTIONS(1949),
    [anon_sym___thread] = ACTIONS(1949),
    [anon_sym_const] = ACTIONS(1949),
    [anon_sym_constexpr] = ACTIONS(1949),
    [anon_sym_volatile] = ACTIONS(1949),
    [anon_sym_restrict] = ACTIONS(1949),
    [anon_sym___restrict__] = ACTIONS(1949),
    [anon_sym__Atomic] = ACTIONS(1949),
    [anon_sym__Noreturn] = ACTIONS(1949),
    [anon_sym_noreturn] = ACTIONS(1949),
    [anon_sym_mutable] = ACTIONS(1949),
    [anon_sym_constinit] = ACTIONS(1949),
    [anon_sym_consteval] = ACTIONS(1949),
    [anon_sym_alignas] = ACTIONS(1949),
    [anon_sym__Alignas] = ACTIONS(1949),
    [sym_primitive_type] = ACTIONS(1949),
    [anon_sym_enum] = ACTIONS(1949),
    [anon_sym_class] = ACTIONS(1949),
    [anon_sym_struct] = ACTIONS(1949),
    [anon_sym_union] = ACTIONS(1949),
    [anon_sym_if] = ACTIONS(1949),
    [anon_sym_else] = ACTIONS(1949),
    [anon_sym_switch] = ACTIONS(1949),
    [anon_sym_case] = ACTIONS(1949),
    [anon_sym_default] = ACTIONS(1949),
    [anon_sym_while] = ACTIONS(1949),
    [anon_sym_do] = ACTIONS(1949),
    [anon_sym_for] = ACTIONS(1949),
    [anon_sym_return] = ACTIONS(1949),
    [anon_sym_break] = ACTIONS(1949),
    [anon_sym_continue] = ACTIONS(1949),
    [anon_sym_goto] = ACTIONS(1949),
    [anon_sym___try] = ACTIONS(1949),
    [anon_sym___leave] = ACTIONS(1949),
    [anon_sym_not] = ACTIONS(1949),
    [anon_sym_compl] = ACTIONS(1949),
    [anon_sym_DASH_DASH] = ACTIONS(1951),
    [anon_sym_PLUS_PLUS] = ACTIONS(1951),
    [anon_sym_sizeof] = ACTIONS(1949),
    [anon_sym___alignof__] = ACTIONS(1949),
    [anon_sym___alignof] = ACTIONS(1949),
    [anon_sym__alignof] = ACTIONS(1949),
    [anon_sym_alignof] = ACTIONS(1949),
    [anon_sym__Alignof] = ACTIONS(1949),
    [anon_sym_offsetof] = ACTIONS(1949),
    [anon_sym__Generic] = ACTIONS(1949),
    [anon_sym_asm] = ACTIONS(1949),
    [anon_sym___asm__] = ACTIONS(1949),
    [sym_number_literal] = ACTIONS(1951),
    [anon_sym_L_SQUOTE] = ACTIONS(1951),
    [anon_sym_u_SQUOTE] = ACTIONS(1951),
    [anon_sym_U_SQUOTE] = ACTIONS(1951),
    [anon_sym_u8_SQUOTE] = ACTIONS(1951),
    [anon_sym_SQUOTE] = ACTIONS(1951),
    [anon_sym_L_DQUOTE] = ACTIONS(1951),
    [anon_sym_u_DQUOTE] = ACTIONS(1951),
    [anon_sym_U_DQUOTE] = ACTIONS(1951),
    [anon_sym_u8_DQUOTE] = ACTIONS(1951),
    [anon_sym_DQUOTE] = ACTIONS(1951),
    [sym_true] = ACTIONS(1949),
    [sym_false] = ACTIONS(1949),
    [anon_sym_NULL] = ACTIONS(1949),
    [anon_sym_nullptr] = ACTIONS(1949),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1949),
    [anon_sym_decltype] = ACTIONS(1949),
    [anon_sym_final] = ACTIONS(1949),
    [anon_sym_override] = ACTIONS(1949),
    [sym_virtual] = ACTIONS(1949),
    [anon_sym_explicit] = ACTIONS(1949),
    [anon_sym_typename] = ACTIONS(1949),
    [anon_sym_template] = ACTIONS(1949),
    [anon_sym_operator] = ACTIONS(1949),
    [anon_sym_try] = ACTIONS(1949),
    [anon_sym_delete] = ACTIONS(1949),
    [anon_sym_throw] = ACTIONS(1949),
    [anon_sym_namespace] = ACTIONS(1949),
    [anon_sym_using] = ACTIONS(1949),
    [anon_sym_static_assert] = ACTIONS(1949),
    [anon_sym_concept] = ACTIONS(1949),
    [anon_sym_co_return] = ACTIONS(1949),
    [anon_sym_co_yield] = ACTIONS(1949),
    [anon_sym_R_DQUOTE] = ACTIONS(1951),
    [anon_sym_LR_DQUOTE] = ACTIONS(1951),
    [anon_sym_uR_DQUOTE] = ACTIONS(1951),
    [anon_sym_UR_DQUOTE] = ACTIONS(1951),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1951),
    [anon_sym_co_await] = ACTIONS(1949),
    [anon_sym_new] = ACTIONS(1949),
    [anon_sym_requires] = ACTIONS(1949),
    [sym_this] = ACTIONS(1949),
    [anon_sym_discard] = ACTIONS(1949),
    [anon_sym_precise] = ACTIONS(1949),
    [anon_sym_shared] = ACTIONS(1949),
    [anon_sym_groupshared] = ACTIONS(1949),
    [anon_sym_uniform] = ACTIONS(1949),
    [anon_sym_row_major] = ACTIONS(1949),
    [anon_sym_column_major] = ACTIONS(1949),
    [anon_sym_globallycoherent] = ACTIONS(1949),
    [anon_sym_centroid] = ACTIONS(1949),
    [anon_sym_noperspective] = ACTIONS(1949),
    [anon_sym_nointerpolation] = ACTIONS(1949),
    [anon_sym_sample] = ACTIONS(1949),
    [anon_sym_linear] = ACTIONS(1949),
    [anon_sym_snorm] = ACTIONS(1949),
    [anon_sym_unorm] = ACTIONS(1949),
    [anon_sym_point] = ACTIONS(1949),
    [anon_sym_line] = ACTIONS(1949),
    [anon_sym_triangleadj] = ACTIONS(1949),
    [anon_sym_lineadj] = ACTIONS(1949),
    [anon_sym_triangle] = ACTIONS(1949),
    [anon_sym_cbuffer] = ACTIONS(1949),
  },
  [332] = {
    [sym_identifier] = ACTIONS(2524),
    [aux_sym_preproc_include_token1] = ACTIONS(2524),
    [aux_sym_preproc_def_token1] = ACTIONS(2524),
    [aux_sym_preproc_if_token1] = ACTIONS(2524),
    [aux_sym_preproc_if_token2] = ACTIONS(2524),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2524),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2524),
    [aux_sym_preproc_else_token1] = ACTIONS(2524),
    [aux_sym_preproc_elif_token1] = ACTIONS(2524),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2524),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2524),
    [sym_preproc_directive] = ACTIONS(2524),
    [anon_sym_LPAREN2] = ACTIONS(2526),
    [anon_sym_BANG] = ACTIONS(2526),
    [anon_sym_TILDE] = ACTIONS(2526),
    [anon_sym_DASH] = ACTIONS(2524),
    [anon_sym_PLUS] = ACTIONS(2524),
    [anon_sym_STAR] = ACTIONS(2526),
    [anon_sym_AMP_AMP] = ACTIONS(2526),
    [anon_sym_AMP] = ACTIONS(2524),
    [anon_sym_SEMI] = ACTIONS(2526),
    [anon_sym___extension__] = ACTIONS(2524),
    [anon_sym_typedef] = ACTIONS(2524),
    [anon_sym_in] = ACTIONS(2524),
    [anon_sym_out] = ACTIONS(2524),
    [anon_sym_inout] = ACTIONS(2524),
    [anon_sym_extern] = ACTIONS(2524),
    [anon_sym___attribute__] = ACTIONS(2524),
    [anon_sym_COLON_COLON] = ACTIONS(2526),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2526),
    [anon_sym___declspec] = ACTIONS(2524),
    [anon_sym___based] = ACTIONS(2524),
    [anon_sym___cdecl] = ACTIONS(2524),
    [anon_sym___clrcall] = ACTIONS(2524),
    [anon_sym___stdcall] = ACTIONS(2524),
    [anon_sym___fastcall] = ACTIONS(2524),
    [anon_sym___thiscall] = ACTIONS(2524),
    [anon_sym___vectorcall] = ACTIONS(2524),
    [anon_sym_LBRACE] = ACTIONS(2526),
    [anon_sym_signed] = ACTIONS(2524),
    [anon_sym_unsigned] = ACTIONS(2524),
    [anon_sym_long] = ACTIONS(2524),
    [anon_sym_short] = ACTIONS(2524),
    [anon_sym_LBRACK] = ACTIONS(2524),
    [anon_sym_static] = ACTIONS(2524),
    [anon_sym_register] = ACTIONS(2524),
    [anon_sym_inline] = ACTIONS(2524),
    [anon_sym___inline] = ACTIONS(2524),
    [anon_sym___inline__] = ACTIONS(2524),
    [anon_sym___forceinline] = ACTIONS(2524),
    [anon_sym_thread_local] = ACTIONS(2524),
    [anon_sym___thread] = ACTIONS(2524),
    [anon_sym_const] = ACTIONS(2524),
    [anon_sym_constexpr] = ACTIONS(2524),
    [anon_sym_volatile] = ACTIONS(2524),
    [anon_sym_restrict] = ACTIONS(2524),
    [anon_sym___restrict__] = ACTIONS(2524),
    [anon_sym__Atomic] = ACTIONS(2524),
    [anon_sym__Noreturn] = ACTIONS(2524),
    [anon_sym_noreturn] = ACTIONS(2524),
    [anon_sym_mutable] = ACTIONS(2524),
    [anon_sym_constinit] = ACTIONS(2524),
    [anon_sym_consteval] = ACTIONS(2524),
    [anon_sym_alignas] = ACTIONS(2524),
    [anon_sym__Alignas] = ACTIONS(2524),
    [sym_primitive_type] = ACTIONS(2524),
    [anon_sym_enum] = ACTIONS(2524),
    [anon_sym_class] = ACTIONS(2524),
    [anon_sym_struct] = ACTIONS(2524),
    [anon_sym_union] = ACTIONS(2524),
    [anon_sym_if] = ACTIONS(2524),
    [anon_sym_switch] = ACTIONS(2524),
    [anon_sym_case] = ACTIONS(2524),
    [anon_sym_default] = ACTIONS(2524),
    [anon_sym_while] = ACTIONS(2524),
    [anon_sym_do] = ACTIONS(2524),
    [anon_sym_for] = ACTIONS(2524),
    [anon_sym_return] = ACTIONS(2524),
    [anon_sym_break] = ACTIONS(2524),
    [anon_sym_continue] = ACTIONS(2524),
    [anon_sym_goto] = ACTIONS(2524),
    [anon_sym___try] = ACTIONS(2524),
    [anon_sym___leave] = ACTIONS(2524),
    [anon_sym_not] = ACTIONS(2524),
    [anon_sym_compl] = ACTIONS(2524),
    [anon_sym_DASH_DASH] = ACTIONS(2526),
    [anon_sym_PLUS_PLUS] = ACTIONS(2526),
    [anon_sym_sizeof] = ACTIONS(2524),
    [anon_sym___alignof__] = ACTIONS(2524),
    [anon_sym___alignof] = ACTIONS(2524),
    [anon_sym__alignof] = ACTIONS(2524),
    [anon_sym_alignof] = ACTIONS(2524),
    [anon_sym__Alignof] = ACTIONS(2524),
    [anon_sym_offsetof] = ACTIONS(2524),
    [anon_sym__Generic] = ACTIONS(2524),
    [anon_sym_asm] = ACTIONS(2524),
    [anon_sym___asm__] = ACTIONS(2524),
    [sym_number_literal] = ACTIONS(2526),
    [anon_sym_L_SQUOTE] = ACTIONS(2526),
    [anon_sym_u_SQUOTE] = ACTIONS(2526),
    [anon_sym_U_SQUOTE] = ACTIONS(2526),
    [anon_sym_u8_SQUOTE] = ACTIONS(2526),
    [anon_sym_SQUOTE] = ACTIONS(2526),
    [anon_sym_L_DQUOTE] = ACTIONS(2526),
    [anon_sym_u_DQUOTE] = ACTIONS(2526),
    [anon_sym_U_DQUOTE] = ACTIONS(2526),
    [anon_sym_u8_DQUOTE] = ACTIONS(2526),
    [anon_sym_DQUOTE] = ACTIONS(2526),
    [sym_true] = ACTIONS(2524),
    [sym_false] = ACTIONS(2524),
    [anon_sym_NULL] = ACTIONS(2524),
    [anon_sym_nullptr] = ACTIONS(2524),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2524),
    [anon_sym_decltype] = ACTIONS(2524),
    [sym_virtual] = ACTIONS(2524),
    [anon_sym_explicit] = ACTIONS(2524),
    [anon_sym_typename] = ACTIONS(2524),
    [anon_sym_template] = ACTIONS(2524),
    [anon_sym_operator] = ACTIONS(2524),
    [anon_sym_try] = ACTIONS(2524),
    [anon_sym_delete] = ACTIONS(2524),
    [anon_sym_throw] = ACTIONS(2524),
    [anon_sym_namespace] = ACTIONS(2524),
    [anon_sym_using] = ACTIONS(2524),
    [anon_sym_static_assert] = ACTIONS(2524),
    [anon_sym_concept] = ACTIONS(2524),
    [anon_sym_co_return] = ACTIONS(2524),
    [anon_sym_co_yield] = ACTIONS(2524),
    [anon_sym_R_DQUOTE] = ACTIONS(2526),
    [anon_sym_LR_DQUOTE] = ACTIONS(2526),
    [anon_sym_uR_DQUOTE] = ACTIONS(2526),
    [anon_sym_UR_DQUOTE] = ACTIONS(2526),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2526),
    [anon_sym_co_await] = ACTIONS(2524),
    [anon_sym_new] = ACTIONS(2524),
    [anon_sym_requires] = ACTIONS(2524),
    [sym_this] = ACTIONS(2524),
    [anon_sym_discard] = ACTIONS(2524),
    [anon_sym_precise] = ACTIONS(2524),
    [anon_sym_shared] = ACTIONS(2524),
    [anon_sym_groupshared] = ACTIONS(2524),
    [anon_sym_uniform] = ACTIONS(2524),
    [anon_sym_row_major] = ACTIONS(2524),
    [anon_sym_column_major] = ACTIONS(2524),
    [anon_sym_globallycoherent] = ACTIONS(2524),
    [anon_sym_centroid] = ACTIONS(2524),
    [anon_sym_noperspective] = ACTIONS(2524),
    [anon_sym_nointerpolation] = ACTIONS(2524),
    [anon_sym_sample] = ACTIONS(2524),
    [anon_sym_linear] = ACTIONS(2524),
    [anon_sym_snorm] = ACTIONS(2524),
    [anon_sym_unorm] = ACTIONS(2524),
    [anon_sym_point] = ACTIONS(2524),
    [anon_sym_line] = ACTIONS(2524),
    [anon_sym_triangleadj] = ACTIONS(2524),
    [anon_sym_lineadj] = ACTIONS(2524),
    [anon_sym_triangle] = ACTIONS(2524),
    [anon_sym_cbuffer] = ACTIONS(2524),
  },
  [333] = {
    [sym_identifier] = ACTIONS(2528),
    [aux_sym_preproc_include_token1] = ACTIONS(2528),
    [aux_sym_preproc_def_token1] = ACTIONS(2528),
    [aux_sym_preproc_if_token1] = ACTIONS(2528),
    [aux_sym_preproc_if_token2] = ACTIONS(2528),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2528),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2528),
    [aux_sym_preproc_else_token1] = ACTIONS(2528),
    [aux_sym_preproc_elif_token1] = ACTIONS(2528),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2528),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2528),
    [sym_preproc_directive] = ACTIONS(2528),
    [anon_sym_LPAREN2] = ACTIONS(2530),
    [anon_sym_BANG] = ACTIONS(2530),
    [anon_sym_TILDE] = ACTIONS(2530),
    [anon_sym_DASH] = ACTIONS(2528),
    [anon_sym_PLUS] = ACTIONS(2528),
    [anon_sym_STAR] = ACTIONS(2530),
    [anon_sym_AMP_AMP] = ACTIONS(2530),
    [anon_sym_AMP] = ACTIONS(2528),
    [anon_sym_SEMI] = ACTIONS(2530),
    [anon_sym___extension__] = ACTIONS(2528),
    [anon_sym_typedef] = ACTIONS(2528),
    [anon_sym_in] = ACTIONS(2528),
    [anon_sym_out] = ACTIONS(2528),
    [anon_sym_inout] = ACTIONS(2528),
    [anon_sym_extern] = ACTIONS(2528),
    [anon_sym___attribute__] = ACTIONS(2528),
    [anon_sym_COLON_COLON] = ACTIONS(2530),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2530),
    [anon_sym___declspec] = ACTIONS(2528),
    [anon_sym___based] = ACTIONS(2528),
    [anon_sym___cdecl] = ACTIONS(2528),
    [anon_sym___clrcall] = ACTIONS(2528),
    [anon_sym___stdcall] = ACTIONS(2528),
    [anon_sym___fastcall] = ACTIONS(2528),
    [anon_sym___thiscall] = ACTIONS(2528),
    [anon_sym___vectorcall] = ACTIONS(2528),
    [anon_sym_LBRACE] = ACTIONS(2530),
    [anon_sym_signed] = ACTIONS(2528),
    [anon_sym_unsigned] = ACTIONS(2528),
    [anon_sym_long] = ACTIONS(2528),
    [anon_sym_short] = ACTIONS(2528),
    [anon_sym_LBRACK] = ACTIONS(2528),
    [anon_sym_static] = ACTIONS(2528),
    [anon_sym_register] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(2528),
    [anon_sym___inline] = ACTIONS(2528),
    [anon_sym___inline__] = ACTIONS(2528),
    [anon_sym___forceinline] = ACTIONS(2528),
    [anon_sym_thread_local] = ACTIONS(2528),
    [anon_sym___thread] = ACTIONS(2528),
    [anon_sym_const] = ACTIONS(2528),
    [anon_sym_constexpr] = ACTIONS(2528),
    [anon_sym_volatile] = ACTIONS(2528),
    [anon_sym_restrict] = ACTIONS(2528),
    [anon_sym___restrict__] = ACTIONS(2528),
    [anon_sym__Atomic] = ACTIONS(2528),
    [anon_sym__Noreturn] = ACTIONS(2528),
    [anon_sym_noreturn] = ACTIONS(2528),
    [anon_sym_mutable] = ACTIONS(2528),
    [anon_sym_constinit] = ACTIONS(2528),
    [anon_sym_consteval] = ACTIONS(2528),
    [anon_sym_alignas] = ACTIONS(2528),
    [anon_sym__Alignas] = ACTIONS(2528),
    [sym_primitive_type] = ACTIONS(2528),
    [anon_sym_enum] = ACTIONS(2528),
    [anon_sym_class] = ACTIONS(2528),
    [anon_sym_struct] = ACTIONS(2528),
    [anon_sym_union] = ACTIONS(2528),
    [anon_sym_if] = ACTIONS(2528),
    [anon_sym_switch] = ACTIONS(2528),
    [anon_sym_case] = ACTIONS(2528),
    [anon_sym_default] = ACTIONS(2528),
    [anon_sym_while] = ACTIONS(2528),
    [anon_sym_do] = ACTIONS(2528),
    [anon_sym_for] = ACTIONS(2528),
    [anon_sym_return] = ACTIONS(2528),
    [anon_sym_break] = ACTIONS(2528),
    [anon_sym_continue] = ACTIONS(2528),
    [anon_sym_goto] = ACTIONS(2528),
    [anon_sym___try] = ACTIONS(2528),
    [anon_sym___leave] = ACTIONS(2528),
    [anon_sym_not] = ACTIONS(2528),
    [anon_sym_compl] = ACTIONS(2528),
    [anon_sym_DASH_DASH] = ACTIONS(2530),
    [anon_sym_PLUS_PLUS] = ACTIONS(2530),
    [anon_sym_sizeof] = ACTIONS(2528),
    [anon_sym___alignof__] = ACTIONS(2528),
    [anon_sym___alignof] = ACTIONS(2528),
    [anon_sym__alignof] = ACTIONS(2528),
    [anon_sym_alignof] = ACTIONS(2528),
    [anon_sym__Alignof] = ACTIONS(2528),
    [anon_sym_offsetof] = ACTIONS(2528),
    [anon_sym__Generic] = ACTIONS(2528),
    [anon_sym_asm] = ACTIONS(2528),
    [anon_sym___asm__] = ACTIONS(2528),
    [sym_number_literal] = ACTIONS(2530),
    [anon_sym_L_SQUOTE] = ACTIONS(2530),
    [anon_sym_u_SQUOTE] = ACTIONS(2530),
    [anon_sym_U_SQUOTE] = ACTIONS(2530),
    [anon_sym_u8_SQUOTE] = ACTIONS(2530),
    [anon_sym_SQUOTE] = ACTIONS(2530),
    [anon_sym_L_DQUOTE] = ACTIONS(2530),
    [anon_sym_u_DQUOTE] = ACTIONS(2530),
    [anon_sym_U_DQUOTE] = ACTIONS(2530),
    [anon_sym_u8_DQUOTE] = ACTIONS(2530),
    [anon_sym_DQUOTE] = ACTIONS(2530),
    [sym_true] = ACTIONS(2528),
    [sym_false] = ACTIONS(2528),
    [anon_sym_NULL] = ACTIONS(2528),
    [anon_sym_nullptr] = ACTIONS(2528),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2528),
    [anon_sym_decltype] = ACTIONS(2528),
    [sym_virtual] = ACTIONS(2528),
    [anon_sym_explicit] = ACTIONS(2528),
    [anon_sym_typename] = ACTIONS(2528),
    [anon_sym_template] = ACTIONS(2528),
    [anon_sym_operator] = ACTIONS(2528),
    [anon_sym_try] = ACTIONS(2528),
    [anon_sym_delete] = ACTIONS(2528),
    [anon_sym_throw] = ACTIONS(2528),
    [anon_sym_namespace] = ACTIONS(2528),
    [anon_sym_using] = ACTIONS(2528),
    [anon_sym_static_assert] = ACTIONS(2528),
    [anon_sym_concept] = ACTIONS(2528),
    [anon_sym_co_return] = ACTIONS(2528),
    [anon_sym_co_yield] = ACTIONS(2528),
    [anon_sym_R_DQUOTE] = ACTIONS(2530),
    [anon_sym_LR_DQUOTE] = ACTIONS(2530),
    [anon_sym_uR_DQUOTE] = ACTIONS(2530),
    [anon_sym_UR_DQUOTE] = ACTIONS(2530),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2530),
    [anon_sym_co_await] = ACTIONS(2528),
    [anon_sym_new] = ACTIONS(2528),
    [anon_sym_requires] = ACTIONS(2528),
    [sym_this] = ACTIONS(2528),
    [anon_sym_discard] = ACTIONS(2528),
    [anon_sym_precise] = ACTIONS(2528),
    [anon_sym_shared] = ACTIONS(2528),
    [anon_sym_groupshared] = ACTIONS(2528),
    [anon_sym_uniform] = ACTIONS(2528),
    [anon_sym_row_major] = ACTIONS(2528),
    [anon_sym_column_major] = ACTIONS(2528),
    [anon_sym_globallycoherent] = ACTIONS(2528),
    [anon_sym_centroid] = ACTIONS(2528),
    [anon_sym_noperspective] = ACTIONS(2528),
    [anon_sym_nointerpolation] = ACTIONS(2528),
    [anon_sym_sample] = ACTIONS(2528),
    [anon_sym_linear] = ACTIONS(2528),
    [anon_sym_snorm] = ACTIONS(2528),
    [anon_sym_unorm] = ACTIONS(2528),
    [anon_sym_point] = ACTIONS(2528),
    [anon_sym_line] = ACTIONS(2528),
    [anon_sym_triangleadj] = ACTIONS(2528),
    [anon_sym_lineadj] = ACTIONS(2528),
    [anon_sym_triangle] = ACTIONS(2528),
    [anon_sym_cbuffer] = ACTIONS(2528),
  },
  [334] = {
    [sym_identifier] = ACTIONS(2532),
    [aux_sym_preproc_include_token1] = ACTIONS(2532),
    [aux_sym_preproc_def_token1] = ACTIONS(2532),
    [aux_sym_preproc_if_token1] = ACTIONS(2532),
    [aux_sym_preproc_if_token2] = ACTIONS(2532),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2532),
    [aux_sym_preproc_else_token1] = ACTIONS(2532),
    [aux_sym_preproc_elif_token1] = ACTIONS(2532),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2532),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2532),
    [sym_preproc_directive] = ACTIONS(2532),
    [anon_sym_LPAREN2] = ACTIONS(2534),
    [anon_sym_BANG] = ACTIONS(2534),
    [anon_sym_TILDE] = ACTIONS(2534),
    [anon_sym_DASH] = ACTIONS(2532),
    [anon_sym_PLUS] = ACTIONS(2532),
    [anon_sym_STAR] = ACTIONS(2534),
    [anon_sym_AMP_AMP] = ACTIONS(2534),
    [anon_sym_AMP] = ACTIONS(2532),
    [anon_sym_SEMI] = ACTIONS(2534),
    [anon_sym___extension__] = ACTIONS(2532),
    [anon_sym_typedef] = ACTIONS(2532),
    [anon_sym_in] = ACTIONS(2532),
    [anon_sym_out] = ACTIONS(2532),
    [anon_sym_inout] = ACTIONS(2532),
    [anon_sym_extern] = ACTIONS(2532),
    [anon_sym___attribute__] = ACTIONS(2532),
    [anon_sym_COLON_COLON] = ACTIONS(2534),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2534),
    [anon_sym___declspec] = ACTIONS(2532),
    [anon_sym___based] = ACTIONS(2532),
    [anon_sym___cdecl] = ACTIONS(2532),
    [anon_sym___clrcall] = ACTIONS(2532),
    [anon_sym___stdcall] = ACTIONS(2532),
    [anon_sym___fastcall] = ACTIONS(2532),
    [anon_sym___thiscall] = ACTIONS(2532),
    [anon_sym___vectorcall] = ACTIONS(2532),
    [anon_sym_LBRACE] = ACTIONS(2534),
    [anon_sym_signed] = ACTIONS(2532),
    [anon_sym_unsigned] = ACTIONS(2532),
    [anon_sym_long] = ACTIONS(2532),
    [anon_sym_short] = ACTIONS(2532),
    [anon_sym_LBRACK] = ACTIONS(2532),
    [anon_sym_static] = ACTIONS(2532),
    [anon_sym_register] = ACTIONS(2532),
    [anon_sym_inline] = ACTIONS(2532),
    [anon_sym___inline] = ACTIONS(2532),
    [anon_sym___inline__] = ACTIONS(2532),
    [anon_sym___forceinline] = ACTIONS(2532),
    [anon_sym_thread_local] = ACTIONS(2532),
    [anon_sym___thread] = ACTIONS(2532),
    [anon_sym_const] = ACTIONS(2532),
    [anon_sym_constexpr] = ACTIONS(2532),
    [anon_sym_volatile] = ACTIONS(2532),
    [anon_sym_restrict] = ACTIONS(2532),
    [anon_sym___restrict__] = ACTIONS(2532),
    [anon_sym__Atomic] = ACTIONS(2532),
    [anon_sym__Noreturn] = ACTIONS(2532),
    [anon_sym_noreturn] = ACTIONS(2532),
    [anon_sym_mutable] = ACTIONS(2532),
    [anon_sym_constinit] = ACTIONS(2532),
    [anon_sym_consteval] = ACTIONS(2532),
    [anon_sym_alignas] = ACTIONS(2532),
    [anon_sym__Alignas] = ACTIONS(2532),
    [sym_primitive_type] = ACTIONS(2532),
    [anon_sym_enum] = ACTIONS(2532),
    [anon_sym_class] = ACTIONS(2532),
    [anon_sym_struct] = ACTIONS(2532),
    [anon_sym_union] = ACTIONS(2532),
    [anon_sym_if] = ACTIONS(2532),
    [anon_sym_switch] = ACTIONS(2532),
    [anon_sym_case] = ACTIONS(2532),
    [anon_sym_default] = ACTIONS(2532),
    [anon_sym_while] = ACTIONS(2532),
    [anon_sym_do] = ACTIONS(2532),
    [anon_sym_for] = ACTIONS(2532),
    [anon_sym_return] = ACTIONS(2532),
    [anon_sym_break] = ACTIONS(2532),
    [anon_sym_continue] = ACTIONS(2532),
    [anon_sym_goto] = ACTIONS(2532),
    [anon_sym___try] = ACTIONS(2532),
    [anon_sym___leave] = ACTIONS(2532),
    [anon_sym_not] = ACTIONS(2532),
    [anon_sym_compl] = ACTIONS(2532),
    [anon_sym_DASH_DASH] = ACTIONS(2534),
    [anon_sym_PLUS_PLUS] = ACTIONS(2534),
    [anon_sym_sizeof] = ACTIONS(2532),
    [anon_sym___alignof__] = ACTIONS(2532),
    [anon_sym___alignof] = ACTIONS(2532),
    [anon_sym__alignof] = ACTIONS(2532),
    [anon_sym_alignof] = ACTIONS(2532),
    [anon_sym__Alignof] = ACTIONS(2532),
    [anon_sym_offsetof] = ACTIONS(2532),
    [anon_sym__Generic] = ACTIONS(2532),
    [anon_sym_asm] = ACTIONS(2532),
    [anon_sym___asm__] = ACTIONS(2532),
    [sym_number_literal] = ACTIONS(2534),
    [anon_sym_L_SQUOTE] = ACTIONS(2534),
    [anon_sym_u_SQUOTE] = ACTIONS(2534),
    [anon_sym_U_SQUOTE] = ACTIONS(2534),
    [anon_sym_u8_SQUOTE] = ACTIONS(2534),
    [anon_sym_SQUOTE] = ACTIONS(2534),
    [anon_sym_L_DQUOTE] = ACTIONS(2534),
    [anon_sym_u_DQUOTE] = ACTIONS(2534),
    [anon_sym_U_DQUOTE] = ACTIONS(2534),
    [anon_sym_u8_DQUOTE] = ACTIONS(2534),
    [anon_sym_DQUOTE] = ACTIONS(2534),
    [sym_true] = ACTIONS(2532),
    [sym_false] = ACTIONS(2532),
    [anon_sym_NULL] = ACTIONS(2532),
    [anon_sym_nullptr] = ACTIONS(2532),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2532),
    [anon_sym_decltype] = ACTIONS(2532),
    [sym_virtual] = ACTIONS(2532),
    [anon_sym_explicit] = ACTIONS(2532),
    [anon_sym_typename] = ACTIONS(2532),
    [anon_sym_template] = ACTIONS(2532),
    [anon_sym_operator] = ACTIONS(2532),
    [anon_sym_try] = ACTIONS(2532),
    [anon_sym_delete] = ACTIONS(2532),
    [anon_sym_throw] = ACTIONS(2532),
    [anon_sym_namespace] = ACTIONS(2532),
    [anon_sym_using] = ACTIONS(2532),
    [anon_sym_static_assert] = ACTIONS(2532),
    [anon_sym_concept] = ACTIONS(2532),
    [anon_sym_co_return] = ACTIONS(2532),
    [anon_sym_co_yield] = ACTIONS(2532),
    [anon_sym_R_DQUOTE] = ACTIONS(2534),
    [anon_sym_LR_DQUOTE] = ACTIONS(2534),
    [anon_sym_uR_DQUOTE] = ACTIONS(2534),
    [anon_sym_UR_DQUOTE] = ACTIONS(2534),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2534),
    [anon_sym_co_await] = ACTIONS(2532),
    [anon_sym_new] = ACTIONS(2532),
    [anon_sym_requires] = ACTIONS(2532),
    [sym_this] = ACTIONS(2532),
    [anon_sym_discard] = ACTIONS(2532),
    [anon_sym_precise] = ACTIONS(2532),
    [anon_sym_shared] = ACTIONS(2532),
    [anon_sym_groupshared] = ACTIONS(2532),
    [anon_sym_uniform] = ACTIONS(2532),
    [anon_sym_row_major] = ACTIONS(2532),
    [anon_sym_column_major] = ACTIONS(2532),
    [anon_sym_globallycoherent] = ACTIONS(2532),
    [anon_sym_centroid] = ACTIONS(2532),
    [anon_sym_noperspective] = ACTIONS(2532),
    [anon_sym_nointerpolation] = ACTIONS(2532),
    [anon_sym_sample] = ACTIONS(2532),
    [anon_sym_linear] = ACTIONS(2532),
    [anon_sym_snorm] = ACTIONS(2532),
    [anon_sym_unorm] = ACTIONS(2532),
    [anon_sym_point] = ACTIONS(2532),
    [anon_sym_line] = ACTIONS(2532),
    [anon_sym_triangleadj] = ACTIONS(2532),
    [anon_sym_lineadj] = ACTIONS(2532),
    [anon_sym_triangle] = ACTIONS(2532),
    [anon_sym_cbuffer] = ACTIONS(2532),
  },
  [335] = {
    [sym_identifier] = ACTIONS(2536),
    [aux_sym_preproc_include_token1] = ACTIONS(2536),
    [aux_sym_preproc_def_token1] = ACTIONS(2536),
    [aux_sym_preproc_if_token1] = ACTIONS(2536),
    [aux_sym_preproc_if_token2] = ACTIONS(2536),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2536),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2536),
    [aux_sym_preproc_else_token1] = ACTIONS(2536),
    [aux_sym_preproc_elif_token1] = ACTIONS(2536),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2536),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2536),
    [sym_preproc_directive] = ACTIONS(2536),
    [anon_sym_LPAREN2] = ACTIONS(2538),
    [anon_sym_BANG] = ACTIONS(2538),
    [anon_sym_TILDE] = ACTIONS(2538),
    [anon_sym_DASH] = ACTIONS(2536),
    [anon_sym_PLUS] = ACTIONS(2536),
    [anon_sym_STAR] = ACTIONS(2538),
    [anon_sym_AMP_AMP] = ACTIONS(2538),
    [anon_sym_AMP] = ACTIONS(2536),
    [anon_sym_SEMI] = ACTIONS(2538),
    [anon_sym___extension__] = ACTIONS(2536),
    [anon_sym_typedef] = ACTIONS(2536),
    [anon_sym_in] = ACTIONS(2536),
    [anon_sym_out] = ACTIONS(2536),
    [anon_sym_inout] = ACTIONS(2536),
    [anon_sym_extern] = ACTIONS(2536),
    [anon_sym___attribute__] = ACTIONS(2536),
    [anon_sym_COLON_COLON] = ACTIONS(2538),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2538),
    [anon_sym___declspec] = ACTIONS(2536),
    [anon_sym___based] = ACTIONS(2536),
    [anon_sym___cdecl] = ACTIONS(2536),
    [anon_sym___clrcall] = ACTIONS(2536),
    [anon_sym___stdcall] = ACTIONS(2536),
    [anon_sym___fastcall] = ACTIONS(2536),
    [anon_sym___thiscall] = ACTIONS(2536),
    [anon_sym___vectorcall] = ACTIONS(2536),
    [anon_sym_LBRACE] = ACTIONS(2538),
    [anon_sym_signed] = ACTIONS(2536),
    [anon_sym_unsigned] = ACTIONS(2536),
    [anon_sym_long] = ACTIONS(2536),
    [anon_sym_short] = ACTIONS(2536),
    [anon_sym_LBRACK] = ACTIONS(2536),
    [anon_sym_static] = ACTIONS(2536),
    [anon_sym_register] = ACTIONS(2536),
    [anon_sym_inline] = ACTIONS(2536),
    [anon_sym___inline] = ACTIONS(2536),
    [anon_sym___inline__] = ACTIONS(2536),
    [anon_sym___forceinline] = ACTIONS(2536),
    [anon_sym_thread_local] = ACTIONS(2536),
    [anon_sym___thread] = ACTIONS(2536),
    [anon_sym_const] = ACTIONS(2536),
    [anon_sym_constexpr] = ACTIONS(2536),
    [anon_sym_volatile] = ACTIONS(2536),
    [anon_sym_restrict] = ACTIONS(2536),
    [anon_sym___restrict__] = ACTIONS(2536),
    [anon_sym__Atomic] = ACTIONS(2536),
    [anon_sym__Noreturn] = ACTIONS(2536),
    [anon_sym_noreturn] = ACTIONS(2536),
    [anon_sym_mutable] = ACTIONS(2536),
    [anon_sym_constinit] = ACTIONS(2536),
    [anon_sym_consteval] = ACTIONS(2536),
    [anon_sym_alignas] = ACTIONS(2536),
    [anon_sym__Alignas] = ACTIONS(2536),
    [sym_primitive_type] = ACTIONS(2536),
    [anon_sym_enum] = ACTIONS(2536),
    [anon_sym_class] = ACTIONS(2536),
    [anon_sym_struct] = ACTIONS(2536),
    [anon_sym_union] = ACTIONS(2536),
    [anon_sym_if] = ACTIONS(2536),
    [anon_sym_switch] = ACTIONS(2536),
    [anon_sym_case] = ACTIONS(2536),
    [anon_sym_default] = ACTIONS(2536),
    [anon_sym_while] = ACTIONS(2536),
    [anon_sym_do] = ACTIONS(2536),
    [anon_sym_for] = ACTIONS(2536),
    [anon_sym_return] = ACTIONS(2536),
    [anon_sym_break] = ACTIONS(2536),
    [anon_sym_continue] = ACTIONS(2536),
    [anon_sym_goto] = ACTIONS(2536),
    [anon_sym___try] = ACTIONS(2536),
    [anon_sym___leave] = ACTIONS(2536),
    [anon_sym_not] = ACTIONS(2536),
    [anon_sym_compl] = ACTIONS(2536),
    [anon_sym_DASH_DASH] = ACTIONS(2538),
    [anon_sym_PLUS_PLUS] = ACTIONS(2538),
    [anon_sym_sizeof] = ACTIONS(2536),
    [anon_sym___alignof__] = ACTIONS(2536),
    [anon_sym___alignof] = ACTIONS(2536),
    [anon_sym__alignof] = ACTIONS(2536),
    [anon_sym_alignof] = ACTIONS(2536),
    [anon_sym__Alignof] = ACTIONS(2536),
    [anon_sym_offsetof] = ACTIONS(2536),
    [anon_sym__Generic] = ACTIONS(2536),
    [anon_sym_asm] = ACTIONS(2536),
    [anon_sym___asm__] = ACTIONS(2536),
    [sym_number_literal] = ACTIONS(2538),
    [anon_sym_L_SQUOTE] = ACTIONS(2538),
    [anon_sym_u_SQUOTE] = ACTIONS(2538),
    [anon_sym_U_SQUOTE] = ACTIONS(2538),
    [anon_sym_u8_SQUOTE] = ACTIONS(2538),
    [anon_sym_SQUOTE] = ACTIONS(2538),
    [anon_sym_L_DQUOTE] = ACTIONS(2538),
    [anon_sym_u_DQUOTE] = ACTIONS(2538),
    [anon_sym_U_DQUOTE] = ACTIONS(2538),
    [anon_sym_u8_DQUOTE] = ACTIONS(2538),
    [anon_sym_DQUOTE] = ACTIONS(2538),
    [sym_true] = ACTIONS(2536),
    [sym_false] = ACTIONS(2536),
    [anon_sym_NULL] = ACTIONS(2536),
    [anon_sym_nullptr] = ACTIONS(2536),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2536),
    [anon_sym_decltype] = ACTIONS(2536),
    [sym_virtual] = ACTIONS(2536),
    [anon_sym_explicit] = ACTIONS(2536),
    [anon_sym_typename] = ACTIONS(2536),
    [anon_sym_template] = ACTIONS(2536),
    [anon_sym_operator] = ACTIONS(2536),
    [anon_sym_try] = ACTIONS(2536),
    [anon_sym_delete] = ACTIONS(2536),
    [anon_sym_throw] = ACTIONS(2536),
    [anon_sym_namespace] = ACTIONS(2536),
    [anon_sym_using] = ACTIONS(2536),
    [anon_sym_static_assert] = ACTIONS(2536),
    [anon_sym_concept] = ACTIONS(2536),
    [anon_sym_co_return] = ACTIONS(2536),
    [anon_sym_co_yield] = ACTIONS(2536),
    [anon_sym_R_DQUOTE] = ACTIONS(2538),
    [anon_sym_LR_DQUOTE] = ACTIONS(2538),
    [anon_sym_uR_DQUOTE] = ACTIONS(2538),
    [anon_sym_UR_DQUOTE] = ACTIONS(2538),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2538),
    [anon_sym_co_await] = ACTIONS(2536),
    [anon_sym_new] = ACTIONS(2536),
    [anon_sym_requires] = ACTIONS(2536),
    [sym_this] = ACTIONS(2536),
    [anon_sym_discard] = ACTIONS(2536),
    [anon_sym_precise] = ACTIONS(2536),
    [anon_sym_shared] = ACTIONS(2536),
    [anon_sym_groupshared] = ACTIONS(2536),
    [anon_sym_uniform] = ACTIONS(2536),
    [anon_sym_row_major] = ACTIONS(2536),
    [anon_sym_column_major] = ACTIONS(2536),
    [anon_sym_globallycoherent] = ACTIONS(2536),
    [anon_sym_centroid] = ACTIONS(2536),
    [anon_sym_noperspective] = ACTIONS(2536),
    [anon_sym_nointerpolation] = ACTIONS(2536),
    [anon_sym_sample] = ACTIONS(2536),
    [anon_sym_linear] = ACTIONS(2536),
    [anon_sym_snorm] = ACTIONS(2536),
    [anon_sym_unorm] = ACTIONS(2536),
    [anon_sym_point] = ACTIONS(2536),
    [anon_sym_line] = ACTIONS(2536),
    [anon_sym_triangleadj] = ACTIONS(2536),
    [anon_sym_lineadj] = ACTIONS(2536),
    [anon_sym_triangle] = ACTIONS(2536),
    [anon_sym_cbuffer] = ACTIONS(2536),
  },
  [336] = {
    [sym_identifier] = ACTIONS(2540),
    [aux_sym_preproc_include_token1] = ACTIONS(2540),
    [aux_sym_preproc_def_token1] = ACTIONS(2540),
    [aux_sym_preproc_if_token1] = ACTIONS(2540),
    [aux_sym_preproc_if_token2] = ACTIONS(2540),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2540),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2540),
    [aux_sym_preproc_else_token1] = ACTIONS(2540),
    [aux_sym_preproc_elif_token1] = ACTIONS(2540),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2540),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2540),
    [sym_preproc_directive] = ACTIONS(2540),
    [anon_sym_LPAREN2] = ACTIONS(2542),
    [anon_sym_BANG] = ACTIONS(2542),
    [anon_sym_TILDE] = ACTIONS(2542),
    [anon_sym_DASH] = ACTIONS(2540),
    [anon_sym_PLUS] = ACTIONS(2540),
    [anon_sym_STAR] = ACTIONS(2542),
    [anon_sym_AMP_AMP] = ACTIONS(2542),
    [anon_sym_AMP] = ACTIONS(2540),
    [anon_sym_SEMI] = ACTIONS(2542),
    [anon_sym___extension__] = ACTIONS(2540),
    [anon_sym_typedef] = ACTIONS(2540),
    [anon_sym_in] = ACTIONS(2540),
    [anon_sym_out] = ACTIONS(2540),
    [anon_sym_inout] = ACTIONS(2540),
    [anon_sym_extern] = ACTIONS(2540),
    [anon_sym___attribute__] = ACTIONS(2540),
    [anon_sym_COLON_COLON] = ACTIONS(2542),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2542),
    [anon_sym___declspec] = ACTIONS(2540),
    [anon_sym___based] = ACTIONS(2540),
    [anon_sym___cdecl] = ACTIONS(2540),
    [anon_sym___clrcall] = ACTIONS(2540),
    [anon_sym___stdcall] = ACTIONS(2540),
    [anon_sym___fastcall] = ACTIONS(2540),
    [anon_sym___thiscall] = ACTIONS(2540),
    [anon_sym___vectorcall] = ACTIONS(2540),
    [anon_sym_LBRACE] = ACTIONS(2542),
    [anon_sym_signed] = ACTIONS(2540),
    [anon_sym_unsigned] = ACTIONS(2540),
    [anon_sym_long] = ACTIONS(2540),
    [anon_sym_short] = ACTIONS(2540),
    [anon_sym_LBRACK] = ACTIONS(2540),
    [anon_sym_static] = ACTIONS(2540),
    [anon_sym_register] = ACTIONS(2540),
    [anon_sym_inline] = ACTIONS(2540),
    [anon_sym___inline] = ACTIONS(2540),
    [anon_sym___inline__] = ACTIONS(2540),
    [anon_sym___forceinline] = ACTIONS(2540),
    [anon_sym_thread_local] = ACTIONS(2540),
    [anon_sym___thread] = ACTIONS(2540),
    [anon_sym_const] = ACTIONS(2540),
    [anon_sym_constexpr] = ACTIONS(2540),
    [anon_sym_volatile] = ACTIONS(2540),
    [anon_sym_restrict] = ACTIONS(2540),
    [anon_sym___restrict__] = ACTIONS(2540),
    [anon_sym__Atomic] = ACTIONS(2540),
    [anon_sym__Noreturn] = ACTIONS(2540),
    [anon_sym_noreturn] = ACTIONS(2540),
    [anon_sym_mutable] = ACTIONS(2540),
    [anon_sym_constinit] = ACTIONS(2540),
    [anon_sym_consteval] = ACTIONS(2540),
    [anon_sym_alignas] = ACTIONS(2540),
    [anon_sym__Alignas] = ACTIONS(2540),
    [sym_primitive_type] = ACTIONS(2540),
    [anon_sym_enum] = ACTIONS(2540),
    [anon_sym_class] = ACTIONS(2540),
    [anon_sym_struct] = ACTIONS(2540),
    [anon_sym_union] = ACTIONS(2540),
    [anon_sym_if] = ACTIONS(2540),
    [anon_sym_switch] = ACTIONS(2540),
    [anon_sym_case] = ACTIONS(2540),
    [anon_sym_default] = ACTIONS(2540),
    [anon_sym_while] = ACTIONS(2540),
    [anon_sym_do] = ACTIONS(2540),
    [anon_sym_for] = ACTIONS(2540),
    [anon_sym_return] = ACTIONS(2540),
    [anon_sym_break] = ACTIONS(2540),
    [anon_sym_continue] = ACTIONS(2540),
    [anon_sym_goto] = ACTIONS(2540),
    [anon_sym___try] = ACTIONS(2540),
    [anon_sym___leave] = ACTIONS(2540),
    [anon_sym_not] = ACTIONS(2540),
    [anon_sym_compl] = ACTIONS(2540),
    [anon_sym_DASH_DASH] = ACTIONS(2542),
    [anon_sym_PLUS_PLUS] = ACTIONS(2542),
    [anon_sym_sizeof] = ACTIONS(2540),
    [anon_sym___alignof__] = ACTIONS(2540),
    [anon_sym___alignof] = ACTIONS(2540),
    [anon_sym__alignof] = ACTIONS(2540),
    [anon_sym_alignof] = ACTIONS(2540),
    [anon_sym__Alignof] = ACTIONS(2540),
    [anon_sym_offsetof] = ACTIONS(2540),
    [anon_sym__Generic] = ACTIONS(2540),
    [anon_sym_asm] = ACTIONS(2540),
    [anon_sym___asm__] = ACTIONS(2540),
    [sym_number_literal] = ACTIONS(2542),
    [anon_sym_L_SQUOTE] = ACTIONS(2542),
    [anon_sym_u_SQUOTE] = ACTIONS(2542),
    [anon_sym_U_SQUOTE] = ACTIONS(2542),
    [anon_sym_u8_SQUOTE] = ACTIONS(2542),
    [anon_sym_SQUOTE] = ACTIONS(2542),
    [anon_sym_L_DQUOTE] = ACTIONS(2542),
    [anon_sym_u_DQUOTE] = ACTIONS(2542),
    [anon_sym_U_DQUOTE] = ACTIONS(2542),
    [anon_sym_u8_DQUOTE] = ACTIONS(2542),
    [anon_sym_DQUOTE] = ACTIONS(2542),
    [sym_true] = ACTIONS(2540),
    [sym_false] = ACTIONS(2540),
    [anon_sym_NULL] = ACTIONS(2540),
    [anon_sym_nullptr] = ACTIONS(2540),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2540),
    [anon_sym_decltype] = ACTIONS(2540),
    [sym_virtual] = ACTIONS(2540),
    [anon_sym_explicit] = ACTIONS(2540),
    [anon_sym_typename] = ACTIONS(2540),
    [anon_sym_template] = ACTIONS(2540),
    [anon_sym_operator] = ACTIONS(2540),
    [anon_sym_try] = ACTIONS(2540),
    [anon_sym_delete] = ACTIONS(2540),
    [anon_sym_throw] = ACTIONS(2540),
    [anon_sym_namespace] = ACTIONS(2540),
    [anon_sym_using] = ACTIONS(2540),
    [anon_sym_static_assert] = ACTIONS(2540),
    [anon_sym_concept] = ACTIONS(2540),
    [anon_sym_co_return] = ACTIONS(2540),
    [anon_sym_co_yield] = ACTIONS(2540),
    [anon_sym_R_DQUOTE] = ACTIONS(2542),
    [anon_sym_LR_DQUOTE] = ACTIONS(2542),
    [anon_sym_uR_DQUOTE] = ACTIONS(2542),
    [anon_sym_UR_DQUOTE] = ACTIONS(2542),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2542),
    [anon_sym_co_await] = ACTIONS(2540),
    [anon_sym_new] = ACTIONS(2540),
    [anon_sym_requires] = ACTIONS(2540),
    [sym_this] = ACTIONS(2540),
    [anon_sym_discard] = ACTIONS(2540),
    [anon_sym_precise] = ACTIONS(2540),
    [anon_sym_shared] = ACTIONS(2540),
    [anon_sym_groupshared] = ACTIONS(2540),
    [anon_sym_uniform] = ACTIONS(2540),
    [anon_sym_row_major] = ACTIONS(2540),
    [anon_sym_column_major] = ACTIONS(2540),
    [anon_sym_globallycoherent] = ACTIONS(2540),
    [anon_sym_centroid] = ACTIONS(2540),
    [anon_sym_noperspective] = ACTIONS(2540),
    [anon_sym_nointerpolation] = ACTIONS(2540),
    [anon_sym_sample] = ACTIONS(2540),
    [anon_sym_linear] = ACTIONS(2540),
    [anon_sym_snorm] = ACTIONS(2540),
    [anon_sym_unorm] = ACTIONS(2540),
    [anon_sym_point] = ACTIONS(2540),
    [anon_sym_line] = ACTIONS(2540),
    [anon_sym_triangleadj] = ACTIONS(2540),
    [anon_sym_lineadj] = ACTIONS(2540),
    [anon_sym_triangle] = ACTIONS(2540),
    [anon_sym_cbuffer] = ACTIONS(2540),
  },
  [337] = {
    [sym_identifier] = ACTIONS(1959),
    [aux_sym_preproc_include_token1] = ACTIONS(1959),
    [aux_sym_preproc_def_token1] = ACTIONS(1959),
    [aux_sym_preproc_if_token1] = ACTIONS(1959),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1959),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1959),
    [sym_preproc_directive] = ACTIONS(1959),
    [anon_sym_LPAREN2] = ACTIONS(1961),
    [anon_sym_BANG] = ACTIONS(1961),
    [anon_sym_TILDE] = ACTIONS(1961),
    [anon_sym_DASH] = ACTIONS(1959),
    [anon_sym_PLUS] = ACTIONS(1959),
    [anon_sym_STAR] = ACTIONS(1961),
    [anon_sym_AMP_AMP] = ACTIONS(1961),
    [anon_sym_AMP] = ACTIONS(1959),
    [anon_sym_COLON] = ACTIONS(1959),
    [anon_sym_SEMI] = ACTIONS(1961),
    [anon_sym___extension__] = ACTIONS(1959),
    [anon_sym_typedef] = ACTIONS(1959),
    [anon_sym_in] = ACTIONS(1959),
    [anon_sym_out] = ACTIONS(1959),
    [anon_sym_inout] = ACTIONS(1959),
    [anon_sym_extern] = ACTIONS(1959),
    [anon_sym___attribute__] = ACTIONS(1959),
    [anon_sym_COLON_COLON] = ACTIONS(1961),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1961),
    [anon_sym___declspec] = ACTIONS(1959),
    [anon_sym___based] = ACTIONS(1959),
    [anon_sym___cdecl] = ACTIONS(1959),
    [anon_sym___clrcall] = ACTIONS(1959),
    [anon_sym___stdcall] = ACTIONS(1959),
    [anon_sym___fastcall] = ACTIONS(1959),
    [anon_sym___thiscall] = ACTIONS(1959),
    [anon_sym___vectorcall] = ACTIONS(1959),
    [anon_sym_LBRACE] = ACTIONS(1961),
    [anon_sym_RBRACE] = ACTIONS(1961),
    [anon_sym_signed] = ACTIONS(1959),
    [anon_sym_unsigned] = ACTIONS(1959),
    [anon_sym_long] = ACTIONS(1959),
    [anon_sym_short] = ACTIONS(1959),
    [anon_sym_LBRACK] = ACTIONS(1959),
    [anon_sym_static] = ACTIONS(1959),
    [anon_sym_register] = ACTIONS(1959),
    [anon_sym_inline] = ACTIONS(1959),
    [anon_sym___inline] = ACTIONS(1959),
    [anon_sym___inline__] = ACTIONS(1959),
    [anon_sym___forceinline] = ACTIONS(1959),
    [anon_sym_thread_local] = ACTIONS(1959),
    [anon_sym___thread] = ACTIONS(1959),
    [anon_sym_const] = ACTIONS(1959),
    [anon_sym_constexpr] = ACTIONS(1959),
    [anon_sym_volatile] = ACTIONS(1959),
    [anon_sym_restrict] = ACTIONS(1959),
    [anon_sym___restrict__] = ACTIONS(1959),
    [anon_sym__Atomic] = ACTIONS(1959),
    [anon_sym__Noreturn] = ACTIONS(1959),
    [anon_sym_noreturn] = ACTIONS(1959),
    [anon_sym_mutable] = ACTIONS(1959),
    [anon_sym_constinit] = ACTIONS(1959),
    [anon_sym_consteval] = ACTIONS(1959),
    [anon_sym_alignas] = ACTIONS(1959),
    [anon_sym__Alignas] = ACTIONS(1959),
    [sym_primitive_type] = ACTIONS(1959),
    [anon_sym_enum] = ACTIONS(1959),
    [anon_sym_class] = ACTIONS(1959),
    [anon_sym_struct] = ACTIONS(1959),
    [anon_sym_union] = ACTIONS(1959),
    [anon_sym_if] = ACTIONS(1959),
    [anon_sym_else] = ACTIONS(1959),
    [anon_sym_switch] = ACTIONS(1959),
    [anon_sym_case] = ACTIONS(1959),
    [anon_sym_default] = ACTIONS(1959),
    [anon_sym_while] = ACTIONS(1959),
    [anon_sym_do] = ACTIONS(1959),
    [anon_sym_for] = ACTIONS(1959),
    [anon_sym_return] = ACTIONS(1959),
    [anon_sym_break] = ACTIONS(1959),
    [anon_sym_continue] = ACTIONS(1959),
    [anon_sym_goto] = ACTIONS(1959),
    [anon_sym___try] = ACTIONS(1959),
    [anon_sym___leave] = ACTIONS(1959),
    [anon_sym_not] = ACTIONS(1959),
    [anon_sym_compl] = ACTIONS(1959),
    [anon_sym_DASH_DASH] = ACTIONS(1961),
    [anon_sym_PLUS_PLUS] = ACTIONS(1961),
    [anon_sym_sizeof] = ACTIONS(1959),
    [anon_sym___alignof__] = ACTIONS(1959),
    [anon_sym___alignof] = ACTIONS(1959),
    [anon_sym__alignof] = ACTIONS(1959),
    [anon_sym_alignof] = ACTIONS(1959),
    [anon_sym__Alignof] = ACTIONS(1959),
    [anon_sym_offsetof] = ACTIONS(1959),
    [anon_sym__Generic] = ACTIONS(1959),
    [anon_sym_asm] = ACTIONS(1959),
    [anon_sym___asm__] = ACTIONS(1959),
    [sym_number_literal] = ACTIONS(1961),
    [anon_sym_L_SQUOTE] = ACTIONS(1961),
    [anon_sym_u_SQUOTE] = ACTIONS(1961),
    [anon_sym_U_SQUOTE] = ACTIONS(1961),
    [anon_sym_u8_SQUOTE] = ACTIONS(1961),
    [anon_sym_SQUOTE] = ACTIONS(1961),
    [anon_sym_L_DQUOTE] = ACTIONS(1961),
    [anon_sym_u_DQUOTE] = ACTIONS(1961),
    [anon_sym_U_DQUOTE] = ACTIONS(1961),
    [anon_sym_u8_DQUOTE] = ACTIONS(1961),
    [anon_sym_DQUOTE] = ACTIONS(1961),
    [sym_true] = ACTIONS(1959),
    [sym_false] = ACTIONS(1959),
    [anon_sym_NULL] = ACTIONS(1959),
    [anon_sym_nullptr] = ACTIONS(1959),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1959),
    [anon_sym_decltype] = ACTIONS(1959),
    [anon_sym_final] = ACTIONS(1959),
    [anon_sym_override] = ACTIONS(1959),
    [sym_virtual] = ACTIONS(1959),
    [anon_sym_explicit] = ACTIONS(1959),
    [anon_sym_typename] = ACTIONS(1959),
    [anon_sym_template] = ACTIONS(1959),
    [anon_sym_operator] = ACTIONS(1959),
    [anon_sym_try] = ACTIONS(1959),
    [anon_sym_delete] = ACTIONS(1959),
    [anon_sym_throw] = ACTIONS(1959),
    [anon_sym_namespace] = ACTIONS(1959),
    [anon_sym_using] = ACTIONS(1959),
    [anon_sym_static_assert] = ACTIONS(1959),
    [anon_sym_concept] = ACTIONS(1959),
    [anon_sym_co_return] = ACTIONS(1959),
    [anon_sym_co_yield] = ACTIONS(1959),
    [anon_sym_R_DQUOTE] = ACTIONS(1961),
    [anon_sym_LR_DQUOTE] = ACTIONS(1961),
    [anon_sym_uR_DQUOTE] = ACTIONS(1961),
    [anon_sym_UR_DQUOTE] = ACTIONS(1961),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1961),
    [anon_sym_co_await] = ACTIONS(1959),
    [anon_sym_new] = ACTIONS(1959),
    [anon_sym_requires] = ACTIONS(1959),
    [sym_this] = ACTIONS(1959),
    [anon_sym_discard] = ACTIONS(1959),
    [anon_sym_precise] = ACTIONS(1959),
    [anon_sym_shared] = ACTIONS(1959),
    [anon_sym_groupshared] = ACTIONS(1959),
    [anon_sym_uniform] = ACTIONS(1959),
    [anon_sym_row_major] = ACTIONS(1959),
    [anon_sym_column_major] = ACTIONS(1959),
    [anon_sym_globallycoherent] = ACTIONS(1959),
    [anon_sym_centroid] = ACTIONS(1959),
    [anon_sym_noperspective] = ACTIONS(1959),
    [anon_sym_nointerpolation] = ACTIONS(1959),
    [anon_sym_sample] = ACTIONS(1959),
    [anon_sym_linear] = ACTIONS(1959),
    [anon_sym_snorm] = ACTIONS(1959),
    [anon_sym_unorm] = ACTIONS(1959),
    [anon_sym_point] = ACTIONS(1959),
    [anon_sym_line] = ACTIONS(1959),
    [anon_sym_triangleadj] = ACTIONS(1959),
    [anon_sym_lineadj] = ACTIONS(1959),
    [anon_sym_triangle] = ACTIONS(1959),
    [anon_sym_cbuffer] = ACTIONS(1959),
  },
  [338] = {
    [sym_catch_clause] = STATE(338),
    [aux_sym_constructor_try_statement_repeat1] = STATE(338),
    [sym_identifier] = ACTIONS(1973),
    [aux_sym_preproc_include_token1] = ACTIONS(1973),
    [aux_sym_preproc_def_token1] = ACTIONS(1973),
    [aux_sym_preproc_if_token1] = ACTIONS(1973),
    [aux_sym_preproc_if_token2] = ACTIONS(1973),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1973),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1973),
    [sym_preproc_directive] = ACTIONS(1973),
    [anon_sym_LPAREN2] = ACTIONS(1975),
    [anon_sym_BANG] = ACTIONS(1975),
    [anon_sym_TILDE] = ACTIONS(1975),
    [anon_sym_DASH] = ACTIONS(1973),
    [anon_sym_PLUS] = ACTIONS(1973),
    [anon_sym_STAR] = ACTIONS(1975),
    [anon_sym_AMP_AMP] = ACTIONS(1975),
    [anon_sym_AMP] = ACTIONS(1973),
    [anon_sym_SEMI] = ACTIONS(1975),
    [anon_sym___extension__] = ACTIONS(1973),
    [anon_sym_typedef] = ACTIONS(1973),
    [anon_sym_in] = ACTIONS(1973),
    [anon_sym_out] = ACTIONS(1973),
    [anon_sym_inout] = ACTIONS(1973),
    [anon_sym_extern] = ACTIONS(1973),
    [anon_sym___attribute__] = ACTIONS(1973),
    [anon_sym_COLON_COLON] = ACTIONS(1975),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1975),
    [anon_sym___declspec] = ACTIONS(1973),
    [anon_sym___based] = ACTIONS(1973),
    [anon_sym___cdecl] = ACTIONS(1973),
    [anon_sym___clrcall] = ACTIONS(1973),
    [anon_sym___stdcall] = ACTIONS(1973),
    [anon_sym___fastcall] = ACTIONS(1973),
    [anon_sym___thiscall] = ACTIONS(1973),
    [anon_sym___vectorcall] = ACTIONS(1973),
    [anon_sym_LBRACE] = ACTIONS(1975),
    [anon_sym_signed] = ACTIONS(1973),
    [anon_sym_unsigned] = ACTIONS(1973),
    [anon_sym_long] = ACTIONS(1973),
    [anon_sym_short] = ACTIONS(1973),
    [anon_sym_LBRACK] = ACTIONS(1973),
    [anon_sym_static] = ACTIONS(1973),
    [anon_sym_register] = ACTIONS(1973),
    [anon_sym_inline] = ACTIONS(1973),
    [anon_sym___inline] = ACTIONS(1973),
    [anon_sym___inline__] = ACTIONS(1973),
    [anon_sym___forceinline] = ACTIONS(1973),
    [anon_sym_thread_local] = ACTIONS(1973),
    [anon_sym___thread] = ACTIONS(1973),
    [anon_sym_const] = ACTIONS(1973),
    [anon_sym_constexpr] = ACTIONS(1973),
    [anon_sym_volatile] = ACTIONS(1973),
    [anon_sym_restrict] = ACTIONS(1973),
    [anon_sym___restrict__] = ACTIONS(1973),
    [anon_sym__Atomic] = ACTIONS(1973),
    [anon_sym__Noreturn] = ACTIONS(1973),
    [anon_sym_noreturn] = ACTIONS(1973),
    [anon_sym_mutable] = ACTIONS(1973),
    [anon_sym_constinit] = ACTIONS(1973),
    [anon_sym_consteval] = ACTIONS(1973),
    [anon_sym_alignas] = ACTIONS(1973),
    [anon_sym__Alignas] = ACTIONS(1973),
    [sym_primitive_type] = ACTIONS(1973),
    [anon_sym_enum] = ACTIONS(1973),
    [anon_sym_class] = ACTIONS(1973),
    [anon_sym_struct] = ACTIONS(1973),
    [anon_sym_union] = ACTIONS(1973),
    [anon_sym_if] = ACTIONS(1973),
    [anon_sym_else] = ACTIONS(1973),
    [anon_sym_switch] = ACTIONS(1973),
    [anon_sym_case] = ACTIONS(1973),
    [anon_sym_default] = ACTIONS(1973),
    [anon_sym_while] = ACTIONS(1973),
    [anon_sym_do] = ACTIONS(1973),
    [anon_sym_for] = ACTIONS(1973),
    [anon_sym_return] = ACTIONS(1973),
    [anon_sym_break] = ACTIONS(1973),
    [anon_sym_continue] = ACTIONS(1973),
    [anon_sym_goto] = ACTIONS(1973),
    [anon_sym___try] = ACTIONS(1973),
    [anon_sym___leave] = ACTIONS(1973),
    [anon_sym_not] = ACTIONS(1973),
    [anon_sym_compl] = ACTIONS(1973),
    [anon_sym_DASH_DASH] = ACTIONS(1975),
    [anon_sym_PLUS_PLUS] = ACTIONS(1975),
    [anon_sym_sizeof] = ACTIONS(1973),
    [anon_sym___alignof__] = ACTIONS(1973),
    [anon_sym___alignof] = ACTIONS(1973),
    [anon_sym__alignof] = ACTIONS(1973),
    [anon_sym_alignof] = ACTIONS(1973),
    [anon_sym__Alignof] = ACTIONS(1973),
    [anon_sym_offsetof] = ACTIONS(1973),
    [anon_sym__Generic] = ACTIONS(1973),
    [anon_sym_asm] = ACTIONS(1973),
    [anon_sym___asm__] = ACTIONS(1973),
    [sym_number_literal] = ACTIONS(1975),
    [anon_sym_L_SQUOTE] = ACTIONS(1975),
    [anon_sym_u_SQUOTE] = ACTIONS(1975),
    [anon_sym_U_SQUOTE] = ACTIONS(1975),
    [anon_sym_u8_SQUOTE] = ACTIONS(1975),
    [anon_sym_SQUOTE] = ACTIONS(1975),
    [anon_sym_L_DQUOTE] = ACTIONS(1975),
    [anon_sym_u_DQUOTE] = ACTIONS(1975),
    [anon_sym_U_DQUOTE] = ACTIONS(1975),
    [anon_sym_u8_DQUOTE] = ACTIONS(1975),
    [anon_sym_DQUOTE] = ACTIONS(1975),
    [sym_true] = ACTIONS(1973),
    [sym_false] = ACTIONS(1973),
    [anon_sym_NULL] = ACTIONS(1973),
    [anon_sym_nullptr] = ACTIONS(1973),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1973),
    [anon_sym_decltype] = ACTIONS(1973),
    [sym_virtual] = ACTIONS(1973),
    [anon_sym_explicit] = ACTIONS(1973),
    [anon_sym_typename] = ACTIONS(1973),
    [anon_sym_template] = ACTIONS(1973),
    [anon_sym_operator] = ACTIONS(1973),
    [anon_sym_try] = ACTIONS(1973),
    [anon_sym_delete] = ACTIONS(1973),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_namespace] = ACTIONS(1973),
    [anon_sym_using] = ACTIONS(1973),
    [anon_sym_static_assert] = ACTIONS(1973),
    [anon_sym_concept] = ACTIONS(1973),
    [anon_sym_co_return] = ACTIONS(1973),
    [anon_sym_co_yield] = ACTIONS(1973),
    [anon_sym_catch] = ACTIONS(2544),
    [anon_sym_R_DQUOTE] = ACTIONS(1975),
    [anon_sym_LR_DQUOTE] = ACTIONS(1975),
    [anon_sym_uR_DQUOTE] = ACTIONS(1975),
    [anon_sym_UR_DQUOTE] = ACTIONS(1975),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1975),
    [anon_sym_co_await] = ACTIONS(1973),
    [anon_sym_new] = ACTIONS(1973),
    [anon_sym_requires] = ACTIONS(1973),
    [sym_this] = ACTIONS(1973),
    [anon_sym_discard] = ACTIONS(1973),
    [anon_sym_precise] = ACTIONS(1973),
    [anon_sym_shared] = ACTIONS(1973),
    [anon_sym_groupshared] = ACTIONS(1973),
    [anon_sym_uniform] = ACTIONS(1973),
    [anon_sym_row_major] = ACTIONS(1973),
    [anon_sym_column_major] = ACTIONS(1973),
    [anon_sym_globallycoherent] = ACTIONS(1973),
    [anon_sym_centroid] = ACTIONS(1973),
    [anon_sym_noperspective] = ACTIONS(1973),
    [anon_sym_nointerpolation] = ACTIONS(1973),
    [anon_sym_sample] = ACTIONS(1973),
    [anon_sym_linear] = ACTIONS(1973),
    [anon_sym_snorm] = ACTIONS(1973),
    [anon_sym_unorm] = ACTIONS(1973),
    [anon_sym_point] = ACTIONS(1973),
    [anon_sym_line] = ACTIONS(1973),
    [anon_sym_triangleadj] = ACTIONS(1973),
    [anon_sym_lineadj] = ACTIONS(1973),
    [anon_sym_triangle] = ACTIONS(1973),
    [anon_sym_cbuffer] = ACTIONS(1973),
  },
  [339] = {
    [sym_catch_clause] = STATE(265),
    [aux_sym_constructor_try_statement_repeat1] = STATE(265),
    [sym_identifier] = ACTIONS(1963),
    [aux_sym_preproc_include_token1] = ACTIONS(1963),
    [aux_sym_preproc_def_token1] = ACTIONS(1963),
    [aux_sym_preproc_if_token1] = ACTIONS(1963),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1963),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1963),
    [sym_preproc_directive] = ACTIONS(1963),
    [anon_sym_LPAREN2] = ACTIONS(1965),
    [anon_sym_BANG] = ACTIONS(1965),
    [anon_sym_TILDE] = ACTIONS(1965),
    [anon_sym_DASH] = ACTIONS(1963),
    [anon_sym_PLUS] = ACTIONS(1963),
    [anon_sym_STAR] = ACTIONS(1965),
    [anon_sym_AMP_AMP] = ACTIONS(1965),
    [anon_sym_AMP] = ACTIONS(1963),
    [anon_sym_SEMI] = ACTIONS(1965),
    [anon_sym___extension__] = ACTIONS(1963),
    [anon_sym_typedef] = ACTIONS(1963),
    [anon_sym_in] = ACTIONS(1963),
    [anon_sym_out] = ACTIONS(1963),
    [anon_sym_inout] = ACTIONS(1963),
    [anon_sym_extern] = ACTIONS(1963),
    [anon_sym___attribute__] = ACTIONS(1963),
    [anon_sym_COLON_COLON] = ACTIONS(1965),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1965),
    [anon_sym___declspec] = ACTIONS(1963),
    [anon_sym___based] = ACTIONS(1963),
    [anon_sym___cdecl] = ACTIONS(1963),
    [anon_sym___clrcall] = ACTIONS(1963),
    [anon_sym___stdcall] = ACTIONS(1963),
    [anon_sym___fastcall] = ACTIONS(1963),
    [anon_sym___thiscall] = ACTIONS(1963),
    [anon_sym___vectorcall] = ACTIONS(1963),
    [anon_sym_LBRACE] = ACTIONS(1965),
    [anon_sym_RBRACE] = ACTIONS(1965),
    [anon_sym_signed] = ACTIONS(1963),
    [anon_sym_unsigned] = ACTIONS(1963),
    [anon_sym_long] = ACTIONS(1963),
    [anon_sym_short] = ACTIONS(1963),
    [anon_sym_LBRACK] = ACTIONS(1963),
    [anon_sym_static] = ACTIONS(1963),
    [anon_sym_register] = ACTIONS(1963),
    [anon_sym_inline] = ACTIONS(1963),
    [anon_sym___inline] = ACTIONS(1963),
    [anon_sym___inline__] = ACTIONS(1963),
    [anon_sym___forceinline] = ACTIONS(1963),
    [anon_sym_thread_local] = ACTIONS(1963),
    [anon_sym___thread] = ACTIONS(1963),
    [anon_sym_const] = ACTIONS(1963),
    [anon_sym_constexpr] = ACTIONS(1963),
    [anon_sym_volatile] = ACTIONS(1963),
    [anon_sym_restrict] = ACTIONS(1963),
    [anon_sym___restrict__] = ACTIONS(1963),
    [anon_sym__Atomic] = ACTIONS(1963),
    [anon_sym__Noreturn] = ACTIONS(1963),
    [anon_sym_noreturn] = ACTIONS(1963),
    [anon_sym_mutable] = ACTIONS(1963),
    [anon_sym_constinit] = ACTIONS(1963),
    [anon_sym_consteval] = ACTIONS(1963),
    [anon_sym_alignas] = ACTIONS(1963),
    [anon_sym__Alignas] = ACTIONS(1963),
    [sym_primitive_type] = ACTIONS(1963),
    [anon_sym_enum] = ACTIONS(1963),
    [anon_sym_class] = ACTIONS(1963),
    [anon_sym_struct] = ACTIONS(1963),
    [anon_sym_union] = ACTIONS(1963),
    [anon_sym_if] = ACTIONS(1963),
    [anon_sym_else] = ACTIONS(1963),
    [anon_sym_switch] = ACTIONS(1963),
    [anon_sym_case] = ACTIONS(1963),
    [anon_sym_default] = ACTIONS(1963),
    [anon_sym_while] = ACTIONS(1963),
    [anon_sym_do] = ACTIONS(1963),
    [anon_sym_for] = ACTIONS(1963),
    [anon_sym_return] = ACTIONS(1963),
    [anon_sym_break] = ACTIONS(1963),
    [anon_sym_continue] = ACTIONS(1963),
    [anon_sym_goto] = ACTIONS(1963),
    [anon_sym___try] = ACTIONS(1963),
    [anon_sym___leave] = ACTIONS(1963),
    [anon_sym_not] = ACTIONS(1963),
    [anon_sym_compl] = ACTIONS(1963),
    [anon_sym_DASH_DASH] = ACTIONS(1965),
    [anon_sym_PLUS_PLUS] = ACTIONS(1965),
    [anon_sym_sizeof] = ACTIONS(1963),
    [anon_sym___alignof__] = ACTIONS(1963),
    [anon_sym___alignof] = ACTIONS(1963),
    [anon_sym__alignof] = ACTIONS(1963),
    [anon_sym_alignof] = ACTIONS(1963),
    [anon_sym__Alignof] = ACTIONS(1963),
    [anon_sym_offsetof] = ACTIONS(1963),
    [anon_sym__Generic] = ACTIONS(1963),
    [anon_sym_asm] = ACTIONS(1963),
    [anon_sym___asm__] = ACTIONS(1963),
    [sym_number_literal] = ACTIONS(1965),
    [anon_sym_L_SQUOTE] = ACTIONS(1965),
    [anon_sym_u_SQUOTE] = ACTIONS(1965),
    [anon_sym_U_SQUOTE] = ACTIONS(1965),
    [anon_sym_u8_SQUOTE] = ACTIONS(1965),
    [anon_sym_SQUOTE] = ACTIONS(1965),
    [anon_sym_L_DQUOTE] = ACTIONS(1965),
    [anon_sym_u_DQUOTE] = ACTIONS(1965),
    [anon_sym_U_DQUOTE] = ACTIONS(1965),
    [anon_sym_u8_DQUOTE] = ACTIONS(1965),
    [anon_sym_DQUOTE] = ACTIONS(1965),
    [sym_true] = ACTIONS(1963),
    [sym_false] = ACTIONS(1963),
    [anon_sym_NULL] = ACTIONS(1963),
    [anon_sym_nullptr] = ACTIONS(1963),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1963),
    [anon_sym_decltype] = ACTIONS(1963),
    [sym_virtual] = ACTIONS(1963),
    [anon_sym_explicit] = ACTIONS(1963),
    [anon_sym_typename] = ACTIONS(1963),
    [anon_sym_template] = ACTIONS(1963),
    [anon_sym_operator] = ACTIONS(1963),
    [anon_sym_try] = ACTIONS(1963),
    [anon_sym_delete] = ACTIONS(1963),
    [anon_sym_throw] = ACTIONS(1963),
    [anon_sym_namespace] = ACTIONS(1963),
    [anon_sym_using] = ACTIONS(1963),
    [anon_sym_static_assert] = ACTIONS(1963),
    [anon_sym_concept] = ACTIONS(1963),
    [anon_sym_co_return] = ACTIONS(1963),
    [anon_sym_co_yield] = ACTIONS(1963),
    [anon_sym_catch] = ACTIONS(2547),
    [anon_sym_R_DQUOTE] = ACTIONS(1965),
    [anon_sym_LR_DQUOTE] = ACTIONS(1965),
    [anon_sym_uR_DQUOTE] = ACTIONS(1965),
    [anon_sym_UR_DQUOTE] = ACTIONS(1965),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1965),
    [anon_sym_co_await] = ACTIONS(1963),
    [anon_sym_new] = ACTIONS(1963),
    [anon_sym_requires] = ACTIONS(1963),
    [sym_this] = ACTIONS(1963),
    [anon_sym_discard] = ACTIONS(1963),
    [anon_sym_precise] = ACTIONS(1963),
    [anon_sym_shared] = ACTIONS(1963),
    [anon_sym_groupshared] = ACTIONS(1963),
    [anon_sym_uniform] = ACTIONS(1963),
    [anon_sym_row_major] = ACTIONS(1963),
    [anon_sym_column_major] = ACTIONS(1963),
    [anon_sym_globallycoherent] = ACTIONS(1963),
    [anon_sym_centroid] = ACTIONS(1963),
    [anon_sym_noperspective] = ACTIONS(1963),
    [anon_sym_nointerpolation] = ACTIONS(1963),
    [anon_sym_sample] = ACTIONS(1963),
    [anon_sym_linear] = ACTIONS(1963),
    [anon_sym_snorm] = ACTIONS(1963),
    [anon_sym_unorm] = ACTIONS(1963),
    [anon_sym_point] = ACTIONS(1963),
    [anon_sym_line] = ACTIONS(1963),
    [anon_sym_triangleadj] = ACTIONS(1963),
    [anon_sym_lineadj] = ACTIONS(1963),
    [anon_sym_triangle] = ACTIONS(1963),
    [anon_sym_cbuffer] = ACTIONS(1963),
  },
  [340] = {
    [sym_identifier] = ACTIONS(2549),
    [aux_sym_preproc_include_token1] = ACTIONS(2549),
    [aux_sym_preproc_def_token1] = ACTIONS(2549),
    [aux_sym_preproc_if_token1] = ACTIONS(2549),
    [aux_sym_preproc_if_token2] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2549),
    [aux_sym_preproc_else_token1] = ACTIONS(2549),
    [aux_sym_preproc_elif_token1] = ACTIONS(2549),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2549),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2549),
    [sym_preproc_directive] = ACTIONS(2549),
    [anon_sym_LPAREN2] = ACTIONS(2551),
    [anon_sym_BANG] = ACTIONS(2551),
    [anon_sym_TILDE] = ACTIONS(2551),
    [anon_sym_DASH] = ACTIONS(2549),
    [anon_sym_PLUS] = ACTIONS(2549),
    [anon_sym_STAR] = ACTIONS(2551),
    [anon_sym_AMP_AMP] = ACTIONS(2551),
    [anon_sym_AMP] = ACTIONS(2549),
    [anon_sym_SEMI] = ACTIONS(2551),
    [anon_sym___extension__] = ACTIONS(2549),
    [anon_sym_typedef] = ACTIONS(2549),
    [anon_sym_in] = ACTIONS(2549),
    [anon_sym_out] = ACTIONS(2549),
    [anon_sym_inout] = ACTIONS(2549),
    [anon_sym_extern] = ACTIONS(2549),
    [anon_sym___attribute__] = ACTIONS(2549),
    [anon_sym_COLON_COLON] = ACTIONS(2551),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2551),
    [anon_sym___declspec] = ACTIONS(2549),
    [anon_sym___based] = ACTIONS(2549),
    [anon_sym___cdecl] = ACTIONS(2549),
    [anon_sym___clrcall] = ACTIONS(2549),
    [anon_sym___stdcall] = ACTIONS(2549),
    [anon_sym___fastcall] = ACTIONS(2549),
    [anon_sym___thiscall] = ACTIONS(2549),
    [anon_sym___vectorcall] = ACTIONS(2549),
    [anon_sym_LBRACE] = ACTIONS(2551),
    [anon_sym_signed] = ACTIONS(2549),
    [anon_sym_unsigned] = ACTIONS(2549),
    [anon_sym_long] = ACTIONS(2549),
    [anon_sym_short] = ACTIONS(2549),
    [anon_sym_LBRACK] = ACTIONS(2549),
    [anon_sym_static] = ACTIONS(2549),
    [anon_sym_register] = ACTIONS(2549),
    [anon_sym_inline] = ACTIONS(2549),
    [anon_sym___inline] = ACTIONS(2549),
    [anon_sym___inline__] = ACTIONS(2549),
    [anon_sym___forceinline] = ACTIONS(2549),
    [anon_sym_thread_local] = ACTIONS(2549),
    [anon_sym___thread] = ACTIONS(2549),
    [anon_sym_const] = ACTIONS(2549),
    [anon_sym_constexpr] = ACTIONS(2549),
    [anon_sym_volatile] = ACTIONS(2549),
    [anon_sym_restrict] = ACTIONS(2549),
    [anon_sym___restrict__] = ACTIONS(2549),
    [anon_sym__Atomic] = ACTIONS(2549),
    [anon_sym__Noreturn] = ACTIONS(2549),
    [anon_sym_noreturn] = ACTIONS(2549),
    [anon_sym_mutable] = ACTIONS(2549),
    [anon_sym_constinit] = ACTIONS(2549),
    [anon_sym_consteval] = ACTIONS(2549),
    [anon_sym_alignas] = ACTIONS(2549),
    [anon_sym__Alignas] = ACTIONS(2549),
    [sym_primitive_type] = ACTIONS(2549),
    [anon_sym_enum] = ACTIONS(2549),
    [anon_sym_class] = ACTIONS(2549),
    [anon_sym_struct] = ACTIONS(2549),
    [anon_sym_union] = ACTIONS(2549),
    [anon_sym_if] = ACTIONS(2549),
    [anon_sym_switch] = ACTIONS(2549),
    [anon_sym_case] = ACTIONS(2549),
    [anon_sym_default] = ACTIONS(2549),
    [anon_sym_while] = ACTIONS(2549),
    [anon_sym_do] = ACTIONS(2549),
    [anon_sym_for] = ACTIONS(2549),
    [anon_sym_return] = ACTIONS(2549),
    [anon_sym_break] = ACTIONS(2549),
    [anon_sym_continue] = ACTIONS(2549),
    [anon_sym_goto] = ACTIONS(2549),
    [anon_sym___try] = ACTIONS(2549),
    [anon_sym___leave] = ACTIONS(2549),
    [anon_sym_not] = ACTIONS(2549),
    [anon_sym_compl] = ACTIONS(2549),
    [anon_sym_DASH_DASH] = ACTIONS(2551),
    [anon_sym_PLUS_PLUS] = ACTIONS(2551),
    [anon_sym_sizeof] = ACTIONS(2549),
    [anon_sym___alignof__] = ACTIONS(2549),
    [anon_sym___alignof] = ACTIONS(2549),
    [anon_sym__alignof] = ACTIONS(2549),
    [anon_sym_alignof] = ACTIONS(2549),
    [anon_sym__Alignof] = ACTIONS(2549),
    [anon_sym_offsetof] = ACTIONS(2549),
    [anon_sym__Generic] = ACTIONS(2549),
    [anon_sym_asm] = ACTIONS(2549),
    [anon_sym___asm__] = ACTIONS(2549),
    [sym_number_literal] = ACTIONS(2551),
    [anon_sym_L_SQUOTE] = ACTIONS(2551),
    [anon_sym_u_SQUOTE] = ACTIONS(2551),
    [anon_sym_U_SQUOTE] = ACTIONS(2551),
    [anon_sym_u8_SQUOTE] = ACTIONS(2551),
    [anon_sym_SQUOTE] = ACTIONS(2551),
    [anon_sym_L_DQUOTE] = ACTIONS(2551),
    [anon_sym_u_DQUOTE] = ACTIONS(2551),
    [anon_sym_U_DQUOTE] = ACTIONS(2551),
    [anon_sym_u8_DQUOTE] = ACTIONS(2551),
    [anon_sym_DQUOTE] = ACTIONS(2551),
    [sym_true] = ACTIONS(2549),
    [sym_false] = ACTIONS(2549),
    [anon_sym_NULL] = ACTIONS(2549),
    [anon_sym_nullptr] = ACTIONS(2549),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2549),
    [anon_sym_decltype] = ACTIONS(2549),
    [sym_virtual] = ACTIONS(2549),
    [anon_sym_explicit] = ACTIONS(2549),
    [anon_sym_typename] = ACTIONS(2549),
    [anon_sym_template] = ACTIONS(2549),
    [anon_sym_operator] = ACTIONS(2549),
    [anon_sym_try] = ACTIONS(2549),
    [anon_sym_delete] = ACTIONS(2549),
    [anon_sym_throw] = ACTIONS(2549),
    [anon_sym_namespace] = ACTIONS(2549),
    [anon_sym_using] = ACTIONS(2549),
    [anon_sym_static_assert] = ACTIONS(2549),
    [anon_sym_concept] = ACTIONS(2549),
    [anon_sym_co_return] = ACTIONS(2549),
    [anon_sym_co_yield] = ACTIONS(2549),
    [anon_sym_R_DQUOTE] = ACTIONS(2551),
    [anon_sym_LR_DQUOTE] = ACTIONS(2551),
    [anon_sym_uR_DQUOTE] = ACTIONS(2551),
    [anon_sym_UR_DQUOTE] = ACTIONS(2551),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2551),
    [anon_sym_co_await] = ACTIONS(2549),
    [anon_sym_new] = ACTIONS(2549),
    [anon_sym_requires] = ACTIONS(2549),
    [sym_this] = ACTIONS(2549),
    [anon_sym_discard] = ACTIONS(2549),
    [anon_sym_precise] = ACTIONS(2549),
    [anon_sym_shared] = ACTIONS(2549),
    [anon_sym_groupshared] = ACTIONS(2549),
    [anon_sym_uniform] = ACTIONS(2549),
    [anon_sym_row_major] = ACTIONS(2549),
    [anon_sym_column_major] = ACTIONS(2549),
    [anon_sym_globallycoherent] = ACTIONS(2549),
    [anon_sym_centroid] = ACTIONS(2549),
    [anon_sym_noperspective] = ACTIONS(2549),
    [anon_sym_nointerpolation] = ACTIONS(2549),
    [anon_sym_sample] = ACTIONS(2549),
    [anon_sym_linear] = ACTIONS(2549),
    [anon_sym_snorm] = ACTIONS(2549),
    [anon_sym_unorm] = ACTIONS(2549),
    [anon_sym_point] = ACTIONS(2549),
    [anon_sym_line] = ACTIONS(2549),
    [anon_sym_triangleadj] = ACTIONS(2549),
    [anon_sym_lineadj] = ACTIONS(2549),
    [anon_sym_triangle] = ACTIONS(2549),
    [anon_sym_cbuffer] = ACTIONS(2549),
  },
  [341] = {
    [sym_identifier] = ACTIONS(2553),
    [aux_sym_preproc_include_token1] = ACTIONS(2553),
    [aux_sym_preproc_def_token1] = ACTIONS(2553),
    [aux_sym_preproc_if_token1] = ACTIONS(2553),
    [aux_sym_preproc_if_token2] = ACTIONS(2553),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2553),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2553),
    [aux_sym_preproc_else_token1] = ACTIONS(2553),
    [aux_sym_preproc_elif_token1] = ACTIONS(2553),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2553),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2553),
    [sym_preproc_directive] = ACTIONS(2553),
    [anon_sym_LPAREN2] = ACTIONS(2555),
    [anon_sym_BANG] = ACTIONS(2555),
    [anon_sym_TILDE] = ACTIONS(2555),
    [anon_sym_DASH] = ACTIONS(2553),
    [anon_sym_PLUS] = ACTIONS(2553),
    [anon_sym_STAR] = ACTIONS(2555),
    [anon_sym_AMP_AMP] = ACTIONS(2555),
    [anon_sym_AMP] = ACTIONS(2553),
    [anon_sym_SEMI] = ACTIONS(2555),
    [anon_sym___extension__] = ACTIONS(2553),
    [anon_sym_typedef] = ACTIONS(2553),
    [anon_sym_in] = ACTIONS(2553),
    [anon_sym_out] = ACTIONS(2553),
    [anon_sym_inout] = ACTIONS(2553),
    [anon_sym_extern] = ACTIONS(2553),
    [anon_sym___attribute__] = ACTIONS(2553),
    [anon_sym_COLON_COLON] = ACTIONS(2555),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2555),
    [anon_sym___declspec] = ACTIONS(2553),
    [anon_sym___based] = ACTIONS(2553),
    [anon_sym___cdecl] = ACTIONS(2553),
    [anon_sym___clrcall] = ACTIONS(2553),
    [anon_sym___stdcall] = ACTIONS(2553),
    [anon_sym___fastcall] = ACTIONS(2553),
    [anon_sym___thiscall] = ACTIONS(2553),
    [anon_sym___vectorcall] = ACTIONS(2553),
    [anon_sym_LBRACE] = ACTIONS(2555),
    [anon_sym_signed] = ACTIONS(2553),
    [anon_sym_unsigned] = ACTIONS(2553),
    [anon_sym_long] = ACTIONS(2553),
    [anon_sym_short] = ACTIONS(2553),
    [anon_sym_LBRACK] = ACTIONS(2553),
    [anon_sym_static] = ACTIONS(2553),
    [anon_sym_register] = ACTIONS(2553),
    [anon_sym_inline] = ACTIONS(2553),
    [anon_sym___inline] = ACTIONS(2553),
    [anon_sym___inline__] = ACTIONS(2553),
    [anon_sym___forceinline] = ACTIONS(2553),
    [anon_sym_thread_local] = ACTIONS(2553),
    [anon_sym___thread] = ACTIONS(2553),
    [anon_sym_const] = ACTIONS(2553),
    [anon_sym_constexpr] = ACTIONS(2553),
    [anon_sym_volatile] = ACTIONS(2553),
    [anon_sym_restrict] = ACTIONS(2553),
    [anon_sym___restrict__] = ACTIONS(2553),
    [anon_sym__Atomic] = ACTIONS(2553),
    [anon_sym__Noreturn] = ACTIONS(2553),
    [anon_sym_noreturn] = ACTIONS(2553),
    [anon_sym_mutable] = ACTIONS(2553),
    [anon_sym_constinit] = ACTIONS(2553),
    [anon_sym_consteval] = ACTIONS(2553),
    [anon_sym_alignas] = ACTIONS(2553),
    [anon_sym__Alignas] = ACTIONS(2553),
    [sym_primitive_type] = ACTIONS(2553),
    [anon_sym_enum] = ACTIONS(2553),
    [anon_sym_class] = ACTIONS(2553),
    [anon_sym_struct] = ACTIONS(2553),
    [anon_sym_union] = ACTIONS(2553),
    [anon_sym_if] = ACTIONS(2553),
    [anon_sym_switch] = ACTIONS(2553),
    [anon_sym_case] = ACTIONS(2553),
    [anon_sym_default] = ACTIONS(2553),
    [anon_sym_while] = ACTIONS(2553),
    [anon_sym_do] = ACTIONS(2553),
    [anon_sym_for] = ACTIONS(2553),
    [anon_sym_return] = ACTIONS(2553),
    [anon_sym_break] = ACTIONS(2553),
    [anon_sym_continue] = ACTIONS(2553),
    [anon_sym_goto] = ACTIONS(2553),
    [anon_sym___try] = ACTIONS(2553),
    [anon_sym___leave] = ACTIONS(2553),
    [anon_sym_not] = ACTIONS(2553),
    [anon_sym_compl] = ACTIONS(2553),
    [anon_sym_DASH_DASH] = ACTIONS(2555),
    [anon_sym_PLUS_PLUS] = ACTIONS(2555),
    [anon_sym_sizeof] = ACTIONS(2553),
    [anon_sym___alignof__] = ACTIONS(2553),
    [anon_sym___alignof] = ACTIONS(2553),
    [anon_sym__alignof] = ACTIONS(2553),
    [anon_sym_alignof] = ACTIONS(2553),
    [anon_sym__Alignof] = ACTIONS(2553),
    [anon_sym_offsetof] = ACTIONS(2553),
    [anon_sym__Generic] = ACTIONS(2553),
    [anon_sym_asm] = ACTIONS(2553),
    [anon_sym___asm__] = ACTIONS(2553),
    [sym_number_literal] = ACTIONS(2555),
    [anon_sym_L_SQUOTE] = ACTIONS(2555),
    [anon_sym_u_SQUOTE] = ACTIONS(2555),
    [anon_sym_U_SQUOTE] = ACTIONS(2555),
    [anon_sym_u8_SQUOTE] = ACTIONS(2555),
    [anon_sym_SQUOTE] = ACTIONS(2555),
    [anon_sym_L_DQUOTE] = ACTIONS(2555),
    [anon_sym_u_DQUOTE] = ACTIONS(2555),
    [anon_sym_U_DQUOTE] = ACTIONS(2555),
    [anon_sym_u8_DQUOTE] = ACTIONS(2555),
    [anon_sym_DQUOTE] = ACTIONS(2555),
    [sym_true] = ACTIONS(2553),
    [sym_false] = ACTIONS(2553),
    [anon_sym_NULL] = ACTIONS(2553),
    [anon_sym_nullptr] = ACTIONS(2553),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2553),
    [anon_sym_decltype] = ACTIONS(2553),
    [sym_virtual] = ACTIONS(2553),
    [anon_sym_explicit] = ACTIONS(2553),
    [anon_sym_typename] = ACTIONS(2553),
    [anon_sym_template] = ACTIONS(2553),
    [anon_sym_operator] = ACTIONS(2553),
    [anon_sym_try] = ACTIONS(2553),
    [anon_sym_delete] = ACTIONS(2553),
    [anon_sym_throw] = ACTIONS(2553),
    [anon_sym_namespace] = ACTIONS(2553),
    [anon_sym_using] = ACTIONS(2553),
    [anon_sym_static_assert] = ACTIONS(2553),
    [anon_sym_concept] = ACTIONS(2553),
    [anon_sym_co_return] = ACTIONS(2553),
    [anon_sym_co_yield] = ACTIONS(2553),
    [anon_sym_R_DQUOTE] = ACTIONS(2555),
    [anon_sym_LR_DQUOTE] = ACTIONS(2555),
    [anon_sym_uR_DQUOTE] = ACTIONS(2555),
    [anon_sym_UR_DQUOTE] = ACTIONS(2555),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2555),
    [anon_sym_co_await] = ACTIONS(2553),
    [anon_sym_new] = ACTIONS(2553),
    [anon_sym_requires] = ACTIONS(2553),
    [sym_this] = ACTIONS(2553),
    [anon_sym_discard] = ACTIONS(2553),
    [anon_sym_precise] = ACTIONS(2553),
    [anon_sym_shared] = ACTIONS(2553),
    [anon_sym_groupshared] = ACTIONS(2553),
    [anon_sym_uniform] = ACTIONS(2553),
    [anon_sym_row_major] = ACTIONS(2553),
    [anon_sym_column_major] = ACTIONS(2553),
    [anon_sym_globallycoherent] = ACTIONS(2553),
    [anon_sym_centroid] = ACTIONS(2553),
    [anon_sym_noperspective] = ACTIONS(2553),
    [anon_sym_nointerpolation] = ACTIONS(2553),
    [anon_sym_sample] = ACTIONS(2553),
    [anon_sym_linear] = ACTIONS(2553),
    [anon_sym_snorm] = ACTIONS(2553),
    [anon_sym_unorm] = ACTIONS(2553),
    [anon_sym_point] = ACTIONS(2553),
    [anon_sym_line] = ACTIONS(2553),
    [anon_sym_triangleadj] = ACTIONS(2553),
    [anon_sym_lineadj] = ACTIONS(2553),
    [anon_sym_triangle] = ACTIONS(2553),
    [anon_sym_cbuffer] = ACTIONS(2553),
  },
  [342] = {
    [sym_identifier] = ACTIONS(2557),
    [aux_sym_preproc_include_token1] = ACTIONS(2557),
    [aux_sym_preproc_def_token1] = ACTIONS(2557),
    [aux_sym_preproc_if_token1] = ACTIONS(2557),
    [aux_sym_preproc_if_token2] = ACTIONS(2557),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2557),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2557),
    [aux_sym_preproc_else_token1] = ACTIONS(2557),
    [aux_sym_preproc_elif_token1] = ACTIONS(2557),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2557),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2557),
    [sym_preproc_directive] = ACTIONS(2557),
    [anon_sym_LPAREN2] = ACTIONS(2559),
    [anon_sym_BANG] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(2559),
    [anon_sym_DASH] = ACTIONS(2557),
    [anon_sym_PLUS] = ACTIONS(2557),
    [anon_sym_STAR] = ACTIONS(2559),
    [anon_sym_AMP_AMP] = ACTIONS(2559),
    [anon_sym_AMP] = ACTIONS(2557),
    [anon_sym_SEMI] = ACTIONS(2559),
    [anon_sym___extension__] = ACTIONS(2557),
    [anon_sym_typedef] = ACTIONS(2557),
    [anon_sym_in] = ACTIONS(2557),
    [anon_sym_out] = ACTIONS(2557),
    [anon_sym_inout] = ACTIONS(2557),
    [anon_sym_extern] = ACTIONS(2557),
    [anon_sym___attribute__] = ACTIONS(2557),
    [anon_sym_COLON_COLON] = ACTIONS(2559),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2559),
    [anon_sym___declspec] = ACTIONS(2557),
    [anon_sym___based] = ACTIONS(2557),
    [anon_sym___cdecl] = ACTIONS(2557),
    [anon_sym___clrcall] = ACTIONS(2557),
    [anon_sym___stdcall] = ACTIONS(2557),
    [anon_sym___fastcall] = ACTIONS(2557),
    [anon_sym___thiscall] = ACTIONS(2557),
    [anon_sym___vectorcall] = ACTIONS(2557),
    [anon_sym_LBRACE] = ACTIONS(2559),
    [anon_sym_signed] = ACTIONS(2557),
    [anon_sym_unsigned] = ACTIONS(2557),
    [anon_sym_long] = ACTIONS(2557),
    [anon_sym_short] = ACTIONS(2557),
    [anon_sym_LBRACK] = ACTIONS(2557),
    [anon_sym_static] = ACTIONS(2557),
    [anon_sym_register] = ACTIONS(2557),
    [anon_sym_inline] = ACTIONS(2557),
    [anon_sym___inline] = ACTIONS(2557),
    [anon_sym___inline__] = ACTIONS(2557),
    [anon_sym___forceinline] = ACTIONS(2557),
    [anon_sym_thread_local] = ACTIONS(2557),
    [anon_sym___thread] = ACTIONS(2557),
    [anon_sym_const] = ACTIONS(2557),
    [anon_sym_constexpr] = ACTIONS(2557),
    [anon_sym_volatile] = ACTIONS(2557),
    [anon_sym_restrict] = ACTIONS(2557),
    [anon_sym___restrict__] = ACTIONS(2557),
    [anon_sym__Atomic] = ACTIONS(2557),
    [anon_sym__Noreturn] = ACTIONS(2557),
    [anon_sym_noreturn] = ACTIONS(2557),
    [anon_sym_mutable] = ACTIONS(2557),
    [anon_sym_constinit] = ACTIONS(2557),
    [anon_sym_consteval] = ACTIONS(2557),
    [anon_sym_alignas] = ACTIONS(2557),
    [anon_sym__Alignas] = ACTIONS(2557),
    [sym_primitive_type] = ACTIONS(2557),
    [anon_sym_enum] = ACTIONS(2557),
    [anon_sym_class] = ACTIONS(2557),
    [anon_sym_struct] = ACTIONS(2557),
    [anon_sym_union] = ACTIONS(2557),
    [anon_sym_if] = ACTIONS(2557),
    [anon_sym_switch] = ACTIONS(2557),
    [anon_sym_case] = ACTIONS(2557),
    [anon_sym_default] = ACTIONS(2557),
    [anon_sym_while] = ACTIONS(2557),
    [anon_sym_do] = ACTIONS(2557),
    [anon_sym_for] = ACTIONS(2557),
    [anon_sym_return] = ACTIONS(2557),
    [anon_sym_break] = ACTIONS(2557),
    [anon_sym_continue] = ACTIONS(2557),
    [anon_sym_goto] = ACTIONS(2557),
    [anon_sym___try] = ACTIONS(2557),
    [anon_sym___leave] = ACTIONS(2557),
    [anon_sym_not] = ACTIONS(2557),
    [anon_sym_compl] = ACTIONS(2557),
    [anon_sym_DASH_DASH] = ACTIONS(2559),
    [anon_sym_PLUS_PLUS] = ACTIONS(2559),
    [anon_sym_sizeof] = ACTIONS(2557),
    [anon_sym___alignof__] = ACTIONS(2557),
    [anon_sym___alignof] = ACTIONS(2557),
    [anon_sym__alignof] = ACTIONS(2557),
    [anon_sym_alignof] = ACTIONS(2557),
    [anon_sym__Alignof] = ACTIONS(2557),
    [anon_sym_offsetof] = ACTIONS(2557),
    [anon_sym__Generic] = ACTIONS(2557),
    [anon_sym_asm] = ACTIONS(2557),
    [anon_sym___asm__] = ACTIONS(2557),
    [sym_number_literal] = ACTIONS(2559),
    [anon_sym_L_SQUOTE] = ACTIONS(2559),
    [anon_sym_u_SQUOTE] = ACTIONS(2559),
    [anon_sym_U_SQUOTE] = ACTIONS(2559),
    [anon_sym_u8_SQUOTE] = ACTIONS(2559),
    [anon_sym_SQUOTE] = ACTIONS(2559),
    [anon_sym_L_DQUOTE] = ACTIONS(2559),
    [anon_sym_u_DQUOTE] = ACTIONS(2559),
    [anon_sym_U_DQUOTE] = ACTIONS(2559),
    [anon_sym_u8_DQUOTE] = ACTIONS(2559),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_true] = ACTIONS(2557),
    [sym_false] = ACTIONS(2557),
    [anon_sym_NULL] = ACTIONS(2557),
    [anon_sym_nullptr] = ACTIONS(2557),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2557),
    [anon_sym_decltype] = ACTIONS(2557),
    [sym_virtual] = ACTIONS(2557),
    [anon_sym_explicit] = ACTIONS(2557),
    [anon_sym_typename] = ACTIONS(2557),
    [anon_sym_template] = ACTIONS(2557),
    [anon_sym_operator] = ACTIONS(2557),
    [anon_sym_try] = ACTIONS(2557),
    [anon_sym_delete] = ACTIONS(2557),
    [anon_sym_throw] = ACTIONS(2557),
    [anon_sym_namespace] = ACTIONS(2557),
    [anon_sym_using] = ACTIONS(2557),
    [anon_sym_static_assert] = ACTIONS(2557),
    [anon_sym_concept] = ACTIONS(2557),
    [anon_sym_co_return] = ACTIONS(2557),
    [anon_sym_co_yield] = ACTIONS(2557),
    [anon_sym_R_DQUOTE] = ACTIONS(2559),
    [anon_sym_LR_DQUOTE] = ACTIONS(2559),
    [anon_sym_uR_DQUOTE] = ACTIONS(2559),
    [anon_sym_UR_DQUOTE] = ACTIONS(2559),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2559),
    [anon_sym_co_await] = ACTIONS(2557),
    [anon_sym_new] = ACTIONS(2557),
    [anon_sym_requires] = ACTIONS(2557),
    [sym_this] = ACTIONS(2557),
    [anon_sym_discard] = ACTIONS(2557),
    [anon_sym_precise] = ACTIONS(2557),
    [anon_sym_shared] = ACTIONS(2557),
    [anon_sym_groupshared] = ACTIONS(2557),
    [anon_sym_uniform] = ACTIONS(2557),
    [anon_sym_row_major] = ACTIONS(2557),
    [anon_sym_column_major] = ACTIONS(2557),
    [anon_sym_globallycoherent] = ACTIONS(2557),
    [anon_sym_centroid] = ACTIONS(2557),
    [anon_sym_noperspective] = ACTIONS(2557),
    [anon_sym_nointerpolation] = ACTIONS(2557),
    [anon_sym_sample] = ACTIONS(2557),
    [anon_sym_linear] = ACTIONS(2557),
    [anon_sym_snorm] = ACTIONS(2557),
    [anon_sym_unorm] = ACTIONS(2557),
    [anon_sym_point] = ACTIONS(2557),
    [anon_sym_line] = ACTIONS(2557),
    [anon_sym_triangleadj] = ACTIONS(2557),
    [anon_sym_lineadj] = ACTIONS(2557),
    [anon_sym_triangle] = ACTIONS(2557),
    [anon_sym_cbuffer] = ACTIONS(2557),
  },
  [343] = {
    [sym_identifier] = ACTIONS(2561),
    [aux_sym_preproc_include_token1] = ACTIONS(2561),
    [aux_sym_preproc_def_token1] = ACTIONS(2561),
    [aux_sym_preproc_if_token1] = ACTIONS(2561),
    [aux_sym_preproc_if_token2] = ACTIONS(2561),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2561),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2561),
    [aux_sym_preproc_else_token1] = ACTIONS(2561),
    [aux_sym_preproc_elif_token1] = ACTIONS(2561),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2561),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2561),
    [sym_preproc_directive] = ACTIONS(2561),
    [anon_sym_LPAREN2] = ACTIONS(2563),
    [anon_sym_BANG] = ACTIONS(2563),
    [anon_sym_TILDE] = ACTIONS(2563),
    [anon_sym_DASH] = ACTIONS(2561),
    [anon_sym_PLUS] = ACTIONS(2561),
    [anon_sym_STAR] = ACTIONS(2563),
    [anon_sym_AMP_AMP] = ACTIONS(2563),
    [anon_sym_AMP] = ACTIONS(2561),
    [anon_sym_SEMI] = ACTIONS(2563),
    [anon_sym___extension__] = ACTIONS(2561),
    [anon_sym_typedef] = ACTIONS(2561),
    [anon_sym_in] = ACTIONS(2561),
    [anon_sym_out] = ACTIONS(2561),
    [anon_sym_inout] = ACTIONS(2561),
    [anon_sym_extern] = ACTIONS(2561),
    [anon_sym___attribute__] = ACTIONS(2561),
    [anon_sym_COLON_COLON] = ACTIONS(2563),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2563),
    [anon_sym___declspec] = ACTIONS(2561),
    [anon_sym___based] = ACTIONS(2561),
    [anon_sym___cdecl] = ACTIONS(2561),
    [anon_sym___clrcall] = ACTIONS(2561),
    [anon_sym___stdcall] = ACTIONS(2561),
    [anon_sym___fastcall] = ACTIONS(2561),
    [anon_sym___thiscall] = ACTIONS(2561),
    [anon_sym___vectorcall] = ACTIONS(2561),
    [anon_sym_LBRACE] = ACTIONS(2563),
    [anon_sym_signed] = ACTIONS(2561),
    [anon_sym_unsigned] = ACTIONS(2561),
    [anon_sym_long] = ACTIONS(2561),
    [anon_sym_short] = ACTIONS(2561),
    [anon_sym_LBRACK] = ACTIONS(2561),
    [anon_sym_static] = ACTIONS(2561),
    [anon_sym_register] = ACTIONS(2561),
    [anon_sym_inline] = ACTIONS(2561),
    [anon_sym___inline] = ACTIONS(2561),
    [anon_sym___inline__] = ACTIONS(2561),
    [anon_sym___forceinline] = ACTIONS(2561),
    [anon_sym_thread_local] = ACTIONS(2561),
    [anon_sym___thread] = ACTIONS(2561),
    [anon_sym_const] = ACTIONS(2561),
    [anon_sym_constexpr] = ACTIONS(2561),
    [anon_sym_volatile] = ACTIONS(2561),
    [anon_sym_restrict] = ACTIONS(2561),
    [anon_sym___restrict__] = ACTIONS(2561),
    [anon_sym__Atomic] = ACTIONS(2561),
    [anon_sym__Noreturn] = ACTIONS(2561),
    [anon_sym_noreturn] = ACTIONS(2561),
    [anon_sym_mutable] = ACTIONS(2561),
    [anon_sym_constinit] = ACTIONS(2561),
    [anon_sym_consteval] = ACTIONS(2561),
    [anon_sym_alignas] = ACTIONS(2561),
    [anon_sym__Alignas] = ACTIONS(2561),
    [sym_primitive_type] = ACTIONS(2561),
    [anon_sym_enum] = ACTIONS(2561),
    [anon_sym_class] = ACTIONS(2561),
    [anon_sym_struct] = ACTIONS(2561),
    [anon_sym_union] = ACTIONS(2561),
    [anon_sym_if] = ACTIONS(2561),
    [anon_sym_switch] = ACTIONS(2561),
    [anon_sym_case] = ACTIONS(2561),
    [anon_sym_default] = ACTIONS(2561),
    [anon_sym_while] = ACTIONS(2561),
    [anon_sym_do] = ACTIONS(2561),
    [anon_sym_for] = ACTIONS(2561),
    [anon_sym_return] = ACTIONS(2561),
    [anon_sym_break] = ACTIONS(2561),
    [anon_sym_continue] = ACTIONS(2561),
    [anon_sym_goto] = ACTIONS(2561),
    [anon_sym___try] = ACTIONS(2561),
    [anon_sym___leave] = ACTIONS(2561),
    [anon_sym_not] = ACTIONS(2561),
    [anon_sym_compl] = ACTIONS(2561),
    [anon_sym_DASH_DASH] = ACTIONS(2563),
    [anon_sym_PLUS_PLUS] = ACTIONS(2563),
    [anon_sym_sizeof] = ACTIONS(2561),
    [anon_sym___alignof__] = ACTIONS(2561),
    [anon_sym___alignof] = ACTIONS(2561),
    [anon_sym__alignof] = ACTIONS(2561),
    [anon_sym_alignof] = ACTIONS(2561),
    [anon_sym__Alignof] = ACTIONS(2561),
    [anon_sym_offsetof] = ACTIONS(2561),
    [anon_sym__Generic] = ACTIONS(2561),
    [anon_sym_asm] = ACTIONS(2561),
    [anon_sym___asm__] = ACTIONS(2561),
    [sym_number_literal] = ACTIONS(2563),
    [anon_sym_L_SQUOTE] = ACTIONS(2563),
    [anon_sym_u_SQUOTE] = ACTIONS(2563),
    [anon_sym_U_SQUOTE] = ACTIONS(2563),
    [anon_sym_u8_SQUOTE] = ACTIONS(2563),
    [anon_sym_SQUOTE] = ACTIONS(2563),
    [anon_sym_L_DQUOTE] = ACTIONS(2563),
    [anon_sym_u_DQUOTE] = ACTIONS(2563),
    [anon_sym_U_DQUOTE] = ACTIONS(2563),
    [anon_sym_u8_DQUOTE] = ACTIONS(2563),
    [anon_sym_DQUOTE] = ACTIONS(2563),
    [sym_true] = ACTIONS(2561),
    [sym_false] = ACTIONS(2561),
    [anon_sym_NULL] = ACTIONS(2561),
    [anon_sym_nullptr] = ACTIONS(2561),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2561),
    [anon_sym_decltype] = ACTIONS(2561),
    [sym_virtual] = ACTIONS(2561),
    [anon_sym_explicit] = ACTIONS(2561),
    [anon_sym_typename] = ACTIONS(2561),
    [anon_sym_template] = ACTIONS(2561),
    [anon_sym_operator] = ACTIONS(2561),
    [anon_sym_try] = ACTIONS(2561),
    [anon_sym_delete] = ACTIONS(2561),
    [anon_sym_throw] = ACTIONS(2561),
    [anon_sym_namespace] = ACTIONS(2561),
    [anon_sym_using] = ACTIONS(2561),
    [anon_sym_static_assert] = ACTIONS(2561),
    [anon_sym_concept] = ACTIONS(2561),
    [anon_sym_co_return] = ACTIONS(2561),
    [anon_sym_co_yield] = ACTIONS(2561),
    [anon_sym_R_DQUOTE] = ACTIONS(2563),
    [anon_sym_LR_DQUOTE] = ACTIONS(2563),
    [anon_sym_uR_DQUOTE] = ACTIONS(2563),
    [anon_sym_UR_DQUOTE] = ACTIONS(2563),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2563),
    [anon_sym_co_await] = ACTIONS(2561),
    [anon_sym_new] = ACTIONS(2561),
    [anon_sym_requires] = ACTIONS(2561),
    [sym_this] = ACTIONS(2561),
    [anon_sym_discard] = ACTIONS(2561),
    [anon_sym_precise] = ACTIONS(2561),
    [anon_sym_shared] = ACTIONS(2561),
    [anon_sym_groupshared] = ACTIONS(2561),
    [anon_sym_uniform] = ACTIONS(2561),
    [anon_sym_row_major] = ACTIONS(2561),
    [anon_sym_column_major] = ACTIONS(2561),
    [anon_sym_globallycoherent] = ACTIONS(2561),
    [anon_sym_centroid] = ACTIONS(2561),
    [anon_sym_noperspective] = ACTIONS(2561),
    [anon_sym_nointerpolation] = ACTIONS(2561),
    [anon_sym_sample] = ACTIONS(2561),
    [anon_sym_linear] = ACTIONS(2561),
    [anon_sym_snorm] = ACTIONS(2561),
    [anon_sym_unorm] = ACTIONS(2561),
    [anon_sym_point] = ACTIONS(2561),
    [anon_sym_line] = ACTIONS(2561),
    [anon_sym_triangleadj] = ACTIONS(2561),
    [anon_sym_lineadj] = ACTIONS(2561),
    [anon_sym_triangle] = ACTIONS(2561),
    [anon_sym_cbuffer] = ACTIONS(2561),
  },
  [344] = {
    [sym_identifier] = ACTIONS(2565),
    [aux_sym_preproc_include_token1] = ACTIONS(2565),
    [aux_sym_preproc_def_token1] = ACTIONS(2565),
    [aux_sym_preproc_if_token1] = ACTIONS(2565),
    [aux_sym_preproc_if_token2] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2565),
    [aux_sym_preproc_else_token1] = ACTIONS(2565),
    [aux_sym_preproc_elif_token1] = ACTIONS(2565),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2565),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2565),
    [sym_preproc_directive] = ACTIONS(2565),
    [anon_sym_LPAREN2] = ACTIONS(2567),
    [anon_sym_BANG] = ACTIONS(2567),
    [anon_sym_TILDE] = ACTIONS(2567),
    [anon_sym_DASH] = ACTIONS(2565),
    [anon_sym_PLUS] = ACTIONS(2565),
    [anon_sym_STAR] = ACTIONS(2567),
    [anon_sym_AMP_AMP] = ACTIONS(2567),
    [anon_sym_AMP] = ACTIONS(2565),
    [anon_sym_SEMI] = ACTIONS(2567),
    [anon_sym___extension__] = ACTIONS(2565),
    [anon_sym_typedef] = ACTIONS(2565),
    [anon_sym_in] = ACTIONS(2565),
    [anon_sym_out] = ACTIONS(2565),
    [anon_sym_inout] = ACTIONS(2565),
    [anon_sym_extern] = ACTIONS(2565),
    [anon_sym___attribute__] = ACTIONS(2565),
    [anon_sym_COLON_COLON] = ACTIONS(2567),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2567),
    [anon_sym___declspec] = ACTIONS(2565),
    [anon_sym___based] = ACTIONS(2565),
    [anon_sym___cdecl] = ACTIONS(2565),
    [anon_sym___clrcall] = ACTIONS(2565),
    [anon_sym___stdcall] = ACTIONS(2565),
    [anon_sym___fastcall] = ACTIONS(2565),
    [anon_sym___thiscall] = ACTIONS(2565),
    [anon_sym___vectorcall] = ACTIONS(2565),
    [anon_sym_LBRACE] = ACTIONS(2567),
    [anon_sym_signed] = ACTIONS(2565),
    [anon_sym_unsigned] = ACTIONS(2565),
    [anon_sym_long] = ACTIONS(2565),
    [anon_sym_short] = ACTIONS(2565),
    [anon_sym_LBRACK] = ACTIONS(2565),
    [anon_sym_static] = ACTIONS(2565),
    [anon_sym_register] = ACTIONS(2565),
    [anon_sym_inline] = ACTIONS(2565),
    [anon_sym___inline] = ACTIONS(2565),
    [anon_sym___inline__] = ACTIONS(2565),
    [anon_sym___forceinline] = ACTIONS(2565),
    [anon_sym_thread_local] = ACTIONS(2565),
    [anon_sym___thread] = ACTIONS(2565),
    [anon_sym_const] = ACTIONS(2565),
    [anon_sym_constexpr] = ACTIONS(2565),
    [anon_sym_volatile] = ACTIONS(2565),
    [anon_sym_restrict] = ACTIONS(2565),
    [anon_sym___restrict__] = ACTIONS(2565),
    [anon_sym__Atomic] = ACTIONS(2565),
    [anon_sym__Noreturn] = ACTIONS(2565),
    [anon_sym_noreturn] = ACTIONS(2565),
    [anon_sym_mutable] = ACTIONS(2565),
    [anon_sym_constinit] = ACTIONS(2565),
    [anon_sym_consteval] = ACTIONS(2565),
    [anon_sym_alignas] = ACTIONS(2565),
    [anon_sym__Alignas] = ACTIONS(2565),
    [sym_primitive_type] = ACTIONS(2565),
    [anon_sym_enum] = ACTIONS(2565),
    [anon_sym_class] = ACTIONS(2565),
    [anon_sym_struct] = ACTIONS(2565),
    [anon_sym_union] = ACTIONS(2565),
    [anon_sym_if] = ACTIONS(2565),
    [anon_sym_switch] = ACTIONS(2565),
    [anon_sym_case] = ACTIONS(2565),
    [anon_sym_default] = ACTIONS(2565),
    [anon_sym_while] = ACTIONS(2565),
    [anon_sym_do] = ACTIONS(2565),
    [anon_sym_for] = ACTIONS(2565),
    [anon_sym_return] = ACTIONS(2565),
    [anon_sym_break] = ACTIONS(2565),
    [anon_sym_continue] = ACTIONS(2565),
    [anon_sym_goto] = ACTIONS(2565),
    [anon_sym___try] = ACTIONS(2565),
    [anon_sym___leave] = ACTIONS(2565),
    [anon_sym_not] = ACTIONS(2565),
    [anon_sym_compl] = ACTIONS(2565),
    [anon_sym_DASH_DASH] = ACTIONS(2567),
    [anon_sym_PLUS_PLUS] = ACTIONS(2567),
    [anon_sym_sizeof] = ACTIONS(2565),
    [anon_sym___alignof__] = ACTIONS(2565),
    [anon_sym___alignof] = ACTIONS(2565),
    [anon_sym__alignof] = ACTIONS(2565),
    [anon_sym_alignof] = ACTIONS(2565),
    [anon_sym__Alignof] = ACTIONS(2565),
    [anon_sym_offsetof] = ACTIONS(2565),
    [anon_sym__Generic] = ACTIONS(2565),
    [anon_sym_asm] = ACTIONS(2565),
    [anon_sym___asm__] = ACTIONS(2565),
    [sym_number_literal] = ACTIONS(2567),
    [anon_sym_L_SQUOTE] = ACTIONS(2567),
    [anon_sym_u_SQUOTE] = ACTIONS(2567),
    [anon_sym_U_SQUOTE] = ACTIONS(2567),
    [anon_sym_u8_SQUOTE] = ACTIONS(2567),
    [anon_sym_SQUOTE] = ACTIONS(2567),
    [anon_sym_L_DQUOTE] = ACTIONS(2567),
    [anon_sym_u_DQUOTE] = ACTIONS(2567),
    [anon_sym_U_DQUOTE] = ACTIONS(2567),
    [anon_sym_u8_DQUOTE] = ACTIONS(2567),
    [anon_sym_DQUOTE] = ACTIONS(2567),
    [sym_true] = ACTIONS(2565),
    [sym_false] = ACTIONS(2565),
    [anon_sym_NULL] = ACTIONS(2565),
    [anon_sym_nullptr] = ACTIONS(2565),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2565),
    [anon_sym_decltype] = ACTIONS(2565),
    [sym_virtual] = ACTIONS(2565),
    [anon_sym_explicit] = ACTIONS(2565),
    [anon_sym_typename] = ACTIONS(2565),
    [anon_sym_template] = ACTIONS(2565),
    [anon_sym_operator] = ACTIONS(2565),
    [anon_sym_try] = ACTIONS(2565),
    [anon_sym_delete] = ACTIONS(2565),
    [anon_sym_throw] = ACTIONS(2565),
    [anon_sym_namespace] = ACTIONS(2565),
    [anon_sym_using] = ACTIONS(2565),
    [anon_sym_static_assert] = ACTIONS(2565),
    [anon_sym_concept] = ACTIONS(2565),
    [anon_sym_co_return] = ACTIONS(2565),
    [anon_sym_co_yield] = ACTIONS(2565),
    [anon_sym_R_DQUOTE] = ACTIONS(2567),
    [anon_sym_LR_DQUOTE] = ACTIONS(2567),
    [anon_sym_uR_DQUOTE] = ACTIONS(2567),
    [anon_sym_UR_DQUOTE] = ACTIONS(2567),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2567),
    [anon_sym_co_await] = ACTIONS(2565),
    [anon_sym_new] = ACTIONS(2565),
    [anon_sym_requires] = ACTIONS(2565),
    [sym_this] = ACTIONS(2565),
    [anon_sym_discard] = ACTIONS(2565),
    [anon_sym_precise] = ACTIONS(2565),
    [anon_sym_shared] = ACTIONS(2565),
    [anon_sym_groupshared] = ACTIONS(2565),
    [anon_sym_uniform] = ACTIONS(2565),
    [anon_sym_row_major] = ACTIONS(2565),
    [anon_sym_column_major] = ACTIONS(2565),
    [anon_sym_globallycoherent] = ACTIONS(2565),
    [anon_sym_centroid] = ACTIONS(2565),
    [anon_sym_noperspective] = ACTIONS(2565),
    [anon_sym_nointerpolation] = ACTIONS(2565),
    [anon_sym_sample] = ACTIONS(2565),
    [anon_sym_linear] = ACTIONS(2565),
    [anon_sym_snorm] = ACTIONS(2565),
    [anon_sym_unorm] = ACTIONS(2565),
    [anon_sym_point] = ACTIONS(2565),
    [anon_sym_line] = ACTIONS(2565),
    [anon_sym_triangleadj] = ACTIONS(2565),
    [anon_sym_lineadj] = ACTIONS(2565),
    [anon_sym_triangle] = ACTIONS(2565),
    [anon_sym_cbuffer] = ACTIONS(2565),
  },
  [345] = {
    [sym_identifier] = ACTIONS(2569),
    [aux_sym_preproc_include_token1] = ACTIONS(2569),
    [aux_sym_preproc_def_token1] = ACTIONS(2569),
    [aux_sym_preproc_if_token1] = ACTIONS(2569),
    [aux_sym_preproc_if_token2] = ACTIONS(2569),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2569),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2569),
    [aux_sym_preproc_else_token1] = ACTIONS(2569),
    [aux_sym_preproc_elif_token1] = ACTIONS(2569),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2569),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2569),
    [sym_preproc_directive] = ACTIONS(2569),
    [anon_sym_LPAREN2] = ACTIONS(2571),
    [anon_sym_BANG] = ACTIONS(2571),
    [anon_sym_TILDE] = ACTIONS(2571),
    [anon_sym_DASH] = ACTIONS(2569),
    [anon_sym_PLUS] = ACTIONS(2569),
    [anon_sym_STAR] = ACTIONS(2571),
    [anon_sym_AMP_AMP] = ACTIONS(2571),
    [anon_sym_AMP] = ACTIONS(2569),
    [anon_sym_SEMI] = ACTIONS(2571),
    [anon_sym___extension__] = ACTIONS(2569),
    [anon_sym_typedef] = ACTIONS(2569),
    [anon_sym_in] = ACTIONS(2569),
    [anon_sym_out] = ACTIONS(2569),
    [anon_sym_inout] = ACTIONS(2569),
    [anon_sym_extern] = ACTIONS(2569),
    [anon_sym___attribute__] = ACTIONS(2569),
    [anon_sym_COLON_COLON] = ACTIONS(2571),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2571),
    [anon_sym___declspec] = ACTIONS(2569),
    [anon_sym___based] = ACTIONS(2569),
    [anon_sym___cdecl] = ACTIONS(2569),
    [anon_sym___clrcall] = ACTIONS(2569),
    [anon_sym___stdcall] = ACTIONS(2569),
    [anon_sym___fastcall] = ACTIONS(2569),
    [anon_sym___thiscall] = ACTIONS(2569),
    [anon_sym___vectorcall] = ACTIONS(2569),
    [anon_sym_LBRACE] = ACTIONS(2571),
    [anon_sym_signed] = ACTIONS(2569),
    [anon_sym_unsigned] = ACTIONS(2569),
    [anon_sym_long] = ACTIONS(2569),
    [anon_sym_short] = ACTIONS(2569),
    [anon_sym_LBRACK] = ACTIONS(2569),
    [anon_sym_static] = ACTIONS(2569),
    [anon_sym_register] = ACTIONS(2569),
    [anon_sym_inline] = ACTIONS(2569),
    [anon_sym___inline] = ACTIONS(2569),
    [anon_sym___inline__] = ACTIONS(2569),
    [anon_sym___forceinline] = ACTIONS(2569),
    [anon_sym_thread_local] = ACTIONS(2569),
    [anon_sym___thread] = ACTIONS(2569),
    [anon_sym_const] = ACTIONS(2569),
    [anon_sym_constexpr] = ACTIONS(2569),
    [anon_sym_volatile] = ACTIONS(2569),
    [anon_sym_restrict] = ACTIONS(2569),
    [anon_sym___restrict__] = ACTIONS(2569),
    [anon_sym__Atomic] = ACTIONS(2569),
    [anon_sym__Noreturn] = ACTIONS(2569),
    [anon_sym_noreturn] = ACTIONS(2569),
    [anon_sym_mutable] = ACTIONS(2569),
    [anon_sym_constinit] = ACTIONS(2569),
    [anon_sym_consteval] = ACTIONS(2569),
    [anon_sym_alignas] = ACTIONS(2569),
    [anon_sym__Alignas] = ACTIONS(2569),
    [sym_primitive_type] = ACTIONS(2569),
    [anon_sym_enum] = ACTIONS(2569),
    [anon_sym_class] = ACTIONS(2569),
    [anon_sym_struct] = ACTIONS(2569),
    [anon_sym_union] = ACTIONS(2569),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_switch] = ACTIONS(2569),
    [anon_sym_case] = ACTIONS(2569),
    [anon_sym_default] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2569),
    [anon_sym_do] = ACTIONS(2569),
    [anon_sym_for] = ACTIONS(2569),
    [anon_sym_return] = ACTIONS(2569),
    [anon_sym_break] = ACTIONS(2569),
    [anon_sym_continue] = ACTIONS(2569),
    [anon_sym_goto] = ACTIONS(2569),
    [anon_sym___try] = ACTIONS(2569),
    [anon_sym___leave] = ACTIONS(2569),
    [anon_sym_not] = ACTIONS(2569),
    [anon_sym_compl] = ACTIONS(2569),
    [anon_sym_DASH_DASH] = ACTIONS(2571),
    [anon_sym_PLUS_PLUS] = ACTIONS(2571),
    [anon_sym_sizeof] = ACTIONS(2569),
    [anon_sym___alignof__] = ACTIONS(2569),
    [anon_sym___alignof] = ACTIONS(2569),
    [anon_sym__alignof] = ACTIONS(2569),
    [anon_sym_alignof] = ACTIONS(2569),
    [anon_sym__Alignof] = ACTIONS(2569),
    [anon_sym_offsetof] = ACTIONS(2569),
    [anon_sym__Generic] = ACTIONS(2569),
    [anon_sym_asm] = ACTIONS(2569),
    [anon_sym___asm__] = ACTIONS(2569),
    [sym_number_literal] = ACTIONS(2571),
    [anon_sym_L_SQUOTE] = ACTIONS(2571),
    [anon_sym_u_SQUOTE] = ACTIONS(2571),
    [anon_sym_U_SQUOTE] = ACTIONS(2571),
    [anon_sym_u8_SQUOTE] = ACTIONS(2571),
    [anon_sym_SQUOTE] = ACTIONS(2571),
    [anon_sym_L_DQUOTE] = ACTIONS(2571),
    [anon_sym_u_DQUOTE] = ACTIONS(2571),
    [anon_sym_U_DQUOTE] = ACTIONS(2571),
    [anon_sym_u8_DQUOTE] = ACTIONS(2571),
    [anon_sym_DQUOTE] = ACTIONS(2571),
    [sym_true] = ACTIONS(2569),
    [sym_false] = ACTIONS(2569),
    [anon_sym_NULL] = ACTIONS(2569),
    [anon_sym_nullptr] = ACTIONS(2569),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2569),
    [anon_sym_decltype] = ACTIONS(2569),
    [sym_virtual] = ACTIONS(2569),
    [anon_sym_explicit] = ACTIONS(2569),
    [anon_sym_typename] = ACTIONS(2569),
    [anon_sym_template] = ACTIONS(2569),
    [anon_sym_operator] = ACTIONS(2569),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_delete] = ACTIONS(2569),
    [anon_sym_throw] = ACTIONS(2569),
    [anon_sym_namespace] = ACTIONS(2569),
    [anon_sym_using] = ACTIONS(2569),
    [anon_sym_static_assert] = ACTIONS(2569),
    [anon_sym_concept] = ACTIONS(2569),
    [anon_sym_co_return] = ACTIONS(2569),
    [anon_sym_co_yield] = ACTIONS(2569),
    [anon_sym_R_DQUOTE] = ACTIONS(2571),
    [anon_sym_LR_DQUOTE] = ACTIONS(2571),
    [anon_sym_uR_DQUOTE] = ACTIONS(2571),
    [anon_sym_UR_DQUOTE] = ACTIONS(2571),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2571),
    [anon_sym_co_await] = ACTIONS(2569),
    [anon_sym_new] = ACTIONS(2569),
    [anon_sym_requires] = ACTIONS(2569),
    [sym_this] = ACTIONS(2569),
    [anon_sym_discard] = ACTIONS(2569),
    [anon_sym_precise] = ACTIONS(2569),
    [anon_sym_shared] = ACTIONS(2569),
    [anon_sym_groupshared] = ACTIONS(2569),
    [anon_sym_uniform] = ACTIONS(2569),
    [anon_sym_row_major] = ACTIONS(2569),
    [anon_sym_column_major] = ACTIONS(2569),
    [anon_sym_globallycoherent] = ACTIONS(2569),
    [anon_sym_centroid] = ACTIONS(2569),
    [anon_sym_noperspective] = ACTIONS(2569),
    [anon_sym_nointerpolation] = ACTIONS(2569),
    [anon_sym_sample] = ACTIONS(2569),
    [anon_sym_linear] = ACTIONS(2569),
    [anon_sym_snorm] = ACTIONS(2569),
    [anon_sym_unorm] = ACTIONS(2569),
    [anon_sym_point] = ACTIONS(2569),
    [anon_sym_line] = ACTIONS(2569),
    [anon_sym_triangleadj] = ACTIONS(2569),
    [anon_sym_lineadj] = ACTIONS(2569),
    [anon_sym_triangle] = ACTIONS(2569),
    [anon_sym_cbuffer] = ACTIONS(2569),
  },
  [346] = {
    [sym_identifier] = ACTIONS(2573),
    [aux_sym_preproc_include_token1] = ACTIONS(2573),
    [aux_sym_preproc_def_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token2] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2573),
    [aux_sym_preproc_else_token1] = ACTIONS(2573),
    [aux_sym_preproc_elif_token1] = ACTIONS(2573),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2573),
    [sym_preproc_directive] = ACTIONS(2573),
    [anon_sym_LPAREN2] = ACTIONS(2575),
    [anon_sym_BANG] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(2575),
    [anon_sym_DASH] = ACTIONS(2573),
    [anon_sym_PLUS] = ACTIONS(2573),
    [anon_sym_STAR] = ACTIONS(2575),
    [anon_sym_AMP_AMP] = ACTIONS(2575),
    [anon_sym_AMP] = ACTIONS(2573),
    [anon_sym_SEMI] = ACTIONS(2575),
    [anon_sym___extension__] = ACTIONS(2573),
    [anon_sym_typedef] = ACTIONS(2573),
    [anon_sym_in] = ACTIONS(2573),
    [anon_sym_out] = ACTIONS(2573),
    [anon_sym_inout] = ACTIONS(2573),
    [anon_sym_extern] = ACTIONS(2573),
    [anon_sym___attribute__] = ACTIONS(2573),
    [anon_sym_COLON_COLON] = ACTIONS(2575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2575),
    [anon_sym___declspec] = ACTIONS(2573),
    [anon_sym___based] = ACTIONS(2573),
    [anon_sym___cdecl] = ACTIONS(2573),
    [anon_sym___clrcall] = ACTIONS(2573),
    [anon_sym___stdcall] = ACTIONS(2573),
    [anon_sym___fastcall] = ACTIONS(2573),
    [anon_sym___thiscall] = ACTIONS(2573),
    [anon_sym___vectorcall] = ACTIONS(2573),
    [anon_sym_LBRACE] = ACTIONS(2575),
    [anon_sym_signed] = ACTIONS(2573),
    [anon_sym_unsigned] = ACTIONS(2573),
    [anon_sym_long] = ACTIONS(2573),
    [anon_sym_short] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2573),
    [anon_sym_static] = ACTIONS(2573),
    [anon_sym_register] = ACTIONS(2573),
    [anon_sym_inline] = ACTIONS(2573),
    [anon_sym___inline] = ACTIONS(2573),
    [anon_sym___inline__] = ACTIONS(2573),
    [anon_sym___forceinline] = ACTIONS(2573),
    [anon_sym_thread_local] = ACTIONS(2573),
    [anon_sym___thread] = ACTIONS(2573),
    [anon_sym_const] = ACTIONS(2573),
    [anon_sym_constexpr] = ACTIONS(2573),
    [anon_sym_volatile] = ACTIONS(2573),
    [anon_sym_restrict] = ACTIONS(2573),
    [anon_sym___restrict__] = ACTIONS(2573),
    [anon_sym__Atomic] = ACTIONS(2573),
    [anon_sym__Noreturn] = ACTIONS(2573),
    [anon_sym_noreturn] = ACTIONS(2573),
    [anon_sym_mutable] = ACTIONS(2573),
    [anon_sym_constinit] = ACTIONS(2573),
    [anon_sym_consteval] = ACTIONS(2573),
    [anon_sym_alignas] = ACTIONS(2573),
    [anon_sym__Alignas] = ACTIONS(2573),
    [sym_primitive_type] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_class] = ACTIONS(2573),
    [anon_sym_struct] = ACTIONS(2573),
    [anon_sym_union] = ACTIONS(2573),
    [anon_sym_if] = ACTIONS(2573),
    [anon_sym_switch] = ACTIONS(2573),
    [anon_sym_case] = ACTIONS(2573),
    [anon_sym_default] = ACTIONS(2573),
    [anon_sym_while] = ACTIONS(2573),
    [anon_sym_do] = ACTIONS(2573),
    [anon_sym_for] = ACTIONS(2573),
    [anon_sym_return] = ACTIONS(2573),
    [anon_sym_break] = ACTIONS(2573),
    [anon_sym_continue] = ACTIONS(2573),
    [anon_sym_goto] = ACTIONS(2573),
    [anon_sym___try] = ACTIONS(2573),
    [anon_sym___leave] = ACTIONS(2573),
    [anon_sym_not] = ACTIONS(2573),
    [anon_sym_compl] = ACTIONS(2573),
    [anon_sym_DASH_DASH] = ACTIONS(2575),
    [anon_sym_PLUS_PLUS] = ACTIONS(2575),
    [anon_sym_sizeof] = ACTIONS(2573),
    [anon_sym___alignof__] = ACTIONS(2573),
    [anon_sym___alignof] = ACTIONS(2573),
    [anon_sym__alignof] = ACTIONS(2573),
    [anon_sym_alignof] = ACTIONS(2573),
    [anon_sym__Alignof] = ACTIONS(2573),
    [anon_sym_offsetof] = ACTIONS(2573),
    [anon_sym__Generic] = ACTIONS(2573),
    [anon_sym_asm] = ACTIONS(2573),
    [anon_sym___asm__] = ACTIONS(2573),
    [sym_number_literal] = ACTIONS(2575),
    [anon_sym_L_SQUOTE] = ACTIONS(2575),
    [anon_sym_u_SQUOTE] = ACTIONS(2575),
    [anon_sym_U_SQUOTE] = ACTIONS(2575),
    [anon_sym_u8_SQUOTE] = ACTIONS(2575),
    [anon_sym_SQUOTE] = ACTIONS(2575),
    [anon_sym_L_DQUOTE] = ACTIONS(2575),
    [anon_sym_u_DQUOTE] = ACTIONS(2575),
    [anon_sym_U_DQUOTE] = ACTIONS(2575),
    [anon_sym_u8_DQUOTE] = ACTIONS(2575),
    [anon_sym_DQUOTE] = ACTIONS(2575),
    [sym_true] = ACTIONS(2573),
    [sym_false] = ACTIONS(2573),
    [anon_sym_NULL] = ACTIONS(2573),
    [anon_sym_nullptr] = ACTIONS(2573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2573),
    [anon_sym_decltype] = ACTIONS(2573),
    [sym_virtual] = ACTIONS(2573),
    [anon_sym_explicit] = ACTIONS(2573),
    [anon_sym_typename] = ACTIONS(2573),
    [anon_sym_template] = ACTIONS(2573),
    [anon_sym_operator] = ACTIONS(2573),
    [anon_sym_try] = ACTIONS(2573),
    [anon_sym_delete] = ACTIONS(2573),
    [anon_sym_throw] = ACTIONS(2573),
    [anon_sym_namespace] = ACTIONS(2573),
    [anon_sym_using] = ACTIONS(2573),
    [anon_sym_static_assert] = ACTIONS(2573),
    [anon_sym_concept] = ACTIONS(2573),
    [anon_sym_co_return] = ACTIONS(2573),
    [anon_sym_co_yield] = ACTIONS(2573),
    [anon_sym_R_DQUOTE] = ACTIONS(2575),
    [anon_sym_LR_DQUOTE] = ACTIONS(2575),
    [anon_sym_uR_DQUOTE] = ACTIONS(2575),
    [anon_sym_UR_DQUOTE] = ACTIONS(2575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2575),
    [anon_sym_co_await] = ACTIONS(2573),
    [anon_sym_new] = ACTIONS(2573),
    [anon_sym_requires] = ACTIONS(2573),
    [sym_this] = ACTIONS(2573),
    [anon_sym_discard] = ACTIONS(2573),
    [anon_sym_precise] = ACTIONS(2573),
    [anon_sym_shared] = ACTIONS(2573),
    [anon_sym_groupshared] = ACTIONS(2573),
    [anon_sym_uniform] = ACTIONS(2573),
    [anon_sym_row_major] = ACTIONS(2573),
    [anon_sym_column_major] = ACTIONS(2573),
    [anon_sym_globallycoherent] = ACTIONS(2573),
    [anon_sym_centroid] = ACTIONS(2573),
    [anon_sym_noperspective] = ACTIONS(2573),
    [anon_sym_nointerpolation] = ACTIONS(2573),
    [anon_sym_sample] = ACTIONS(2573),
    [anon_sym_linear] = ACTIONS(2573),
    [anon_sym_snorm] = ACTIONS(2573),
    [anon_sym_unorm] = ACTIONS(2573),
    [anon_sym_point] = ACTIONS(2573),
    [anon_sym_line] = ACTIONS(2573),
    [anon_sym_triangleadj] = ACTIONS(2573),
    [anon_sym_lineadj] = ACTIONS(2573),
    [anon_sym_triangle] = ACTIONS(2573),
    [anon_sym_cbuffer] = ACTIONS(2573),
  },
  [347] = {
    [sym_identifier] = ACTIONS(2577),
    [aux_sym_preproc_include_token1] = ACTIONS(2577),
    [aux_sym_preproc_def_token1] = ACTIONS(2577),
    [aux_sym_preproc_if_token1] = ACTIONS(2577),
    [aux_sym_preproc_if_token2] = ACTIONS(2577),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2577),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2577),
    [aux_sym_preproc_else_token1] = ACTIONS(2577),
    [aux_sym_preproc_elif_token1] = ACTIONS(2577),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2577),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2577),
    [sym_preproc_directive] = ACTIONS(2577),
    [anon_sym_LPAREN2] = ACTIONS(2579),
    [anon_sym_BANG] = ACTIONS(2579),
    [anon_sym_TILDE] = ACTIONS(2579),
    [anon_sym_DASH] = ACTIONS(2577),
    [anon_sym_PLUS] = ACTIONS(2577),
    [anon_sym_STAR] = ACTIONS(2579),
    [anon_sym_AMP_AMP] = ACTIONS(2579),
    [anon_sym_AMP] = ACTIONS(2577),
    [anon_sym_SEMI] = ACTIONS(2579),
    [anon_sym___extension__] = ACTIONS(2577),
    [anon_sym_typedef] = ACTIONS(2577),
    [anon_sym_in] = ACTIONS(2577),
    [anon_sym_out] = ACTIONS(2577),
    [anon_sym_inout] = ACTIONS(2577),
    [anon_sym_extern] = ACTIONS(2577),
    [anon_sym___attribute__] = ACTIONS(2577),
    [anon_sym_COLON_COLON] = ACTIONS(2579),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2579),
    [anon_sym___declspec] = ACTIONS(2577),
    [anon_sym___based] = ACTIONS(2577),
    [anon_sym___cdecl] = ACTIONS(2577),
    [anon_sym___clrcall] = ACTIONS(2577),
    [anon_sym___stdcall] = ACTIONS(2577),
    [anon_sym___fastcall] = ACTIONS(2577),
    [anon_sym___thiscall] = ACTIONS(2577),
    [anon_sym___vectorcall] = ACTIONS(2577),
    [anon_sym_LBRACE] = ACTIONS(2579),
    [anon_sym_signed] = ACTIONS(2577),
    [anon_sym_unsigned] = ACTIONS(2577),
    [anon_sym_long] = ACTIONS(2577),
    [anon_sym_short] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2577),
    [anon_sym_static] = ACTIONS(2577),
    [anon_sym_register] = ACTIONS(2577),
    [anon_sym_inline] = ACTIONS(2577),
    [anon_sym___inline] = ACTIONS(2577),
    [anon_sym___inline__] = ACTIONS(2577),
    [anon_sym___forceinline] = ACTIONS(2577),
    [anon_sym_thread_local] = ACTIONS(2577),
    [anon_sym___thread] = ACTIONS(2577),
    [anon_sym_const] = ACTIONS(2577),
    [anon_sym_constexpr] = ACTIONS(2577),
    [anon_sym_volatile] = ACTIONS(2577),
    [anon_sym_restrict] = ACTIONS(2577),
    [anon_sym___restrict__] = ACTIONS(2577),
    [anon_sym__Atomic] = ACTIONS(2577),
    [anon_sym__Noreturn] = ACTIONS(2577),
    [anon_sym_noreturn] = ACTIONS(2577),
    [anon_sym_mutable] = ACTIONS(2577),
    [anon_sym_constinit] = ACTIONS(2577),
    [anon_sym_consteval] = ACTIONS(2577),
    [anon_sym_alignas] = ACTIONS(2577),
    [anon_sym__Alignas] = ACTIONS(2577),
    [sym_primitive_type] = ACTIONS(2577),
    [anon_sym_enum] = ACTIONS(2577),
    [anon_sym_class] = ACTIONS(2577),
    [anon_sym_struct] = ACTIONS(2577),
    [anon_sym_union] = ACTIONS(2577),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_switch] = ACTIONS(2577),
    [anon_sym_case] = ACTIONS(2577),
    [anon_sym_default] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(2577),
    [anon_sym_do] = ACTIONS(2577),
    [anon_sym_for] = ACTIONS(2577),
    [anon_sym_return] = ACTIONS(2577),
    [anon_sym_break] = ACTIONS(2577),
    [anon_sym_continue] = ACTIONS(2577),
    [anon_sym_goto] = ACTIONS(2577),
    [anon_sym___try] = ACTIONS(2577),
    [anon_sym___leave] = ACTIONS(2577),
    [anon_sym_not] = ACTIONS(2577),
    [anon_sym_compl] = ACTIONS(2577),
    [anon_sym_DASH_DASH] = ACTIONS(2579),
    [anon_sym_PLUS_PLUS] = ACTIONS(2579),
    [anon_sym_sizeof] = ACTIONS(2577),
    [anon_sym___alignof__] = ACTIONS(2577),
    [anon_sym___alignof] = ACTIONS(2577),
    [anon_sym__alignof] = ACTIONS(2577),
    [anon_sym_alignof] = ACTIONS(2577),
    [anon_sym__Alignof] = ACTIONS(2577),
    [anon_sym_offsetof] = ACTIONS(2577),
    [anon_sym__Generic] = ACTIONS(2577),
    [anon_sym_asm] = ACTIONS(2577),
    [anon_sym___asm__] = ACTIONS(2577),
    [sym_number_literal] = ACTIONS(2579),
    [anon_sym_L_SQUOTE] = ACTIONS(2579),
    [anon_sym_u_SQUOTE] = ACTIONS(2579),
    [anon_sym_U_SQUOTE] = ACTIONS(2579),
    [anon_sym_u8_SQUOTE] = ACTIONS(2579),
    [anon_sym_SQUOTE] = ACTIONS(2579),
    [anon_sym_L_DQUOTE] = ACTIONS(2579),
    [anon_sym_u_DQUOTE] = ACTIONS(2579),
    [anon_sym_U_DQUOTE] = ACTIONS(2579),
    [anon_sym_u8_DQUOTE] = ACTIONS(2579),
    [anon_sym_DQUOTE] = ACTIONS(2579),
    [sym_true] = ACTIONS(2577),
    [sym_false] = ACTIONS(2577),
    [anon_sym_NULL] = ACTIONS(2577),
    [anon_sym_nullptr] = ACTIONS(2577),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2577),
    [anon_sym_decltype] = ACTIONS(2577),
    [sym_virtual] = ACTIONS(2577),
    [anon_sym_explicit] = ACTIONS(2577),
    [anon_sym_typename] = ACTIONS(2577),
    [anon_sym_template] = ACTIONS(2577),
    [anon_sym_operator] = ACTIONS(2577),
    [anon_sym_try] = ACTIONS(2577),
    [anon_sym_delete] = ACTIONS(2577),
    [anon_sym_throw] = ACTIONS(2577),
    [anon_sym_namespace] = ACTIONS(2577),
    [anon_sym_using] = ACTIONS(2577),
    [anon_sym_static_assert] = ACTIONS(2577),
    [anon_sym_concept] = ACTIONS(2577),
    [anon_sym_co_return] = ACTIONS(2577),
    [anon_sym_co_yield] = ACTIONS(2577),
    [anon_sym_R_DQUOTE] = ACTIONS(2579),
    [anon_sym_LR_DQUOTE] = ACTIONS(2579),
    [anon_sym_uR_DQUOTE] = ACTIONS(2579),
    [anon_sym_UR_DQUOTE] = ACTIONS(2579),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2579),
    [anon_sym_co_await] = ACTIONS(2577),
    [anon_sym_new] = ACTIONS(2577),
    [anon_sym_requires] = ACTIONS(2577),
    [sym_this] = ACTIONS(2577),
    [anon_sym_discard] = ACTIONS(2577),
    [anon_sym_precise] = ACTIONS(2577),
    [anon_sym_shared] = ACTIONS(2577),
    [anon_sym_groupshared] = ACTIONS(2577),
    [anon_sym_uniform] = ACTIONS(2577),
    [anon_sym_row_major] = ACTIONS(2577),
    [anon_sym_column_major] = ACTIONS(2577),
    [anon_sym_globallycoherent] = ACTIONS(2577),
    [anon_sym_centroid] = ACTIONS(2577),
    [anon_sym_noperspective] = ACTIONS(2577),
    [anon_sym_nointerpolation] = ACTIONS(2577),
    [anon_sym_sample] = ACTIONS(2577),
    [anon_sym_linear] = ACTIONS(2577),
    [anon_sym_snorm] = ACTIONS(2577),
    [anon_sym_unorm] = ACTIONS(2577),
    [anon_sym_point] = ACTIONS(2577),
    [anon_sym_line] = ACTIONS(2577),
    [anon_sym_triangleadj] = ACTIONS(2577),
    [anon_sym_lineadj] = ACTIONS(2577),
    [anon_sym_triangle] = ACTIONS(2577),
    [anon_sym_cbuffer] = ACTIONS(2577),
  },
  [348] = {
    [sym_catch_clause] = STATE(265),
    [aux_sym_constructor_try_statement_repeat1] = STATE(265),
    [sym_identifier] = ACTIONS(1984),
    [aux_sym_preproc_include_token1] = ACTIONS(1984),
    [aux_sym_preproc_def_token1] = ACTIONS(1984),
    [aux_sym_preproc_if_token1] = ACTIONS(1984),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1984),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1984),
    [sym_preproc_directive] = ACTIONS(1984),
    [anon_sym_LPAREN2] = ACTIONS(1986),
    [anon_sym_BANG] = ACTIONS(1986),
    [anon_sym_TILDE] = ACTIONS(1986),
    [anon_sym_DASH] = ACTIONS(1984),
    [anon_sym_PLUS] = ACTIONS(1984),
    [anon_sym_STAR] = ACTIONS(1986),
    [anon_sym_AMP_AMP] = ACTIONS(1986),
    [anon_sym_AMP] = ACTIONS(1984),
    [anon_sym_SEMI] = ACTIONS(1986),
    [anon_sym___extension__] = ACTIONS(1984),
    [anon_sym_typedef] = ACTIONS(1984),
    [anon_sym_in] = ACTIONS(1984),
    [anon_sym_out] = ACTIONS(1984),
    [anon_sym_inout] = ACTIONS(1984),
    [anon_sym_extern] = ACTIONS(1984),
    [anon_sym___attribute__] = ACTIONS(1984),
    [anon_sym_COLON_COLON] = ACTIONS(1986),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1986),
    [anon_sym___declspec] = ACTIONS(1984),
    [anon_sym___based] = ACTIONS(1984),
    [anon_sym___cdecl] = ACTIONS(1984),
    [anon_sym___clrcall] = ACTIONS(1984),
    [anon_sym___stdcall] = ACTIONS(1984),
    [anon_sym___fastcall] = ACTIONS(1984),
    [anon_sym___thiscall] = ACTIONS(1984),
    [anon_sym___vectorcall] = ACTIONS(1984),
    [anon_sym_LBRACE] = ACTIONS(1986),
    [anon_sym_RBRACE] = ACTIONS(1986),
    [anon_sym_signed] = ACTIONS(1984),
    [anon_sym_unsigned] = ACTIONS(1984),
    [anon_sym_long] = ACTIONS(1984),
    [anon_sym_short] = ACTIONS(1984),
    [anon_sym_LBRACK] = ACTIONS(1984),
    [anon_sym_static] = ACTIONS(1984),
    [anon_sym_register] = ACTIONS(1984),
    [anon_sym_inline] = ACTIONS(1984),
    [anon_sym___inline] = ACTIONS(1984),
    [anon_sym___inline__] = ACTIONS(1984),
    [anon_sym___forceinline] = ACTIONS(1984),
    [anon_sym_thread_local] = ACTIONS(1984),
    [anon_sym___thread] = ACTIONS(1984),
    [anon_sym_const] = ACTIONS(1984),
    [anon_sym_constexpr] = ACTIONS(1984),
    [anon_sym_volatile] = ACTIONS(1984),
    [anon_sym_restrict] = ACTIONS(1984),
    [anon_sym___restrict__] = ACTIONS(1984),
    [anon_sym__Atomic] = ACTIONS(1984),
    [anon_sym__Noreturn] = ACTIONS(1984),
    [anon_sym_noreturn] = ACTIONS(1984),
    [anon_sym_mutable] = ACTIONS(1984),
    [anon_sym_constinit] = ACTIONS(1984),
    [anon_sym_consteval] = ACTIONS(1984),
    [anon_sym_alignas] = ACTIONS(1984),
    [anon_sym__Alignas] = ACTIONS(1984),
    [sym_primitive_type] = ACTIONS(1984),
    [anon_sym_enum] = ACTIONS(1984),
    [anon_sym_class] = ACTIONS(1984),
    [anon_sym_struct] = ACTIONS(1984),
    [anon_sym_union] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(1984),
    [anon_sym_switch] = ACTIONS(1984),
    [anon_sym_case] = ACTIONS(1984),
    [anon_sym_default] = ACTIONS(1984),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_do] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1984),
    [anon_sym_return] = ACTIONS(1984),
    [anon_sym_break] = ACTIONS(1984),
    [anon_sym_continue] = ACTIONS(1984),
    [anon_sym_goto] = ACTIONS(1984),
    [anon_sym___try] = ACTIONS(1984),
    [anon_sym___leave] = ACTIONS(1984),
    [anon_sym_not] = ACTIONS(1984),
    [anon_sym_compl] = ACTIONS(1984),
    [anon_sym_DASH_DASH] = ACTIONS(1986),
    [anon_sym_PLUS_PLUS] = ACTIONS(1986),
    [anon_sym_sizeof] = ACTIONS(1984),
    [anon_sym___alignof__] = ACTIONS(1984),
    [anon_sym___alignof] = ACTIONS(1984),
    [anon_sym__alignof] = ACTIONS(1984),
    [anon_sym_alignof] = ACTIONS(1984),
    [anon_sym__Alignof] = ACTIONS(1984),
    [anon_sym_offsetof] = ACTIONS(1984),
    [anon_sym__Generic] = ACTIONS(1984),
    [anon_sym_asm] = ACTIONS(1984),
    [anon_sym___asm__] = ACTIONS(1984),
    [sym_number_literal] = ACTIONS(1986),
    [anon_sym_L_SQUOTE] = ACTIONS(1986),
    [anon_sym_u_SQUOTE] = ACTIONS(1986),
    [anon_sym_U_SQUOTE] = ACTIONS(1986),
    [anon_sym_u8_SQUOTE] = ACTIONS(1986),
    [anon_sym_SQUOTE] = ACTIONS(1986),
    [anon_sym_L_DQUOTE] = ACTIONS(1986),
    [anon_sym_u_DQUOTE] = ACTIONS(1986),
    [anon_sym_U_DQUOTE] = ACTIONS(1986),
    [anon_sym_u8_DQUOTE] = ACTIONS(1986),
    [anon_sym_DQUOTE] = ACTIONS(1986),
    [sym_true] = ACTIONS(1984),
    [sym_false] = ACTIONS(1984),
    [anon_sym_NULL] = ACTIONS(1984),
    [anon_sym_nullptr] = ACTIONS(1984),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1984),
    [anon_sym_decltype] = ACTIONS(1984),
    [sym_virtual] = ACTIONS(1984),
    [anon_sym_explicit] = ACTIONS(1984),
    [anon_sym_typename] = ACTIONS(1984),
    [anon_sym_template] = ACTIONS(1984),
    [anon_sym_operator] = ACTIONS(1984),
    [anon_sym_try] = ACTIONS(1984),
    [anon_sym_delete] = ACTIONS(1984),
    [anon_sym_throw] = ACTIONS(1984),
    [anon_sym_namespace] = ACTIONS(1984),
    [anon_sym_using] = ACTIONS(1984),
    [anon_sym_static_assert] = ACTIONS(1984),
    [anon_sym_concept] = ACTIONS(1984),
    [anon_sym_co_return] = ACTIONS(1984),
    [anon_sym_co_yield] = ACTIONS(1984),
    [anon_sym_catch] = ACTIONS(2547),
    [anon_sym_R_DQUOTE] = ACTIONS(1986),
    [anon_sym_LR_DQUOTE] = ACTIONS(1986),
    [anon_sym_uR_DQUOTE] = ACTIONS(1986),
    [anon_sym_UR_DQUOTE] = ACTIONS(1986),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1986),
    [anon_sym_co_await] = ACTIONS(1984),
    [anon_sym_new] = ACTIONS(1984),
    [anon_sym_requires] = ACTIONS(1984),
    [sym_this] = ACTIONS(1984),
    [anon_sym_discard] = ACTIONS(1984),
    [anon_sym_precise] = ACTIONS(1984),
    [anon_sym_shared] = ACTIONS(1984),
    [anon_sym_groupshared] = ACTIONS(1984),
    [anon_sym_uniform] = ACTIONS(1984),
    [anon_sym_row_major] = ACTIONS(1984),
    [anon_sym_column_major] = ACTIONS(1984),
    [anon_sym_globallycoherent] = ACTIONS(1984),
    [anon_sym_centroid] = ACTIONS(1984),
    [anon_sym_noperspective] = ACTIONS(1984),
    [anon_sym_nointerpolation] = ACTIONS(1984),
    [anon_sym_sample] = ACTIONS(1984),
    [anon_sym_linear] = ACTIONS(1984),
    [anon_sym_snorm] = ACTIONS(1984),
    [anon_sym_unorm] = ACTIONS(1984),
    [anon_sym_point] = ACTIONS(1984),
    [anon_sym_line] = ACTIONS(1984),
    [anon_sym_triangleadj] = ACTIONS(1984),
    [anon_sym_lineadj] = ACTIONS(1984),
    [anon_sym_triangle] = ACTIONS(1984),
    [anon_sym_cbuffer] = ACTIONS(1984),
  },
  [349] = {
    [sym_catch_clause] = STATE(338),
    [aux_sym_constructor_try_statement_repeat1] = STATE(338),
    [sym_identifier] = ACTIONS(1990),
    [aux_sym_preproc_include_token1] = ACTIONS(1990),
    [aux_sym_preproc_def_token1] = ACTIONS(1990),
    [aux_sym_preproc_if_token1] = ACTIONS(1990),
    [aux_sym_preproc_if_token2] = ACTIONS(1990),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1990),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1990),
    [sym_preproc_directive] = ACTIONS(1990),
    [anon_sym_LPAREN2] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1992),
    [anon_sym_TILDE] = ACTIONS(1992),
    [anon_sym_DASH] = ACTIONS(1990),
    [anon_sym_PLUS] = ACTIONS(1990),
    [anon_sym_STAR] = ACTIONS(1992),
    [anon_sym_AMP_AMP] = ACTIONS(1992),
    [anon_sym_AMP] = ACTIONS(1990),
    [anon_sym_SEMI] = ACTIONS(1992),
    [anon_sym___extension__] = ACTIONS(1990),
    [anon_sym_typedef] = ACTIONS(1990),
    [anon_sym_in] = ACTIONS(1990),
    [anon_sym_out] = ACTIONS(1990),
    [anon_sym_inout] = ACTIONS(1990),
    [anon_sym_extern] = ACTIONS(1990),
    [anon_sym___attribute__] = ACTIONS(1990),
    [anon_sym_COLON_COLON] = ACTIONS(1992),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1992),
    [anon_sym___declspec] = ACTIONS(1990),
    [anon_sym___based] = ACTIONS(1990),
    [anon_sym___cdecl] = ACTIONS(1990),
    [anon_sym___clrcall] = ACTIONS(1990),
    [anon_sym___stdcall] = ACTIONS(1990),
    [anon_sym___fastcall] = ACTIONS(1990),
    [anon_sym___thiscall] = ACTIONS(1990),
    [anon_sym___vectorcall] = ACTIONS(1990),
    [anon_sym_LBRACE] = ACTIONS(1992),
    [anon_sym_signed] = ACTIONS(1990),
    [anon_sym_unsigned] = ACTIONS(1990),
    [anon_sym_long] = ACTIONS(1990),
    [anon_sym_short] = ACTIONS(1990),
    [anon_sym_LBRACK] = ACTIONS(1990),
    [anon_sym_static] = ACTIONS(1990),
    [anon_sym_register] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1990),
    [anon_sym___inline] = ACTIONS(1990),
    [anon_sym___inline__] = ACTIONS(1990),
    [anon_sym___forceinline] = ACTIONS(1990),
    [anon_sym_thread_local] = ACTIONS(1990),
    [anon_sym___thread] = ACTIONS(1990),
    [anon_sym_const] = ACTIONS(1990),
    [anon_sym_constexpr] = ACTIONS(1990),
    [anon_sym_volatile] = ACTIONS(1990),
    [anon_sym_restrict] = ACTIONS(1990),
    [anon_sym___restrict__] = ACTIONS(1990),
    [anon_sym__Atomic] = ACTIONS(1990),
    [anon_sym__Noreturn] = ACTIONS(1990),
    [anon_sym_noreturn] = ACTIONS(1990),
    [anon_sym_mutable] = ACTIONS(1990),
    [anon_sym_constinit] = ACTIONS(1990),
    [anon_sym_consteval] = ACTIONS(1990),
    [anon_sym_alignas] = ACTIONS(1990),
    [anon_sym__Alignas] = ACTIONS(1990),
    [sym_primitive_type] = ACTIONS(1990),
    [anon_sym_enum] = ACTIONS(1990),
    [anon_sym_class] = ACTIONS(1990),
    [anon_sym_struct] = ACTIONS(1990),
    [anon_sym_union] = ACTIONS(1990),
    [anon_sym_if] = ACTIONS(1990),
    [anon_sym_switch] = ACTIONS(1990),
    [anon_sym_case] = ACTIONS(1990),
    [anon_sym_default] = ACTIONS(1990),
    [anon_sym_while] = ACTIONS(1990),
    [anon_sym_do] = ACTIONS(1990),
    [anon_sym_for] = ACTIONS(1990),
    [anon_sym_return] = ACTIONS(1990),
    [anon_sym_break] = ACTIONS(1990),
    [anon_sym_continue] = ACTIONS(1990),
    [anon_sym_goto] = ACTIONS(1990),
    [anon_sym___try] = ACTIONS(1990),
    [anon_sym___leave] = ACTIONS(1990),
    [anon_sym_not] = ACTIONS(1990),
    [anon_sym_compl] = ACTIONS(1990),
    [anon_sym_DASH_DASH] = ACTIONS(1992),
    [anon_sym_PLUS_PLUS] = ACTIONS(1992),
    [anon_sym_sizeof] = ACTIONS(1990),
    [anon_sym___alignof__] = ACTIONS(1990),
    [anon_sym___alignof] = ACTIONS(1990),
    [anon_sym__alignof] = ACTIONS(1990),
    [anon_sym_alignof] = ACTIONS(1990),
    [anon_sym__Alignof] = ACTIONS(1990),
    [anon_sym_offsetof] = ACTIONS(1990),
    [anon_sym__Generic] = ACTIONS(1990),
    [anon_sym_asm] = ACTIONS(1990),
    [anon_sym___asm__] = ACTIONS(1990),
    [sym_number_literal] = ACTIONS(1992),
    [anon_sym_L_SQUOTE] = ACTIONS(1992),
    [anon_sym_u_SQUOTE] = ACTIONS(1992),
    [anon_sym_U_SQUOTE] = ACTIONS(1992),
    [anon_sym_u8_SQUOTE] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1992),
    [anon_sym_L_DQUOTE] = ACTIONS(1992),
    [anon_sym_u_DQUOTE] = ACTIONS(1992),
    [anon_sym_U_DQUOTE] = ACTIONS(1992),
    [anon_sym_u8_DQUOTE] = ACTIONS(1992),
    [anon_sym_DQUOTE] = ACTIONS(1992),
    [sym_true] = ACTIONS(1990),
    [sym_false] = ACTIONS(1990),
    [anon_sym_NULL] = ACTIONS(1990),
    [anon_sym_nullptr] = ACTIONS(1990),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1990),
    [anon_sym_decltype] = ACTIONS(1990),
    [sym_virtual] = ACTIONS(1990),
    [anon_sym_explicit] = ACTIONS(1990),
    [anon_sym_typename] = ACTIONS(1990),
    [anon_sym_template] = ACTIONS(1990),
    [anon_sym_operator] = ACTIONS(1990),
    [anon_sym_try] = ACTIONS(1990),
    [anon_sym_delete] = ACTIONS(1990),
    [anon_sym_throw] = ACTIONS(1990),
    [anon_sym_namespace] = ACTIONS(1990),
    [anon_sym_using] = ACTIONS(1990),
    [anon_sym_static_assert] = ACTIONS(1990),
    [anon_sym_concept] = ACTIONS(1990),
    [anon_sym_co_return] = ACTIONS(1990),
    [anon_sym_co_yield] = ACTIONS(1990),
    [anon_sym_catch] = ACTIONS(2452),
    [anon_sym_R_DQUOTE] = ACTIONS(1992),
    [anon_sym_LR_DQUOTE] = ACTIONS(1992),
    [anon_sym_uR_DQUOTE] = ACTIONS(1992),
    [anon_sym_UR_DQUOTE] = ACTIONS(1992),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1992),
    [anon_sym_co_await] = ACTIONS(1990),
    [anon_sym_new] = ACTIONS(1990),
    [anon_sym_requires] = ACTIONS(1990),
    [sym_this] = ACTIONS(1990),
    [anon_sym_discard] = ACTIONS(1990),
    [anon_sym_precise] = ACTIONS(1990),
    [anon_sym_shared] = ACTIONS(1990),
    [anon_sym_groupshared] = ACTIONS(1990),
    [anon_sym_uniform] = ACTIONS(1990),
    [anon_sym_row_major] = ACTIONS(1990),
    [anon_sym_column_major] = ACTIONS(1990),
    [anon_sym_globallycoherent] = ACTIONS(1990),
    [anon_sym_centroid] = ACTIONS(1990),
    [anon_sym_noperspective] = ACTIONS(1990),
    [anon_sym_nointerpolation] = ACTIONS(1990),
    [anon_sym_sample] = ACTIONS(1990),
    [anon_sym_linear] = ACTIONS(1990),
    [anon_sym_snorm] = ACTIONS(1990),
    [anon_sym_unorm] = ACTIONS(1990),
    [anon_sym_point] = ACTIONS(1990),
    [anon_sym_line] = ACTIONS(1990),
    [anon_sym_triangleadj] = ACTIONS(1990),
    [anon_sym_lineadj] = ACTIONS(1990),
    [anon_sym_triangle] = ACTIONS(1990),
    [anon_sym_cbuffer] = ACTIONS(1990),
  },
  [350] = {
    [sym_catch_clause] = STATE(265),
    [aux_sym_constructor_try_statement_repeat1] = STATE(265),
    [sym_identifier] = ACTIONS(1990),
    [aux_sym_preproc_include_token1] = ACTIONS(1990),
    [aux_sym_preproc_def_token1] = ACTIONS(1990),
    [aux_sym_preproc_if_token1] = ACTIONS(1990),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1990),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1990),
    [sym_preproc_directive] = ACTIONS(1990),
    [anon_sym_LPAREN2] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1992),
    [anon_sym_TILDE] = ACTIONS(1992),
    [anon_sym_DASH] = ACTIONS(1990),
    [anon_sym_PLUS] = ACTIONS(1990),
    [anon_sym_STAR] = ACTIONS(1992),
    [anon_sym_AMP_AMP] = ACTIONS(1992),
    [anon_sym_AMP] = ACTIONS(1990),
    [anon_sym_SEMI] = ACTIONS(1992),
    [anon_sym___extension__] = ACTIONS(1990),
    [anon_sym_typedef] = ACTIONS(1990),
    [anon_sym_in] = ACTIONS(1990),
    [anon_sym_out] = ACTIONS(1990),
    [anon_sym_inout] = ACTIONS(1990),
    [anon_sym_extern] = ACTIONS(1990),
    [anon_sym___attribute__] = ACTIONS(1990),
    [anon_sym_COLON_COLON] = ACTIONS(1992),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1992),
    [anon_sym___declspec] = ACTIONS(1990),
    [anon_sym___based] = ACTIONS(1990),
    [anon_sym___cdecl] = ACTIONS(1990),
    [anon_sym___clrcall] = ACTIONS(1990),
    [anon_sym___stdcall] = ACTIONS(1990),
    [anon_sym___fastcall] = ACTIONS(1990),
    [anon_sym___thiscall] = ACTIONS(1990),
    [anon_sym___vectorcall] = ACTIONS(1990),
    [anon_sym_LBRACE] = ACTIONS(1992),
    [anon_sym_RBRACE] = ACTIONS(1992),
    [anon_sym_signed] = ACTIONS(1990),
    [anon_sym_unsigned] = ACTIONS(1990),
    [anon_sym_long] = ACTIONS(1990),
    [anon_sym_short] = ACTIONS(1990),
    [anon_sym_LBRACK] = ACTIONS(1990),
    [anon_sym_static] = ACTIONS(1990),
    [anon_sym_register] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1990),
    [anon_sym___inline] = ACTIONS(1990),
    [anon_sym___inline__] = ACTIONS(1990),
    [anon_sym___forceinline] = ACTIONS(1990),
    [anon_sym_thread_local] = ACTIONS(1990),
    [anon_sym___thread] = ACTIONS(1990),
    [anon_sym_const] = ACTIONS(1990),
    [anon_sym_constexpr] = ACTIONS(1990),
    [anon_sym_volatile] = ACTIONS(1990),
    [anon_sym_restrict] = ACTIONS(1990),
    [anon_sym___restrict__] = ACTIONS(1990),
    [anon_sym__Atomic] = ACTIONS(1990),
    [anon_sym__Noreturn] = ACTIONS(1990),
    [anon_sym_noreturn] = ACTIONS(1990),
    [anon_sym_mutable] = ACTIONS(1990),
    [anon_sym_constinit] = ACTIONS(1990),
    [anon_sym_consteval] = ACTIONS(1990),
    [anon_sym_alignas] = ACTIONS(1990),
    [anon_sym__Alignas] = ACTIONS(1990),
    [sym_primitive_type] = ACTIONS(1990),
    [anon_sym_enum] = ACTIONS(1990),
    [anon_sym_class] = ACTIONS(1990),
    [anon_sym_struct] = ACTIONS(1990),
    [anon_sym_union] = ACTIONS(1990),
    [anon_sym_if] = ACTIONS(1990),
    [anon_sym_switch] = ACTIONS(1990),
    [anon_sym_case] = ACTIONS(1990),
    [anon_sym_default] = ACTIONS(1990),
    [anon_sym_while] = ACTIONS(1990),
    [anon_sym_do] = ACTIONS(1990),
    [anon_sym_for] = ACTIONS(1990),
    [anon_sym_return] = ACTIONS(1990),
    [anon_sym_break] = ACTIONS(1990),
    [anon_sym_continue] = ACTIONS(1990),
    [anon_sym_goto] = ACTIONS(1990),
    [anon_sym___try] = ACTIONS(1990),
    [anon_sym___leave] = ACTIONS(1990),
    [anon_sym_not] = ACTIONS(1990),
    [anon_sym_compl] = ACTIONS(1990),
    [anon_sym_DASH_DASH] = ACTIONS(1992),
    [anon_sym_PLUS_PLUS] = ACTIONS(1992),
    [anon_sym_sizeof] = ACTIONS(1990),
    [anon_sym___alignof__] = ACTIONS(1990),
    [anon_sym___alignof] = ACTIONS(1990),
    [anon_sym__alignof] = ACTIONS(1990),
    [anon_sym_alignof] = ACTIONS(1990),
    [anon_sym__Alignof] = ACTIONS(1990),
    [anon_sym_offsetof] = ACTIONS(1990),
    [anon_sym__Generic] = ACTIONS(1990),
    [anon_sym_asm] = ACTIONS(1990),
    [anon_sym___asm__] = ACTIONS(1990),
    [sym_number_literal] = ACTIONS(1992),
    [anon_sym_L_SQUOTE] = ACTIONS(1992),
    [anon_sym_u_SQUOTE] = ACTIONS(1992),
    [anon_sym_U_SQUOTE] = ACTIONS(1992),
    [anon_sym_u8_SQUOTE] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1992),
    [anon_sym_L_DQUOTE] = ACTIONS(1992),
    [anon_sym_u_DQUOTE] = ACTIONS(1992),
    [anon_sym_U_DQUOTE] = ACTIONS(1992),
    [anon_sym_u8_DQUOTE] = ACTIONS(1992),
    [anon_sym_DQUOTE] = ACTIONS(1992),
    [sym_true] = ACTIONS(1990),
    [sym_false] = ACTIONS(1990),
    [anon_sym_NULL] = ACTIONS(1990),
    [anon_sym_nullptr] = ACTIONS(1990),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1990),
    [anon_sym_decltype] = ACTIONS(1990),
    [sym_virtual] = ACTIONS(1990),
    [anon_sym_explicit] = ACTIONS(1990),
    [anon_sym_typename] = ACTIONS(1990),
    [anon_sym_template] = ACTIONS(1990),
    [anon_sym_operator] = ACTIONS(1990),
    [anon_sym_try] = ACTIONS(1990),
    [anon_sym_delete] = ACTIONS(1990),
    [anon_sym_throw] = ACTIONS(1990),
    [anon_sym_namespace] = ACTIONS(1990),
    [anon_sym_using] = ACTIONS(1990),
    [anon_sym_static_assert] = ACTIONS(1990),
    [anon_sym_concept] = ACTIONS(1990),
    [anon_sym_co_return] = ACTIONS(1990),
    [anon_sym_co_yield] = ACTIONS(1990),
    [anon_sym_catch] = ACTIONS(2547),
    [anon_sym_R_DQUOTE] = ACTIONS(1992),
    [anon_sym_LR_DQUOTE] = ACTIONS(1992),
    [anon_sym_uR_DQUOTE] = ACTIONS(1992),
    [anon_sym_UR_DQUOTE] = ACTIONS(1992),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1992),
    [anon_sym_co_await] = ACTIONS(1990),
    [anon_sym_new] = ACTIONS(1990),
    [anon_sym_requires] = ACTIONS(1990),
    [sym_this] = ACTIONS(1990),
    [anon_sym_discard] = ACTIONS(1990),
    [anon_sym_precise] = ACTIONS(1990),
    [anon_sym_shared] = ACTIONS(1990),
    [anon_sym_groupshared] = ACTIONS(1990),
    [anon_sym_uniform] = ACTIONS(1990),
    [anon_sym_row_major] = ACTIONS(1990),
    [anon_sym_column_major] = ACTIONS(1990),
    [anon_sym_globallycoherent] = ACTIONS(1990),
    [anon_sym_centroid] = ACTIONS(1990),
    [anon_sym_noperspective] = ACTIONS(1990),
    [anon_sym_nointerpolation] = ACTIONS(1990),
    [anon_sym_sample] = ACTIONS(1990),
    [anon_sym_linear] = ACTIONS(1990),
    [anon_sym_snorm] = ACTIONS(1990),
    [anon_sym_unorm] = ACTIONS(1990),
    [anon_sym_point] = ACTIONS(1990),
    [anon_sym_line] = ACTIONS(1990),
    [anon_sym_triangleadj] = ACTIONS(1990),
    [anon_sym_lineadj] = ACTIONS(1990),
    [anon_sym_triangle] = ACTIONS(1990),
    [anon_sym_cbuffer] = ACTIONS(1990),
  },
  [351] = {
    [sym_catch_clause] = STATE(338),
    [aux_sym_constructor_try_statement_repeat1] = STATE(338),
    [sym_identifier] = ACTIONS(1984),
    [aux_sym_preproc_include_token1] = ACTIONS(1984),
    [aux_sym_preproc_def_token1] = ACTIONS(1984),
    [aux_sym_preproc_if_token1] = ACTIONS(1984),
    [aux_sym_preproc_if_token2] = ACTIONS(1984),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1984),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1984),
    [sym_preproc_directive] = ACTIONS(1984),
    [anon_sym_LPAREN2] = ACTIONS(1986),
    [anon_sym_BANG] = ACTIONS(1986),
    [anon_sym_TILDE] = ACTIONS(1986),
    [anon_sym_DASH] = ACTIONS(1984),
    [anon_sym_PLUS] = ACTIONS(1984),
    [anon_sym_STAR] = ACTIONS(1986),
    [anon_sym_AMP_AMP] = ACTIONS(1986),
    [anon_sym_AMP] = ACTIONS(1984),
    [anon_sym_SEMI] = ACTIONS(1986),
    [anon_sym___extension__] = ACTIONS(1984),
    [anon_sym_typedef] = ACTIONS(1984),
    [anon_sym_in] = ACTIONS(1984),
    [anon_sym_out] = ACTIONS(1984),
    [anon_sym_inout] = ACTIONS(1984),
    [anon_sym_extern] = ACTIONS(1984),
    [anon_sym___attribute__] = ACTIONS(1984),
    [anon_sym_COLON_COLON] = ACTIONS(1986),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1986),
    [anon_sym___declspec] = ACTIONS(1984),
    [anon_sym___based] = ACTIONS(1984),
    [anon_sym___cdecl] = ACTIONS(1984),
    [anon_sym___clrcall] = ACTIONS(1984),
    [anon_sym___stdcall] = ACTIONS(1984),
    [anon_sym___fastcall] = ACTIONS(1984),
    [anon_sym___thiscall] = ACTIONS(1984),
    [anon_sym___vectorcall] = ACTIONS(1984),
    [anon_sym_LBRACE] = ACTIONS(1986),
    [anon_sym_signed] = ACTIONS(1984),
    [anon_sym_unsigned] = ACTIONS(1984),
    [anon_sym_long] = ACTIONS(1984),
    [anon_sym_short] = ACTIONS(1984),
    [anon_sym_LBRACK] = ACTIONS(1984),
    [anon_sym_static] = ACTIONS(1984),
    [anon_sym_register] = ACTIONS(1984),
    [anon_sym_inline] = ACTIONS(1984),
    [anon_sym___inline] = ACTIONS(1984),
    [anon_sym___inline__] = ACTIONS(1984),
    [anon_sym___forceinline] = ACTIONS(1984),
    [anon_sym_thread_local] = ACTIONS(1984),
    [anon_sym___thread] = ACTIONS(1984),
    [anon_sym_const] = ACTIONS(1984),
    [anon_sym_constexpr] = ACTIONS(1984),
    [anon_sym_volatile] = ACTIONS(1984),
    [anon_sym_restrict] = ACTIONS(1984),
    [anon_sym___restrict__] = ACTIONS(1984),
    [anon_sym__Atomic] = ACTIONS(1984),
    [anon_sym__Noreturn] = ACTIONS(1984),
    [anon_sym_noreturn] = ACTIONS(1984),
    [anon_sym_mutable] = ACTIONS(1984),
    [anon_sym_constinit] = ACTIONS(1984),
    [anon_sym_consteval] = ACTIONS(1984),
    [anon_sym_alignas] = ACTIONS(1984),
    [anon_sym__Alignas] = ACTIONS(1984),
    [sym_primitive_type] = ACTIONS(1984),
    [anon_sym_enum] = ACTIONS(1984),
    [anon_sym_class] = ACTIONS(1984),
    [anon_sym_struct] = ACTIONS(1984),
    [anon_sym_union] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(1984),
    [anon_sym_switch] = ACTIONS(1984),
    [anon_sym_case] = ACTIONS(1984),
    [anon_sym_default] = ACTIONS(1984),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_do] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1984),
    [anon_sym_return] = ACTIONS(1984),
    [anon_sym_break] = ACTIONS(1984),
    [anon_sym_continue] = ACTIONS(1984),
    [anon_sym_goto] = ACTIONS(1984),
    [anon_sym___try] = ACTIONS(1984),
    [anon_sym___leave] = ACTIONS(1984),
    [anon_sym_not] = ACTIONS(1984),
    [anon_sym_compl] = ACTIONS(1984),
    [anon_sym_DASH_DASH] = ACTIONS(1986),
    [anon_sym_PLUS_PLUS] = ACTIONS(1986),
    [anon_sym_sizeof] = ACTIONS(1984),
    [anon_sym___alignof__] = ACTIONS(1984),
    [anon_sym___alignof] = ACTIONS(1984),
    [anon_sym__alignof] = ACTIONS(1984),
    [anon_sym_alignof] = ACTIONS(1984),
    [anon_sym__Alignof] = ACTIONS(1984),
    [anon_sym_offsetof] = ACTIONS(1984),
    [anon_sym__Generic] = ACTIONS(1984),
    [anon_sym_asm] = ACTIONS(1984),
    [anon_sym___asm__] = ACTIONS(1984),
    [sym_number_literal] = ACTIONS(1986),
    [anon_sym_L_SQUOTE] = ACTIONS(1986),
    [anon_sym_u_SQUOTE] = ACTIONS(1986),
    [anon_sym_U_SQUOTE] = ACTIONS(1986),
    [anon_sym_u8_SQUOTE] = ACTIONS(1986),
    [anon_sym_SQUOTE] = ACTIONS(1986),
    [anon_sym_L_DQUOTE] = ACTIONS(1986),
    [anon_sym_u_DQUOTE] = ACTIONS(1986),
    [anon_sym_U_DQUOTE] = ACTIONS(1986),
    [anon_sym_u8_DQUOTE] = ACTIONS(1986),
    [anon_sym_DQUOTE] = ACTIONS(1986),
    [sym_true] = ACTIONS(1984),
    [sym_false] = ACTIONS(1984),
    [anon_sym_NULL] = ACTIONS(1984),
    [anon_sym_nullptr] = ACTIONS(1984),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1984),
    [anon_sym_decltype] = ACTIONS(1984),
    [sym_virtual] = ACTIONS(1984),
    [anon_sym_explicit] = ACTIONS(1984),
    [anon_sym_typename] = ACTIONS(1984),
    [anon_sym_template] = ACTIONS(1984),
    [anon_sym_operator] = ACTIONS(1984),
    [anon_sym_try] = ACTIONS(1984),
    [anon_sym_delete] = ACTIONS(1984),
    [anon_sym_throw] = ACTIONS(1984),
    [anon_sym_namespace] = ACTIONS(1984),
    [anon_sym_using] = ACTIONS(1984),
    [anon_sym_static_assert] = ACTIONS(1984),
    [anon_sym_concept] = ACTIONS(1984),
    [anon_sym_co_return] = ACTIONS(1984),
    [anon_sym_co_yield] = ACTIONS(1984),
    [anon_sym_catch] = ACTIONS(2452),
    [anon_sym_R_DQUOTE] = ACTIONS(1986),
    [anon_sym_LR_DQUOTE] = ACTIONS(1986),
    [anon_sym_uR_DQUOTE] = ACTIONS(1986),
    [anon_sym_UR_DQUOTE] = ACTIONS(1986),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1986),
    [anon_sym_co_await] = ACTIONS(1984),
    [anon_sym_new] = ACTIONS(1984),
    [anon_sym_requires] = ACTIONS(1984),
    [sym_this] = ACTIONS(1984),
    [anon_sym_discard] = ACTIONS(1984),
    [anon_sym_precise] = ACTIONS(1984),
    [anon_sym_shared] = ACTIONS(1984),
    [anon_sym_groupshared] = ACTIONS(1984),
    [anon_sym_uniform] = ACTIONS(1984),
    [anon_sym_row_major] = ACTIONS(1984),
    [anon_sym_column_major] = ACTIONS(1984),
    [anon_sym_globallycoherent] = ACTIONS(1984),
    [anon_sym_centroid] = ACTIONS(1984),
    [anon_sym_noperspective] = ACTIONS(1984),
    [anon_sym_nointerpolation] = ACTIONS(1984),
    [anon_sym_sample] = ACTIONS(1984),
    [anon_sym_linear] = ACTIONS(1984),
    [anon_sym_snorm] = ACTIONS(1984),
    [anon_sym_unorm] = ACTIONS(1984),
    [anon_sym_point] = ACTIONS(1984),
    [anon_sym_line] = ACTIONS(1984),
    [anon_sym_triangleadj] = ACTIONS(1984),
    [anon_sym_lineadj] = ACTIONS(1984),
    [anon_sym_triangle] = ACTIONS(1984),
    [anon_sym_cbuffer] = ACTIONS(1984),
  },
  [352] = {
    [sym_else_clause] = STATE(390),
    [sym_identifier] = ACTIONS(2008),
    [aux_sym_preproc_include_token1] = ACTIONS(2008),
    [aux_sym_preproc_def_token1] = ACTIONS(2008),
    [aux_sym_preproc_if_token1] = ACTIONS(2008),
    [aux_sym_preproc_if_token2] = ACTIONS(2008),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2008),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2008),
    [sym_preproc_directive] = ACTIONS(2008),
    [anon_sym_LPAREN2] = ACTIONS(2010),
    [anon_sym_BANG] = ACTIONS(2010),
    [anon_sym_TILDE] = ACTIONS(2010),
    [anon_sym_DASH] = ACTIONS(2008),
    [anon_sym_PLUS] = ACTIONS(2008),
    [anon_sym_STAR] = ACTIONS(2010),
    [anon_sym_AMP_AMP] = ACTIONS(2010),
    [anon_sym_AMP] = ACTIONS(2008),
    [anon_sym_SEMI] = ACTIONS(2010),
    [anon_sym___extension__] = ACTIONS(2008),
    [anon_sym_typedef] = ACTIONS(2008),
    [anon_sym_in] = ACTIONS(2008),
    [anon_sym_out] = ACTIONS(2008),
    [anon_sym_inout] = ACTIONS(2008),
    [anon_sym_extern] = ACTIONS(2008),
    [anon_sym___attribute__] = ACTIONS(2008),
    [anon_sym_COLON_COLON] = ACTIONS(2010),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2010),
    [anon_sym___declspec] = ACTIONS(2008),
    [anon_sym___based] = ACTIONS(2008),
    [anon_sym___cdecl] = ACTIONS(2008),
    [anon_sym___clrcall] = ACTIONS(2008),
    [anon_sym___stdcall] = ACTIONS(2008),
    [anon_sym___fastcall] = ACTIONS(2008),
    [anon_sym___thiscall] = ACTIONS(2008),
    [anon_sym___vectorcall] = ACTIONS(2008),
    [anon_sym_LBRACE] = ACTIONS(2010),
    [anon_sym_signed] = ACTIONS(2008),
    [anon_sym_unsigned] = ACTIONS(2008),
    [anon_sym_long] = ACTIONS(2008),
    [anon_sym_short] = ACTIONS(2008),
    [anon_sym_LBRACK] = ACTIONS(2008),
    [anon_sym_static] = ACTIONS(2008),
    [anon_sym_register] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(2008),
    [anon_sym___inline] = ACTIONS(2008),
    [anon_sym___inline__] = ACTIONS(2008),
    [anon_sym___forceinline] = ACTIONS(2008),
    [anon_sym_thread_local] = ACTIONS(2008),
    [anon_sym___thread] = ACTIONS(2008),
    [anon_sym_const] = ACTIONS(2008),
    [anon_sym_constexpr] = ACTIONS(2008),
    [anon_sym_volatile] = ACTIONS(2008),
    [anon_sym_restrict] = ACTIONS(2008),
    [anon_sym___restrict__] = ACTIONS(2008),
    [anon_sym__Atomic] = ACTIONS(2008),
    [anon_sym__Noreturn] = ACTIONS(2008),
    [anon_sym_noreturn] = ACTIONS(2008),
    [anon_sym_mutable] = ACTIONS(2008),
    [anon_sym_constinit] = ACTIONS(2008),
    [anon_sym_consteval] = ACTIONS(2008),
    [anon_sym_alignas] = ACTIONS(2008),
    [anon_sym__Alignas] = ACTIONS(2008),
    [sym_primitive_type] = ACTIONS(2008),
    [anon_sym_enum] = ACTIONS(2008),
    [anon_sym_class] = ACTIONS(2008),
    [anon_sym_struct] = ACTIONS(2008),
    [anon_sym_union] = ACTIONS(2008),
    [anon_sym_if] = ACTIONS(2008),
    [anon_sym_else] = ACTIONS(2581),
    [anon_sym_switch] = ACTIONS(2008),
    [anon_sym_case] = ACTIONS(2008),
    [anon_sym_default] = ACTIONS(2008),
    [anon_sym_while] = ACTIONS(2008),
    [anon_sym_do] = ACTIONS(2008),
    [anon_sym_for] = ACTIONS(2008),
    [anon_sym_return] = ACTIONS(2008),
    [anon_sym_break] = ACTIONS(2008),
    [anon_sym_continue] = ACTIONS(2008),
    [anon_sym_goto] = ACTIONS(2008),
    [anon_sym___try] = ACTIONS(2008),
    [anon_sym___leave] = ACTIONS(2008),
    [anon_sym_not] = ACTIONS(2008),
    [anon_sym_compl] = ACTIONS(2008),
    [anon_sym_DASH_DASH] = ACTIONS(2010),
    [anon_sym_PLUS_PLUS] = ACTIONS(2010),
    [anon_sym_sizeof] = ACTIONS(2008),
    [anon_sym___alignof__] = ACTIONS(2008),
    [anon_sym___alignof] = ACTIONS(2008),
    [anon_sym__alignof] = ACTIONS(2008),
    [anon_sym_alignof] = ACTIONS(2008),
    [anon_sym__Alignof] = ACTIONS(2008),
    [anon_sym_offsetof] = ACTIONS(2008),
    [anon_sym__Generic] = ACTIONS(2008),
    [anon_sym_asm] = ACTIONS(2008),
    [anon_sym___asm__] = ACTIONS(2008),
    [sym_number_literal] = ACTIONS(2010),
    [anon_sym_L_SQUOTE] = ACTIONS(2010),
    [anon_sym_u_SQUOTE] = ACTIONS(2010),
    [anon_sym_U_SQUOTE] = ACTIONS(2010),
    [anon_sym_u8_SQUOTE] = ACTIONS(2010),
    [anon_sym_SQUOTE] = ACTIONS(2010),
    [anon_sym_L_DQUOTE] = ACTIONS(2010),
    [anon_sym_u_DQUOTE] = ACTIONS(2010),
    [anon_sym_U_DQUOTE] = ACTIONS(2010),
    [anon_sym_u8_DQUOTE] = ACTIONS(2010),
    [anon_sym_DQUOTE] = ACTIONS(2010),
    [sym_true] = ACTIONS(2008),
    [sym_false] = ACTIONS(2008),
    [anon_sym_NULL] = ACTIONS(2008),
    [anon_sym_nullptr] = ACTIONS(2008),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2008),
    [anon_sym_decltype] = ACTIONS(2008),
    [sym_virtual] = ACTIONS(2008),
    [anon_sym_explicit] = ACTIONS(2008),
    [anon_sym_typename] = ACTIONS(2008),
    [anon_sym_template] = ACTIONS(2008),
    [anon_sym_operator] = ACTIONS(2008),
    [anon_sym_try] = ACTIONS(2008),
    [anon_sym_delete] = ACTIONS(2008),
    [anon_sym_throw] = ACTIONS(2008),
    [anon_sym_namespace] = ACTIONS(2008),
    [anon_sym_using] = ACTIONS(2008),
    [anon_sym_static_assert] = ACTIONS(2008),
    [anon_sym_concept] = ACTIONS(2008),
    [anon_sym_co_return] = ACTIONS(2008),
    [anon_sym_co_yield] = ACTIONS(2008),
    [anon_sym_R_DQUOTE] = ACTIONS(2010),
    [anon_sym_LR_DQUOTE] = ACTIONS(2010),
    [anon_sym_uR_DQUOTE] = ACTIONS(2010),
    [anon_sym_UR_DQUOTE] = ACTIONS(2010),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2010),
    [anon_sym_co_await] = ACTIONS(2008),
    [anon_sym_new] = ACTIONS(2008),
    [anon_sym_requires] = ACTIONS(2008),
    [sym_this] = ACTIONS(2008),
    [anon_sym_discard] = ACTIONS(2008),
    [anon_sym_precise] = ACTIONS(2008),
    [anon_sym_shared] = ACTIONS(2008),
    [anon_sym_groupshared] = ACTIONS(2008),
    [anon_sym_uniform] = ACTIONS(2008),
    [anon_sym_row_major] = ACTIONS(2008),
    [anon_sym_column_major] = ACTIONS(2008),
    [anon_sym_globallycoherent] = ACTIONS(2008),
    [anon_sym_centroid] = ACTIONS(2008),
    [anon_sym_noperspective] = ACTIONS(2008),
    [anon_sym_nointerpolation] = ACTIONS(2008),
    [anon_sym_sample] = ACTIONS(2008),
    [anon_sym_linear] = ACTIONS(2008),
    [anon_sym_snorm] = ACTIONS(2008),
    [anon_sym_unorm] = ACTIONS(2008),
    [anon_sym_point] = ACTIONS(2008),
    [anon_sym_line] = ACTIONS(2008),
    [anon_sym_triangleadj] = ACTIONS(2008),
    [anon_sym_lineadj] = ACTIONS(2008),
    [anon_sym_triangle] = ACTIONS(2008),
    [anon_sym_cbuffer] = ACTIONS(2008),
  },
  [353] = {
    [sym_preproc_def] = STATE(369),
    [sym_preproc_function_def] = STATE(369),
    [sym_preproc_call] = STATE(369),
    [sym_preproc_if_in_field_declaration_list] = STATE(369),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(369),
    [sym_preproc_else_in_field_declaration_list] = STATE(8536),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8536),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8536),
    [sym_type_definition] = STATE(369),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5626),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6102),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(369),
    [sym_field_declaration] = STATE(369),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1832),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(369),
    [sym_operator_cast] = STATE(6636),
    [sym_inline_method_definition] = STATE(369),
    [sym__constructor_specifiers] = STATE(1832),
    [sym_operator_cast_definition] = STATE(369),
    [sym_operator_cast_declaration] = STATE(369),
    [sym_constructor_or_destructor_definition] = STATE(369),
    [sym_constructor_or_destructor_declaration] = STATE(369),
    [sym_friend_declaration] = STATE(369),
    [sym_access_specifier] = STATE(8379),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(369),
    [sym_alias_declaration] = STATE(369),
    [sym_static_assert_declaration] = STATE(369),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6636),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(369),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1832),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2587),
    [aux_sym_preproc_if_token2] = ACTIONS(2589),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2591),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2591),
    [aux_sym_preproc_else_token1] = ACTIONS(2593),
    [aux_sym_preproc_elif_token1] = ACTIONS(2595),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2597),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2597),
    [sym_preproc_directive] = ACTIONS(2599),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2609),
    [anon_sym_typedef] = ACTIONS(2611),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2629),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2631),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2635),
    [anon_sym_static_assert] = ACTIONS(2637),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [354] = {
    [sym_preproc_def] = STATE(702),
    [sym_preproc_function_def] = STATE(702),
    [sym_preproc_call] = STATE(702),
    [sym_preproc_if_in_field_declaration_list] = STATE(702),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(702),
    [sym_preproc_else_in_field_declaration_list] = STATE(8323),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8323),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8323),
    [sym_type_definition] = STATE(702),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5626),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6102),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(702),
    [sym_field_declaration] = STATE(702),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1832),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(702),
    [sym_operator_cast] = STATE(6636),
    [sym_inline_method_definition] = STATE(702),
    [sym__constructor_specifiers] = STATE(1832),
    [sym_operator_cast_definition] = STATE(702),
    [sym_operator_cast_declaration] = STATE(702),
    [sym_constructor_or_destructor_definition] = STATE(702),
    [sym_constructor_or_destructor_declaration] = STATE(702),
    [sym_friend_declaration] = STATE(702),
    [sym_access_specifier] = STATE(8379),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(702),
    [sym_alias_declaration] = STATE(702),
    [sym_static_assert_declaration] = STATE(702),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6636),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(702),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1832),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2587),
    [aux_sym_preproc_if_token2] = ACTIONS(2639),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2591),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2591),
    [aux_sym_preproc_else_token1] = ACTIONS(2593),
    [aux_sym_preproc_elif_token1] = ACTIONS(2595),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2597),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2597),
    [sym_preproc_directive] = ACTIONS(2599),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2609),
    [anon_sym_typedef] = ACTIONS(2611),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2629),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2631),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2635),
    [anon_sym_static_assert] = ACTIONS(2637),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [355] = {
    [sym_preproc_def] = STATE(367),
    [sym_preproc_function_def] = STATE(367),
    [sym_preproc_call] = STATE(367),
    [sym_preproc_if_in_field_declaration_list] = STATE(367),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(367),
    [sym_preproc_else_in_field_declaration_list] = STATE(8325),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8325),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8325),
    [sym_type_definition] = STATE(367),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5626),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6102),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(367),
    [sym_field_declaration] = STATE(367),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1832),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(367),
    [sym_operator_cast] = STATE(6636),
    [sym_inline_method_definition] = STATE(367),
    [sym__constructor_specifiers] = STATE(1832),
    [sym_operator_cast_definition] = STATE(367),
    [sym_operator_cast_declaration] = STATE(367),
    [sym_constructor_or_destructor_definition] = STATE(367),
    [sym_constructor_or_destructor_declaration] = STATE(367),
    [sym_friend_declaration] = STATE(367),
    [sym_access_specifier] = STATE(8379),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(367),
    [sym_alias_declaration] = STATE(367),
    [sym_static_assert_declaration] = STATE(367),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6636),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(367),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1832),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2587),
    [aux_sym_preproc_if_token2] = ACTIONS(2641),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2591),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2591),
    [aux_sym_preproc_else_token1] = ACTIONS(2593),
    [aux_sym_preproc_elif_token1] = ACTIONS(2595),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2597),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2597),
    [sym_preproc_directive] = ACTIONS(2599),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2609),
    [anon_sym_typedef] = ACTIONS(2611),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2629),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2631),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2635),
    [anon_sym_static_assert] = ACTIONS(2637),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [356] = {
    [sym_else_clause] = STATE(414),
    [sym_identifier] = ACTIONS(2004),
    [aux_sym_preproc_include_token1] = ACTIONS(2004),
    [aux_sym_preproc_def_token1] = ACTIONS(2004),
    [aux_sym_preproc_if_token1] = ACTIONS(2004),
    [aux_sym_preproc_if_token2] = ACTIONS(2004),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2004),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2004),
    [sym_preproc_directive] = ACTIONS(2004),
    [anon_sym_LPAREN2] = ACTIONS(2006),
    [anon_sym_BANG] = ACTIONS(2006),
    [anon_sym_TILDE] = ACTIONS(2006),
    [anon_sym_DASH] = ACTIONS(2004),
    [anon_sym_PLUS] = ACTIONS(2004),
    [anon_sym_STAR] = ACTIONS(2006),
    [anon_sym_AMP_AMP] = ACTIONS(2006),
    [anon_sym_AMP] = ACTIONS(2004),
    [anon_sym_SEMI] = ACTIONS(2006),
    [anon_sym___extension__] = ACTIONS(2004),
    [anon_sym_typedef] = ACTIONS(2004),
    [anon_sym_in] = ACTIONS(2004),
    [anon_sym_out] = ACTIONS(2004),
    [anon_sym_inout] = ACTIONS(2004),
    [anon_sym_extern] = ACTIONS(2004),
    [anon_sym___attribute__] = ACTIONS(2004),
    [anon_sym_COLON_COLON] = ACTIONS(2006),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2006),
    [anon_sym___declspec] = ACTIONS(2004),
    [anon_sym___based] = ACTIONS(2004),
    [anon_sym___cdecl] = ACTIONS(2004),
    [anon_sym___clrcall] = ACTIONS(2004),
    [anon_sym___stdcall] = ACTIONS(2004),
    [anon_sym___fastcall] = ACTIONS(2004),
    [anon_sym___thiscall] = ACTIONS(2004),
    [anon_sym___vectorcall] = ACTIONS(2004),
    [anon_sym_LBRACE] = ACTIONS(2006),
    [anon_sym_signed] = ACTIONS(2004),
    [anon_sym_unsigned] = ACTIONS(2004),
    [anon_sym_long] = ACTIONS(2004),
    [anon_sym_short] = ACTIONS(2004),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(2004),
    [anon_sym_register] = ACTIONS(2004),
    [anon_sym_inline] = ACTIONS(2004),
    [anon_sym___inline] = ACTIONS(2004),
    [anon_sym___inline__] = ACTIONS(2004),
    [anon_sym___forceinline] = ACTIONS(2004),
    [anon_sym_thread_local] = ACTIONS(2004),
    [anon_sym___thread] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(2004),
    [anon_sym_constexpr] = ACTIONS(2004),
    [anon_sym_volatile] = ACTIONS(2004),
    [anon_sym_restrict] = ACTIONS(2004),
    [anon_sym___restrict__] = ACTIONS(2004),
    [anon_sym__Atomic] = ACTIONS(2004),
    [anon_sym__Noreturn] = ACTIONS(2004),
    [anon_sym_noreturn] = ACTIONS(2004),
    [anon_sym_mutable] = ACTIONS(2004),
    [anon_sym_constinit] = ACTIONS(2004),
    [anon_sym_consteval] = ACTIONS(2004),
    [anon_sym_alignas] = ACTIONS(2004),
    [anon_sym__Alignas] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2004),
    [anon_sym_enum] = ACTIONS(2004),
    [anon_sym_class] = ACTIONS(2004),
    [anon_sym_struct] = ACTIONS(2004),
    [anon_sym_union] = ACTIONS(2004),
    [anon_sym_if] = ACTIONS(2004),
    [anon_sym_else] = ACTIONS(2581),
    [anon_sym_switch] = ACTIONS(2004),
    [anon_sym_case] = ACTIONS(2004),
    [anon_sym_default] = ACTIONS(2004),
    [anon_sym_while] = ACTIONS(2004),
    [anon_sym_do] = ACTIONS(2004),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_return] = ACTIONS(2004),
    [anon_sym_break] = ACTIONS(2004),
    [anon_sym_continue] = ACTIONS(2004),
    [anon_sym_goto] = ACTIONS(2004),
    [anon_sym___try] = ACTIONS(2004),
    [anon_sym___leave] = ACTIONS(2004),
    [anon_sym_not] = ACTIONS(2004),
    [anon_sym_compl] = ACTIONS(2004),
    [anon_sym_DASH_DASH] = ACTIONS(2006),
    [anon_sym_PLUS_PLUS] = ACTIONS(2006),
    [anon_sym_sizeof] = ACTIONS(2004),
    [anon_sym___alignof__] = ACTIONS(2004),
    [anon_sym___alignof] = ACTIONS(2004),
    [anon_sym__alignof] = ACTIONS(2004),
    [anon_sym_alignof] = ACTIONS(2004),
    [anon_sym__Alignof] = ACTIONS(2004),
    [anon_sym_offsetof] = ACTIONS(2004),
    [anon_sym__Generic] = ACTIONS(2004),
    [anon_sym_asm] = ACTIONS(2004),
    [anon_sym___asm__] = ACTIONS(2004),
    [sym_number_literal] = ACTIONS(2006),
    [anon_sym_L_SQUOTE] = ACTIONS(2006),
    [anon_sym_u_SQUOTE] = ACTIONS(2006),
    [anon_sym_U_SQUOTE] = ACTIONS(2006),
    [anon_sym_u8_SQUOTE] = ACTIONS(2006),
    [anon_sym_SQUOTE] = ACTIONS(2006),
    [anon_sym_L_DQUOTE] = ACTIONS(2006),
    [anon_sym_u_DQUOTE] = ACTIONS(2006),
    [anon_sym_U_DQUOTE] = ACTIONS(2006),
    [anon_sym_u8_DQUOTE] = ACTIONS(2006),
    [anon_sym_DQUOTE] = ACTIONS(2006),
    [sym_true] = ACTIONS(2004),
    [sym_false] = ACTIONS(2004),
    [anon_sym_NULL] = ACTIONS(2004),
    [anon_sym_nullptr] = ACTIONS(2004),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2004),
    [anon_sym_decltype] = ACTIONS(2004),
    [sym_virtual] = ACTIONS(2004),
    [anon_sym_explicit] = ACTIONS(2004),
    [anon_sym_typename] = ACTIONS(2004),
    [anon_sym_template] = ACTIONS(2004),
    [anon_sym_operator] = ACTIONS(2004),
    [anon_sym_try] = ACTIONS(2004),
    [anon_sym_delete] = ACTIONS(2004),
    [anon_sym_throw] = ACTIONS(2004),
    [anon_sym_namespace] = ACTIONS(2004),
    [anon_sym_using] = ACTIONS(2004),
    [anon_sym_static_assert] = ACTIONS(2004),
    [anon_sym_concept] = ACTIONS(2004),
    [anon_sym_co_return] = ACTIONS(2004),
    [anon_sym_co_yield] = ACTIONS(2004),
    [anon_sym_R_DQUOTE] = ACTIONS(2006),
    [anon_sym_LR_DQUOTE] = ACTIONS(2006),
    [anon_sym_uR_DQUOTE] = ACTIONS(2006),
    [anon_sym_UR_DQUOTE] = ACTIONS(2006),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2006),
    [anon_sym_co_await] = ACTIONS(2004),
    [anon_sym_new] = ACTIONS(2004),
    [anon_sym_requires] = ACTIONS(2004),
    [sym_this] = ACTIONS(2004),
    [anon_sym_discard] = ACTIONS(2004),
    [anon_sym_precise] = ACTIONS(2004),
    [anon_sym_shared] = ACTIONS(2004),
    [anon_sym_groupshared] = ACTIONS(2004),
    [anon_sym_uniform] = ACTIONS(2004),
    [anon_sym_row_major] = ACTIONS(2004),
    [anon_sym_column_major] = ACTIONS(2004),
    [anon_sym_globallycoherent] = ACTIONS(2004),
    [anon_sym_centroid] = ACTIONS(2004),
    [anon_sym_noperspective] = ACTIONS(2004),
    [anon_sym_nointerpolation] = ACTIONS(2004),
    [anon_sym_sample] = ACTIONS(2004),
    [anon_sym_linear] = ACTIONS(2004),
    [anon_sym_snorm] = ACTIONS(2004),
    [anon_sym_unorm] = ACTIONS(2004),
    [anon_sym_point] = ACTIONS(2004),
    [anon_sym_line] = ACTIONS(2004),
    [anon_sym_triangleadj] = ACTIONS(2004),
    [anon_sym_lineadj] = ACTIONS(2004),
    [anon_sym_triangle] = ACTIONS(2004),
    [anon_sym_cbuffer] = ACTIONS(2004),
  },
  [357] = {
    [sym_preproc_def] = STATE(702),
    [sym_preproc_function_def] = STATE(702),
    [sym_preproc_call] = STATE(702),
    [sym_preproc_if_in_field_declaration_list] = STATE(702),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(702),
    [sym_preproc_else_in_field_declaration_list] = STATE(8071),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8071),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8071),
    [sym_type_definition] = STATE(702),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5626),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6102),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(702),
    [sym_field_declaration] = STATE(702),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1832),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(702),
    [sym_operator_cast] = STATE(6636),
    [sym_inline_method_definition] = STATE(702),
    [sym__constructor_specifiers] = STATE(1832),
    [sym_operator_cast_definition] = STATE(702),
    [sym_operator_cast_declaration] = STATE(702),
    [sym_constructor_or_destructor_definition] = STATE(702),
    [sym_constructor_or_destructor_declaration] = STATE(702),
    [sym_friend_declaration] = STATE(702),
    [sym_access_specifier] = STATE(8379),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(702),
    [sym_alias_declaration] = STATE(702),
    [sym_static_assert_declaration] = STATE(702),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6636),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(702),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1832),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2587),
    [aux_sym_preproc_if_token2] = ACTIONS(2643),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2591),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2591),
    [aux_sym_preproc_else_token1] = ACTIONS(2593),
    [aux_sym_preproc_elif_token1] = ACTIONS(2595),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2597),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2597),
    [sym_preproc_directive] = ACTIONS(2599),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2609),
    [anon_sym_typedef] = ACTIONS(2611),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2629),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2631),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2635),
    [anon_sym_static_assert] = ACTIONS(2637),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [358] = {
    [sym_else_clause] = STATE(498),
    [sym_identifier] = ACTIONS(1994),
    [aux_sym_preproc_include_token1] = ACTIONS(1994),
    [aux_sym_preproc_def_token1] = ACTIONS(1994),
    [aux_sym_preproc_if_token1] = ACTIONS(1994),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1994),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1994),
    [sym_preproc_directive] = ACTIONS(1994),
    [anon_sym_LPAREN2] = ACTIONS(1996),
    [anon_sym_BANG] = ACTIONS(1996),
    [anon_sym_TILDE] = ACTIONS(1996),
    [anon_sym_DASH] = ACTIONS(1994),
    [anon_sym_PLUS] = ACTIONS(1994),
    [anon_sym_STAR] = ACTIONS(1996),
    [anon_sym_AMP_AMP] = ACTIONS(1996),
    [anon_sym_AMP] = ACTIONS(1994),
    [anon_sym_SEMI] = ACTIONS(1996),
    [anon_sym___extension__] = ACTIONS(1994),
    [anon_sym_typedef] = ACTIONS(1994),
    [anon_sym_in] = ACTIONS(1994),
    [anon_sym_out] = ACTIONS(1994),
    [anon_sym_inout] = ACTIONS(1994),
    [anon_sym_extern] = ACTIONS(1994),
    [anon_sym___attribute__] = ACTIONS(1994),
    [anon_sym_COLON_COLON] = ACTIONS(1996),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1996),
    [anon_sym___declspec] = ACTIONS(1994),
    [anon_sym___based] = ACTIONS(1994),
    [anon_sym___cdecl] = ACTIONS(1994),
    [anon_sym___clrcall] = ACTIONS(1994),
    [anon_sym___stdcall] = ACTIONS(1994),
    [anon_sym___fastcall] = ACTIONS(1994),
    [anon_sym___thiscall] = ACTIONS(1994),
    [anon_sym___vectorcall] = ACTIONS(1994),
    [anon_sym_LBRACE] = ACTIONS(1996),
    [anon_sym_RBRACE] = ACTIONS(1996),
    [anon_sym_signed] = ACTIONS(1994),
    [anon_sym_unsigned] = ACTIONS(1994),
    [anon_sym_long] = ACTIONS(1994),
    [anon_sym_short] = ACTIONS(1994),
    [anon_sym_LBRACK] = ACTIONS(1994),
    [anon_sym_static] = ACTIONS(1994),
    [anon_sym_register] = ACTIONS(1994),
    [anon_sym_inline] = ACTIONS(1994),
    [anon_sym___inline] = ACTIONS(1994),
    [anon_sym___inline__] = ACTIONS(1994),
    [anon_sym___forceinline] = ACTIONS(1994),
    [anon_sym_thread_local] = ACTIONS(1994),
    [anon_sym___thread] = ACTIONS(1994),
    [anon_sym_const] = ACTIONS(1994),
    [anon_sym_constexpr] = ACTIONS(1994),
    [anon_sym_volatile] = ACTIONS(1994),
    [anon_sym_restrict] = ACTIONS(1994),
    [anon_sym___restrict__] = ACTIONS(1994),
    [anon_sym__Atomic] = ACTIONS(1994),
    [anon_sym__Noreturn] = ACTIONS(1994),
    [anon_sym_noreturn] = ACTIONS(1994),
    [anon_sym_mutable] = ACTIONS(1994),
    [anon_sym_constinit] = ACTIONS(1994),
    [anon_sym_consteval] = ACTIONS(1994),
    [anon_sym_alignas] = ACTIONS(1994),
    [anon_sym__Alignas] = ACTIONS(1994),
    [sym_primitive_type] = ACTIONS(1994),
    [anon_sym_enum] = ACTIONS(1994),
    [anon_sym_class] = ACTIONS(1994),
    [anon_sym_struct] = ACTIONS(1994),
    [anon_sym_union] = ACTIONS(1994),
    [anon_sym_if] = ACTIONS(1994),
    [anon_sym_else] = ACTIONS(2645),
    [anon_sym_switch] = ACTIONS(1994),
    [anon_sym_case] = ACTIONS(1994),
    [anon_sym_default] = ACTIONS(1994),
    [anon_sym_while] = ACTIONS(1994),
    [anon_sym_do] = ACTIONS(1994),
    [anon_sym_for] = ACTIONS(1994),
    [anon_sym_return] = ACTIONS(1994),
    [anon_sym_break] = ACTIONS(1994),
    [anon_sym_continue] = ACTIONS(1994),
    [anon_sym_goto] = ACTIONS(1994),
    [anon_sym___try] = ACTIONS(1994),
    [anon_sym___leave] = ACTIONS(1994),
    [anon_sym_not] = ACTIONS(1994),
    [anon_sym_compl] = ACTIONS(1994),
    [anon_sym_DASH_DASH] = ACTIONS(1996),
    [anon_sym_PLUS_PLUS] = ACTIONS(1996),
    [anon_sym_sizeof] = ACTIONS(1994),
    [anon_sym___alignof__] = ACTIONS(1994),
    [anon_sym___alignof] = ACTIONS(1994),
    [anon_sym__alignof] = ACTIONS(1994),
    [anon_sym_alignof] = ACTIONS(1994),
    [anon_sym__Alignof] = ACTIONS(1994),
    [anon_sym_offsetof] = ACTIONS(1994),
    [anon_sym__Generic] = ACTIONS(1994),
    [anon_sym_asm] = ACTIONS(1994),
    [anon_sym___asm__] = ACTIONS(1994),
    [sym_number_literal] = ACTIONS(1996),
    [anon_sym_L_SQUOTE] = ACTIONS(1996),
    [anon_sym_u_SQUOTE] = ACTIONS(1996),
    [anon_sym_U_SQUOTE] = ACTIONS(1996),
    [anon_sym_u8_SQUOTE] = ACTIONS(1996),
    [anon_sym_SQUOTE] = ACTIONS(1996),
    [anon_sym_L_DQUOTE] = ACTIONS(1996),
    [anon_sym_u_DQUOTE] = ACTIONS(1996),
    [anon_sym_U_DQUOTE] = ACTIONS(1996),
    [anon_sym_u8_DQUOTE] = ACTIONS(1996),
    [anon_sym_DQUOTE] = ACTIONS(1996),
    [sym_true] = ACTIONS(1994),
    [sym_false] = ACTIONS(1994),
    [anon_sym_NULL] = ACTIONS(1994),
    [anon_sym_nullptr] = ACTIONS(1994),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1994),
    [anon_sym_decltype] = ACTIONS(1994),
    [sym_virtual] = ACTIONS(1994),
    [anon_sym_explicit] = ACTIONS(1994),
    [anon_sym_typename] = ACTIONS(1994),
    [anon_sym_template] = ACTIONS(1994),
    [anon_sym_operator] = ACTIONS(1994),
    [anon_sym_try] = ACTIONS(1994),
    [anon_sym_delete] = ACTIONS(1994),
    [anon_sym_throw] = ACTIONS(1994),
    [anon_sym_namespace] = ACTIONS(1994),
    [anon_sym_using] = ACTIONS(1994),
    [anon_sym_static_assert] = ACTIONS(1994),
    [anon_sym_concept] = ACTIONS(1994),
    [anon_sym_co_return] = ACTIONS(1994),
    [anon_sym_co_yield] = ACTIONS(1994),
    [anon_sym_R_DQUOTE] = ACTIONS(1996),
    [anon_sym_LR_DQUOTE] = ACTIONS(1996),
    [anon_sym_uR_DQUOTE] = ACTIONS(1996),
    [anon_sym_UR_DQUOTE] = ACTIONS(1996),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1996),
    [anon_sym_co_await] = ACTIONS(1994),
    [anon_sym_new] = ACTIONS(1994),
    [anon_sym_requires] = ACTIONS(1994),
    [sym_this] = ACTIONS(1994),
    [anon_sym_discard] = ACTIONS(1994),
    [anon_sym_precise] = ACTIONS(1994),
    [anon_sym_shared] = ACTIONS(1994),
    [anon_sym_groupshared] = ACTIONS(1994),
    [anon_sym_uniform] = ACTIONS(1994),
    [anon_sym_row_major] = ACTIONS(1994),
    [anon_sym_column_major] = ACTIONS(1994),
    [anon_sym_globallycoherent] = ACTIONS(1994),
    [anon_sym_centroid] = ACTIONS(1994),
    [anon_sym_noperspective] = ACTIONS(1994),
    [anon_sym_nointerpolation] = ACTIONS(1994),
    [anon_sym_sample] = ACTIONS(1994),
    [anon_sym_linear] = ACTIONS(1994),
    [anon_sym_snorm] = ACTIONS(1994),
    [anon_sym_unorm] = ACTIONS(1994),
    [anon_sym_point] = ACTIONS(1994),
    [anon_sym_line] = ACTIONS(1994),
    [anon_sym_triangleadj] = ACTIONS(1994),
    [anon_sym_lineadj] = ACTIONS(1994),
    [anon_sym_triangle] = ACTIONS(1994),
    [anon_sym_cbuffer] = ACTIONS(1994),
  },
  [359] = {
    [sym_preproc_def] = STATE(702),
    [sym_preproc_function_def] = STATE(702),
    [sym_preproc_call] = STATE(702),
    [sym_preproc_if_in_field_declaration_list] = STATE(702),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(702),
    [sym_preproc_else_in_field_declaration_list] = STATE(8085),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8085),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8085),
    [sym_type_definition] = STATE(702),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5626),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6102),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(702),
    [sym_field_declaration] = STATE(702),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1832),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(702),
    [sym_operator_cast] = STATE(6636),
    [sym_inline_method_definition] = STATE(702),
    [sym__constructor_specifiers] = STATE(1832),
    [sym_operator_cast_definition] = STATE(702),
    [sym_operator_cast_declaration] = STATE(702),
    [sym_constructor_or_destructor_definition] = STATE(702),
    [sym_constructor_or_destructor_declaration] = STATE(702),
    [sym_friend_declaration] = STATE(702),
    [sym_access_specifier] = STATE(8379),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(702),
    [sym_alias_declaration] = STATE(702),
    [sym_static_assert_declaration] = STATE(702),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6636),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(702),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1832),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2587),
    [aux_sym_preproc_if_token2] = ACTIONS(2647),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2591),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2591),
    [aux_sym_preproc_else_token1] = ACTIONS(2593),
    [aux_sym_preproc_elif_token1] = ACTIONS(2595),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2597),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2597),
    [sym_preproc_directive] = ACTIONS(2599),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2609),
    [anon_sym_typedef] = ACTIONS(2611),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2629),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2631),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2635),
    [anon_sym_static_assert] = ACTIONS(2637),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [360] = {
    [sym_preproc_def] = STATE(357),
    [sym_preproc_function_def] = STATE(357),
    [sym_preproc_call] = STATE(357),
    [sym_preproc_if_in_field_declaration_list] = STATE(357),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(357),
    [sym_preproc_else_in_field_declaration_list] = STATE(8086),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8086),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8086),
    [sym_type_definition] = STATE(357),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5626),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6102),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(357),
    [sym_field_declaration] = STATE(357),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1832),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(357),
    [sym_operator_cast] = STATE(6636),
    [sym_inline_method_definition] = STATE(357),
    [sym__constructor_specifiers] = STATE(1832),
    [sym_operator_cast_definition] = STATE(357),
    [sym_operator_cast_declaration] = STATE(357),
    [sym_constructor_or_destructor_definition] = STATE(357),
    [sym_constructor_or_destructor_declaration] = STATE(357),
    [sym_friend_declaration] = STATE(357),
    [sym_access_specifier] = STATE(8379),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(357),
    [sym_alias_declaration] = STATE(357),
    [sym_static_assert_declaration] = STATE(357),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6636),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(357),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1832),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2587),
    [aux_sym_preproc_if_token2] = ACTIONS(2649),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2591),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2591),
    [aux_sym_preproc_else_token1] = ACTIONS(2593),
    [aux_sym_preproc_elif_token1] = ACTIONS(2595),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2597),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2597),
    [sym_preproc_directive] = ACTIONS(2599),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2609),
    [anon_sym_typedef] = ACTIONS(2611),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2629),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2631),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2635),
    [anon_sym_static_assert] = ACTIONS(2637),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [361] = {
    [sym_identifier] = ACTIONS(2012),
    [aux_sym_preproc_include_token1] = ACTIONS(2012),
    [aux_sym_preproc_def_token1] = ACTIONS(2012),
    [aux_sym_preproc_if_token1] = ACTIONS(2012),
    [aux_sym_preproc_if_token2] = ACTIONS(2012),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2012),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2012),
    [sym_preproc_directive] = ACTIONS(2012),
    [anon_sym_LPAREN2] = ACTIONS(2014),
    [anon_sym_BANG] = ACTIONS(2014),
    [anon_sym_TILDE] = ACTIONS(2014),
    [anon_sym_DASH] = ACTIONS(2012),
    [anon_sym_PLUS] = ACTIONS(2012),
    [anon_sym_STAR] = ACTIONS(2014),
    [anon_sym_AMP_AMP] = ACTIONS(2014),
    [anon_sym_AMP] = ACTIONS(2012),
    [anon_sym_SEMI] = ACTIONS(2014),
    [anon_sym___extension__] = ACTIONS(2012),
    [anon_sym_typedef] = ACTIONS(2012),
    [anon_sym_in] = ACTIONS(2012),
    [anon_sym_out] = ACTIONS(2012),
    [anon_sym_inout] = ACTIONS(2012),
    [anon_sym_extern] = ACTIONS(2012),
    [anon_sym___attribute__] = ACTIONS(2012),
    [anon_sym_COLON_COLON] = ACTIONS(2014),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2014),
    [anon_sym___declspec] = ACTIONS(2012),
    [anon_sym___based] = ACTIONS(2012),
    [anon_sym___cdecl] = ACTIONS(2012),
    [anon_sym___clrcall] = ACTIONS(2012),
    [anon_sym___stdcall] = ACTIONS(2012),
    [anon_sym___fastcall] = ACTIONS(2012),
    [anon_sym___thiscall] = ACTIONS(2012),
    [anon_sym___vectorcall] = ACTIONS(2012),
    [anon_sym_LBRACE] = ACTIONS(2014),
    [anon_sym_signed] = ACTIONS(2012),
    [anon_sym_unsigned] = ACTIONS(2012),
    [anon_sym_long] = ACTIONS(2012),
    [anon_sym_short] = ACTIONS(2012),
    [anon_sym_LBRACK] = ACTIONS(2012),
    [anon_sym_static] = ACTIONS(2012),
    [anon_sym_register] = ACTIONS(2012),
    [anon_sym_inline] = ACTIONS(2012),
    [anon_sym___inline] = ACTIONS(2012),
    [anon_sym___inline__] = ACTIONS(2012),
    [anon_sym___forceinline] = ACTIONS(2012),
    [anon_sym_thread_local] = ACTIONS(2012),
    [anon_sym___thread] = ACTIONS(2012),
    [anon_sym_const] = ACTIONS(2012),
    [anon_sym_constexpr] = ACTIONS(2012),
    [anon_sym_volatile] = ACTIONS(2012),
    [anon_sym_restrict] = ACTIONS(2012),
    [anon_sym___restrict__] = ACTIONS(2012),
    [anon_sym__Atomic] = ACTIONS(2012),
    [anon_sym__Noreturn] = ACTIONS(2012),
    [anon_sym_noreturn] = ACTIONS(2012),
    [anon_sym_mutable] = ACTIONS(2012),
    [anon_sym_constinit] = ACTIONS(2012),
    [anon_sym_consteval] = ACTIONS(2012),
    [anon_sym_alignas] = ACTIONS(2012),
    [anon_sym__Alignas] = ACTIONS(2012),
    [sym_primitive_type] = ACTIONS(2012),
    [anon_sym_enum] = ACTIONS(2012),
    [anon_sym_class] = ACTIONS(2012),
    [anon_sym_struct] = ACTIONS(2012),
    [anon_sym_union] = ACTIONS(2012),
    [anon_sym_if] = ACTIONS(2012),
    [anon_sym_else] = ACTIONS(2012),
    [anon_sym_switch] = ACTIONS(2012),
    [anon_sym_case] = ACTIONS(2012),
    [anon_sym_default] = ACTIONS(2012),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_do] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2012),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_break] = ACTIONS(2012),
    [anon_sym_continue] = ACTIONS(2012),
    [anon_sym_goto] = ACTIONS(2012),
    [anon_sym___try] = ACTIONS(2012),
    [anon_sym___leave] = ACTIONS(2012),
    [anon_sym_not] = ACTIONS(2012),
    [anon_sym_compl] = ACTIONS(2012),
    [anon_sym_DASH_DASH] = ACTIONS(2014),
    [anon_sym_PLUS_PLUS] = ACTIONS(2014),
    [anon_sym_sizeof] = ACTIONS(2012),
    [anon_sym___alignof__] = ACTIONS(2012),
    [anon_sym___alignof] = ACTIONS(2012),
    [anon_sym__alignof] = ACTIONS(2012),
    [anon_sym_alignof] = ACTIONS(2012),
    [anon_sym__Alignof] = ACTIONS(2012),
    [anon_sym_offsetof] = ACTIONS(2012),
    [anon_sym__Generic] = ACTIONS(2012),
    [anon_sym_asm] = ACTIONS(2012),
    [anon_sym___asm__] = ACTIONS(2012),
    [sym_number_literal] = ACTIONS(2014),
    [anon_sym_L_SQUOTE] = ACTIONS(2014),
    [anon_sym_u_SQUOTE] = ACTIONS(2014),
    [anon_sym_U_SQUOTE] = ACTIONS(2014),
    [anon_sym_u8_SQUOTE] = ACTIONS(2014),
    [anon_sym_SQUOTE] = ACTIONS(2014),
    [anon_sym_L_DQUOTE] = ACTIONS(2014),
    [anon_sym_u_DQUOTE] = ACTIONS(2014),
    [anon_sym_U_DQUOTE] = ACTIONS(2014),
    [anon_sym_u8_DQUOTE] = ACTIONS(2014),
    [anon_sym_DQUOTE] = ACTIONS(2014),
    [sym_true] = ACTIONS(2012),
    [sym_false] = ACTIONS(2012),
    [anon_sym_NULL] = ACTIONS(2012),
    [anon_sym_nullptr] = ACTIONS(2012),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2012),
    [anon_sym_decltype] = ACTIONS(2012),
    [sym_virtual] = ACTIONS(2012),
    [anon_sym_explicit] = ACTIONS(2012),
    [anon_sym_typename] = ACTIONS(2012),
    [anon_sym_template] = ACTIONS(2012),
    [anon_sym_operator] = ACTIONS(2012),
    [anon_sym_try] = ACTIONS(2012),
    [anon_sym_delete] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2012),
    [anon_sym_namespace] = ACTIONS(2012),
    [anon_sym_using] = ACTIONS(2012),
    [anon_sym_static_assert] = ACTIONS(2012),
    [anon_sym_concept] = ACTIONS(2012),
    [anon_sym_co_return] = ACTIONS(2012),
    [anon_sym_co_yield] = ACTIONS(2012),
    [anon_sym_catch] = ACTIONS(2012),
    [anon_sym_R_DQUOTE] = ACTIONS(2014),
    [anon_sym_LR_DQUOTE] = ACTIONS(2014),
    [anon_sym_uR_DQUOTE] = ACTIONS(2014),
    [anon_sym_UR_DQUOTE] = ACTIONS(2014),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2014),
    [anon_sym_co_await] = ACTIONS(2012),
    [anon_sym_new] = ACTIONS(2012),
    [anon_sym_requires] = ACTIONS(2012),
    [sym_this] = ACTIONS(2012),
    [anon_sym_discard] = ACTIONS(2012),
    [anon_sym_precise] = ACTIONS(2012),
    [anon_sym_shared] = ACTIONS(2012),
    [anon_sym_groupshared] = ACTIONS(2012),
    [anon_sym_uniform] = ACTIONS(2012),
    [anon_sym_row_major] = ACTIONS(2012),
    [anon_sym_column_major] = ACTIONS(2012),
    [anon_sym_globallycoherent] = ACTIONS(2012),
    [anon_sym_centroid] = ACTIONS(2012),
    [anon_sym_noperspective] = ACTIONS(2012),
    [anon_sym_nointerpolation] = ACTIONS(2012),
    [anon_sym_sample] = ACTIONS(2012),
    [anon_sym_linear] = ACTIONS(2012),
    [anon_sym_snorm] = ACTIONS(2012),
    [anon_sym_unorm] = ACTIONS(2012),
    [anon_sym_point] = ACTIONS(2012),
    [anon_sym_line] = ACTIONS(2012),
    [anon_sym_triangleadj] = ACTIONS(2012),
    [anon_sym_lineadj] = ACTIONS(2012),
    [anon_sym_triangle] = ACTIONS(2012),
    [anon_sym_cbuffer] = ACTIONS(2012),
  },
  [362] = {
    [sym_identifier] = ACTIONS(2012),
    [aux_sym_preproc_include_token1] = ACTIONS(2012),
    [aux_sym_preproc_def_token1] = ACTIONS(2012),
    [aux_sym_preproc_if_token1] = ACTIONS(2012),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2012),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2012),
    [sym_preproc_directive] = ACTIONS(2012),
    [anon_sym_LPAREN2] = ACTIONS(2014),
    [anon_sym_BANG] = ACTIONS(2014),
    [anon_sym_TILDE] = ACTIONS(2014),
    [anon_sym_DASH] = ACTIONS(2012),
    [anon_sym_PLUS] = ACTIONS(2012),
    [anon_sym_STAR] = ACTIONS(2014),
    [anon_sym_AMP_AMP] = ACTIONS(2014),
    [anon_sym_AMP] = ACTIONS(2012),
    [anon_sym_SEMI] = ACTIONS(2014),
    [anon_sym___extension__] = ACTIONS(2012),
    [anon_sym_typedef] = ACTIONS(2012),
    [anon_sym_in] = ACTIONS(2012),
    [anon_sym_out] = ACTIONS(2012),
    [anon_sym_inout] = ACTIONS(2012),
    [anon_sym_extern] = ACTIONS(2012),
    [anon_sym___attribute__] = ACTIONS(2012),
    [anon_sym_COLON_COLON] = ACTIONS(2014),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2014),
    [anon_sym___declspec] = ACTIONS(2012),
    [anon_sym___based] = ACTIONS(2012),
    [anon_sym___cdecl] = ACTIONS(2012),
    [anon_sym___clrcall] = ACTIONS(2012),
    [anon_sym___stdcall] = ACTIONS(2012),
    [anon_sym___fastcall] = ACTIONS(2012),
    [anon_sym___thiscall] = ACTIONS(2012),
    [anon_sym___vectorcall] = ACTIONS(2012),
    [anon_sym_LBRACE] = ACTIONS(2014),
    [anon_sym_RBRACE] = ACTIONS(2014),
    [anon_sym_signed] = ACTIONS(2012),
    [anon_sym_unsigned] = ACTIONS(2012),
    [anon_sym_long] = ACTIONS(2012),
    [anon_sym_short] = ACTIONS(2012),
    [anon_sym_LBRACK] = ACTIONS(2012),
    [anon_sym_static] = ACTIONS(2012),
    [anon_sym_register] = ACTIONS(2012),
    [anon_sym_inline] = ACTIONS(2012),
    [anon_sym___inline] = ACTIONS(2012),
    [anon_sym___inline__] = ACTIONS(2012),
    [anon_sym___forceinline] = ACTIONS(2012),
    [anon_sym_thread_local] = ACTIONS(2012),
    [anon_sym___thread] = ACTIONS(2012),
    [anon_sym_const] = ACTIONS(2012),
    [anon_sym_constexpr] = ACTIONS(2012),
    [anon_sym_volatile] = ACTIONS(2012),
    [anon_sym_restrict] = ACTIONS(2012),
    [anon_sym___restrict__] = ACTIONS(2012),
    [anon_sym__Atomic] = ACTIONS(2012),
    [anon_sym__Noreturn] = ACTIONS(2012),
    [anon_sym_noreturn] = ACTIONS(2012),
    [anon_sym_mutable] = ACTIONS(2012),
    [anon_sym_constinit] = ACTIONS(2012),
    [anon_sym_consteval] = ACTIONS(2012),
    [anon_sym_alignas] = ACTIONS(2012),
    [anon_sym__Alignas] = ACTIONS(2012),
    [sym_primitive_type] = ACTIONS(2012),
    [anon_sym_enum] = ACTIONS(2012),
    [anon_sym_class] = ACTIONS(2012),
    [anon_sym_struct] = ACTIONS(2012),
    [anon_sym_union] = ACTIONS(2012),
    [anon_sym_if] = ACTIONS(2012),
    [anon_sym_else] = ACTIONS(2012),
    [anon_sym_switch] = ACTIONS(2012),
    [anon_sym_case] = ACTIONS(2012),
    [anon_sym_default] = ACTIONS(2012),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_do] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2012),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_break] = ACTIONS(2012),
    [anon_sym_continue] = ACTIONS(2012),
    [anon_sym_goto] = ACTIONS(2012),
    [anon_sym___try] = ACTIONS(2012),
    [anon_sym___leave] = ACTIONS(2012),
    [anon_sym_not] = ACTIONS(2012),
    [anon_sym_compl] = ACTIONS(2012),
    [anon_sym_DASH_DASH] = ACTIONS(2014),
    [anon_sym_PLUS_PLUS] = ACTIONS(2014),
    [anon_sym_sizeof] = ACTIONS(2012),
    [anon_sym___alignof__] = ACTIONS(2012),
    [anon_sym___alignof] = ACTIONS(2012),
    [anon_sym__alignof] = ACTIONS(2012),
    [anon_sym_alignof] = ACTIONS(2012),
    [anon_sym__Alignof] = ACTIONS(2012),
    [anon_sym_offsetof] = ACTIONS(2012),
    [anon_sym__Generic] = ACTIONS(2012),
    [anon_sym_asm] = ACTIONS(2012),
    [anon_sym___asm__] = ACTIONS(2012),
    [sym_number_literal] = ACTIONS(2014),
    [anon_sym_L_SQUOTE] = ACTIONS(2014),
    [anon_sym_u_SQUOTE] = ACTIONS(2014),
    [anon_sym_U_SQUOTE] = ACTIONS(2014),
    [anon_sym_u8_SQUOTE] = ACTIONS(2014),
    [anon_sym_SQUOTE] = ACTIONS(2014),
    [anon_sym_L_DQUOTE] = ACTIONS(2014),
    [anon_sym_u_DQUOTE] = ACTIONS(2014),
    [anon_sym_U_DQUOTE] = ACTIONS(2014),
    [anon_sym_u8_DQUOTE] = ACTIONS(2014),
    [anon_sym_DQUOTE] = ACTIONS(2014),
    [sym_true] = ACTIONS(2012),
    [sym_false] = ACTIONS(2012),
    [anon_sym_NULL] = ACTIONS(2012),
    [anon_sym_nullptr] = ACTIONS(2012),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2012),
    [anon_sym_decltype] = ACTIONS(2012),
    [sym_virtual] = ACTIONS(2012),
    [anon_sym_explicit] = ACTIONS(2012),
    [anon_sym_typename] = ACTIONS(2012),
    [anon_sym_template] = ACTIONS(2012),
    [anon_sym_operator] = ACTIONS(2012),
    [anon_sym_try] = ACTIONS(2012),
    [anon_sym_delete] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2012),
    [anon_sym_namespace] = ACTIONS(2012),
    [anon_sym_using] = ACTIONS(2012),
    [anon_sym_static_assert] = ACTIONS(2012),
    [anon_sym_concept] = ACTIONS(2012),
    [anon_sym_co_return] = ACTIONS(2012),
    [anon_sym_co_yield] = ACTIONS(2012),
    [anon_sym_catch] = ACTIONS(2012),
    [anon_sym_R_DQUOTE] = ACTIONS(2014),
    [anon_sym_LR_DQUOTE] = ACTIONS(2014),
    [anon_sym_uR_DQUOTE] = ACTIONS(2014),
    [anon_sym_UR_DQUOTE] = ACTIONS(2014),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2014),
    [anon_sym_co_await] = ACTIONS(2012),
    [anon_sym_new] = ACTIONS(2012),
    [anon_sym_requires] = ACTIONS(2012),
    [sym_this] = ACTIONS(2012),
    [anon_sym_discard] = ACTIONS(2012),
    [anon_sym_precise] = ACTIONS(2012),
    [anon_sym_shared] = ACTIONS(2012),
    [anon_sym_groupshared] = ACTIONS(2012),
    [anon_sym_uniform] = ACTIONS(2012),
    [anon_sym_row_major] = ACTIONS(2012),
    [anon_sym_column_major] = ACTIONS(2012),
    [anon_sym_globallycoherent] = ACTIONS(2012),
    [anon_sym_centroid] = ACTIONS(2012),
    [anon_sym_noperspective] = ACTIONS(2012),
    [anon_sym_nointerpolation] = ACTIONS(2012),
    [anon_sym_sample] = ACTIONS(2012),
    [anon_sym_linear] = ACTIONS(2012),
    [anon_sym_snorm] = ACTIONS(2012),
    [anon_sym_unorm] = ACTIONS(2012),
    [anon_sym_point] = ACTIONS(2012),
    [anon_sym_line] = ACTIONS(2012),
    [anon_sym_triangleadj] = ACTIONS(2012),
    [anon_sym_lineadj] = ACTIONS(2012),
    [anon_sym_triangle] = ACTIONS(2012),
    [anon_sym_cbuffer] = ACTIONS(2012),
  },
  [363] = {
    [sym_preproc_def] = STATE(354),
    [sym_preproc_function_def] = STATE(354),
    [sym_preproc_call] = STATE(354),
    [sym_preproc_if_in_field_declaration_list] = STATE(354),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(354),
    [sym_preproc_else_in_field_declaration_list] = STATE(8333),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8333),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8333),
    [sym_type_definition] = STATE(354),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5626),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6102),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(354),
    [sym_field_declaration] = STATE(354),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1832),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(354),
    [sym_operator_cast] = STATE(6636),
    [sym_inline_method_definition] = STATE(354),
    [sym__constructor_specifiers] = STATE(1832),
    [sym_operator_cast_definition] = STATE(354),
    [sym_operator_cast_declaration] = STATE(354),
    [sym_constructor_or_destructor_definition] = STATE(354),
    [sym_constructor_or_destructor_declaration] = STATE(354),
    [sym_friend_declaration] = STATE(354),
    [sym_access_specifier] = STATE(8379),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(354),
    [sym_alias_declaration] = STATE(354),
    [sym_static_assert_declaration] = STATE(354),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6636),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(354),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1832),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2587),
    [aux_sym_preproc_if_token2] = ACTIONS(2651),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2591),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2591),
    [aux_sym_preproc_else_token1] = ACTIONS(2593),
    [aux_sym_preproc_elif_token1] = ACTIONS(2595),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2597),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2597),
    [sym_preproc_directive] = ACTIONS(2599),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2609),
    [anon_sym_typedef] = ACTIONS(2611),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2629),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2631),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2635),
    [anon_sym_static_assert] = ACTIONS(2637),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [364] = {
    [sym_else_clause] = STATE(454),
    [ts_builtin_sym_end] = ACTIONS(1996),
    [sym_identifier] = ACTIONS(1994),
    [aux_sym_preproc_include_token1] = ACTIONS(1994),
    [aux_sym_preproc_def_token1] = ACTIONS(1994),
    [aux_sym_preproc_if_token1] = ACTIONS(1994),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1994),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1994),
    [sym_preproc_directive] = ACTIONS(1994),
    [anon_sym_LPAREN2] = ACTIONS(1996),
    [anon_sym_BANG] = ACTIONS(1996),
    [anon_sym_TILDE] = ACTIONS(1996),
    [anon_sym_DASH] = ACTIONS(1994),
    [anon_sym_PLUS] = ACTIONS(1994),
    [anon_sym_STAR] = ACTIONS(1996),
    [anon_sym_AMP_AMP] = ACTIONS(1996),
    [anon_sym_AMP] = ACTIONS(1994),
    [anon_sym_SEMI] = ACTIONS(1996),
    [anon_sym___extension__] = ACTIONS(1994),
    [anon_sym_typedef] = ACTIONS(1994),
    [anon_sym_in] = ACTIONS(1994),
    [anon_sym_out] = ACTIONS(1994),
    [anon_sym_inout] = ACTIONS(1994),
    [anon_sym_extern] = ACTIONS(1994),
    [anon_sym___attribute__] = ACTIONS(1994),
    [anon_sym_COLON_COLON] = ACTIONS(1996),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1996),
    [anon_sym___declspec] = ACTIONS(1994),
    [anon_sym___based] = ACTIONS(1994),
    [anon_sym___cdecl] = ACTIONS(1994),
    [anon_sym___clrcall] = ACTIONS(1994),
    [anon_sym___stdcall] = ACTIONS(1994),
    [anon_sym___fastcall] = ACTIONS(1994),
    [anon_sym___thiscall] = ACTIONS(1994),
    [anon_sym___vectorcall] = ACTIONS(1994),
    [anon_sym_LBRACE] = ACTIONS(1996),
    [anon_sym_signed] = ACTIONS(1994),
    [anon_sym_unsigned] = ACTIONS(1994),
    [anon_sym_long] = ACTIONS(1994),
    [anon_sym_short] = ACTIONS(1994),
    [anon_sym_LBRACK] = ACTIONS(1994),
    [anon_sym_static] = ACTIONS(1994),
    [anon_sym_register] = ACTIONS(1994),
    [anon_sym_inline] = ACTIONS(1994),
    [anon_sym___inline] = ACTIONS(1994),
    [anon_sym___inline__] = ACTIONS(1994),
    [anon_sym___forceinline] = ACTIONS(1994),
    [anon_sym_thread_local] = ACTIONS(1994),
    [anon_sym___thread] = ACTIONS(1994),
    [anon_sym_const] = ACTIONS(1994),
    [anon_sym_constexpr] = ACTIONS(1994),
    [anon_sym_volatile] = ACTIONS(1994),
    [anon_sym_restrict] = ACTIONS(1994),
    [anon_sym___restrict__] = ACTIONS(1994),
    [anon_sym__Atomic] = ACTIONS(1994),
    [anon_sym__Noreturn] = ACTIONS(1994),
    [anon_sym_noreturn] = ACTIONS(1994),
    [anon_sym_mutable] = ACTIONS(1994),
    [anon_sym_constinit] = ACTIONS(1994),
    [anon_sym_consteval] = ACTIONS(1994),
    [anon_sym_alignas] = ACTIONS(1994),
    [anon_sym__Alignas] = ACTIONS(1994),
    [sym_primitive_type] = ACTIONS(1994),
    [anon_sym_enum] = ACTIONS(1994),
    [anon_sym_class] = ACTIONS(1994),
    [anon_sym_struct] = ACTIONS(1994),
    [anon_sym_union] = ACTIONS(1994),
    [anon_sym_if] = ACTIONS(1994),
    [anon_sym_else] = ACTIONS(2653),
    [anon_sym_switch] = ACTIONS(1994),
    [anon_sym_case] = ACTIONS(1994),
    [anon_sym_default] = ACTIONS(1994),
    [anon_sym_while] = ACTIONS(1994),
    [anon_sym_do] = ACTIONS(1994),
    [anon_sym_for] = ACTIONS(1994),
    [anon_sym_return] = ACTIONS(1994),
    [anon_sym_break] = ACTIONS(1994),
    [anon_sym_continue] = ACTIONS(1994),
    [anon_sym_goto] = ACTIONS(1994),
    [anon_sym___try] = ACTIONS(1994),
    [anon_sym___leave] = ACTIONS(1994),
    [anon_sym_not] = ACTIONS(1994),
    [anon_sym_compl] = ACTIONS(1994),
    [anon_sym_DASH_DASH] = ACTIONS(1996),
    [anon_sym_PLUS_PLUS] = ACTIONS(1996),
    [anon_sym_sizeof] = ACTIONS(1994),
    [anon_sym___alignof__] = ACTIONS(1994),
    [anon_sym___alignof] = ACTIONS(1994),
    [anon_sym__alignof] = ACTIONS(1994),
    [anon_sym_alignof] = ACTIONS(1994),
    [anon_sym__Alignof] = ACTIONS(1994),
    [anon_sym_offsetof] = ACTIONS(1994),
    [anon_sym__Generic] = ACTIONS(1994),
    [anon_sym_asm] = ACTIONS(1994),
    [anon_sym___asm__] = ACTIONS(1994),
    [sym_number_literal] = ACTIONS(1996),
    [anon_sym_L_SQUOTE] = ACTIONS(1996),
    [anon_sym_u_SQUOTE] = ACTIONS(1996),
    [anon_sym_U_SQUOTE] = ACTIONS(1996),
    [anon_sym_u8_SQUOTE] = ACTIONS(1996),
    [anon_sym_SQUOTE] = ACTIONS(1996),
    [anon_sym_L_DQUOTE] = ACTIONS(1996),
    [anon_sym_u_DQUOTE] = ACTIONS(1996),
    [anon_sym_U_DQUOTE] = ACTIONS(1996),
    [anon_sym_u8_DQUOTE] = ACTIONS(1996),
    [anon_sym_DQUOTE] = ACTIONS(1996),
    [sym_true] = ACTIONS(1994),
    [sym_false] = ACTIONS(1994),
    [anon_sym_NULL] = ACTIONS(1994),
    [anon_sym_nullptr] = ACTIONS(1994),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1994),
    [anon_sym_decltype] = ACTIONS(1994),
    [sym_virtual] = ACTIONS(1994),
    [anon_sym_explicit] = ACTIONS(1994),
    [anon_sym_typename] = ACTIONS(1994),
    [anon_sym_template] = ACTIONS(1994),
    [anon_sym_operator] = ACTIONS(1994),
    [anon_sym_try] = ACTIONS(1994),
    [anon_sym_delete] = ACTIONS(1994),
    [anon_sym_throw] = ACTIONS(1994),
    [anon_sym_namespace] = ACTIONS(1994),
    [anon_sym_using] = ACTIONS(1994),
    [anon_sym_static_assert] = ACTIONS(1994),
    [anon_sym_concept] = ACTIONS(1994),
    [anon_sym_co_return] = ACTIONS(1994),
    [anon_sym_co_yield] = ACTIONS(1994),
    [anon_sym_R_DQUOTE] = ACTIONS(1996),
    [anon_sym_LR_DQUOTE] = ACTIONS(1996),
    [anon_sym_uR_DQUOTE] = ACTIONS(1996),
    [anon_sym_UR_DQUOTE] = ACTIONS(1996),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1996),
    [anon_sym_co_await] = ACTIONS(1994),
    [anon_sym_new] = ACTIONS(1994),
    [anon_sym_requires] = ACTIONS(1994),
    [sym_this] = ACTIONS(1994),
    [anon_sym_discard] = ACTIONS(1994),
    [anon_sym_precise] = ACTIONS(1994),
    [anon_sym_shared] = ACTIONS(1994),
    [anon_sym_groupshared] = ACTIONS(1994),
    [anon_sym_uniform] = ACTIONS(1994),
    [anon_sym_row_major] = ACTIONS(1994),
    [anon_sym_column_major] = ACTIONS(1994),
    [anon_sym_globallycoherent] = ACTIONS(1994),
    [anon_sym_centroid] = ACTIONS(1994),
    [anon_sym_noperspective] = ACTIONS(1994),
    [anon_sym_nointerpolation] = ACTIONS(1994),
    [anon_sym_sample] = ACTIONS(1994),
    [anon_sym_linear] = ACTIONS(1994),
    [anon_sym_snorm] = ACTIONS(1994),
    [anon_sym_unorm] = ACTIONS(1994),
    [anon_sym_point] = ACTIONS(1994),
    [anon_sym_line] = ACTIONS(1994),
    [anon_sym_triangleadj] = ACTIONS(1994),
    [anon_sym_lineadj] = ACTIONS(1994),
    [anon_sym_triangle] = ACTIONS(1994),
    [anon_sym_cbuffer] = ACTIONS(1994),
  },
  [365] = {
    [sym_else_clause] = STATE(424),
    [ts_builtin_sym_end] = ACTIONS(2010),
    [sym_identifier] = ACTIONS(2008),
    [aux_sym_preproc_include_token1] = ACTIONS(2008),
    [aux_sym_preproc_def_token1] = ACTIONS(2008),
    [aux_sym_preproc_if_token1] = ACTIONS(2008),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2008),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2008),
    [sym_preproc_directive] = ACTIONS(2008),
    [anon_sym_LPAREN2] = ACTIONS(2010),
    [anon_sym_BANG] = ACTIONS(2010),
    [anon_sym_TILDE] = ACTIONS(2010),
    [anon_sym_DASH] = ACTIONS(2008),
    [anon_sym_PLUS] = ACTIONS(2008),
    [anon_sym_STAR] = ACTIONS(2010),
    [anon_sym_AMP_AMP] = ACTIONS(2010),
    [anon_sym_AMP] = ACTIONS(2008),
    [anon_sym_SEMI] = ACTIONS(2010),
    [anon_sym___extension__] = ACTIONS(2008),
    [anon_sym_typedef] = ACTIONS(2008),
    [anon_sym_in] = ACTIONS(2008),
    [anon_sym_out] = ACTIONS(2008),
    [anon_sym_inout] = ACTIONS(2008),
    [anon_sym_extern] = ACTIONS(2008),
    [anon_sym___attribute__] = ACTIONS(2008),
    [anon_sym_COLON_COLON] = ACTIONS(2010),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2010),
    [anon_sym___declspec] = ACTIONS(2008),
    [anon_sym___based] = ACTIONS(2008),
    [anon_sym___cdecl] = ACTIONS(2008),
    [anon_sym___clrcall] = ACTIONS(2008),
    [anon_sym___stdcall] = ACTIONS(2008),
    [anon_sym___fastcall] = ACTIONS(2008),
    [anon_sym___thiscall] = ACTIONS(2008),
    [anon_sym___vectorcall] = ACTIONS(2008),
    [anon_sym_LBRACE] = ACTIONS(2010),
    [anon_sym_signed] = ACTIONS(2008),
    [anon_sym_unsigned] = ACTIONS(2008),
    [anon_sym_long] = ACTIONS(2008),
    [anon_sym_short] = ACTIONS(2008),
    [anon_sym_LBRACK] = ACTIONS(2008),
    [anon_sym_static] = ACTIONS(2008),
    [anon_sym_register] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(2008),
    [anon_sym___inline] = ACTIONS(2008),
    [anon_sym___inline__] = ACTIONS(2008),
    [anon_sym___forceinline] = ACTIONS(2008),
    [anon_sym_thread_local] = ACTIONS(2008),
    [anon_sym___thread] = ACTIONS(2008),
    [anon_sym_const] = ACTIONS(2008),
    [anon_sym_constexpr] = ACTIONS(2008),
    [anon_sym_volatile] = ACTIONS(2008),
    [anon_sym_restrict] = ACTIONS(2008),
    [anon_sym___restrict__] = ACTIONS(2008),
    [anon_sym__Atomic] = ACTIONS(2008),
    [anon_sym__Noreturn] = ACTIONS(2008),
    [anon_sym_noreturn] = ACTIONS(2008),
    [anon_sym_mutable] = ACTIONS(2008),
    [anon_sym_constinit] = ACTIONS(2008),
    [anon_sym_consteval] = ACTIONS(2008),
    [anon_sym_alignas] = ACTIONS(2008),
    [anon_sym__Alignas] = ACTIONS(2008),
    [sym_primitive_type] = ACTIONS(2008),
    [anon_sym_enum] = ACTIONS(2008),
    [anon_sym_class] = ACTIONS(2008),
    [anon_sym_struct] = ACTIONS(2008),
    [anon_sym_union] = ACTIONS(2008),
    [anon_sym_if] = ACTIONS(2008),
    [anon_sym_else] = ACTIONS(2653),
    [anon_sym_switch] = ACTIONS(2008),
    [anon_sym_case] = ACTIONS(2008),
    [anon_sym_default] = ACTIONS(2008),
    [anon_sym_while] = ACTIONS(2008),
    [anon_sym_do] = ACTIONS(2008),
    [anon_sym_for] = ACTIONS(2008),
    [anon_sym_return] = ACTIONS(2008),
    [anon_sym_break] = ACTIONS(2008),
    [anon_sym_continue] = ACTIONS(2008),
    [anon_sym_goto] = ACTIONS(2008),
    [anon_sym___try] = ACTIONS(2008),
    [anon_sym___leave] = ACTIONS(2008),
    [anon_sym_not] = ACTIONS(2008),
    [anon_sym_compl] = ACTIONS(2008),
    [anon_sym_DASH_DASH] = ACTIONS(2010),
    [anon_sym_PLUS_PLUS] = ACTIONS(2010),
    [anon_sym_sizeof] = ACTIONS(2008),
    [anon_sym___alignof__] = ACTIONS(2008),
    [anon_sym___alignof] = ACTIONS(2008),
    [anon_sym__alignof] = ACTIONS(2008),
    [anon_sym_alignof] = ACTIONS(2008),
    [anon_sym__Alignof] = ACTIONS(2008),
    [anon_sym_offsetof] = ACTIONS(2008),
    [anon_sym__Generic] = ACTIONS(2008),
    [anon_sym_asm] = ACTIONS(2008),
    [anon_sym___asm__] = ACTIONS(2008),
    [sym_number_literal] = ACTIONS(2010),
    [anon_sym_L_SQUOTE] = ACTIONS(2010),
    [anon_sym_u_SQUOTE] = ACTIONS(2010),
    [anon_sym_U_SQUOTE] = ACTIONS(2010),
    [anon_sym_u8_SQUOTE] = ACTIONS(2010),
    [anon_sym_SQUOTE] = ACTIONS(2010),
    [anon_sym_L_DQUOTE] = ACTIONS(2010),
    [anon_sym_u_DQUOTE] = ACTIONS(2010),
    [anon_sym_U_DQUOTE] = ACTIONS(2010),
    [anon_sym_u8_DQUOTE] = ACTIONS(2010),
    [anon_sym_DQUOTE] = ACTIONS(2010),
    [sym_true] = ACTIONS(2008),
    [sym_false] = ACTIONS(2008),
    [anon_sym_NULL] = ACTIONS(2008),
    [anon_sym_nullptr] = ACTIONS(2008),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2008),
    [anon_sym_decltype] = ACTIONS(2008),
    [sym_virtual] = ACTIONS(2008),
    [anon_sym_explicit] = ACTIONS(2008),
    [anon_sym_typename] = ACTIONS(2008),
    [anon_sym_template] = ACTIONS(2008),
    [anon_sym_operator] = ACTIONS(2008),
    [anon_sym_try] = ACTIONS(2008),
    [anon_sym_delete] = ACTIONS(2008),
    [anon_sym_throw] = ACTIONS(2008),
    [anon_sym_namespace] = ACTIONS(2008),
    [anon_sym_using] = ACTIONS(2008),
    [anon_sym_static_assert] = ACTIONS(2008),
    [anon_sym_concept] = ACTIONS(2008),
    [anon_sym_co_return] = ACTIONS(2008),
    [anon_sym_co_yield] = ACTIONS(2008),
    [anon_sym_R_DQUOTE] = ACTIONS(2010),
    [anon_sym_LR_DQUOTE] = ACTIONS(2010),
    [anon_sym_uR_DQUOTE] = ACTIONS(2010),
    [anon_sym_UR_DQUOTE] = ACTIONS(2010),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2010),
    [anon_sym_co_await] = ACTIONS(2008),
    [anon_sym_new] = ACTIONS(2008),
    [anon_sym_requires] = ACTIONS(2008),
    [sym_this] = ACTIONS(2008),
    [anon_sym_discard] = ACTIONS(2008),
    [anon_sym_precise] = ACTIONS(2008),
    [anon_sym_shared] = ACTIONS(2008),
    [anon_sym_groupshared] = ACTIONS(2008),
    [anon_sym_uniform] = ACTIONS(2008),
    [anon_sym_row_major] = ACTIONS(2008),
    [anon_sym_column_major] = ACTIONS(2008),
    [anon_sym_globallycoherent] = ACTIONS(2008),
    [anon_sym_centroid] = ACTIONS(2008),
    [anon_sym_noperspective] = ACTIONS(2008),
    [anon_sym_nointerpolation] = ACTIONS(2008),
    [anon_sym_sample] = ACTIONS(2008),
    [anon_sym_linear] = ACTIONS(2008),
    [anon_sym_snorm] = ACTIONS(2008),
    [anon_sym_unorm] = ACTIONS(2008),
    [anon_sym_point] = ACTIONS(2008),
    [anon_sym_line] = ACTIONS(2008),
    [anon_sym_triangleadj] = ACTIONS(2008),
    [anon_sym_lineadj] = ACTIONS(2008),
    [anon_sym_triangle] = ACTIONS(2008),
    [anon_sym_cbuffer] = ACTIONS(2008),
  },
  [366] = {
    [sym_identifier] = ACTIONS(1947),
    [aux_sym_preproc_include_token1] = ACTIONS(1947),
    [aux_sym_preproc_def_token1] = ACTIONS(1947),
    [aux_sym_preproc_if_token1] = ACTIONS(1947),
    [aux_sym_preproc_if_token2] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1947),
    [sym_preproc_directive] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1945),
    [anon_sym_BANG] = ACTIONS(1945),
    [anon_sym_TILDE] = ACTIONS(1945),
    [anon_sym_DASH] = ACTIONS(1947),
    [anon_sym_PLUS] = ACTIONS(1947),
    [anon_sym_STAR] = ACTIONS(1945),
    [anon_sym_AMP_AMP] = ACTIONS(1945),
    [anon_sym_AMP] = ACTIONS(1947),
    [anon_sym_SEMI] = ACTIONS(1945),
    [anon_sym___extension__] = ACTIONS(1947),
    [anon_sym_typedef] = ACTIONS(1947),
    [anon_sym_in] = ACTIONS(1947),
    [anon_sym_out] = ACTIONS(1947),
    [anon_sym_inout] = ACTIONS(1947),
    [anon_sym_extern] = ACTIONS(1947),
    [anon_sym___attribute__] = ACTIONS(1947),
    [anon_sym_COLON_COLON] = ACTIONS(1945),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1945),
    [anon_sym___declspec] = ACTIONS(1947),
    [anon_sym___based] = ACTIONS(1947),
    [anon_sym___cdecl] = ACTIONS(1947),
    [anon_sym___clrcall] = ACTIONS(1947),
    [anon_sym___stdcall] = ACTIONS(1947),
    [anon_sym___fastcall] = ACTIONS(1947),
    [anon_sym___thiscall] = ACTIONS(1947),
    [anon_sym___vectorcall] = ACTIONS(1947),
    [anon_sym_LBRACE] = ACTIONS(1945),
    [anon_sym_signed] = ACTIONS(1947),
    [anon_sym_unsigned] = ACTIONS(1947),
    [anon_sym_long] = ACTIONS(1947),
    [anon_sym_short] = ACTIONS(1947),
    [anon_sym_LBRACK] = ACTIONS(1947),
    [anon_sym_static] = ACTIONS(1947),
    [anon_sym_register] = ACTIONS(1947),
    [anon_sym_inline] = ACTIONS(1947),
    [anon_sym___inline] = ACTIONS(1947),
    [anon_sym___inline__] = ACTIONS(1947),
    [anon_sym___forceinline] = ACTIONS(1947),
    [anon_sym_thread_local] = ACTIONS(1947),
    [anon_sym___thread] = ACTIONS(1947),
    [anon_sym_const] = ACTIONS(1947),
    [anon_sym_constexpr] = ACTIONS(1947),
    [anon_sym_volatile] = ACTIONS(1947),
    [anon_sym_restrict] = ACTIONS(1947),
    [anon_sym___restrict__] = ACTIONS(1947),
    [anon_sym__Atomic] = ACTIONS(1947),
    [anon_sym__Noreturn] = ACTIONS(1947),
    [anon_sym_noreturn] = ACTIONS(1947),
    [anon_sym_mutable] = ACTIONS(1947),
    [anon_sym_constinit] = ACTIONS(1947),
    [anon_sym_consteval] = ACTIONS(1947),
    [anon_sym_alignas] = ACTIONS(1947),
    [anon_sym__Alignas] = ACTIONS(1947),
    [sym_primitive_type] = ACTIONS(1947),
    [anon_sym_enum] = ACTIONS(1947),
    [anon_sym_class] = ACTIONS(1947),
    [anon_sym_struct] = ACTIONS(1947),
    [anon_sym_union] = ACTIONS(1947),
    [anon_sym_if] = ACTIONS(1947),
    [anon_sym_else] = ACTIONS(1947),
    [anon_sym_switch] = ACTIONS(1947),
    [anon_sym_case] = ACTIONS(1947),
    [anon_sym_default] = ACTIONS(1947),
    [anon_sym_while] = ACTIONS(1947),
    [anon_sym_do] = ACTIONS(1947),
    [anon_sym_for] = ACTIONS(1947),
    [anon_sym_return] = ACTIONS(1947),
    [anon_sym_break] = ACTIONS(1947),
    [anon_sym_continue] = ACTIONS(1947),
    [anon_sym_goto] = ACTIONS(1947),
    [anon_sym___try] = ACTIONS(1947),
    [anon_sym___leave] = ACTIONS(1947),
    [anon_sym_not] = ACTIONS(1947),
    [anon_sym_compl] = ACTIONS(1947),
    [anon_sym_DASH_DASH] = ACTIONS(1945),
    [anon_sym_PLUS_PLUS] = ACTIONS(1945),
    [anon_sym_sizeof] = ACTIONS(1947),
    [anon_sym___alignof__] = ACTIONS(1947),
    [anon_sym___alignof] = ACTIONS(1947),
    [anon_sym__alignof] = ACTIONS(1947),
    [anon_sym_alignof] = ACTIONS(1947),
    [anon_sym__Alignof] = ACTIONS(1947),
    [anon_sym_offsetof] = ACTIONS(1947),
    [anon_sym__Generic] = ACTIONS(1947),
    [anon_sym_asm] = ACTIONS(1947),
    [anon_sym___asm__] = ACTIONS(1947),
    [sym_number_literal] = ACTIONS(1945),
    [anon_sym_L_SQUOTE] = ACTIONS(1945),
    [anon_sym_u_SQUOTE] = ACTIONS(1945),
    [anon_sym_U_SQUOTE] = ACTIONS(1945),
    [anon_sym_u8_SQUOTE] = ACTIONS(1945),
    [anon_sym_SQUOTE] = ACTIONS(1945),
    [anon_sym_L_DQUOTE] = ACTIONS(1945),
    [anon_sym_u_DQUOTE] = ACTIONS(1945),
    [anon_sym_U_DQUOTE] = ACTIONS(1945),
    [anon_sym_u8_DQUOTE] = ACTIONS(1945),
    [anon_sym_DQUOTE] = ACTIONS(1945),
    [sym_true] = ACTIONS(1947),
    [sym_false] = ACTIONS(1947),
    [anon_sym_NULL] = ACTIONS(1947),
    [anon_sym_nullptr] = ACTIONS(1947),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1947),
    [anon_sym_decltype] = ACTIONS(1947),
    [sym_virtual] = ACTIONS(1947),
    [anon_sym_explicit] = ACTIONS(1947),
    [anon_sym_typename] = ACTIONS(1947),
    [anon_sym_template] = ACTIONS(1947),
    [anon_sym_operator] = ACTIONS(1947),
    [anon_sym_try] = ACTIONS(1947),
    [anon_sym_delete] = ACTIONS(1947),
    [anon_sym_throw] = ACTIONS(1947),
    [anon_sym_namespace] = ACTIONS(1947),
    [anon_sym_using] = ACTIONS(1947),
    [anon_sym_static_assert] = ACTIONS(1947),
    [anon_sym_concept] = ACTIONS(1947),
    [anon_sym_co_return] = ACTIONS(1947),
    [anon_sym_co_yield] = ACTIONS(1947),
    [anon_sym_catch] = ACTIONS(1947),
    [anon_sym_R_DQUOTE] = ACTIONS(1945),
    [anon_sym_LR_DQUOTE] = ACTIONS(1945),
    [anon_sym_uR_DQUOTE] = ACTIONS(1945),
    [anon_sym_UR_DQUOTE] = ACTIONS(1945),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1945),
    [anon_sym_co_await] = ACTIONS(1947),
    [anon_sym_new] = ACTIONS(1947),
    [anon_sym_requires] = ACTIONS(1947),
    [sym_this] = ACTIONS(1947),
    [anon_sym_discard] = ACTIONS(1947),
    [anon_sym_precise] = ACTIONS(1947),
    [anon_sym_shared] = ACTIONS(1947),
    [anon_sym_groupshared] = ACTIONS(1947),
    [anon_sym_uniform] = ACTIONS(1947),
    [anon_sym_row_major] = ACTIONS(1947),
    [anon_sym_column_major] = ACTIONS(1947),
    [anon_sym_globallycoherent] = ACTIONS(1947),
    [anon_sym_centroid] = ACTIONS(1947),
    [anon_sym_noperspective] = ACTIONS(1947),
    [anon_sym_nointerpolation] = ACTIONS(1947),
    [anon_sym_sample] = ACTIONS(1947),
    [anon_sym_linear] = ACTIONS(1947),
    [anon_sym_snorm] = ACTIONS(1947),
    [anon_sym_unorm] = ACTIONS(1947),
    [anon_sym_point] = ACTIONS(1947),
    [anon_sym_line] = ACTIONS(1947),
    [anon_sym_triangleadj] = ACTIONS(1947),
    [anon_sym_lineadj] = ACTIONS(1947),
    [anon_sym_triangle] = ACTIONS(1947),
    [anon_sym_cbuffer] = ACTIONS(1947),
  },
  [367] = {
    [sym_preproc_def] = STATE(702),
    [sym_preproc_function_def] = STATE(702),
    [sym_preproc_call] = STATE(702),
    [sym_preproc_if_in_field_declaration_list] = STATE(702),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(702),
    [sym_preproc_else_in_field_declaration_list] = STATE(8315),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8315),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8315),
    [sym_type_definition] = STATE(702),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5626),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6102),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(702),
    [sym_field_declaration] = STATE(702),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1832),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(702),
    [sym_operator_cast] = STATE(6636),
    [sym_inline_method_definition] = STATE(702),
    [sym__constructor_specifiers] = STATE(1832),
    [sym_operator_cast_definition] = STATE(702),
    [sym_operator_cast_declaration] = STATE(702),
    [sym_constructor_or_destructor_definition] = STATE(702),
    [sym_constructor_or_destructor_declaration] = STATE(702),
    [sym_friend_declaration] = STATE(702),
    [sym_access_specifier] = STATE(8379),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(702),
    [sym_alias_declaration] = STATE(702),
    [sym_static_assert_declaration] = STATE(702),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6636),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(702),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1832),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2587),
    [aux_sym_preproc_if_token2] = ACTIONS(2655),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2591),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2591),
    [aux_sym_preproc_else_token1] = ACTIONS(2593),
    [aux_sym_preproc_elif_token1] = ACTIONS(2595),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2597),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2597),
    [sym_preproc_directive] = ACTIONS(2599),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2609),
    [anon_sym_typedef] = ACTIONS(2611),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2629),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2631),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2635),
    [anon_sym_static_assert] = ACTIONS(2637),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [368] = {
    [sym_preproc_def] = STATE(702),
    [sym_preproc_function_def] = STATE(702),
    [sym_preproc_call] = STATE(702),
    [sym_preproc_if_in_field_declaration_list] = STATE(702),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(702),
    [sym_preproc_else_in_field_declaration_list] = STATE(8537),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8537),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8537),
    [sym_type_definition] = STATE(702),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5626),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6102),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(702),
    [sym_field_declaration] = STATE(702),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1832),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(702),
    [sym_operator_cast] = STATE(6636),
    [sym_inline_method_definition] = STATE(702),
    [sym__constructor_specifiers] = STATE(1832),
    [sym_operator_cast_definition] = STATE(702),
    [sym_operator_cast_declaration] = STATE(702),
    [sym_constructor_or_destructor_definition] = STATE(702),
    [sym_constructor_or_destructor_declaration] = STATE(702),
    [sym_friend_declaration] = STATE(702),
    [sym_access_specifier] = STATE(8379),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(702),
    [sym_alias_declaration] = STATE(702),
    [sym_static_assert_declaration] = STATE(702),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6636),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(702),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1832),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2587),
    [aux_sym_preproc_if_token2] = ACTIONS(2657),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2591),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2591),
    [aux_sym_preproc_else_token1] = ACTIONS(2593),
    [aux_sym_preproc_elif_token1] = ACTIONS(2595),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2597),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2597),
    [sym_preproc_directive] = ACTIONS(2599),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2609),
    [anon_sym_typedef] = ACTIONS(2611),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2629),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2631),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2635),
    [anon_sym_static_assert] = ACTIONS(2637),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [369] = {
    [sym_preproc_def] = STATE(702),
    [sym_preproc_function_def] = STATE(702),
    [sym_preproc_call] = STATE(702),
    [sym_preproc_if_in_field_declaration_list] = STATE(702),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(702),
    [sym_preproc_else_in_field_declaration_list] = STATE(8586),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8586),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8586),
    [sym_type_definition] = STATE(702),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5626),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6102),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(702),
    [sym_field_declaration] = STATE(702),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1832),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(702),
    [sym_operator_cast] = STATE(6636),
    [sym_inline_method_definition] = STATE(702),
    [sym__constructor_specifiers] = STATE(1832),
    [sym_operator_cast_definition] = STATE(702),
    [sym_operator_cast_declaration] = STATE(702),
    [sym_constructor_or_destructor_definition] = STATE(702),
    [sym_constructor_or_destructor_declaration] = STATE(702),
    [sym_friend_declaration] = STATE(702),
    [sym_access_specifier] = STATE(8379),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(702),
    [sym_alias_declaration] = STATE(702),
    [sym_static_assert_declaration] = STATE(702),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6636),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(702),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1832),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2587),
    [aux_sym_preproc_if_token2] = ACTIONS(2659),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2591),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2591),
    [aux_sym_preproc_else_token1] = ACTIONS(2593),
    [aux_sym_preproc_elif_token1] = ACTIONS(2595),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2597),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2597),
    [sym_preproc_directive] = ACTIONS(2599),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2609),
    [anon_sym_typedef] = ACTIONS(2611),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2629),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2631),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2635),
    [anon_sym_static_assert] = ACTIONS(2637),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [370] = {
    [sym_identifier] = ACTIONS(1931),
    [aux_sym_preproc_include_token1] = ACTIONS(1931),
    [aux_sym_preproc_def_token1] = ACTIONS(1931),
    [aux_sym_preproc_if_token1] = ACTIONS(1931),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1931),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1931),
    [sym_preproc_directive] = ACTIONS(1931),
    [anon_sym_LPAREN2] = ACTIONS(1929),
    [anon_sym_BANG] = ACTIONS(1929),
    [anon_sym_TILDE] = ACTIONS(1929),
    [anon_sym_DASH] = ACTIONS(1931),
    [anon_sym_PLUS] = ACTIONS(1931),
    [anon_sym_STAR] = ACTIONS(1929),
    [anon_sym_AMP_AMP] = ACTIONS(1929),
    [anon_sym_AMP] = ACTIONS(1931),
    [anon_sym_SEMI] = ACTIONS(1929),
    [anon_sym___extension__] = ACTIONS(1931),
    [anon_sym_typedef] = ACTIONS(1931),
    [anon_sym_in] = ACTIONS(1931),
    [anon_sym_out] = ACTIONS(1931),
    [anon_sym_inout] = ACTIONS(1931),
    [anon_sym_extern] = ACTIONS(1931),
    [anon_sym___attribute__] = ACTIONS(1931),
    [anon_sym_COLON_COLON] = ACTIONS(1929),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1929),
    [anon_sym___declspec] = ACTIONS(1931),
    [anon_sym___based] = ACTIONS(1931),
    [anon_sym___cdecl] = ACTIONS(1931),
    [anon_sym___clrcall] = ACTIONS(1931),
    [anon_sym___stdcall] = ACTIONS(1931),
    [anon_sym___fastcall] = ACTIONS(1931),
    [anon_sym___thiscall] = ACTIONS(1931),
    [anon_sym___vectorcall] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1929),
    [anon_sym_RBRACE] = ACTIONS(1929),
    [anon_sym_signed] = ACTIONS(1931),
    [anon_sym_unsigned] = ACTIONS(1931),
    [anon_sym_long] = ACTIONS(1931),
    [anon_sym_short] = ACTIONS(1931),
    [anon_sym_LBRACK] = ACTIONS(1931),
    [anon_sym_static] = ACTIONS(1931),
    [anon_sym_register] = ACTIONS(1931),
    [anon_sym_inline] = ACTIONS(1931),
    [anon_sym___inline] = ACTIONS(1931),
    [anon_sym___inline__] = ACTIONS(1931),
    [anon_sym___forceinline] = ACTIONS(1931),
    [anon_sym_thread_local] = ACTIONS(1931),
    [anon_sym___thread] = ACTIONS(1931),
    [anon_sym_const] = ACTIONS(1931),
    [anon_sym_constexpr] = ACTIONS(1931),
    [anon_sym_volatile] = ACTIONS(1931),
    [anon_sym_restrict] = ACTIONS(1931),
    [anon_sym___restrict__] = ACTIONS(1931),
    [anon_sym__Atomic] = ACTIONS(1931),
    [anon_sym__Noreturn] = ACTIONS(1931),
    [anon_sym_noreturn] = ACTIONS(1931),
    [anon_sym_mutable] = ACTIONS(1931),
    [anon_sym_constinit] = ACTIONS(1931),
    [anon_sym_consteval] = ACTIONS(1931),
    [anon_sym_alignas] = ACTIONS(1931),
    [anon_sym__Alignas] = ACTIONS(1931),
    [sym_primitive_type] = ACTIONS(1931),
    [anon_sym_enum] = ACTIONS(1931),
    [anon_sym_class] = ACTIONS(1931),
    [anon_sym_struct] = ACTIONS(1931),
    [anon_sym_union] = ACTIONS(1931),
    [anon_sym_if] = ACTIONS(1931),
    [anon_sym_else] = ACTIONS(1931),
    [anon_sym_switch] = ACTIONS(1931),
    [anon_sym_case] = ACTIONS(1931),
    [anon_sym_default] = ACTIONS(1931),
    [anon_sym_while] = ACTIONS(1931),
    [anon_sym_do] = ACTIONS(1931),
    [anon_sym_for] = ACTIONS(1931),
    [anon_sym_return] = ACTIONS(1931),
    [anon_sym_break] = ACTIONS(1931),
    [anon_sym_continue] = ACTIONS(1931),
    [anon_sym_goto] = ACTIONS(1931),
    [anon_sym___try] = ACTIONS(1931),
    [anon_sym___leave] = ACTIONS(1931),
    [anon_sym_not] = ACTIONS(1931),
    [anon_sym_compl] = ACTIONS(1931),
    [anon_sym_DASH_DASH] = ACTIONS(1929),
    [anon_sym_PLUS_PLUS] = ACTIONS(1929),
    [anon_sym_sizeof] = ACTIONS(1931),
    [anon_sym___alignof__] = ACTIONS(1931),
    [anon_sym___alignof] = ACTIONS(1931),
    [anon_sym__alignof] = ACTIONS(1931),
    [anon_sym_alignof] = ACTIONS(1931),
    [anon_sym__Alignof] = ACTIONS(1931),
    [anon_sym_offsetof] = ACTIONS(1931),
    [anon_sym__Generic] = ACTIONS(1931),
    [anon_sym_asm] = ACTIONS(1931),
    [anon_sym___asm__] = ACTIONS(1931),
    [sym_number_literal] = ACTIONS(1929),
    [anon_sym_L_SQUOTE] = ACTIONS(1929),
    [anon_sym_u_SQUOTE] = ACTIONS(1929),
    [anon_sym_U_SQUOTE] = ACTIONS(1929),
    [anon_sym_u8_SQUOTE] = ACTIONS(1929),
    [anon_sym_SQUOTE] = ACTIONS(1929),
    [anon_sym_L_DQUOTE] = ACTIONS(1929),
    [anon_sym_u_DQUOTE] = ACTIONS(1929),
    [anon_sym_U_DQUOTE] = ACTIONS(1929),
    [anon_sym_u8_DQUOTE] = ACTIONS(1929),
    [anon_sym_DQUOTE] = ACTIONS(1929),
    [sym_true] = ACTIONS(1931),
    [sym_false] = ACTIONS(1931),
    [anon_sym_NULL] = ACTIONS(1931),
    [anon_sym_nullptr] = ACTIONS(1931),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1931),
    [anon_sym_decltype] = ACTIONS(1931),
    [sym_virtual] = ACTIONS(1931),
    [anon_sym_explicit] = ACTIONS(1931),
    [anon_sym_typename] = ACTIONS(1931),
    [anon_sym_template] = ACTIONS(1931),
    [anon_sym_operator] = ACTIONS(1931),
    [anon_sym_try] = ACTIONS(1931),
    [anon_sym_delete] = ACTIONS(1931),
    [anon_sym_throw] = ACTIONS(1931),
    [anon_sym_namespace] = ACTIONS(1931),
    [anon_sym_using] = ACTIONS(1931),
    [anon_sym_static_assert] = ACTIONS(1931),
    [anon_sym_concept] = ACTIONS(1931),
    [anon_sym_co_return] = ACTIONS(1931),
    [anon_sym_co_yield] = ACTIONS(1931),
    [anon_sym_catch] = ACTIONS(1931),
    [anon_sym_R_DQUOTE] = ACTIONS(1929),
    [anon_sym_LR_DQUOTE] = ACTIONS(1929),
    [anon_sym_uR_DQUOTE] = ACTIONS(1929),
    [anon_sym_UR_DQUOTE] = ACTIONS(1929),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1929),
    [anon_sym_co_await] = ACTIONS(1931),
    [anon_sym_new] = ACTIONS(1931),
    [anon_sym_requires] = ACTIONS(1931),
    [sym_this] = ACTIONS(1931),
    [anon_sym_discard] = ACTIONS(1931),
    [anon_sym_precise] = ACTIONS(1931),
    [anon_sym_shared] = ACTIONS(1931),
    [anon_sym_groupshared] = ACTIONS(1931),
    [anon_sym_uniform] = ACTIONS(1931),
    [anon_sym_row_major] = ACTIONS(1931),
    [anon_sym_column_major] = ACTIONS(1931),
    [anon_sym_globallycoherent] = ACTIONS(1931),
    [anon_sym_centroid] = ACTIONS(1931),
    [anon_sym_noperspective] = ACTIONS(1931),
    [anon_sym_nointerpolation] = ACTIONS(1931),
    [anon_sym_sample] = ACTIONS(1931),
    [anon_sym_linear] = ACTIONS(1931),
    [anon_sym_snorm] = ACTIONS(1931),
    [anon_sym_unorm] = ACTIONS(1931),
    [anon_sym_point] = ACTIONS(1931),
    [anon_sym_line] = ACTIONS(1931),
    [anon_sym_triangleadj] = ACTIONS(1931),
    [anon_sym_lineadj] = ACTIONS(1931),
    [anon_sym_triangle] = ACTIONS(1931),
    [anon_sym_cbuffer] = ACTIONS(1931),
  },
  [371] = {
    [sym_identifier] = ACTIONS(1931),
    [aux_sym_preproc_include_token1] = ACTIONS(1931),
    [aux_sym_preproc_def_token1] = ACTIONS(1931),
    [aux_sym_preproc_if_token1] = ACTIONS(1931),
    [aux_sym_preproc_if_token2] = ACTIONS(1931),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1931),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1931),
    [sym_preproc_directive] = ACTIONS(1931),
    [anon_sym_LPAREN2] = ACTIONS(1929),
    [anon_sym_BANG] = ACTIONS(1929),
    [anon_sym_TILDE] = ACTIONS(1929),
    [anon_sym_DASH] = ACTIONS(1931),
    [anon_sym_PLUS] = ACTIONS(1931),
    [anon_sym_STAR] = ACTIONS(1929),
    [anon_sym_AMP_AMP] = ACTIONS(1929),
    [anon_sym_AMP] = ACTIONS(1931),
    [anon_sym_SEMI] = ACTIONS(1929),
    [anon_sym___extension__] = ACTIONS(1931),
    [anon_sym_typedef] = ACTIONS(1931),
    [anon_sym_in] = ACTIONS(1931),
    [anon_sym_out] = ACTIONS(1931),
    [anon_sym_inout] = ACTIONS(1931),
    [anon_sym_extern] = ACTIONS(1931),
    [anon_sym___attribute__] = ACTIONS(1931),
    [anon_sym_COLON_COLON] = ACTIONS(1929),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1929),
    [anon_sym___declspec] = ACTIONS(1931),
    [anon_sym___based] = ACTIONS(1931),
    [anon_sym___cdecl] = ACTIONS(1931),
    [anon_sym___clrcall] = ACTIONS(1931),
    [anon_sym___stdcall] = ACTIONS(1931),
    [anon_sym___fastcall] = ACTIONS(1931),
    [anon_sym___thiscall] = ACTIONS(1931),
    [anon_sym___vectorcall] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1929),
    [anon_sym_signed] = ACTIONS(1931),
    [anon_sym_unsigned] = ACTIONS(1931),
    [anon_sym_long] = ACTIONS(1931),
    [anon_sym_short] = ACTIONS(1931),
    [anon_sym_LBRACK] = ACTIONS(1931),
    [anon_sym_static] = ACTIONS(1931),
    [anon_sym_register] = ACTIONS(1931),
    [anon_sym_inline] = ACTIONS(1931),
    [anon_sym___inline] = ACTIONS(1931),
    [anon_sym___inline__] = ACTIONS(1931),
    [anon_sym___forceinline] = ACTIONS(1931),
    [anon_sym_thread_local] = ACTIONS(1931),
    [anon_sym___thread] = ACTIONS(1931),
    [anon_sym_const] = ACTIONS(1931),
    [anon_sym_constexpr] = ACTIONS(1931),
    [anon_sym_volatile] = ACTIONS(1931),
    [anon_sym_restrict] = ACTIONS(1931),
    [anon_sym___restrict__] = ACTIONS(1931),
    [anon_sym__Atomic] = ACTIONS(1931),
    [anon_sym__Noreturn] = ACTIONS(1931),
    [anon_sym_noreturn] = ACTIONS(1931),
    [anon_sym_mutable] = ACTIONS(1931),
    [anon_sym_constinit] = ACTIONS(1931),
    [anon_sym_consteval] = ACTIONS(1931),
    [anon_sym_alignas] = ACTIONS(1931),
    [anon_sym__Alignas] = ACTIONS(1931),
    [sym_primitive_type] = ACTIONS(1931),
    [anon_sym_enum] = ACTIONS(1931),
    [anon_sym_class] = ACTIONS(1931),
    [anon_sym_struct] = ACTIONS(1931),
    [anon_sym_union] = ACTIONS(1931),
    [anon_sym_if] = ACTIONS(1931),
    [anon_sym_else] = ACTIONS(1931),
    [anon_sym_switch] = ACTIONS(1931),
    [anon_sym_case] = ACTIONS(1931),
    [anon_sym_default] = ACTIONS(1931),
    [anon_sym_while] = ACTIONS(1931),
    [anon_sym_do] = ACTIONS(1931),
    [anon_sym_for] = ACTIONS(1931),
    [anon_sym_return] = ACTIONS(1931),
    [anon_sym_break] = ACTIONS(1931),
    [anon_sym_continue] = ACTIONS(1931),
    [anon_sym_goto] = ACTIONS(1931),
    [anon_sym___try] = ACTIONS(1931),
    [anon_sym___leave] = ACTIONS(1931),
    [anon_sym_not] = ACTIONS(1931),
    [anon_sym_compl] = ACTIONS(1931),
    [anon_sym_DASH_DASH] = ACTIONS(1929),
    [anon_sym_PLUS_PLUS] = ACTIONS(1929),
    [anon_sym_sizeof] = ACTIONS(1931),
    [anon_sym___alignof__] = ACTIONS(1931),
    [anon_sym___alignof] = ACTIONS(1931),
    [anon_sym__alignof] = ACTIONS(1931),
    [anon_sym_alignof] = ACTIONS(1931),
    [anon_sym__Alignof] = ACTIONS(1931),
    [anon_sym_offsetof] = ACTIONS(1931),
    [anon_sym__Generic] = ACTIONS(1931),
    [anon_sym_asm] = ACTIONS(1931),
    [anon_sym___asm__] = ACTIONS(1931),
    [sym_number_literal] = ACTIONS(1929),
    [anon_sym_L_SQUOTE] = ACTIONS(1929),
    [anon_sym_u_SQUOTE] = ACTIONS(1929),
    [anon_sym_U_SQUOTE] = ACTIONS(1929),
    [anon_sym_u8_SQUOTE] = ACTIONS(1929),
    [anon_sym_SQUOTE] = ACTIONS(1929),
    [anon_sym_L_DQUOTE] = ACTIONS(1929),
    [anon_sym_u_DQUOTE] = ACTIONS(1929),
    [anon_sym_U_DQUOTE] = ACTIONS(1929),
    [anon_sym_u8_DQUOTE] = ACTIONS(1929),
    [anon_sym_DQUOTE] = ACTIONS(1929),
    [sym_true] = ACTIONS(1931),
    [sym_false] = ACTIONS(1931),
    [anon_sym_NULL] = ACTIONS(1931),
    [anon_sym_nullptr] = ACTIONS(1931),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1931),
    [anon_sym_decltype] = ACTIONS(1931),
    [sym_virtual] = ACTIONS(1931),
    [anon_sym_explicit] = ACTIONS(1931),
    [anon_sym_typename] = ACTIONS(1931),
    [anon_sym_template] = ACTIONS(1931),
    [anon_sym_operator] = ACTIONS(1931),
    [anon_sym_try] = ACTIONS(1931),
    [anon_sym_delete] = ACTIONS(1931),
    [anon_sym_throw] = ACTIONS(1931),
    [anon_sym_namespace] = ACTIONS(1931),
    [anon_sym_using] = ACTIONS(1931),
    [anon_sym_static_assert] = ACTIONS(1931),
    [anon_sym_concept] = ACTIONS(1931),
    [anon_sym_co_return] = ACTIONS(1931),
    [anon_sym_co_yield] = ACTIONS(1931),
    [anon_sym_catch] = ACTIONS(1931),
    [anon_sym_R_DQUOTE] = ACTIONS(1929),
    [anon_sym_LR_DQUOTE] = ACTIONS(1929),
    [anon_sym_uR_DQUOTE] = ACTIONS(1929),
    [anon_sym_UR_DQUOTE] = ACTIONS(1929),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1929),
    [anon_sym_co_await] = ACTIONS(1931),
    [anon_sym_new] = ACTIONS(1931),
    [anon_sym_requires] = ACTIONS(1931),
    [sym_this] = ACTIONS(1931),
    [anon_sym_discard] = ACTIONS(1931),
    [anon_sym_precise] = ACTIONS(1931),
    [anon_sym_shared] = ACTIONS(1931),
    [anon_sym_groupshared] = ACTIONS(1931),
    [anon_sym_uniform] = ACTIONS(1931),
    [anon_sym_row_major] = ACTIONS(1931),
    [anon_sym_column_major] = ACTIONS(1931),
    [anon_sym_globallycoherent] = ACTIONS(1931),
    [anon_sym_centroid] = ACTIONS(1931),
    [anon_sym_noperspective] = ACTIONS(1931),
    [anon_sym_nointerpolation] = ACTIONS(1931),
    [anon_sym_sample] = ACTIONS(1931),
    [anon_sym_linear] = ACTIONS(1931),
    [anon_sym_snorm] = ACTIONS(1931),
    [anon_sym_unorm] = ACTIONS(1931),
    [anon_sym_point] = ACTIONS(1931),
    [anon_sym_line] = ACTIONS(1931),
    [anon_sym_triangleadj] = ACTIONS(1931),
    [anon_sym_lineadj] = ACTIONS(1931),
    [anon_sym_triangle] = ACTIONS(1931),
    [anon_sym_cbuffer] = ACTIONS(1931),
  },
  [372] = {
    [sym_else_clause] = STATE(542),
    [sym_identifier] = ACTIONS(2008),
    [aux_sym_preproc_include_token1] = ACTIONS(2008),
    [aux_sym_preproc_def_token1] = ACTIONS(2008),
    [aux_sym_preproc_if_token1] = ACTIONS(2008),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2008),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2008),
    [sym_preproc_directive] = ACTIONS(2008),
    [anon_sym_LPAREN2] = ACTIONS(2010),
    [anon_sym_BANG] = ACTIONS(2010),
    [anon_sym_TILDE] = ACTIONS(2010),
    [anon_sym_DASH] = ACTIONS(2008),
    [anon_sym_PLUS] = ACTIONS(2008),
    [anon_sym_STAR] = ACTIONS(2010),
    [anon_sym_AMP_AMP] = ACTIONS(2010),
    [anon_sym_AMP] = ACTIONS(2008),
    [anon_sym_SEMI] = ACTIONS(2010),
    [anon_sym___extension__] = ACTIONS(2008),
    [anon_sym_typedef] = ACTIONS(2008),
    [anon_sym_in] = ACTIONS(2008),
    [anon_sym_out] = ACTIONS(2008),
    [anon_sym_inout] = ACTIONS(2008),
    [anon_sym_extern] = ACTIONS(2008),
    [anon_sym___attribute__] = ACTIONS(2008),
    [anon_sym_COLON_COLON] = ACTIONS(2010),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2010),
    [anon_sym___declspec] = ACTIONS(2008),
    [anon_sym___based] = ACTIONS(2008),
    [anon_sym___cdecl] = ACTIONS(2008),
    [anon_sym___clrcall] = ACTIONS(2008),
    [anon_sym___stdcall] = ACTIONS(2008),
    [anon_sym___fastcall] = ACTIONS(2008),
    [anon_sym___thiscall] = ACTIONS(2008),
    [anon_sym___vectorcall] = ACTIONS(2008),
    [anon_sym_LBRACE] = ACTIONS(2010),
    [anon_sym_RBRACE] = ACTIONS(2010),
    [anon_sym_signed] = ACTIONS(2008),
    [anon_sym_unsigned] = ACTIONS(2008),
    [anon_sym_long] = ACTIONS(2008),
    [anon_sym_short] = ACTIONS(2008),
    [anon_sym_LBRACK] = ACTIONS(2008),
    [anon_sym_static] = ACTIONS(2008),
    [anon_sym_register] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(2008),
    [anon_sym___inline] = ACTIONS(2008),
    [anon_sym___inline__] = ACTIONS(2008),
    [anon_sym___forceinline] = ACTIONS(2008),
    [anon_sym_thread_local] = ACTIONS(2008),
    [anon_sym___thread] = ACTIONS(2008),
    [anon_sym_const] = ACTIONS(2008),
    [anon_sym_constexpr] = ACTIONS(2008),
    [anon_sym_volatile] = ACTIONS(2008),
    [anon_sym_restrict] = ACTIONS(2008),
    [anon_sym___restrict__] = ACTIONS(2008),
    [anon_sym__Atomic] = ACTIONS(2008),
    [anon_sym__Noreturn] = ACTIONS(2008),
    [anon_sym_noreturn] = ACTIONS(2008),
    [anon_sym_mutable] = ACTIONS(2008),
    [anon_sym_constinit] = ACTIONS(2008),
    [anon_sym_consteval] = ACTIONS(2008),
    [anon_sym_alignas] = ACTIONS(2008),
    [anon_sym__Alignas] = ACTIONS(2008),
    [sym_primitive_type] = ACTIONS(2008),
    [anon_sym_enum] = ACTIONS(2008),
    [anon_sym_class] = ACTIONS(2008),
    [anon_sym_struct] = ACTIONS(2008),
    [anon_sym_union] = ACTIONS(2008),
    [anon_sym_if] = ACTIONS(2008),
    [anon_sym_else] = ACTIONS(2645),
    [anon_sym_switch] = ACTIONS(2008),
    [anon_sym_case] = ACTIONS(2008),
    [anon_sym_default] = ACTIONS(2008),
    [anon_sym_while] = ACTIONS(2008),
    [anon_sym_do] = ACTIONS(2008),
    [anon_sym_for] = ACTIONS(2008),
    [anon_sym_return] = ACTIONS(2008),
    [anon_sym_break] = ACTIONS(2008),
    [anon_sym_continue] = ACTIONS(2008),
    [anon_sym_goto] = ACTIONS(2008),
    [anon_sym___try] = ACTIONS(2008),
    [anon_sym___leave] = ACTIONS(2008),
    [anon_sym_not] = ACTIONS(2008),
    [anon_sym_compl] = ACTIONS(2008),
    [anon_sym_DASH_DASH] = ACTIONS(2010),
    [anon_sym_PLUS_PLUS] = ACTIONS(2010),
    [anon_sym_sizeof] = ACTIONS(2008),
    [anon_sym___alignof__] = ACTIONS(2008),
    [anon_sym___alignof] = ACTIONS(2008),
    [anon_sym__alignof] = ACTIONS(2008),
    [anon_sym_alignof] = ACTIONS(2008),
    [anon_sym__Alignof] = ACTIONS(2008),
    [anon_sym_offsetof] = ACTIONS(2008),
    [anon_sym__Generic] = ACTIONS(2008),
    [anon_sym_asm] = ACTIONS(2008),
    [anon_sym___asm__] = ACTIONS(2008),
    [sym_number_literal] = ACTIONS(2010),
    [anon_sym_L_SQUOTE] = ACTIONS(2010),
    [anon_sym_u_SQUOTE] = ACTIONS(2010),
    [anon_sym_U_SQUOTE] = ACTIONS(2010),
    [anon_sym_u8_SQUOTE] = ACTIONS(2010),
    [anon_sym_SQUOTE] = ACTIONS(2010),
    [anon_sym_L_DQUOTE] = ACTIONS(2010),
    [anon_sym_u_DQUOTE] = ACTIONS(2010),
    [anon_sym_U_DQUOTE] = ACTIONS(2010),
    [anon_sym_u8_DQUOTE] = ACTIONS(2010),
    [anon_sym_DQUOTE] = ACTIONS(2010),
    [sym_true] = ACTIONS(2008),
    [sym_false] = ACTIONS(2008),
    [anon_sym_NULL] = ACTIONS(2008),
    [anon_sym_nullptr] = ACTIONS(2008),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2008),
    [anon_sym_decltype] = ACTIONS(2008),
    [sym_virtual] = ACTIONS(2008),
    [anon_sym_explicit] = ACTIONS(2008),
    [anon_sym_typename] = ACTIONS(2008),
    [anon_sym_template] = ACTIONS(2008),
    [anon_sym_operator] = ACTIONS(2008),
    [anon_sym_try] = ACTIONS(2008),
    [anon_sym_delete] = ACTIONS(2008),
    [anon_sym_throw] = ACTIONS(2008),
    [anon_sym_namespace] = ACTIONS(2008),
    [anon_sym_using] = ACTIONS(2008),
    [anon_sym_static_assert] = ACTIONS(2008),
    [anon_sym_concept] = ACTIONS(2008),
    [anon_sym_co_return] = ACTIONS(2008),
    [anon_sym_co_yield] = ACTIONS(2008),
    [anon_sym_R_DQUOTE] = ACTIONS(2010),
    [anon_sym_LR_DQUOTE] = ACTIONS(2010),
    [anon_sym_uR_DQUOTE] = ACTIONS(2010),
    [anon_sym_UR_DQUOTE] = ACTIONS(2010),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2010),
    [anon_sym_co_await] = ACTIONS(2008),
    [anon_sym_new] = ACTIONS(2008),
    [anon_sym_requires] = ACTIONS(2008),
    [sym_this] = ACTIONS(2008),
    [anon_sym_discard] = ACTIONS(2008),
    [anon_sym_precise] = ACTIONS(2008),
    [anon_sym_shared] = ACTIONS(2008),
    [anon_sym_groupshared] = ACTIONS(2008),
    [anon_sym_uniform] = ACTIONS(2008),
    [anon_sym_row_major] = ACTIONS(2008),
    [anon_sym_column_major] = ACTIONS(2008),
    [anon_sym_globallycoherent] = ACTIONS(2008),
    [anon_sym_centroid] = ACTIONS(2008),
    [anon_sym_noperspective] = ACTIONS(2008),
    [anon_sym_nointerpolation] = ACTIONS(2008),
    [anon_sym_sample] = ACTIONS(2008),
    [anon_sym_linear] = ACTIONS(2008),
    [anon_sym_snorm] = ACTIONS(2008),
    [anon_sym_unorm] = ACTIONS(2008),
    [anon_sym_point] = ACTIONS(2008),
    [anon_sym_line] = ACTIONS(2008),
    [anon_sym_triangleadj] = ACTIONS(2008),
    [anon_sym_lineadj] = ACTIONS(2008),
    [anon_sym_triangle] = ACTIONS(2008),
    [anon_sym_cbuffer] = ACTIONS(2008),
  },
  [373] = {
    [sym_preproc_def] = STATE(368),
    [sym_preproc_function_def] = STATE(368),
    [sym_preproc_call] = STATE(368),
    [sym_preproc_if_in_field_declaration_list] = STATE(368),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(368),
    [sym_preproc_else_in_field_declaration_list] = STATE(8412),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8412),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8412),
    [sym_type_definition] = STATE(368),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5626),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6102),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(368),
    [sym_field_declaration] = STATE(368),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1832),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(368),
    [sym_operator_cast] = STATE(6636),
    [sym_inline_method_definition] = STATE(368),
    [sym__constructor_specifiers] = STATE(1832),
    [sym_operator_cast_definition] = STATE(368),
    [sym_operator_cast_declaration] = STATE(368),
    [sym_constructor_or_destructor_definition] = STATE(368),
    [sym_constructor_or_destructor_declaration] = STATE(368),
    [sym_friend_declaration] = STATE(368),
    [sym_access_specifier] = STATE(8379),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(368),
    [sym_alias_declaration] = STATE(368),
    [sym_static_assert_declaration] = STATE(368),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6636),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(368),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1832),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2587),
    [aux_sym_preproc_if_token2] = ACTIONS(2661),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2591),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2591),
    [aux_sym_preproc_else_token1] = ACTIONS(2593),
    [aux_sym_preproc_elif_token1] = ACTIONS(2595),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2597),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2597),
    [sym_preproc_directive] = ACTIONS(2599),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2609),
    [anon_sym_typedef] = ACTIONS(2611),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2629),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2631),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2635),
    [anon_sym_static_assert] = ACTIONS(2637),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [374] = {
    [sym_else_clause] = STATE(421),
    [sym_identifier] = ACTIONS(1994),
    [aux_sym_preproc_include_token1] = ACTIONS(1994),
    [aux_sym_preproc_def_token1] = ACTIONS(1994),
    [aux_sym_preproc_if_token1] = ACTIONS(1994),
    [aux_sym_preproc_if_token2] = ACTIONS(1994),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1994),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1994),
    [sym_preproc_directive] = ACTIONS(1994),
    [anon_sym_LPAREN2] = ACTIONS(1996),
    [anon_sym_BANG] = ACTIONS(1996),
    [anon_sym_TILDE] = ACTIONS(1996),
    [anon_sym_DASH] = ACTIONS(1994),
    [anon_sym_PLUS] = ACTIONS(1994),
    [anon_sym_STAR] = ACTIONS(1996),
    [anon_sym_AMP_AMP] = ACTIONS(1996),
    [anon_sym_AMP] = ACTIONS(1994),
    [anon_sym_SEMI] = ACTIONS(1996),
    [anon_sym___extension__] = ACTIONS(1994),
    [anon_sym_typedef] = ACTIONS(1994),
    [anon_sym_in] = ACTIONS(1994),
    [anon_sym_out] = ACTIONS(1994),
    [anon_sym_inout] = ACTIONS(1994),
    [anon_sym_extern] = ACTIONS(1994),
    [anon_sym___attribute__] = ACTIONS(1994),
    [anon_sym_COLON_COLON] = ACTIONS(1996),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1996),
    [anon_sym___declspec] = ACTIONS(1994),
    [anon_sym___based] = ACTIONS(1994),
    [anon_sym___cdecl] = ACTIONS(1994),
    [anon_sym___clrcall] = ACTIONS(1994),
    [anon_sym___stdcall] = ACTIONS(1994),
    [anon_sym___fastcall] = ACTIONS(1994),
    [anon_sym___thiscall] = ACTIONS(1994),
    [anon_sym___vectorcall] = ACTIONS(1994),
    [anon_sym_LBRACE] = ACTIONS(1996),
    [anon_sym_signed] = ACTIONS(1994),
    [anon_sym_unsigned] = ACTIONS(1994),
    [anon_sym_long] = ACTIONS(1994),
    [anon_sym_short] = ACTIONS(1994),
    [anon_sym_LBRACK] = ACTIONS(1994),
    [anon_sym_static] = ACTIONS(1994),
    [anon_sym_register] = ACTIONS(1994),
    [anon_sym_inline] = ACTIONS(1994),
    [anon_sym___inline] = ACTIONS(1994),
    [anon_sym___inline__] = ACTIONS(1994),
    [anon_sym___forceinline] = ACTIONS(1994),
    [anon_sym_thread_local] = ACTIONS(1994),
    [anon_sym___thread] = ACTIONS(1994),
    [anon_sym_const] = ACTIONS(1994),
    [anon_sym_constexpr] = ACTIONS(1994),
    [anon_sym_volatile] = ACTIONS(1994),
    [anon_sym_restrict] = ACTIONS(1994),
    [anon_sym___restrict__] = ACTIONS(1994),
    [anon_sym__Atomic] = ACTIONS(1994),
    [anon_sym__Noreturn] = ACTIONS(1994),
    [anon_sym_noreturn] = ACTIONS(1994),
    [anon_sym_mutable] = ACTIONS(1994),
    [anon_sym_constinit] = ACTIONS(1994),
    [anon_sym_consteval] = ACTIONS(1994),
    [anon_sym_alignas] = ACTIONS(1994),
    [anon_sym__Alignas] = ACTIONS(1994),
    [sym_primitive_type] = ACTIONS(1994),
    [anon_sym_enum] = ACTIONS(1994),
    [anon_sym_class] = ACTIONS(1994),
    [anon_sym_struct] = ACTIONS(1994),
    [anon_sym_union] = ACTIONS(1994),
    [anon_sym_if] = ACTIONS(1994),
    [anon_sym_else] = ACTIONS(2581),
    [anon_sym_switch] = ACTIONS(1994),
    [anon_sym_case] = ACTIONS(1994),
    [anon_sym_default] = ACTIONS(1994),
    [anon_sym_while] = ACTIONS(1994),
    [anon_sym_do] = ACTIONS(1994),
    [anon_sym_for] = ACTIONS(1994),
    [anon_sym_return] = ACTIONS(1994),
    [anon_sym_break] = ACTIONS(1994),
    [anon_sym_continue] = ACTIONS(1994),
    [anon_sym_goto] = ACTIONS(1994),
    [anon_sym___try] = ACTIONS(1994),
    [anon_sym___leave] = ACTIONS(1994),
    [anon_sym_not] = ACTIONS(1994),
    [anon_sym_compl] = ACTIONS(1994),
    [anon_sym_DASH_DASH] = ACTIONS(1996),
    [anon_sym_PLUS_PLUS] = ACTIONS(1996),
    [anon_sym_sizeof] = ACTIONS(1994),
    [anon_sym___alignof__] = ACTIONS(1994),
    [anon_sym___alignof] = ACTIONS(1994),
    [anon_sym__alignof] = ACTIONS(1994),
    [anon_sym_alignof] = ACTIONS(1994),
    [anon_sym__Alignof] = ACTIONS(1994),
    [anon_sym_offsetof] = ACTIONS(1994),
    [anon_sym__Generic] = ACTIONS(1994),
    [anon_sym_asm] = ACTIONS(1994),
    [anon_sym___asm__] = ACTIONS(1994),
    [sym_number_literal] = ACTIONS(1996),
    [anon_sym_L_SQUOTE] = ACTIONS(1996),
    [anon_sym_u_SQUOTE] = ACTIONS(1996),
    [anon_sym_U_SQUOTE] = ACTIONS(1996),
    [anon_sym_u8_SQUOTE] = ACTIONS(1996),
    [anon_sym_SQUOTE] = ACTIONS(1996),
    [anon_sym_L_DQUOTE] = ACTIONS(1996),
    [anon_sym_u_DQUOTE] = ACTIONS(1996),
    [anon_sym_U_DQUOTE] = ACTIONS(1996),
    [anon_sym_u8_DQUOTE] = ACTIONS(1996),
    [anon_sym_DQUOTE] = ACTIONS(1996),
    [sym_true] = ACTIONS(1994),
    [sym_false] = ACTIONS(1994),
    [anon_sym_NULL] = ACTIONS(1994),
    [anon_sym_nullptr] = ACTIONS(1994),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1994),
    [anon_sym_decltype] = ACTIONS(1994),
    [sym_virtual] = ACTIONS(1994),
    [anon_sym_explicit] = ACTIONS(1994),
    [anon_sym_typename] = ACTIONS(1994),
    [anon_sym_template] = ACTIONS(1994),
    [anon_sym_operator] = ACTIONS(1994),
    [anon_sym_try] = ACTIONS(1994),
    [anon_sym_delete] = ACTIONS(1994),
    [anon_sym_throw] = ACTIONS(1994),
    [anon_sym_namespace] = ACTIONS(1994),
    [anon_sym_using] = ACTIONS(1994),
    [anon_sym_static_assert] = ACTIONS(1994),
    [anon_sym_concept] = ACTIONS(1994),
    [anon_sym_co_return] = ACTIONS(1994),
    [anon_sym_co_yield] = ACTIONS(1994),
    [anon_sym_R_DQUOTE] = ACTIONS(1996),
    [anon_sym_LR_DQUOTE] = ACTIONS(1996),
    [anon_sym_uR_DQUOTE] = ACTIONS(1996),
    [anon_sym_UR_DQUOTE] = ACTIONS(1996),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1996),
    [anon_sym_co_await] = ACTIONS(1994),
    [anon_sym_new] = ACTIONS(1994),
    [anon_sym_requires] = ACTIONS(1994),
    [sym_this] = ACTIONS(1994),
    [anon_sym_discard] = ACTIONS(1994),
    [anon_sym_precise] = ACTIONS(1994),
    [anon_sym_shared] = ACTIONS(1994),
    [anon_sym_groupshared] = ACTIONS(1994),
    [anon_sym_uniform] = ACTIONS(1994),
    [anon_sym_row_major] = ACTIONS(1994),
    [anon_sym_column_major] = ACTIONS(1994),
    [anon_sym_globallycoherent] = ACTIONS(1994),
    [anon_sym_centroid] = ACTIONS(1994),
    [anon_sym_noperspective] = ACTIONS(1994),
    [anon_sym_nointerpolation] = ACTIONS(1994),
    [anon_sym_sample] = ACTIONS(1994),
    [anon_sym_linear] = ACTIONS(1994),
    [anon_sym_snorm] = ACTIONS(1994),
    [anon_sym_unorm] = ACTIONS(1994),
    [anon_sym_point] = ACTIONS(1994),
    [anon_sym_line] = ACTIONS(1994),
    [anon_sym_triangleadj] = ACTIONS(1994),
    [anon_sym_lineadj] = ACTIONS(1994),
    [anon_sym_triangle] = ACTIONS(1994),
    [anon_sym_cbuffer] = ACTIONS(1994),
  },
  [375] = {
    [sym_preproc_def] = STATE(702),
    [sym_preproc_function_def] = STATE(702),
    [sym_preproc_call] = STATE(702),
    [sym_preproc_if_in_field_declaration_list] = STATE(702),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(702),
    [sym_preproc_else_in_field_declaration_list] = STATE(8291),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8291),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8291),
    [sym_type_definition] = STATE(702),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5626),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6102),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(702),
    [sym_field_declaration] = STATE(702),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1832),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(702),
    [sym_operator_cast] = STATE(6636),
    [sym_inline_method_definition] = STATE(702),
    [sym__constructor_specifiers] = STATE(1832),
    [sym_operator_cast_definition] = STATE(702),
    [sym_operator_cast_declaration] = STATE(702),
    [sym_constructor_or_destructor_definition] = STATE(702),
    [sym_constructor_or_destructor_declaration] = STATE(702),
    [sym_friend_declaration] = STATE(702),
    [sym_access_specifier] = STATE(8379),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(702),
    [sym_alias_declaration] = STATE(702),
    [sym_static_assert_declaration] = STATE(702),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6636),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(702),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1832),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2587),
    [aux_sym_preproc_if_token2] = ACTIONS(2663),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2591),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2591),
    [aux_sym_preproc_else_token1] = ACTIONS(2593),
    [aux_sym_preproc_elif_token1] = ACTIONS(2595),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2597),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2597),
    [sym_preproc_directive] = ACTIONS(2599),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2609),
    [anon_sym_typedef] = ACTIONS(2611),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2629),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2631),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2635),
    [anon_sym_static_assert] = ACTIONS(2637),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [376] = {
    [sym_identifier] = ACTIONS(1947),
    [aux_sym_preproc_include_token1] = ACTIONS(1947),
    [aux_sym_preproc_def_token1] = ACTIONS(1947),
    [aux_sym_preproc_if_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1947),
    [sym_preproc_directive] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1945),
    [anon_sym_BANG] = ACTIONS(1945),
    [anon_sym_TILDE] = ACTIONS(1945),
    [anon_sym_DASH] = ACTIONS(1947),
    [anon_sym_PLUS] = ACTIONS(1947),
    [anon_sym_STAR] = ACTIONS(1945),
    [anon_sym_AMP_AMP] = ACTIONS(1945),
    [anon_sym_AMP] = ACTIONS(1947),
    [anon_sym_SEMI] = ACTIONS(1945),
    [anon_sym___extension__] = ACTIONS(1947),
    [anon_sym_typedef] = ACTIONS(1947),
    [anon_sym_in] = ACTIONS(1947),
    [anon_sym_out] = ACTIONS(1947),
    [anon_sym_inout] = ACTIONS(1947),
    [anon_sym_extern] = ACTIONS(1947),
    [anon_sym___attribute__] = ACTIONS(1947),
    [anon_sym_COLON_COLON] = ACTIONS(1945),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1945),
    [anon_sym___declspec] = ACTIONS(1947),
    [anon_sym___based] = ACTIONS(1947),
    [anon_sym___cdecl] = ACTIONS(1947),
    [anon_sym___clrcall] = ACTIONS(1947),
    [anon_sym___stdcall] = ACTIONS(1947),
    [anon_sym___fastcall] = ACTIONS(1947),
    [anon_sym___thiscall] = ACTIONS(1947),
    [anon_sym___vectorcall] = ACTIONS(1947),
    [anon_sym_LBRACE] = ACTIONS(1945),
    [anon_sym_RBRACE] = ACTIONS(1945),
    [anon_sym_signed] = ACTIONS(1947),
    [anon_sym_unsigned] = ACTIONS(1947),
    [anon_sym_long] = ACTIONS(1947),
    [anon_sym_short] = ACTIONS(1947),
    [anon_sym_LBRACK] = ACTIONS(1947),
    [anon_sym_static] = ACTIONS(1947),
    [anon_sym_register] = ACTIONS(1947),
    [anon_sym_inline] = ACTIONS(1947),
    [anon_sym___inline] = ACTIONS(1947),
    [anon_sym___inline__] = ACTIONS(1947),
    [anon_sym___forceinline] = ACTIONS(1947),
    [anon_sym_thread_local] = ACTIONS(1947),
    [anon_sym___thread] = ACTIONS(1947),
    [anon_sym_const] = ACTIONS(1947),
    [anon_sym_constexpr] = ACTIONS(1947),
    [anon_sym_volatile] = ACTIONS(1947),
    [anon_sym_restrict] = ACTIONS(1947),
    [anon_sym___restrict__] = ACTIONS(1947),
    [anon_sym__Atomic] = ACTIONS(1947),
    [anon_sym__Noreturn] = ACTIONS(1947),
    [anon_sym_noreturn] = ACTIONS(1947),
    [anon_sym_mutable] = ACTIONS(1947),
    [anon_sym_constinit] = ACTIONS(1947),
    [anon_sym_consteval] = ACTIONS(1947),
    [anon_sym_alignas] = ACTIONS(1947),
    [anon_sym__Alignas] = ACTIONS(1947),
    [sym_primitive_type] = ACTIONS(1947),
    [anon_sym_enum] = ACTIONS(1947),
    [anon_sym_class] = ACTIONS(1947),
    [anon_sym_struct] = ACTIONS(1947),
    [anon_sym_union] = ACTIONS(1947),
    [anon_sym_if] = ACTIONS(1947),
    [anon_sym_else] = ACTIONS(1947),
    [anon_sym_switch] = ACTIONS(1947),
    [anon_sym_case] = ACTIONS(1947),
    [anon_sym_default] = ACTIONS(1947),
    [anon_sym_while] = ACTIONS(1947),
    [anon_sym_do] = ACTIONS(1947),
    [anon_sym_for] = ACTIONS(1947),
    [anon_sym_return] = ACTIONS(1947),
    [anon_sym_break] = ACTIONS(1947),
    [anon_sym_continue] = ACTIONS(1947),
    [anon_sym_goto] = ACTIONS(1947),
    [anon_sym___try] = ACTIONS(1947),
    [anon_sym___leave] = ACTIONS(1947),
    [anon_sym_not] = ACTIONS(1947),
    [anon_sym_compl] = ACTIONS(1947),
    [anon_sym_DASH_DASH] = ACTIONS(1945),
    [anon_sym_PLUS_PLUS] = ACTIONS(1945),
    [anon_sym_sizeof] = ACTIONS(1947),
    [anon_sym___alignof__] = ACTIONS(1947),
    [anon_sym___alignof] = ACTIONS(1947),
    [anon_sym__alignof] = ACTIONS(1947),
    [anon_sym_alignof] = ACTIONS(1947),
    [anon_sym__Alignof] = ACTIONS(1947),
    [anon_sym_offsetof] = ACTIONS(1947),
    [anon_sym__Generic] = ACTIONS(1947),
    [anon_sym_asm] = ACTIONS(1947),
    [anon_sym___asm__] = ACTIONS(1947),
    [sym_number_literal] = ACTIONS(1945),
    [anon_sym_L_SQUOTE] = ACTIONS(1945),
    [anon_sym_u_SQUOTE] = ACTIONS(1945),
    [anon_sym_U_SQUOTE] = ACTIONS(1945),
    [anon_sym_u8_SQUOTE] = ACTIONS(1945),
    [anon_sym_SQUOTE] = ACTIONS(1945),
    [anon_sym_L_DQUOTE] = ACTIONS(1945),
    [anon_sym_u_DQUOTE] = ACTIONS(1945),
    [anon_sym_U_DQUOTE] = ACTIONS(1945),
    [anon_sym_u8_DQUOTE] = ACTIONS(1945),
    [anon_sym_DQUOTE] = ACTIONS(1945),
    [sym_true] = ACTIONS(1947),
    [sym_false] = ACTIONS(1947),
    [anon_sym_NULL] = ACTIONS(1947),
    [anon_sym_nullptr] = ACTIONS(1947),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1947),
    [anon_sym_decltype] = ACTIONS(1947),
    [sym_virtual] = ACTIONS(1947),
    [anon_sym_explicit] = ACTIONS(1947),
    [anon_sym_typename] = ACTIONS(1947),
    [anon_sym_template] = ACTIONS(1947),
    [anon_sym_operator] = ACTIONS(1947),
    [anon_sym_try] = ACTIONS(1947),
    [anon_sym_delete] = ACTIONS(1947),
    [anon_sym_throw] = ACTIONS(1947),
    [anon_sym_namespace] = ACTIONS(1947),
    [anon_sym_using] = ACTIONS(1947),
    [anon_sym_static_assert] = ACTIONS(1947),
    [anon_sym_concept] = ACTIONS(1947),
    [anon_sym_co_return] = ACTIONS(1947),
    [anon_sym_co_yield] = ACTIONS(1947),
    [anon_sym_catch] = ACTIONS(1947),
    [anon_sym_R_DQUOTE] = ACTIONS(1945),
    [anon_sym_LR_DQUOTE] = ACTIONS(1945),
    [anon_sym_uR_DQUOTE] = ACTIONS(1945),
    [anon_sym_UR_DQUOTE] = ACTIONS(1945),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1945),
    [anon_sym_co_await] = ACTIONS(1947),
    [anon_sym_new] = ACTIONS(1947),
    [anon_sym_requires] = ACTIONS(1947),
    [sym_this] = ACTIONS(1947),
    [anon_sym_discard] = ACTIONS(1947),
    [anon_sym_precise] = ACTIONS(1947),
    [anon_sym_shared] = ACTIONS(1947),
    [anon_sym_groupshared] = ACTIONS(1947),
    [anon_sym_uniform] = ACTIONS(1947),
    [anon_sym_row_major] = ACTIONS(1947),
    [anon_sym_column_major] = ACTIONS(1947),
    [anon_sym_globallycoherent] = ACTIONS(1947),
    [anon_sym_centroid] = ACTIONS(1947),
    [anon_sym_noperspective] = ACTIONS(1947),
    [anon_sym_nointerpolation] = ACTIONS(1947),
    [anon_sym_sample] = ACTIONS(1947),
    [anon_sym_linear] = ACTIONS(1947),
    [anon_sym_snorm] = ACTIONS(1947),
    [anon_sym_unorm] = ACTIONS(1947),
    [anon_sym_point] = ACTIONS(1947),
    [anon_sym_line] = ACTIONS(1947),
    [anon_sym_triangleadj] = ACTIONS(1947),
    [anon_sym_lineadj] = ACTIONS(1947),
    [anon_sym_triangle] = ACTIONS(1947),
    [anon_sym_cbuffer] = ACTIONS(1947),
  },
  [377] = {
    [ts_builtin_sym_end] = ACTIONS(2014),
    [sym_identifier] = ACTIONS(2012),
    [aux_sym_preproc_include_token1] = ACTIONS(2012),
    [aux_sym_preproc_def_token1] = ACTIONS(2012),
    [aux_sym_preproc_if_token1] = ACTIONS(2012),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2012),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2012),
    [sym_preproc_directive] = ACTIONS(2012),
    [anon_sym_LPAREN2] = ACTIONS(2014),
    [anon_sym_BANG] = ACTIONS(2014),
    [anon_sym_TILDE] = ACTIONS(2014),
    [anon_sym_DASH] = ACTIONS(2012),
    [anon_sym_PLUS] = ACTIONS(2012),
    [anon_sym_STAR] = ACTIONS(2014),
    [anon_sym_AMP_AMP] = ACTIONS(2014),
    [anon_sym_AMP] = ACTIONS(2012),
    [anon_sym_SEMI] = ACTIONS(2014),
    [anon_sym___extension__] = ACTIONS(2012),
    [anon_sym_typedef] = ACTIONS(2012),
    [anon_sym_in] = ACTIONS(2012),
    [anon_sym_out] = ACTIONS(2012),
    [anon_sym_inout] = ACTIONS(2012),
    [anon_sym_extern] = ACTIONS(2012),
    [anon_sym___attribute__] = ACTIONS(2012),
    [anon_sym_COLON_COLON] = ACTIONS(2014),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2014),
    [anon_sym___declspec] = ACTIONS(2012),
    [anon_sym___based] = ACTIONS(2012),
    [anon_sym___cdecl] = ACTIONS(2012),
    [anon_sym___clrcall] = ACTIONS(2012),
    [anon_sym___stdcall] = ACTIONS(2012),
    [anon_sym___fastcall] = ACTIONS(2012),
    [anon_sym___thiscall] = ACTIONS(2012),
    [anon_sym___vectorcall] = ACTIONS(2012),
    [anon_sym_LBRACE] = ACTIONS(2014),
    [anon_sym_signed] = ACTIONS(2012),
    [anon_sym_unsigned] = ACTIONS(2012),
    [anon_sym_long] = ACTIONS(2012),
    [anon_sym_short] = ACTIONS(2012),
    [anon_sym_LBRACK] = ACTIONS(2012),
    [anon_sym_static] = ACTIONS(2012),
    [anon_sym_register] = ACTIONS(2012),
    [anon_sym_inline] = ACTIONS(2012),
    [anon_sym___inline] = ACTIONS(2012),
    [anon_sym___inline__] = ACTIONS(2012),
    [anon_sym___forceinline] = ACTIONS(2012),
    [anon_sym_thread_local] = ACTIONS(2012),
    [anon_sym___thread] = ACTIONS(2012),
    [anon_sym_const] = ACTIONS(2012),
    [anon_sym_constexpr] = ACTIONS(2012),
    [anon_sym_volatile] = ACTIONS(2012),
    [anon_sym_restrict] = ACTIONS(2012),
    [anon_sym___restrict__] = ACTIONS(2012),
    [anon_sym__Atomic] = ACTIONS(2012),
    [anon_sym__Noreturn] = ACTIONS(2012),
    [anon_sym_noreturn] = ACTIONS(2012),
    [anon_sym_mutable] = ACTIONS(2012),
    [anon_sym_constinit] = ACTIONS(2012),
    [anon_sym_consteval] = ACTIONS(2012),
    [anon_sym_alignas] = ACTIONS(2012),
    [anon_sym__Alignas] = ACTIONS(2012),
    [sym_primitive_type] = ACTIONS(2012),
    [anon_sym_enum] = ACTIONS(2012),
    [anon_sym_class] = ACTIONS(2012),
    [anon_sym_struct] = ACTIONS(2012),
    [anon_sym_union] = ACTIONS(2012),
    [anon_sym_if] = ACTIONS(2012),
    [anon_sym_else] = ACTIONS(2012),
    [anon_sym_switch] = ACTIONS(2012),
    [anon_sym_case] = ACTIONS(2012),
    [anon_sym_default] = ACTIONS(2012),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_do] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2012),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_break] = ACTIONS(2012),
    [anon_sym_continue] = ACTIONS(2012),
    [anon_sym_goto] = ACTIONS(2012),
    [anon_sym___try] = ACTIONS(2012),
    [anon_sym___leave] = ACTIONS(2012),
    [anon_sym_not] = ACTIONS(2012),
    [anon_sym_compl] = ACTIONS(2012),
    [anon_sym_DASH_DASH] = ACTIONS(2014),
    [anon_sym_PLUS_PLUS] = ACTIONS(2014),
    [anon_sym_sizeof] = ACTIONS(2012),
    [anon_sym___alignof__] = ACTIONS(2012),
    [anon_sym___alignof] = ACTIONS(2012),
    [anon_sym__alignof] = ACTIONS(2012),
    [anon_sym_alignof] = ACTIONS(2012),
    [anon_sym__Alignof] = ACTIONS(2012),
    [anon_sym_offsetof] = ACTIONS(2012),
    [anon_sym__Generic] = ACTIONS(2012),
    [anon_sym_asm] = ACTIONS(2012),
    [anon_sym___asm__] = ACTIONS(2012),
    [sym_number_literal] = ACTIONS(2014),
    [anon_sym_L_SQUOTE] = ACTIONS(2014),
    [anon_sym_u_SQUOTE] = ACTIONS(2014),
    [anon_sym_U_SQUOTE] = ACTIONS(2014),
    [anon_sym_u8_SQUOTE] = ACTIONS(2014),
    [anon_sym_SQUOTE] = ACTIONS(2014),
    [anon_sym_L_DQUOTE] = ACTIONS(2014),
    [anon_sym_u_DQUOTE] = ACTIONS(2014),
    [anon_sym_U_DQUOTE] = ACTIONS(2014),
    [anon_sym_u8_DQUOTE] = ACTIONS(2014),
    [anon_sym_DQUOTE] = ACTIONS(2014),
    [sym_true] = ACTIONS(2012),
    [sym_false] = ACTIONS(2012),
    [anon_sym_NULL] = ACTIONS(2012),
    [anon_sym_nullptr] = ACTIONS(2012),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2012),
    [anon_sym_decltype] = ACTIONS(2012),
    [sym_virtual] = ACTIONS(2012),
    [anon_sym_explicit] = ACTIONS(2012),
    [anon_sym_typename] = ACTIONS(2012),
    [anon_sym_template] = ACTIONS(2012),
    [anon_sym_operator] = ACTIONS(2012),
    [anon_sym_try] = ACTIONS(2012),
    [anon_sym_delete] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2012),
    [anon_sym_namespace] = ACTIONS(2012),
    [anon_sym_using] = ACTIONS(2012),
    [anon_sym_static_assert] = ACTIONS(2012),
    [anon_sym_concept] = ACTIONS(2012),
    [anon_sym_co_return] = ACTIONS(2012),
    [anon_sym_co_yield] = ACTIONS(2012),
    [anon_sym_catch] = ACTIONS(2012),
    [anon_sym_R_DQUOTE] = ACTIONS(2014),
    [anon_sym_LR_DQUOTE] = ACTIONS(2014),
    [anon_sym_uR_DQUOTE] = ACTIONS(2014),
    [anon_sym_UR_DQUOTE] = ACTIONS(2014),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2014),
    [anon_sym_co_await] = ACTIONS(2012),
    [anon_sym_new] = ACTIONS(2012),
    [anon_sym_requires] = ACTIONS(2012),
    [sym_this] = ACTIONS(2012),
    [anon_sym_discard] = ACTIONS(2012),
    [anon_sym_precise] = ACTIONS(2012),
    [anon_sym_shared] = ACTIONS(2012),
    [anon_sym_groupshared] = ACTIONS(2012),
    [anon_sym_uniform] = ACTIONS(2012),
    [anon_sym_row_major] = ACTIONS(2012),
    [anon_sym_column_major] = ACTIONS(2012),
    [anon_sym_globallycoherent] = ACTIONS(2012),
    [anon_sym_centroid] = ACTIONS(2012),
    [anon_sym_noperspective] = ACTIONS(2012),
    [anon_sym_nointerpolation] = ACTIONS(2012),
    [anon_sym_sample] = ACTIONS(2012),
    [anon_sym_linear] = ACTIONS(2012),
    [anon_sym_snorm] = ACTIONS(2012),
    [anon_sym_unorm] = ACTIONS(2012),
    [anon_sym_point] = ACTIONS(2012),
    [anon_sym_line] = ACTIONS(2012),
    [anon_sym_triangleadj] = ACTIONS(2012),
    [anon_sym_lineadj] = ACTIONS(2012),
    [anon_sym_triangle] = ACTIONS(2012),
    [anon_sym_cbuffer] = ACTIONS(2012),
  },
  [378] = {
    [sym_preproc_def] = STATE(359),
    [sym_preproc_function_def] = STATE(359),
    [sym_preproc_call] = STATE(359),
    [sym_preproc_if_in_field_declaration_list] = STATE(359),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(359),
    [sym_preproc_else_in_field_declaration_list] = STATE(8093),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8093),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8093),
    [sym_type_definition] = STATE(359),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5626),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6102),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(359),
    [sym_field_declaration] = STATE(359),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1832),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(359),
    [sym_operator_cast] = STATE(6636),
    [sym_inline_method_definition] = STATE(359),
    [sym__constructor_specifiers] = STATE(1832),
    [sym_operator_cast_definition] = STATE(359),
    [sym_operator_cast_declaration] = STATE(359),
    [sym_constructor_or_destructor_definition] = STATE(359),
    [sym_constructor_or_destructor_declaration] = STATE(359),
    [sym_friend_declaration] = STATE(359),
    [sym_access_specifier] = STATE(8379),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(359),
    [sym_alias_declaration] = STATE(359),
    [sym_static_assert_declaration] = STATE(359),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6636),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(359),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1832),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2587),
    [aux_sym_preproc_if_token2] = ACTIONS(2665),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2591),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2591),
    [aux_sym_preproc_else_token1] = ACTIONS(2593),
    [aux_sym_preproc_elif_token1] = ACTIONS(2595),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2597),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2597),
    [sym_preproc_directive] = ACTIONS(2599),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2609),
    [anon_sym_typedef] = ACTIONS(2611),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2629),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2631),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2635),
    [anon_sym_static_assert] = ACTIONS(2637),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [379] = {
    [sym_else_clause] = STATE(398),
    [ts_builtin_sym_end] = ACTIONS(2006),
    [sym_identifier] = ACTIONS(2004),
    [aux_sym_preproc_include_token1] = ACTIONS(2004),
    [aux_sym_preproc_def_token1] = ACTIONS(2004),
    [aux_sym_preproc_if_token1] = ACTIONS(2004),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2004),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2004),
    [sym_preproc_directive] = ACTIONS(2004),
    [anon_sym_LPAREN2] = ACTIONS(2006),
    [anon_sym_BANG] = ACTIONS(2006),
    [anon_sym_TILDE] = ACTIONS(2006),
    [anon_sym_DASH] = ACTIONS(2004),
    [anon_sym_PLUS] = ACTIONS(2004),
    [anon_sym_STAR] = ACTIONS(2006),
    [anon_sym_AMP_AMP] = ACTIONS(2006),
    [anon_sym_AMP] = ACTIONS(2004),
    [anon_sym_SEMI] = ACTIONS(2006),
    [anon_sym___extension__] = ACTIONS(2004),
    [anon_sym_typedef] = ACTIONS(2004),
    [anon_sym_in] = ACTIONS(2004),
    [anon_sym_out] = ACTIONS(2004),
    [anon_sym_inout] = ACTIONS(2004),
    [anon_sym_extern] = ACTIONS(2004),
    [anon_sym___attribute__] = ACTIONS(2004),
    [anon_sym_COLON_COLON] = ACTIONS(2006),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2006),
    [anon_sym___declspec] = ACTIONS(2004),
    [anon_sym___based] = ACTIONS(2004),
    [anon_sym___cdecl] = ACTIONS(2004),
    [anon_sym___clrcall] = ACTIONS(2004),
    [anon_sym___stdcall] = ACTIONS(2004),
    [anon_sym___fastcall] = ACTIONS(2004),
    [anon_sym___thiscall] = ACTIONS(2004),
    [anon_sym___vectorcall] = ACTIONS(2004),
    [anon_sym_LBRACE] = ACTIONS(2006),
    [anon_sym_signed] = ACTIONS(2004),
    [anon_sym_unsigned] = ACTIONS(2004),
    [anon_sym_long] = ACTIONS(2004),
    [anon_sym_short] = ACTIONS(2004),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(2004),
    [anon_sym_register] = ACTIONS(2004),
    [anon_sym_inline] = ACTIONS(2004),
    [anon_sym___inline] = ACTIONS(2004),
    [anon_sym___inline__] = ACTIONS(2004),
    [anon_sym___forceinline] = ACTIONS(2004),
    [anon_sym_thread_local] = ACTIONS(2004),
    [anon_sym___thread] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(2004),
    [anon_sym_constexpr] = ACTIONS(2004),
    [anon_sym_volatile] = ACTIONS(2004),
    [anon_sym_restrict] = ACTIONS(2004),
    [anon_sym___restrict__] = ACTIONS(2004),
    [anon_sym__Atomic] = ACTIONS(2004),
    [anon_sym__Noreturn] = ACTIONS(2004),
    [anon_sym_noreturn] = ACTIONS(2004),
    [anon_sym_mutable] = ACTIONS(2004),
    [anon_sym_constinit] = ACTIONS(2004),
    [anon_sym_consteval] = ACTIONS(2004),
    [anon_sym_alignas] = ACTIONS(2004),
    [anon_sym__Alignas] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2004),
    [anon_sym_enum] = ACTIONS(2004),
    [anon_sym_class] = ACTIONS(2004),
    [anon_sym_struct] = ACTIONS(2004),
    [anon_sym_union] = ACTIONS(2004),
    [anon_sym_if] = ACTIONS(2004),
    [anon_sym_else] = ACTIONS(2653),
    [anon_sym_switch] = ACTIONS(2004),
    [anon_sym_case] = ACTIONS(2004),
    [anon_sym_default] = ACTIONS(2004),
    [anon_sym_while] = ACTIONS(2004),
    [anon_sym_do] = ACTIONS(2004),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_return] = ACTIONS(2004),
    [anon_sym_break] = ACTIONS(2004),
    [anon_sym_continue] = ACTIONS(2004),
    [anon_sym_goto] = ACTIONS(2004),
    [anon_sym___try] = ACTIONS(2004),
    [anon_sym___leave] = ACTIONS(2004),
    [anon_sym_not] = ACTIONS(2004),
    [anon_sym_compl] = ACTIONS(2004),
    [anon_sym_DASH_DASH] = ACTIONS(2006),
    [anon_sym_PLUS_PLUS] = ACTIONS(2006),
    [anon_sym_sizeof] = ACTIONS(2004),
    [anon_sym___alignof__] = ACTIONS(2004),
    [anon_sym___alignof] = ACTIONS(2004),
    [anon_sym__alignof] = ACTIONS(2004),
    [anon_sym_alignof] = ACTIONS(2004),
    [anon_sym__Alignof] = ACTIONS(2004),
    [anon_sym_offsetof] = ACTIONS(2004),
    [anon_sym__Generic] = ACTIONS(2004),
    [anon_sym_asm] = ACTIONS(2004),
    [anon_sym___asm__] = ACTIONS(2004),
    [sym_number_literal] = ACTIONS(2006),
    [anon_sym_L_SQUOTE] = ACTIONS(2006),
    [anon_sym_u_SQUOTE] = ACTIONS(2006),
    [anon_sym_U_SQUOTE] = ACTIONS(2006),
    [anon_sym_u8_SQUOTE] = ACTIONS(2006),
    [anon_sym_SQUOTE] = ACTIONS(2006),
    [anon_sym_L_DQUOTE] = ACTIONS(2006),
    [anon_sym_u_DQUOTE] = ACTIONS(2006),
    [anon_sym_U_DQUOTE] = ACTIONS(2006),
    [anon_sym_u8_DQUOTE] = ACTIONS(2006),
    [anon_sym_DQUOTE] = ACTIONS(2006),
    [sym_true] = ACTIONS(2004),
    [sym_false] = ACTIONS(2004),
    [anon_sym_NULL] = ACTIONS(2004),
    [anon_sym_nullptr] = ACTIONS(2004),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2004),
    [anon_sym_decltype] = ACTIONS(2004),
    [sym_virtual] = ACTIONS(2004),
    [anon_sym_explicit] = ACTIONS(2004),
    [anon_sym_typename] = ACTIONS(2004),
    [anon_sym_template] = ACTIONS(2004),
    [anon_sym_operator] = ACTIONS(2004),
    [anon_sym_try] = ACTIONS(2004),
    [anon_sym_delete] = ACTIONS(2004),
    [anon_sym_throw] = ACTIONS(2004),
    [anon_sym_namespace] = ACTIONS(2004),
    [anon_sym_using] = ACTIONS(2004),
    [anon_sym_static_assert] = ACTIONS(2004),
    [anon_sym_concept] = ACTIONS(2004),
    [anon_sym_co_return] = ACTIONS(2004),
    [anon_sym_co_yield] = ACTIONS(2004),
    [anon_sym_R_DQUOTE] = ACTIONS(2006),
    [anon_sym_LR_DQUOTE] = ACTIONS(2006),
    [anon_sym_uR_DQUOTE] = ACTIONS(2006),
    [anon_sym_UR_DQUOTE] = ACTIONS(2006),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2006),
    [anon_sym_co_await] = ACTIONS(2004),
    [anon_sym_new] = ACTIONS(2004),
    [anon_sym_requires] = ACTIONS(2004),
    [sym_this] = ACTIONS(2004),
    [anon_sym_discard] = ACTIONS(2004),
    [anon_sym_precise] = ACTIONS(2004),
    [anon_sym_shared] = ACTIONS(2004),
    [anon_sym_groupshared] = ACTIONS(2004),
    [anon_sym_uniform] = ACTIONS(2004),
    [anon_sym_row_major] = ACTIONS(2004),
    [anon_sym_column_major] = ACTIONS(2004),
    [anon_sym_globallycoherent] = ACTIONS(2004),
    [anon_sym_centroid] = ACTIONS(2004),
    [anon_sym_noperspective] = ACTIONS(2004),
    [anon_sym_nointerpolation] = ACTIONS(2004),
    [anon_sym_sample] = ACTIONS(2004),
    [anon_sym_linear] = ACTIONS(2004),
    [anon_sym_snorm] = ACTIONS(2004),
    [anon_sym_unorm] = ACTIONS(2004),
    [anon_sym_point] = ACTIONS(2004),
    [anon_sym_line] = ACTIONS(2004),
    [anon_sym_triangleadj] = ACTIONS(2004),
    [anon_sym_lineadj] = ACTIONS(2004),
    [anon_sym_triangle] = ACTIONS(2004),
    [anon_sym_cbuffer] = ACTIONS(2004),
  },
  [380] = {
    [sym_preproc_def] = STATE(702),
    [sym_preproc_function_def] = STATE(702),
    [sym_preproc_call] = STATE(702),
    [sym_preproc_if_in_field_declaration_list] = STATE(702),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(702),
    [sym_preproc_else_in_field_declaration_list] = STATE(8401),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8401),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8401),
    [sym_type_definition] = STATE(702),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5626),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6102),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(702),
    [sym_field_declaration] = STATE(702),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1832),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(702),
    [sym_operator_cast] = STATE(6636),
    [sym_inline_method_definition] = STATE(702),
    [sym__constructor_specifiers] = STATE(1832),
    [sym_operator_cast_definition] = STATE(702),
    [sym_operator_cast_declaration] = STATE(702),
    [sym_constructor_or_destructor_definition] = STATE(702),
    [sym_constructor_or_destructor_declaration] = STATE(702),
    [sym_friend_declaration] = STATE(702),
    [sym_access_specifier] = STATE(8379),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(702),
    [sym_alias_declaration] = STATE(702),
    [sym_static_assert_declaration] = STATE(702),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6636),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(702),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1832),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2587),
    [aux_sym_preproc_if_token2] = ACTIONS(2667),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2591),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2591),
    [aux_sym_preproc_else_token1] = ACTIONS(2593),
    [aux_sym_preproc_elif_token1] = ACTIONS(2595),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2597),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2597),
    [sym_preproc_directive] = ACTIONS(2599),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2609),
    [anon_sym_typedef] = ACTIONS(2611),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2629),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2631),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2635),
    [anon_sym_static_assert] = ACTIONS(2637),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [381] = {
    [sym_preproc_def] = STATE(375),
    [sym_preproc_function_def] = STATE(375),
    [sym_preproc_call] = STATE(375),
    [sym_preproc_if_in_field_declaration_list] = STATE(375),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(375),
    [sym_preproc_else_in_field_declaration_list] = STATE(8145),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8145),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8145),
    [sym_type_definition] = STATE(375),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5626),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6102),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(375),
    [sym_field_declaration] = STATE(375),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1832),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(375),
    [sym_operator_cast] = STATE(6636),
    [sym_inline_method_definition] = STATE(375),
    [sym__constructor_specifiers] = STATE(1832),
    [sym_operator_cast_definition] = STATE(375),
    [sym_operator_cast_declaration] = STATE(375),
    [sym_constructor_or_destructor_definition] = STATE(375),
    [sym_constructor_or_destructor_declaration] = STATE(375),
    [sym_friend_declaration] = STATE(375),
    [sym_access_specifier] = STATE(8379),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(375),
    [sym_alias_declaration] = STATE(375),
    [sym_static_assert_declaration] = STATE(375),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6636),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(375),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1832),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2587),
    [aux_sym_preproc_if_token2] = ACTIONS(2669),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2591),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2591),
    [aux_sym_preproc_else_token1] = ACTIONS(2593),
    [aux_sym_preproc_elif_token1] = ACTIONS(2595),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2597),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2597),
    [sym_preproc_directive] = ACTIONS(2599),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2609),
    [anon_sym_typedef] = ACTIONS(2611),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2629),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2631),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2635),
    [anon_sym_static_assert] = ACTIONS(2637),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [382] = {
    [sym_preproc_def] = STATE(380),
    [sym_preproc_function_def] = STATE(380),
    [sym_preproc_call] = STATE(380),
    [sym_preproc_if_in_field_declaration_list] = STATE(380),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(380),
    [sym_preproc_else_in_field_declaration_list] = STATE(8290),
    [sym_preproc_elif_in_field_declaration_list] = STATE(8290),
    [sym_preproc_elifdef_in_field_declaration_list] = STATE(8290),
    [sym_type_definition] = STATE(380),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5626),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6102),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(380),
    [sym_field_declaration] = STATE(380),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1832),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(380),
    [sym_operator_cast] = STATE(6636),
    [sym_inline_method_definition] = STATE(380),
    [sym__constructor_specifiers] = STATE(1832),
    [sym_operator_cast_definition] = STATE(380),
    [sym_operator_cast_declaration] = STATE(380),
    [sym_constructor_or_destructor_definition] = STATE(380),
    [sym_constructor_or_destructor_declaration] = STATE(380),
    [sym_friend_declaration] = STATE(380),
    [sym_access_specifier] = STATE(8379),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(380),
    [sym_alias_declaration] = STATE(380),
    [sym_static_assert_declaration] = STATE(380),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6636),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(380),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1832),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2585),
    [aux_sym_preproc_if_token1] = ACTIONS(2587),
    [aux_sym_preproc_if_token2] = ACTIONS(2671),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2591),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2591),
    [aux_sym_preproc_else_token1] = ACTIONS(2593),
    [aux_sym_preproc_elif_token1] = ACTIONS(2595),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2597),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2597),
    [sym_preproc_directive] = ACTIONS(2599),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2609),
    [anon_sym_typedef] = ACTIONS(2611),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2629),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2631),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2635),
    [anon_sym_static_assert] = ACTIONS(2637),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [383] = {
    [sym_else_clause] = STATE(517),
    [sym_identifier] = ACTIONS(2004),
    [aux_sym_preproc_include_token1] = ACTIONS(2004),
    [aux_sym_preproc_def_token1] = ACTIONS(2004),
    [aux_sym_preproc_if_token1] = ACTIONS(2004),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2004),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2004),
    [sym_preproc_directive] = ACTIONS(2004),
    [anon_sym_LPAREN2] = ACTIONS(2006),
    [anon_sym_BANG] = ACTIONS(2006),
    [anon_sym_TILDE] = ACTIONS(2006),
    [anon_sym_DASH] = ACTIONS(2004),
    [anon_sym_PLUS] = ACTIONS(2004),
    [anon_sym_STAR] = ACTIONS(2006),
    [anon_sym_AMP_AMP] = ACTIONS(2006),
    [anon_sym_AMP] = ACTIONS(2004),
    [anon_sym_SEMI] = ACTIONS(2006),
    [anon_sym___extension__] = ACTIONS(2004),
    [anon_sym_typedef] = ACTIONS(2004),
    [anon_sym_in] = ACTIONS(2004),
    [anon_sym_out] = ACTIONS(2004),
    [anon_sym_inout] = ACTIONS(2004),
    [anon_sym_extern] = ACTIONS(2004),
    [anon_sym___attribute__] = ACTIONS(2004),
    [anon_sym_COLON_COLON] = ACTIONS(2006),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2006),
    [anon_sym___declspec] = ACTIONS(2004),
    [anon_sym___based] = ACTIONS(2004),
    [anon_sym___cdecl] = ACTIONS(2004),
    [anon_sym___clrcall] = ACTIONS(2004),
    [anon_sym___stdcall] = ACTIONS(2004),
    [anon_sym___fastcall] = ACTIONS(2004),
    [anon_sym___thiscall] = ACTIONS(2004),
    [anon_sym___vectorcall] = ACTIONS(2004),
    [anon_sym_LBRACE] = ACTIONS(2006),
    [anon_sym_RBRACE] = ACTIONS(2006),
    [anon_sym_signed] = ACTIONS(2004),
    [anon_sym_unsigned] = ACTIONS(2004),
    [anon_sym_long] = ACTIONS(2004),
    [anon_sym_short] = ACTIONS(2004),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(2004),
    [anon_sym_register] = ACTIONS(2004),
    [anon_sym_inline] = ACTIONS(2004),
    [anon_sym___inline] = ACTIONS(2004),
    [anon_sym___inline__] = ACTIONS(2004),
    [anon_sym___forceinline] = ACTIONS(2004),
    [anon_sym_thread_local] = ACTIONS(2004),
    [anon_sym___thread] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(2004),
    [anon_sym_constexpr] = ACTIONS(2004),
    [anon_sym_volatile] = ACTIONS(2004),
    [anon_sym_restrict] = ACTIONS(2004),
    [anon_sym___restrict__] = ACTIONS(2004),
    [anon_sym__Atomic] = ACTIONS(2004),
    [anon_sym__Noreturn] = ACTIONS(2004),
    [anon_sym_noreturn] = ACTIONS(2004),
    [anon_sym_mutable] = ACTIONS(2004),
    [anon_sym_constinit] = ACTIONS(2004),
    [anon_sym_consteval] = ACTIONS(2004),
    [anon_sym_alignas] = ACTIONS(2004),
    [anon_sym__Alignas] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2004),
    [anon_sym_enum] = ACTIONS(2004),
    [anon_sym_class] = ACTIONS(2004),
    [anon_sym_struct] = ACTIONS(2004),
    [anon_sym_union] = ACTIONS(2004),
    [anon_sym_if] = ACTIONS(2004),
    [anon_sym_else] = ACTIONS(2645),
    [anon_sym_switch] = ACTIONS(2004),
    [anon_sym_case] = ACTIONS(2004),
    [anon_sym_default] = ACTIONS(2004),
    [anon_sym_while] = ACTIONS(2004),
    [anon_sym_do] = ACTIONS(2004),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_return] = ACTIONS(2004),
    [anon_sym_break] = ACTIONS(2004),
    [anon_sym_continue] = ACTIONS(2004),
    [anon_sym_goto] = ACTIONS(2004),
    [anon_sym___try] = ACTIONS(2004),
    [anon_sym___leave] = ACTIONS(2004),
    [anon_sym_not] = ACTIONS(2004),
    [anon_sym_compl] = ACTIONS(2004),
    [anon_sym_DASH_DASH] = ACTIONS(2006),
    [anon_sym_PLUS_PLUS] = ACTIONS(2006),
    [anon_sym_sizeof] = ACTIONS(2004),
    [anon_sym___alignof__] = ACTIONS(2004),
    [anon_sym___alignof] = ACTIONS(2004),
    [anon_sym__alignof] = ACTIONS(2004),
    [anon_sym_alignof] = ACTIONS(2004),
    [anon_sym__Alignof] = ACTIONS(2004),
    [anon_sym_offsetof] = ACTIONS(2004),
    [anon_sym__Generic] = ACTIONS(2004),
    [anon_sym_asm] = ACTIONS(2004),
    [anon_sym___asm__] = ACTIONS(2004),
    [sym_number_literal] = ACTIONS(2006),
    [anon_sym_L_SQUOTE] = ACTIONS(2006),
    [anon_sym_u_SQUOTE] = ACTIONS(2006),
    [anon_sym_U_SQUOTE] = ACTIONS(2006),
    [anon_sym_u8_SQUOTE] = ACTIONS(2006),
    [anon_sym_SQUOTE] = ACTIONS(2006),
    [anon_sym_L_DQUOTE] = ACTIONS(2006),
    [anon_sym_u_DQUOTE] = ACTIONS(2006),
    [anon_sym_U_DQUOTE] = ACTIONS(2006),
    [anon_sym_u8_DQUOTE] = ACTIONS(2006),
    [anon_sym_DQUOTE] = ACTIONS(2006),
    [sym_true] = ACTIONS(2004),
    [sym_false] = ACTIONS(2004),
    [anon_sym_NULL] = ACTIONS(2004),
    [anon_sym_nullptr] = ACTIONS(2004),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2004),
    [anon_sym_decltype] = ACTIONS(2004),
    [sym_virtual] = ACTIONS(2004),
    [anon_sym_explicit] = ACTIONS(2004),
    [anon_sym_typename] = ACTIONS(2004),
    [anon_sym_template] = ACTIONS(2004),
    [anon_sym_operator] = ACTIONS(2004),
    [anon_sym_try] = ACTIONS(2004),
    [anon_sym_delete] = ACTIONS(2004),
    [anon_sym_throw] = ACTIONS(2004),
    [anon_sym_namespace] = ACTIONS(2004),
    [anon_sym_using] = ACTIONS(2004),
    [anon_sym_static_assert] = ACTIONS(2004),
    [anon_sym_concept] = ACTIONS(2004),
    [anon_sym_co_return] = ACTIONS(2004),
    [anon_sym_co_yield] = ACTIONS(2004),
    [anon_sym_R_DQUOTE] = ACTIONS(2006),
    [anon_sym_LR_DQUOTE] = ACTIONS(2006),
    [anon_sym_uR_DQUOTE] = ACTIONS(2006),
    [anon_sym_UR_DQUOTE] = ACTIONS(2006),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2006),
    [anon_sym_co_await] = ACTIONS(2004),
    [anon_sym_new] = ACTIONS(2004),
    [anon_sym_requires] = ACTIONS(2004),
    [sym_this] = ACTIONS(2004),
    [anon_sym_discard] = ACTIONS(2004),
    [anon_sym_precise] = ACTIONS(2004),
    [anon_sym_shared] = ACTIONS(2004),
    [anon_sym_groupshared] = ACTIONS(2004),
    [anon_sym_uniform] = ACTIONS(2004),
    [anon_sym_row_major] = ACTIONS(2004),
    [anon_sym_column_major] = ACTIONS(2004),
    [anon_sym_globallycoherent] = ACTIONS(2004),
    [anon_sym_centroid] = ACTIONS(2004),
    [anon_sym_noperspective] = ACTIONS(2004),
    [anon_sym_nointerpolation] = ACTIONS(2004),
    [anon_sym_sample] = ACTIONS(2004),
    [anon_sym_linear] = ACTIONS(2004),
    [anon_sym_snorm] = ACTIONS(2004),
    [anon_sym_unorm] = ACTIONS(2004),
    [anon_sym_point] = ACTIONS(2004),
    [anon_sym_line] = ACTIONS(2004),
    [anon_sym_triangleadj] = ACTIONS(2004),
    [anon_sym_lineadj] = ACTIONS(2004),
    [anon_sym_triangle] = ACTIONS(2004),
    [anon_sym_cbuffer] = ACTIONS(2004),
  },
  [384] = {
    [sym_identifier] = ACTIONS(2178),
    [aux_sym_preproc_include_token1] = ACTIONS(2178),
    [aux_sym_preproc_def_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token2] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2178),
    [sym_preproc_directive] = ACTIONS(2178),
    [anon_sym_LPAREN2] = ACTIONS(2180),
    [anon_sym_BANG] = ACTIONS(2180),
    [anon_sym_TILDE] = ACTIONS(2180),
    [anon_sym_DASH] = ACTIONS(2178),
    [anon_sym_PLUS] = ACTIONS(2178),
    [anon_sym_STAR] = ACTIONS(2180),
    [anon_sym_AMP_AMP] = ACTIONS(2180),
    [anon_sym_AMP] = ACTIONS(2178),
    [anon_sym_SEMI] = ACTIONS(2180),
    [anon_sym___extension__] = ACTIONS(2178),
    [anon_sym_typedef] = ACTIONS(2178),
    [anon_sym_in] = ACTIONS(2178),
    [anon_sym_out] = ACTIONS(2178),
    [anon_sym_inout] = ACTIONS(2178),
    [anon_sym_extern] = ACTIONS(2178),
    [anon_sym___attribute__] = ACTIONS(2178),
    [anon_sym_COLON_COLON] = ACTIONS(2180),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2180),
    [anon_sym___declspec] = ACTIONS(2178),
    [anon_sym___based] = ACTIONS(2178),
    [anon_sym___cdecl] = ACTIONS(2178),
    [anon_sym___clrcall] = ACTIONS(2178),
    [anon_sym___stdcall] = ACTIONS(2178),
    [anon_sym___fastcall] = ACTIONS(2178),
    [anon_sym___thiscall] = ACTIONS(2178),
    [anon_sym___vectorcall] = ACTIONS(2178),
    [anon_sym_LBRACE] = ACTIONS(2180),
    [anon_sym_signed] = ACTIONS(2178),
    [anon_sym_unsigned] = ACTIONS(2178),
    [anon_sym_long] = ACTIONS(2178),
    [anon_sym_short] = ACTIONS(2178),
    [anon_sym_LBRACK] = ACTIONS(2178),
    [anon_sym_static] = ACTIONS(2178),
    [anon_sym_register] = ACTIONS(2178),
    [anon_sym_inline] = ACTIONS(2178),
    [anon_sym___inline] = ACTIONS(2178),
    [anon_sym___inline__] = ACTIONS(2178),
    [anon_sym___forceinline] = ACTIONS(2178),
    [anon_sym_thread_local] = ACTIONS(2178),
    [anon_sym___thread] = ACTIONS(2178),
    [anon_sym_const] = ACTIONS(2178),
    [anon_sym_constexpr] = ACTIONS(2178),
    [anon_sym_volatile] = ACTIONS(2178),
    [anon_sym_restrict] = ACTIONS(2178),
    [anon_sym___restrict__] = ACTIONS(2178),
    [anon_sym__Atomic] = ACTIONS(2178),
    [anon_sym__Noreturn] = ACTIONS(2178),
    [anon_sym_noreturn] = ACTIONS(2178),
    [anon_sym_mutable] = ACTIONS(2178),
    [anon_sym_constinit] = ACTIONS(2178),
    [anon_sym_consteval] = ACTIONS(2178),
    [anon_sym_alignas] = ACTIONS(2178),
    [anon_sym__Alignas] = ACTIONS(2178),
    [sym_primitive_type] = ACTIONS(2178),
    [anon_sym_enum] = ACTIONS(2178),
    [anon_sym_class] = ACTIONS(2178),
    [anon_sym_struct] = ACTIONS(2178),
    [anon_sym_union] = ACTIONS(2178),
    [anon_sym_if] = ACTIONS(2178),
    [anon_sym_else] = ACTIONS(2178),
    [anon_sym_switch] = ACTIONS(2178),
    [anon_sym_case] = ACTIONS(2178),
    [anon_sym_default] = ACTIONS(2178),
    [anon_sym_while] = ACTIONS(2178),
    [anon_sym_do] = ACTIONS(2178),
    [anon_sym_for] = ACTIONS(2178),
    [anon_sym_return] = ACTIONS(2178),
    [anon_sym_break] = ACTIONS(2178),
    [anon_sym_continue] = ACTIONS(2178),
    [anon_sym_goto] = ACTIONS(2178),
    [anon_sym___try] = ACTIONS(2178),
    [anon_sym___leave] = ACTIONS(2178),
    [anon_sym_not] = ACTIONS(2178),
    [anon_sym_compl] = ACTIONS(2178),
    [anon_sym_DASH_DASH] = ACTIONS(2180),
    [anon_sym_PLUS_PLUS] = ACTIONS(2180),
    [anon_sym_sizeof] = ACTIONS(2178),
    [anon_sym___alignof__] = ACTIONS(2178),
    [anon_sym___alignof] = ACTIONS(2178),
    [anon_sym__alignof] = ACTIONS(2178),
    [anon_sym_alignof] = ACTIONS(2178),
    [anon_sym__Alignof] = ACTIONS(2178),
    [anon_sym_offsetof] = ACTIONS(2178),
    [anon_sym__Generic] = ACTIONS(2178),
    [anon_sym_asm] = ACTIONS(2178),
    [anon_sym___asm__] = ACTIONS(2178),
    [sym_number_literal] = ACTIONS(2180),
    [anon_sym_L_SQUOTE] = ACTIONS(2180),
    [anon_sym_u_SQUOTE] = ACTIONS(2180),
    [anon_sym_U_SQUOTE] = ACTIONS(2180),
    [anon_sym_u8_SQUOTE] = ACTIONS(2180),
    [anon_sym_SQUOTE] = ACTIONS(2180),
    [anon_sym_L_DQUOTE] = ACTIONS(2180),
    [anon_sym_u_DQUOTE] = ACTIONS(2180),
    [anon_sym_U_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8_DQUOTE] = ACTIONS(2180),
    [anon_sym_DQUOTE] = ACTIONS(2180),
    [sym_true] = ACTIONS(2178),
    [sym_false] = ACTIONS(2178),
    [anon_sym_NULL] = ACTIONS(2178),
    [anon_sym_nullptr] = ACTIONS(2178),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2178),
    [anon_sym_decltype] = ACTIONS(2178),
    [sym_virtual] = ACTIONS(2178),
    [anon_sym_explicit] = ACTIONS(2178),
    [anon_sym_typename] = ACTIONS(2178),
    [anon_sym_template] = ACTIONS(2178),
    [anon_sym_operator] = ACTIONS(2178),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_delete] = ACTIONS(2178),
    [anon_sym_throw] = ACTIONS(2178),
    [anon_sym_namespace] = ACTIONS(2178),
    [anon_sym_using] = ACTIONS(2178),
    [anon_sym_static_assert] = ACTIONS(2178),
    [anon_sym_concept] = ACTIONS(2178),
    [anon_sym_co_return] = ACTIONS(2178),
    [anon_sym_co_yield] = ACTIONS(2178),
    [anon_sym_R_DQUOTE] = ACTIONS(2180),
    [anon_sym_LR_DQUOTE] = ACTIONS(2180),
    [anon_sym_uR_DQUOTE] = ACTIONS(2180),
    [anon_sym_UR_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2180),
    [anon_sym_co_await] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2178),
    [anon_sym_requires] = ACTIONS(2178),
    [sym_this] = ACTIONS(2178),
    [anon_sym_discard] = ACTIONS(2178),
    [anon_sym_precise] = ACTIONS(2178),
    [anon_sym_shared] = ACTIONS(2178),
    [anon_sym_groupshared] = ACTIONS(2178),
    [anon_sym_uniform] = ACTIONS(2178),
    [anon_sym_row_major] = ACTIONS(2178),
    [anon_sym_column_major] = ACTIONS(2178),
    [anon_sym_globallycoherent] = ACTIONS(2178),
    [anon_sym_centroid] = ACTIONS(2178),
    [anon_sym_noperspective] = ACTIONS(2178),
    [anon_sym_nointerpolation] = ACTIONS(2178),
    [anon_sym_sample] = ACTIONS(2178),
    [anon_sym_linear] = ACTIONS(2178),
    [anon_sym_snorm] = ACTIONS(2178),
    [anon_sym_unorm] = ACTIONS(2178),
    [anon_sym_point] = ACTIONS(2178),
    [anon_sym_line] = ACTIONS(2178),
    [anon_sym_triangleadj] = ACTIONS(2178),
    [anon_sym_lineadj] = ACTIONS(2178),
    [anon_sym_triangle] = ACTIONS(2178),
    [anon_sym_cbuffer] = ACTIONS(2178),
  },
  [385] = {
    [sym_identifier] = ACTIONS(2122),
    [aux_sym_preproc_include_token1] = ACTIONS(2122),
    [aux_sym_preproc_def_token1] = ACTIONS(2122),
    [aux_sym_preproc_if_token1] = ACTIONS(2122),
    [aux_sym_preproc_if_token2] = ACTIONS(2122),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2122),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2122),
    [sym_preproc_directive] = ACTIONS(2122),
    [anon_sym_LPAREN2] = ACTIONS(2124),
    [anon_sym_BANG] = ACTIONS(2124),
    [anon_sym_TILDE] = ACTIONS(2124),
    [anon_sym_DASH] = ACTIONS(2122),
    [anon_sym_PLUS] = ACTIONS(2122),
    [anon_sym_STAR] = ACTIONS(2124),
    [anon_sym_AMP_AMP] = ACTIONS(2124),
    [anon_sym_AMP] = ACTIONS(2122),
    [anon_sym_SEMI] = ACTIONS(2124),
    [anon_sym___extension__] = ACTIONS(2122),
    [anon_sym_typedef] = ACTIONS(2122),
    [anon_sym_in] = ACTIONS(2122),
    [anon_sym_out] = ACTIONS(2122),
    [anon_sym_inout] = ACTIONS(2122),
    [anon_sym_extern] = ACTIONS(2122),
    [anon_sym___attribute__] = ACTIONS(2122),
    [anon_sym_COLON_COLON] = ACTIONS(2124),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2124),
    [anon_sym___declspec] = ACTIONS(2122),
    [anon_sym___based] = ACTIONS(2122),
    [anon_sym___cdecl] = ACTIONS(2122),
    [anon_sym___clrcall] = ACTIONS(2122),
    [anon_sym___stdcall] = ACTIONS(2122),
    [anon_sym___fastcall] = ACTIONS(2122),
    [anon_sym___thiscall] = ACTIONS(2122),
    [anon_sym___vectorcall] = ACTIONS(2122),
    [anon_sym_LBRACE] = ACTIONS(2124),
    [anon_sym_signed] = ACTIONS(2122),
    [anon_sym_unsigned] = ACTIONS(2122),
    [anon_sym_long] = ACTIONS(2122),
    [anon_sym_short] = ACTIONS(2122),
    [anon_sym_LBRACK] = ACTIONS(2122),
    [anon_sym_static] = ACTIONS(2122),
    [anon_sym_register] = ACTIONS(2122),
    [anon_sym_inline] = ACTIONS(2122),
    [anon_sym___inline] = ACTIONS(2122),
    [anon_sym___inline__] = ACTIONS(2122),
    [anon_sym___forceinline] = ACTIONS(2122),
    [anon_sym_thread_local] = ACTIONS(2122),
    [anon_sym___thread] = ACTIONS(2122),
    [anon_sym_const] = ACTIONS(2122),
    [anon_sym_constexpr] = ACTIONS(2122),
    [anon_sym_volatile] = ACTIONS(2122),
    [anon_sym_restrict] = ACTIONS(2122),
    [anon_sym___restrict__] = ACTIONS(2122),
    [anon_sym__Atomic] = ACTIONS(2122),
    [anon_sym__Noreturn] = ACTIONS(2122),
    [anon_sym_noreturn] = ACTIONS(2122),
    [anon_sym_mutable] = ACTIONS(2122),
    [anon_sym_constinit] = ACTIONS(2122),
    [anon_sym_consteval] = ACTIONS(2122),
    [anon_sym_alignas] = ACTIONS(2122),
    [anon_sym__Alignas] = ACTIONS(2122),
    [sym_primitive_type] = ACTIONS(2122),
    [anon_sym_enum] = ACTIONS(2122),
    [anon_sym_class] = ACTIONS(2122),
    [anon_sym_struct] = ACTIONS(2122),
    [anon_sym_union] = ACTIONS(2122),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_else] = ACTIONS(2122),
    [anon_sym_switch] = ACTIONS(2122),
    [anon_sym_case] = ACTIONS(2122),
    [anon_sym_default] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2122),
    [anon_sym_do] = ACTIONS(2122),
    [anon_sym_for] = ACTIONS(2122),
    [anon_sym_return] = ACTIONS(2122),
    [anon_sym_break] = ACTIONS(2122),
    [anon_sym_continue] = ACTIONS(2122),
    [anon_sym_goto] = ACTIONS(2122),
    [anon_sym___try] = ACTIONS(2122),
    [anon_sym___leave] = ACTIONS(2122),
    [anon_sym_not] = ACTIONS(2122),
    [anon_sym_compl] = ACTIONS(2122),
    [anon_sym_DASH_DASH] = ACTIONS(2124),
    [anon_sym_PLUS_PLUS] = ACTIONS(2124),
    [anon_sym_sizeof] = ACTIONS(2122),
    [anon_sym___alignof__] = ACTIONS(2122),
    [anon_sym___alignof] = ACTIONS(2122),
    [anon_sym__alignof] = ACTIONS(2122),
    [anon_sym_alignof] = ACTIONS(2122),
    [anon_sym__Alignof] = ACTIONS(2122),
    [anon_sym_offsetof] = ACTIONS(2122),
    [anon_sym__Generic] = ACTIONS(2122),
    [anon_sym_asm] = ACTIONS(2122),
    [anon_sym___asm__] = ACTIONS(2122),
    [sym_number_literal] = ACTIONS(2124),
    [anon_sym_L_SQUOTE] = ACTIONS(2124),
    [anon_sym_u_SQUOTE] = ACTIONS(2124),
    [anon_sym_U_SQUOTE] = ACTIONS(2124),
    [anon_sym_u8_SQUOTE] = ACTIONS(2124),
    [anon_sym_SQUOTE] = ACTIONS(2124),
    [anon_sym_L_DQUOTE] = ACTIONS(2124),
    [anon_sym_u_DQUOTE] = ACTIONS(2124),
    [anon_sym_U_DQUOTE] = ACTIONS(2124),
    [anon_sym_u8_DQUOTE] = ACTIONS(2124),
    [anon_sym_DQUOTE] = ACTIONS(2124),
    [sym_true] = ACTIONS(2122),
    [sym_false] = ACTIONS(2122),
    [anon_sym_NULL] = ACTIONS(2122),
    [anon_sym_nullptr] = ACTIONS(2122),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2122),
    [anon_sym_decltype] = ACTIONS(2122),
    [sym_virtual] = ACTIONS(2122),
    [anon_sym_explicit] = ACTIONS(2122),
    [anon_sym_typename] = ACTIONS(2122),
    [anon_sym_template] = ACTIONS(2122),
    [anon_sym_operator] = ACTIONS(2122),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_delete] = ACTIONS(2122),
    [anon_sym_throw] = ACTIONS(2122),
    [anon_sym_namespace] = ACTIONS(2122),
    [anon_sym_using] = ACTIONS(2122),
    [anon_sym_static_assert] = ACTIONS(2122),
    [anon_sym_concept] = ACTIONS(2122),
    [anon_sym_co_return] = ACTIONS(2122),
    [anon_sym_co_yield] = ACTIONS(2122),
    [anon_sym_R_DQUOTE] = ACTIONS(2124),
    [anon_sym_LR_DQUOTE] = ACTIONS(2124),
    [anon_sym_uR_DQUOTE] = ACTIONS(2124),
    [anon_sym_UR_DQUOTE] = ACTIONS(2124),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2124),
    [anon_sym_co_await] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(2122),
    [anon_sym_requires] = ACTIONS(2122),
    [sym_this] = ACTIONS(2122),
    [anon_sym_discard] = ACTIONS(2122),
    [anon_sym_precise] = ACTIONS(2122),
    [anon_sym_shared] = ACTIONS(2122),
    [anon_sym_groupshared] = ACTIONS(2122),
    [anon_sym_uniform] = ACTIONS(2122),
    [anon_sym_row_major] = ACTIONS(2122),
    [anon_sym_column_major] = ACTIONS(2122),
    [anon_sym_globallycoherent] = ACTIONS(2122),
    [anon_sym_centroid] = ACTIONS(2122),
    [anon_sym_noperspective] = ACTIONS(2122),
    [anon_sym_nointerpolation] = ACTIONS(2122),
    [anon_sym_sample] = ACTIONS(2122),
    [anon_sym_linear] = ACTIONS(2122),
    [anon_sym_snorm] = ACTIONS(2122),
    [anon_sym_unorm] = ACTIONS(2122),
    [anon_sym_point] = ACTIONS(2122),
    [anon_sym_line] = ACTIONS(2122),
    [anon_sym_triangleadj] = ACTIONS(2122),
    [anon_sym_lineadj] = ACTIONS(2122),
    [anon_sym_triangle] = ACTIONS(2122),
    [anon_sym_cbuffer] = ACTIONS(2122),
  },
  [386] = {
    [sym_identifier] = ACTIONS(2126),
    [aux_sym_preproc_include_token1] = ACTIONS(2126),
    [aux_sym_preproc_def_token1] = ACTIONS(2126),
    [aux_sym_preproc_if_token1] = ACTIONS(2126),
    [aux_sym_preproc_if_token2] = ACTIONS(2126),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2126),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2126),
    [sym_preproc_directive] = ACTIONS(2126),
    [anon_sym_LPAREN2] = ACTIONS(2128),
    [anon_sym_BANG] = ACTIONS(2128),
    [anon_sym_TILDE] = ACTIONS(2128),
    [anon_sym_DASH] = ACTIONS(2126),
    [anon_sym_PLUS] = ACTIONS(2126),
    [anon_sym_STAR] = ACTIONS(2128),
    [anon_sym_AMP_AMP] = ACTIONS(2128),
    [anon_sym_AMP] = ACTIONS(2126),
    [anon_sym_SEMI] = ACTIONS(2128),
    [anon_sym___extension__] = ACTIONS(2126),
    [anon_sym_typedef] = ACTIONS(2126),
    [anon_sym_in] = ACTIONS(2126),
    [anon_sym_out] = ACTIONS(2126),
    [anon_sym_inout] = ACTIONS(2126),
    [anon_sym_extern] = ACTIONS(2126),
    [anon_sym___attribute__] = ACTIONS(2126),
    [anon_sym_COLON_COLON] = ACTIONS(2128),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2128),
    [anon_sym___declspec] = ACTIONS(2126),
    [anon_sym___based] = ACTIONS(2126),
    [anon_sym___cdecl] = ACTIONS(2126),
    [anon_sym___clrcall] = ACTIONS(2126),
    [anon_sym___stdcall] = ACTIONS(2126),
    [anon_sym___fastcall] = ACTIONS(2126),
    [anon_sym___thiscall] = ACTIONS(2126),
    [anon_sym___vectorcall] = ACTIONS(2126),
    [anon_sym_LBRACE] = ACTIONS(2128),
    [anon_sym_signed] = ACTIONS(2126),
    [anon_sym_unsigned] = ACTIONS(2126),
    [anon_sym_long] = ACTIONS(2126),
    [anon_sym_short] = ACTIONS(2126),
    [anon_sym_LBRACK] = ACTIONS(2126),
    [anon_sym_static] = ACTIONS(2126),
    [anon_sym_register] = ACTIONS(2126),
    [anon_sym_inline] = ACTIONS(2126),
    [anon_sym___inline] = ACTIONS(2126),
    [anon_sym___inline__] = ACTIONS(2126),
    [anon_sym___forceinline] = ACTIONS(2126),
    [anon_sym_thread_local] = ACTIONS(2126),
    [anon_sym___thread] = ACTIONS(2126),
    [anon_sym_const] = ACTIONS(2126),
    [anon_sym_constexpr] = ACTIONS(2126),
    [anon_sym_volatile] = ACTIONS(2126),
    [anon_sym_restrict] = ACTIONS(2126),
    [anon_sym___restrict__] = ACTIONS(2126),
    [anon_sym__Atomic] = ACTIONS(2126),
    [anon_sym__Noreturn] = ACTIONS(2126),
    [anon_sym_noreturn] = ACTIONS(2126),
    [anon_sym_mutable] = ACTIONS(2126),
    [anon_sym_constinit] = ACTIONS(2126),
    [anon_sym_consteval] = ACTIONS(2126),
    [anon_sym_alignas] = ACTIONS(2126),
    [anon_sym__Alignas] = ACTIONS(2126),
    [sym_primitive_type] = ACTIONS(2126),
    [anon_sym_enum] = ACTIONS(2126),
    [anon_sym_class] = ACTIONS(2126),
    [anon_sym_struct] = ACTIONS(2126),
    [anon_sym_union] = ACTIONS(2126),
    [anon_sym_if] = ACTIONS(2126),
    [anon_sym_else] = ACTIONS(2126),
    [anon_sym_switch] = ACTIONS(2126),
    [anon_sym_case] = ACTIONS(2126),
    [anon_sym_default] = ACTIONS(2126),
    [anon_sym_while] = ACTIONS(2126),
    [anon_sym_do] = ACTIONS(2126),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_return] = ACTIONS(2126),
    [anon_sym_break] = ACTIONS(2126),
    [anon_sym_continue] = ACTIONS(2126),
    [anon_sym_goto] = ACTIONS(2126),
    [anon_sym___try] = ACTIONS(2126),
    [anon_sym___leave] = ACTIONS(2126),
    [anon_sym_not] = ACTIONS(2126),
    [anon_sym_compl] = ACTIONS(2126),
    [anon_sym_DASH_DASH] = ACTIONS(2128),
    [anon_sym_PLUS_PLUS] = ACTIONS(2128),
    [anon_sym_sizeof] = ACTIONS(2126),
    [anon_sym___alignof__] = ACTIONS(2126),
    [anon_sym___alignof] = ACTIONS(2126),
    [anon_sym__alignof] = ACTIONS(2126),
    [anon_sym_alignof] = ACTIONS(2126),
    [anon_sym__Alignof] = ACTIONS(2126),
    [anon_sym_offsetof] = ACTIONS(2126),
    [anon_sym__Generic] = ACTIONS(2126),
    [anon_sym_asm] = ACTIONS(2126),
    [anon_sym___asm__] = ACTIONS(2126),
    [sym_number_literal] = ACTIONS(2128),
    [anon_sym_L_SQUOTE] = ACTIONS(2128),
    [anon_sym_u_SQUOTE] = ACTIONS(2128),
    [anon_sym_U_SQUOTE] = ACTIONS(2128),
    [anon_sym_u8_SQUOTE] = ACTIONS(2128),
    [anon_sym_SQUOTE] = ACTIONS(2128),
    [anon_sym_L_DQUOTE] = ACTIONS(2128),
    [anon_sym_u_DQUOTE] = ACTIONS(2128),
    [anon_sym_U_DQUOTE] = ACTIONS(2128),
    [anon_sym_u8_DQUOTE] = ACTIONS(2128),
    [anon_sym_DQUOTE] = ACTIONS(2128),
    [sym_true] = ACTIONS(2126),
    [sym_false] = ACTIONS(2126),
    [anon_sym_NULL] = ACTIONS(2126),
    [anon_sym_nullptr] = ACTIONS(2126),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2126),
    [anon_sym_decltype] = ACTIONS(2126),
    [sym_virtual] = ACTIONS(2126),
    [anon_sym_explicit] = ACTIONS(2126),
    [anon_sym_typename] = ACTIONS(2126),
    [anon_sym_template] = ACTIONS(2126),
    [anon_sym_operator] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2126),
    [anon_sym_delete] = ACTIONS(2126),
    [anon_sym_throw] = ACTIONS(2126),
    [anon_sym_namespace] = ACTIONS(2126),
    [anon_sym_using] = ACTIONS(2126),
    [anon_sym_static_assert] = ACTIONS(2126),
    [anon_sym_concept] = ACTIONS(2126),
    [anon_sym_co_return] = ACTIONS(2126),
    [anon_sym_co_yield] = ACTIONS(2126),
    [anon_sym_R_DQUOTE] = ACTIONS(2128),
    [anon_sym_LR_DQUOTE] = ACTIONS(2128),
    [anon_sym_uR_DQUOTE] = ACTIONS(2128),
    [anon_sym_UR_DQUOTE] = ACTIONS(2128),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2128),
    [anon_sym_co_await] = ACTIONS(2126),
    [anon_sym_new] = ACTIONS(2126),
    [anon_sym_requires] = ACTIONS(2126),
    [sym_this] = ACTIONS(2126),
    [anon_sym_discard] = ACTIONS(2126),
    [anon_sym_precise] = ACTIONS(2126),
    [anon_sym_shared] = ACTIONS(2126),
    [anon_sym_groupshared] = ACTIONS(2126),
    [anon_sym_uniform] = ACTIONS(2126),
    [anon_sym_row_major] = ACTIONS(2126),
    [anon_sym_column_major] = ACTIONS(2126),
    [anon_sym_globallycoherent] = ACTIONS(2126),
    [anon_sym_centroid] = ACTIONS(2126),
    [anon_sym_noperspective] = ACTIONS(2126),
    [anon_sym_nointerpolation] = ACTIONS(2126),
    [anon_sym_sample] = ACTIONS(2126),
    [anon_sym_linear] = ACTIONS(2126),
    [anon_sym_snorm] = ACTIONS(2126),
    [anon_sym_unorm] = ACTIONS(2126),
    [anon_sym_point] = ACTIONS(2126),
    [anon_sym_line] = ACTIONS(2126),
    [anon_sym_triangleadj] = ACTIONS(2126),
    [anon_sym_lineadj] = ACTIONS(2126),
    [anon_sym_triangle] = ACTIONS(2126),
    [anon_sym_cbuffer] = ACTIONS(2126),
  },
  [387] = {
    [sym_identifier] = ACTIONS(2154),
    [aux_sym_preproc_include_token1] = ACTIONS(2154),
    [aux_sym_preproc_def_token1] = ACTIONS(2154),
    [aux_sym_preproc_if_token1] = ACTIONS(2154),
    [aux_sym_preproc_if_token2] = ACTIONS(2154),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2154),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2154),
    [sym_preproc_directive] = ACTIONS(2154),
    [anon_sym_LPAREN2] = ACTIONS(2156),
    [anon_sym_BANG] = ACTIONS(2156),
    [anon_sym_TILDE] = ACTIONS(2156),
    [anon_sym_DASH] = ACTIONS(2154),
    [anon_sym_PLUS] = ACTIONS(2154),
    [anon_sym_STAR] = ACTIONS(2156),
    [anon_sym_AMP_AMP] = ACTIONS(2156),
    [anon_sym_AMP] = ACTIONS(2154),
    [anon_sym_SEMI] = ACTIONS(2156),
    [anon_sym___extension__] = ACTIONS(2154),
    [anon_sym_typedef] = ACTIONS(2154),
    [anon_sym_in] = ACTIONS(2154),
    [anon_sym_out] = ACTIONS(2154),
    [anon_sym_inout] = ACTIONS(2154),
    [anon_sym_extern] = ACTIONS(2154),
    [anon_sym___attribute__] = ACTIONS(2154),
    [anon_sym_COLON_COLON] = ACTIONS(2156),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2156),
    [anon_sym___declspec] = ACTIONS(2154),
    [anon_sym___based] = ACTIONS(2154),
    [anon_sym___cdecl] = ACTIONS(2154),
    [anon_sym___clrcall] = ACTIONS(2154),
    [anon_sym___stdcall] = ACTIONS(2154),
    [anon_sym___fastcall] = ACTIONS(2154),
    [anon_sym___thiscall] = ACTIONS(2154),
    [anon_sym___vectorcall] = ACTIONS(2154),
    [anon_sym_LBRACE] = ACTIONS(2156),
    [anon_sym_signed] = ACTIONS(2154),
    [anon_sym_unsigned] = ACTIONS(2154),
    [anon_sym_long] = ACTIONS(2154),
    [anon_sym_short] = ACTIONS(2154),
    [anon_sym_LBRACK] = ACTIONS(2154),
    [anon_sym_static] = ACTIONS(2154),
    [anon_sym_register] = ACTIONS(2154),
    [anon_sym_inline] = ACTIONS(2154),
    [anon_sym___inline] = ACTIONS(2154),
    [anon_sym___inline__] = ACTIONS(2154),
    [anon_sym___forceinline] = ACTIONS(2154),
    [anon_sym_thread_local] = ACTIONS(2154),
    [anon_sym___thread] = ACTIONS(2154),
    [anon_sym_const] = ACTIONS(2154),
    [anon_sym_constexpr] = ACTIONS(2154),
    [anon_sym_volatile] = ACTIONS(2154),
    [anon_sym_restrict] = ACTIONS(2154),
    [anon_sym___restrict__] = ACTIONS(2154),
    [anon_sym__Atomic] = ACTIONS(2154),
    [anon_sym__Noreturn] = ACTIONS(2154),
    [anon_sym_noreturn] = ACTIONS(2154),
    [anon_sym_mutable] = ACTIONS(2154),
    [anon_sym_constinit] = ACTIONS(2154),
    [anon_sym_consteval] = ACTIONS(2154),
    [anon_sym_alignas] = ACTIONS(2154),
    [anon_sym__Alignas] = ACTIONS(2154),
    [sym_primitive_type] = ACTIONS(2154),
    [anon_sym_enum] = ACTIONS(2154),
    [anon_sym_class] = ACTIONS(2154),
    [anon_sym_struct] = ACTIONS(2154),
    [anon_sym_union] = ACTIONS(2154),
    [anon_sym_if] = ACTIONS(2154),
    [anon_sym_else] = ACTIONS(2154),
    [anon_sym_switch] = ACTIONS(2154),
    [anon_sym_case] = ACTIONS(2154),
    [anon_sym_default] = ACTIONS(2154),
    [anon_sym_while] = ACTIONS(2154),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_for] = ACTIONS(2154),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_break] = ACTIONS(2154),
    [anon_sym_continue] = ACTIONS(2154),
    [anon_sym_goto] = ACTIONS(2154),
    [anon_sym___try] = ACTIONS(2154),
    [anon_sym___leave] = ACTIONS(2154),
    [anon_sym_not] = ACTIONS(2154),
    [anon_sym_compl] = ACTIONS(2154),
    [anon_sym_DASH_DASH] = ACTIONS(2156),
    [anon_sym_PLUS_PLUS] = ACTIONS(2156),
    [anon_sym_sizeof] = ACTIONS(2154),
    [anon_sym___alignof__] = ACTIONS(2154),
    [anon_sym___alignof] = ACTIONS(2154),
    [anon_sym__alignof] = ACTIONS(2154),
    [anon_sym_alignof] = ACTIONS(2154),
    [anon_sym__Alignof] = ACTIONS(2154),
    [anon_sym_offsetof] = ACTIONS(2154),
    [anon_sym__Generic] = ACTIONS(2154),
    [anon_sym_asm] = ACTIONS(2154),
    [anon_sym___asm__] = ACTIONS(2154),
    [sym_number_literal] = ACTIONS(2156),
    [anon_sym_L_SQUOTE] = ACTIONS(2156),
    [anon_sym_u_SQUOTE] = ACTIONS(2156),
    [anon_sym_U_SQUOTE] = ACTIONS(2156),
    [anon_sym_u8_SQUOTE] = ACTIONS(2156),
    [anon_sym_SQUOTE] = ACTIONS(2156),
    [anon_sym_L_DQUOTE] = ACTIONS(2156),
    [anon_sym_u_DQUOTE] = ACTIONS(2156),
    [anon_sym_U_DQUOTE] = ACTIONS(2156),
    [anon_sym_u8_DQUOTE] = ACTIONS(2156),
    [anon_sym_DQUOTE] = ACTIONS(2156),
    [sym_true] = ACTIONS(2154),
    [sym_false] = ACTIONS(2154),
    [anon_sym_NULL] = ACTIONS(2154),
    [anon_sym_nullptr] = ACTIONS(2154),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2154),
    [anon_sym_decltype] = ACTIONS(2154),
    [sym_virtual] = ACTIONS(2154),
    [anon_sym_explicit] = ACTIONS(2154),
    [anon_sym_typename] = ACTIONS(2154),
    [anon_sym_template] = ACTIONS(2154),
    [anon_sym_operator] = ACTIONS(2154),
    [anon_sym_try] = ACTIONS(2154),
    [anon_sym_delete] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2154),
    [anon_sym_namespace] = ACTIONS(2154),
    [anon_sym_using] = ACTIONS(2154),
    [anon_sym_static_assert] = ACTIONS(2154),
    [anon_sym_concept] = ACTIONS(2154),
    [anon_sym_co_return] = ACTIONS(2154),
    [anon_sym_co_yield] = ACTIONS(2154),
    [anon_sym_R_DQUOTE] = ACTIONS(2156),
    [anon_sym_LR_DQUOTE] = ACTIONS(2156),
    [anon_sym_uR_DQUOTE] = ACTIONS(2156),
    [anon_sym_UR_DQUOTE] = ACTIONS(2156),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2156),
    [anon_sym_co_await] = ACTIONS(2154),
    [anon_sym_new] = ACTIONS(2154),
    [anon_sym_requires] = ACTIONS(2154),
    [sym_this] = ACTIONS(2154),
    [anon_sym_discard] = ACTIONS(2154),
    [anon_sym_precise] = ACTIONS(2154),
    [anon_sym_shared] = ACTIONS(2154),
    [anon_sym_groupshared] = ACTIONS(2154),
    [anon_sym_uniform] = ACTIONS(2154),
    [anon_sym_row_major] = ACTIONS(2154),
    [anon_sym_column_major] = ACTIONS(2154),
    [anon_sym_globallycoherent] = ACTIONS(2154),
    [anon_sym_centroid] = ACTIONS(2154),
    [anon_sym_noperspective] = ACTIONS(2154),
    [anon_sym_nointerpolation] = ACTIONS(2154),
    [anon_sym_sample] = ACTIONS(2154),
    [anon_sym_linear] = ACTIONS(2154),
    [anon_sym_snorm] = ACTIONS(2154),
    [anon_sym_unorm] = ACTIONS(2154),
    [anon_sym_point] = ACTIONS(2154),
    [anon_sym_line] = ACTIONS(2154),
    [anon_sym_triangleadj] = ACTIONS(2154),
    [anon_sym_lineadj] = ACTIONS(2154),
    [anon_sym_triangle] = ACTIONS(2154),
    [anon_sym_cbuffer] = ACTIONS(2154),
  },
  [388] = {
    [sym_identifier] = ACTIONS(2158),
    [aux_sym_preproc_include_token1] = ACTIONS(2158),
    [aux_sym_preproc_def_token1] = ACTIONS(2158),
    [aux_sym_preproc_if_token1] = ACTIONS(2158),
    [aux_sym_preproc_if_token2] = ACTIONS(2158),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2158),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2158),
    [sym_preproc_directive] = ACTIONS(2158),
    [anon_sym_LPAREN2] = ACTIONS(2160),
    [anon_sym_BANG] = ACTIONS(2160),
    [anon_sym_TILDE] = ACTIONS(2160),
    [anon_sym_DASH] = ACTIONS(2158),
    [anon_sym_PLUS] = ACTIONS(2158),
    [anon_sym_STAR] = ACTIONS(2160),
    [anon_sym_AMP_AMP] = ACTIONS(2160),
    [anon_sym_AMP] = ACTIONS(2158),
    [anon_sym_SEMI] = ACTIONS(2160),
    [anon_sym___extension__] = ACTIONS(2158),
    [anon_sym_typedef] = ACTIONS(2158),
    [anon_sym_in] = ACTIONS(2158),
    [anon_sym_out] = ACTIONS(2158),
    [anon_sym_inout] = ACTIONS(2158),
    [anon_sym_extern] = ACTIONS(2158),
    [anon_sym___attribute__] = ACTIONS(2158),
    [anon_sym_COLON_COLON] = ACTIONS(2160),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2160),
    [anon_sym___declspec] = ACTIONS(2158),
    [anon_sym___based] = ACTIONS(2158),
    [anon_sym___cdecl] = ACTIONS(2158),
    [anon_sym___clrcall] = ACTIONS(2158),
    [anon_sym___stdcall] = ACTIONS(2158),
    [anon_sym___fastcall] = ACTIONS(2158),
    [anon_sym___thiscall] = ACTIONS(2158),
    [anon_sym___vectorcall] = ACTIONS(2158),
    [anon_sym_LBRACE] = ACTIONS(2160),
    [anon_sym_signed] = ACTIONS(2158),
    [anon_sym_unsigned] = ACTIONS(2158),
    [anon_sym_long] = ACTIONS(2158),
    [anon_sym_short] = ACTIONS(2158),
    [anon_sym_LBRACK] = ACTIONS(2158),
    [anon_sym_static] = ACTIONS(2158),
    [anon_sym_register] = ACTIONS(2158),
    [anon_sym_inline] = ACTIONS(2158),
    [anon_sym___inline] = ACTIONS(2158),
    [anon_sym___inline__] = ACTIONS(2158),
    [anon_sym___forceinline] = ACTIONS(2158),
    [anon_sym_thread_local] = ACTIONS(2158),
    [anon_sym___thread] = ACTIONS(2158),
    [anon_sym_const] = ACTIONS(2158),
    [anon_sym_constexpr] = ACTIONS(2158),
    [anon_sym_volatile] = ACTIONS(2158),
    [anon_sym_restrict] = ACTIONS(2158),
    [anon_sym___restrict__] = ACTIONS(2158),
    [anon_sym__Atomic] = ACTIONS(2158),
    [anon_sym__Noreturn] = ACTIONS(2158),
    [anon_sym_noreturn] = ACTIONS(2158),
    [anon_sym_mutable] = ACTIONS(2158),
    [anon_sym_constinit] = ACTIONS(2158),
    [anon_sym_consteval] = ACTIONS(2158),
    [anon_sym_alignas] = ACTIONS(2158),
    [anon_sym__Alignas] = ACTIONS(2158),
    [sym_primitive_type] = ACTIONS(2158),
    [anon_sym_enum] = ACTIONS(2158),
    [anon_sym_class] = ACTIONS(2158),
    [anon_sym_struct] = ACTIONS(2158),
    [anon_sym_union] = ACTIONS(2158),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_else] = ACTIONS(2158),
    [anon_sym_switch] = ACTIONS(2158),
    [anon_sym_case] = ACTIONS(2158),
    [anon_sym_default] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2158),
    [anon_sym_do] = ACTIONS(2158),
    [anon_sym_for] = ACTIONS(2158),
    [anon_sym_return] = ACTIONS(2158),
    [anon_sym_break] = ACTIONS(2158),
    [anon_sym_continue] = ACTIONS(2158),
    [anon_sym_goto] = ACTIONS(2158),
    [anon_sym___try] = ACTIONS(2158),
    [anon_sym___leave] = ACTIONS(2158),
    [anon_sym_not] = ACTIONS(2158),
    [anon_sym_compl] = ACTIONS(2158),
    [anon_sym_DASH_DASH] = ACTIONS(2160),
    [anon_sym_PLUS_PLUS] = ACTIONS(2160),
    [anon_sym_sizeof] = ACTIONS(2158),
    [anon_sym___alignof__] = ACTIONS(2158),
    [anon_sym___alignof] = ACTIONS(2158),
    [anon_sym__alignof] = ACTIONS(2158),
    [anon_sym_alignof] = ACTIONS(2158),
    [anon_sym__Alignof] = ACTIONS(2158),
    [anon_sym_offsetof] = ACTIONS(2158),
    [anon_sym__Generic] = ACTIONS(2158),
    [anon_sym_asm] = ACTIONS(2158),
    [anon_sym___asm__] = ACTIONS(2158),
    [sym_number_literal] = ACTIONS(2160),
    [anon_sym_L_SQUOTE] = ACTIONS(2160),
    [anon_sym_u_SQUOTE] = ACTIONS(2160),
    [anon_sym_U_SQUOTE] = ACTIONS(2160),
    [anon_sym_u8_SQUOTE] = ACTIONS(2160),
    [anon_sym_SQUOTE] = ACTIONS(2160),
    [anon_sym_L_DQUOTE] = ACTIONS(2160),
    [anon_sym_u_DQUOTE] = ACTIONS(2160),
    [anon_sym_U_DQUOTE] = ACTIONS(2160),
    [anon_sym_u8_DQUOTE] = ACTIONS(2160),
    [anon_sym_DQUOTE] = ACTIONS(2160),
    [sym_true] = ACTIONS(2158),
    [sym_false] = ACTIONS(2158),
    [anon_sym_NULL] = ACTIONS(2158),
    [anon_sym_nullptr] = ACTIONS(2158),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2158),
    [anon_sym_decltype] = ACTIONS(2158),
    [sym_virtual] = ACTIONS(2158),
    [anon_sym_explicit] = ACTIONS(2158),
    [anon_sym_typename] = ACTIONS(2158),
    [anon_sym_template] = ACTIONS(2158),
    [anon_sym_operator] = ACTIONS(2158),
    [anon_sym_try] = ACTIONS(2158),
    [anon_sym_delete] = ACTIONS(2158),
    [anon_sym_throw] = ACTIONS(2158),
    [anon_sym_namespace] = ACTIONS(2158),
    [anon_sym_using] = ACTIONS(2158),
    [anon_sym_static_assert] = ACTIONS(2158),
    [anon_sym_concept] = ACTIONS(2158),
    [anon_sym_co_return] = ACTIONS(2158),
    [anon_sym_co_yield] = ACTIONS(2158),
    [anon_sym_R_DQUOTE] = ACTIONS(2160),
    [anon_sym_LR_DQUOTE] = ACTIONS(2160),
    [anon_sym_uR_DQUOTE] = ACTIONS(2160),
    [anon_sym_UR_DQUOTE] = ACTIONS(2160),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2160),
    [anon_sym_co_await] = ACTIONS(2158),
    [anon_sym_new] = ACTIONS(2158),
    [anon_sym_requires] = ACTIONS(2158),
    [sym_this] = ACTIONS(2158),
    [anon_sym_discard] = ACTIONS(2158),
    [anon_sym_precise] = ACTIONS(2158),
    [anon_sym_shared] = ACTIONS(2158),
    [anon_sym_groupshared] = ACTIONS(2158),
    [anon_sym_uniform] = ACTIONS(2158),
    [anon_sym_row_major] = ACTIONS(2158),
    [anon_sym_column_major] = ACTIONS(2158),
    [anon_sym_globallycoherent] = ACTIONS(2158),
    [anon_sym_centroid] = ACTIONS(2158),
    [anon_sym_noperspective] = ACTIONS(2158),
    [anon_sym_nointerpolation] = ACTIONS(2158),
    [anon_sym_sample] = ACTIONS(2158),
    [anon_sym_linear] = ACTIONS(2158),
    [anon_sym_snorm] = ACTIONS(2158),
    [anon_sym_unorm] = ACTIONS(2158),
    [anon_sym_point] = ACTIONS(2158),
    [anon_sym_line] = ACTIONS(2158),
    [anon_sym_triangleadj] = ACTIONS(2158),
    [anon_sym_lineadj] = ACTIONS(2158),
    [anon_sym_triangle] = ACTIONS(2158),
    [anon_sym_cbuffer] = ACTIONS(2158),
  },
  [389] = {
    [sym_identifier] = ACTIONS(2260),
    [aux_sym_preproc_include_token1] = ACTIONS(2260),
    [aux_sym_preproc_def_token1] = ACTIONS(2260),
    [aux_sym_preproc_if_token1] = ACTIONS(2260),
    [aux_sym_preproc_if_token2] = ACTIONS(2260),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2260),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2260),
    [sym_preproc_directive] = ACTIONS(2260),
    [anon_sym_LPAREN2] = ACTIONS(2262),
    [anon_sym_BANG] = ACTIONS(2262),
    [anon_sym_TILDE] = ACTIONS(2262),
    [anon_sym_DASH] = ACTIONS(2260),
    [anon_sym_PLUS] = ACTIONS(2260),
    [anon_sym_STAR] = ACTIONS(2262),
    [anon_sym_AMP_AMP] = ACTIONS(2262),
    [anon_sym_AMP] = ACTIONS(2260),
    [anon_sym_SEMI] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(2260),
    [anon_sym_typedef] = ACTIONS(2260),
    [anon_sym_in] = ACTIONS(2260),
    [anon_sym_out] = ACTIONS(2260),
    [anon_sym_inout] = ACTIONS(2260),
    [anon_sym_extern] = ACTIONS(2260),
    [anon_sym___attribute__] = ACTIONS(2260),
    [anon_sym_COLON_COLON] = ACTIONS(2262),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2262),
    [anon_sym___declspec] = ACTIONS(2260),
    [anon_sym___based] = ACTIONS(2260),
    [anon_sym___cdecl] = ACTIONS(2260),
    [anon_sym___clrcall] = ACTIONS(2260),
    [anon_sym___stdcall] = ACTIONS(2260),
    [anon_sym___fastcall] = ACTIONS(2260),
    [anon_sym___thiscall] = ACTIONS(2260),
    [anon_sym___vectorcall] = ACTIONS(2260),
    [anon_sym_LBRACE] = ACTIONS(2262),
    [anon_sym_signed] = ACTIONS(2260),
    [anon_sym_unsigned] = ACTIONS(2260),
    [anon_sym_long] = ACTIONS(2260),
    [anon_sym_short] = ACTIONS(2260),
    [anon_sym_LBRACK] = ACTIONS(2260),
    [anon_sym_static] = ACTIONS(2260),
    [anon_sym_register] = ACTIONS(2260),
    [anon_sym_inline] = ACTIONS(2260),
    [anon_sym___inline] = ACTIONS(2260),
    [anon_sym___inline__] = ACTIONS(2260),
    [anon_sym___forceinline] = ACTIONS(2260),
    [anon_sym_thread_local] = ACTIONS(2260),
    [anon_sym___thread] = ACTIONS(2260),
    [anon_sym_const] = ACTIONS(2260),
    [anon_sym_constexpr] = ACTIONS(2260),
    [anon_sym_volatile] = ACTIONS(2260),
    [anon_sym_restrict] = ACTIONS(2260),
    [anon_sym___restrict__] = ACTIONS(2260),
    [anon_sym__Atomic] = ACTIONS(2260),
    [anon_sym__Noreturn] = ACTIONS(2260),
    [anon_sym_noreturn] = ACTIONS(2260),
    [anon_sym_mutable] = ACTIONS(2260),
    [anon_sym_constinit] = ACTIONS(2260),
    [anon_sym_consteval] = ACTIONS(2260),
    [anon_sym_alignas] = ACTIONS(2260),
    [anon_sym__Alignas] = ACTIONS(2260),
    [sym_primitive_type] = ACTIONS(2260),
    [anon_sym_enum] = ACTIONS(2260),
    [anon_sym_class] = ACTIONS(2260),
    [anon_sym_struct] = ACTIONS(2260),
    [anon_sym_union] = ACTIONS(2260),
    [anon_sym_if] = ACTIONS(2260),
    [anon_sym_else] = ACTIONS(2260),
    [anon_sym_switch] = ACTIONS(2260),
    [anon_sym_case] = ACTIONS(2260),
    [anon_sym_default] = ACTIONS(2260),
    [anon_sym_while] = ACTIONS(2260),
    [anon_sym_do] = ACTIONS(2260),
    [anon_sym_for] = ACTIONS(2260),
    [anon_sym_return] = ACTIONS(2260),
    [anon_sym_break] = ACTIONS(2260),
    [anon_sym_continue] = ACTIONS(2260),
    [anon_sym_goto] = ACTIONS(2260),
    [anon_sym___try] = ACTIONS(2260),
    [anon_sym___leave] = ACTIONS(2260),
    [anon_sym_not] = ACTIONS(2260),
    [anon_sym_compl] = ACTIONS(2260),
    [anon_sym_DASH_DASH] = ACTIONS(2262),
    [anon_sym_PLUS_PLUS] = ACTIONS(2262),
    [anon_sym_sizeof] = ACTIONS(2260),
    [anon_sym___alignof__] = ACTIONS(2260),
    [anon_sym___alignof] = ACTIONS(2260),
    [anon_sym__alignof] = ACTIONS(2260),
    [anon_sym_alignof] = ACTIONS(2260),
    [anon_sym__Alignof] = ACTIONS(2260),
    [anon_sym_offsetof] = ACTIONS(2260),
    [anon_sym__Generic] = ACTIONS(2260),
    [anon_sym_asm] = ACTIONS(2260),
    [anon_sym___asm__] = ACTIONS(2260),
    [sym_number_literal] = ACTIONS(2262),
    [anon_sym_L_SQUOTE] = ACTIONS(2262),
    [anon_sym_u_SQUOTE] = ACTIONS(2262),
    [anon_sym_U_SQUOTE] = ACTIONS(2262),
    [anon_sym_u8_SQUOTE] = ACTIONS(2262),
    [anon_sym_SQUOTE] = ACTIONS(2262),
    [anon_sym_L_DQUOTE] = ACTIONS(2262),
    [anon_sym_u_DQUOTE] = ACTIONS(2262),
    [anon_sym_U_DQUOTE] = ACTIONS(2262),
    [anon_sym_u8_DQUOTE] = ACTIONS(2262),
    [anon_sym_DQUOTE] = ACTIONS(2262),
    [sym_true] = ACTIONS(2260),
    [sym_false] = ACTIONS(2260),
    [anon_sym_NULL] = ACTIONS(2260),
    [anon_sym_nullptr] = ACTIONS(2260),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2260),
    [anon_sym_decltype] = ACTIONS(2260),
    [sym_virtual] = ACTIONS(2260),
    [anon_sym_explicit] = ACTIONS(2260),
    [anon_sym_typename] = ACTIONS(2260),
    [anon_sym_template] = ACTIONS(2260),
    [anon_sym_operator] = ACTIONS(2260),
    [anon_sym_try] = ACTIONS(2260),
    [anon_sym_delete] = ACTIONS(2260),
    [anon_sym_throw] = ACTIONS(2260),
    [anon_sym_namespace] = ACTIONS(2260),
    [anon_sym_using] = ACTIONS(2260),
    [anon_sym_static_assert] = ACTIONS(2260),
    [anon_sym_concept] = ACTIONS(2260),
    [anon_sym_co_return] = ACTIONS(2260),
    [anon_sym_co_yield] = ACTIONS(2260),
    [anon_sym_R_DQUOTE] = ACTIONS(2262),
    [anon_sym_LR_DQUOTE] = ACTIONS(2262),
    [anon_sym_uR_DQUOTE] = ACTIONS(2262),
    [anon_sym_UR_DQUOTE] = ACTIONS(2262),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2262),
    [anon_sym_co_await] = ACTIONS(2260),
    [anon_sym_new] = ACTIONS(2260),
    [anon_sym_requires] = ACTIONS(2260),
    [sym_this] = ACTIONS(2260),
    [anon_sym_discard] = ACTIONS(2260),
    [anon_sym_precise] = ACTIONS(2260),
    [anon_sym_shared] = ACTIONS(2260),
    [anon_sym_groupshared] = ACTIONS(2260),
    [anon_sym_uniform] = ACTIONS(2260),
    [anon_sym_row_major] = ACTIONS(2260),
    [anon_sym_column_major] = ACTIONS(2260),
    [anon_sym_globallycoherent] = ACTIONS(2260),
    [anon_sym_centroid] = ACTIONS(2260),
    [anon_sym_noperspective] = ACTIONS(2260),
    [anon_sym_nointerpolation] = ACTIONS(2260),
    [anon_sym_sample] = ACTIONS(2260),
    [anon_sym_linear] = ACTIONS(2260),
    [anon_sym_snorm] = ACTIONS(2260),
    [anon_sym_unorm] = ACTIONS(2260),
    [anon_sym_point] = ACTIONS(2260),
    [anon_sym_line] = ACTIONS(2260),
    [anon_sym_triangleadj] = ACTIONS(2260),
    [anon_sym_lineadj] = ACTIONS(2260),
    [anon_sym_triangle] = ACTIONS(2260),
    [anon_sym_cbuffer] = ACTIONS(2260),
  },
  [390] = {
    [sym_identifier] = ACTIONS(2208),
    [aux_sym_preproc_include_token1] = ACTIONS(2208),
    [aux_sym_preproc_def_token1] = ACTIONS(2208),
    [aux_sym_preproc_if_token1] = ACTIONS(2208),
    [aux_sym_preproc_if_token2] = ACTIONS(2208),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2208),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2208),
    [sym_preproc_directive] = ACTIONS(2208),
    [anon_sym_LPAREN2] = ACTIONS(2210),
    [anon_sym_BANG] = ACTIONS(2210),
    [anon_sym_TILDE] = ACTIONS(2210),
    [anon_sym_DASH] = ACTIONS(2208),
    [anon_sym_PLUS] = ACTIONS(2208),
    [anon_sym_STAR] = ACTIONS(2210),
    [anon_sym_AMP_AMP] = ACTIONS(2210),
    [anon_sym_AMP] = ACTIONS(2208),
    [anon_sym_SEMI] = ACTIONS(2210),
    [anon_sym___extension__] = ACTIONS(2208),
    [anon_sym_typedef] = ACTIONS(2208),
    [anon_sym_in] = ACTIONS(2208),
    [anon_sym_out] = ACTIONS(2208),
    [anon_sym_inout] = ACTIONS(2208),
    [anon_sym_extern] = ACTIONS(2208),
    [anon_sym___attribute__] = ACTIONS(2208),
    [anon_sym_COLON_COLON] = ACTIONS(2210),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2210),
    [anon_sym___declspec] = ACTIONS(2208),
    [anon_sym___based] = ACTIONS(2208),
    [anon_sym___cdecl] = ACTIONS(2208),
    [anon_sym___clrcall] = ACTIONS(2208),
    [anon_sym___stdcall] = ACTIONS(2208),
    [anon_sym___fastcall] = ACTIONS(2208),
    [anon_sym___thiscall] = ACTIONS(2208),
    [anon_sym___vectorcall] = ACTIONS(2208),
    [anon_sym_LBRACE] = ACTIONS(2210),
    [anon_sym_signed] = ACTIONS(2208),
    [anon_sym_unsigned] = ACTIONS(2208),
    [anon_sym_long] = ACTIONS(2208),
    [anon_sym_short] = ACTIONS(2208),
    [anon_sym_LBRACK] = ACTIONS(2208),
    [anon_sym_static] = ACTIONS(2208),
    [anon_sym_register] = ACTIONS(2208),
    [anon_sym_inline] = ACTIONS(2208),
    [anon_sym___inline] = ACTIONS(2208),
    [anon_sym___inline__] = ACTIONS(2208),
    [anon_sym___forceinline] = ACTIONS(2208),
    [anon_sym_thread_local] = ACTIONS(2208),
    [anon_sym___thread] = ACTIONS(2208),
    [anon_sym_const] = ACTIONS(2208),
    [anon_sym_constexpr] = ACTIONS(2208),
    [anon_sym_volatile] = ACTIONS(2208),
    [anon_sym_restrict] = ACTIONS(2208),
    [anon_sym___restrict__] = ACTIONS(2208),
    [anon_sym__Atomic] = ACTIONS(2208),
    [anon_sym__Noreturn] = ACTIONS(2208),
    [anon_sym_noreturn] = ACTIONS(2208),
    [anon_sym_mutable] = ACTIONS(2208),
    [anon_sym_constinit] = ACTIONS(2208),
    [anon_sym_consteval] = ACTIONS(2208),
    [anon_sym_alignas] = ACTIONS(2208),
    [anon_sym__Alignas] = ACTIONS(2208),
    [sym_primitive_type] = ACTIONS(2208),
    [anon_sym_enum] = ACTIONS(2208),
    [anon_sym_class] = ACTIONS(2208),
    [anon_sym_struct] = ACTIONS(2208),
    [anon_sym_union] = ACTIONS(2208),
    [anon_sym_if] = ACTIONS(2208),
    [anon_sym_else] = ACTIONS(2208),
    [anon_sym_switch] = ACTIONS(2208),
    [anon_sym_case] = ACTIONS(2208),
    [anon_sym_default] = ACTIONS(2208),
    [anon_sym_while] = ACTIONS(2208),
    [anon_sym_do] = ACTIONS(2208),
    [anon_sym_for] = ACTIONS(2208),
    [anon_sym_return] = ACTIONS(2208),
    [anon_sym_break] = ACTIONS(2208),
    [anon_sym_continue] = ACTIONS(2208),
    [anon_sym_goto] = ACTIONS(2208),
    [anon_sym___try] = ACTIONS(2208),
    [anon_sym___leave] = ACTIONS(2208),
    [anon_sym_not] = ACTIONS(2208),
    [anon_sym_compl] = ACTIONS(2208),
    [anon_sym_DASH_DASH] = ACTIONS(2210),
    [anon_sym_PLUS_PLUS] = ACTIONS(2210),
    [anon_sym_sizeof] = ACTIONS(2208),
    [anon_sym___alignof__] = ACTIONS(2208),
    [anon_sym___alignof] = ACTIONS(2208),
    [anon_sym__alignof] = ACTIONS(2208),
    [anon_sym_alignof] = ACTIONS(2208),
    [anon_sym__Alignof] = ACTIONS(2208),
    [anon_sym_offsetof] = ACTIONS(2208),
    [anon_sym__Generic] = ACTIONS(2208),
    [anon_sym_asm] = ACTIONS(2208),
    [anon_sym___asm__] = ACTIONS(2208),
    [sym_number_literal] = ACTIONS(2210),
    [anon_sym_L_SQUOTE] = ACTIONS(2210),
    [anon_sym_u_SQUOTE] = ACTIONS(2210),
    [anon_sym_U_SQUOTE] = ACTIONS(2210),
    [anon_sym_u8_SQUOTE] = ACTIONS(2210),
    [anon_sym_SQUOTE] = ACTIONS(2210),
    [anon_sym_L_DQUOTE] = ACTIONS(2210),
    [anon_sym_u_DQUOTE] = ACTIONS(2210),
    [anon_sym_U_DQUOTE] = ACTIONS(2210),
    [anon_sym_u8_DQUOTE] = ACTIONS(2210),
    [anon_sym_DQUOTE] = ACTIONS(2210),
    [sym_true] = ACTIONS(2208),
    [sym_false] = ACTIONS(2208),
    [anon_sym_NULL] = ACTIONS(2208),
    [anon_sym_nullptr] = ACTIONS(2208),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2208),
    [anon_sym_decltype] = ACTIONS(2208),
    [sym_virtual] = ACTIONS(2208),
    [anon_sym_explicit] = ACTIONS(2208),
    [anon_sym_typename] = ACTIONS(2208),
    [anon_sym_template] = ACTIONS(2208),
    [anon_sym_operator] = ACTIONS(2208),
    [anon_sym_try] = ACTIONS(2208),
    [anon_sym_delete] = ACTIONS(2208),
    [anon_sym_throw] = ACTIONS(2208),
    [anon_sym_namespace] = ACTIONS(2208),
    [anon_sym_using] = ACTIONS(2208),
    [anon_sym_static_assert] = ACTIONS(2208),
    [anon_sym_concept] = ACTIONS(2208),
    [anon_sym_co_return] = ACTIONS(2208),
    [anon_sym_co_yield] = ACTIONS(2208),
    [anon_sym_R_DQUOTE] = ACTIONS(2210),
    [anon_sym_LR_DQUOTE] = ACTIONS(2210),
    [anon_sym_uR_DQUOTE] = ACTIONS(2210),
    [anon_sym_UR_DQUOTE] = ACTIONS(2210),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2210),
    [anon_sym_co_await] = ACTIONS(2208),
    [anon_sym_new] = ACTIONS(2208),
    [anon_sym_requires] = ACTIONS(2208),
    [sym_this] = ACTIONS(2208),
    [anon_sym_discard] = ACTIONS(2208),
    [anon_sym_precise] = ACTIONS(2208),
    [anon_sym_shared] = ACTIONS(2208),
    [anon_sym_groupshared] = ACTIONS(2208),
    [anon_sym_uniform] = ACTIONS(2208),
    [anon_sym_row_major] = ACTIONS(2208),
    [anon_sym_column_major] = ACTIONS(2208),
    [anon_sym_globallycoherent] = ACTIONS(2208),
    [anon_sym_centroid] = ACTIONS(2208),
    [anon_sym_noperspective] = ACTIONS(2208),
    [anon_sym_nointerpolation] = ACTIONS(2208),
    [anon_sym_sample] = ACTIONS(2208),
    [anon_sym_linear] = ACTIONS(2208),
    [anon_sym_snorm] = ACTIONS(2208),
    [anon_sym_unorm] = ACTIONS(2208),
    [anon_sym_point] = ACTIONS(2208),
    [anon_sym_line] = ACTIONS(2208),
    [anon_sym_triangleadj] = ACTIONS(2208),
    [anon_sym_lineadj] = ACTIONS(2208),
    [anon_sym_triangle] = ACTIONS(2208),
    [anon_sym_cbuffer] = ACTIONS(2208),
  },
  [391] = {
    [sym_identifier] = ACTIONS(2212),
    [aux_sym_preproc_include_token1] = ACTIONS(2212),
    [aux_sym_preproc_def_token1] = ACTIONS(2212),
    [aux_sym_preproc_if_token1] = ACTIONS(2212),
    [aux_sym_preproc_if_token2] = ACTIONS(2212),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2212),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2212),
    [sym_preproc_directive] = ACTIONS(2212),
    [anon_sym_LPAREN2] = ACTIONS(2214),
    [anon_sym_BANG] = ACTIONS(2214),
    [anon_sym_TILDE] = ACTIONS(2214),
    [anon_sym_DASH] = ACTIONS(2212),
    [anon_sym_PLUS] = ACTIONS(2212),
    [anon_sym_STAR] = ACTIONS(2214),
    [anon_sym_AMP_AMP] = ACTIONS(2214),
    [anon_sym_AMP] = ACTIONS(2212),
    [anon_sym_SEMI] = ACTIONS(2214),
    [anon_sym___extension__] = ACTIONS(2212),
    [anon_sym_typedef] = ACTIONS(2212),
    [anon_sym_in] = ACTIONS(2212),
    [anon_sym_out] = ACTIONS(2212),
    [anon_sym_inout] = ACTIONS(2212),
    [anon_sym_extern] = ACTIONS(2212),
    [anon_sym___attribute__] = ACTIONS(2212),
    [anon_sym_COLON_COLON] = ACTIONS(2214),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2214),
    [anon_sym___declspec] = ACTIONS(2212),
    [anon_sym___based] = ACTIONS(2212),
    [anon_sym___cdecl] = ACTIONS(2212),
    [anon_sym___clrcall] = ACTIONS(2212),
    [anon_sym___stdcall] = ACTIONS(2212),
    [anon_sym___fastcall] = ACTIONS(2212),
    [anon_sym___thiscall] = ACTIONS(2212),
    [anon_sym___vectorcall] = ACTIONS(2212),
    [anon_sym_LBRACE] = ACTIONS(2214),
    [anon_sym_signed] = ACTIONS(2212),
    [anon_sym_unsigned] = ACTIONS(2212),
    [anon_sym_long] = ACTIONS(2212),
    [anon_sym_short] = ACTIONS(2212),
    [anon_sym_LBRACK] = ACTIONS(2212),
    [anon_sym_static] = ACTIONS(2212),
    [anon_sym_register] = ACTIONS(2212),
    [anon_sym_inline] = ACTIONS(2212),
    [anon_sym___inline] = ACTIONS(2212),
    [anon_sym___inline__] = ACTIONS(2212),
    [anon_sym___forceinline] = ACTIONS(2212),
    [anon_sym_thread_local] = ACTIONS(2212),
    [anon_sym___thread] = ACTIONS(2212),
    [anon_sym_const] = ACTIONS(2212),
    [anon_sym_constexpr] = ACTIONS(2212),
    [anon_sym_volatile] = ACTIONS(2212),
    [anon_sym_restrict] = ACTIONS(2212),
    [anon_sym___restrict__] = ACTIONS(2212),
    [anon_sym__Atomic] = ACTIONS(2212),
    [anon_sym__Noreturn] = ACTIONS(2212),
    [anon_sym_noreturn] = ACTIONS(2212),
    [anon_sym_mutable] = ACTIONS(2212),
    [anon_sym_constinit] = ACTIONS(2212),
    [anon_sym_consteval] = ACTIONS(2212),
    [anon_sym_alignas] = ACTIONS(2212),
    [anon_sym__Alignas] = ACTIONS(2212),
    [sym_primitive_type] = ACTIONS(2212),
    [anon_sym_enum] = ACTIONS(2212),
    [anon_sym_class] = ACTIONS(2212),
    [anon_sym_struct] = ACTIONS(2212),
    [anon_sym_union] = ACTIONS(2212),
    [anon_sym_if] = ACTIONS(2212),
    [anon_sym_else] = ACTIONS(2212),
    [anon_sym_switch] = ACTIONS(2212),
    [anon_sym_case] = ACTIONS(2212),
    [anon_sym_default] = ACTIONS(2212),
    [anon_sym_while] = ACTIONS(2212),
    [anon_sym_do] = ACTIONS(2212),
    [anon_sym_for] = ACTIONS(2212),
    [anon_sym_return] = ACTIONS(2212),
    [anon_sym_break] = ACTIONS(2212),
    [anon_sym_continue] = ACTIONS(2212),
    [anon_sym_goto] = ACTIONS(2212),
    [anon_sym___try] = ACTIONS(2212),
    [anon_sym___leave] = ACTIONS(2212),
    [anon_sym_not] = ACTIONS(2212),
    [anon_sym_compl] = ACTIONS(2212),
    [anon_sym_DASH_DASH] = ACTIONS(2214),
    [anon_sym_PLUS_PLUS] = ACTIONS(2214),
    [anon_sym_sizeof] = ACTIONS(2212),
    [anon_sym___alignof__] = ACTIONS(2212),
    [anon_sym___alignof] = ACTIONS(2212),
    [anon_sym__alignof] = ACTIONS(2212),
    [anon_sym_alignof] = ACTIONS(2212),
    [anon_sym__Alignof] = ACTIONS(2212),
    [anon_sym_offsetof] = ACTIONS(2212),
    [anon_sym__Generic] = ACTIONS(2212),
    [anon_sym_asm] = ACTIONS(2212),
    [anon_sym___asm__] = ACTIONS(2212),
    [sym_number_literal] = ACTIONS(2214),
    [anon_sym_L_SQUOTE] = ACTIONS(2214),
    [anon_sym_u_SQUOTE] = ACTIONS(2214),
    [anon_sym_U_SQUOTE] = ACTIONS(2214),
    [anon_sym_u8_SQUOTE] = ACTIONS(2214),
    [anon_sym_SQUOTE] = ACTIONS(2214),
    [anon_sym_L_DQUOTE] = ACTIONS(2214),
    [anon_sym_u_DQUOTE] = ACTIONS(2214),
    [anon_sym_U_DQUOTE] = ACTIONS(2214),
    [anon_sym_u8_DQUOTE] = ACTIONS(2214),
    [anon_sym_DQUOTE] = ACTIONS(2214),
    [sym_true] = ACTIONS(2212),
    [sym_false] = ACTIONS(2212),
    [anon_sym_NULL] = ACTIONS(2212),
    [anon_sym_nullptr] = ACTIONS(2212),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2212),
    [anon_sym_decltype] = ACTIONS(2212),
    [sym_virtual] = ACTIONS(2212),
    [anon_sym_explicit] = ACTIONS(2212),
    [anon_sym_typename] = ACTIONS(2212),
    [anon_sym_template] = ACTIONS(2212),
    [anon_sym_operator] = ACTIONS(2212),
    [anon_sym_try] = ACTIONS(2212),
    [anon_sym_delete] = ACTIONS(2212),
    [anon_sym_throw] = ACTIONS(2212),
    [anon_sym_namespace] = ACTIONS(2212),
    [anon_sym_using] = ACTIONS(2212),
    [anon_sym_static_assert] = ACTIONS(2212),
    [anon_sym_concept] = ACTIONS(2212),
    [anon_sym_co_return] = ACTIONS(2212),
    [anon_sym_co_yield] = ACTIONS(2212),
    [anon_sym_R_DQUOTE] = ACTIONS(2214),
    [anon_sym_LR_DQUOTE] = ACTIONS(2214),
    [anon_sym_uR_DQUOTE] = ACTIONS(2214),
    [anon_sym_UR_DQUOTE] = ACTIONS(2214),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2214),
    [anon_sym_co_await] = ACTIONS(2212),
    [anon_sym_new] = ACTIONS(2212),
    [anon_sym_requires] = ACTIONS(2212),
    [sym_this] = ACTIONS(2212),
    [anon_sym_discard] = ACTIONS(2212),
    [anon_sym_precise] = ACTIONS(2212),
    [anon_sym_shared] = ACTIONS(2212),
    [anon_sym_groupshared] = ACTIONS(2212),
    [anon_sym_uniform] = ACTIONS(2212),
    [anon_sym_row_major] = ACTIONS(2212),
    [anon_sym_column_major] = ACTIONS(2212),
    [anon_sym_globallycoherent] = ACTIONS(2212),
    [anon_sym_centroid] = ACTIONS(2212),
    [anon_sym_noperspective] = ACTIONS(2212),
    [anon_sym_nointerpolation] = ACTIONS(2212),
    [anon_sym_sample] = ACTIONS(2212),
    [anon_sym_linear] = ACTIONS(2212),
    [anon_sym_snorm] = ACTIONS(2212),
    [anon_sym_unorm] = ACTIONS(2212),
    [anon_sym_point] = ACTIONS(2212),
    [anon_sym_line] = ACTIONS(2212),
    [anon_sym_triangleadj] = ACTIONS(2212),
    [anon_sym_lineadj] = ACTIONS(2212),
    [anon_sym_triangle] = ACTIONS(2212),
    [anon_sym_cbuffer] = ACTIONS(2212),
  },
  [392] = {
    [sym_identifier] = ACTIONS(2232),
    [aux_sym_preproc_include_token1] = ACTIONS(2232),
    [aux_sym_preproc_def_token1] = ACTIONS(2232),
    [aux_sym_preproc_if_token1] = ACTIONS(2232),
    [aux_sym_preproc_if_token2] = ACTIONS(2232),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2232),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2232),
    [sym_preproc_directive] = ACTIONS(2232),
    [anon_sym_LPAREN2] = ACTIONS(2234),
    [anon_sym_BANG] = ACTIONS(2234),
    [anon_sym_TILDE] = ACTIONS(2234),
    [anon_sym_DASH] = ACTIONS(2232),
    [anon_sym_PLUS] = ACTIONS(2232),
    [anon_sym_STAR] = ACTIONS(2234),
    [anon_sym_AMP_AMP] = ACTIONS(2234),
    [anon_sym_AMP] = ACTIONS(2232),
    [anon_sym_SEMI] = ACTIONS(2234),
    [anon_sym___extension__] = ACTIONS(2232),
    [anon_sym_typedef] = ACTIONS(2232),
    [anon_sym_in] = ACTIONS(2232),
    [anon_sym_out] = ACTIONS(2232),
    [anon_sym_inout] = ACTIONS(2232),
    [anon_sym_extern] = ACTIONS(2232),
    [anon_sym___attribute__] = ACTIONS(2232),
    [anon_sym_COLON_COLON] = ACTIONS(2234),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2234),
    [anon_sym___declspec] = ACTIONS(2232),
    [anon_sym___based] = ACTIONS(2232),
    [anon_sym___cdecl] = ACTIONS(2232),
    [anon_sym___clrcall] = ACTIONS(2232),
    [anon_sym___stdcall] = ACTIONS(2232),
    [anon_sym___fastcall] = ACTIONS(2232),
    [anon_sym___thiscall] = ACTIONS(2232),
    [anon_sym___vectorcall] = ACTIONS(2232),
    [anon_sym_LBRACE] = ACTIONS(2234),
    [anon_sym_signed] = ACTIONS(2232),
    [anon_sym_unsigned] = ACTIONS(2232),
    [anon_sym_long] = ACTIONS(2232),
    [anon_sym_short] = ACTIONS(2232),
    [anon_sym_LBRACK] = ACTIONS(2232),
    [anon_sym_static] = ACTIONS(2232),
    [anon_sym_register] = ACTIONS(2232),
    [anon_sym_inline] = ACTIONS(2232),
    [anon_sym___inline] = ACTIONS(2232),
    [anon_sym___inline__] = ACTIONS(2232),
    [anon_sym___forceinline] = ACTIONS(2232),
    [anon_sym_thread_local] = ACTIONS(2232),
    [anon_sym___thread] = ACTIONS(2232),
    [anon_sym_const] = ACTIONS(2232),
    [anon_sym_constexpr] = ACTIONS(2232),
    [anon_sym_volatile] = ACTIONS(2232),
    [anon_sym_restrict] = ACTIONS(2232),
    [anon_sym___restrict__] = ACTIONS(2232),
    [anon_sym__Atomic] = ACTIONS(2232),
    [anon_sym__Noreturn] = ACTIONS(2232),
    [anon_sym_noreturn] = ACTIONS(2232),
    [anon_sym_mutable] = ACTIONS(2232),
    [anon_sym_constinit] = ACTIONS(2232),
    [anon_sym_consteval] = ACTIONS(2232),
    [anon_sym_alignas] = ACTIONS(2232),
    [anon_sym__Alignas] = ACTIONS(2232),
    [sym_primitive_type] = ACTIONS(2232),
    [anon_sym_enum] = ACTIONS(2232),
    [anon_sym_class] = ACTIONS(2232),
    [anon_sym_struct] = ACTIONS(2232),
    [anon_sym_union] = ACTIONS(2232),
    [anon_sym_if] = ACTIONS(2232),
    [anon_sym_else] = ACTIONS(2232),
    [anon_sym_switch] = ACTIONS(2232),
    [anon_sym_case] = ACTIONS(2232),
    [anon_sym_default] = ACTIONS(2232),
    [anon_sym_while] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(2232),
    [anon_sym_for] = ACTIONS(2232),
    [anon_sym_return] = ACTIONS(2232),
    [anon_sym_break] = ACTIONS(2232),
    [anon_sym_continue] = ACTIONS(2232),
    [anon_sym_goto] = ACTIONS(2232),
    [anon_sym___try] = ACTIONS(2232),
    [anon_sym___leave] = ACTIONS(2232),
    [anon_sym_not] = ACTIONS(2232),
    [anon_sym_compl] = ACTIONS(2232),
    [anon_sym_DASH_DASH] = ACTIONS(2234),
    [anon_sym_PLUS_PLUS] = ACTIONS(2234),
    [anon_sym_sizeof] = ACTIONS(2232),
    [anon_sym___alignof__] = ACTIONS(2232),
    [anon_sym___alignof] = ACTIONS(2232),
    [anon_sym__alignof] = ACTIONS(2232),
    [anon_sym_alignof] = ACTIONS(2232),
    [anon_sym__Alignof] = ACTIONS(2232),
    [anon_sym_offsetof] = ACTIONS(2232),
    [anon_sym__Generic] = ACTIONS(2232),
    [anon_sym_asm] = ACTIONS(2232),
    [anon_sym___asm__] = ACTIONS(2232),
    [sym_number_literal] = ACTIONS(2234),
    [anon_sym_L_SQUOTE] = ACTIONS(2234),
    [anon_sym_u_SQUOTE] = ACTIONS(2234),
    [anon_sym_U_SQUOTE] = ACTIONS(2234),
    [anon_sym_u8_SQUOTE] = ACTIONS(2234),
    [anon_sym_SQUOTE] = ACTIONS(2234),
    [anon_sym_L_DQUOTE] = ACTIONS(2234),
    [anon_sym_u_DQUOTE] = ACTIONS(2234),
    [anon_sym_U_DQUOTE] = ACTIONS(2234),
    [anon_sym_u8_DQUOTE] = ACTIONS(2234),
    [anon_sym_DQUOTE] = ACTIONS(2234),
    [sym_true] = ACTIONS(2232),
    [sym_false] = ACTIONS(2232),
    [anon_sym_NULL] = ACTIONS(2232),
    [anon_sym_nullptr] = ACTIONS(2232),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2232),
    [anon_sym_decltype] = ACTIONS(2232),
    [sym_virtual] = ACTIONS(2232),
    [anon_sym_explicit] = ACTIONS(2232),
    [anon_sym_typename] = ACTIONS(2232),
    [anon_sym_template] = ACTIONS(2232),
    [anon_sym_operator] = ACTIONS(2232),
    [anon_sym_try] = ACTIONS(2232),
    [anon_sym_delete] = ACTIONS(2232),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_namespace] = ACTIONS(2232),
    [anon_sym_using] = ACTIONS(2232),
    [anon_sym_static_assert] = ACTIONS(2232),
    [anon_sym_concept] = ACTIONS(2232),
    [anon_sym_co_return] = ACTIONS(2232),
    [anon_sym_co_yield] = ACTIONS(2232),
    [anon_sym_R_DQUOTE] = ACTIONS(2234),
    [anon_sym_LR_DQUOTE] = ACTIONS(2234),
    [anon_sym_uR_DQUOTE] = ACTIONS(2234),
    [anon_sym_UR_DQUOTE] = ACTIONS(2234),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2234),
    [anon_sym_co_await] = ACTIONS(2232),
    [anon_sym_new] = ACTIONS(2232),
    [anon_sym_requires] = ACTIONS(2232),
    [sym_this] = ACTIONS(2232),
    [anon_sym_discard] = ACTIONS(2232),
    [anon_sym_precise] = ACTIONS(2232),
    [anon_sym_shared] = ACTIONS(2232),
    [anon_sym_groupshared] = ACTIONS(2232),
    [anon_sym_uniform] = ACTIONS(2232),
    [anon_sym_row_major] = ACTIONS(2232),
    [anon_sym_column_major] = ACTIONS(2232),
    [anon_sym_globallycoherent] = ACTIONS(2232),
    [anon_sym_centroid] = ACTIONS(2232),
    [anon_sym_noperspective] = ACTIONS(2232),
    [anon_sym_nointerpolation] = ACTIONS(2232),
    [anon_sym_sample] = ACTIONS(2232),
    [anon_sym_linear] = ACTIONS(2232),
    [anon_sym_snorm] = ACTIONS(2232),
    [anon_sym_unorm] = ACTIONS(2232),
    [anon_sym_point] = ACTIONS(2232),
    [anon_sym_line] = ACTIONS(2232),
    [anon_sym_triangleadj] = ACTIONS(2232),
    [anon_sym_lineadj] = ACTIONS(2232),
    [anon_sym_triangle] = ACTIONS(2232),
    [anon_sym_cbuffer] = ACTIONS(2232),
  },
  [393] = {
    [ts_builtin_sym_end] = ACTIONS(2132),
    [sym_identifier] = ACTIONS(2130),
    [aux_sym_preproc_include_token1] = ACTIONS(2130),
    [aux_sym_preproc_def_token1] = ACTIONS(2130),
    [aux_sym_preproc_if_token1] = ACTIONS(2130),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2130),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2130),
    [sym_preproc_directive] = ACTIONS(2130),
    [anon_sym_LPAREN2] = ACTIONS(2132),
    [anon_sym_BANG] = ACTIONS(2132),
    [anon_sym_TILDE] = ACTIONS(2132),
    [anon_sym_DASH] = ACTIONS(2130),
    [anon_sym_PLUS] = ACTIONS(2130),
    [anon_sym_STAR] = ACTIONS(2132),
    [anon_sym_AMP_AMP] = ACTIONS(2132),
    [anon_sym_AMP] = ACTIONS(2130),
    [anon_sym_SEMI] = ACTIONS(2132),
    [anon_sym___extension__] = ACTIONS(2130),
    [anon_sym_typedef] = ACTIONS(2130),
    [anon_sym_in] = ACTIONS(2130),
    [anon_sym_out] = ACTIONS(2130),
    [anon_sym_inout] = ACTIONS(2130),
    [anon_sym_extern] = ACTIONS(2130),
    [anon_sym___attribute__] = ACTIONS(2130),
    [anon_sym_COLON_COLON] = ACTIONS(2132),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2132),
    [anon_sym___declspec] = ACTIONS(2130),
    [anon_sym___based] = ACTIONS(2130),
    [anon_sym___cdecl] = ACTIONS(2130),
    [anon_sym___clrcall] = ACTIONS(2130),
    [anon_sym___stdcall] = ACTIONS(2130),
    [anon_sym___fastcall] = ACTIONS(2130),
    [anon_sym___thiscall] = ACTIONS(2130),
    [anon_sym___vectorcall] = ACTIONS(2130),
    [anon_sym_LBRACE] = ACTIONS(2132),
    [anon_sym_signed] = ACTIONS(2130),
    [anon_sym_unsigned] = ACTIONS(2130),
    [anon_sym_long] = ACTIONS(2130),
    [anon_sym_short] = ACTIONS(2130),
    [anon_sym_LBRACK] = ACTIONS(2130),
    [anon_sym_static] = ACTIONS(2130),
    [anon_sym_register] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(2130),
    [anon_sym___inline] = ACTIONS(2130),
    [anon_sym___inline__] = ACTIONS(2130),
    [anon_sym___forceinline] = ACTIONS(2130),
    [anon_sym_thread_local] = ACTIONS(2130),
    [anon_sym___thread] = ACTIONS(2130),
    [anon_sym_const] = ACTIONS(2130),
    [anon_sym_constexpr] = ACTIONS(2130),
    [anon_sym_volatile] = ACTIONS(2130),
    [anon_sym_restrict] = ACTIONS(2130),
    [anon_sym___restrict__] = ACTIONS(2130),
    [anon_sym__Atomic] = ACTIONS(2130),
    [anon_sym__Noreturn] = ACTIONS(2130),
    [anon_sym_noreturn] = ACTIONS(2130),
    [anon_sym_mutable] = ACTIONS(2130),
    [anon_sym_constinit] = ACTIONS(2130),
    [anon_sym_consteval] = ACTIONS(2130),
    [anon_sym_alignas] = ACTIONS(2130),
    [anon_sym__Alignas] = ACTIONS(2130),
    [sym_primitive_type] = ACTIONS(2130),
    [anon_sym_enum] = ACTIONS(2130),
    [anon_sym_class] = ACTIONS(2130),
    [anon_sym_struct] = ACTIONS(2130),
    [anon_sym_union] = ACTIONS(2130),
    [anon_sym_if] = ACTIONS(2130),
    [anon_sym_else] = ACTIONS(2130),
    [anon_sym_switch] = ACTIONS(2130),
    [anon_sym_case] = ACTIONS(2130),
    [anon_sym_default] = ACTIONS(2130),
    [anon_sym_while] = ACTIONS(2130),
    [anon_sym_do] = ACTIONS(2130),
    [anon_sym_for] = ACTIONS(2130),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_break] = ACTIONS(2130),
    [anon_sym_continue] = ACTIONS(2130),
    [anon_sym_goto] = ACTIONS(2130),
    [anon_sym___try] = ACTIONS(2130),
    [anon_sym___leave] = ACTIONS(2130),
    [anon_sym_not] = ACTIONS(2130),
    [anon_sym_compl] = ACTIONS(2130),
    [anon_sym_DASH_DASH] = ACTIONS(2132),
    [anon_sym_PLUS_PLUS] = ACTIONS(2132),
    [anon_sym_sizeof] = ACTIONS(2130),
    [anon_sym___alignof__] = ACTIONS(2130),
    [anon_sym___alignof] = ACTIONS(2130),
    [anon_sym__alignof] = ACTIONS(2130),
    [anon_sym_alignof] = ACTIONS(2130),
    [anon_sym__Alignof] = ACTIONS(2130),
    [anon_sym_offsetof] = ACTIONS(2130),
    [anon_sym__Generic] = ACTIONS(2130),
    [anon_sym_asm] = ACTIONS(2130),
    [anon_sym___asm__] = ACTIONS(2130),
    [sym_number_literal] = ACTIONS(2132),
    [anon_sym_L_SQUOTE] = ACTIONS(2132),
    [anon_sym_u_SQUOTE] = ACTIONS(2132),
    [anon_sym_U_SQUOTE] = ACTIONS(2132),
    [anon_sym_u8_SQUOTE] = ACTIONS(2132),
    [anon_sym_SQUOTE] = ACTIONS(2132),
    [anon_sym_L_DQUOTE] = ACTIONS(2132),
    [anon_sym_u_DQUOTE] = ACTIONS(2132),
    [anon_sym_U_DQUOTE] = ACTIONS(2132),
    [anon_sym_u8_DQUOTE] = ACTIONS(2132),
    [anon_sym_DQUOTE] = ACTIONS(2132),
    [sym_true] = ACTIONS(2130),
    [sym_false] = ACTIONS(2130),
    [anon_sym_NULL] = ACTIONS(2130),
    [anon_sym_nullptr] = ACTIONS(2130),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2130),
    [anon_sym_decltype] = ACTIONS(2130),
    [sym_virtual] = ACTIONS(2130),
    [anon_sym_explicit] = ACTIONS(2130),
    [anon_sym_typename] = ACTIONS(2130),
    [anon_sym_template] = ACTIONS(2130),
    [anon_sym_operator] = ACTIONS(2130),
    [anon_sym_try] = ACTIONS(2130),
    [anon_sym_delete] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2130),
    [anon_sym_namespace] = ACTIONS(2130),
    [anon_sym_using] = ACTIONS(2130),
    [anon_sym_static_assert] = ACTIONS(2130),
    [anon_sym_concept] = ACTIONS(2130),
    [anon_sym_co_return] = ACTIONS(2130),
    [anon_sym_co_yield] = ACTIONS(2130),
    [anon_sym_R_DQUOTE] = ACTIONS(2132),
    [anon_sym_LR_DQUOTE] = ACTIONS(2132),
    [anon_sym_uR_DQUOTE] = ACTIONS(2132),
    [anon_sym_UR_DQUOTE] = ACTIONS(2132),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2132),
    [anon_sym_co_await] = ACTIONS(2130),
    [anon_sym_new] = ACTIONS(2130),
    [anon_sym_requires] = ACTIONS(2130),
    [sym_this] = ACTIONS(2130),
    [anon_sym_discard] = ACTIONS(2130),
    [anon_sym_precise] = ACTIONS(2130),
    [anon_sym_shared] = ACTIONS(2130),
    [anon_sym_groupshared] = ACTIONS(2130),
    [anon_sym_uniform] = ACTIONS(2130),
    [anon_sym_row_major] = ACTIONS(2130),
    [anon_sym_column_major] = ACTIONS(2130),
    [anon_sym_globallycoherent] = ACTIONS(2130),
    [anon_sym_centroid] = ACTIONS(2130),
    [anon_sym_noperspective] = ACTIONS(2130),
    [anon_sym_nointerpolation] = ACTIONS(2130),
    [anon_sym_sample] = ACTIONS(2130),
    [anon_sym_linear] = ACTIONS(2130),
    [anon_sym_snorm] = ACTIONS(2130),
    [anon_sym_unorm] = ACTIONS(2130),
    [anon_sym_point] = ACTIONS(2130),
    [anon_sym_line] = ACTIONS(2130),
    [anon_sym_triangleadj] = ACTIONS(2130),
    [anon_sym_lineadj] = ACTIONS(2130),
    [anon_sym_triangle] = ACTIONS(2130),
    [anon_sym_cbuffer] = ACTIONS(2130),
  },
  [394] = {
    [ts_builtin_sym_end] = ACTIONS(2258),
    [sym_identifier] = ACTIONS(2256),
    [aux_sym_preproc_include_token1] = ACTIONS(2256),
    [aux_sym_preproc_def_token1] = ACTIONS(2256),
    [aux_sym_preproc_if_token1] = ACTIONS(2256),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2256),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2256),
    [sym_preproc_directive] = ACTIONS(2256),
    [anon_sym_LPAREN2] = ACTIONS(2258),
    [anon_sym_BANG] = ACTIONS(2258),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_DASH] = ACTIONS(2256),
    [anon_sym_PLUS] = ACTIONS(2256),
    [anon_sym_STAR] = ACTIONS(2258),
    [anon_sym_AMP_AMP] = ACTIONS(2258),
    [anon_sym_AMP] = ACTIONS(2256),
    [anon_sym_SEMI] = ACTIONS(2258),
    [anon_sym___extension__] = ACTIONS(2256),
    [anon_sym_typedef] = ACTIONS(2256),
    [anon_sym_in] = ACTIONS(2256),
    [anon_sym_out] = ACTIONS(2256),
    [anon_sym_inout] = ACTIONS(2256),
    [anon_sym_extern] = ACTIONS(2256),
    [anon_sym___attribute__] = ACTIONS(2256),
    [anon_sym_COLON_COLON] = ACTIONS(2258),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2258),
    [anon_sym___declspec] = ACTIONS(2256),
    [anon_sym___based] = ACTIONS(2256),
    [anon_sym___cdecl] = ACTIONS(2256),
    [anon_sym___clrcall] = ACTIONS(2256),
    [anon_sym___stdcall] = ACTIONS(2256),
    [anon_sym___fastcall] = ACTIONS(2256),
    [anon_sym___thiscall] = ACTIONS(2256),
    [anon_sym___vectorcall] = ACTIONS(2256),
    [anon_sym_LBRACE] = ACTIONS(2258),
    [anon_sym_signed] = ACTIONS(2256),
    [anon_sym_unsigned] = ACTIONS(2256),
    [anon_sym_long] = ACTIONS(2256),
    [anon_sym_short] = ACTIONS(2256),
    [anon_sym_LBRACK] = ACTIONS(2256),
    [anon_sym_static] = ACTIONS(2256),
    [anon_sym_register] = ACTIONS(2256),
    [anon_sym_inline] = ACTIONS(2256),
    [anon_sym___inline] = ACTIONS(2256),
    [anon_sym___inline__] = ACTIONS(2256),
    [anon_sym___forceinline] = ACTIONS(2256),
    [anon_sym_thread_local] = ACTIONS(2256),
    [anon_sym___thread] = ACTIONS(2256),
    [anon_sym_const] = ACTIONS(2256),
    [anon_sym_constexpr] = ACTIONS(2256),
    [anon_sym_volatile] = ACTIONS(2256),
    [anon_sym_restrict] = ACTIONS(2256),
    [anon_sym___restrict__] = ACTIONS(2256),
    [anon_sym__Atomic] = ACTIONS(2256),
    [anon_sym__Noreturn] = ACTIONS(2256),
    [anon_sym_noreturn] = ACTIONS(2256),
    [anon_sym_mutable] = ACTIONS(2256),
    [anon_sym_constinit] = ACTIONS(2256),
    [anon_sym_consteval] = ACTIONS(2256),
    [anon_sym_alignas] = ACTIONS(2256),
    [anon_sym__Alignas] = ACTIONS(2256),
    [sym_primitive_type] = ACTIONS(2256),
    [anon_sym_enum] = ACTIONS(2256),
    [anon_sym_class] = ACTIONS(2256),
    [anon_sym_struct] = ACTIONS(2256),
    [anon_sym_union] = ACTIONS(2256),
    [anon_sym_if] = ACTIONS(2256),
    [anon_sym_else] = ACTIONS(2256),
    [anon_sym_switch] = ACTIONS(2256),
    [anon_sym_case] = ACTIONS(2256),
    [anon_sym_default] = ACTIONS(2256),
    [anon_sym_while] = ACTIONS(2256),
    [anon_sym_do] = ACTIONS(2256),
    [anon_sym_for] = ACTIONS(2256),
    [anon_sym_return] = ACTIONS(2256),
    [anon_sym_break] = ACTIONS(2256),
    [anon_sym_continue] = ACTIONS(2256),
    [anon_sym_goto] = ACTIONS(2256),
    [anon_sym___try] = ACTIONS(2256),
    [anon_sym___leave] = ACTIONS(2256),
    [anon_sym_not] = ACTIONS(2256),
    [anon_sym_compl] = ACTIONS(2256),
    [anon_sym_DASH_DASH] = ACTIONS(2258),
    [anon_sym_PLUS_PLUS] = ACTIONS(2258),
    [anon_sym_sizeof] = ACTIONS(2256),
    [anon_sym___alignof__] = ACTIONS(2256),
    [anon_sym___alignof] = ACTIONS(2256),
    [anon_sym__alignof] = ACTIONS(2256),
    [anon_sym_alignof] = ACTIONS(2256),
    [anon_sym__Alignof] = ACTIONS(2256),
    [anon_sym_offsetof] = ACTIONS(2256),
    [anon_sym__Generic] = ACTIONS(2256),
    [anon_sym_asm] = ACTIONS(2256),
    [anon_sym___asm__] = ACTIONS(2256),
    [sym_number_literal] = ACTIONS(2258),
    [anon_sym_L_SQUOTE] = ACTIONS(2258),
    [anon_sym_u_SQUOTE] = ACTIONS(2258),
    [anon_sym_U_SQUOTE] = ACTIONS(2258),
    [anon_sym_u8_SQUOTE] = ACTIONS(2258),
    [anon_sym_SQUOTE] = ACTIONS(2258),
    [anon_sym_L_DQUOTE] = ACTIONS(2258),
    [anon_sym_u_DQUOTE] = ACTIONS(2258),
    [anon_sym_U_DQUOTE] = ACTIONS(2258),
    [anon_sym_u8_DQUOTE] = ACTIONS(2258),
    [anon_sym_DQUOTE] = ACTIONS(2258),
    [sym_true] = ACTIONS(2256),
    [sym_false] = ACTIONS(2256),
    [anon_sym_NULL] = ACTIONS(2256),
    [anon_sym_nullptr] = ACTIONS(2256),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2256),
    [anon_sym_decltype] = ACTIONS(2256),
    [sym_virtual] = ACTIONS(2256),
    [anon_sym_explicit] = ACTIONS(2256),
    [anon_sym_typename] = ACTIONS(2256),
    [anon_sym_template] = ACTIONS(2256),
    [anon_sym_operator] = ACTIONS(2256),
    [anon_sym_try] = ACTIONS(2256),
    [anon_sym_delete] = ACTIONS(2256),
    [anon_sym_throw] = ACTIONS(2256),
    [anon_sym_namespace] = ACTIONS(2256),
    [anon_sym_using] = ACTIONS(2256),
    [anon_sym_static_assert] = ACTIONS(2256),
    [anon_sym_concept] = ACTIONS(2256),
    [anon_sym_co_return] = ACTIONS(2256),
    [anon_sym_co_yield] = ACTIONS(2256),
    [anon_sym_R_DQUOTE] = ACTIONS(2258),
    [anon_sym_LR_DQUOTE] = ACTIONS(2258),
    [anon_sym_uR_DQUOTE] = ACTIONS(2258),
    [anon_sym_UR_DQUOTE] = ACTIONS(2258),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2258),
    [anon_sym_co_await] = ACTIONS(2256),
    [anon_sym_new] = ACTIONS(2256),
    [anon_sym_requires] = ACTIONS(2256),
    [sym_this] = ACTIONS(2256),
    [anon_sym_discard] = ACTIONS(2256),
    [anon_sym_precise] = ACTIONS(2256),
    [anon_sym_shared] = ACTIONS(2256),
    [anon_sym_groupshared] = ACTIONS(2256),
    [anon_sym_uniform] = ACTIONS(2256),
    [anon_sym_row_major] = ACTIONS(2256),
    [anon_sym_column_major] = ACTIONS(2256),
    [anon_sym_globallycoherent] = ACTIONS(2256),
    [anon_sym_centroid] = ACTIONS(2256),
    [anon_sym_noperspective] = ACTIONS(2256),
    [anon_sym_nointerpolation] = ACTIONS(2256),
    [anon_sym_sample] = ACTIONS(2256),
    [anon_sym_linear] = ACTIONS(2256),
    [anon_sym_snorm] = ACTIONS(2256),
    [anon_sym_unorm] = ACTIONS(2256),
    [anon_sym_point] = ACTIONS(2256),
    [anon_sym_line] = ACTIONS(2256),
    [anon_sym_triangleadj] = ACTIONS(2256),
    [anon_sym_lineadj] = ACTIONS(2256),
    [anon_sym_triangle] = ACTIONS(2256),
    [anon_sym_cbuffer] = ACTIONS(2256),
  },
  [395] = {
    [ts_builtin_sym_end] = ACTIONS(2254),
    [sym_identifier] = ACTIONS(2252),
    [aux_sym_preproc_include_token1] = ACTIONS(2252),
    [aux_sym_preproc_def_token1] = ACTIONS(2252),
    [aux_sym_preproc_if_token1] = ACTIONS(2252),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2252),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2252),
    [sym_preproc_directive] = ACTIONS(2252),
    [anon_sym_LPAREN2] = ACTIONS(2254),
    [anon_sym_BANG] = ACTIONS(2254),
    [anon_sym_TILDE] = ACTIONS(2254),
    [anon_sym_DASH] = ACTIONS(2252),
    [anon_sym_PLUS] = ACTIONS(2252),
    [anon_sym_STAR] = ACTIONS(2254),
    [anon_sym_AMP_AMP] = ACTIONS(2254),
    [anon_sym_AMP] = ACTIONS(2252),
    [anon_sym_SEMI] = ACTIONS(2254),
    [anon_sym___extension__] = ACTIONS(2252),
    [anon_sym_typedef] = ACTIONS(2252),
    [anon_sym_in] = ACTIONS(2252),
    [anon_sym_out] = ACTIONS(2252),
    [anon_sym_inout] = ACTIONS(2252),
    [anon_sym_extern] = ACTIONS(2252),
    [anon_sym___attribute__] = ACTIONS(2252),
    [anon_sym_COLON_COLON] = ACTIONS(2254),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2254),
    [anon_sym___declspec] = ACTIONS(2252),
    [anon_sym___based] = ACTIONS(2252),
    [anon_sym___cdecl] = ACTIONS(2252),
    [anon_sym___clrcall] = ACTIONS(2252),
    [anon_sym___stdcall] = ACTIONS(2252),
    [anon_sym___fastcall] = ACTIONS(2252),
    [anon_sym___thiscall] = ACTIONS(2252),
    [anon_sym___vectorcall] = ACTIONS(2252),
    [anon_sym_LBRACE] = ACTIONS(2254),
    [anon_sym_signed] = ACTIONS(2252),
    [anon_sym_unsigned] = ACTIONS(2252),
    [anon_sym_long] = ACTIONS(2252),
    [anon_sym_short] = ACTIONS(2252),
    [anon_sym_LBRACK] = ACTIONS(2252),
    [anon_sym_static] = ACTIONS(2252),
    [anon_sym_register] = ACTIONS(2252),
    [anon_sym_inline] = ACTIONS(2252),
    [anon_sym___inline] = ACTIONS(2252),
    [anon_sym___inline__] = ACTIONS(2252),
    [anon_sym___forceinline] = ACTIONS(2252),
    [anon_sym_thread_local] = ACTIONS(2252),
    [anon_sym___thread] = ACTIONS(2252),
    [anon_sym_const] = ACTIONS(2252),
    [anon_sym_constexpr] = ACTIONS(2252),
    [anon_sym_volatile] = ACTIONS(2252),
    [anon_sym_restrict] = ACTIONS(2252),
    [anon_sym___restrict__] = ACTIONS(2252),
    [anon_sym__Atomic] = ACTIONS(2252),
    [anon_sym__Noreturn] = ACTIONS(2252),
    [anon_sym_noreturn] = ACTIONS(2252),
    [anon_sym_mutable] = ACTIONS(2252),
    [anon_sym_constinit] = ACTIONS(2252),
    [anon_sym_consteval] = ACTIONS(2252),
    [anon_sym_alignas] = ACTIONS(2252),
    [anon_sym__Alignas] = ACTIONS(2252),
    [sym_primitive_type] = ACTIONS(2252),
    [anon_sym_enum] = ACTIONS(2252),
    [anon_sym_class] = ACTIONS(2252),
    [anon_sym_struct] = ACTIONS(2252),
    [anon_sym_union] = ACTIONS(2252),
    [anon_sym_if] = ACTIONS(2252),
    [anon_sym_else] = ACTIONS(2252),
    [anon_sym_switch] = ACTIONS(2252),
    [anon_sym_case] = ACTIONS(2252),
    [anon_sym_default] = ACTIONS(2252),
    [anon_sym_while] = ACTIONS(2252),
    [anon_sym_do] = ACTIONS(2252),
    [anon_sym_for] = ACTIONS(2252),
    [anon_sym_return] = ACTIONS(2252),
    [anon_sym_break] = ACTIONS(2252),
    [anon_sym_continue] = ACTIONS(2252),
    [anon_sym_goto] = ACTIONS(2252),
    [anon_sym___try] = ACTIONS(2252),
    [anon_sym___leave] = ACTIONS(2252),
    [anon_sym_not] = ACTIONS(2252),
    [anon_sym_compl] = ACTIONS(2252),
    [anon_sym_DASH_DASH] = ACTIONS(2254),
    [anon_sym_PLUS_PLUS] = ACTIONS(2254),
    [anon_sym_sizeof] = ACTIONS(2252),
    [anon_sym___alignof__] = ACTIONS(2252),
    [anon_sym___alignof] = ACTIONS(2252),
    [anon_sym__alignof] = ACTIONS(2252),
    [anon_sym_alignof] = ACTIONS(2252),
    [anon_sym__Alignof] = ACTIONS(2252),
    [anon_sym_offsetof] = ACTIONS(2252),
    [anon_sym__Generic] = ACTIONS(2252),
    [anon_sym_asm] = ACTIONS(2252),
    [anon_sym___asm__] = ACTIONS(2252),
    [sym_number_literal] = ACTIONS(2254),
    [anon_sym_L_SQUOTE] = ACTIONS(2254),
    [anon_sym_u_SQUOTE] = ACTIONS(2254),
    [anon_sym_U_SQUOTE] = ACTIONS(2254),
    [anon_sym_u8_SQUOTE] = ACTIONS(2254),
    [anon_sym_SQUOTE] = ACTIONS(2254),
    [anon_sym_L_DQUOTE] = ACTIONS(2254),
    [anon_sym_u_DQUOTE] = ACTIONS(2254),
    [anon_sym_U_DQUOTE] = ACTIONS(2254),
    [anon_sym_u8_DQUOTE] = ACTIONS(2254),
    [anon_sym_DQUOTE] = ACTIONS(2254),
    [sym_true] = ACTIONS(2252),
    [sym_false] = ACTIONS(2252),
    [anon_sym_NULL] = ACTIONS(2252),
    [anon_sym_nullptr] = ACTIONS(2252),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2252),
    [anon_sym_decltype] = ACTIONS(2252),
    [sym_virtual] = ACTIONS(2252),
    [anon_sym_explicit] = ACTIONS(2252),
    [anon_sym_typename] = ACTIONS(2252),
    [anon_sym_template] = ACTIONS(2252),
    [anon_sym_operator] = ACTIONS(2252),
    [anon_sym_try] = ACTIONS(2252),
    [anon_sym_delete] = ACTIONS(2252),
    [anon_sym_throw] = ACTIONS(2252),
    [anon_sym_namespace] = ACTIONS(2252),
    [anon_sym_using] = ACTIONS(2252),
    [anon_sym_static_assert] = ACTIONS(2252),
    [anon_sym_concept] = ACTIONS(2252),
    [anon_sym_co_return] = ACTIONS(2252),
    [anon_sym_co_yield] = ACTIONS(2252),
    [anon_sym_R_DQUOTE] = ACTIONS(2254),
    [anon_sym_LR_DQUOTE] = ACTIONS(2254),
    [anon_sym_uR_DQUOTE] = ACTIONS(2254),
    [anon_sym_UR_DQUOTE] = ACTIONS(2254),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2254),
    [anon_sym_co_await] = ACTIONS(2252),
    [anon_sym_new] = ACTIONS(2252),
    [anon_sym_requires] = ACTIONS(2252),
    [sym_this] = ACTIONS(2252),
    [anon_sym_discard] = ACTIONS(2252),
    [anon_sym_precise] = ACTIONS(2252),
    [anon_sym_shared] = ACTIONS(2252),
    [anon_sym_groupshared] = ACTIONS(2252),
    [anon_sym_uniform] = ACTIONS(2252),
    [anon_sym_row_major] = ACTIONS(2252),
    [anon_sym_column_major] = ACTIONS(2252),
    [anon_sym_globallycoherent] = ACTIONS(2252),
    [anon_sym_centroid] = ACTIONS(2252),
    [anon_sym_noperspective] = ACTIONS(2252),
    [anon_sym_nointerpolation] = ACTIONS(2252),
    [anon_sym_sample] = ACTIONS(2252),
    [anon_sym_linear] = ACTIONS(2252),
    [anon_sym_snorm] = ACTIONS(2252),
    [anon_sym_unorm] = ACTIONS(2252),
    [anon_sym_point] = ACTIONS(2252),
    [anon_sym_line] = ACTIONS(2252),
    [anon_sym_triangleadj] = ACTIONS(2252),
    [anon_sym_lineadj] = ACTIONS(2252),
    [anon_sym_triangle] = ACTIONS(2252),
    [anon_sym_cbuffer] = ACTIONS(2252),
  },
  [396] = {
    [ts_builtin_sym_end] = ACTIONS(2222),
    [sym_identifier] = ACTIONS(2220),
    [aux_sym_preproc_include_token1] = ACTIONS(2220),
    [aux_sym_preproc_def_token1] = ACTIONS(2220),
    [aux_sym_preproc_if_token1] = ACTIONS(2220),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2220),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2220),
    [sym_preproc_directive] = ACTIONS(2220),
    [anon_sym_LPAREN2] = ACTIONS(2222),
    [anon_sym_BANG] = ACTIONS(2222),
    [anon_sym_TILDE] = ACTIONS(2222),
    [anon_sym_DASH] = ACTIONS(2220),
    [anon_sym_PLUS] = ACTIONS(2220),
    [anon_sym_STAR] = ACTIONS(2222),
    [anon_sym_AMP_AMP] = ACTIONS(2222),
    [anon_sym_AMP] = ACTIONS(2220),
    [anon_sym_SEMI] = ACTIONS(2222),
    [anon_sym___extension__] = ACTIONS(2220),
    [anon_sym_typedef] = ACTIONS(2220),
    [anon_sym_in] = ACTIONS(2220),
    [anon_sym_out] = ACTIONS(2220),
    [anon_sym_inout] = ACTIONS(2220),
    [anon_sym_extern] = ACTIONS(2220),
    [anon_sym___attribute__] = ACTIONS(2220),
    [anon_sym_COLON_COLON] = ACTIONS(2222),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2222),
    [anon_sym___declspec] = ACTIONS(2220),
    [anon_sym___based] = ACTIONS(2220),
    [anon_sym___cdecl] = ACTIONS(2220),
    [anon_sym___clrcall] = ACTIONS(2220),
    [anon_sym___stdcall] = ACTIONS(2220),
    [anon_sym___fastcall] = ACTIONS(2220),
    [anon_sym___thiscall] = ACTIONS(2220),
    [anon_sym___vectorcall] = ACTIONS(2220),
    [anon_sym_LBRACE] = ACTIONS(2222),
    [anon_sym_signed] = ACTIONS(2220),
    [anon_sym_unsigned] = ACTIONS(2220),
    [anon_sym_long] = ACTIONS(2220),
    [anon_sym_short] = ACTIONS(2220),
    [anon_sym_LBRACK] = ACTIONS(2220),
    [anon_sym_static] = ACTIONS(2220),
    [anon_sym_register] = ACTIONS(2220),
    [anon_sym_inline] = ACTIONS(2220),
    [anon_sym___inline] = ACTIONS(2220),
    [anon_sym___inline__] = ACTIONS(2220),
    [anon_sym___forceinline] = ACTIONS(2220),
    [anon_sym_thread_local] = ACTIONS(2220),
    [anon_sym___thread] = ACTIONS(2220),
    [anon_sym_const] = ACTIONS(2220),
    [anon_sym_constexpr] = ACTIONS(2220),
    [anon_sym_volatile] = ACTIONS(2220),
    [anon_sym_restrict] = ACTIONS(2220),
    [anon_sym___restrict__] = ACTIONS(2220),
    [anon_sym__Atomic] = ACTIONS(2220),
    [anon_sym__Noreturn] = ACTIONS(2220),
    [anon_sym_noreturn] = ACTIONS(2220),
    [anon_sym_mutable] = ACTIONS(2220),
    [anon_sym_constinit] = ACTIONS(2220),
    [anon_sym_consteval] = ACTIONS(2220),
    [anon_sym_alignas] = ACTIONS(2220),
    [anon_sym__Alignas] = ACTIONS(2220),
    [sym_primitive_type] = ACTIONS(2220),
    [anon_sym_enum] = ACTIONS(2220),
    [anon_sym_class] = ACTIONS(2220),
    [anon_sym_struct] = ACTIONS(2220),
    [anon_sym_union] = ACTIONS(2220),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_else] = ACTIONS(2220),
    [anon_sym_switch] = ACTIONS(2220),
    [anon_sym_case] = ACTIONS(2220),
    [anon_sym_default] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2220),
    [anon_sym_do] = ACTIONS(2220),
    [anon_sym_for] = ACTIONS(2220),
    [anon_sym_return] = ACTIONS(2220),
    [anon_sym_break] = ACTIONS(2220),
    [anon_sym_continue] = ACTIONS(2220),
    [anon_sym_goto] = ACTIONS(2220),
    [anon_sym___try] = ACTIONS(2220),
    [anon_sym___leave] = ACTIONS(2220),
    [anon_sym_not] = ACTIONS(2220),
    [anon_sym_compl] = ACTIONS(2220),
    [anon_sym_DASH_DASH] = ACTIONS(2222),
    [anon_sym_PLUS_PLUS] = ACTIONS(2222),
    [anon_sym_sizeof] = ACTIONS(2220),
    [anon_sym___alignof__] = ACTIONS(2220),
    [anon_sym___alignof] = ACTIONS(2220),
    [anon_sym__alignof] = ACTIONS(2220),
    [anon_sym_alignof] = ACTIONS(2220),
    [anon_sym__Alignof] = ACTIONS(2220),
    [anon_sym_offsetof] = ACTIONS(2220),
    [anon_sym__Generic] = ACTIONS(2220),
    [anon_sym_asm] = ACTIONS(2220),
    [anon_sym___asm__] = ACTIONS(2220),
    [sym_number_literal] = ACTIONS(2222),
    [anon_sym_L_SQUOTE] = ACTIONS(2222),
    [anon_sym_u_SQUOTE] = ACTIONS(2222),
    [anon_sym_U_SQUOTE] = ACTIONS(2222),
    [anon_sym_u8_SQUOTE] = ACTIONS(2222),
    [anon_sym_SQUOTE] = ACTIONS(2222),
    [anon_sym_L_DQUOTE] = ACTIONS(2222),
    [anon_sym_u_DQUOTE] = ACTIONS(2222),
    [anon_sym_U_DQUOTE] = ACTIONS(2222),
    [anon_sym_u8_DQUOTE] = ACTIONS(2222),
    [anon_sym_DQUOTE] = ACTIONS(2222),
    [sym_true] = ACTIONS(2220),
    [sym_false] = ACTIONS(2220),
    [anon_sym_NULL] = ACTIONS(2220),
    [anon_sym_nullptr] = ACTIONS(2220),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2220),
    [anon_sym_decltype] = ACTIONS(2220),
    [sym_virtual] = ACTIONS(2220),
    [anon_sym_explicit] = ACTIONS(2220),
    [anon_sym_typename] = ACTIONS(2220),
    [anon_sym_template] = ACTIONS(2220),
    [anon_sym_operator] = ACTIONS(2220),
    [anon_sym_try] = ACTIONS(2220),
    [anon_sym_delete] = ACTIONS(2220),
    [anon_sym_throw] = ACTIONS(2220),
    [anon_sym_namespace] = ACTIONS(2220),
    [anon_sym_using] = ACTIONS(2220),
    [anon_sym_static_assert] = ACTIONS(2220),
    [anon_sym_concept] = ACTIONS(2220),
    [anon_sym_co_return] = ACTIONS(2220),
    [anon_sym_co_yield] = ACTIONS(2220),
    [anon_sym_R_DQUOTE] = ACTIONS(2222),
    [anon_sym_LR_DQUOTE] = ACTIONS(2222),
    [anon_sym_uR_DQUOTE] = ACTIONS(2222),
    [anon_sym_UR_DQUOTE] = ACTIONS(2222),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2222),
    [anon_sym_co_await] = ACTIONS(2220),
    [anon_sym_new] = ACTIONS(2220),
    [anon_sym_requires] = ACTIONS(2220),
    [sym_this] = ACTIONS(2220),
    [anon_sym_discard] = ACTIONS(2220),
    [anon_sym_precise] = ACTIONS(2220),
    [anon_sym_shared] = ACTIONS(2220),
    [anon_sym_groupshared] = ACTIONS(2220),
    [anon_sym_uniform] = ACTIONS(2220),
    [anon_sym_row_major] = ACTIONS(2220),
    [anon_sym_column_major] = ACTIONS(2220),
    [anon_sym_globallycoherent] = ACTIONS(2220),
    [anon_sym_centroid] = ACTIONS(2220),
    [anon_sym_noperspective] = ACTIONS(2220),
    [anon_sym_nointerpolation] = ACTIONS(2220),
    [anon_sym_sample] = ACTIONS(2220),
    [anon_sym_linear] = ACTIONS(2220),
    [anon_sym_snorm] = ACTIONS(2220),
    [anon_sym_unorm] = ACTIONS(2220),
    [anon_sym_point] = ACTIONS(2220),
    [anon_sym_line] = ACTIONS(2220),
    [anon_sym_triangleadj] = ACTIONS(2220),
    [anon_sym_lineadj] = ACTIONS(2220),
    [anon_sym_triangle] = ACTIONS(2220),
    [anon_sym_cbuffer] = ACTIONS(2220),
  },
  [397] = {
    [ts_builtin_sym_end] = ACTIONS(2192),
    [sym_identifier] = ACTIONS(2190),
    [aux_sym_preproc_include_token1] = ACTIONS(2190),
    [aux_sym_preproc_def_token1] = ACTIONS(2190),
    [aux_sym_preproc_if_token1] = ACTIONS(2190),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2190),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2190),
    [sym_preproc_directive] = ACTIONS(2190),
    [anon_sym_LPAREN2] = ACTIONS(2192),
    [anon_sym_BANG] = ACTIONS(2192),
    [anon_sym_TILDE] = ACTIONS(2192),
    [anon_sym_DASH] = ACTIONS(2190),
    [anon_sym_PLUS] = ACTIONS(2190),
    [anon_sym_STAR] = ACTIONS(2192),
    [anon_sym_AMP_AMP] = ACTIONS(2192),
    [anon_sym_AMP] = ACTIONS(2190),
    [anon_sym_SEMI] = ACTIONS(2192),
    [anon_sym___extension__] = ACTIONS(2190),
    [anon_sym_typedef] = ACTIONS(2190),
    [anon_sym_in] = ACTIONS(2190),
    [anon_sym_out] = ACTIONS(2190),
    [anon_sym_inout] = ACTIONS(2190),
    [anon_sym_extern] = ACTIONS(2190),
    [anon_sym___attribute__] = ACTIONS(2190),
    [anon_sym_COLON_COLON] = ACTIONS(2192),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2192),
    [anon_sym___declspec] = ACTIONS(2190),
    [anon_sym___based] = ACTIONS(2190),
    [anon_sym___cdecl] = ACTIONS(2190),
    [anon_sym___clrcall] = ACTIONS(2190),
    [anon_sym___stdcall] = ACTIONS(2190),
    [anon_sym___fastcall] = ACTIONS(2190),
    [anon_sym___thiscall] = ACTIONS(2190),
    [anon_sym___vectorcall] = ACTIONS(2190),
    [anon_sym_LBRACE] = ACTIONS(2192),
    [anon_sym_signed] = ACTIONS(2190),
    [anon_sym_unsigned] = ACTIONS(2190),
    [anon_sym_long] = ACTIONS(2190),
    [anon_sym_short] = ACTIONS(2190),
    [anon_sym_LBRACK] = ACTIONS(2190),
    [anon_sym_static] = ACTIONS(2190),
    [anon_sym_register] = ACTIONS(2190),
    [anon_sym_inline] = ACTIONS(2190),
    [anon_sym___inline] = ACTIONS(2190),
    [anon_sym___inline__] = ACTIONS(2190),
    [anon_sym___forceinline] = ACTIONS(2190),
    [anon_sym_thread_local] = ACTIONS(2190),
    [anon_sym___thread] = ACTIONS(2190),
    [anon_sym_const] = ACTIONS(2190),
    [anon_sym_constexpr] = ACTIONS(2190),
    [anon_sym_volatile] = ACTIONS(2190),
    [anon_sym_restrict] = ACTIONS(2190),
    [anon_sym___restrict__] = ACTIONS(2190),
    [anon_sym__Atomic] = ACTIONS(2190),
    [anon_sym__Noreturn] = ACTIONS(2190),
    [anon_sym_noreturn] = ACTIONS(2190),
    [anon_sym_mutable] = ACTIONS(2190),
    [anon_sym_constinit] = ACTIONS(2190),
    [anon_sym_consteval] = ACTIONS(2190),
    [anon_sym_alignas] = ACTIONS(2190),
    [anon_sym__Alignas] = ACTIONS(2190),
    [sym_primitive_type] = ACTIONS(2190),
    [anon_sym_enum] = ACTIONS(2190),
    [anon_sym_class] = ACTIONS(2190),
    [anon_sym_struct] = ACTIONS(2190),
    [anon_sym_union] = ACTIONS(2190),
    [anon_sym_if] = ACTIONS(2190),
    [anon_sym_else] = ACTIONS(2190),
    [anon_sym_switch] = ACTIONS(2190),
    [anon_sym_case] = ACTIONS(2190),
    [anon_sym_default] = ACTIONS(2190),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_do] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2190),
    [anon_sym_return] = ACTIONS(2190),
    [anon_sym_break] = ACTIONS(2190),
    [anon_sym_continue] = ACTIONS(2190),
    [anon_sym_goto] = ACTIONS(2190),
    [anon_sym___try] = ACTIONS(2190),
    [anon_sym___leave] = ACTIONS(2190),
    [anon_sym_not] = ACTIONS(2190),
    [anon_sym_compl] = ACTIONS(2190),
    [anon_sym_DASH_DASH] = ACTIONS(2192),
    [anon_sym_PLUS_PLUS] = ACTIONS(2192),
    [anon_sym_sizeof] = ACTIONS(2190),
    [anon_sym___alignof__] = ACTIONS(2190),
    [anon_sym___alignof] = ACTIONS(2190),
    [anon_sym__alignof] = ACTIONS(2190),
    [anon_sym_alignof] = ACTIONS(2190),
    [anon_sym__Alignof] = ACTIONS(2190),
    [anon_sym_offsetof] = ACTIONS(2190),
    [anon_sym__Generic] = ACTIONS(2190),
    [anon_sym_asm] = ACTIONS(2190),
    [anon_sym___asm__] = ACTIONS(2190),
    [sym_number_literal] = ACTIONS(2192),
    [anon_sym_L_SQUOTE] = ACTIONS(2192),
    [anon_sym_u_SQUOTE] = ACTIONS(2192),
    [anon_sym_U_SQUOTE] = ACTIONS(2192),
    [anon_sym_u8_SQUOTE] = ACTIONS(2192),
    [anon_sym_SQUOTE] = ACTIONS(2192),
    [anon_sym_L_DQUOTE] = ACTIONS(2192),
    [anon_sym_u_DQUOTE] = ACTIONS(2192),
    [anon_sym_U_DQUOTE] = ACTIONS(2192),
    [anon_sym_u8_DQUOTE] = ACTIONS(2192),
    [anon_sym_DQUOTE] = ACTIONS(2192),
    [sym_true] = ACTIONS(2190),
    [sym_false] = ACTIONS(2190),
    [anon_sym_NULL] = ACTIONS(2190),
    [anon_sym_nullptr] = ACTIONS(2190),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2190),
    [anon_sym_decltype] = ACTIONS(2190),
    [sym_virtual] = ACTIONS(2190),
    [anon_sym_explicit] = ACTIONS(2190),
    [anon_sym_typename] = ACTIONS(2190),
    [anon_sym_template] = ACTIONS(2190),
    [anon_sym_operator] = ACTIONS(2190),
    [anon_sym_try] = ACTIONS(2190),
    [anon_sym_delete] = ACTIONS(2190),
    [anon_sym_throw] = ACTIONS(2190),
    [anon_sym_namespace] = ACTIONS(2190),
    [anon_sym_using] = ACTIONS(2190),
    [anon_sym_static_assert] = ACTIONS(2190),
    [anon_sym_concept] = ACTIONS(2190),
    [anon_sym_co_return] = ACTIONS(2190),
    [anon_sym_co_yield] = ACTIONS(2190),
    [anon_sym_R_DQUOTE] = ACTIONS(2192),
    [anon_sym_LR_DQUOTE] = ACTIONS(2192),
    [anon_sym_uR_DQUOTE] = ACTIONS(2192),
    [anon_sym_UR_DQUOTE] = ACTIONS(2192),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2192),
    [anon_sym_co_await] = ACTIONS(2190),
    [anon_sym_new] = ACTIONS(2190),
    [anon_sym_requires] = ACTIONS(2190),
    [sym_this] = ACTIONS(2190),
    [anon_sym_discard] = ACTIONS(2190),
    [anon_sym_precise] = ACTIONS(2190),
    [anon_sym_shared] = ACTIONS(2190),
    [anon_sym_groupshared] = ACTIONS(2190),
    [anon_sym_uniform] = ACTIONS(2190),
    [anon_sym_row_major] = ACTIONS(2190),
    [anon_sym_column_major] = ACTIONS(2190),
    [anon_sym_globallycoherent] = ACTIONS(2190),
    [anon_sym_centroid] = ACTIONS(2190),
    [anon_sym_noperspective] = ACTIONS(2190),
    [anon_sym_nointerpolation] = ACTIONS(2190),
    [anon_sym_sample] = ACTIONS(2190),
    [anon_sym_linear] = ACTIONS(2190),
    [anon_sym_snorm] = ACTIONS(2190),
    [anon_sym_unorm] = ACTIONS(2190),
    [anon_sym_point] = ACTIONS(2190),
    [anon_sym_line] = ACTIONS(2190),
    [anon_sym_triangleadj] = ACTIONS(2190),
    [anon_sym_lineadj] = ACTIONS(2190),
    [anon_sym_triangle] = ACTIONS(2190),
    [anon_sym_cbuffer] = ACTIONS(2190),
  },
  [398] = {
    [ts_builtin_sym_end] = ACTIONS(2188),
    [sym_identifier] = ACTIONS(2186),
    [aux_sym_preproc_include_token1] = ACTIONS(2186),
    [aux_sym_preproc_def_token1] = ACTIONS(2186),
    [aux_sym_preproc_if_token1] = ACTIONS(2186),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2186),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2186),
    [sym_preproc_directive] = ACTIONS(2186),
    [anon_sym_LPAREN2] = ACTIONS(2188),
    [anon_sym_BANG] = ACTIONS(2188),
    [anon_sym_TILDE] = ACTIONS(2188),
    [anon_sym_DASH] = ACTIONS(2186),
    [anon_sym_PLUS] = ACTIONS(2186),
    [anon_sym_STAR] = ACTIONS(2188),
    [anon_sym_AMP_AMP] = ACTIONS(2188),
    [anon_sym_AMP] = ACTIONS(2186),
    [anon_sym_SEMI] = ACTIONS(2188),
    [anon_sym___extension__] = ACTIONS(2186),
    [anon_sym_typedef] = ACTIONS(2186),
    [anon_sym_in] = ACTIONS(2186),
    [anon_sym_out] = ACTIONS(2186),
    [anon_sym_inout] = ACTIONS(2186),
    [anon_sym_extern] = ACTIONS(2186),
    [anon_sym___attribute__] = ACTIONS(2186),
    [anon_sym_COLON_COLON] = ACTIONS(2188),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2188),
    [anon_sym___declspec] = ACTIONS(2186),
    [anon_sym___based] = ACTIONS(2186),
    [anon_sym___cdecl] = ACTIONS(2186),
    [anon_sym___clrcall] = ACTIONS(2186),
    [anon_sym___stdcall] = ACTIONS(2186),
    [anon_sym___fastcall] = ACTIONS(2186),
    [anon_sym___thiscall] = ACTIONS(2186),
    [anon_sym___vectorcall] = ACTIONS(2186),
    [anon_sym_LBRACE] = ACTIONS(2188),
    [anon_sym_signed] = ACTIONS(2186),
    [anon_sym_unsigned] = ACTIONS(2186),
    [anon_sym_long] = ACTIONS(2186),
    [anon_sym_short] = ACTIONS(2186),
    [anon_sym_LBRACK] = ACTIONS(2186),
    [anon_sym_static] = ACTIONS(2186),
    [anon_sym_register] = ACTIONS(2186),
    [anon_sym_inline] = ACTIONS(2186),
    [anon_sym___inline] = ACTIONS(2186),
    [anon_sym___inline__] = ACTIONS(2186),
    [anon_sym___forceinline] = ACTIONS(2186),
    [anon_sym_thread_local] = ACTIONS(2186),
    [anon_sym___thread] = ACTIONS(2186),
    [anon_sym_const] = ACTIONS(2186),
    [anon_sym_constexpr] = ACTIONS(2186),
    [anon_sym_volatile] = ACTIONS(2186),
    [anon_sym_restrict] = ACTIONS(2186),
    [anon_sym___restrict__] = ACTIONS(2186),
    [anon_sym__Atomic] = ACTIONS(2186),
    [anon_sym__Noreturn] = ACTIONS(2186),
    [anon_sym_noreturn] = ACTIONS(2186),
    [anon_sym_mutable] = ACTIONS(2186),
    [anon_sym_constinit] = ACTIONS(2186),
    [anon_sym_consteval] = ACTIONS(2186),
    [anon_sym_alignas] = ACTIONS(2186),
    [anon_sym__Alignas] = ACTIONS(2186),
    [sym_primitive_type] = ACTIONS(2186),
    [anon_sym_enum] = ACTIONS(2186),
    [anon_sym_class] = ACTIONS(2186),
    [anon_sym_struct] = ACTIONS(2186),
    [anon_sym_union] = ACTIONS(2186),
    [anon_sym_if] = ACTIONS(2186),
    [anon_sym_else] = ACTIONS(2186),
    [anon_sym_switch] = ACTIONS(2186),
    [anon_sym_case] = ACTIONS(2186),
    [anon_sym_default] = ACTIONS(2186),
    [anon_sym_while] = ACTIONS(2186),
    [anon_sym_do] = ACTIONS(2186),
    [anon_sym_for] = ACTIONS(2186),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_break] = ACTIONS(2186),
    [anon_sym_continue] = ACTIONS(2186),
    [anon_sym_goto] = ACTIONS(2186),
    [anon_sym___try] = ACTIONS(2186),
    [anon_sym___leave] = ACTIONS(2186),
    [anon_sym_not] = ACTIONS(2186),
    [anon_sym_compl] = ACTIONS(2186),
    [anon_sym_DASH_DASH] = ACTIONS(2188),
    [anon_sym_PLUS_PLUS] = ACTIONS(2188),
    [anon_sym_sizeof] = ACTIONS(2186),
    [anon_sym___alignof__] = ACTIONS(2186),
    [anon_sym___alignof] = ACTIONS(2186),
    [anon_sym__alignof] = ACTIONS(2186),
    [anon_sym_alignof] = ACTIONS(2186),
    [anon_sym__Alignof] = ACTIONS(2186),
    [anon_sym_offsetof] = ACTIONS(2186),
    [anon_sym__Generic] = ACTIONS(2186),
    [anon_sym_asm] = ACTIONS(2186),
    [anon_sym___asm__] = ACTIONS(2186),
    [sym_number_literal] = ACTIONS(2188),
    [anon_sym_L_SQUOTE] = ACTIONS(2188),
    [anon_sym_u_SQUOTE] = ACTIONS(2188),
    [anon_sym_U_SQUOTE] = ACTIONS(2188),
    [anon_sym_u8_SQUOTE] = ACTIONS(2188),
    [anon_sym_SQUOTE] = ACTIONS(2188),
    [anon_sym_L_DQUOTE] = ACTIONS(2188),
    [anon_sym_u_DQUOTE] = ACTIONS(2188),
    [anon_sym_U_DQUOTE] = ACTIONS(2188),
    [anon_sym_u8_DQUOTE] = ACTIONS(2188),
    [anon_sym_DQUOTE] = ACTIONS(2188),
    [sym_true] = ACTIONS(2186),
    [sym_false] = ACTIONS(2186),
    [anon_sym_NULL] = ACTIONS(2186),
    [anon_sym_nullptr] = ACTIONS(2186),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2186),
    [anon_sym_decltype] = ACTIONS(2186),
    [sym_virtual] = ACTIONS(2186),
    [anon_sym_explicit] = ACTIONS(2186),
    [anon_sym_typename] = ACTIONS(2186),
    [anon_sym_template] = ACTIONS(2186),
    [anon_sym_operator] = ACTIONS(2186),
    [anon_sym_try] = ACTIONS(2186),
    [anon_sym_delete] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2186),
    [anon_sym_namespace] = ACTIONS(2186),
    [anon_sym_using] = ACTIONS(2186),
    [anon_sym_static_assert] = ACTIONS(2186),
    [anon_sym_concept] = ACTIONS(2186),
    [anon_sym_co_return] = ACTIONS(2186),
    [anon_sym_co_yield] = ACTIONS(2186),
    [anon_sym_R_DQUOTE] = ACTIONS(2188),
    [anon_sym_LR_DQUOTE] = ACTIONS(2188),
    [anon_sym_uR_DQUOTE] = ACTIONS(2188),
    [anon_sym_UR_DQUOTE] = ACTIONS(2188),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2188),
    [anon_sym_co_await] = ACTIONS(2186),
    [anon_sym_new] = ACTIONS(2186),
    [anon_sym_requires] = ACTIONS(2186),
    [sym_this] = ACTIONS(2186),
    [anon_sym_discard] = ACTIONS(2186),
    [anon_sym_precise] = ACTIONS(2186),
    [anon_sym_shared] = ACTIONS(2186),
    [anon_sym_groupshared] = ACTIONS(2186),
    [anon_sym_uniform] = ACTIONS(2186),
    [anon_sym_row_major] = ACTIONS(2186),
    [anon_sym_column_major] = ACTIONS(2186),
    [anon_sym_globallycoherent] = ACTIONS(2186),
    [anon_sym_centroid] = ACTIONS(2186),
    [anon_sym_noperspective] = ACTIONS(2186),
    [anon_sym_nointerpolation] = ACTIONS(2186),
    [anon_sym_sample] = ACTIONS(2186),
    [anon_sym_linear] = ACTIONS(2186),
    [anon_sym_snorm] = ACTIONS(2186),
    [anon_sym_unorm] = ACTIONS(2186),
    [anon_sym_point] = ACTIONS(2186),
    [anon_sym_line] = ACTIONS(2186),
    [anon_sym_triangleadj] = ACTIONS(2186),
    [anon_sym_lineadj] = ACTIONS(2186),
    [anon_sym_triangle] = ACTIONS(2186),
    [anon_sym_cbuffer] = ACTIONS(2186),
  },
  [399] = {
    [sym_identifier] = ACTIONS(2174),
    [aux_sym_preproc_include_token1] = ACTIONS(2174),
    [aux_sym_preproc_def_token1] = ACTIONS(2174),
    [aux_sym_preproc_if_token1] = ACTIONS(2174),
    [aux_sym_preproc_if_token2] = ACTIONS(2174),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2174),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2174),
    [sym_preproc_directive] = ACTIONS(2174),
    [anon_sym_LPAREN2] = ACTIONS(2176),
    [anon_sym_BANG] = ACTIONS(2176),
    [anon_sym_TILDE] = ACTIONS(2176),
    [anon_sym_DASH] = ACTIONS(2174),
    [anon_sym_PLUS] = ACTIONS(2174),
    [anon_sym_STAR] = ACTIONS(2176),
    [anon_sym_AMP_AMP] = ACTIONS(2176),
    [anon_sym_AMP] = ACTIONS(2174),
    [anon_sym_SEMI] = ACTIONS(2176),
    [anon_sym___extension__] = ACTIONS(2174),
    [anon_sym_typedef] = ACTIONS(2174),
    [anon_sym_in] = ACTIONS(2174),
    [anon_sym_out] = ACTIONS(2174),
    [anon_sym_inout] = ACTIONS(2174),
    [anon_sym_extern] = ACTIONS(2174),
    [anon_sym___attribute__] = ACTIONS(2174),
    [anon_sym_COLON_COLON] = ACTIONS(2176),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2176),
    [anon_sym___declspec] = ACTIONS(2174),
    [anon_sym___based] = ACTIONS(2174),
    [anon_sym___cdecl] = ACTIONS(2174),
    [anon_sym___clrcall] = ACTIONS(2174),
    [anon_sym___stdcall] = ACTIONS(2174),
    [anon_sym___fastcall] = ACTIONS(2174),
    [anon_sym___thiscall] = ACTIONS(2174),
    [anon_sym___vectorcall] = ACTIONS(2174),
    [anon_sym_LBRACE] = ACTIONS(2176),
    [anon_sym_signed] = ACTIONS(2174),
    [anon_sym_unsigned] = ACTIONS(2174),
    [anon_sym_long] = ACTIONS(2174),
    [anon_sym_short] = ACTIONS(2174),
    [anon_sym_LBRACK] = ACTIONS(2174),
    [anon_sym_static] = ACTIONS(2174),
    [anon_sym_register] = ACTIONS(2174),
    [anon_sym_inline] = ACTIONS(2174),
    [anon_sym___inline] = ACTIONS(2174),
    [anon_sym___inline__] = ACTIONS(2174),
    [anon_sym___forceinline] = ACTIONS(2174),
    [anon_sym_thread_local] = ACTIONS(2174),
    [anon_sym___thread] = ACTIONS(2174),
    [anon_sym_const] = ACTIONS(2174),
    [anon_sym_constexpr] = ACTIONS(2174),
    [anon_sym_volatile] = ACTIONS(2174),
    [anon_sym_restrict] = ACTIONS(2174),
    [anon_sym___restrict__] = ACTIONS(2174),
    [anon_sym__Atomic] = ACTIONS(2174),
    [anon_sym__Noreturn] = ACTIONS(2174),
    [anon_sym_noreturn] = ACTIONS(2174),
    [anon_sym_mutable] = ACTIONS(2174),
    [anon_sym_constinit] = ACTIONS(2174),
    [anon_sym_consteval] = ACTIONS(2174),
    [anon_sym_alignas] = ACTIONS(2174),
    [anon_sym__Alignas] = ACTIONS(2174),
    [sym_primitive_type] = ACTIONS(2174),
    [anon_sym_enum] = ACTIONS(2174),
    [anon_sym_class] = ACTIONS(2174),
    [anon_sym_struct] = ACTIONS(2174),
    [anon_sym_union] = ACTIONS(2174),
    [anon_sym_if] = ACTIONS(2174),
    [anon_sym_else] = ACTIONS(2174),
    [anon_sym_switch] = ACTIONS(2174),
    [anon_sym_case] = ACTIONS(2174),
    [anon_sym_default] = ACTIONS(2174),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_do] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2174),
    [anon_sym_return] = ACTIONS(2174),
    [anon_sym_break] = ACTIONS(2174),
    [anon_sym_continue] = ACTIONS(2174),
    [anon_sym_goto] = ACTIONS(2174),
    [anon_sym___try] = ACTIONS(2174),
    [anon_sym___leave] = ACTIONS(2174),
    [anon_sym_not] = ACTIONS(2174),
    [anon_sym_compl] = ACTIONS(2174),
    [anon_sym_DASH_DASH] = ACTIONS(2176),
    [anon_sym_PLUS_PLUS] = ACTIONS(2176),
    [anon_sym_sizeof] = ACTIONS(2174),
    [anon_sym___alignof__] = ACTIONS(2174),
    [anon_sym___alignof] = ACTIONS(2174),
    [anon_sym__alignof] = ACTIONS(2174),
    [anon_sym_alignof] = ACTIONS(2174),
    [anon_sym__Alignof] = ACTIONS(2174),
    [anon_sym_offsetof] = ACTIONS(2174),
    [anon_sym__Generic] = ACTIONS(2174),
    [anon_sym_asm] = ACTIONS(2174),
    [anon_sym___asm__] = ACTIONS(2174),
    [sym_number_literal] = ACTIONS(2176),
    [anon_sym_L_SQUOTE] = ACTIONS(2176),
    [anon_sym_u_SQUOTE] = ACTIONS(2176),
    [anon_sym_U_SQUOTE] = ACTIONS(2176),
    [anon_sym_u8_SQUOTE] = ACTIONS(2176),
    [anon_sym_SQUOTE] = ACTIONS(2176),
    [anon_sym_L_DQUOTE] = ACTIONS(2176),
    [anon_sym_u_DQUOTE] = ACTIONS(2176),
    [anon_sym_U_DQUOTE] = ACTIONS(2176),
    [anon_sym_u8_DQUOTE] = ACTIONS(2176),
    [anon_sym_DQUOTE] = ACTIONS(2176),
    [sym_true] = ACTIONS(2174),
    [sym_false] = ACTIONS(2174),
    [anon_sym_NULL] = ACTIONS(2174),
    [anon_sym_nullptr] = ACTIONS(2174),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2174),
    [anon_sym_decltype] = ACTIONS(2174),
    [sym_virtual] = ACTIONS(2174),
    [anon_sym_explicit] = ACTIONS(2174),
    [anon_sym_typename] = ACTIONS(2174),
    [anon_sym_template] = ACTIONS(2174),
    [anon_sym_operator] = ACTIONS(2174),
    [anon_sym_try] = ACTIONS(2174),
    [anon_sym_delete] = ACTIONS(2174),
    [anon_sym_throw] = ACTIONS(2174),
    [anon_sym_namespace] = ACTIONS(2174),
    [anon_sym_using] = ACTIONS(2174),
    [anon_sym_static_assert] = ACTIONS(2174),
    [anon_sym_concept] = ACTIONS(2174),
    [anon_sym_co_return] = ACTIONS(2174),
    [anon_sym_co_yield] = ACTIONS(2174),
    [anon_sym_R_DQUOTE] = ACTIONS(2176),
    [anon_sym_LR_DQUOTE] = ACTIONS(2176),
    [anon_sym_uR_DQUOTE] = ACTIONS(2176),
    [anon_sym_UR_DQUOTE] = ACTIONS(2176),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2176),
    [anon_sym_co_await] = ACTIONS(2174),
    [anon_sym_new] = ACTIONS(2174),
    [anon_sym_requires] = ACTIONS(2174),
    [sym_this] = ACTIONS(2174),
    [anon_sym_discard] = ACTIONS(2174),
    [anon_sym_precise] = ACTIONS(2174),
    [anon_sym_shared] = ACTIONS(2174),
    [anon_sym_groupshared] = ACTIONS(2174),
    [anon_sym_uniform] = ACTIONS(2174),
    [anon_sym_row_major] = ACTIONS(2174),
    [anon_sym_column_major] = ACTIONS(2174),
    [anon_sym_globallycoherent] = ACTIONS(2174),
    [anon_sym_centroid] = ACTIONS(2174),
    [anon_sym_noperspective] = ACTIONS(2174),
    [anon_sym_nointerpolation] = ACTIONS(2174),
    [anon_sym_sample] = ACTIONS(2174),
    [anon_sym_linear] = ACTIONS(2174),
    [anon_sym_snorm] = ACTIONS(2174),
    [anon_sym_unorm] = ACTIONS(2174),
    [anon_sym_point] = ACTIONS(2174),
    [anon_sym_line] = ACTIONS(2174),
    [anon_sym_triangleadj] = ACTIONS(2174),
    [anon_sym_lineadj] = ACTIONS(2174),
    [anon_sym_triangle] = ACTIONS(2174),
    [anon_sym_cbuffer] = ACTIONS(2174),
  },
  [400] = {
    [ts_builtin_sym_end] = ACTIONS(2266),
    [sym_identifier] = ACTIONS(2264),
    [aux_sym_preproc_include_token1] = ACTIONS(2264),
    [aux_sym_preproc_def_token1] = ACTIONS(2264),
    [aux_sym_preproc_if_token1] = ACTIONS(2264),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2264),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2264),
    [sym_preproc_directive] = ACTIONS(2264),
    [anon_sym_LPAREN2] = ACTIONS(2266),
    [anon_sym_BANG] = ACTIONS(2266),
    [anon_sym_TILDE] = ACTIONS(2266),
    [anon_sym_DASH] = ACTIONS(2264),
    [anon_sym_PLUS] = ACTIONS(2264),
    [anon_sym_STAR] = ACTIONS(2266),
    [anon_sym_AMP_AMP] = ACTIONS(2266),
    [anon_sym_AMP] = ACTIONS(2264),
    [anon_sym_SEMI] = ACTIONS(2266),
    [anon_sym___extension__] = ACTIONS(2264),
    [anon_sym_typedef] = ACTIONS(2264),
    [anon_sym_in] = ACTIONS(2264),
    [anon_sym_out] = ACTIONS(2264),
    [anon_sym_inout] = ACTIONS(2264),
    [anon_sym_extern] = ACTIONS(2264),
    [anon_sym___attribute__] = ACTIONS(2264),
    [anon_sym_COLON_COLON] = ACTIONS(2266),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2266),
    [anon_sym___declspec] = ACTIONS(2264),
    [anon_sym___based] = ACTIONS(2264),
    [anon_sym___cdecl] = ACTIONS(2264),
    [anon_sym___clrcall] = ACTIONS(2264),
    [anon_sym___stdcall] = ACTIONS(2264),
    [anon_sym___fastcall] = ACTIONS(2264),
    [anon_sym___thiscall] = ACTIONS(2264),
    [anon_sym___vectorcall] = ACTIONS(2264),
    [anon_sym_LBRACE] = ACTIONS(2266),
    [anon_sym_signed] = ACTIONS(2264),
    [anon_sym_unsigned] = ACTIONS(2264),
    [anon_sym_long] = ACTIONS(2264),
    [anon_sym_short] = ACTIONS(2264),
    [anon_sym_LBRACK] = ACTIONS(2264),
    [anon_sym_static] = ACTIONS(2264),
    [anon_sym_register] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(2264),
    [anon_sym___inline] = ACTIONS(2264),
    [anon_sym___inline__] = ACTIONS(2264),
    [anon_sym___forceinline] = ACTIONS(2264),
    [anon_sym_thread_local] = ACTIONS(2264),
    [anon_sym___thread] = ACTIONS(2264),
    [anon_sym_const] = ACTIONS(2264),
    [anon_sym_constexpr] = ACTIONS(2264),
    [anon_sym_volatile] = ACTIONS(2264),
    [anon_sym_restrict] = ACTIONS(2264),
    [anon_sym___restrict__] = ACTIONS(2264),
    [anon_sym__Atomic] = ACTIONS(2264),
    [anon_sym__Noreturn] = ACTIONS(2264),
    [anon_sym_noreturn] = ACTIONS(2264),
    [anon_sym_mutable] = ACTIONS(2264),
    [anon_sym_constinit] = ACTIONS(2264),
    [anon_sym_consteval] = ACTIONS(2264),
    [anon_sym_alignas] = ACTIONS(2264),
    [anon_sym__Alignas] = ACTIONS(2264),
    [sym_primitive_type] = ACTIONS(2264),
    [anon_sym_enum] = ACTIONS(2264),
    [anon_sym_class] = ACTIONS(2264),
    [anon_sym_struct] = ACTIONS(2264),
    [anon_sym_union] = ACTIONS(2264),
    [anon_sym_if] = ACTIONS(2264),
    [anon_sym_else] = ACTIONS(2264),
    [anon_sym_switch] = ACTIONS(2264),
    [anon_sym_case] = ACTIONS(2264),
    [anon_sym_default] = ACTIONS(2264),
    [anon_sym_while] = ACTIONS(2264),
    [anon_sym_do] = ACTIONS(2264),
    [anon_sym_for] = ACTIONS(2264),
    [anon_sym_return] = ACTIONS(2264),
    [anon_sym_break] = ACTIONS(2264),
    [anon_sym_continue] = ACTIONS(2264),
    [anon_sym_goto] = ACTIONS(2264),
    [anon_sym___try] = ACTIONS(2264),
    [anon_sym___leave] = ACTIONS(2264),
    [anon_sym_not] = ACTIONS(2264),
    [anon_sym_compl] = ACTIONS(2264),
    [anon_sym_DASH_DASH] = ACTIONS(2266),
    [anon_sym_PLUS_PLUS] = ACTIONS(2266),
    [anon_sym_sizeof] = ACTIONS(2264),
    [anon_sym___alignof__] = ACTIONS(2264),
    [anon_sym___alignof] = ACTIONS(2264),
    [anon_sym__alignof] = ACTIONS(2264),
    [anon_sym_alignof] = ACTIONS(2264),
    [anon_sym__Alignof] = ACTIONS(2264),
    [anon_sym_offsetof] = ACTIONS(2264),
    [anon_sym__Generic] = ACTIONS(2264),
    [anon_sym_asm] = ACTIONS(2264),
    [anon_sym___asm__] = ACTIONS(2264),
    [sym_number_literal] = ACTIONS(2266),
    [anon_sym_L_SQUOTE] = ACTIONS(2266),
    [anon_sym_u_SQUOTE] = ACTIONS(2266),
    [anon_sym_U_SQUOTE] = ACTIONS(2266),
    [anon_sym_u8_SQUOTE] = ACTIONS(2266),
    [anon_sym_SQUOTE] = ACTIONS(2266),
    [anon_sym_L_DQUOTE] = ACTIONS(2266),
    [anon_sym_u_DQUOTE] = ACTIONS(2266),
    [anon_sym_U_DQUOTE] = ACTIONS(2266),
    [anon_sym_u8_DQUOTE] = ACTIONS(2266),
    [anon_sym_DQUOTE] = ACTIONS(2266),
    [sym_true] = ACTIONS(2264),
    [sym_false] = ACTIONS(2264),
    [anon_sym_NULL] = ACTIONS(2264),
    [anon_sym_nullptr] = ACTIONS(2264),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2264),
    [anon_sym_decltype] = ACTIONS(2264),
    [sym_virtual] = ACTIONS(2264),
    [anon_sym_explicit] = ACTIONS(2264),
    [anon_sym_typename] = ACTIONS(2264),
    [anon_sym_template] = ACTIONS(2264),
    [anon_sym_operator] = ACTIONS(2264),
    [anon_sym_try] = ACTIONS(2264),
    [anon_sym_delete] = ACTIONS(2264),
    [anon_sym_throw] = ACTIONS(2264),
    [anon_sym_namespace] = ACTIONS(2264),
    [anon_sym_using] = ACTIONS(2264),
    [anon_sym_static_assert] = ACTIONS(2264),
    [anon_sym_concept] = ACTIONS(2264),
    [anon_sym_co_return] = ACTIONS(2264),
    [anon_sym_co_yield] = ACTIONS(2264),
    [anon_sym_R_DQUOTE] = ACTIONS(2266),
    [anon_sym_LR_DQUOTE] = ACTIONS(2266),
    [anon_sym_uR_DQUOTE] = ACTIONS(2266),
    [anon_sym_UR_DQUOTE] = ACTIONS(2266),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2266),
    [anon_sym_co_await] = ACTIONS(2264),
    [anon_sym_new] = ACTIONS(2264),
    [anon_sym_requires] = ACTIONS(2264),
    [sym_this] = ACTIONS(2264),
    [anon_sym_discard] = ACTIONS(2264),
    [anon_sym_precise] = ACTIONS(2264),
    [anon_sym_shared] = ACTIONS(2264),
    [anon_sym_groupshared] = ACTIONS(2264),
    [anon_sym_uniform] = ACTIONS(2264),
    [anon_sym_row_major] = ACTIONS(2264),
    [anon_sym_column_major] = ACTIONS(2264),
    [anon_sym_globallycoherent] = ACTIONS(2264),
    [anon_sym_centroid] = ACTIONS(2264),
    [anon_sym_noperspective] = ACTIONS(2264),
    [anon_sym_nointerpolation] = ACTIONS(2264),
    [anon_sym_sample] = ACTIONS(2264),
    [anon_sym_linear] = ACTIONS(2264),
    [anon_sym_snorm] = ACTIONS(2264),
    [anon_sym_unorm] = ACTIONS(2264),
    [anon_sym_point] = ACTIONS(2264),
    [anon_sym_line] = ACTIONS(2264),
    [anon_sym_triangleadj] = ACTIONS(2264),
    [anon_sym_lineadj] = ACTIONS(2264),
    [anon_sym_triangle] = ACTIONS(2264),
    [anon_sym_cbuffer] = ACTIONS(2264),
  },
  [401] = {
    [ts_builtin_sym_end] = ACTIONS(2120),
    [sym_identifier] = ACTIONS(2118),
    [aux_sym_preproc_include_token1] = ACTIONS(2118),
    [aux_sym_preproc_def_token1] = ACTIONS(2118),
    [aux_sym_preproc_if_token1] = ACTIONS(2118),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2118),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2118),
    [sym_preproc_directive] = ACTIONS(2118),
    [anon_sym_LPAREN2] = ACTIONS(2120),
    [anon_sym_BANG] = ACTIONS(2120),
    [anon_sym_TILDE] = ACTIONS(2120),
    [anon_sym_DASH] = ACTIONS(2118),
    [anon_sym_PLUS] = ACTIONS(2118),
    [anon_sym_STAR] = ACTIONS(2120),
    [anon_sym_AMP_AMP] = ACTIONS(2120),
    [anon_sym_AMP] = ACTIONS(2118),
    [anon_sym_SEMI] = ACTIONS(2120),
    [anon_sym___extension__] = ACTIONS(2118),
    [anon_sym_typedef] = ACTIONS(2118),
    [anon_sym_in] = ACTIONS(2118),
    [anon_sym_out] = ACTIONS(2118),
    [anon_sym_inout] = ACTIONS(2118),
    [anon_sym_extern] = ACTIONS(2118),
    [anon_sym___attribute__] = ACTIONS(2118),
    [anon_sym_COLON_COLON] = ACTIONS(2120),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2120),
    [anon_sym___declspec] = ACTIONS(2118),
    [anon_sym___based] = ACTIONS(2118),
    [anon_sym___cdecl] = ACTIONS(2118),
    [anon_sym___clrcall] = ACTIONS(2118),
    [anon_sym___stdcall] = ACTIONS(2118),
    [anon_sym___fastcall] = ACTIONS(2118),
    [anon_sym___thiscall] = ACTIONS(2118),
    [anon_sym___vectorcall] = ACTIONS(2118),
    [anon_sym_LBRACE] = ACTIONS(2120),
    [anon_sym_signed] = ACTIONS(2118),
    [anon_sym_unsigned] = ACTIONS(2118),
    [anon_sym_long] = ACTIONS(2118),
    [anon_sym_short] = ACTIONS(2118),
    [anon_sym_LBRACK] = ACTIONS(2118),
    [anon_sym_static] = ACTIONS(2118),
    [anon_sym_register] = ACTIONS(2118),
    [anon_sym_inline] = ACTIONS(2118),
    [anon_sym___inline] = ACTIONS(2118),
    [anon_sym___inline__] = ACTIONS(2118),
    [anon_sym___forceinline] = ACTIONS(2118),
    [anon_sym_thread_local] = ACTIONS(2118),
    [anon_sym___thread] = ACTIONS(2118),
    [anon_sym_const] = ACTIONS(2118),
    [anon_sym_constexpr] = ACTIONS(2118),
    [anon_sym_volatile] = ACTIONS(2118),
    [anon_sym_restrict] = ACTIONS(2118),
    [anon_sym___restrict__] = ACTIONS(2118),
    [anon_sym__Atomic] = ACTIONS(2118),
    [anon_sym__Noreturn] = ACTIONS(2118),
    [anon_sym_noreturn] = ACTIONS(2118),
    [anon_sym_mutable] = ACTIONS(2118),
    [anon_sym_constinit] = ACTIONS(2118),
    [anon_sym_consteval] = ACTIONS(2118),
    [anon_sym_alignas] = ACTIONS(2118),
    [anon_sym__Alignas] = ACTIONS(2118),
    [sym_primitive_type] = ACTIONS(2118),
    [anon_sym_enum] = ACTIONS(2118),
    [anon_sym_class] = ACTIONS(2118),
    [anon_sym_struct] = ACTIONS(2118),
    [anon_sym_union] = ACTIONS(2118),
    [anon_sym_if] = ACTIONS(2118),
    [anon_sym_else] = ACTIONS(2118),
    [anon_sym_switch] = ACTIONS(2118),
    [anon_sym_case] = ACTIONS(2118),
    [anon_sym_default] = ACTIONS(2118),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_do] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2118),
    [anon_sym_return] = ACTIONS(2118),
    [anon_sym_break] = ACTIONS(2118),
    [anon_sym_continue] = ACTIONS(2118),
    [anon_sym_goto] = ACTIONS(2118),
    [anon_sym___try] = ACTIONS(2118),
    [anon_sym___leave] = ACTIONS(2118),
    [anon_sym_not] = ACTIONS(2118),
    [anon_sym_compl] = ACTIONS(2118),
    [anon_sym_DASH_DASH] = ACTIONS(2120),
    [anon_sym_PLUS_PLUS] = ACTIONS(2120),
    [anon_sym_sizeof] = ACTIONS(2118),
    [anon_sym___alignof__] = ACTIONS(2118),
    [anon_sym___alignof] = ACTIONS(2118),
    [anon_sym__alignof] = ACTIONS(2118),
    [anon_sym_alignof] = ACTIONS(2118),
    [anon_sym__Alignof] = ACTIONS(2118),
    [anon_sym_offsetof] = ACTIONS(2118),
    [anon_sym__Generic] = ACTIONS(2118),
    [anon_sym_asm] = ACTIONS(2118),
    [anon_sym___asm__] = ACTIONS(2118),
    [sym_number_literal] = ACTIONS(2120),
    [anon_sym_L_SQUOTE] = ACTIONS(2120),
    [anon_sym_u_SQUOTE] = ACTIONS(2120),
    [anon_sym_U_SQUOTE] = ACTIONS(2120),
    [anon_sym_u8_SQUOTE] = ACTIONS(2120),
    [anon_sym_SQUOTE] = ACTIONS(2120),
    [anon_sym_L_DQUOTE] = ACTIONS(2120),
    [anon_sym_u_DQUOTE] = ACTIONS(2120),
    [anon_sym_U_DQUOTE] = ACTIONS(2120),
    [anon_sym_u8_DQUOTE] = ACTIONS(2120),
    [anon_sym_DQUOTE] = ACTIONS(2120),
    [sym_true] = ACTIONS(2118),
    [sym_false] = ACTIONS(2118),
    [anon_sym_NULL] = ACTIONS(2118),
    [anon_sym_nullptr] = ACTIONS(2118),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2118),
    [anon_sym_decltype] = ACTIONS(2118),
    [sym_virtual] = ACTIONS(2118),
    [anon_sym_explicit] = ACTIONS(2118),
    [anon_sym_typename] = ACTIONS(2118),
    [anon_sym_template] = ACTIONS(2118),
    [anon_sym_operator] = ACTIONS(2118),
    [anon_sym_try] = ACTIONS(2118),
    [anon_sym_delete] = ACTIONS(2118),
    [anon_sym_throw] = ACTIONS(2118),
    [anon_sym_namespace] = ACTIONS(2118),
    [anon_sym_using] = ACTIONS(2118),
    [anon_sym_static_assert] = ACTIONS(2118),
    [anon_sym_concept] = ACTIONS(2118),
    [anon_sym_co_return] = ACTIONS(2118),
    [anon_sym_co_yield] = ACTIONS(2118),
    [anon_sym_R_DQUOTE] = ACTIONS(2120),
    [anon_sym_LR_DQUOTE] = ACTIONS(2120),
    [anon_sym_uR_DQUOTE] = ACTIONS(2120),
    [anon_sym_UR_DQUOTE] = ACTIONS(2120),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2120),
    [anon_sym_co_await] = ACTIONS(2118),
    [anon_sym_new] = ACTIONS(2118),
    [anon_sym_requires] = ACTIONS(2118),
    [sym_this] = ACTIONS(2118),
    [anon_sym_discard] = ACTIONS(2118),
    [anon_sym_precise] = ACTIONS(2118),
    [anon_sym_shared] = ACTIONS(2118),
    [anon_sym_groupshared] = ACTIONS(2118),
    [anon_sym_uniform] = ACTIONS(2118),
    [anon_sym_row_major] = ACTIONS(2118),
    [anon_sym_column_major] = ACTIONS(2118),
    [anon_sym_globallycoherent] = ACTIONS(2118),
    [anon_sym_centroid] = ACTIONS(2118),
    [anon_sym_noperspective] = ACTIONS(2118),
    [anon_sym_nointerpolation] = ACTIONS(2118),
    [anon_sym_sample] = ACTIONS(2118),
    [anon_sym_linear] = ACTIONS(2118),
    [anon_sym_snorm] = ACTIONS(2118),
    [anon_sym_unorm] = ACTIONS(2118),
    [anon_sym_point] = ACTIONS(2118),
    [anon_sym_line] = ACTIONS(2118),
    [anon_sym_triangleadj] = ACTIONS(2118),
    [anon_sym_lineadj] = ACTIONS(2118),
    [anon_sym_triangle] = ACTIONS(2118),
    [anon_sym_cbuffer] = ACTIONS(2118),
  },
  [402] = {
    [sym_identifier] = ACTIONS(2122),
    [aux_sym_preproc_include_token1] = ACTIONS(2122),
    [aux_sym_preproc_def_token1] = ACTIONS(2122),
    [aux_sym_preproc_if_token1] = ACTIONS(2122),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2122),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2122),
    [sym_preproc_directive] = ACTIONS(2122),
    [anon_sym_LPAREN2] = ACTIONS(2124),
    [anon_sym_BANG] = ACTIONS(2124),
    [anon_sym_TILDE] = ACTIONS(2124),
    [anon_sym_DASH] = ACTIONS(2122),
    [anon_sym_PLUS] = ACTIONS(2122),
    [anon_sym_STAR] = ACTIONS(2124),
    [anon_sym_AMP_AMP] = ACTIONS(2124),
    [anon_sym_AMP] = ACTIONS(2122),
    [anon_sym_SEMI] = ACTIONS(2124),
    [anon_sym___extension__] = ACTIONS(2122),
    [anon_sym_typedef] = ACTIONS(2122),
    [anon_sym_in] = ACTIONS(2122),
    [anon_sym_out] = ACTIONS(2122),
    [anon_sym_inout] = ACTIONS(2122),
    [anon_sym_extern] = ACTIONS(2122),
    [anon_sym___attribute__] = ACTIONS(2122),
    [anon_sym_COLON_COLON] = ACTIONS(2124),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2124),
    [anon_sym___declspec] = ACTIONS(2122),
    [anon_sym___based] = ACTIONS(2122),
    [anon_sym___cdecl] = ACTIONS(2122),
    [anon_sym___clrcall] = ACTIONS(2122),
    [anon_sym___stdcall] = ACTIONS(2122),
    [anon_sym___fastcall] = ACTIONS(2122),
    [anon_sym___thiscall] = ACTIONS(2122),
    [anon_sym___vectorcall] = ACTIONS(2122),
    [anon_sym_LBRACE] = ACTIONS(2124),
    [anon_sym_RBRACE] = ACTIONS(2124),
    [anon_sym_signed] = ACTIONS(2122),
    [anon_sym_unsigned] = ACTIONS(2122),
    [anon_sym_long] = ACTIONS(2122),
    [anon_sym_short] = ACTIONS(2122),
    [anon_sym_LBRACK] = ACTIONS(2122),
    [anon_sym_static] = ACTIONS(2122),
    [anon_sym_register] = ACTIONS(2122),
    [anon_sym_inline] = ACTIONS(2122),
    [anon_sym___inline] = ACTIONS(2122),
    [anon_sym___inline__] = ACTIONS(2122),
    [anon_sym___forceinline] = ACTIONS(2122),
    [anon_sym_thread_local] = ACTIONS(2122),
    [anon_sym___thread] = ACTIONS(2122),
    [anon_sym_const] = ACTIONS(2122),
    [anon_sym_constexpr] = ACTIONS(2122),
    [anon_sym_volatile] = ACTIONS(2122),
    [anon_sym_restrict] = ACTIONS(2122),
    [anon_sym___restrict__] = ACTIONS(2122),
    [anon_sym__Atomic] = ACTIONS(2122),
    [anon_sym__Noreturn] = ACTIONS(2122),
    [anon_sym_noreturn] = ACTIONS(2122),
    [anon_sym_mutable] = ACTIONS(2122),
    [anon_sym_constinit] = ACTIONS(2122),
    [anon_sym_consteval] = ACTIONS(2122),
    [anon_sym_alignas] = ACTIONS(2122),
    [anon_sym__Alignas] = ACTIONS(2122),
    [sym_primitive_type] = ACTIONS(2122),
    [anon_sym_enum] = ACTIONS(2122),
    [anon_sym_class] = ACTIONS(2122),
    [anon_sym_struct] = ACTIONS(2122),
    [anon_sym_union] = ACTIONS(2122),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_else] = ACTIONS(2122),
    [anon_sym_switch] = ACTIONS(2122),
    [anon_sym_case] = ACTIONS(2122),
    [anon_sym_default] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2122),
    [anon_sym_do] = ACTIONS(2122),
    [anon_sym_for] = ACTIONS(2122),
    [anon_sym_return] = ACTIONS(2122),
    [anon_sym_break] = ACTIONS(2122),
    [anon_sym_continue] = ACTIONS(2122),
    [anon_sym_goto] = ACTIONS(2122),
    [anon_sym___try] = ACTIONS(2122),
    [anon_sym___leave] = ACTIONS(2122),
    [anon_sym_not] = ACTIONS(2122),
    [anon_sym_compl] = ACTIONS(2122),
    [anon_sym_DASH_DASH] = ACTIONS(2124),
    [anon_sym_PLUS_PLUS] = ACTIONS(2124),
    [anon_sym_sizeof] = ACTIONS(2122),
    [anon_sym___alignof__] = ACTIONS(2122),
    [anon_sym___alignof] = ACTIONS(2122),
    [anon_sym__alignof] = ACTIONS(2122),
    [anon_sym_alignof] = ACTIONS(2122),
    [anon_sym__Alignof] = ACTIONS(2122),
    [anon_sym_offsetof] = ACTIONS(2122),
    [anon_sym__Generic] = ACTIONS(2122),
    [anon_sym_asm] = ACTIONS(2122),
    [anon_sym___asm__] = ACTIONS(2122),
    [sym_number_literal] = ACTIONS(2124),
    [anon_sym_L_SQUOTE] = ACTIONS(2124),
    [anon_sym_u_SQUOTE] = ACTIONS(2124),
    [anon_sym_U_SQUOTE] = ACTIONS(2124),
    [anon_sym_u8_SQUOTE] = ACTIONS(2124),
    [anon_sym_SQUOTE] = ACTIONS(2124),
    [anon_sym_L_DQUOTE] = ACTIONS(2124),
    [anon_sym_u_DQUOTE] = ACTIONS(2124),
    [anon_sym_U_DQUOTE] = ACTIONS(2124),
    [anon_sym_u8_DQUOTE] = ACTIONS(2124),
    [anon_sym_DQUOTE] = ACTIONS(2124),
    [sym_true] = ACTIONS(2122),
    [sym_false] = ACTIONS(2122),
    [anon_sym_NULL] = ACTIONS(2122),
    [anon_sym_nullptr] = ACTIONS(2122),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2122),
    [anon_sym_decltype] = ACTIONS(2122),
    [sym_virtual] = ACTIONS(2122),
    [anon_sym_explicit] = ACTIONS(2122),
    [anon_sym_typename] = ACTIONS(2122),
    [anon_sym_template] = ACTIONS(2122),
    [anon_sym_operator] = ACTIONS(2122),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_delete] = ACTIONS(2122),
    [anon_sym_throw] = ACTIONS(2122),
    [anon_sym_namespace] = ACTIONS(2122),
    [anon_sym_using] = ACTIONS(2122),
    [anon_sym_static_assert] = ACTIONS(2122),
    [anon_sym_concept] = ACTIONS(2122),
    [anon_sym_co_return] = ACTIONS(2122),
    [anon_sym_co_yield] = ACTIONS(2122),
    [anon_sym_R_DQUOTE] = ACTIONS(2124),
    [anon_sym_LR_DQUOTE] = ACTIONS(2124),
    [anon_sym_uR_DQUOTE] = ACTIONS(2124),
    [anon_sym_UR_DQUOTE] = ACTIONS(2124),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2124),
    [anon_sym_co_await] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(2122),
    [anon_sym_requires] = ACTIONS(2122),
    [sym_this] = ACTIONS(2122),
    [anon_sym_discard] = ACTIONS(2122),
    [anon_sym_precise] = ACTIONS(2122),
    [anon_sym_shared] = ACTIONS(2122),
    [anon_sym_groupshared] = ACTIONS(2122),
    [anon_sym_uniform] = ACTIONS(2122),
    [anon_sym_row_major] = ACTIONS(2122),
    [anon_sym_column_major] = ACTIONS(2122),
    [anon_sym_globallycoherent] = ACTIONS(2122),
    [anon_sym_centroid] = ACTIONS(2122),
    [anon_sym_noperspective] = ACTIONS(2122),
    [anon_sym_nointerpolation] = ACTIONS(2122),
    [anon_sym_sample] = ACTIONS(2122),
    [anon_sym_linear] = ACTIONS(2122),
    [anon_sym_snorm] = ACTIONS(2122),
    [anon_sym_unorm] = ACTIONS(2122),
    [anon_sym_point] = ACTIONS(2122),
    [anon_sym_line] = ACTIONS(2122),
    [anon_sym_triangleadj] = ACTIONS(2122),
    [anon_sym_lineadj] = ACTIONS(2122),
    [anon_sym_triangle] = ACTIONS(2122),
    [anon_sym_cbuffer] = ACTIONS(2122),
  },
  [403] = {
    [sym_identifier] = ACTIONS(2126),
    [aux_sym_preproc_include_token1] = ACTIONS(2126),
    [aux_sym_preproc_def_token1] = ACTIONS(2126),
    [aux_sym_preproc_if_token1] = ACTIONS(2126),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2126),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2126),
    [sym_preproc_directive] = ACTIONS(2126),
    [anon_sym_LPAREN2] = ACTIONS(2128),
    [anon_sym_BANG] = ACTIONS(2128),
    [anon_sym_TILDE] = ACTIONS(2128),
    [anon_sym_DASH] = ACTIONS(2126),
    [anon_sym_PLUS] = ACTIONS(2126),
    [anon_sym_STAR] = ACTIONS(2128),
    [anon_sym_AMP_AMP] = ACTIONS(2128),
    [anon_sym_AMP] = ACTIONS(2126),
    [anon_sym_SEMI] = ACTIONS(2128),
    [anon_sym___extension__] = ACTIONS(2126),
    [anon_sym_typedef] = ACTIONS(2126),
    [anon_sym_in] = ACTIONS(2126),
    [anon_sym_out] = ACTIONS(2126),
    [anon_sym_inout] = ACTIONS(2126),
    [anon_sym_extern] = ACTIONS(2126),
    [anon_sym___attribute__] = ACTIONS(2126),
    [anon_sym_COLON_COLON] = ACTIONS(2128),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2128),
    [anon_sym___declspec] = ACTIONS(2126),
    [anon_sym___based] = ACTIONS(2126),
    [anon_sym___cdecl] = ACTIONS(2126),
    [anon_sym___clrcall] = ACTIONS(2126),
    [anon_sym___stdcall] = ACTIONS(2126),
    [anon_sym___fastcall] = ACTIONS(2126),
    [anon_sym___thiscall] = ACTIONS(2126),
    [anon_sym___vectorcall] = ACTIONS(2126),
    [anon_sym_LBRACE] = ACTIONS(2128),
    [anon_sym_RBRACE] = ACTIONS(2128),
    [anon_sym_signed] = ACTIONS(2126),
    [anon_sym_unsigned] = ACTIONS(2126),
    [anon_sym_long] = ACTIONS(2126),
    [anon_sym_short] = ACTIONS(2126),
    [anon_sym_LBRACK] = ACTIONS(2126),
    [anon_sym_static] = ACTIONS(2126),
    [anon_sym_register] = ACTIONS(2126),
    [anon_sym_inline] = ACTIONS(2126),
    [anon_sym___inline] = ACTIONS(2126),
    [anon_sym___inline__] = ACTIONS(2126),
    [anon_sym___forceinline] = ACTIONS(2126),
    [anon_sym_thread_local] = ACTIONS(2126),
    [anon_sym___thread] = ACTIONS(2126),
    [anon_sym_const] = ACTIONS(2126),
    [anon_sym_constexpr] = ACTIONS(2126),
    [anon_sym_volatile] = ACTIONS(2126),
    [anon_sym_restrict] = ACTIONS(2126),
    [anon_sym___restrict__] = ACTIONS(2126),
    [anon_sym__Atomic] = ACTIONS(2126),
    [anon_sym__Noreturn] = ACTIONS(2126),
    [anon_sym_noreturn] = ACTIONS(2126),
    [anon_sym_mutable] = ACTIONS(2126),
    [anon_sym_constinit] = ACTIONS(2126),
    [anon_sym_consteval] = ACTIONS(2126),
    [anon_sym_alignas] = ACTIONS(2126),
    [anon_sym__Alignas] = ACTIONS(2126),
    [sym_primitive_type] = ACTIONS(2126),
    [anon_sym_enum] = ACTIONS(2126),
    [anon_sym_class] = ACTIONS(2126),
    [anon_sym_struct] = ACTIONS(2126),
    [anon_sym_union] = ACTIONS(2126),
    [anon_sym_if] = ACTIONS(2126),
    [anon_sym_else] = ACTIONS(2126),
    [anon_sym_switch] = ACTIONS(2126),
    [anon_sym_case] = ACTIONS(2126),
    [anon_sym_default] = ACTIONS(2126),
    [anon_sym_while] = ACTIONS(2126),
    [anon_sym_do] = ACTIONS(2126),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_return] = ACTIONS(2126),
    [anon_sym_break] = ACTIONS(2126),
    [anon_sym_continue] = ACTIONS(2126),
    [anon_sym_goto] = ACTIONS(2126),
    [anon_sym___try] = ACTIONS(2126),
    [anon_sym___leave] = ACTIONS(2126),
    [anon_sym_not] = ACTIONS(2126),
    [anon_sym_compl] = ACTIONS(2126),
    [anon_sym_DASH_DASH] = ACTIONS(2128),
    [anon_sym_PLUS_PLUS] = ACTIONS(2128),
    [anon_sym_sizeof] = ACTIONS(2126),
    [anon_sym___alignof__] = ACTIONS(2126),
    [anon_sym___alignof] = ACTIONS(2126),
    [anon_sym__alignof] = ACTIONS(2126),
    [anon_sym_alignof] = ACTIONS(2126),
    [anon_sym__Alignof] = ACTIONS(2126),
    [anon_sym_offsetof] = ACTIONS(2126),
    [anon_sym__Generic] = ACTIONS(2126),
    [anon_sym_asm] = ACTIONS(2126),
    [anon_sym___asm__] = ACTIONS(2126),
    [sym_number_literal] = ACTIONS(2128),
    [anon_sym_L_SQUOTE] = ACTIONS(2128),
    [anon_sym_u_SQUOTE] = ACTIONS(2128),
    [anon_sym_U_SQUOTE] = ACTIONS(2128),
    [anon_sym_u8_SQUOTE] = ACTIONS(2128),
    [anon_sym_SQUOTE] = ACTIONS(2128),
    [anon_sym_L_DQUOTE] = ACTIONS(2128),
    [anon_sym_u_DQUOTE] = ACTIONS(2128),
    [anon_sym_U_DQUOTE] = ACTIONS(2128),
    [anon_sym_u8_DQUOTE] = ACTIONS(2128),
    [anon_sym_DQUOTE] = ACTIONS(2128),
    [sym_true] = ACTIONS(2126),
    [sym_false] = ACTIONS(2126),
    [anon_sym_NULL] = ACTIONS(2126),
    [anon_sym_nullptr] = ACTIONS(2126),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2126),
    [anon_sym_decltype] = ACTIONS(2126),
    [sym_virtual] = ACTIONS(2126),
    [anon_sym_explicit] = ACTIONS(2126),
    [anon_sym_typename] = ACTIONS(2126),
    [anon_sym_template] = ACTIONS(2126),
    [anon_sym_operator] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2126),
    [anon_sym_delete] = ACTIONS(2126),
    [anon_sym_throw] = ACTIONS(2126),
    [anon_sym_namespace] = ACTIONS(2126),
    [anon_sym_using] = ACTIONS(2126),
    [anon_sym_static_assert] = ACTIONS(2126),
    [anon_sym_concept] = ACTIONS(2126),
    [anon_sym_co_return] = ACTIONS(2126),
    [anon_sym_co_yield] = ACTIONS(2126),
    [anon_sym_R_DQUOTE] = ACTIONS(2128),
    [anon_sym_LR_DQUOTE] = ACTIONS(2128),
    [anon_sym_uR_DQUOTE] = ACTIONS(2128),
    [anon_sym_UR_DQUOTE] = ACTIONS(2128),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2128),
    [anon_sym_co_await] = ACTIONS(2126),
    [anon_sym_new] = ACTIONS(2126),
    [anon_sym_requires] = ACTIONS(2126),
    [sym_this] = ACTIONS(2126),
    [anon_sym_discard] = ACTIONS(2126),
    [anon_sym_precise] = ACTIONS(2126),
    [anon_sym_shared] = ACTIONS(2126),
    [anon_sym_groupshared] = ACTIONS(2126),
    [anon_sym_uniform] = ACTIONS(2126),
    [anon_sym_row_major] = ACTIONS(2126),
    [anon_sym_column_major] = ACTIONS(2126),
    [anon_sym_globallycoherent] = ACTIONS(2126),
    [anon_sym_centroid] = ACTIONS(2126),
    [anon_sym_noperspective] = ACTIONS(2126),
    [anon_sym_nointerpolation] = ACTIONS(2126),
    [anon_sym_sample] = ACTIONS(2126),
    [anon_sym_linear] = ACTIONS(2126),
    [anon_sym_snorm] = ACTIONS(2126),
    [anon_sym_unorm] = ACTIONS(2126),
    [anon_sym_point] = ACTIONS(2126),
    [anon_sym_line] = ACTIONS(2126),
    [anon_sym_triangleadj] = ACTIONS(2126),
    [anon_sym_lineadj] = ACTIONS(2126),
    [anon_sym_triangle] = ACTIONS(2126),
    [anon_sym_cbuffer] = ACTIONS(2126),
  },
  [404] = {
    [sym_identifier] = ACTIONS(2154),
    [aux_sym_preproc_include_token1] = ACTIONS(2154),
    [aux_sym_preproc_def_token1] = ACTIONS(2154),
    [aux_sym_preproc_if_token1] = ACTIONS(2154),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2154),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2154),
    [sym_preproc_directive] = ACTIONS(2154),
    [anon_sym_LPAREN2] = ACTIONS(2156),
    [anon_sym_BANG] = ACTIONS(2156),
    [anon_sym_TILDE] = ACTIONS(2156),
    [anon_sym_DASH] = ACTIONS(2154),
    [anon_sym_PLUS] = ACTIONS(2154),
    [anon_sym_STAR] = ACTIONS(2156),
    [anon_sym_AMP_AMP] = ACTIONS(2156),
    [anon_sym_AMP] = ACTIONS(2154),
    [anon_sym_SEMI] = ACTIONS(2156),
    [anon_sym___extension__] = ACTIONS(2154),
    [anon_sym_typedef] = ACTIONS(2154),
    [anon_sym_in] = ACTIONS(2154),
    [anon_sym_out] = ACTIONS(2154),
    [anon_sym_inout] = ACTIONS(2154),
    [anon_sym_extern] = ACTIONS(2154),
    [anon_sym___attribute__] = ACTIONS(2154),
    [anon_sym_COLON_COLON] = ACTIONS(2156),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2156),
    [anon_sym___declspec] = ACTIONS(2154),
    [anon_sym___based] = ACTIONS(2154),
    [anon_sym___cdecl] = ACTIONS(2154),
    [anon_sym___clrcall] = ACTIONS(2154),
    [anon_sym___stdcall] = ACTIONS(2154),
    [anon_sym___fastcall] = ACTIONS(2154),
    [anon_sym___thiscall] = ACTIONS(2154),
    [anon_sym___vectorcall] = ACTIONS(2154),
    [anon_sym_LBRACE] = ACTIONS(2156),
    [anon_sym_RBRACE] = ACTIONS(2156),
    [anon_sym_signed] = ACTIONS(2154),
    [anon_sym_unsigned] = ACTIONS(2154),
    [anon_sym_long] = ACTIONS(2154),
    [anon_sym_short] = ACTIONS(2154),
    [anon_sym_LBRACK] = ACTIONS(2154),
    [anon_sym_static] = ACTIONS(2154),
    [anon_sym_register] = ACTIONS(2154),
    [anon_sym_inline] = ACTIONS(2154),
    [anon_sym___inline] = ACTIONS(2154),
    [anon_sym___inline__] = ACTIONS(2154),
    [anon_sym___forceinline] = ACTIONS(2154),
    [anon_sym_thread_local] = ACTIONS(2154),
    [anon_sym___thread] = ACTIONS(2154),
    [anon_sym_const] = ACTIONS(2154),
    [anon_sym_constexpr] = ACTIONS(2154),
    [anon_sym_volatile] = ACTIONS(2154),
    [anon_sym_restrict] = ACTIONS(2154),
    [anon_sym___restrict__] = ACTIONS(2154),
    [anon_sym__Atomic] = ACTIONS(2154),
    [anon_sym__Noreturn] = ACTIONS(2154),
    [anon_sym_noreturn] = ACTIONS(2154),
    [anon_sym_mutable] = ACTIONS(2154),
    [anon_sym_constinit] = ACTIONS(2154),
    [anon_sym_consteval] = ACTIONS(2154),
    [anon_sym_alignas] = ACTIONS(2154),
    [anon_sym__Alignas] = ACTIONS(2154),
    [sym_primitive_type] = ACTIONS(2154),
    [anon_sym_enum] = ACTIONS(2154),
    [anon_sym_class] = ACTIONS(2154),
    [anon_sym_struct] = ACTIONS(2154),
    [anon_sym_union] = ACTIONS(2154),
    [anon_sym_if] = ACTIONS(2154),
    [anon_sym_else] = ACTIONS(2154),
    [anon_sym_switch] = ACTIONS(2154),
    [anon_sym_case] = ACTIONS(2154),
    [anon_sym_default] = ACTIONS(2154),
    [anon_sym_while] = ACTIONS(2154),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_for] = ACTIONS(2154),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_break] = ACTIONS(2154),
    [anon_sym_continue] = ACTIONS(2154),
    [anon_sym_goto] = ACTIONS(2154),
    [anon_sym___try] = ACTIONS(2154),
    [anon_sym___leave] = ACTIONS(2154),
    [anon_sym_not] = ACTIONS(2154),
    [anon_sym_compl] = ACTIONS(2154),
    [anon_sym_DASH_DASH] = ACTIONS(2156),
    [anon_sym_PLUS_PLUS] = ACTIONS(2156),
    [anon_sym_sizeof] = ACTIONS(2154),
    [anon_sym___alignof__] = ACTIONS(2154),
    [anon_sym___alignof] = ACTIONS(2154),
    [anon_sym__alignof] = ACTIONS(2154),
    [anon_sym_alignof] = ACTIONS(2154),
    [anon_sym__Alignof] = ACTIONS(2154),
    [anon_sym_offsetof] = ACTIONS(2154),
    [anon_sym__Generic] = ACTIONS(2154),
    [anon_sym_asm] = ACTIONS(2154),
    [anon_sym___asm__] = ACTIONS(2154),
    [sym_number_literal] = ACTIONS(2156),
    [anon_sym_L_SQUOTE] = ACTIONS(2156),
    [anon_sym_u_SQUOTE] = ACTIONS(2156),
    [anon_sym_U_SQUOTE] = ACTIONS(2156),
    [anon_sym_u8_SQUOTE] = ACTIONS(2156),
    [anon_sym_SQUOTE] = ACTIONS(2156),
    [anon_sym_L_DQUOTE] = ACTIONS(2156),
    [anon_sym_u_DQUOTE] = ACTIONS(2156),
    [anon_sym_U_DQUOTE] = ACTIONS(2156),
    [anon_sym_u8_DQUOTE] = ACTIONS(2156),
    [anon_sym_DQUOTE] = ACTIONS(2156),
    [sym_true] = ACTIONS(2154),
    [sym_false] = ACTIONS(2154),
    [anon_sym_NULL] = ACTIONS(2154),
    [anon_sym_nullptr] = ACTIONS(2154),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2154),
    [anon_sym_decltype] = ACTIONS(2154),
    [sym_virtual] = ACTIONS(2154),
    [anon_sym_explicit] = ACTIONS(2154),
    [anon_sym_typename] = ACTIONS(2154),
    [anon_sym_template] = ACTIONS(2154),
    [anon_sym_operator] = ACTIONS(2154),
    [anon_sym_try] = ACTIONS(2154),
    [anon_sym_delete] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2154),
    [anon_sym_namespace] = ACTIONS(2154),
    [anon_sym_using] = ACTIONS(2154),
    [anon_sym_static_assert] = ACTIONS(2154),
    [anon_sym_concept] = ACTIONS(2154),
    [anon_sym_co_return] = ACTIONS(2154),
    [anon_sym_co_yield] = ACTIONS(2154),
    [anon_sym_R_DQUOTE] = ACTIONS(2156),
    [anon_sym_LR_DQUOTE] = ACTIONS(2156),
    [anon_sym_uR_DQUOTE] = ACTIONS(2156),
    [anon_sym_UR_DQUOTE] = ACTIONS(2156),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2156),
    [anon_sym_co_await] = ACTIONS(2154),
    [anon_sym_new] = ACTIONS(2154),
    [anon_sym_requires] = ACTIONS(2154),
    [sym_this] = ACTIONS(2154),
    [anon_sym_discard] = ACTIONS(2154),
    [anon_sym_precise] = ACTIONS(2154),
    [anon_sym_shared] = ACTIONS(2154),
    [anon_sym_groupshared] = ACTIONS(2154),
    [anon_sym_uniform] = ACTIONS(2154),
    [anon_sym_row_major] = ACTIONS(2154),
    [anon_sym_column_major] = ACTIONS(2154),
    [anon_sym_globallycoherent] = ACTIONS(2154),
    [anon_sym_centroid] = ACTIONS(2154),
    [anon_sym_noperspective] = ACTIONS(2154),
    [anon_sym_nointerpolation] = ACTIONS(2154),
    [anon_sym_sample] = ACTIONS(2154),
    [anon_sym_linear] = ACTIONS(2154),
    [anon_sym_snorm] = ACTIONS(2154),
    [anon_sym_unorm] = ACTIONS(2154),
    [anon_sym_point] = ACTIONS(2154),
    [anon_sym_line] = ACTIONS(2154),
    [anon_sym_triangleadj] = ACTIONS(2154),
    [anon_sym_lineadj] = ACTIONS(2154),
    [anon_sym_triangle] = ACTIONS(2154),
    [anon_sym_cbuffer] = ACTIONS(2154),
  },
  [405] = {
    [sym_identifier] = ACTIONS(2158),
    [aux_sym_preproc_include_token1] = ACTIONS(2158),
    [aux_sym_preproc_def_token1] = ACTIONS(2158),
    [aux_sym_preproc_if_token1] = ACTIONS(2158),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2158),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2158),
    [sym_preproc_directive] = ACTIONS(2158),
    [anon_sym_LPAREN2] = ACTIONS(2160),
    [anon_sym_BANG] = ACTIONS(2160),
    [anon_sym_TILDE] = ACTIONS(2160),
    [anon_sym_DASH] = ACTIONS(2158),
    [anon_sym_PLUS] = ACTIONS(2158),
    [anon_sym_STAR] = ACTIONS(2160),
    [anon_sym_AMP_AMP] = ACTIONS(2160),
    [anon_sym_AMP] = ACTIONS(2158),
    [anon_sym_SEMI] = ACTIONS(2160),
    [anon_sym___extension__] = ACTIONS(2158),
    [anon_sym_typedef] = ACTIONS(2158),
    [anon_sym_in] = ACTIONS(2158),
    [anon_sym_out] = ACTIONS(2158),
    [anon_sym_inout] = ACTIONS(2158),
    [anon_sym_extern] = ACTIONS(2158),
    [anon_sym___attribute__] = ACTIONS(2158),
    [anon_sym_COLON_COLON] = ACTIONS(2160),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2160),
    [anon_sym___declspec] = ACTIONS(2158),
    [anon_sym___based] = ACTIONS(2158),
    [anon_sym___cdecl] = ACTIONS(2158),
    [anon_sym___clrcall] = ACTIONS(2158),
    [anon_sym___stdcall] = ACTIONS(2158),
    [anon_sym___fastcall] = ACTIONS(2158),
    [anon_sym___thiscall] = ACTIONS(2158),
    [anon_sym___vectorcall] = ACTIONS(2158),
    [anon_sym_LBRACE] = ACTIONS(2160),
    [anon_sym_RBRACE] = ACTIONS(2160),
    [anon_sym_signed] = ACTIONS(2158),
    [anon_sym_unsigned] = ACTIONS(2158),
    [anon_sym_long] = ACTIONS(2158),
    [anon_sym_short] = ACTIONS(2158),
    [anon_sym_LBRACK] = ACTIONS(2158),
    [anon_sym_static] = ACTIONS(2158),
    [anon_sym_register] = ACTIONS(2158),
    [anon_sym_inline] = ACTIONS(2158),
    [anon_sym___inline] = ACTIONS(2158),
    [anon_sym___inline__] = ACTIONS(2158),
    [anon_sym___forceinline] = ACTIONS(2158),
    [anon_sym_thread_local] = ACTIONS(2158),
    [anon_sym___thread] = ACTIONS(2158),
    [anon_sym_const] = ACTIONS(2158),
    [anon_sym_constexpr] = ACTIONS(2158),
    [anon_sym_volatile] = ACTIONS(2158),
    [anon_sym_restrict] = ACTIONS(2158),
    [anon_sym___restrict__] = ACTIONS(2158),
    [anon_sym__Atomic] = ACTIONS(2158),
    [anon_sym__Noreturn] = ACTIONS(2158),
    [anon_sym_noreturn] = ACTIONS(2158),
    [anon_sym_mutable] = ACTIONS(2158),
    [anon_sym_constinit] = ACTIONS(2158),
    [anon_sym_consteval] = ACTIONS(2158),
    [anon_sym_alignas] = ACTIONS(2158),
    [anon_sym__Alignas] = ACTIONS(2158),
    [sym_primitive_type] = ACTIONS(2158),
    [anon_sym_enum] = ACTIONS(2158),
    [anon_sym_class] = ACTIONS(2158),
    [anon_sym_struct] = ACTIONS(2158),
    [anon_sym_union] = ACTIONS(2158),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_else] = ACTIONS(2158),
    [anon_sym_switch] = ACTIONS(2158),
    [anon_sym_case] = ACTIONS(2158),
    [anon_sym_default] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2158),
    [anon_sym_do] = ACTIONS(2158),
    [anon_sym_for] = ACTIONS(2158),
    [anon_sym_return] = ACTIONS(2158),
    [anon_sym_break] = ACTIONS(2158),
    [anon_sym_continue] = ACTIONS(2158),
    [anon_sym_goto] = ACTIONS(2158),
    [anon_sym___try] = ACTIONS(2158),
    [anon_sym___leave] = ACTIONS(2158),
    [anon_sym_not] = ACTIONS(2158),
    [anon_sym_compl] = ACTIONS(2158),
    [anon_sym_DASH_DASH] = ACTIONS(2160),
    [anon_sym_PLUS_PLUS] = ACTIONS(2160),
    [anon_sym_sizeof] = ACTIONS(2158),
    [anon_sym___alignof__] = ACTIONS(2158),
    [anon_sym___alignof] = ACTIONS(2158),
    [anon_sym__alignof] = ACTIONS(2158),
    [anon_sym_alignof] = ACTIONS(2158),
    [anon_sym__Alignof] = ACTIONS(2158),
    [anon_sym_offsetof] = ACTIONS(2158),
    [anon_sym__Generic] = ACTIONS(2158),
    [anon_sym_asm] = ACTIONS(2158),
    [anon_sym___asm__] = ACTIONS(2158),
    [sym_number_literal] = ACTIONS(2160),
    [anon_sym_L_SQUOTE] = ACTIONS(2160),
    [anon_sym_u_SQUOTE] = ACTIONS(2160),
    [anon_sym_U_SQUOTE] = ACTIONS(2160),
    [anon_sym_u8_SQUOTE] = ACTIONS(2160),
    [anon_sym_SQUOTE] = ACTIONS(2160),
    [anon_sym_L_DQUOTE] = ACTIONS(2160),
    [anon_sym_u_DQUOTE] = ACTIONS(2160),
    [anon_sym_U_DQUOTE] = ACTIONS(2160),
    [anon_sym_u8_DQUOTE] = ACTIONS(2160),
    [anon_sym_DQUOTE] = ACTIONS(2160),
    [sym_true] = ACTIONS(2158),
    [sym_false] = ACTIONS(2158),
    [anon_sym_NULL] = ACTIONS(2158),
    [anon_sym_nullptr] = ACTIONS(2158),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2158),
    [anon_sym_decltype] = ACTIONS(2158),
    [sym_virtual] = ACTIONS(2158),
    [anon_sym_explicit] = ACTIONS(2158),
    [anon_sym_typename] = ACTIONS(2158),
    [anon_sym_template] = ACTIONS(2158),
    [anon_sym_operator] = ACTIONS(2158),
    [anon_sym_try] = ACTIONS(2158),
    [anon_sym_delete] = ACTIONS(2158),
    [anon_sym_throw] = ACTIONS(2158),
    [anon_sym_namespace] = ACTIONS(2158),
    [anon_sym_using] = ACTIONS(2158),
    [anon_sym_static_assert] = ACTIONS(2158),
    [anon_sym_concept] = ACTIONS(2158),
    [anon_sym_co_return] = ACTIONS(2158),
    [anon_sym_co_yield] = ACTIONS(2158),
    [anon_sym_R_DQUOTE] = ACTIONS(2160),
    [anon_sym_LR_DQUOTE] = ACTIONS(2160),
    [anon_sym_uR_DQUOTE] = ACTIONS(2160),
    [anon_sym_UR_DQUOTE] = ACTIONS(2160),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2160),
    [anon_sym_co_await] = ACTIONS(2158),
    [anon_sym_new] = ACTIONS(2158),
    [anon_sym_requires] = ACTIONS(2158),
    [sym_this] = ACTIONS(2158),
    [anon_sym_discard] = ACTIONS(2158),
    [anon_sym_precise] = ACTIONS(2158),
    [anon_sym_shared] = ACTIONS(2158),
    [anon_sym_groupshared] = ACTIONS(2158),
    [anon_sym_uniform] = ACTIONS(2158),
    [anon_sym_row_major] = ACTIONS(2158),
    [anon_sym_column_major] = ACTIONS(2158),
    [anon_sym_globallycoherent] = ACTIONS(2158),
    [anon_sym_centroid] = ACTIONS(2158),
    [anon_sym_noperspective] = ACTIONS(2158),
    [anon_sym_nointerpolation] = ACTIONS(2158),
    [anon_sym_sample] = ACTIONS(2158),
    [anon_sym_linear] = ACTIONS(2158),
    [anon_sym_snorm] = ACTIONS(2158),
    [anon_sym_unorm] = ACTIONS(2158),
    [anon_sym_point] = ACTIONS(2158),
    [anon_sym_line] = ACTIONS(2158),
    [anon_sym_triangleadj] = ACTIONS(2158),
    [anon_sym_lineadj] = ACTIONS(2158),
    [anon_sym_triangle] = ACTIONS(2158),
    [anon_sym_cbuffer] = ACTIONS(2158),
  },
  [406] = {
    [sym_identifier] = ACTIONS(2256),
    [aux_sym_preproc_include_token1] = ACTIONS(2256),
    [aux_sym_preproc_def_token1] = ACTIONS(2256),
    [aux_sym_preproc_if_token1] = ACTIONS(2256),
    [aux_sym_preproc_if_token2] = ACTIONS(2256),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2256),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2256),
    [sym_preproc_directive] = ACTIONS(2256),
    [anon_sym_LPAREN2] = ACTIONS(2258),
    [anon_sym_BANG] = ACTIONS(2258),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_DASH] = ACTIONS(2256),
    [anon_sym_PLUS] = ACTIONS(2256),
    [anon_sym_STAR] = ACTIONS(2258),
    [anon_sym_AMP_AMP] = ACTIONS(2258),
    [anon_sym_AMP] = ACTIONS(2256),
    [anon_sym_SEMI] = ACTIONS(2258),
    [anon_sym___extension__] = ACTIONS(2256),
    [anon_sym_typedef] = ACTIONS(2256),
    [anon_sym_in] = ACTIONS(2256),
    [anon_sym_out] = ACTIONS(2256),
    [anon_sym_inout] = ACTIONS(2256),
    [anon_sym_extern] = ACTIONS(2256),
    [anon_sym___attribute__] = ACTIONS(2256),
    [anon_sym_COLON_COLON] = ACTIONS(2258),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2258),
    [anon_sym___declspec] = ACTIONS(2256),
    [anon_sym___based] = ACTIONS(2256),
    [anon_sym___cdecl] = ACTIONS(2256),
    [anon_sym___clrcall] = ACTIONS(2256),
    [anon_sym___stdcall] = ACTIONS(2256),
    [anon_sym___fastcall] = ACTIONS(2256),
    [anon_sym___thiscall] = ACTIONS(2256),
    [anon_sym___vectorcall] = ACTIONS(2256),
    [anon_sym_LBRACE] = ACTIONS(2258),
    [anon_sym_signed] = ACTIONS(2256),
    [anon_sym_unsigned] = ACTIONS(2256),
    [anon_sym_long] = ACTIONS(2256),
    [anon_sym_short] = ACTIONS(2256),
    [anon_sym_LBRACK] = ACTIONS(2256),
    [anon_sym_static] = ACTIONS(2256),
    [anon_sym_register] = ACTIONS(2256),
    [anon_sym_inline] = ACTIONS(2256),
    [anon_sym___inline] = ACTIONS(2256),
    [anon_sym___inline__] = ACTIONS(2256),
    [anon_sym___forceinline] = ACTIONS(2256),
    [anon_sym_thread_local] = ACTIONS(2256),
    [anon_sym___thread] = ACTIONS(2256),
    [anon_sym_const] = ACTIONS(2256),
    [anon_sym_constexpr] = ACTIONS(2256),
    [anon_sym_volatile] = ACTIONS(2256),
    [anon_sym_restrict] = ACTIONS(2256),
    [anon_sym___restrict__] = ACTIONS(2256),
    [anon_sym__Atomic] = ACTIONS(2256),
    [anon_sym__Noreturn] = ACTIONS(2256),
    [anon_sym_noreturn] = ACTIONS(2256),
    [anon_sym_mutable] = ACTIONS(2256),
    [anon_sym_constinit] = ACTIONS(2256),
    [anon_sym_consteval] = ACTIONS(2256),
    [anon_sym_alignas] = ACTIONS(2256),
    [anon_sym__Alignas] = ACTIONS(2256),
    [sym_primitive_type] = ACTIONS(2256),
    [anon_sym_enum] = ACTIONS(2256),
    [anon_sym_class] = ACTIONS(2256),
    [anon_sym_struct] = ACTIONS(2256),
    [anon_sym_union] = ACTIONS(2256),
    [anon_sym_if] = ACTIONS(2256),
    [anon_sym_else] = ACTIONS(2256),
    [anon_sym_switch] = ACTIONS(2256),
    [anon_sym_case] = ACTIONS(2256),
    [anon_sym_default] = ACTIONS(2256),
    [anon_sym_while] = ACTIONS(2256),
    [anon_sym_do] = ACTIONS(2256),
    [anon_sym_for] = ACTIONS(2256),
    [anon_sym_return] = ACTIONS(2256),
    [anon_sym_break] = ACTIONS(2256),
    [anon_sym_continue] = ACTIONS(2256),
    [anon_sym_goto] = ACTIONS(2256),
    [anon_sym___try] = ACTIONS(2256),
    [anon_sym___leave] = ACTIONS(2256),
    [anon_sym_not] = ACTIONS(2256),
    [anon_sym_compl] = ACTIONS(2256),
    [anon_sym_DASH_DASH] = ACTIONS(2258),
    [anon_sym_PLUS_PLUS] = ACTIONS(2258),
    [anon_sym_sizeof] = ACTIONS(2256),
    [anon_sym___alignof__] = ACTIONS(2256),
    [anon_sym___alignof] = ACTIONS(2256),
    [anon_sym__alignof] = ACTIONS(2256),
    [anon_sym_alignof] = ACTIONS(2256),
    [anon_sym__Alignof] = ACTIONS(2256),
    [anon_sym_offsetof] = ACTIONS(2256),
    [anon_sym__Generic] = ACTIONS(2256),
    [anon_sym_asm] = ACTIONS(2256),
    [anon_sym___asm__] = ACTIONS(2256),
    [sym_number_literal] = ACTIONS(2258),
    [anon_sym_L_SQUOTE] = ACTIONS(2258),
    [anon_sym_u_SQUOTE] = ACTIONS(2258),
    [anon_sym_U_SQUOTE] = ACTIONS(2258),
    [anon_sym_u8_SQUOTE] = ACTIONS(2258),
    [anon_sym_SQUOTE] = ACTIONS(2258),
    [anon_sym_L_DQUOTE] = ACTIONS(2258),
    [anon_sym_u_DQUOTE] = ACTIONS(2258),
    [anon_sym_U_DQUOTE] = ACTIONS(2258),
    [anon_sym_u8_DQUOTE] = ACTIONS(2258),
    [anon_sym_DQUOTE] = ACTIONS(2258),
    [sym_true] = ACTIONS(2256),
    [sym_false] = ACTIONS(2256),
    [anon_sym_NULL] = ACTIONS(2256),
    [anon_sym_nullptr] = ACTIONS(2256),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2256),
    [anon_sym_decltype] = ACTIONS(2256),
    [sym_virtual] = ACTIONS(2256),
    [anon_sym_explicit] = ACTIONS(2256),
    [anon_sym_typename] = ACTIONS(2256),
    [anon_sym_template] = ACTIONS(2256),
    [anon_sym_operator] = ACTIONS(2256),
    [anon_sym_try] = ACTIONS(2256),
    [anon_sym_delete] = ACTIONS(2256),
    [anon_sym_throw] = ACTIONS(2256),
    [anon_sym_namespace] = ACTIONS(2256),
    [anon_sym_using] = ACTIONS(2256),
    [anon_sym_static_assert] = ACTIONS(2256),
    [anon_sym_concept] = ACTIONS(2256),
    [anon_sym_co_return] = ACTIONS(2256),
    [anon_sym_co_yield] = ACTIONS(2256),
    [anon_sym_R_DQUOTE] = ACTIONS(2258),
    [anon_sym_LR_DQUOTE] = ACTIONS(2258),
    [anon_sym_uR_DQUOTE] = ACTIONS(2258),
    [anon_sym_UR_DQUOTE] = ACTIONS(2258),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2258),
    [anon_sym_co_await] = ACTIONS(2256),
    [anon_sym_new] = ACTIONS(2256),
    [anon_sym_requires] = ACTIONS(2256),
    [sym_this] = ACTIONS(2256),
    [anon_sym_discard] = ACTIONS(2256),
    [anon_sym_precise] = ACTIONS(2256),
    [anon_sym_shared] = ACTIONS(2256),
    [anon_sym_groupshared] = ACTIONS(2256),
    [anon_sym_uniform] = ACTIONS(2256),
    [anon_sym_row_major] = ACTIONS(2256),
    [anon_sym_column_major] = ACTIONS(2256),
    [anon_sym_globallycoherent] = ACTIONS(2256),
    [anon_sym_centroid] = ACTIONS(2256),
    [anon_sym_noperspective] = ACTIONS(2256),
    [anon_sym_nointerpolation] = ACTIONS(2256),
    [anon_sym_sample] = ACTIONS(2256),
    [anon_sym_linear] = ACTIONS(2256),
    [anon_sym_snorm] = ACTIONS(2256),
    [anon_sym_unorm] = ACTIONS(2256),
    [anon_sym_point] = ACTIONS(2256),
    [anon_sym_line] = ACTIONS(2256),
    [anon_sym_triangleadj] = ACTIONS(2256),
    [anon_sym_lineadj] = ACTIONS(2256),
    [anon_sym_triangle] = ACTIONS(2256),
    [anon_sym_cbuffer] = ACTIONS(2256),
  },
  [407] = {
    [sym_identifier] = ACTIONS(2252),
    [aux_sym_preproc_include_token1] = ACTIONS(2252),
    [aux_sym_preproc_def_token1] = ACTIONS(2252),
    [aux_sym_preproc_if_token1] = ACTIONS(2252),
    [aux_sym_preproc_if_token2] = ACTIONS(2252),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2252),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2252),
    [sym_preproc_directive] = ACTIONS(2252),
    [anon_sym_LPAREN2] = ACTIONS(2254),
    [anon_sym_BANG] = ACTIONS(2254),
    [anon_sym_TILDE] = ACTIONS(2254),
    [anon_sym_DASH] = ACTIONS(2252),
    [anon_sym_PLUS] = ACTIONS(2252),
    [anon_sym_STAR] = ACTIONS(2254),
    [anon_sym_AMP_AMP] = ACTIONS(2254),
    [anon_sym_AMP] = ACTIONS(2252),
    [anon_sym_SEMI] = ACTIONS(2254),
    [anon_sym___extension__] = ACTIONS(2252),
    [anon_sym_typedef] = ACTIONS(2252),
    [anon_sym_in] = ACTIONS(2252),
    [anon_sym_out] = ACTIONS(2252),
    [anon_sym_inout] = ACTIONS(2252),
    [anon_sym_extern] = ACTIONS(2252),
    [anon_sym___attribute__] = ACTIONS(2252),
    [anon_sym_COLON_COLON] = ACTIONS(2254),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2254),
    [anon_sym___declspec] = ACTIONS(2252),
    [anon_sym___based] = ACTIONS(2252),
    [anon_sym___cdecl] = ACTIONS(2252),
    [anon_sym___clrcall] = ACTIONS(2252),
    [anon_sym___stdcall] = ACTIONS(2252),
    [anon_sym___fastcall] = ACTIONS(2252),
    [anon_sym___thiscall] = ACTIONS(2252),
    [anon_sym___vectorcall] = ACTIONS(2252),
    [anon_sym_LBRACE] = ACTIONS(2254),
    [anon_sym_signed] = ACTIONS(2252),
    [anon_sym_unsigned] = ACTIONS(2252),
    [anon_sym_long] = ACTIONS(2252),
    [anon_sym_short] = ACTIONS(2252),
    [anon_sym_LBRACK] = ACTIONS(2252),
    [anon_sym_static] = ACTIONS(2252),
    [anon_sym_register] = ACTIONS(2252),
    [anon_sym_inline] = ACTIONS(2252),
    [anon_sym___inline] = ACTIONS(2252),
    [anon_sym___inline__] = ACTIONS(2252),
    [anon_sym___forceinline] = ACTIONS(2252),
    [anon_sym_thread_local] = ACTIONS(2252),
    [anon_sym___thread] = ACTIONS(2252),
    [anon_sym_const] = ACTIONS(2252),
    [anon_sym_constexpr] = ACTIONS(2252),
    [anon_sym_volatile] = ACTIONS(2252),
    [anon_sym_restrict] = ACTIONS(2252),
    [anon_sym___restrict__] = ACTIONS(2252),
    [anon_sym__Atomic] = ACTIONS(2252),
    [anon_sym__Noreturn] = ACTIONS(2252),
    [anon_sym_noreturn] = ACTIONS(2252),
    [anon_sym_mutable] = ACTIONS(2252),
    [anon_sym_constinit] = ACTIONS(2252),
    [anon_sym_consteval] = ACTIONS(2252),
    [anon_sym_alignas] = ACTIONS(2252),
    [anon_sym__Alignas] = ACTIONS(2252),
    [sym_primitive_type] = ACTIONS(2252),
    [anon_sym_enum] = ACTIONS(2252),
    [anon_sym_class] = ACTIONS(2252),
    [anon_sym_struct] = ACTIONS(2252),
    [anon_sym_union] = ACTIONS(2252),
    [anon_sym_if] = ACTIONS(2252),
    [anon_sym_else] = ACTIONS(2252),
    [anon_sym_switch] = ACTIONS(2252),
    [anon_sym_case] = ACTIONS(2252),
    [anon_sym_default] = ACTIONS(2252),
    [anon_sym_while] = ACTIONS(2252),
    [anon_sym_do] = ACTIONS(2252),
    [anon_sym_for] = ACTIONS(2252),
    [anon_sym_return] = ACTIONS(2252),
    [anon_sym_break] = ACTIONS(2252),
    [anon_sym_continue] = ACTIONS(2252),
    [anon_sym_goto] = ACTIONS(2252),
    [anon_sym___try] = ACTIONS(2252),
    [anon_sym___leave] = ACTIONS(2252),
    [anon_sym_not] = ACTIONS(2252),
    [anon_sym_compl] = ACTIONS(2252),
    [anon_sym_DASH_DASH] = ACTIONS(2254),
    [anon_sym_PLUS_PLUS] = ACTIONS(2254),
    [anon_sym_sizeof] = ACTIONS(2252),
    [anon_sym___alignof__] = ACTIONS(2252),
    [anon_sym___alignof] = ACTIONS(2252),
    [anon_sym__alignof] = ACTIONS(2252),
    [anon_sym_alignof] = ACTIONS(2252),
    [anon_sym__Alignof] = ACTIONS(2252),
    [anon_sym_offsetof] = ACTIONS(2252),
    [anon_sym__Generic] = ACTIONS(2252),
    [anon_sym_asm] = ACTIONS(2252),
    [anon_sym___asm__] = ACTIONS(2252),
    [sym_number_literal] = ACTIONS(2254),
    [anon_sym_L_SQUOTE] = ACTIONS(2254),
    [anon_sym_u_SQUOTE] = ACTIONS(2254),
    [anon_sym_U_SQUOTE] = ACTIONS(2254),
    [anon_sym_u8_SQUOTE] = ACTIONS(2254),
    [anon_sym_SQUOTE] = ACTIONS(2254),
    [anon_sym_L_DQUOTE] = ACTIONS(2254),
    [anon_sym_u_DQUOTE] = ACTIONS(2254),
    [anon_sym_U_DQUOTE] = ACTIONS(2254),
    [anon_sym_u8_DQUOTE] = ACTIONS(2254),
    [anon_sym_DQUOTE] = ACTIONS(2254),
    [sym_true] = ACTIONS(2252),
    [sym_false] = ACTIONS(2252),
    [anon_sym_NULL] = ACTIONS(2252),
    [anon_sym_nullptr] = ACTIONS(2252),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2252),
    [anon_sym_decltype] = ACTIONS(2252),
    [sym_virtual] = ACTIONS(2252),
    [anon_sym_explicit] = ACTIONS(2252),
    [anon_sym_typename] = ACTIONS(2252),
    [anon_sym_template] = ACTIONS(2252),
    [anon_sym_operator] = ACTIONS(2252),
    [anon_sym_try] = ACTIONS(2252),
    [anon_sym_delete] = ACTIONS(2252),
    [anon_sym_throw] = ACTIONS(2252),
    [anon_sym_namespace] = ACTIONS(2252),
    [anon_sym_using] = ACTIONS(2252),
    [anon_sym_static_assert] = ACTIONS(2252),
    [anon_sym_concept] = ACTIONS(2252),
    [anon_sym_co_return] = ACTIONS(2252),
    [anon_sym_co_yield] = ACTIONS(2252),
    [anon_sym_R_DQUOTE] = ACTIONS(2254),
    [anon_sym_LR_DQUOTE] = ACTIONS(2254),
    [anon_sym_uR_DQUOTE] = ACTIONS(2254),
    [anon_sym_UR_DQUOTE] = ACTIONS(2254),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2254),
    [anon_sym_co_await] = ACTIONS(2252),
    [anon_sym_new] = ACTIONS(2252),
    [anon_sym_requires] = ACTIONS(2252),
    [sym_this] = ACTIONS(2252),
    [anon_sym_discard] = ACTIONS(2252),
    [anon_sym_precise] = ACTIONS(2252),
    [anon_sym_shared] = ACTIONS(2252),
    [anon_sym_groupshared] = ACTIONS(2252),
    [anon_sym_uniform] = ACTIONS(2252),
    [anon_sym_row_major] = ACTIONS(2252),
    [anon_sym_column_major] = ACTIONS(2252),
    [anon_sym_globallycoherent] = ACTIONS(2252),
    [anon_sym_centroid] = ACTIONS(2252),
    [anon_sym_noperspective] = ACTIONS(2252),
    [anon_sym_nointerpolation] = ACTIONS(2252),
    [anon_sym_sample] = ACTIONS(2252),
    [anon_sym_linear] = ACTIONS(2252),
    [anon_sym_snorm] = ACTIONS(2252),
    [anon_sym_unorm] = ACTIONS(2252),
    [anon_sym_point] = ACTIONS(2252),
    [anon_sym_line] = ACTIONS(2252),
    [anon_sym_triangleadj] = ACTIONS(2252),
    [anon_sym_lineadj] = ACTIONS(2252),
    [anon_sym_triangle] = ACTIONS(2252),
    [anon_sym_cbuffer] = ACTIONS(2252),
  },
  [408] = {
    [sym_identifier] = ACTIONS(2174),
    [aux_sym_preproc_include_token1] = ACTIONS(2174),
    [aux_sym_preproc_def_token1] = ACTIONS(2174),
    [aux_sym_preproc_if_token1] = ACTIONS(2174),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2174),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2174),
    [sym_preproc_directive] = ACTIONS(2174),
    [anon_sym_LPAREN2] = ACTIONS(2176),
    [anon_sym_BANG] = ACTIONS(2176),
    [anon_sym_TILDE] = ACTIONS(2176),
    [anon_sym_DASH] = ACTIONS(2174),
    [anon_sym_PLUS] = ACTIONS(2174),
    [anon_sym_STAR] = ACTIONS(2176),
    [anon_sym_AMP_AMP] = ACTIONS(2176),
    [anon_sym_AMP] = ACTIONS(2174),
    [anon_sym_SEMI] = ACTIONS(2176),
    [anon_sym___extension__] = ACTIONS(2174),
    [anon_sym_typedef] = ACTIONS(2174),
    [anon_sym_in] = ACTIONS(2174),
    [anon_sym_out] = ACTIONS(2174),
    [anon_sym_inout] = ACTIONS(2174),
    [anon_sym_extern] = ACTIONS(2174),
    [anon_sym___attribute__] = ACTIONS(2174),
    [anon_sym_COLON_COLON] = ACTIONS(2176),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2176),
    [anon_sym___declspec] = ACTIONS(2174),
    [anon_sym___based] = ACTIONS(2174),
    [anon_sym___cdecl] = ACTIONS(2174),
    [anon_sym___clrcall] = ACTIONS(2174),
    [anon_sym___stdcall] = ACTIONS(2174),
    [anon_sym___fastcall] = ACTIONS(2174),
    [anon_sym___thiscall] = ACTIONS(2174),
    [anon_sym___vectorcall] = ACTIONS(2174),
    [anon_sym_LBRACE] = ACTIONS(2176),
    [anon_sym_RBRACE] = ACTIONS(2176),
    [anon_sym_signed] = ACTIONS(2174),
    [anon_sym_unsigned] = ACTIONS(2174),
    [anon_sym_long] = ACTIONS(2174),
    [anon_sym_short] = ACTIONS(2174),
    [anon_sym_LBRACK] = ACTIONS(2174),
    [anon_sym_static] = ACTIONS(2174),
    [anon_sym_register] = ACTIONS(2174),
    [anon_sym_inline] = ACTIONS(2174),
    [anon_sym___inline] = ACTIONS(2174),
    [anon_sym___inline__] = ACTIONS(2174),
    [anon_sym___forceinline] = ACTIONS(2174),
    [anon_sym_thread_local] = ACTIONS(2174),
    [anon_sym___thread] = ACTIONS(2174),
    [anon_sym_const] = ACTIONS(2174),
    [anon_sym_constexpr] = ACTIONS(2174),
    [anon_sym_volatile] = ACTIONS(2174),
    [anon_sym_restrict] = ACTIONS(2174),
    [anon_sym___restrict__] = ACTIONS(2174),
    [anon_sym__Atomic] = ACTIONS(2174),
    [anon_sym__Noreturn] = ACTIONS(2174),
    [anon_sym_noreturn] = ACTIONS(2174),
    [anon_sym_mutable] = ACTIONS(2174),
    [anon_sym_constinit] = ACTIONS(2174),
    [anon_sym_consteval] = ACTIONS(2174),
    [anon_sym_alignas] = ACTIONS(2174),
    [anon_sym__Alignas] = ACTIONS(2174),
    [sym_primitive_type] = ACTIONS(2174),
    [anon_sym_enum] = ACTIONS(2174),
    [anon_sym_class] = ACTIONS(2174),
    [anon_sym_struct] = ACTIONS(2174),
    [anon_sym_union] = ACTIONS(2174),
    [anon_sym_if] = ACTIONS(2174),
    [anon_sym_else] = ACTIONS(2174),
    [anon_sym_switch] = ACTIONS(2174),
    [anon_sym_case] = ACTIONS(2174),
    [anon_sym_default] = ACTIONS(2174),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_do] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2174),
    [anon_sym_return] = ACTIONS(2174),
    [anon_sym_break] = ACTIONS(2174),
    [anon_sym_continue] = ACTIONS(2174),
    [anon_sym_goto] = ACTIONS(2174),
    [anon_sym___try] = ACTIONS(2174),
    [anon_sym___leave] = ACTIONS(2174),
    [anon_sym_not] = ACTIONS(2174),
    [anon_sym_compl] = ACTIONS(2174),
    [anon_sym_DASH_DASH] = ACTIONS(2176),
    [anon_sym_PLUS_PLUS] = ACTIONS(2176),
    [anon_sym_sizeof] = ACTIONS(2174),
    [anon_sym___alignof__] = ACTIONS(2174),
    [anon_sym___alignof] = ACTIONS(2174),
    [anon_sym__alignof] = ACTIONS(2174),
    [anon_sym_alignof] = ACTIONS(2174),
    [anon_sym__Alignof] = ACTIONS(2174),
    [anon_sym_offsetof] = ACTIONS(2174),
    [anon_sym__Generic] = ACTIONS(2174),
    [anon_sym_asm] = ACTIONS(2174),
    [anon_sym___asm__] = ACTIONS(2174),
    [sym_number_literal] = ACTIONS(2176),
    [anon_sym_L_SQUOTE] = ACTIONS(2176),
    [anon_sym_u_SQUOTE] = ACTIONS(2176),
    [anon_sym_U_SQUOTE] = ACTIONS(2176),
    [anon_sym_u8_SQUOTE] = ACTIONS(2176),
    [anon_sym_SQUOTE] = ACTIONS(2176),
    [anon_sym_L_DQUOTE] = ACTIONS(2176),
    [anon_sym_u_DQUOTE] = ACTIONS(2176),
    [anon_sym_U_DQUOTE] = ACTIONS(2176),
    [anon_sym_u8_DQUOTE] = ACTIONS(2176),
    [anon_sym_DQUOTE] = ACTIONS(2176),
    [sym_true] = ACTIONS(2174),
    [sym_false] = ACTIONS(2174),
    [anon_sym_NULL] = ACTIONS(2174),
    [anon_sym_nullptr] = ACTIONS(2174),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2174),
    [anon_sym_decltype] = ACTIONS(2174),
    [sym_virtual] = ACTIONS(2174),
    [anon_sym_explicit] = ACTIONS(2174),
    [anon_sym_typename] = ACTIONS(2174),
    [anon_sym_template] = ACTIONS(2174),
    [anon_sym_operator] = ACTIONS(2174),
    [anon_sym_try] = ACTIONS(2174),
    [anon_sym_delete] = ACTIONS(2174),
    [anon_sym_throw] = ACTIONS(2174),
    [anon_sym_namespace] = ACTIONS(2174),
    [anon_sym_using] = ACTIONS(2174),
    [anon_sym_static_assert] = ACTIONS(2174),
    [anon_sym_concept] = ACTIONS(2174),
    [anon_sym_co_return] = ACTIONS(2174),
    [anon_sym_co_yield] = ACTIONS(2174),
    [anon_sym_R_DQUOTE] = ACTIONS(2176),
    [anon_sym_LR_DQUOTE] = ACTIONS(2176),
    [anon_sym_uR_DQUOTE] = ACTIONS(2176),
    [anon_sym_UR_DQUOTE] = ACTIONS(2176),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2176),
    [anon_sym_co_await] = ACTIONS(2174),
    [anon_sym_new] = ACTIONS(2174),
    [anon_sym_requires] = ACTIONS(2174),
    [sym_this] = ACTIONS(2174),
    [anon_sym_discard] = ACTIONS(2174),
    [anon_sym_precise] = ACTIONS(2174),
    [anon_sym_shared] = ACTIONS(2174),
    [anon_sym_groupshared] = ACTIONS(2174),
    [anon_sym_uniform] = ACTIONS(2174),
    [anon_sym_row_major] = ACTIONS(2174),
    [anon_sym_column_major] = ACTIONS(2174),
    [anon_sym_globallycoherent] = ACTIONS(2174),
    [anon_sym_centroid] = ACTIONS(2174),
    [anon_sym_noperspective] = ACTIONS(2174),
    [anon_sym_nointerpolation] = ACTIONS(2174),
    [anon_sym_sample] = ACTIONS(2174),
    [anon_sym_linear] = ACTIONS(2174),
    [anon_sym_snorm] = ACTIONS(2174),
    [anon_sym_unorm] = ACTIONS(2174),
    [anon_sym_point] = ACTIONS(2174),
    [anon_sym_line] = ACTIONS(2174),
    [anon_sym_triangleadj] = ACTIONS(2174),
    [anon_sym_lineadj] = ACTIONS(2174),
    [anon_sym_triangle] = ACTIONS(2174),
    [anon_sym_cbuffer] = ACTIONS(2174),
  },
  [409] = {
    [sym_identifier] = ACTIONS(2170),
    [aux_sym_preproc_include_token1] = ACTIONS(2170),
    [aux_sym_preproc_def_token1] = ACTIONS(2170),
    [aux_sym_preproc_if_token1] = ACTIONS(2170),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2170),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2170),
    [sym_preproc_directive] = ACTIONS(2170),
    [anon_sym_LPAREN2] = ACTIONS(2172),
    [anon_sym_BANG] = ACTIONS(2172),
    [anon_sym_TILDE] = ACTIONS(2172),
    [anon_sym_DASH] = ACTIONS(2170),
    [anon_sym_PLUS] = ACTIONS(2170),
    [anon_sym_STAR] = ACTIONS(2172),
    [anon_sym_AMP_AMP] = ACTIONS(2172),
    [anon_sym_AMP] = ACTIONS(2170),
    [anon_sym_SEMI] = ACTIONS(2172),
    [anon_sym___extension__] = ACTIONS(2170),
    [anon_sym_typedef] = ACTIONS(2170),
    [anon_sym_in] = ACTIONS(2170),
    [anon_sym_out] = ACTIONS(2170),
    [anon_sym_inout] = ACTIONS(2170),
    [anon_sym_extern] = ACTIONS(2170),
    [anon_sym___attribute__] = ACTIONS(2170),
    [anon_sym_COLON_COLON] = ACTIONS(2172),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2172),
    [anon_sym___declspec] = ACTIONS(2170),
    [anon_sym___based] = ACTIONS(2170),
    [anon_sym___cdecl] = ACTIONS(2170),
    [anon_sym___clrcall] = ACTIONS(2170),
    [anon_sym___stdcall] = ACTIONS(2170),
    [anon_sym___fastcall] = ACTIONS(2170),
    [anon_sym___thiscall] = ACTIONS(2170),
    [anon_sym___vectorcall] = ACTIONS(2170),
    [anon_sym_LBRACE] = ACTIONS(2172),
    [anon_sym_RBRACE] = ACTIONS(2172),
    [anon_sym_signed] = ACTIONS(2170),
    [anon_sym_unsigned] = ACTIONS(2170),
    [anon_sym_long] = ACTIONS(2170),
    [anon_sym_short] = ACTIONS(2170),
    [anon_sym_LBRACK] = ACTIONS(2170),
    [anon_sym_static] = ACTIONS(2170),
    [anon_sym_register] = ACTIONS(2170),
    [anon_sym_inline] = ACTIONS(2170),
    [anon_sym___inline] = ACTIONS(2170),
    [anon_sym___inline__] = ACTIONS(2170),
    [anon_sym___forceinline] = ACTIONS(2170),
    [anon_sym_thread_local] = ACTIONS(2170),
    [anon_sym___thread] = ACTIONS(2170),
    [anon_sym_const] = ACTIONS(2170),
    [anon_sym_constexpr] = ACTIONS(2170),
    [anon_sym_volatile] = ACTIONS(2170),
    [anon_sym_restrict] = ACTIONS(2170),
    [anon_sym___restrict__] = ACTIONS(2170),
    [anon_sym__Atomic] = ACTIONS(2170),
    [anon_sym__Noreturn] = ACTIONS(2170),
    [anon_sym_noreturn] = ACTIONS(2170),
    [anon_sym_mutable] = ACTIONS(2170),
    [anon_sym_constinit] = ACTIONS(2170),
    [anon_sym_consteval] = ACTIONS(2170),
    [anon_sym_alignas] = ACTIONS(2170),
    [anon_sym__Alignas] = ACTIONS(2170),
    [sym_primitive_type] = ACTIONS(2170),
    [anon_sym_enum] = ACTIONS(2170),
    [anon_sym_class] = ACTIONS(2170),
    [anon_sym_struct] = ACTIONS(2170),
    [anon_sym_union] = ACTIONS(2170),
    [anon_sym_if] = ACTIONS(2170),
    [anon_sym_else] = ACTIONS(2170),
    [anon_sym_switch] = ACTIONS(2170),
    [anon_sym_case] = ACTIONS(2170),
    [anon_sym_default] = ACTIONS(2170),
    [anon_sym_while] = ACTIONS(2170),
    [anon_sym_do] = ACTIONS(2170),
    [anon_sym_for] = ACTIONS(2170),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_break] = ACTIONS(2170),
    [anon_sym_continue] = ACTIONS(2170),
    [anon_sym_goto] = ACTIONS(2170),
    [anon_sym___try] = ACTIONS(2170),
    [anon_sym___leave] = ACTIONS(2170),
    [anon_sym_not] = ACTIONS(2170),
    [anon_sym_compl] = ACTIONS(2170),
    [anon_sym_DASH_DASH] = ACTIONS(2172),
    [anon_sym_PLUS_PLUS] = ACTIONS(2172),
    [anon_sym_sizeof] = ACTIONS(2170),
    [anon_sym___alignof__] = ACTIONS(2170),
    [anon_sym___alignof] = ACTIONS(2170),
    [anon_sym__alignof] = ACTIONS(2170),
    [anon_sym_alignof] = ACTIONS(2170),
    [anon_sym__Alignof] = ACTIONS(2170),
    [anon_sym_offsetof] = ACTIONS(2170),
    [anon_sym__Generic] = ACTIONS(2170),
    [anon_sym_asm] = ACTIONS(2170),
    [anon_sym___asm__] = ACTIONS(2170),
    [sym_number_literal] = ACTIONS(2172),
    [anon_sym_L_SQUOTE] = ACTIONS(2172),
    [anon_sym_u_SQUOTE] = ACTIONS(2172),
    [anon_sym_U_SQUOTE] = ACTIONS(2172),
    [anon_sym_u8_SQUOTE] = ACTIONS(2172),
    [anon_sym_SQUOTE] = ACTIONS(2172),
    [anon_sym_L_DQUOTE] = ACTIONS(2172),
    [anon_sym_u_DQUOTE] = ACTIONS(2172),
    [anon_sym_U_DQUOTE] = ACTIONS(2172),
    [anon_sym_u8_DQUOTE] = ACTIONS(2172),
    [anon_sym_DQUOTE] = ACTIONS(2172),
    [sym_true] = ACTIONS(2170),
    [sym_false] = ACTIONS(2170),
    [anon_sym_NULL] = ACTIONS(2170),
    [anon_sym_nullptr] = ACTIONS(2170),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2170),
    [anon_sym_decltype] = ACTIONS(2170),
    [sym_virtual] = ACTIONS(2170),
    [anon_sym_explicit] = ACTIONS(2170),
    [anon_sym_typename] = ACTIONS(2170),
    [anon_sym_template] = ACTIONS(2170),
    [anon_sym_operator] = ACTIONS(2170),
    [anon_sym_try] = ACTIONS(2170),
    [anon_sym_delete] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2170),
    [anon_sym_namespace] = ACTIONS(2170),
    [anon_sym_using] = ACTIONS(2170),
    [anon_sym_static_assert] = ACTIONS(2170),
    [anon_sym_concept] = ACTIONS(2170),
    [anon_sym_co_return] = ACTIONS(2170),
    [anon_sym_co_yield] = ACTIONS(2170),
    [anon_sym_R_DQUOTE] = ACTIONS(2172),
    [anon_sym_LR_DQUOTE] = ACTIONS(2172),
    [anon_sym_uR_DQUOTE] = ACTIONS(2172),
    [anon_sym_UR_DQUOTE] = ACTIONS(2172),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2172),
    [anon_sym_co_await] = ACTIONS(2170),
    [anon_sym_new] = ACTIONS(2170),
    [anon_sym_requires] = ACTIONS(2170),
    [sym_this] = ACTIONS(2170),
    [anon_sym_discard] = ACTIONS(2170),
    [anon_sym_precise] = ACTIONS(2170),
    [anon_sym_shared] = ACTIONS(2170),
    [anon_sym_groupshared] = ACTIONS(2170),
    [anon_sym_uniform] = ACTIONS(2170),
    [anon_sym_row_major] = ACTIONS(2170),
    [anon_sym_column_major] = ACTIONS(2170),
    [anon_sym_globallycoherent] = ACTIONS(2170),
    [anon_sym_centroid] = ACTIONS(2170),
    [anon_sym_noperspective] = ACTIONS(2170),
    [anon_sym_nointerpolation] = ACTIONS(2170),
    [anon_sym_sample] = ACTIONS(2170),
    [anon_sym_linear] = ACTIONS(2170),
    [anon_sym_snorm] = ACTIONS(2170),
    [anon_sym_unorm] = ACTIONS(2170),
    [anon_sym_point] = ACTIONS(2170),
    [anon_sym_line] = ACTIONS(2170),
    [anon_sym_triangleadj] = ACTIONS(2170),
    [anon_sym_lineadj] = ACTIONS(2170),
    [anon_sym_triangle] = ACTIONS(2170),
    [anon_sym_cbuffer] = ACTIONS(2170),
  },
  [410] = {
    [sym_identifier] = ACTIONS(2166),
    [aux_sym_preproc_include_token1] = ACTIONS(2166),
    [aux_sym_preproc_def_token1] = ACTIONS(2166),
    [aux_sym_preproc_if_token1] = ACTIONS(2166),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2166),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2166),
    [sym_preproc_directive] = ACTIONS(2166),
    [anon_sym_LPAREN2] = ACTIONS(2168),
    [anon_sym_BANG] = ACTIONS(2168),
    [anon_sym_TILDE] = ACTIONS(2168),
    [anon_sym_DASH] = ACTIONS(2166),
    [anon_sym_PLUS] = ACTIONS(2166),
    [anon_sym_STAR] = ACTIONS(2168),
    [anon_sym_AMP_AMP] = ACTIONS(2168),
    [anon_sym_AMP] = ACTIONS(2166),
    [anon_sym_SEMI] = ACTIONS(2168),
    [anon_sym___extension__] = ACTIONS(2166),
    [anon_sym_typedef] = ACTIONS(2166),
    [anon_sym_in] = ACTIONS(2166),
    [anon_sym_out] = ACTIONS(2166),
    [anon_sym_inout] = ACTIONS(2166),
    [anon_sym_extern] = ACTIONS(2166),
    [anon_sym___attribute__] = ACTIONS(2166),
    [anon_sym_COLON_COLON] = ACTIONS(2168),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2168),
    [anon_sym___declspec] = ACTIONS(2166),
    [anon_sym___based] = ACTIONS(2166),
    [anon_sym___cdecl] = ACTIONS(2166),
    [anon_sym___clrcall] = ACTIONS(2166),
    [anon_sym___stdcall] = ACTIONS(2166),
    [anon_sym___fastcall] = ACTIONS(2166),
    [anon_sym___thiscall] = ACTIONS(2166),
    [anon_sym___vectorcall] = ACTIONS(2166),
    [anon_sym_LBRACE] = ACTIONS(2168),
    [anon_sym_RBRACE] = ACTIONS(2168),
    [anon_sym_signed] = ACTIONS(2166),
    [anon_sym_unsigned] = ACTIONS(2166),
    [anon_sym_long] = ACTIONS(2166),
    [anon_sym_short] = ACTIONS(2166),
    [anon_sym_LBRACK] = ACTIONS(2166),
    [anon_sym_static] = ACTIONS(2166),
    [anon_sym_register] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(2166),
    [anon_sym___inline] = ACTIONS(2166),
    [anon_sym___inline__] = ACTIONS(2166),
    [anon_sym___forceinline] = ACTIONS(2166),
    [anon_sym_thread_local] = ACTIONS(2166),
    [anon_sym___thread] = ACTIONS(2166),
    [anon_sym_const] = ACTIONS(2166),
    [anon_sym_constexpr] = ACTIONS(2166),
    [anon_sym_volatile] = ACTIONS(2166),
    [anon_sym_restrict] = ACTIONS(2166),
    [anon_sym___restrict__] = ACTIONS(2166),
    [anon_sym__Atomic] = ACTIONS(2166),
    [anon_sym__Noreturn] = ACTIONS(2166),
    [anon_sym_noreturn] = ACTIONS(2166),
    [anon_sym_mutable] = ACTIONS(2166),
    [anon_sym_constinit] = ACTIONS(2166),
    [anon_sym_consteval] = ACTIONS(2166),
    [anon_sym_alignas] = ACTIONS(2166),
    [anon_sym__Alignas] = ACTIONS(2166),
    [sym_primitive_type] = ACTIONS(2166),
    [anon_sym_enum] = ACTIONS(2166),
    [anon_sym_class] = ACTIONS(2166),
    [anon_sym_struct] = ACTIONS(2166),
    [anon_sym_union] = ACTIONS(2166),
    [anon_sym_if] = ACTIONS(2166),
    [anon_sym_else] = ACTIONS(2166),
    [anon_sym_switch] = ACTIONS(2166),
    [anon_sym_case] = ACTIONS(2166),
    [anon_sym_default] = ACTIONS(2166),
    [anon_sym_while] = ACTIONS(2166),
    [anon_sym_do] = ACTIONS(2166),
    [anon_sym_for] = ACTIONS(2166),
    [anon_sym_return] = ACTIONS(2166),
    [anon_sym_break] = ACTIONS(2166),
    [anon_sym_continue] = ACTIONS(2166),
    [anon_sym_goto] = ACTIONS(2166),
    [anon_sym___try] = ACTIONS(2166),
    [anon_sym___leave] = ACTIONS(2166),
    [anon_sym_not] = ACTIONS(2166),
    [anon_sym_compl] = ACTIONS(2166),
    [anon_sym_DASH_DASH] = ACTIONS(2168),
    [anon_sym_PLUS_PLUS] = ACTIONS(2168),
    [anon_sym_sizeof] = ACTIONS(2166),
    [anon_sym___alignof__] = ACTIONS(2166),
    [anon_sym___alignof] = ACTIONS(2166),
    [anon_sym__alignof] = ACTIONS(2166),
    [anon_sym_alignof] = ACTIONS(2166),
    [anon_sym__Alignof] = ACTIONS(2166),
    [anon_sym_offsetof] = ACTIONS(2166),
    [anon_sym__Generic] = ACTIONS(2166),
    [anon_sym_asm] = ACTIONS(2166),
    [anon_sym___asm__] = ACTIONS(2166),
    [sym_number_literal] = ACTIONS(2168),
    [anon_sym_L_SQUOTE] = ACTIONS(2168),
    [anon_sym_u_SQUOTE] = ACTIONS(2168),
    [anon_sym_U_SQUOTE] = ACTIONS(2168),
    [anon_sym_u8_SQUOTE] = ACTIONS(2168),
    [anon_sym_SQUOTE] = ACTIONS(2168),
    [anon_sym_L_DQUOTE] = ACTIONS(2168),
    [anon_sym_u_DQUOTE] = ACTIONS(2168),
    [anon_sym_U_DQUOTE] = ACTIONS(2168),
    [anon_sym_u8_DQUOTE] = ACTIONS(2168),
    [anon_sym_DQUOTE] = ACTIONS(2168),
    [sym_true] = ACTIONS(2166),
    [sym_false] = ACTIONS(2166),
    [anon_sym_NULL] = ACTIONS(2166),
    [anon_sym_nullptr] = ACTIONS(2166),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2166),
    [anon_sym_decltype] = ACTIONS(2166),
    [sym_virtual] = ACTIONS(2166),
    [anon_sym_explicit] = ACTIONS(2166),
    [anon_sym_typename] = ACTIONS(2166),
    [anon_sym_template] = ACTIONS(2166),
    [anon_sym_operator] = ACTIONS(2166),
    [anon_sym_try] = ACTIONS(2166),
    [anon_sym_delete] = ACTIONS(2166),
    [anon_sym_throw] = ACTIONS(2166),
    [anon_sym_namespace] = ACTIONS(2166),
    [anon_sym_using] = ACTIONS(2166),
    [anon_sym_static_assert] = ACTIONS(2166),
    [anon_sym_concept] = ACTIONS(2166),
    [anon_sym_co_return] = ACTIONS(2166),
    [anon_sym_co_yield] = ACTIONS(2166),
    [anon_sym_R_DQUOTE] = ACTIONS(2168),
    [anon_sym_LR_DQUOTE] = ACTIONS(2168),
    [anon_sym_uR_DQUOTE] = ACTIONS(2168),
    [anon_sym_UR_DQUOTE] = ACTIONS(2168),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2168),
    [anon_sym_co_await] = ACTIONS(2166),
    [anon_sym_new] = ACTIONS(2166),
    [anon_sym_requires] = ACTIONS(2166),
    [sym_this] = ACTIONS(2166),
    [anon_sym_discard] = ACTIONS(2166),
    [anon_sym_precise] = ACTIONS(2166),
    [anon_sym_shared] = ACTIONS(2166),
    [anon_sym_groupshared] = ACTIONS(2166),
    [anon_sym_uniform] = ACTIONS(2166),
    [anon_sym_row_major] = ACTIONS(2166),
    [anon_sym_column_major] = ACTIONS(2166),
    [anon_sym_globallycoherent] = ACTIONS(2166),
    [anon_sym_centroid] = ACTIONS(2166),
    [anon_sym_noperspective] = ACTIONS(2166),
    [anon_sym_nointerpolation] = ACTIONS(2166),
    [anon_sym_sample] = ACTIONS(2166),
    [anon_sym_linear] = ACTIONS(2166),
    [anon_sym_snorm] = ACTIONS(2166),
    [anon_sym_unorm] = ACTIONS(2166),
    [anon_sym_point] = ACTIONS(2166),
    [anon_sym_line] = ACTIONS(2166),
    [anon_sym_triangleadj] = ACTIONS(2166),
    [anon_sym_lineadj] = ACTIONS(2166),
    [anon_sym_triangle] = ACTIONS(2166),
    [anon_sym_cbuffer] = ACTIONS(2166),
  },
  [411] = {
    [sym_identifier] = ACTIONS(2146),
    [aux_sym_preproc_include_token1] = ACTIONS(2146),
    [aux_sym_preproc_def_token1] = ACTIONS(2146),
    [aux_sym_preproc_if_token1] = ACTIONS(2146),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2146),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2146),
    [sym_preproc_directive] = ACTIONS(2146),
    [anon_sym_LPAREN2] = ACTIONS(2148),
    [anon_sym_BANG] = ACTIONS(2148),
    [anon_sym_TILDE] = ACTIONS(2148),
    [anon_sym_DASH] = ACTIONS(2146),
    [anon_sym_PLUS] = ACTIONS(2146),
    [anon_sym_STAR] = ACTIONS(2148),
    [anon_sym_AMP_AMP] = ACTIONS(2148),
    [anon_sym_AMP] = ACTIONS(2146),
    [anon_sym_SEMI] = ACTIONS(2148),
    [anon_sym___extension__] = ACTIONS(2146),
    [anon_sym_typedef] = ACTIONS(2146),
    [anon_sym_in] = ACTIONS(2146),
    [anon_sym_out] = ACTIONS(2146),
    [anon_sym_inout] = ACTIONS(2146),
    [anon_sym_extern] = ACTIONS(2146),
    [anon_sym___attribute__] = ACTIONS(2146),
    [anon_sym_COLON_COLON] = ACTIONS(2148),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2148),
    [anon_sym___declspec] = ACTIONS(2146),
    [anon_sym___based] = ACTIONS(2146),
    [anon_sym___cdecl] = ACTIONS(2146),
    [anon_sym___clrcall] = ACTIONS(2146),
    [anon_sym___stdcall] = ACTIONS(2146),
    [anon_sym___fastcall] = ACTIONS(2146),
    [anon_sym___thiscall] = ACTIONS(2146),
    [anon_sym___vectorcall] = ACTIONS(2146),
    [anon_sym_LBRACE] = ACTIONS(2148),
    [anon_sym_RBRACE] = ACTIONS(2148),
    [anon_sym_signed] = ACTIONS(2146),
    [anon_sym_unsigned] = ACTIONS(2146),
    [anon_sym_long] = ACTIONS(2146),
    [anon_sym_short] = ACTIONS(2146),
    [anon_sym_LBRACK] = ACTIONS(2146),
    [anon_sym_static] = ACTIONS(2146),
    [anon_sym_register] = ACTIONS(2146),
    [anon_sym_inline] = ACTIONS(2146),
    [anon_sym___inline] = ACTIONS(2146),
    [anon_sym___inline__] = ACTIONS(2146),
    [anon_sym___forceinline] = ACTIONS(2146),
    [anon_sym_thread_local] = ACTIONS(2146),
    [anon_sym___thread] = ACTIONS(2146),
    [anon_sym_const] = ACTIONS(2146),
    [anon_sym_constexpr] = ACTIONS(2146),
    [anon_sym_volatile] = ACTIONS(2146),
    [anon_sym_restrict] = ACTIONS(2146),
    [anon_sym___restrict__] = ACTIONS(2146),
    [anon_sym__Atomic] = ACTIONS(2146),
    [anon_sym__Noreturn] = ACTIONS(2146),
    [anon_sym_noreturn] = ACTIONS(2146),
    [anon_sym_mutable] = ACTIONS(2146),
    [anon_sym_constinit] = ACTIONS(2146),
    [anon_sym_consteval] = ACTIONS(2146),
    [anon_sym_alignas] = ACTIONS(2146),
    [anon_sym__Alignas] = ACTIONS(2146),
    [sym_primitive_type] = ACTIONS(2146),
    [anon_sym_enum] = ACTIONS(2146),
    [anon_sym_class] = ACTIONS(2146),
    [anon_sym_struct] = ACTIONS(2146),
    [anon_sym_union] = ACTIONS(2146),
    [anon_sym_if] = ACTIONS(2146),
    [anon_sym_else] = ACTIONS(2146),
    [anon_sym_switch] = ACTIONS(2146),
    [anon_sym_case] = ACTIONS(2146),
    [anon_sym_default] = ACTIONS(2146),
    [anon_sym_while] = ACTIONS(2146),
    [anon_sym_do] = ACTIONS(2146),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_return] = ACTIONS(2146),
    [anon_sym_break] = ACTIONS(2146),
    [anon_sym_continue] = ACTIONS(2146),
    [anon_sym_goto] = ACTIONS(2146),
    [anon_sym___try] = ACTIONS(2146),
    [anon_sym___leave] = ACTIONS(2146),
    [anon_sym_not] = ACTIONS(2146),
    [anon_sym_compl] = ACTIONS(2146),
    [anon_sym_DASH_DASH] = ACTIONS(2148),
    [anon_sym_PLUS_PLUS] = ACTIONS(2148),
    [anon_sym_sizeof] = ACTIONS(2146),
    [anon_sym___alignof__] = ACTIONS(2146),
    [anon_sym___alignof] = ACTIONS(2146),
    [anon_sym__alignof] = ACTIONS(2146),
    [anon_sym_alignof] = ACTIONS(2146),
    [anon_sym__Alignof] = ACTIONS(2146),
    [anon_sym_offsetof] = ACTIONS(2146),
    [anon_sym__Generic] = ACTIONS(2146),
    [anon_sym_asm] = ACTIONS(2146),
    [anon_sym___asm__] = ACTIONS(2146),
    [sym_number_literal] = ACTIONS(2148),
    [anon_sym_L_SQUOTE] = ACTIONS(2148),
    [anon_sym_u_SQUOTE] = ACTIONS(2148),
    [anon_sym_U_SQUOTE] = ACTIONS(2148),
    [anon_sym_u8_SQUOTE] = ACTIONS(2148),
    [anon_sym_SQUOTE] = ACTIONS(2148),
    [anon_sym_L_DQUOTE] = ACTIONS(2148),
    [anon_sym_u_DQUOTE] = ACTIONS(2148),
    [anon_sym_U_DQUOTE] = ACTIONS(2148),
    [anon_sym_u8_DQUOTE] = ACTIONS(2148),
    [anon_sym_DQUOTE] = ACTIONS(2148),
    [sym_true] = ACTIONS(2146),
    [sym_false] = ACTIONS(2146),
    [anon_sym_NULL] = ACTIONS(2146),
    [anon_sym_nullptr] = ACTIONS(2146),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2146),
    [anon_sym_decltype] = ACTIONS(2146),
    [sym_virtual] = ACTIONS(2146),
    [anon_sym_explicit] = ACTIONS(2146),
    [anon_sym_typename] = ACTIONS(2146),
    [anon_sym_template] = ACTIONS(2146),
    [anon_sym_operator] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2146),
    [anon_sym_delete] = ACTIONS(2146),
    [anon_sym_throw] = ACTIONS(2146),
    [anon_sym_namespace] = ACTIONS(2146),
    [anon_sym_using] = ACTIONS(2146),
    [anon_sym_static_assert] = ACTIONS(2146),
    [anon_sym_concept] = ACTIONS(2146),
    [anon_sym_co_return] = ACTIONS(2146),
    [anon_sym_co_yield] = ACTIONS(2146),
    [anon_sym_R_DQUOTE] = ACTIONS(2148),
    [anon_sym_LR_DQUOTE] = ACTIONS(2148),
    [anon_sym_uR_DQUOTE] = ACTIONS(2148),
    [anon_sym_UR_DQUOTE] = ACTIONS(2148),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2148),
    [anon_sym_co_await] = ACTIONS(2146),
    [anon_sym_new] = ACTIONS(2146),
    [anon_sym_requires] = ACTIONS(2146),
    [sym_this] = ACTIONS(2146),
    [anon_sym_discard] = ACTIONS(2146),
    [anon_sym_precise] = ACTIONS(2146),
    [anon_sym_shared] = ACTIONS(2146),
    [anon_sym_groupshared] = ACTIONS(2146),
    [anon_sym_uniform] = ACTIONS(2146),
    [anon_sym_row_major] = ACTIONS(2146),
    [anon_sym_column_major] = ACTIONS(2146),
    [anon_sym_globallycoherent] = ACTIONS(2146),
    [anon_sym_centroid] = ACTIONS(2146),
    [anon_sym_noperspective] = ACTIONS(2146),
    [anon_sym_nointerpolation] = ACTIONS(2146),
    [anon_sym_sample] = ACTIONS(2146),
    [anon_sym_linear] = ACTIONS(2146),
    [anon_sym_snorm] = ACTIONS(2146),
    [anon_sym_unorm] = ACTIONS(2146),
    [anon_sym_point] = ACTIONS(2146),
    [anon_sym_line] = ACTIONS(2146),
    [anon_sym_triangleadj] = ACTIONS(2146),
    [anon_sym_lineadj] = ACTIONS(2146),
    [anon_sym_triangle] = ACTIONS(2146),
    [anon_sym_cbuffer] = ACTIONS(2146),
  },
  [412] = {
    [sym_identifier] = ACTIONS(2220),
    [aux_sym_preproc_include_token1] = ACTIONS(2220),
    [aux_sym_preproc_def_token1] = ACTIONS(2220),
    [aux_sym_preproc_if_token1] = ACTIONS(2220),
    [aux_sym_preproc_if_token2] = ACTIONS(2220),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2220),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2220),
    [sym_preproc_directive] = ACTIONS(2220),
    [anon_sym_LPAREN2] = ACTIONS(2222),
    [anon_sym_BANG] = ACTIONS(2222),
    [anon_sym_TILDE] = ACTIONS(2222),
    [anon_sym_DASH] = ACTIONS(2220),
    [anon_sym_PLUS] = ACTIONS(2220),
    [anon_sym_STAR] = ACTIONS(2222),
    [anon_sym_AMP_AMP] = ACTIONS(2222),
    [anon_sym_AMP] = ACTIONS(2220),
    [anon_sym_SEMI] = ACTIONS(2222),
    [anon_sym___extension__] = ACTIONS(2220),
    [anon_sym_typedef] = ACTIONS(2220),
    [anon_sym_in] = ACTIONS(2220),
    [anon_sym_out] = ACTIONS(2220),
    [anon_sym_inout] = ACTIONS(2220),
    [anon_sym_extern] = ACTIONS(2220),
    [anon_sym___attribute__] = ACTIONS(2220),
    [anon_sym_COLON_COLON] = ACTIONS(2222),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2222),
    [anon_sym___declspec] = ACTIONS(2220),
    [anon_sym___based] = ACTIONS(2220),
    [anon_sym___cdecl] = ACTIONS(2220),
    [anon_sym___clrcall] = ACTIONS(2220),
    [anon_sym___stdcall] = ACTIONS(2220),
    [anon_sym___fastcall] = ACTIONS(2220),
    [anon_sym___thiscall] = ACTIONS(2220),
    [anon_sym___vectorcall] = ACTIONS(2220),
    [anon_sym_LBRACE] = ACTIONS(2222),
    [anon_sym_signed] = ACTIONS(2220),
    [anon_sym_unsigned] = ACTIONS(2220),
    [anon_sym_long] = ACTIONS(2220),
    [anon_sym_short] = ACTIONS(2220),
    [anon_sym_LBRACK] = ACTIONS(2220),
    [anon_sym_static] = ACTIONS(2220),
    [anon_sym_register] = ACTIONS(2220),
    [anon_sym_inline] = ACTIONS(2220),
    [anon_sym___inline] = ACTIONS(2220),
    [anon_sym___inline__] = ACTIONS(2220),
    [anon_sym___forceinline] = ACTIONS(2220),
    [anon_sym_thread_local] = ACTIONS(2220),
    [anon_sym___thread] = ACTIONS(2220),
    [anon_sym_const] = ACTIONS(2220),
    [anon_sym_constexpr] = ACTIONS(2220),
    [anon_sym_volatile] = ACTIONS(2220),
    [anon_sym_restrict] = ACTIONS(2220),
    [anon_sym___restrict__] = ACTIONS(2220),
    [anon_sym__Atomic] = ACTIONS(2220),
    [anon_sym__Noreturn] = ACTIONS(2220),
    [anon_sym_noreturn] = ACTIONS(2220),
    [anon_sym_mutable] = ACTIONS(2220),
    [anon_sym_constinit] = ACTIONS(2220),
    [anon_sym_consteval] = ACTIONS(2220),
    [anon_sym_alignas] = ACTIONS(2220),
    [anon_sym__Alignas] = ACTIONS(2220),
    [sym_primitive_type] = ACTIONS(2220),
    [anon_sym_enum] = ACTIONS(2220),
    [anon_sym_class] = ACTIONS(2220),
    [anon_sym_struct] = ACTIONS(2220),
    [anon_sym_union] = ACTIONS(2220),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_else] = ACTIONS(2220),
    [anon_sym_switch] = ACTIONS(2220),
    [anon_sym_case] = ACTIONS(2220),
    [anon_sym_default] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2220),
    [anon_sym_do] = ACTIONS(2220),
    [anon_sym_for] = ACTIONS(2220),
    [anon_sym_return] = ACTIONS(2220),
    [anon_sym_break] = ACTIONS(2220),
    [anon_sym_continue] = ACTIONS(2220),
    [anon_sym_goto] = ACTIONS(2220),
    [anon_sym___try] = ACTIONS(2220),
    [anon_sym___leave] = ACTIONS(2220),
    [anon_sym_not] = ACTIONS(2220),
    [anon_sym_compl] = ACTIONS(2220),
    [anon_sym_DASH_DASH] = ACTIONS(2222),
    [anon_sym_PLUS_PLUS] = ACTIONS(2222),
    [anon_sym_sizeof] = ACTIONS(2220),
    [anon_sym___alignof__] = ACTIONS(2220),
    [anon_sym___alignof] = ACTIONS(2220),
    [anon_sym__alignof] = ACTIONS(2220),
    [anon_sym_alignof] = ACTIONS(2220),
    [anon_sym__Alignof] = ACTIONS(2220),
    [anon_sym_offsetof] = ACTIONS(2220),
    [anon_sym__Generic] = ACTIONS(2220),
    [anon_sym_asm] = ACTIONS(2220),
    [anon_sym___asm__] = ACTIONS(2220),
    [sym_number_literal] = ACTIONS(2222),
    [anon_sym_L_SQUOTE] = ACTIONS(2222),
    [anon_sym_u_SQUOTE] = ACTIONS(2222),
    [anon_sym_U_SQUOTE] = ACTIONS(2222),
    [anon_sym_u8_SQUOTE] = ACTIONS(2222),
    [anon_sym_SQUOTE] = ACTIONS(2222),
    [anon_sym_L_DQUOTE] = ACTIONS(2222),
    [anon_sym_u_DQUOTE] = ACTIONS(2222),
    [anon_sym_U_DQUOTE] = ACTIONS(2222),
    [anon_sym_u8_DQUOTE] = ACTIONS(2222),
    [anon_sym_DQUOTE] = ACTIONS(2222),
    [sym_true] = ACTIONS(2220),
    [sym_false] = ACTIONS(2220),
    [anon_sym_NULL] = ACTIONS(2220),
    [anon_sym_nullptr] = ACTIONS(2220),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2220),
    [anon_sym_decltype] = ACTIONS(2220),
    [sym_virtual] = ACTIONS(2220),
    [anon_sym_explicit] = ACTIONS(2220),
    [anon_sym_typename] = ACTIONS(2220),
    [anon_sym_template] = ACTIONS(2220),
    [anon_sym_operator] = ACTIONS(2220),
    [anon_sym_try] = ACTIONS(2220),
    [anon_sym_delete] = ACTIONS(2220),
    [anon_sym_throw] = ACTIONS(2220),
    [anon_sym_namespace] = ACTIONS(2220),
    [anon_sym_using] = ACTIONS(2220),
    [anon_sym_static_assert] = ACTIONS(2220),
    [anon_sym_concept] = ACTIONS(2220),
    [anon_sym_co_return] = ACTIONS(2220),
    [anon_sym_co_yield] = ACTIONS(2220),
    [anon_sym_R_DQUOTE] = ACTIONS(2222),
    [anon_sym_LR_DQUOTE] = ACTIONS(2222),
    [anon_sym_uR_DQUOTE] = ACTIONS(2222),
    [anon_sym_UR_DQUOTE] = ACTIONS(2222),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2222),
    [anon_sym_co_await] = ACTIONS(2220),
    [anon_sym_new] = ACTIONS(2220),
    [anon_sym_requires] = ACTIONS(2220),
    [sym_this] = ACTIONS(2220),
    [anon_sym_discard] = ACTIONS(2220),
    [anon_sym_precise] = ACTIONS(2220),
    [anon_sym_shared] = ACTIONS(2220),
    [anon_sym_groupshared] = ACTIONS(2220),
    [anon_sym_uniform] = ACTIONS(2220),
    [anon_sym_row_major] = ACTIONS(2220),
    [anon_sym_column_major] = ACTIONS(2220),
    [anon_sym_globallycoherent] = ACTIONS(2220),
    [anon_sym_centroid] = ACTIONS(2220),
    [anon_sym_noperspective] = ACTIONS(2220),
    [anon_sym_nointerpolation] = ACTIONS(2220),
    [anon_sym_sample] = ACTIONS(2220),
    [anon_sym_linear] = ACTIONS(2220),
    [anon_sym_snorm] = ACTIONS(2220),
    [anon_sym_unorm] = ACTIONS(2220),
    [anon_sym_point] = ACTIONS(2220),
    [anon_sym_line] = ACTIONS(2220),
    [anon_sym_triangleadj] = ACTIONS(2220),
    [anon_sym_lineadj] = ACTIONS(2220),
    [anon_sym_triangle] = ACTIONS(2220),
    [anon_sym_cbuffer] = ACTIONS(2220),
  },
  [413] = {
    [sym_identifier] = ACTIONS(2190),
    [aux_sym_preproc_include_token1] = ACTIONS(2190),
    [aux_sym_preproc_def_token1] = ACTIONS(2190),
    [aux_sym_preproc_if_token1] = ACTIONS(2190),
    [aux_sym_preproc_if_token2] = ACTIONS(2190),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2190),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2190),
    [sym_preproc_directive] = ACTIONS(2190),
    [anon_sym_LPAREN2] = ACTIONS(2192),
    [anon_sym_BANG] = ACTIONS(2192),
    [anon_sym_TILDE] = ACTIONS(2192),
    [anon_sym_DASH] = ACTIONS(2190),
    [anon_sym_PLUS] = ACTIONS(2190),
    [anon_sym_STAR] = ACTIONS(2192),
    [anon_sym_AMP_AMP] = ACTIONS(2192),
    [anon_sym_AMP] = ACTIONS(2190),
    [anon_sym_SEMI] = ACTIONS(2192),
    [anon_sym___extension__] = ACTIONS(2190),
    [anon_sym_typedef] = ACTIONS(2190),
    [anon_sym_in] = ACTIONS(2190),
    [anon_sym_out] = ACTIONS(2190),
    [anon_sym_inout] = ACTIONS(2190),
    [anon_sym_extern] = ACTIONS(2190),
    [anon_sym___attribute__] = ACTIONS(2190),
    [anon_sym_COLON_COLON] = ACTIONS(2192),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2192),
    [anon_sym___declspec] = ACTIONS(2190),
    [anon_sym___based] = ACTIONS(2190),
    [anon_sym___cdecl] = ACTIONS(2190),
    [anon_sym___clrcall] = ACTIONS(2190),
    [anon_sym___stdcall] = ACTIONS(2190),
    [anon_sym___fastcall] = ACTIONS(2190),
    [anon_sym___thiscall] = ACTIONS(2190),
    [anon_sym___vectorcall] = ACTIONS(2190),
    [anon_sym_LBRACE] = ACTIONS(2192),
    [anon_sym_signed] = ACTIONS(2190),
    [anon_sym_unsigned] = ACTIONS(2190),
    [anon_sym_long] = ACTIONS(2190),
    [anon_sym_short] = ACTIONS(2190),
    [anon_sym_LBRACK] = ACTIONS(2190),
    [anon_sym_static] = ACTIONS(2190),
    [anon_sym_register] = ACTIONS(2190),
    [anon_sym_inline] = ACTIONS(2190),
    [anon_sym___inline] = ACTIONS(2190),
    [anon_sym___inline__] = ACTIONS(2190),
    [anon_sym___forceinline] = ACTIONS(2190),
    [anon_sym_thread_local] = ACTIONS(2190),
    [anon_sym___thread] = ACTIONS(2190),
    [anon_sym_const] = ACTIONS(2190),
    [anon_sym_constexpr] = ACTIONS(2190),
    [anon_sym_volatile] = ACTIONS(2190),
    [anon_sym_restrict] = ACTIONS(2190),
    [anon_sym___restrict__] = ACTIONS(2190),
    [anon_sym__Atomic] = ACTIONS(2190),
    [anon_sym__Noreturn] = ACTIONS(2190),
    [anon_sym_noreturn] = ACTIONS(2190),
    [anon_sym_mutable] = ACTIONS(2190),
    [anon_sym_constinit] = ACTIONS(2190),
    [anon_sym_consteval] = ACTIONS(2190),
    [anon_sym_alignas] = ACTIONS(2190),
    [anon_sym__Alignas] = ACTIONS(2190),
    [sym_primitive_type] = ACTIONS(2190),
    [anon_sym_enum] = ACTIONS(2190),
    [anon_sym_class] = ACTIONS(2190),
    [anon_sym_struct] = ACTIONS(2190),
    [anon_sym_union] = ACTIONS(2190),
    [anon_sym_if] = ACTIONS(2190),
    [anon_sym_else] = ACTIONS(2190),
    [anon_sym_switch] = ACTIONS(2190),
    [anon_sym_case] = ACTIONS(2190),
    [anon_sym_default] = ACTIONS(2190),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_do] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2190),
    [anon_sym_return] = ACTIONS(2190),
    [anon_sym_break] = ACTIONS(2190),
    [anon_sym_continue] = ACTIONS(2190),
    [anon_sym_goto] = ACTIONS(2190),
    [anon_sym___try] = ACTIONS(2190),
    [anon_sym___leave] = ACTIONS(2190),
    [anon_sym_not] = ACTIONS(2190),
    [anon_sym_compl] = ACTIONS(2190),
    [anon_sym_DASH_DASH] = ACTIONS(2192),
    [anon_sym_PLUS_PLUS] = ACTIONS(2192),
    [anon_sym_sizeof] = ACTIONS(2190),
    [anon_sym___alignof__] = ACTIONS(2190),
    [anon_sym___alignof] = ACTIONS(2190),
    [anon_sym__alignof] = ACTIONS(2190),
    [anon_sym_alignof] = ACTIONS(2190),
    [anon_sym__Alignof] = ACTIONS(2190),
    [anon_sym_offsetof] = ACTIONS(2190),
    [anon_sym__Generic] = ACTIONS(2190),
    [anon_sym_asm] = ACTIONS(2190),
    [anon_sym___asm__] = ACTIONS(2190),
    [sym_number_literal] = ACTIONS(2192),
    [anon_sym_L_SQUOTE] = ACTIONS(2192),
    [anon_sym_u_SQUOTE] = ACTIONS(2192),
    [anon_sym_U_SQUOTE] = ACTIONS(2192),
    [anon_sym_u8_SQUOTE] = ACTIONS(2192),
    [anon_sym_SQUOTE] = ACTIONS(2192),
    [anon_sym_L_DQUOTE] = ACTIONS(2192),
    [anon_sym_u_DQUOTE] = ACTIONS(2192),
    [anon_sym_U_DQUOTE] = ACTIONS(2192),
    [anon_sym_u8_DQUOTE] = ACTIONS(2192),
    [anon_sym_DQUOTE] = ACTIONS(2192),
    [sym_true] = ACTIONS(2190),
    [sym_false] = ACTIONS(2190),
    [anon_sym_NULL] = ACTIONS(2190),
    [anon_sym_nullptr] = ACTIONS(2190),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2190),
    [anon_sym_decltype] = ACTIONS(2190),
    [sym_virtual] = ACTIONS(2190),
    [anon_sym_explicit] = ACTIONS(2190),
    [anon_sym_typename] = ACTIONS(2190),
    [anon_sym_template] = ACTIONS(2190),
    [anon_sym_operator] = ACTIONS(2190),
    [anon_sym_try] = ACTIONS(2190),
    [anon_sym_delete] = ACTIONS(2190),
    [anon_sym_throw] = ACTIONS(2190),
    [anon_sym_namespace] = ACTIONS(2190),
    [anon_sym_using] = ACTIONS(2190),
    [anon_sym_static_assert] = ACTIONS(2190),
    [anon_sym_concept] = ACTIONS(2190),
    [anon_sym_co_return] = ACTIONS(2190),
    [anon_sym_co_yield] = ACTIONS(2190),
    [anon_sym_R_DQUOTE] = ACTIONS(2192),
    [anon_sym_LR_DQUOTE] = ACTIONS(2192),
    [anon_sym_uR_DQUOTE] = ACTIONS(2192),
    [anon_sym_UR_DQUOTE] = ACTIONS(2192),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2192),
    [anon_sym_co_await] = ACTIONS(2190),
    [anon_sym_new] = ACTIONS(2190),
    [anon_sym_requires] = ACTIONS(2190),
    [sym_this] = ACTIONS(2190),
    [anon_sym_discard] = ACTIONS(2190),
    [anon_sym_precise] = ACTIONS(2190),
    [anon_sym_shared] = ACTIONS(2190),
    [anon_sym_groupshared] = ACTIONS(2190),
    [anon_sym_uniform] = ACTIONS(2190),
    [anon_sym_row_major] = ACTIONS(2190),
    [anon_sym_column_major] = ACTIONS(2190),
    [anon_sym_globallycoherent] = ACTIONS(2190),
    [anon_sym_centroid] = ACTIONS(2190),
    [anon_sym_noperspective] = ACTIONS(2190),
    [anon_sym_nointerpolation] = ACTIONS(2190),
    [anon_sym_sample] = ACTIONS(2190),
    [anon_sym_linear] = ACTIONS(2190),
    [anon_sym_snorm] = ACTIONS(2190),
    [anon_sym_unorm] = ACTIONS(2190),
    [anon_sym_point] = ACTIONS(2190),
    [anon_sym_line] = ACTIONS(2190),
    [anon_sym_triangleadj] = ACTIONS(2190),
    [anon_sym_lineadj] = ACTIONS(2190),
    [anon_sym_triangle] = ACTIONS(2190),
    [anon_sym_cbuffer] = ACTIONS(2190),
  },
  [414] = {
    [sym_identifier] = ACTIONS(2186),
    [aux_sym_preproc_include_token1] = ACTIONS(2186),
    [aux_sym_preproc_def_token1] = ACTIONS(2186),
    [aux_sym_preproc_if_token1] = ACTIONS(2186),
    [aux_sym_preproc_if_token2] = ACTIONS(2186),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2186),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2186),
    [sym_preproc_directive] = ACTIONS(2186),
    [anon_sym_LPAREN2] = ACTIONS(2188),
    [anon_sym_BANG] = ACTIONS(2188),
    [anon_sym_TILDE] = ACTIONS(2188),
    [anon_sym_DASH] = ACTIONS(2186),
    [anon_sym_PLUS] = ACTIONS(2186),
    [anon_sym_STAR] = ACTIONS(2188),
    [anon_sym_AMP_AMP] = ACTIONS(2188),
    [anon_sym_AMP] = ACTIONS(2186),
    [anon_sym_SEMI] = ACTIONS(2188),
    [anon_sym___extension__] = ACTIONS(2186),
    [anon_sym_typedef] = ACTIONS(2186),
    [anon_sym_in] = ACTIONS(2186),
    [anon_sym_out] = ACTIONS(2186),
    [anon_sym_inout] = ACTIONS(2186),
    [anon_sym_extern] = ACTIONS(2186),
    [anon_sym___attribute__] = ACTIONS(2186),
    [anon_sym_COLON_COLON] = ACTIONS(2188),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2188),
    [anon_sym___declspec] = ACTIONS(2186),
    [anon_sym___based] = ACTIONS(2186),
    [anon_sym___cdecl] = ACTIONS(2186),
    [anon_sym___clrcall] = ACTIONS(2186),
    [anon_sym___stdcall] = ACTIONS(2186),
    [anon_sym___fastcall] = ACTIONS(2186),
    [anon_sym___thiscall] = ACTIONS(2186),
    [anon_sym___vectorcall] = ACTIONS(2186),
    [anon_sym_LBRACE] = ACTIONS(2188),
    [anon_sym_signed] = ACTIONS(2186),
    [anon_sym_unsigned] = ACTIONS(2186),
    [anon_sym_long] = ACTIONS(2186),
    [anon_sym_short] = ACTIONS(2186),
    [anon_sym_LBRACK] = ACTIONS(2186),
    [anon_sym_static] = ACTIONS(2186),
    [anon_sym_register] = ACTIONS(2186),
    [anon_sym_inline] = ACTIONS(2186),
    [anon_sym___inline] = ACTIONS(2186),
    [anon_sym___inline__] = ACTIONS(2186),
    [anon_sym___forceinline] = ACTIONS(2186),
    [anon_sym_thread_local] = ACTIONS(2186),
    [anon_sym___thread] = ACTIONS(2186),
    [anon_sym_const] = ACTIONS(2186),
    [anon_sym_constexpr] = ACTIONS(2186),
    [anon_sym_volatile] = ACTIONS(2186),
    [anon_sym_restrict] = ACTIONS(2186),
    [anon_sym___restrict__] = ACTIONS(2186),
    [anon_sym__Atomic] = ACTIONS(2186),
    [anon_sym__Noreturn] = ACTIONS(2186),
    [anon_sym_noreturn] = ACTIONS(2186),
    [anon_sym_mutable] = ACTIONS(2186),
    [anon_sym_constinit] = ACTIONS(2186),
    [anon_sym_consteval] = ACTIONS(2186),
    [anon_sym_alignas] = ACTIONS(2186),
    [anon_sym__Alignas] = ACTIONS(2186),
    [sym_primitive_type] = ACTIONS(2186),
    [anon_sym_enum] = ACTIONS(2186),
    [anon_sym_class] = ACTIONS(2186),
    [anon_sym_struct] = ACTIONS(2186),
    [anon_sym_union] = ACTIONS(2186),
    [anon_sym_if] = ACTIONS(2186),
    [anon_sym_else] = ACTIONS(2186),
    [anon_sym_switch] = ACTIONS(2186),
    [anon_sym_case] = ACTIONS(2186),
    [anon_sym_default] = ACTIONS(2186),
    [anon_sym_while] = ACTIONS(2186),
    [anon_sym_do] = ACTIONS(2186),
    [anon_sym_for] = ACTIONS(2186),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_break] = ACTIONS(2186),
    [anon_sym_continue] = ACTIONS(2186),
    [anon_sym_goto] = ACTIONS(2186),
    [anon_sym___try] = ACTIONS(2186),
    [anon_sym___leave] = ACTIONS(2186),
    [anon_sym_not] = ACTIONS(2186),
    [anon_sym_compl] = ACTIONS(2186),
    [anon_sym_DASH_DASH] = ACTIONS(2188),
    [anon_sym_PLUS_PLUS] = ACTIONS(2188),
    [anon_sym_sizeof] = ACTIONS(2186),
    [anon_sym___alignof__] = ACTIONS(2186),
    [anon_sym___alignof] = ACTIONS(2186),
    [anon_sym__alignof] = ACTIONS(2186),
    [anon_sym_alignof] = ACTIONS(2186),
    [anon_sym__Alignof] = ACTIONS(2186),
    [anon_sym_offsetof] = ACTIONS(2186),
    [anon_sym__Generic] = ACTIONS(2186),
    [anon_sym_asm] = ACTIONS(2186),
    [anon_sym___asm__] = ACTIONS(2186),
    [sym_number_literal] = ACTIONS(2188),
    [anon_sym_L_SQUOTE] = ACTIONS(2188),
    [anon_sym_u_SQUOTE] = ACTIONS(2188),
    [anon_sym_U_SQUOTE] = ACTIONS(2188),
    [anon_sym_u8_SQUOTE] = ACTIONS(2188),
    [anon_sym_SQUOTE] = ACTIONS(2188),
    [anon_sym_L_DQUOTE] = ACTIONS(2188),
    [anon_sym_u_DQUOTE] = ACTIONS(2188),
    [anon_sym_U_DQUOTE] = ACTIONS(2188),
    [anon_sym_u8_DQUOTE] = ACTIONS(2188),
    [anon_sym_DQUOTE] = ACTIONS(2188),
    [sym_true] = ACTIONS(2186),
    [sym_false] = ACTIONS(2186),
    [anon_sym_NULL] = ACTIONS(2186),
    [anon_sym_nullptr] = ACTIONS(2186),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2186),
    [anon_sym_decltype] = ACTIONS(2186),
    [sym_virtual] = ACTIONS(2186),
    [anon_sym_explicit] = ACTIONS(2186),
    [anon_sym_typename] = ACTIONS(2186),
    [anon_sym_template] = ACTIONS(2186),
    [anon_sym_operator] = ACTIONS(2186),
    [anon_sym_try] = ACTIONS(2186),
    [anon_sym_delete] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2186),
    [anon_sym_namespace] = ACTIONS(2186),
    [anon_sym_using] = ACTIONS(2186),
    [anon_sym_static_assert] = ACTIONS(2186),
    [anon_sym_concept] = ACTIONS(2186),
    [anon_sym_co_return] = ACTIONS(2186),
    [anon_sym_co_yield] = ACTIONS(2186),
    [anon_sym_R_DQUOTE] = ACTIONS(2188),
    [anon_sym_LR_DQUOTE] = ACTIONS(2188),
    [anon_sym_uR_DQUOTE] = ACTIONS(2188),
    [anon_sym_UR_DQUOTE] = ACTIONS(2188),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2188),
    [anon_sym_co_await] = ACTIONS(2186),
    [anon_sym_new] = ACTIONS(2186),
    [anon_sym_requires] = ACTIONS(2186),
    [sym_this] = ACTIONS(2186),
    [anon_sym_discard] = ACTIONS(2186),
    [anon_sym_precise] = ACTIONS(2186),
    [anon_sym_shared] = ACTIONS(2186),
    [anon_sym_groupshared] = ACTIONS(2186),
    [anon_sym_uniform] = ACTIONS(2186),
    [anon_sym_row_major] = ACTIONS(2186),
    [anon_sym_column_major] = ACTIONS(2186),
    [anon_sym_globallycoherent] = ACTIONS(2186),
    [anon_sym_centroid] = ACTIONS(2186),
    [anon_sym_noperspective] = ACTIONS(2186),
    [anon_sym_nointerpolation] = ACTIONS(2186),
    [anon_sym_sample] = ACTIONS(2186),
    [anon_sym_linear] = ACTIONS(2186),
    [anon_sym_snorm] = ACTIONS(2186),
    [anon_sym_unorm] = ACTIONS(2186),
    [anon_sym_point] = ACTIONS(2186),
    [anon_sym_line] = ACTIONS(2186),
    [anon_sym_triangleadj] = ACTIONS(2186),
    [anon_sym_lineadj] = ACTIONS(2186),
    [anon_sym_triangle] = ACTIONS(2186),
    [anon_sym_cbuffer] = ACTIONS(2186),
  },
  [415] = {
    [ts_builtin_sym_end] = ACTIONS(2140),
    [sym_identifier] = ACTIONS(2138),
    [aux_sym_preproc_include_token1] = ACTIONS(2138),
    [aux_sym_preproc_def_token1] = ACTIONS(2138),
    [aux_sym_preproc_if_token1] = ACTIONS(2138),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2138),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2138),
    [sym_preproc_directive] = ACTIONS(2138),
    [anon_sym_LPAREN2] = ACTIONS(2140),
    [anon_sym_BANG] = ACTIONS(2140),
    [anon_sym_TILDE] = ACTIONS(2140),
    [anon_sym_DASH] = ACTIONS(2138),
    [anon_sym_PLUS] = ACTIONS(2138),
    [anon_sym_STAR] = ACTIONS(2140),
    [anon_sym_AMP_AMP] = ACTIONS(2140),
    [anon_sym_AMP] = ACTIONS(2138),
    [anon_sym_SEMI] = ACTIONS(2140),
    [anon_sym___extension__] = ACTIONS(2138),
    [anon_sym_typedef] = ACTIONS(2138),
    [anon_sym_in] = ACTIONS(2138),
    [anon_sym_out] = ACTIONS(2138),
    [anon_sym_inout] = ACTIONS(2138),
    [anon_sym_extern] = ACTIONS(2138),
    [anon_sym___attribute__] = ACTIONS(2138),
    [anon_sym_COLON_COLON] = ACTIONS(2140),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2140),
    [anon_sym___declspec] = ACTIONS(2138),
    [anon_sym___based] = ACTIONS(2138),
    [anon_sym___cdecl] = ACTIONS(2138),
    [anon_sym___clrcall] = ACTIONS(2138),
    [anon_sym___stdcall] = ACTIONS(2138),
    [anon_sym___fastcall] = ACTIONS(2138),
    [anon_sym___thiscall] = ACTIONS(2138),
    [anon_sym___vectorcall] = ACTIONS(2138),
    [anon_sym_LBRACE] = ACTIONS(2140),
    [anon_sym_signed] = ACTIONS(2138),
    [anon_sym_unsigned] = ACTIONS(2138),
    [anon_sym_long] = ACTIONS(2138),
    [anon_sym_short] = ACTIONS(2138),
    [anon_sym_LBRACK] = ACTIONS(2138),
    [anon_sym_static] = ACTIONS(2138),
    [anon_sym_register] = ACTIONS(2138),
    [anon_sym_inline] = ACTIONS(2138),
    [anon_sym___inline] = ACTIONS(2138),
    [anon_sym___inline__] = ACTIONS(2138),
    [anon_sym___forceinline] = ACTIONS(2138),
    [anon_sym_thread_local] = ACTIONS(2138),
    [anon_sym___thread] = ACTIONS(2138),
    [anon_sym_const] = ACTIONS(2138),
    [anon_sym_constexpr] = ACTIONS(2138),
    [anon_sym_volatile] = ACTIONS(2138),
    [anon_sym_restrict] = ACTIONS(2138),
    [anon_sym___restrict__] = ACTIONS(2138),
    [anon_sym__Atomic] = ACTIONS(2138),
    [anon_sym__Noreturn] = ACTIONS(2138),
    [anon_sym_noreturn] = ACTIONS(2138),
    [anon_sym_mutable] = ACTIONS(2138),
    [anon_sym_constinit] = ACTIONS(2138),
    [anon_sym_consteval] = ACTIONS(2138),
    [anon_sym_alignas] = ACTIONS(2138),
    [anon_sym__Alignas] = ACTIONS(2138),
    [sym_primitive_type] = ACTIONS(2138),
    [anon_sym_enum] = ACTIONS(2138),
    [anon_sym_class] = ACTIONS(2138),
    [anon_sym_struct] = ACTIONS(2138),
    [anon_sym_union] = ACTIONS(2138),
    [anon_sym_if] = ACTIONS(2138),
    [anon_sym_else] = ACTIONS(2138),
    [anon_sym_switch] = ACTIONS(2138),
    [anon_sym_case] = ACTIONS(2138),
    [anon_sym_default] = ACTIONS(2138),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_do] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2138),
    [anon_sym_return] = ACTIONS(2138),
    [anon_sym_break] = ACTIONS(2138),
    [anon_sym_continue] = ACTIONS(2138),
    [anon_sym_goto] = ACTIONS(2138),
    [anon_sym___try] = ACTIONS(2138),
    [anon_sym___leave] = ACTIONS(2138),
    [anon_sym_not] = ACTIONS(2138),
    [anon_sym_compl] = ACTIONS(2138),
    [anon_sym_DASH_DASH] = ACTIONS(2140),
    [anon_sym_PLUS_PLUS] = ACTIONS(2140),
    [anon_sym_sizeof] = ACTIONS(2138),
    [anon_sym___alignof__] = ACTIONS(2138),
    [anon_sym___alignof] = ACTIONS(2138),
    [anon_sym__alignof] = ACTIONS(2138),
    [anon_sym_alignof] = ACTIONS(2138),
    [anon_sym__Alignof] = ACTIONS(2138),
    [anon_sym_offsetof] = ACTIONS(2138),
    [anon_sym__Generic] = ACTIONS(2138),
    [anon_sym_asm] = ACTIONS(2138),
    [anon_sym___asm__] = ACTIONS(2138),
    [sym_number_literal] = ACTIONS(2140),
    [anon_sym_L_SQUOTE] = ACTIONS(2140),
    [anon_sym_u_SQUOTE] = ACTIONS(2140),
    [anon_sym_U_SQUOTE] = ACTIONS(2140),
    [anon_sym_u8_SQUOTE] = ACTIONS(2140),
    [anon_sym_SQUOTE] = ACTIONS(2140),
    [anon_sym_L_DQUOTE] = ACTIONS(2140),
    [anon_sym_u_DQUOTE] = ACTIONS(2140),
    [anon_sym_U_DQUOTE] = ACTIONS(2140),
    [anon_sym_u8_DQUOTE] = ACTIONS(2140),
    [anon_sym_DQUOTE] = ACTIONS(2140),
    [sym_true] = ACTIONS(2138),
    [sym_false] = ACTIONS(2138),
    [anon_sym_NULL] = ACTIONS(2138),
    [anon_sym_nullptr] = ACTIONS(2138),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2138),
    [anon_sym_decltype] = ACTIONS(2138),
    [sym_virtual] = ACTIONS(2138),
    [anon_sym_explicit] = ACTIONS(2138),
    [anon_sym_typename] = ACTIONS(2138),
    [anon_sym_template] = ACTIONS(2138),
    [anon_sym_operator] = ACTIONS(2138),
    [anon_sym_try] = ACTIONS(2138),
    [anon_sym_delete] = ACTIONS(2138),
    [anon_sym_throw] = ACTIONS(2138),
    [anon_sym_namespace] = ACTIONS(2138),
    [anon_sym_using] = ACTIONS(2138),
    [anon_sym_static_assert] = ACTIONS(2138),
    [anon_sym_concept] = ACTIONS(2138),
    [anon_sym_co_return] = ACTIONS(2138),
    [anon_sym_co_yield] = ACTIONS(2138),
    [anon_sym_R_DQUOTE] = ACTIONS(2140),
    [anon_sym_LR_DQUOTE] = ACTIONS(2140),
    [anon_sym_uR_DQUOTE] = ACTIONS(2140),
    [anon_sym_UR_DQUOTE] = ACTIONS(2140),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2140),
    [anon_sym_co_await] = ACTIONS(2138),
    [anon_sym_new] = ACTIONS(2138),
    [anon_sym_requires] = ACTIONS(2138),
    [sym_this] = ACTIONS(2138),
    [anon_sym_discard] = ACTIONS(2138),
    [anon_sym_precise] = ACTIONS(2138),
    [anon_sym_shared] = ACTIONS(2138),
    [anon_sym_groupshared] = ACTIONS(2138),
    [anon_sym_uniform] = ACTIONS(2138),
    [anon_sym_row_major] = ACTIONS(2138),
    [anon_sym_column_major] = ACTIONS(2138),
    [anon_sym_globallycoherent] = ACTIONS(2138),
    [anon_sym_centroid] = ACTIONS(2138),
    [anon_sym_noperspective] = ACTIONS(2138),
    [anon_sym_nointerpolation] = ACTIONS(2138),
    [anon_sym_sample] = ACTIONS(2138),
    [anon_sym_linear] = ACTIONS(2138),
    [anon_sym_snorm] = ACTIONS(2138),
    [anon_sym_unorm] = ACTIONS(2138),
    [anon_sym_point] = ACTIONS(2138),
    [anon_sym_line] = ACTIONS(2138),
    [anon_sym_triangleadj] = ACTIONS(2138),
    [anon_sym_lineadj] = ACTIONS(2138),
    [anon_sym_triangle] = ACTIONS(2138),
    [anon_sym_cbuffer] = ACTIONS(2138),
  },
  [416] = {
    [ts_builtin_sym_end] = ACTIONS(2096),
    [sym_identifier] = ACTIONS(2094),
    [aux_sym_preproc_include_token1] = ACTIONS(2094),
    [aux_sym_preproc_def_token1] = ACTIONS(2094),
    [aux_sym_preproc_if_token1] = ACTIONS(2094),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2094),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2094),
    [sym_preproc_directive] = ACTIONS(2094),
    [anon_sym_LPAREN2] = ACTIONS(2096),
    [anon_sym_BANG] = ACTIONS(2096),
    [anon_sym_TILDE] = ACTIONS(2096),
    [anon_sym_DASH] = ACTIONS(2094),
    [anon_sym_PLUS] = ACTIONS(2094),
    [anon_sym_STAR] = ACTIONS(2096),
    [anon_sym_AMP_AMP] = ACTIONS(2096),
    [anon_sym_AMP] = ACTIONS(2094),
    [anon_sym_SEMI] = ACTIONS(2096),
    [anon_sym___extension__] = ACTIONS(2094),
    [anon_sym_typedef] = ACTIONS(2094),
    [anon_sym_in] = ACTIONS(2094),
    [anon_sym_out] = ACTIONS(2094),
    [anon_sym_inout] = ACTIONS(2094),
    [anon_sym_extern] = ACTIONS(2094),
    [anon_sym___attribute__] = ACTIONS(2094),
    [anon_sym_COLON_COLON] = ACTIONS(2096),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2096),
    [anon_sym___declspec] = ACTIONS(2094),
    [anon_sym___based] = ACTIONS(2094),
    [anon_sym___cdecl] = ACTIONS(2094),
    [anon_sym___clrcall] = ACTIONS(2094),
    [anon_sym___stdcall] = ACTIONS(2094),
    [anon_sym___fastcall] = ACTIONS(2094),
    [anon_sym___thiscall] = ACTIONS(2094),
    [anon_sym___vectorcall] = ACTIONS(2094),
    [anon_sym_LBRACE] = ACTIONS(2096),
    [anon_sym_signed] = ACTIONS(2094),
    [anon_sym_unsigned] = ACTIONS(2094),
    [anon_sym_long] = ACTIONS(2094),
    [anon_sym_short] = ACTIONS(2094),
    [anon_sym_LBRACK] = ACTIONS(2094),
    [anon_sym_static] = ACTIONS(2094),
    [anon_sym_register] = ACTIONS(2094),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym___inline] = ACTIONS(2094),
    [anon_sym___inline__] = ACTIONS(2094),
    [anon_sym___forceinline] = ACTIONS(2094),
    [anon_sym_thread_local] = ACTIONS(2094),
    [anon_sym___thread] = ACTIONS(2094),
    [anon_sym_const] = ACTIONS(2094),
    [anon_sym_constexpr] = ACTIONS(2094),
    [anon_sym_volatile] = ACTIONS(2094),
    [anon_sym_restrict] = ACTIONS(2094),
    [anon_sym___restrict__] = ACTIONS(2094),
    [anon_sym__Atomic] = ACTIONS(2094),
    [anon_sym__Noreturn] = ACTIONS(2094),
    [anon_sym_noreturn] = ACTIONS(2094),
    [anon_sym_mutable] = ACTIONS(2094),
    [anon_sym_constinit] = ACTIONS(2094),
    [anon_sym_consteval] = ACTIONS(2094),
    [anon_sym_alignas] = ACTIONS(2094),
    [anon_sym__Alignas] = ACTIONS(2094),
    [sym_primitive_type] = ACTIONS(2094),
    [anon_sym_enum] = ACTIONS(2094),
    [anon_sym_class] = ACTIONS(2094),
    [anon_sym_struct] = ACTIONS(2094),
    [anon_sym_union] = ACTIONS(2094),
    [anon_sym_if] = ACTIONS(2094),
    [anon_sym_else] = ACTIONS(2094),
    [anon_sym_switch] = ACTIONS(2094),
    [anon_sym_case] = ACTIONS(2094),
    [anon_sym_default] = ACTIONS(2094),
    [anon_sym_while] = ACTIONS(2094),
    [anon_sym_do] = ACTIONS(2094),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_return] = ACTIONS(2094),
    [anon_sym_break] = ACTIONS(2094),
    [anon_sym_continue] = ACTIONS(2094),
    [anon_sym_goto] = ACTIONS(2094),
    [anon_sym___try] = ACTIONS(2094),
    [anon_sym___leave] = ACTIONS(2094),
    [anon_sym_not] = ACTIONS(2094),
    [anon_sym_compl] = ACTIONS(2094),
    [anon_sym_DASH_DASH] = ACTIONS(2096),
    [anon_sym_PLUS_PLUS] = ACTIONS(2096),
    [anon_sym_sizeof] = ACTIONS(2094),
    [anon_sym___alignof__] = ACTIONS(2094),
    [anon_sym___alignof] = ACTIONS(2094),
    [anon_sym__alignof] = ACTIONS(2094),
    [anon_sym_alignof] = ACTIONS(2094),
    [anon_sym__Alignof] = ACTIONS(2094),
    [anon_sym_offsetof] = ACTIONS(2094),
    [anon_sym__Generic] = ACTIONS(2094),
    [anon_sym_asm] = ACTIONS(2094),
    [anon_sym___asm__] = ACTIONS(2094),
    [sym_number_literal] = ACTIONS(2096),
    [anon_sym_L_SQUOTE] = ACTIONS(2096),
    [anon_sym_u_SQUOTE] = ACTIONS(2096),
    [anon_sym_U_SQUOTE] = ACTIONS(2096),
    [anon_sym_u8_SQUOTE] = ACTIONS(2096),
    [anon_sym_SQUOTE] = ACTIONS(2096),
    [anon_sym_L_DQUOTE] = ACTIONS(2096),
    [anon_sym_u_DQUOTE] = ACTIONS(2096),
    [anon_sym_U_DQUOTE] = ACTIONS(2096),
    [anon_sym_u8_DQUOTE] = ACTIONS(2096),
    [anon_sym_DQUOTE] = ACTIONS(2096),
    [sym_true] = ACTIONS(2094),
    [sym_false] = ACTIONS(2094),
    [anon_sym_NULL] = ACTIONS(2094),
    [anon_sym_nullptr] = ACTIONS(2094),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2094),
    [anon_sym_decltype] = ACTIONS(2094),
    [sym_virtual] = ACTIONS(2094),
    [anon_sym_explicit] = ACTIONS(2094),
    [anon_sym_typename] = ACTIONS(2094),
    [anon_sym_template] = ACTIONS(2094),
    [anon_sym_operator] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2094),
    [anon_sym_delete] = ACTIONS(2094),
    [anon_sym_throw] = ACTIONS(2094),
    [anon_sym_namespace] = ACTIONS(2094),
    [anon_sym_using] = ACTIONS(2094),
    [anon_sym_static_assert] = ACTIONS(2094),
    [anon_sym_concept] = ACTIONS(2094),
    [anon_sym_co_return] = ACTIONS(2094),
    [anon_sym_co_yield] = ACTIONS(2094),
    [anon_sym_R_DQUOTE] = ACTIONS(2096),
    [anon_sym_LR_DQUOTE] = ACTIONS(2096),
    [anon_sym_uR_DQUOTE] = ACTIONS(2096),
    [anon_sym_UR_DQUOTE] = ACTIONS(2096),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2096),
    [anon_sym_co_await] = ACTIONS(2094),
    [anon_sym_new] = ACTIONS(2094),
    [anon_sym_requires] = ACTIONS(2094),
    [sym_this] = ACTIONS(2094),
    [anon_sym_discard] = ACTIONS(2094),
    [anon_sym_precise] = ACTIONS(2094),
    [anon_sym_shared] = ACTIONS(2094),
    [anon_sym_groupshared] = ACTIONS(2094),
    [anon_sym_uniform] = ACTIONS(2094),
    [anon_sym_row_major] = ACTIONS(2094),
    [anon_sym_column_major] = ACTIONS(2094),
    [anon_sym_globallycoherent] = ACTIONS(2094),
    [anon_sym_centroid] = ACTIONS(2094),
    [anon_sym_noperspective] = ACTIONS(2094),
    [anon_sym_nointerpolation] = ACTIONS(2094),
    [anon_sym_sample] = ACTIONS(2094),
    [anon_sym_linear] = ACTIONS(2094),
    [anon_sym_snorm] = ACTIONS(2094),
    [anon_sym_unorm] = ACTIONS(2094),
    [anon_sym_point] = ACTIONS(2094),
    [anon_sym_line] = ACTIONS(2094),
    [anon_sym_triangleadj] = ACTIONS(2094),
    [anon_sym_lineadj] = ACTIONS(2094),
    [anon_sym_triangle] = ACTIONS(2094),
    [anon_sym_cbuffer] = ACTIONS(2094),
  },
  [417] = {
    [ts_builtin_sym_end] = ACTIONS(2136),
    [sym_identifier] = ACTIONS(2134),
    [aux_sym_preproc_include_token1] = ACTIONS(2134),
    [aux_sym_preproc_def_token1] = ACTIONS(2134),
    [aux_sym_preproc_if_token1] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2134),
    [sym_preproc_directive] = ACTIONS(2134),
    [anon_sym_LPAREN2] = ACTIONS(2136),
    [anon_sym_BANG] = ACTIONS(2136),
    [anon_sym_TILDE] = ACTIONS(2136),
    [anon_sym_DASH] = ACTIONS(2134),
    [anon_sym_PLUS] = ACTIONS(2134),
    [anon_sym_STAR] = ACTIONS(2136),
    [anon_sym_AMP_AMP] = ACTIONS(2136),
    [anon_sym_AMP] = ACTIONS(2134),
    [anon_sym_SEMI] = ACTIONS(2136),
    [anon_sym___extension__] = ACTIONS(2134),
    [anon_sym_typedef] = ACTIONS(2134),
    [anon_sym_in] = ACTIONS(2134),
    [anon_sym_out] = ACTIONS(2134),
    [anon_sym_inout] = ACTIONS(2134),
    [anon_sym_extern] = ACTIONS(2134),
    [anon_sym___attribute__] = ACTIONS(2134),
    [anon_sym_COLON_COLON] = ACTIONS(2136),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2136),
    [anon_sym___declspec] = ACTIONS(2134),
    [anon_sym___based] = ACTIONS(2134),
    [anon_sym___cdecl] = ACTIONS(2134),
    [anon_sym___clrcall] = ACTIONS(2134),
    [anon_sym___stdcall] = ACTIONS(2134),
    [anon_sym___fastcall] = ACTIONS(2134),
    [anon_sym___thiscall] = ACTIONS(2134),
    [anon_sym___vectorcall] = ACTIONS(2134),
    [anon_sym_LBRACE] = ACTIONS(2136),
    [anon_sym_signed] = ACTIONS(2134),
    [anon_sym_unsigned] = ACTIONS(2134),
    [anon_sym_long] = ACTIONS(2134),
    [anon_sym_short] = ACTIONS(2134),
    [anon_sym_LBRACK] = ACTIONS(2134),
    [anon_sym_static] = ACTIONS(2134),
    [anon_sym_register] = ACTIONS(2134),
    [anon_sym_inline] = ACTIONS(2134),
    [anon_sym___inline] = ACTIONS(2134),
    [anon_sym___inline__] = ACTIONS(2134),
    [anon_sym___forceinline] = ACTIONS(2134),
    [anon_sym_thread_local] = ACTIONS(2134),
    [anon_sym___thread] = ACTIONS(2134),
    [anon_sym_const] = ACTIONS(2134),
    [anon_sym_constexpr] = ACTIONS(2134),
    [anon_sym_volatile] = ACTIONS(2134),
    [anon_sym_restrict] = ACTIONS(2134),
    [anon_sym___restrict__] = ACTIONS(2134),
    [anon_sym__Atomic] = ACTIONS(2134),
    [anon_sym__Noreturn] = ACTIONS(2134),
    [anon_sym_noreturn] = ACTIONS(2134),
    [anon_sym_mutable] = ACTIONS(2134),
    [anon_sym_constinit] = ACTIONS(2134),
    [anon_sym_consteval] = ACTIONS(2134),
    [anon_sym_alignas] = ACTIONS(2134),
    [anon_sym__Alignas] = ACTIONS(2134),
    [sym_primitive_type] = ACTIONS(2134),
    [anon_sym_enum] = ACTIONS(2134),
    [anon_sym_class] = ACTIONS(2134),
    [anon_sym_struct] = ACTIONS(2134),
    [anon_sym_union] = ACTIONS(2134),
    [anon_sym_if] = ACTIONS(2134),
    [anon_sym_else] = ACTIONS(2134),
    [anon_sym_switch] = ACTIONS(2134),
    [anon_sym_case] = ACTIONS(2134),
    [anon_sym_default] = ACTIONS(2134),
    [anon_sym_while] = ACTIONS(2134),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_for] = ACTIONS(2134),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_break] = ACTIONS(2134),
    [anon_sym_continue] = ACTIONS(2134),
    [anon_sym_goto] = ACTIONS(2134),
    [anon_sym___try] = ACTIONS(2134),
    [anon_sym___leave] = ACTIONS(2134),
    [anon_sym_not] = ACTIONS(2134),
    [anon_sym_compl] = ACTIONS(2134),
    [anon_sym_DASH_DASH] = ACTIONS(2136),
    [anon_sym_PLUS_PLUS] = ACTIONS(2136),
    [anon_sym_sizeof] = ACTIONS(2134),
    [anon_sym___alignof__] = ACTIONS(2134),
    [anon_sym___alignof] = ACTIONS(2134),
    [anon_sym__alignof] = ACTIONS(2134),
    [anon_sym_alignof] = ACTIONS(2134),
    [anon_sym__Alignof] = ACTIONS(2134),
    [anon_sym_offsetof] = ACTIONS(2134),
    [anon_sym__Generic] = ACTIONS(2134),
    [anon_sym_asm] = ACTIONS(2134),
    [anon_sym___asm__] = ACTIONS(2134),
    [sym_number_literal] = ACTIONS(2136),
    [anon_sym_L_SQUOTE] = ACTIONS(2136),
    [anon_sym_u_SQUOTE] = ACTIONS(2136),
    [anon_sym_U_SQUOTE] = ACTIONS(2136),
    [anon_sym_u8_SQUOTE] = ACTIONS(2136),
    [anon_sym_SQUOTE] = ACTIONS(2136),
    [anon_sym_L_DQUOTE] = ACTIONS(2136),
    [anon_sym_u_DQUOTE] = ACTIONS(2136),
    [anon_sym_U_DQUOTE] = ACTIONS(2136),
    [anon_sym_u8_DQUOTE] = ACTIONS(2136),
    [anon_sym_DQUOTE] = ACTIONS(2136),
    [sym_true] = ACTIONS(2134),
    [sym_false] = ACTIONS(2134),
    [anon_sym_NULL] = ACTIONS(2134),
    [anon_sym_nullptr] = ACTIONS(2134),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2134),
    [anon_sym_decltype] = ACTIONS(2134),
    [sym_virtual] = ACTIONS(2134),
    [anon_sym_explicit] = ACTIONS(2134),
    [anon_sym_typename] = ACTIONS(2134),
    [anon_sym_template] = ACTIONS(2134),
    [anon_sym_operator] = ACTIONS(2134),
    [anon_sym_try] = ACTIONS(2134),
    [anon_sym_delete] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2134),
    [anon_sym_namespace] = ACTIONS(2134),
    [anon_sym_using] = ACTIONS(2134),
    [anon_sym_static_assert] = ACTIONS(2134),
    [anon_sym_concept] = ACTIONS(2134),
    [anon_sym_co_return] = ACTIONS(2134),
    [anon_sym_co_yield] = ACTIONS(2134),
    [anon_sym_R_DQUOTE] = ACTIONS(2136),
    [anon_sym_LR_DQUOTE] = ACTIONS(2136),
    [anon_sym_uR_DQUOTE] = ACTIONS(2136),
    [anon_sym_UR_DQUOTE] = ACTIONS(2136),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2136),
    [anon_sym_co_await] = ACTIONS(2134),
    [anon_sym_new] = ACTIONS(2134),
    [anon_sym_requires] = ACTIONS(2134),
    [sym_this] = ACTIONS(2134),
    [anon_sym_discard] = ACTIONS(2134),
    [anon_sym_precise] = ACTIONS(2134),
    [anon_sym_shared] = ACTIONS(2134),
    [anon_sym_groupshared] = ACTIONS(2134),
    [anon_sym_uniform] = ACTIONS(2134),
    [anon_sym_row_major] = ACTIONS(2134),
    [anon_sym_column_major] = ACTIONS(2134),
    [anon_sym_globallycoherent] = ACTIONS(2134),
    [anon_sym_centroid] = ACTIONS(2134),
    [anon_sym_noperspective] = ACTIONS(2134),
    [anon_sym_nointerpolation] = ACTIONS(2134),
    [anon_sym_sample] = ACTIONS(2134),
    [anon_sym_linear] = ACTIONS(2134),
    [anon_sym_snorm] = ACTIONS(2134),
    [anon_sym_unorm] = ACTIONS(2134),
    [anon_sym_point] = ACTIONS(2134),
    [anon_sym_line] = ACTIONS(2134),
    [anon_sym_triangleadj] = ACTIONS(2134),
    [anon_sym_lineadj] = ACTIONS(2134),
    [anon_sym_triangle] = ACTIONS(2134),
    [anon_sym_cbuffer] = ACTIONS(2134),
  },
  [418] = {
    [sym_identifier] = ACTIONS(2170),
    [aux_sym_preproc_include_token1] = ACTIONS(2170),
    [aux_sym_preproc_def_token1] = ACTIONS(2170),
    [aux_sym_preproc_if_token1] = ACTIONS(2170),
    [aux_sym_preproc_if_token2] = ACTIONS(2170),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2170),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2170),
    [sym_preproc_directive] = ACTIONS(2170),
    [anon_sym_LPAREN2] = ACTIONS(2172),
    [anon_sym_BANG] = ACTIONS(2172),
    [anon_sym_TILDE] = ACTIONS(2172),
    [anon_sym_DASH] = ACTIONS(2170),
    [anon_sym_PLUS] = ACTIONS(2170),
    [anon_sym_STAR] = ACTIONS(2172),
    [anon_sym_AMP_AMP] = ACTIONS(2172),
    [anon_sym_AMP] = ACTIONS(2170),
    [anon_sym_SEMI] = ACTIONS(2172),
    [anon_sym___extension__] = ACTIONS(2170),
    [anon_sym_typedef] = ACTIONS(2170),
    [anon_sym_in] = ACTIONS(2170),
    [anon_sym_out] = ACTIONS(2170),
    [anon_sym_inout] = ACTIONS(2170),
    [anon_sym_extern] = ACTIONS(2170),
    [anon_sym___attribute__] = ACTIONS(2170),
    [anon_sym_COLON_COLON] = ACTIONS(2172),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2172),
    [anon_sym___declspec] = ACTIONS(2170),
    [anon_sym___based] = ACTIONS(2170),
    [anon_sym___cdecl] = ACTIONS(2170),
    [anon_sym___clrcall] = ACTIONS(2170),
    [anon_sym___stdcall] = ACTIONS(2170),
    [anon_sym___fastcall] = ACTIONS(2170),
    [anon_sym___thiscall] = ACTIONS(2170),
    [anon_sym___vectorcall] = ACTIONS(2170),
    [anon_sym_LBRACE] = ACTIONS(2172),
    [anon_sym_signed] = ACTIONS(2170),
    [anon_sym_unsigned] = ACTIONS(2170),
    [anon_sym_long] = ACTIONS(2170),
    [anon_sym_short] = ACTIONS(2170),
    [anon_sym_LBRACK] = ACTIONS(2170),
    [anon_sym_static] = ACTIONS(2170),
    [anon_sym_register] = ACTIONS(2170),
    [anon_sym_inline] = ACTIONS(2170),
    [anon_sym___inline] = ACTIONS(2170),
    [anon_sym___inline__] = ACTIONS(2170),
    [anon_sym___forceinline] = ACTIONS(2170),
    [anon_sym_thread_local] = ACTIONS(2170),
    [anon_sym___thread] = ACTIONS(2170),
    [anon_sym_const] = ACTIONS(2170),
    [anon_sym_constexpr] = ACTIONS(2170),
    [anon_sym_volatile] = ACTIONS(2170),
    [anon_sym_restrict] = ACTIONS(2170),
    [anon_sym___restrict__] = ACTIONS(2170),
    [anon_sym__Atomic] = ACTIONS(2170),
    [anon_sym__Noreturn] = ACTIONS(2170),
    [anon_sym_noreturn] = ACTIONS(2170),
    [anon_sym_mutable] = ACTIONS(2170),
    [anon_sym_constinit] = ACTIONS(2170),
    [anon_sym_consteval] = ACTIONS(2170),
    [anon_sym_alignas] = ACTIONS(2170),
    [anon_sym__Alignas] = ACTIONS(2170),
    [sym_primitive_type] = ACTIONS(2170),
    [anon_sym_enum] = ACTIONS(2170),
    [anon_sym_class] = ACTIONS(2170),
    [anon_sym_struct] = ACTIONS(2170),
    [anon_sym_union] = ACTIONS(2170),
    [anon_sym_if] = ACTIONS(2170),
    [anon_sym_else] = ACTIONS(2170),
    [anon_sym_switch] = ACTIONS(2170),
    [anon_sym_case] = ACTIONS(2170),
    [anon_sym_default] = ACTIONS(2170),
    [anon_sym_while] = ACTIONS(2170),
    [anon_sym_do] = ACTIONS(2170),
    [anon_sym_for] = ACTIONS(2170),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_break] = ACTIONS(2170),
    [anon_sym_continue] = ACTIONS(2170),
    [anon_sym_goto] = ACTIONS(2170),
    [anon_sym___try] = ACTIONS(2170),
    [anon_sym___leave] = ACTIONS(2170),
    [anon_sym_not] = ACTIONS(2170),
    [anon_sym_compl] = ACTIONS(2170),
    [anon_sym_DASH_DASH] = ACTIONS(2172),
    [anon_sym_PLUS_PLUS] = ACTIONS(2172),
    [anon_sym_sizeof] = ACTIONS(2170),
    [anon_sym___alignof__] = ACTIONS(2170),
    [anon_sym___alignof] = ACTIONS(2170),
    [anon_sym__alignof] = ACTIONS(2170),
    [anon_sym_alignof] = ACTIONS(2170),
    [anon_sym__Alignof] = ACTIONS(2170),
    [anon_sym_offsetof] = ACTIONS(2170),
    [anon_sym__Generic] = ACTIONS(2170),
    [anon_sym_asm] = ACTIONS(2170),
    [anon_sym___asm__] = ACTIONS(2170),
    [sym_number_literal] = ACTIONS(2172),
    [anon_sym_L_SQUOTE] = ACTIONS(2172),
    [anon_sym_u_SQUOTE] = ACTIONS(2172),
    [anon_sym_U_SQUOTE] = ACTIONS(2172),
    [anon_sym_u8_SQUOTE] = ACTIONS(2172),
    [anon_sym_SQUOTE] = ACTIONS(2172),
    [anon_sym_L_DQUOTE] = ACTIONS(2172),
    [anon_sym_u_DQUOTE] = ACTIONS(2172),
    [anon_sym_U_DQUOTE] = ACTIONS(2172),
    [anon_sym_u8_DQUOTE] = ACTIONS(2172),
    [anon_sym_DQUOTE] = ACTIONS(2172),
    [sym_true] = ACTIONS(2170),
    [sym_false] = ACTIONS(2170),
    [anon_sym_NULL] = ACTIONS(2170),
    [anon_sym_nullptr] = ACTIONS(2170),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2170),
    [anon_sym_decltype] = ACTIONS(2170),
    [sym_virtual] = ACTIONS(2170),
    [anon_sym_explicit] = ACTIONS(2170),
    [anon_sym_typename] = ACTIONS(2170),
    [anon_sym_template] = ACTIONS(2170),
    [anon_sym_operator] = ACTIONS(2170),
    [anon_sym_try] = ACTIONS(2170),
    [anon_sym_delete] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2170),
    [anon_sym_namespace] = ACTIONS(2170),
    [anon_sym_using] = ACTIONS(2170),
    [anon_sym_static_assert] = ACTIONS(2170),
    [anon_sym_concept] = ACTIONS(2170),
    [anon_sym_co_return] = ACTIONS(2170),
    [anon_sym_co_yield] = ACTIONS(2170),
    [anon_sym_R_DQUOTE] = ACTIONS(2172),
    [anon_sym_LR_DQUOTE] = ACTIONS(2172),
    [anon_sym_uR_DQUOTE] = ACTIONS(2172),
    [anon_sym_UR_DQUOTE] = ACTIONS(2172),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2172),
    [anon_sym_co_await] = ACTIONS(2170),
    [anon_sym_new] = ACTIONS(2170),
    [anon_sym_requires] = ACTIONS(2170),
    [sym_this] = ACTIONS(2170),
    [anon_sym_discard] = ACTIONS(2170),
    [anon_sym_precise] = ACTIONS(2170),
    [anon_sym_shared] = ACTIONS(2170),
    [anon_sym_groupshared] = ACTIONS(2170),
    [anon_sym_uniform] = ACTIONS(2170),
    [anon_sym_row_major] = ACTIONS(2170),
    [anon_sym_column_major] = ACTIONS(2170),
    [anon_sym_globallycoherent] = ACTIONS(2170),
    [anon_sym_centroid] = ACTIONS(2170),
    [anon_sym_noperspective] = ACTIONS(2170),
    [anon_sym_nointerpolation] = ACTIONS(2170),
    [anon_sym_sample] = ACTIONS(2170),
    [anon_sym_linear] = ACTIONS(2170),
    [anon_sym_snorm] = ACTIONS(2170),
    [anon_sym_unorm] = ACTIONS(2170),
    [anon_sym_point] = ACTIONS(2170),
    [anon_sym_line] = ACTIONS(2170),
    [anon_sym_triangleadj] = ACTIONS(2170),
    [anon_sym_lineadj] = ACTIONS(2170),
    [anon_sym_triangle] = ACTIONS(2170),
    [anon_sym_cbuffer] = ACTIONS(2170),
  },
  [419] = {
    [sym_identifier] = ACTIONS(2166),
    [aux_sym_preproc_include_token1] = ACTIONS(2166),
    [aux_sym_preproc_def_token1] = ACTIONS(2166),
    [aux_sym_preproc_if_token1] = ACTIONS(2166),
    [aux_sym_preproc_if_token2] = ACTIONS(2166),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2166),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2166),
    [sym_preproc_directive] = ACTIONS(2166),
    [anon_sym_LPAREN2] = ACTIONS(2168),
    [anon_sym_BANG] = ACTIONS(2168),
    [anon_sym_TILDE] = ACTIONS(2168),
    [anon_sym_DASH] = ACTIONS(2166),
    [anon_sym_PLUS] = ACTIONS(2166),
    [anon_sym_STAR] = ACTIONS(2168),
    [anon_sym_AMP_AMP] = ACTIONS(2168),
    [anon_sym_AMP] = ACTIONS(2166),
    [anon_sym_SEMI] = ACTIONS(2168),
    [anon_sym___extension__] = ACTIONS(2166),
    [anon_sym_typedef] = ACTIONS(2166),
    [anon_sym_in] = ACTIONS(2166),
    [anon_sym_out] = ACTIONS(2166),
    [anon_sym_inout] = ACTIONS(2166),
    [anon_sym_extern] = ACTIONS(2166),
    [anon_sym___attribute__] = ACTIONS(2166),
    [anon_sym_COLON_COLON] = ACTIONS(2168),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2168),
    [anon_sym___declspec] = ACTIONS(2166),
    [anon_sym___based] = ACTIONS(2166),
    [anon_sym___cdecl] = ACTIONS(2166),
    [anon_sym___clrcall] = ACTIONS(2166),
    [anon_sym___stdcall] = ACTIONS(2166),
    [anon_sym___fastcall] = ACTIONS(2166),
    [anon_sym___thiscall] = ACTIONS(2166),
    [anon_sym___vectorcall] = ACTIONS(2166),
    [anon_sym_LBRACE] = ACTIONS(2168),
    [anon_sym_signed] = ACTIONS(2166),
    [anon_sym_unsigned] = ACTIONS(2166),
    [anon_sym_long] = ACTIONS(2166),
    [anon_sym_short] = ACTIONS(2166),
    [anon_sym_LBRACK] = ACTIONS(2166),
    [anon_sym_static] = ACTIONS(2166),
    [anon_sym_register] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(2166),
    [anon_sym___inline] = ACTIONS(2166),
    [anon_sym___inline__] = ACTIONS(2166),
    [anon_sym___forceinline] = ACTIONS(2166),
    [anon_sym_thread_local] = ACTIONS(2166),
    [anon_sym___thread] = ACTIONS(2166),
    [anon_sym_const] = ACTIONS(2166),
    [anon_sym_constexpr] = ACTIONS(2166),
    [anon_sym_volatile] = ACTIONS(2166),
    [anon_sym_restrict] = ACTIONS(2166),
    [anon_sym___restrict__] = ACTIONS(2166),
    [anon_sym__Atomic] = ACTIONS(2166),
    [anon_sym__Noreturn] = ACTIONS(2166),
    [anon_sym_noreturn] = ACTIONS(2166),
    [anon_sym_mutable] = ACTIONS(2166),
    [anon_sym_constinit] = ACTIONS(2166),
    [anon_sym_consteval] = ACTIONS(2166),
    [anon_sym_alignas] = ACTIONS(2166),
    [anon_sym__Alignas] = ACTIONS(2166),
    [sym_primitive_type] = ACTIONS(2166),
    [anon_sym_enum] = ACTIONS(2166),
    [anon_sym_class] = ACTIONS(2166),
    [anon_sym_struct] = ACTIONS(2166),
    [anon_sym_union] = ACTIONS(2166),
    [anon_sym_if] = ACTIONS(2166),
    [anon_sym_else] = ACTIONS(2166),
    [anon_sym_switch] = ACTIONS(2166),
    [anon_sym_case] = ACTIONS(2166),
    [anon_sym_default] = ACTIONS(2166),
    [anon_sym_while] = ACTIONS(2166),
    [anon_sym_do] = ACTIONS(2166),
    [anon_sym_for] = ACTIONS(2166),
    [anon_sym_return] = ACTIONS(2166),
    [anon_sym_break] = ACTIONS(2166),
    [anon_sym_continue] = ACTIONS(2166),
    [anon_sym_goto] = ACTIONS(2166),
    [anon_sym___try] = ACTIONS(2166),
    [anon_sym___leave] = ACTIONS(2166),
    [anon_sym_not] = ACTIONS(2166),
    [anon_sym_compl] = ACTIONS(2166),
    [anon_sym_DASH_DASH] = ACTIONS(2168),
    [anon_sym_PLUS_PLUS] = ACTIONS(2168),
    [anon_sym_sizeof] = ACTIONS(2166),
    [anon_sym___alignof__] = ACTIONS(2166),
    [anon_sym___alignof] = ACTIONS(2166),
    [anon_sym__alignof] = ACTIONS(2166),
    [anon_sym_alignof] = ACTIONS(2166),
    [anon_sym__Alignof] = ACTIONS(2166),
    [anon_sym_offsetof] = ACTIONS(2166),
    [anon_sym__Generic] = ACTIONS(2166),
    [anon_sym_asm] = ACTIONS(2166),
    [anon_sym___asm__] = ACTIONS(2166),
    [sym_number_literal] = ACTIONS(2168),
    [anon_sym_L_SQUOTE] = ACTIONS(2168),
    [anon_sym_u_SQUOTE] = ACTIONS(2168),
    [anon_sym_U_SQUOTE] = ACTIONS(2168),
    [anon_sym_u8_SQUOTE] = ACTIONS(2168),
    [anon_sym_SQUOTE] = ACTIONS(2168),
    [anon_sym_L_DQUOTE] = ACTIONS(2168),
    [anon_sym_u_DQUOTE] = ACTIONS(2168),
    [anon_sym_U_DQUOTE] = ACTIONS(2168),
    [anon_sym_u8_DQUOTE] = ACTIONS(2168),
    [anon_sym_DQUOTE] = ACTIONS(2168),
    [sym_true] = ACTIONS(2166),
    [sym_false] = ACTIONS(2166),
    [anon_sym_NULL] = ACTIONS(2166),
    [anon_sym_nullptr] = ACTIONS(2166),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2166),
    [anon_sym_decltype] = ACTIONS(2166),
    [sym_virtual] = ACTIONS(2166),
    [anon_sym_explicit] = ACTIONS(2166),
    [anon_sym_typename] = ACTIONS(2166),
    [anon_sym_template] = ACTIONS(2166),
    [anon_sym_operator] = ACTIONS(2166),
    [anon_sym_try] = ACTIONS(2166),
    [anon_sym_delete] = ACTIONS(2166),
    [anon_sym_throw] = ACTIONS(2166),
    [anon_sym_namespace] = ACTIONS(2166),
    [anon_sym_using] = ACTIONS(2166),
    [anon_sym_static_assert] = ACTIONS(2166),
    [anon_sym_concept] = ACTIONS(2166),
    [anon_sym_co_return] = ACTIONS(2166),
    [anon_sym_co_yield] = ACTIONS(2166),
    [anon_sym_R_DQUOTE] = ACTIONS(2168),
    [anon_sym_LR_DQUOTE] = ACTIONS(2168),
    [anon_sym_uR_DQUOTE] = ACTIONS(2168),
    [anon_sym_UR_DQUOTE] = ACTIONS(2168),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2168),
    [anon_sym_co_await] = ACTIONS(2166),
    [anon_sym_new] = ACTIONS(2166),
    [anon_sym_requires] = ACTIONS(2166),
    [sym_this] = ACTIONS(2166),
    [anon_sym_discard] = ACTIONS(2166),
    [anon_sym_precise] = ACTIONS(2166),
    [anon_sym_shared] = ACTIONS(2166),
    [anon_sym_groupshared] = ACTIONS(2166),
    [anon_sym_uniform] = ACTIONS(2166),
    [anon_sym_row_major] = ACTIONS(2166),
    [anon_sym_column_major] = ACTIONS(2166),
    [anon_sym_globallycoherent] = ACTIONS(2166),
    [anon_sym_centroid] = ACTIONS(2166),
    [anon_sym_noperspective] = ACTIONS(2166),
    [anon_sym_nointerpolation] = ACTIONS(2166),
    [anon_sym_sample] = ACTIONS(2166),
    [anon_sym_linear] = ACTIONS(2166),
    [anon_sym_snorm] = ACTIONS(2166),
    [anon_sym_unorm] = ACTIONS(2166),
    [anon_sym_point] = ACTIONS(2166),
    [anon_sym_line] = ACTIONS(2166),
    [anon_sym_triangleadj] = ACTIONS(2166),
    [anon_sym_lineadj] = ACTIONS(2166),
    [anon_sym_triangle] = ACTIONS(2166),
    [anon_sym_cbuffer] = ACTIONS(2166),
  },
  [420] = {
    [sym_identifier] = ACTIONS(2146),
    [aux_sym_preproc_include_token1] = ACTIONS(2146),
    [aux_sym_preproc_def_token1] = ACTIONS(2146),
    [aux_sym_preproc_if_token1] = ACTIONS(2146),
    [aux_sym_preproc_if_token2] = ACTIONS(2146),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2146),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2146),
    [sym_preproc_directive] = ACTIONS(2146),
    [anon_sym_LPAREN2] = ACTIONS(2148),
    [anon_sym_BANG] = ACTIONS(2148),
    [anon_sym_TILDE] = ACTIONS(2148),
    [anon_sym_DASH] = ACTIONS(2146),
    [anon_sym_PLUS] = ACTIONS(2146),
    [anon_sym_STAR] = ACTIONS(2148),
    [anon_sym_AMP_AMP] = ACTIONS(2148),
    [anon_sym_AMP] = ACTIONS(2146),
    [anon_sym_SEMI] = ACTIONS(2148),
    [anon_sym___extension__] = ACTIONS(2146),
    [anon_sym_typedef] = ACTIONS(2146),
    [anon_sym_in] = ACTIONS(2146),
    [anon_sym_out] = ACTIONS(2146),
    [anon_sym_inout] = ACTIONS(2146),
    [anon_sym_extern] = ACTIONS(2146),
    [anon_sym___attribute__] = ACTIONS(2146),
    [anon_sym_COLON_COLON] = ACTIONS(2148),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2148),
    [anon_sym___declspec] = ACTIONS(2146),
    [anon_sym___based] = ACTIONS(2146),
    [anon_sym___cdecl] = ACTIONS(2146),
    [anon_sym___clrcall] = ACTIONS(2146),
    [anon_sym___stdcall] = ACTIONS(2146),
    [anon_sym___fastcall] = ACTIONS(2146),
    [anon_sym___thiscall] = ACTIONS(2146),
    [anon_sym___vectorcall] = ACTIONS(2146),
    [anon_sym_LBRACE] = ACTIONS(2148),
    [anon_sym_signed] = ACTIONS(2146),
    [anon_sym_unsigned] = ACTIONS(2146),
    [anon_sym_long] = ACTIONS(2146),
    [anon_sym_short] = ACTIONS(2146),
    [anon_sym_LBRACK] = ACTIONS(2146),
    [anon_sym_static] = ACTIONS(2146),
    [anon_sym_register] = ACTIONS(2146),
    [anon_sym_inline] = ACTIONS(2146),
    [anon_sym___inline] = ACTIONS(2146),
    [anon_sym___inline__] = ACTIONS(2146),
    [anon_sym___forceinline] = ACTIONS(2146),
    [anon_sym_thread_local] = ACTIONS(2146),
    [anon_sym___thread] = ACTIONS(2146),
    [anon_sym_const] = ACTIONS(2146),
    [anon_sym_constexpr] = ACTIONS(2146),
    [anon_sym_volatile] = ACTIONS(2146),
    [anon_sym_restrict] = ACTIONS(2146),
    [anon_sym___restrict__] = ACTIONS(2146),
    [anon_sym__Atomic] = ACTIONS(2146),
    [anon_sym__Noreturn] = ACTIONS(2146),
    [anon_sym_noreturn] = ACTIONS(2146),
    [anon_sym_mutable] = ACTIONS(2146),
    [anon_sym_constinit] = ACTIONS(2146),
    [anon_sym_consteval] = ACTIONS(2146),
    [anon_sym_alignas] = ACTIONS(2146),
    [anon_sym__Alignas] = ACTIONS(2146),
    [sym_primitive_type] = ACTIONS(2146),
    [anon_sym_enum] = ACTIONS(2146),
    [anon_sym_class] = ACTIONS(2146),
    [anon_sym_struct] = ACTIONS(2146),
    [anon_sym_union] = ACTIONS(2146),
    [anon_sym_if] = ACTIONS(2146),
    [anon_sym_else] = ACTIONS(2146),
    [anon_sym_switch] = ACTIONS(2146),
    [anon_sym_case] = ACTIONS(2146),
    [anon_sym_default] = ACTIONS(2146),
    [anon_sym_while] = ACTIONS(2146),
    [anon_sym_do] = ACTIONS(2146),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_return] = ACTIONS(2146),
    [anon_sym_break] = ACTIONS(2146),
    [anon_sym_continue] = ACTIONS(2146),
    [anon_sym_goto] = ACTIONS(2146),
    [anon_sym___try] = ACTIONS(2146),
    [anon_sym___leave] = ACTIONS(2146),
    [anon_sym_not] = ACTIONS(2146),
    [anon_sym_compl] = ACTIONS(2146),
    [anon_sym_DASH_DASH] = ACTIONS(2148),
    [anon_sym_PLUS_PLUS] = ACTIONS(2148),
    [anon_sym_sizeof] = ACTIONS(2146),
    [anon_sym___alignof__] = ACTIONS(2146),
    [anon_sym___alignof] = ACTIONS(2146),
    [anon_sym__alignof] = ACTIONS(2146),
    [anon_sym_alignof] = ACTIONS(2146),
    [anon_sym__Alignof] = ACTIONS(2146),
    [anon_sym_offsetof] = ACTIONS(2146),
    [anon_sym__Generic] = ACTIONS(2146),
    [anon_sym_asm] = ACTIONS(2146),
    [anon_sym___asm__] = ACTIONS(2146),
    [sym_number_literal] = ACTIONS(2148),
    [anon_sym_L_SQUOTE] = ACTIONS(2148),
    [anon_sym_u_SQUOTE] = ACTIONS(2148),
    [anon_sym_U_SQUOTE] = ACTIONS(2148),
    [anon_sym_u8_SQUOTE] = ACTIONS(2148),
    [anon_sym_SQUOTE] = ACTIONS(2148),
    [anon_sym_L_DQUOTE] = ACTIONS(2148),
    [anon_sym_u_DQUOTE] = ACTIONS(2148),
    [anon_sym_U_DQUOTE] = ACTIONS(2148),
    [anon_sym_u8_DQUOTE] = ACTIONS(2148),
    [anon_sym_DQUOTE] = ACTIONS(2148),
    [sym_true] = ACTIONS(2146),
    [sym_false] = ACTIONS(2146),
    [anon_sym_NULL] = ACTIONS(2146),
    [anon_sym_nullptr] = ACTIONS(2146),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2146),
    [anon_sym_decltype] = ACTIONS(2146),
    [sym_virtual] = ACTIONS(2146),
    [anon_sym_explicit] = ACTIONS(2146),
    [anon_sym_typename] = ACTIONS(2146),
    [anon_sym_template] = ACTIONS(2146),
    [anon_sym_operator] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2146),
    [anon_sym_delete] = ACTIONS(2146),
    [anon_sym_throw] = ACTIONS(2146),
    [anon_sym_namespace] = ACTIONS(2146),
    [anon_sym_using] = ACTIONS(2146),
    [anon_sym_static_assert] = ACTIONS(2146),
    [anon_sym_concept] = ACTIONS(2146),
    [anon_sym_co_return] = ACTIONS(2146),
    [anon_sym_co_yield] = ACTIONS(2146),
    [anon_sym_R_DQUOTE] = ACTIONS(2148),
    [anon_sym_LR_DQUOTE] = ACTIONS(2148),
    [anon_sym_uR_DQUOTE] = ACTIONS(2148),
    [anon_sym_UR_DQUOTE] = ACTIONS(2148),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2148),
    [anon_sym_co_await] = ACTIONS(2146),
    [anon_sym_new] = ACTIONS(2146),
    [anon_sym_requires] = ACTIONS(2146),
    [sym_this] = ACTIONS(2146),
    [anon_sym_discard] = ACTIONS(2146),
    [anon_sym_precise] = ACTIONS(2146),
    [anon_sym_shared] = ACTIONS(2146),
    [anon_sym_groupshared] = ACTIONS(2146),
    [anon_sym_uniform] = ACTIONS(2146),
    [anon_sym_row_major] = ACTIONS(2146),
    [anon_sym_column_major] = ACTIONS(2146),
    [anon_sym_globallycoherent] = ACTIONS(2146),
    [anon_sym_centroid] = ACTIONS(2146),
    [anon_sym_noperspective] = ACTIONS(2146),
    [anon_sym_nointerpolation] = ACTIONS(2146),
    [anon_sym_sample] = ACTIONS(2146),
    [anon_sym_linear] = ACTIONS(2146),
    [anon_sym_snorm] = ACTIONS(2146),
    [anon_sym_unorm] = ACTIONS(2146),
    [anon_sym_point] = ACTIONS(2146),
    [anon_sym_line] = ACTIONS(2146),
    [anon_sym_triangleadj] = ACTIONS(2146),
    [anon_sym_lineadj] = ACTIONS(2146),
    [anon_sym_triangle] = ACTIONS(2146),
    [anon_sym_cbuffer] = ACTIONS(2146),
  },
  [421] = {
    [sym_identifier] = ACTIONS(2090),
    [aux_sym_preproc_include_token1] = ACTIONS(2090),
    [aux_sym_preproc_def_token1] = ACTIONS(2090),
    [aux_sym_preproc_if_token1] = ACTIONS(2090),
    [aux_sym_preproc_if_token2] = ACTIONS(2090),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2090),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2090),
    [sym_preproc_directive] = ACTIONS(2090),
    [anon_sym_LPAREN2] = ACTIONS(2092),
    [anon_sym_BANG] = ACTIONS(2092),
    [anon_sym_TILDE] = ACTIONS(2092),
    [anon_sym_DASH] = ACTIONS(2090),
    [anon_sym_PLUS] = ACTIONS(2090),
    [anon_sym_STAR] = ACTIONS(2092),
    [anon_sym_AMP_AMP] = ACTIONS(2092),
    [anon_sym_AMP] = ACTIONS(2090),
    [anon_sym_SEMI] = ACTIONS(2092),
    [anon_sym___extension__] = ACTIONS(2090),
    [anon_sym_typedef] = ACTIONS(2090),
    [anon_sym_in] = ACTIONS(2090),
    [anon_sym_out] = ACTIONS(2090),
    [anon_sym_inout] = ACTIONS(2090),
    [anon_sym_extern] = ACTIONS(2090),
    [anon_sym___attribute__] = ACTIONS(2090),
    [anon_sym_COLON_COLON] = ACTIONS(2092),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2092),
    [anon_sym___declspec] = ACTIONS(2090),
    [anon_sym___based] = ACTIONS(2090),
    [anon_sym___cdecl] = ACTIONS(2090),
    [anon_sym___clrcall] = ACTIONS(2090),
    [anon_sym___stdcall] = ACTIONS(2090),
    [anon_sym___fastcall] = ACTIONS(2090),
    [anon_sym___thiscall] = ACTIONS(2090),
    [anon_sym___vectorcall] = ACTIONS(2090),
    [anon_sym_LBRACE] = ACTIONS(2092),
    [anon_sym_signed] = ACTIONS(2090),
    [anon_sym_unsigned] = ACTIONS(2090),
    [anon_sym_long] = ACTIONS(2090),
    [anon_sym_short] = ACTIONS(2090),
    [anon_sym_LBRACK] = ACTIONS(2090),
    [anon_sym_static] = ACTIONS(2090),
    [anon_sym_register] = ACTIONS(2090),
    [anon_sym_inline] = ACTIONS(2090),
    [anon_sym___inline] = ACTIONS(2090),
    [anon_sym___inline__] = ACTIONS(2090),
    [anon_sym___forceinline] = ACTIONS(2090),
    [anon_sym_thread_local] = ACTIONS(2090),
    [anon_sym___thread] = ACTIONS(2090),
    [anon_sym_const] = ACTIONS(2090),
    [anon_sym_constexpr] = ACTIONS(2090),
    [anon_sym_volatile] = ACTIONS(2090),
    [anon_sym_restrict] = ACTIONS(2090),
    [anon_sym___restrict__] = ACTIONS(2090),
    [anon_sym__Atomic] = ACTIONS(2090),
    [anon_sym__Noreturn] = ACTIONS(2090),
    [anon_sym_noreturn] = ACTIONS(2090),
    [anon_sym_mutable] = ACTIONS(2090),
    [anon_sym_constinit] = ACTIONS(2090),
    [anon_sym_consteval] = ACTIONS(2090),
    [anon_sym_alignas] = ACTIONS(2090),
    [anon_sym__Alignas] = ACTIONS(2090),
    [sym_primitive_type] = ACTIONS(2090),
    [anon_sym_enum] = ACTIONS(2090),
    [anon_sym_class] = ACTIONS(2090),
    [anon_sym_struct] = ACTIONS(2090),
    [anon_sym_union] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(2090),
    [anon_sym_else] = ACTIONS(2090),
    [anon_sym_switch] = ACTIONS(2090),
    [anon_sym_case] = ACTIONS(2090),
    [anon_sym_default] = ACTIONS(2090),
    [anon_sym_while] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(2090),
    [anon_sym_for] = ACTIONS(2090),
    [anon_sym_return] = ACTIONS(2090),
    [anon_sym_break] = ACTIONS(2090),
    [anon_sym_continue] = ACTIONS(2090),
    [anon_sym_goto] = ACTIONS(2090),
    [anon_sym___try] = ACTIONS(2090),
    [anon_sym___leave] = ACTIONS(2090),
    [anon_sym_not] = ACTIONS(2090),
    [anon_sym_compl] = ACTIONS(2090),
    [anon_sym_DASH_DASH] = ACTIONS(2092),
    [anon_sym_PLUS_PLUS] = ACTIONS(2092),
    [anon_sym_sizeof] = ACTIONS(2090),
    [anon_sym___alignof__] = ACTIONS(2090),
    [anon_sym___alignof] = ACTIONS(2090),
    [anon_sym__alignof] = ACTIONS(2090),
    [anon_sym_alignof] = ACTIONS(2090),
    [anon_sym__Alignof] = ACTIONS(2090),
    [anon_sym_offsetof] = ACTIONS(2090),
    [anon_sym__Generic] = ACTIONS(2090),
    [anon_sym_asm] = ACTIONS(2090),
    [anon_sym___asm__] = ACTIONS(2090),
    [sym_number_literal] = ACTIONS(2092),
    [anon_sym_L_SQUOTE] = ACTIONS(2092),
    [anon_sym_u_SQUOTE] = ACTIONS(2092),
    [anon_sym_U_SQUOTE] = ACTIONS(2092),
    [anon_sym_u8_SQUOTE] = ACTIONS(2092),
    [anon_sym_SQUOTE] = ACTIONS(2092),
    [anon_sym_L_DQUOTE] = ACTIONS(2092),
    [anon_sym_u_DQUOTE] = ACTIONS(2092),
    [anon_sym_U_DQUOTE] = ACTIONS(2092),
    [anon_sym_u8_DQUOTE] = ACTIONS(2092),
    [anon_sym_DQUOTE] = ACTIONS(2092),
    [sym_true] = ACTIONS(2090),
    [sym_false] = ACTIONS(2090),
    [anon_sym_NULL] = ACTIONS(2090),
    [anon_sym_nullptr] = ACTIONS(2090),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2090),
    [anon_sym_decltype] = ACTIONS(2090),
    [sym_virtual] = ACTIONS(2090),
    [anon_sym_explicit] = ACTIONS(2090),
    [anon_sym_typename] = ACTIONS(2090),
    [anon_sym_template] = ACTIONS(2090),
    [anon_sym_operator] = ACTIONS(2090),
    [anon_sym_try] = ACTIONS(2090),
    [anon_sym_delete] = ACTIONS(2090),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_namespace] = ACTIONS(2090),
    [anon_sym_using] = ACTIONS(2090),
    [anon_sym_static_assert] = ACTIONS(2090),
    [anon_sym_concept] = ACTIONS(2090),
    [anon_sym_co_return] = ACTIONS(2090),
    [anon_sym_co_yield] = ACTIONS(2090),
    [anon_sym_R_DQUOTE] = ACTIONS(2092),
    [anon_sym_LR_DQUOTE] = ACTIONS(2092),
    [anon_sym_uR_DQUOTE] = ACTIONS(2092),
    [anon_sym_UR_DQUOTE] = ACTIONS(2092),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2092),
    [anon_sym_co_await] = ACTIONS(2090),
    [anon_sym_new] = ACTIONS(2090),
    [anon_sym_requires] = ACTIONS(2090),
    [sym_this] = ACTIONS(2090),
    [anon_sym_discard] = ACTIONS(2090),
    [anon_sym_precise] = ACTIONS(2090),
    [anon_sym_shared] = ACTIONS(2090),
    [anon_sym_groupshared] = ACTIONS(2090),
    [anon_sym_uniform] = ACTIONS(2090),
    [anon_sym_row_major] = ACTIONS(2090),
    [anon_sym_column_major] = ACTIONS(2090),
    [anon_sym_globallycoherent] = ACTIONS(2090),
    [anon_sym_centroid] = ACTIONS(2090),
    [anon_sym_noperspective] = ACTIONS(2090),
    [anon_sym_nointerpolation] = ACTIONS(2090),
    [anon_sym_sample] = ACTIONS(2090),
    [anon_sym_linear] = ACTIONS(2090),
    [anon_sym_snorm] = ACTIONS(2090),
    [anon_sym_unorm] = ACTIONS(2090),
    [anon_sym_point] = ACTIONS(2090),
    [anon_sym_line] = ACTIONS(2090),
    [anon_sym_triangleadj] = ACTIONS(2090),
    [anon_sym_lineadj] = ACTIONS(2090),
    [anon_sym_triangle] = ACTIONS(2090),
    [anon_sym_cbuffer] = ACTIONS(2090),
  },
  [422] = {
    [ts_builtin_sym_end] = ACTIONS(2206),
    [sym_identifier] = ACTIONS(2204),
    [aux_sym_preproc_include_token1] = ACTIONS(2204),
    [aux_sym_preproc_def_token1] = ACTIONS(2204),
    [aux_sym_preproc_if_token1] = ACTIONS(2204),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2204),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2204),
    [sym_preproc_directive] = ACTIONS(2204),
    [anon_sym_LPAREN2] = ACTIONS(2206),
    [anon_sym_BANG] = ACTIONS(2206),
    [anon_sym_TILDE] = ACTIONS(2206),
    [anon_sym_DASH] = ACTIONS(2204),
    [anon_sym_PLUS] = ACTIONS(2204),
    [anon_sym_STAR] = ACTIONS(2206),
    [anon_sym_AMP_AMP] = ACTIONS(2206),
    [anon_sym_AMP] = ACTIONS(2204),
    [anon_sym_SEMI] = ACTIONS(2206),
    [anon_sym___extension__] = ACTIONS(2204),
    [anon_sym_typedef] = ACTIONS(2204),
    [anon_sym_in] = ACTIONS(2204),
    [anon_sym_out] = ACTIONS(2204),
    [anon_sym_inout] = ACTIONS(2204),
    [anon_sym_extern] = ACTIONS(2204),
    [anon_sym___attribute__] = ACTIONS(2204),
    [anon_sym_COLON_COLON] = ACTIONS(2206),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2206),
    [anon_sym___declspec] = ACTIONS(2204),
    [anon_sym___based] = ACTIONS(2204),
    [anon_sym___cdecl] = ACTIONS(2204),
    [anon_sym___clrcall] = ACTIONS(2204),
    [anon_sym___stdcall] = ACTIONS(2204),
    [anon_sym___fastcall] = ACTIONS(2204),
    [anon_sym___thiscall] = ACTIONS(2204),
    [anon_sym___vectorcall] = ACTIONS(2204),
    [anon_sym_LBRACE] = ACTIONS(2206),
    [anon_sym_signed] = ACTIONS(2204),
    [anon_sym_unsigned] = ACTIONS(2204),
    [anon_sym_long] = ACTIONS(2204),
    [anon_sym_short] = ACTIONS(2204),
    [anon_sym_LBRACK] = ACTIONS(2204),
    [anon_sym_static] = ACTIONS(2204),
    [anon_sym_register] = ACTIONS(2204),
    [anon_sym_inline] = ACTIONS(2204),
    [anon_sym___inline] = ACTIONS(2204),
    [anon_sym___inline__] = ACTIONS(2204),
    [anon_sym___forceinline] = ACTIONS(2204),
    [anon_sym_thread_local] = ACTIONS(2204),
    [anon_sym___thread] = ACTIONS(2204),
    [anon_sym_const] = ACTIONS(2204),
    [anon_sym_constexpr] = ACTIONS(2204),
    [anon_sym_volatile] = ACTIONS(2204),
    [anon_sym_restrict] = ACTIONS(2204),
    [anon_sym___restrict__] = ACTIONS(2204),
    [anon_sym__Atomic] = ACTIONS(2204),
    [anon_sym__Noreturn] = ACTIONS(2204),
    [anon_sym_noreturn] = ACTIONS(2204),
    [anon_sym_mutable] = ACTIONS(2204),
    [anon_sym_constinit] = ACTIONS(2204),
    [anon_sym_consteval] = ACTIONS(2204),
    [anon_sym_alignas] = ACTIONS(2204),
    [anon_sym__Alignas] = ACTIONS(2204),
    [sym_primitive_type] = ACTIONS(2204),
    [anon_sym_enum] = ACTIONS(2204),
    [anon_sym_class] = ACTIONS(2204),
    [anon_sym_struct] = ACTIONS(2204),
    [anon_sym_union] = ACTIONS(2204),
    [anon_sym_if] = ACTIONS(2204),
    [anon_sym_else] = ACTIONS(2204),
    [anon_sym_switch] = ACTIONS(2204),
    [anon_sym_case] = ACTIONS(2204),
    [anon_sym_default] = ACTIONS(2204),
    [anon_sym_while] = ACTIONS(2204),
    [anon_sym_do] = ACTIONS(2204),
    [anon_sym_for] = ACTIONS(2204),
    [anon_sym_return] = ACTIONS(2204),
    [anon_sym_break] = ACTIONS(2204),
    [anon_sym_continue] = ACTIONS(2204),
    [anon_sym_goto] = ACTIONS(2204),
    [anon_sym___try] = ACTIONS(2204),
    [anon_sym___leave] = ACTIONS(2204),
    [anon_sym_not] = ACTIONS(2204),
    [anon_sym_compl] = ACTIONS(2204),
    [anon_sym_DASH_DASH] = ACTIONS(2206),
    [anon_sym_PLUS_PLUS] = ACTIONS(2206),
    [anon_sym_sizeof] = ACTIONS(2204),
    [anon_sym___alignof__] = ACTIONS(2204),
    [anon_sym___alignof] = ACTIONS(2204),
    [anon_sym__alignof] = ACTIONS(2204),
    [anon_sym_alignof] = ACTIONS(2204),
    [anon_sym__Alignof] = ACTIONS(2204),
    [anon_sym_offsetof] = ACTIONS(2204),
    [anon_sym__Generic] = ACTIONS(2204),
    [anon_sym_asm] = ACTIONS(2204),
    [anon_sym___asm__] = ACTIONS(2204),
    [sym_number_literal] = ACTIONS(2206),
    [anon_sym_L_SQUOTE] = ACTIONS(2206),
    [anon_sym_u_SQUOTE] = ACTIONS(2206),
    [anon_sym_U_SQUOTE] = ACTIONS(2206),
    [anon_sym_u8_SQUOTE] = ACTIONS(2206),
    [anon_sym_SQUOTE] = ACTIONS(2206),
    [anon_sym_L_DQUOTE] = ACTIONS(2206),
    [anon_sym_u_DQUOTE] = ACTIONS(2206),
    [anon_sym_U_DQUOTE] = ACTIONS(2206),
    [anon_sym_u8_DQUOTE] = ACTIONS(2206),
    [anon_sym_DQUOTE] = ACTIONS(2206),
    [sym_true] = ACTIONS(2204),
    [sym_false] = ACTIONS(2204),
    [anon_sym_NULL] = ACTIONS(2204),
    [anon_sym_nullptr] = ACTIONS(2204),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2204),
    [anon_sym_decltype] = ACTIONS(2204),
    [sym_virtual] = ACTIONS(2204),
    [anon_sym_explicit] = ACTIONS(2204),
    [anon_sym_typename] = ACTIONS(2204),
    [anon_sym_template] = ACTIONS(2204),
    [anon_sym_operator] = ACTIONS(2204),
    [anon_sym_try] = ACTIONS(2204),
    [anon_sym_delete] = ACTIONS(2204),
    [anon_sym_throw] = ACTIONS(2204),
    [anon_sym_namespace] = ACTIONS(2204),
    [anon_sym_using] = ACTIONS(2204),
    [anon_sym_static_assert] = ACTIONS(2204),
    [anon_sym_concept] = ACTIONS(2204),
    [anon_sym_co_return] = ACTIONS(2204),
    [anon_sym_co_yield] = ACTIONS(2204),
    [anon_sym_R_DQUOTE] = ACTIONS(2206),
    [anon_sym_LR_DQUOTE] = ACTIONS(2206),
    [anon_sym_uR_DQUOTE] = ACTIONS(2206),
    [anon_sym_UR_DQUOTE] = ACTIONS(2206),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2206),
    [anon_sym_co_await] = ACTIONS(2204),
    [anon_sym_new] = ACTIONS(2204),
    [anon_sym_requires] = ACTIONS(2204),
    [sym_this] = ACTIONS(2204),
    [anon_sym_discard] = ACTIONS(2204),
    [anon_sym_precise] = ACTIONS(2204),
    [anon_sym_shared] = ACTIONS(2204),
    [anon_sym_groupshared] = ACTIONS(2204),
    [anon_sym_uniform] = ACTIONS(2204),
    [anon_sym_row_major] = ACTIONS(2204),
    [anon_sym_column_major] = ACTIONS(2204),
    [anon_sym_globallycoherent] = ACTIONS(2204),
    [anon_sym_centroid] = ACTIONS(2204),
    [anon_sym_noperspective] = ACTIONS(2204),
    [anon_sym_nointerpolation] = ACTIONS(2204),
    [anon_sym_sample] = ACTIONS(2204),
    [anon_sym_linear] = ACTIONS(2204),
    [anon_sym_snorm] = ACTIONS(2204),
    [anon_sym_unorm] = ACTIONS(2204),
    [anon_sym_point] = ACTIONS(2204),
    [anon_sym_line] = ACTIONS(2204),
    [anon_sym_triangleadj] = ACTIONS(2204),
    [anon_sym_lineadj] = ACTIONS(2204),
    [anon_sym_triangle] = ACTIONS(2204),
    [anon_sym_cbuffer] = ACTIONS(2204),
  },
  [423] = {
    [ts_builtin_sym_end] = ACTIONS(2262),
    [sym_identifier] = ACTIONS(2260),
    [aux_sym_preproc_include_token1] = ACTIONS(2260),
    [aux_sym_preproc_def_token1] = ACTIONS(2260),
    [aux_sym_preproc_if_token1] = ACTIONS(2260),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2260),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2260),
    [sym_preproc_directive] = ACTIONS(2260),
    [anon_sym_LPAREN2] = ACTIONS(2262),
    [anon_sym_BANG] = ACTIONS(2262),
    [anon_sym_TILDE] = ACTIONS(2262),
    [anon_sym_DASH] = ACTIONS(2260),
    [anon_sym_PLUS] = ACTIONS(2260),
    [anon_sym_STAR] = ACTIONS(2262),
    [anon_sym_AMP_AMP] = ACTIONS(2262),
    [anon_sym_AMP] = ACTIONS(2260),
    [anon_sym_SEMI] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(2260),
    [anon_sym_typedef] = ACTIONS(2260),
    [anon_sym_in] = ACTIONS(2260),
    [anon_sym_out] = ACTIONS(2260),
    [anon_sym_inout] = ACTIONS(2260),
    [anon_sym_extern] = ACTIONS(2260),
    [anon_sym___attribute__] = ACTIONS(2260),
    [anon_sym_COLON_COLON] = ACTIONS(2262),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2262),
    [anon_sym___declspec] = ACTIONS(2260),
    [anon_sym___based] = ACTIONS(2260),
    [anon_sym___cdecl] = ACTIONS(2260),
    [anon_sym___clrcall] = ACTIONS(2260),
    [anon_sym___stdcall] = ACTIONS(2260),
    [anon_sym___fastcall] = ACTIONS(2260),
    [anon_sym___thiscall] = ACTIONS(2260),
    [anon_sym___vectorcall] = ACTIONS(2260),
    [anon_sym_LBRACE] = ACTIONS(2262),
    [anon_sym_signed] = ACTIONS(2260),
    [anon_sym_unsigned] = ACTIONS(2260),
    [anon_sym_long] = ACTIONS(2260),
    [anon_sym_short] = ACTIONS(2260),
    [anon_sym_LBRACK] = ACTIONS(2260),
    [anon_sym_static] = ACTIONS(2260),
    [anon_sym_register] = ACTIONS(2260),
    [anon_sym_inline] = ACTIONS(2260),
    [anon_sym___inline] = ACTIONS(2260),
    [anon_sym___inline__] = ACTIONS(2260),
    [anon_sym___forceinline] = ACTIONS(2260),
    [anon_sym_thread_local] = ACTIONS(2260),
    [anon_sym___thread] = ACTIONS(2260),
    [anon_sym_const] = ACTIONS(2260),
    [anon_sym_constexpr] = ACTIONS(2260),
    [anon_sym_volatile] = ACTIONS(2260),
    [anon_sym_restrict] = ACTIONS(2260),
    [anon_sym___restrict__] = ACTIONS(2260),
    [anon_sym__Atomic] = ACTIONS(2260),
    [anon_sym__Noreturn] = ACTIONS(2260),
    [anon_sym_noreturn] = ACTIONS(2260),
    [anon_sym_mutable] = ACTIONS(2260),
    [anon_sym_constinit] = ACTIONS(2260),
    [anon_sym_consteval] = ACTIONS(2260),
    [anon_sym_alignas] = ACTIONS(2260),
    [anon_sym__Alignas] = ACTIONS(2260),
    [sym_primitive_type] = ACTIONS(2260),
    [anon_sym_enum] = ACTIONS(2260),
    [anon_sym_class] = ACTIONS(2260),
    [anon_sym_struct] = ACTIONS(2260),
    [anon_sym_union] = ACTIONS(2260),
    [anon_sym_if] = ACTIONS(2260),
    [anon_sym_else] = ACTIONS(2260),
    [anon_sym_switch] = ACTIONS(2260),
    [anon_sym_case] = ACTIONS(2260),
    [anon_sym_default] = ACTIONS(2260),
    [anon_sym_while] = ACTIONS(2260),
    [anon_sym_do] = ACTIONS(2260),
    [anon_sym_for] = ACTIONS(2260),
    [anon_sym_return] = ACTIONS(2260),
    [anon_sym_break] = ACTIONS(2260),
    [anon_sym_continue] = ACTIONS(2260),
    [anon_sym_goto] = ACTIONS(2260),
    [anon_sym___try] = ACTIONS(2260),
    [anon_sym___leave] = ACTIONS(2260),
    [anon_sym_not] = ACTIONS(2260),
    [anon_sym_compl] = ACTIONS(2260),
    [anon_sym_DASH_DASH] = ACTIONS(2262),
    [anon_sym_PLUS_PLUS] = ACTIONS(2262),
    [anon_sym_sizeof] = ACTIONS(2260),
    [anon_sym___alignof__] = ACTIONS(2260),
    [anon_sym___alignof] = ACTIONS(2260),
    [anon_sym__alignof] = ACTIONS(2260),
    [anon_sym_alignof] = ACTIONS(2260),
    [anon_sym__Alignof] = ACTIONS(2260),
    [anon_sym_offsetof] = ACTIONS(2260),
    [anon_sym__Generic] = ACTIONS(2260),
    [anon_sym_asm] = ACTIONS(2260),
    [anon_sym___asm__] = ACTIONS(2260),
    [sym_number_literal] = ACTIONS(2262),
    [anon_sym_L_SQUOTE] = ACTIONS(2262),
    [anon_sym_u_SQUOTE] = ACTIONS(2262),
    [anon_sym_U_SQUOTE] = ACTIONS(2262),
    [anon_sym_u8_SQUOTE] = ACTIONS(2262),
    [anon_sym_SQUOTE] = ACTIONS(2262),
    [anon_sym_L_DQUOTE] = ACTIONS(2262),
    [anon_sym_u_DQUOTE] = ACTIONS(2262),
    [anon_sym_U_DQUOTE] = ACTIONS(2262),
    [anon_sym_u8_DQUOTE] = ACTIONS(2262),
    [anon_sym_DQUOTE] = ACTIONS(2262),
    [sym_true] = ACTIONS(2260),
    [sym_false] = ACTIONS(2260),
    [anon_sym_NULL] = ACTIONS(2260),
    [anon_sym_nullptr] = ACTIONS(2260),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2260),
    [anon_sym_decltype] = ACTIONS(2260),
    [sym_virtual] = ACTIONS(2260),
    [anon_sym_explicit] = ACTIONS(2260),
    [anon_sym_typename] = ACTIONS(2260),
    [anon_sym_template] = ACTIONS(2260),
    [anon_sym_operator] = ACTIONS(2260),
    [anon_sym_try] = ACTIONS(2260),
    [anon_sym_delete] = ACTIONS(2260),
    [anon_sym_throw] = ACTIONS(2260),
    [anon_sym_namespace] = ACTIONS(2260),
    [anon_sym_using] = ACTIONS(2260),
    [anon_sym_static_assert] = ACTIONS(2260),
    [anon_sym_concept] = ACTIONS(2260),
    [anon_sym_co_return] = ACTIONS(2260),
    [anon_sym_co_yield] = ACTIONS(2260),
    [anon_sym_R_DQUOTE] = ACTIONS(2262),
    [anon_sym_LR_DQUOTE] = ACTIONS(2262),
    [anon_sym_uR_DQUOTE] = ACTIONS(2262),
    [anon_sym_UR_DQUOTE] = ACTIONS(2262),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2262),
    [anon_sym_co_await] = ACTIONS(2260),
    [anon_sym_new] = ACTIONS(2260),
    [anon_sym_requires] = ACTIONS(2260),
    [sym_this] = ACTIONS(2260),
    [anon_sym_discard] = ACTIONS(2260),
    [anon_sym_precise] = ACTIONS(2260),
    [anon_sym_shared] = ACTIONS(2260),
    [anon_sym_groupshared] = ACTIONS(2260),
    [anon_sym_uniform] = ACTIONS(2260),
    [anon_sym_row_major] = ACTIONS(2260),
    [anon_sym_column_major] = ACTIONS(2260),
    [anon_sym_globallycoherent] = ACTIONS(2260),
    [anon_sym_centroid] = ACTIONS(2260),
    [anon_sym_noperspective] = ACTIONS(2260),
    [anon_sym_nointerpolation] = ACTIONS(2260),
    [anon_sym_sample] = ACTIONS(2260),
    [anon_sym_linear] = ACTIONS(2260),
    [anon_sym_snorm] = ACTIONS(2260),
    [anon_sym_unorm] = ACTIONS(2260),
    [anon_sym_point] = ACTIONS(2260),
    [anon_sym_line] = ACTIONS(2260),
    [anon_sym_triangleadj] = ACTIONS(2260),
    [anon_sym_lineadj] = ACTIONS(2260),
    [anon_sym_triangle] = ACTIONS(2260),
    [anon_sym_cbuffer] = ACTIONS(2260),
  },
  [424] = {
    [ts_builtin_sym_end] = ACTIONS(2210),
    [sym_identifier] = ACTIONS(2208),
    [aux_sym_preproc_include_token1] = ACTIONS(2208),
    [aux_sym_preproc_def_token1] = ACTIONS(2208),
    [aux_sym_preproc_if_token1] = ACTIONS(2208),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2208),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2208),
    [sym_preproc_directive] = ACTIONS(2208),
    [anon_sym_LPAREN2] = ACTIONS(2210),
    [anon_sym_BANG] = ACTIONS(2210),
    [anon_sym_TILDE] = ACTIONS(2210),
    [anon_sym_DASH] = ACTIONS(2208),
    [anon_sym_PLUS] = ACTIONS(2208),
    [anon_sym_STAR] = ACTIONS(2210),
    [anon_sym_AMP_AMP] = ACTIONS(2210),
    [anon_sym_AMP] = ACTIONS(2208),
    [anon_sym_SEMI] = ACTIONS(2210),
    [anon_sym___extension__] = ACTIONS(2208),
    [anon_sym_typedef] = ACTIONS(2208),
    [anon_sym_in] = ACTIONS(2208),
    [anon_sym_out] = ACTIONS(2208),
    [anon_sym_inout] = ACTIONS(2208),
    [anon_sym_extern] = ACTIONS(2208),
    [anon_sym___attribute__] = ACTIONS(2208),
    [anon_sym_COLON_COLON] = ACTIONS(2210),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2210),
    [anon_sym___declspec] = ACTIONS(2208),
    [anon_sym___based] = ACTIONS(2208),
    [anon_sym___cdecl] = ACTIONS(2208),
    [anon_sym___clrcall] = ACTIONS(2208),
    [anon_sym___stdcall] = ACTIONS(2208),
    [anon_sym___fastcall] = ACTIONS(2208),
    [anon_sym___thiscall] = ACTIONS(2208),
    [anon_sym___vectorcall] = ACTIONS(2208),
    [anon_sym_LBRACE] = ACTIONS(2210),
    [anon_sym_signed] = ACTIONS(2208),
    [anon_sym_unsigned] = ACTIONS(2208),
    [anon_sym_long] = ACTIONS(2208),
    [anon_sym_short] = ACTIONS(2208),
    [anon_sym_LBRACK] = ACTIONS(2208),
    [anon_sym_static] = ACTIONS(2208),
    [anon_sym_register] = ACTIONS(2208),
    [anon_sym_inline] = ACTIONS(2208),
    [anon_sym___inline] = ACTIONS(2208),
    [anon_sym___inline__] = ACTIONS(2208),
    [anon_sym___forceinline] = ACTIONS(2208),
    [anon_sym_thread_local] = ACTIONS(2208),
    [anon_sym___thread] = ACTIONS(2208),
    [anon_sym_const] = ACTIONS(2208),
    [anon_sym_constexpr] = ACTIONS(2208),
    [anon_sym_volatile] = ACTIONS(2208),
    [anon_sym_restrict] = ACTIONS(2208),
    [anon_sym___restrict__] = ACTIONS(2208),
    [anon_sym__Atomic] = ACTIONS(2208),
    [anon_sym__Noreturn] = ACTIONS(2208),
    [anon_sym_noreturn] = ACTIONS(2208),
    [anon_sym_mutable] = ACTIONS(2208),
    [anon_sym_constinit] = ACTIONS(2208),
    [anon_sym_consteval] = ACTIONS(2208),
    [anon_sym_alignas] = ACTIONS(2208),
    [anon_sym__Alignas] = ACTIONS(2208),
    [sym_primitive_type] = ACTIONS(2208),
    [anon_sym_enum] = ACTIONS(2208),
    [anon_sym_class] = ACTIONS(2208),
    [anon_sym_struct] = ACTIONS(2208),
    [anon_sym_union] = ACTIONS(2208),
    [anon_sym_if] = ACTIONS(2208),
    [anon_sym_else] = ACTIONS(2208),
    [anon_sym_switch] = ACTIONS(2208),
    [anon_sym_case] = ACTIONS(2208),
    [anon_sym_default] = ACTIONS(2208),
    [anon_sym_while] = ACTIONS(2208),
    [anon_sym_do] = ACTIONS(2208),
    [anon_sym_for] = ACTIONS(2208),
    [anon_sym_return] = ACTIONS(2208),
    [anon_sym_break] = ACTIONS(2208),
    [anon_sym_continue] = ACTIONS(2208),
    [anon_sym_goto] = ACTIONS(2208),
    [anon_sym___try] = ACTIONS(2208),
    [anon_sym___leave] = ACTIONS(2208),
    [anon_sym_not] = ACTIONS(2208),
    [anon_sym_compl] = ACTIONS(2208),
    [anon_sym_DASH_DASH] = ACTIONS(2210),
    [anon_sym_PLUS_PLUS] = ACTIONS(2210),
    [anon_sym_sizeof] = ACTIONS(2208),
    [anon_sym___alignof__] = ACTIONS(2208),
    [anon_sym___alignof] = ACTIONS(2208),
    [anon_sym__alignof] = ACTIONS(2208),
    [anon_sym_alignof] = ACTIONS(2208),
    [anon_sym__Alignof] = ACTIONS(2208),
    [anon_sym_offsetof] = ACTIONS(2208),
    [anon_sym__Generic] = ACTIONS(2208),
    [anon_sym_asm] = ACTIONS(2208),
    [anon_sym___asm__] = ACTIONS(2208),
    [sym_number_literal] = ACTIONS(2210),
    [anon_sym_L_SQUOTE] = ACTIONS(2210),
    [anon_sym_u_SQUOTE] = ACTIONS(2210),
    [anon_sym_U_SQUOTE] = ACTIONS(2210),
    [anon_sym_u8_SQUOTE] = ACTIONS(2210),
    [anon_sym_SQUOTE] = ACTIONS(2210),
    [anon_sym_L_DQUOTE] = ACTIONS(2210),
    [anon_sym_u_DQUOTE] = ACTIONS(2210),
    [anon_sym_U_DQUOTE] = ACTIONS(2210),
    [anon_sym_u8_DQUOTE] = ACTIONS(2210),
    [anon_sym_DQUOTE] = ACTIONS(2210),
    [sym_true] = ACTIONS(2208),
    [sym_false] = ACTIONS(2208),
    [anon_sym_NULL] = ACTIONS(2208),
    [anon_sym_nullptr] = ACTIONS(2208),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2208),
    [anon_sym_decltype] = ACTIONS(2208),
    [sym_virtual] = ACTIONS(2208),
    [anon_sym_explicit] = ACTIONS(2208),
    [anon_sym_typename] = ACTIONS(2208),
    [anon_sym_template] = ACTIONS(2208),
    [anon_sym_operator] = ACTIONS(2208),
    [anon_sym_try] = ACTIONS(2208),
    [anon_sym_delete] = ACTIONS(2208),
    [anon_sym_throw] = ACTIONS(2208),
    [anon_sym_namespace] = ACTIONS(2208),
    [anon_sym_using] = ACTIONS(2208),
    [anon_sym_static_assert] = ACTIONS(2208),
    [anon_sym_concept] = ACTIONS(2208),
    [anon_sym_co_return] = ACTIONS(2208),
    [anon_sym_co_yield] = ACTIONS(2208),
    [anon_sym_R_DQUOTE] = ACTIONS(2210),
    [anon_sym_LR_DQUOTE] = ACTIONS(2210),
    [anon_sym_uR_DQUOTE] = ACTIONS(2210),
    [anon_sym_UR_DQUOTE] = ACTIONS(2210),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2210),
    [anon_sym_co_await] = ACTIONS(2208),
    [anon_sym_new] = ACTIONS(2208),
    [anon_sym_requires] = ACTIONS(2208),
    [sym_this] = ACTIONS(2208),
    [anon_sym_discard] = ACTIONS(2208),
    [anon_sym_precise] = ACTIONS(2208),
    [anon_sym_shared] = ACTIONS(2208),
    [anon_sym_groupshared] = ACTIONS(2208),
    [anon_sym_uniform] = ACTIONS(2208),
    [anon_sym_row_major] = ACTIONS(2208),
    [anon_sym_column_major] = ACTIONS(2208),
    [anon_sym_globallycoherent] = ACTIONS(2208),
    [anon_sym_centroid] = ACTIONS(2208),
    [anon_sym_noperspective] = ACTIONS(2208),
    [anon_sym_nointerpolation] = ACTIONS(2208),
    [anon_sym_sample] = ACTIONS(2208),
    [anon_sym_linear] = ACTIONS(2208),
    [anon_sym_snorm] = ACTIONS(2208),
    [anon_sym_unorm] = ACTIONS(2208),
    [anon_sym_point] = ACTIONS(2208),
    [anon_sym_line] = ACTIONS(2208),
    [anon_sym_triangleadj] = ACTIONS(2208),
    [anon_sym_lineadj] = ACTIONS(2208),
    [anon_sym_triangle] = ACTIONS(2208),
    [anon_sym_cbuffer] = ACTIONS(2208),
  },
  [425] = {
    [ts_builtin_sym_end] = ACTIONS(2214),
    [sym_identifier] = ACTIONS(2212),
    [aux_sym_preproc_include_token1] = ACTIONS(2212),
    [aux_sym_preproc_def_token1] = ACTIONS(2212),
    [aux_sym_preproc_if_token1] = ACTIONS(2212),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2212),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2212),
    [sym_preproc_directive] = ACTIONS(2212),
    [anon_sym_LPAREN2] = ACTIONS(2214),
    [anon_sym_BANG] = ACTIONS(2214),
    [anon_sym_TILDE] = ACTIONS(2214),
    [anon_sym_DASH] = ACTIONS(2212),
    [anon_sym_PLUS] = ACTIONS(2212),
    [anon_sym_STAR] = ACTIONS(2214),
    [anon_sym_AMP_AMP] = ACTIONS(2214),
    [anon_sym_AMP] = ACTIONS(2212),
    [anon_sym_SEMI] = ACTIONS(2214),
    [anon_sym___extension__] = ACTIONS(2212),
    [anon_sym_typedef] = ACTIONS(2212),
    [anon_sym_in] = ACTIONS(2212),
    [anon_sym_out] = ACTIONS(2212),
    [anon_sym_inout] = ACTIONS(2212),
    [anon_sym_extern] = ACTIONS(2212),
    [anon_sym___attribute__] = ACTIONS(2212),
    [anon_sym_COLON_COLON] = ACTIONS(2214),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2214),
    [anon_sym___declspec] = ACTIONS(2212),
    [anon_sym___based] = ACTIONS(2212),
    [anon_sym___cdecl] = ACTIONS(2212),
    [anon_sym___clrcall] = ACTIONS(2212),
    [anon_sym___stdcall] = ACTIONS(2212),
    [anon_sym___fastcall] = ACTIONS(2212),
    [anon_sym___thiscall] = ACTIONS(2212),
    [anon_sym___vectorcall] = ACTIONS(2212),
    [anon_sym_LBRACE] = ACTIONS(2214),
    [anon_sym_signed] = ACTIONS(2212),
    [anon_sym_unsigned] = ACTIONS(2212),
    [anon_sym_long] = ACTIONS(2212),
    [anon_sym_short] = ACTIONS(2212),
    [anon_sym_LBRACK] = ACTIONS(2212),
    [anon_sym_static] = ACTIONS(2212),
    [anon_sym_register] = ACTIONS(2212),
    [anon_sym_inline] = ACTIONS(2212),
    [anon_sym___inline] = ACTIONS(2212),
    [anon_sym___inline__] = ACTIONS(2212),
    [anon_sym___forceinline] = ACTIONS(2212),
    [anon_sym_thread_local] = ACTIONS(2212),
    [anon_sym___thread] = ACTIONS(2212),
    [anon_sym_const] = ACTIONS(2212),
    [anon_sym_constexpr] = ACTIONS(2212),
    [anon_sym_volatile] = ACTIONS(2212),
    [anon_sym_restrict] = ACTIONS(2212),
    [anon_sym___restrict__] = ACTIONS(2212),
    [anon_sym__Atomic] = ACTIONS(2212),
    [anon_sym__Noreturn] = ACTIONS(2212),
    [anon_sym_noreturn] = ACTIONS(2212),
    [anon_sym_mutable] = ACTIONS(2212),
    [anon_sym_constinit] = ACTIONS(2212),
    [anon_sym_consteval] = ACTIONS(2212),
    [anon_sym_alignas] = ACTIONS(2212),
    [anon_sym__Alignas] = ACTIONS(2212),
    [sym_primitive_type] = ACTIONS(2212),
    [anon_sym_enum] = ACTIONS(2212),
    [anon_sym_class] = ACTIONS(2212),
    [anon_sym_struct] = ACTIONS(2212),
    [anon_sym_union] = ACTIONS(2212),
    [anon_sym_if] = ACTIONS(2212),
    [anon_sym_else] = ACTIONS(2212),
    [anon_sym_switch] = ACTIONS(2212),
    [anon_sym_case] = ACTIONS(2212),
    [anon_sym_default] = ACTIONS(2212),
    [anon_sym_while] = ACTIONS(2212),
    [anon_sym_do] = ACTIONS(2212),
    [anon_sym_for] = ACTIONS(2212),
    [anon_sym_return] = ACTIONS(2212),
    [anon_sym_break] = ACTIONS(2212),
    [anon_sym_continue] = ACTIONS(2212),
    [anon_sym_goto] = ACTIONS(2212),
    [anon_sym___try] = ACTIONS(2212),
    [anon_sym___leave] = ACTIONS(2212),
    [anon_sym_not] = ACTIONS(2212),
    [anon_sym_compl] = ACTIONS(2212),
    [anon_sym_DASH_DASH] = ACTIONS(2214),
    [anon_sym_PLUS_PLUS] = ACTIONS(2214),
    [anon_sym_sizeof] = ACTIONS(2212),
    [anon_sym___alignof__] = ACTIONS(2212),
    [anon_sym___alignof] = ACTIONS(2212),
    [anon_sym__alignof] = ACTIONS(2212),
    [anon_sym_alignof] = ACTIONS(2212),
    [anon_sym__Alignof] = ACTIONS(2212),
    [anon_sym_offsetof] = ACTIONS(2212),
    [anon_sym__Generic] = ACTIONS(2212),
    [anon_sym_asm] = ACTIONS(2212),
    [anon_sym___asm__] = ACTIONS(2212),
    [sym_number_literal] = ACTIONS(2214),
    [anon_sym_L_SQUOTE] = ACTIONS(2214),
    [anon_sym_u_SQUOTE] = ACTIONS(2214),
    [anon_sym_U_SQUOTE] = ACTIONS(2214),
    [anon_sym_u8_SQUOTE] = ACTIONS(2214),
    [anon_sym_SQUOTE] = ACTIONS(2214),
    [anon_sym_L_DQUOTE] = ACTIONS(2214),
    [anon_sym_u_DQUOTE] = ACTIONS(2214),
    [anon_sym_U_DQUOTE] = ACTIONS(2214),
    [anon_sym_u8_DQUOTE] = ACTIONS(2214),
    [anon_sym_DQUOTE] = ACTIONS(2214),
    [sym_true] = ACTIONS(2212),
    [sym_false] = ACTIONS(2212),
    [anon_sym_NULL] = ACTIONS(2212),
    [anon_sym_nullptr] = ACTIONS(2212),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2212),
    [anon_sym_decltype] = ACTIONS(2212),
    [sym_virtual] = ACTIONS(2212),
    [anon_sym_explicit] = ACTIONS(2212),
    [anon_sym_typename] = ACTIONS(2212),
    [anon_sym_template] = ACTIONS(2212),
    [anon_sym_operator] = ACTIONS(2212),
    [anon_sym_try] = ACTIONS(2212),
    [anon_sym_delete] = ACTIONS(2212),
    [anon_sym_throw] = ACTIONS(2212),
    [anon_sym_namespace] = ACTIONS(2212),
    [anon_sym_using] = ACTIONS(2212),
    [anon_sym_static_assert] = ACTIONS(2212),
    [anon_sym_concept] = ACTIONS(2212),
    [anon_sym_co_return] = ACTIONS(2212),
    [anon_sym_co_yield] = ACTIONS(2212),
    [anon_sym_R_DQUOTE] = ACTIONS(2214),
    [anon_sym_LR_DQUOTE] = ACTIONS(2214),
    [anon_sym_uR_DQUOTE] = ACTIONS(2214),
    [anon_sym_UR_DQUOTE] = ACTIONS(2214),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2214),
    [anon_sym_co_await] = ACTIONS(2212),
    [anon_sym_new] = ACTIONS(2212),
    [anon_sym_requires] = ACTIONS(2212),
    [sym_this] = ACTIONS(2212),
    [anon_sym_discard] = ACTIONS(2212),
    [anon_sym_precise] = ACTIONS(2212),
    [anon_sym_shared] = ACTIONS(2212),
    [anon_sym_groupshared] = ACTIONS(2212),
    [anon_sym_uniform] = ACTIONS(2212),
    [anon_sym_row_major] = ACTIONS(2212),
    [anon_sym_column_major] = ACTIONS(2212),
    [anon_sym_globallycoherent] = ACTIONS(2212),
    [anon_sym_centroid] = ACTIONS(2212),
    [anon_sym_noperspective] = ACTIONS(2212),
    [anon_sym_nointerpolation] = ACTIONS(2212),
    [anon_sym_sample] = ACTIONS(2212),
    [anon_sym_linear] = ACTIONS(2212),
    [anon_sym_snorm] = ACTIONS(2212),
    [anon_sym_unorm] = ACTIONS(2212),
    [anon_sym_point] = ACTIONS(2212),
    [anon_sym_line] = ACTIONS(2212),
    [anon_sym_triangleadj] = ACTIONS(2212),
    [anon_sym_lineadj] = ACTIONS(2212),
    [anon_sym_triangle] = ACTIONS(2212),
    [anon_sym_cbuffer] = ACTIONS(2212),
  },
  [426] = {
    [sym_identifier] = ACTIONS(2232),
    [aux_sym_preproc_include_token1] = ACTIONS(2232),
    [aux_sym_preproc_def_token1] = ACTIONS(2232),
    [aux_sym_preproc_if_token1] = ACTIONS(2232),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2232),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2232),
    [sym_preproc_directive] = ACTIONS(2232),
    [anon_sym_LPAREN2] = ACTIONS(2234),
    [anon_sym_BANG] = ACTIONS(2234),
    [anon_sym_TILDE] = ACTIONS(2234),
    [anon_sym_DASH] = ACTIONS(2232),
    [anon_sym_PLUS] = ACTIONS(2232),
    [anon_sym_STAR] = ACTIONS(2234),
    [anon_sym_AMP_AMP] = ACTIONS(2234),
    [anon_sym_AMP] = ACTIONS(2232),
    [anon_sym_SEMI] = ACTIONS(2234),
    [anon_sym___extension__] = ACTIONS(2232),
    [anon_sym_typedef] = ACTIONS(2232),
    [anon_sym_in] = ACTIONS(2232),
    [anon_sym_out] = ACTIONS(2232),
    [anon_sym_inout] = ACTIONS(2232),
    [anon_sym_extern] = ACTIONS(2232),
    [anon_sym___attribute__] = ACTIONS(2232),
    [anon_sym_COLON_COLON] = ACTIONS(2234),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2234),
    [anon_sym___declspec] = ACTIONS(2232),
    [anon_sym___based] = ACTIONS(2232),
    [anon_sym___cdecl] = ACTIONS(2232),
    [anon_sym___clrcall] = ACTIONS(2232),
    [anon_sym___stdcall] = ACTIONS(2232),
    [anon_sym___fastcall] = ACTIONS(2232),
    [anon_sym___thiscall] = ACTIONS(2232),
    [anon_sym___vectorcall] = ACTIONS(2232),
    [anon_sym_LBRACE] = ACTIONS(2234),
    [anon_sym_RBRACE] = ACTIONS(2234),
    [anon_sym_signed] = ACTIONS(2232),
    [anon_sym_unsigned] = ACTIONS(2232),
    [anon_sym_long] = ACTIONS(2232),
    [anon_sym_short] = ACTIONS(2232),
    [anon_sym_LBRACK] = ACTIONS(2232),
    [anon_sym_static] = ACTIONS(2232),
    [anon_sym_register] = ACTIONS(2232),
    [anon_sym_inline] = ACTIONS(2232),
    [anon_sym___inline] = ACTIONS(2232),
    [anon_sym___inline__] = ACTIONS(2232),
    [anon_sym___forceinline] = ACTIONS(2232),
    [anon_sym_thread_local] = ACTIONS(2232),
    [anon_sym___thread] = ACTIONS(2232),
    [anon_sym_const] = ACTIONS(2232),
    [anon_sym_constexpr] = ACTIONS(2232),
    [anon_sym_volatile] = ACTIONS(2232),
    [anon_sym_restrict] = ACTIONS(2232),
    [anon_sym___restrict__] = ACTIONS(2232),
    [anon_sym__Atomic] = ACTIONS(2232),
    [anon_sym__Noreturn] = ACTIONS(2232),
    [anon_sym_noreturn] = ACTIONS(2232),
    [anon_sym_mutable] = ACTIONS(2232),
    [anon_sym_constinit] = ACTIONS(2232),
    [anon_sym_consteval] = ACTIONS(2232),
    [anon_sym_alignas] = ACTIONS(2232),
    [anon_sym__Alignas] = ACTIONS(2232),
    [sym_primitive_type] = ACTIONS(2232),
    [anon_sym_enum] = ACTIONS(2232),
    [anon_sym_class] = ACTIONS(2232),
    [anon_sym_struct] = ACTIONS(2232),
    [anon_sym_union] = ACTIONS(2232),
    [anon_sym_if] = ACTIONS(2232),
    [anon_sym_else] = ACTIONS(2232),
    [anon_sym_switch] = ACTIONS(2232),
    [anon_sym_case] = ACTIONS(2232),
    [anon_sym_default] = ACTIONS(2232),
    [anon_sym_while] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(2232),
    [anon_sym_for] = ACTIONS(2232),
    [anon_sym_return] = ACTIONS(2232),
    [anon_sym_break] = ACTIONS(2232),
    [anon_sym_continue] = ACTIONS(2232),
    [anon_sym_goto] = ACTIONS(2232),
    [anon_sym___try] = ACTIONS(2232),
    [anon_sym___leave] = ACTIONS(2232),
    [anon_sym_not] = ACTIONS(2232),
    [anon_sym_compl] = ACTIONS(2232),
    [anon_sym_DASH_DASH] = ACTIONS(2234),
    [anon_sym_PLUS_PLUS] = ACTIONS(2234),
    [anon_sym_sizeof] = ACTIONS(2232),
    [anon_sym___alignof__] = ACTIONS(2232),
    [anon_sym___alignof] = ACTIONS(2232),
    [anon_sym__alignof] = ACTIONS(2232),
    [anon_sym_alignof] = ACTIONS(2232),
    [anon_sym__Alignof] = ACTIONS(2232),
    [anon_sym_offsetof] = ACTIONS(2232),
    [anon_sym__Generic] = ACTIONS(2232),
    [anon_sym_asm] = ACTIONS(2232),
    [anon_sym___asm__] = ACTIONS(2232),
    [sym_number_literal] = ACTIONS(2234),
    [anon_sym_L_SQUOTE] = ACTIONS(2234),
    [anon_sym_u_SQUOTE] = ACTIONS(2234),
    [anon_sym_U_SQUOTE] = ACTIONS(2234),
    [anon_sym_u8_SQUOTE] = ACTIONS(2234),
    [anon_sym_SQUOTE] = ACTIONS(2234),
    [anon_sym_L_DQUOTE] = ACTIONS(2234),
    [anon_sym_u_DQUOTE] = ACTIONS(2234),
    [anon_sym_U_DQUOTE] = ACTIONS(2234),
    [anon_sym_u8_DQUOTE] = ACTIONS(2234),
    [anon_sym_DQUOTE] = ACTIONS(2234),
    [sym_true] = ACTIONS(2232),
    [sym_false] = ACTIONS(2232),
    [anon_sym_NULL] = ACTIONS(2232),
    [anon_sym_nullptr] = ACTIONS(2232),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2232),
    [anon_sym_decltype] = ACTIONS(2232),
    [sym_virtual] = ACTIONS(2232),
    [anon_sym_explicit] = ACTIONS(2232),
    [anon_sym_typename] = ACTIONS(2232),
    [anon_sym_template] = ACTIONS(2232),
    [anon_sym_operator] = ACTIONS(2232),
    [anon_sym_try] = ACTIONS(2232),
    [anon_sym_delete] = ACTIONS(2232),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_namespace] = ACTIONS(2232),
    [anon_sym_using] = ACTIONS(2232),
    [anon_sym_static_assert] = ACTIONS(2232),
    [anon_sym_concept] = ACTIONS(2232),
    [anon_sym_co_return] = ACTIONS(2232),
    [anon_sym_co_yield] = ACTIONS(2232),
    [anon_sym_R_DQUOTE] = ACTIONS(2234),
    [anon_sym_LR_DQUOTE] = ACTIONS(2234),
    [anon_sym_uR_DQUOTE] = ACTIONS(2234),
    [anon_sym_UR_DQUOTE] = ACTIONS(2234),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2234),
    [anon_sym_co_await] = ACTIONS(2232),
    [anon_sym_new] = ACTIONS(2232),
    [anon_sym_requires] = ACTIONS(2232),
    [sym_this] = ACTIONS(2232),
    [anon_sym_discard] = ACTIONS(2232),
    [anon_sym_precise] = ACTIONS(2232),
    [anon_sym_shared] = ACTIONS(2232),
    [anon_sym_groupshared] = ACTIONS(2232),
    [anon_sym_uniform] = ACTIONS(2232),
    [anon_sym_row_major] = ACTIONS(2232),
    [anon_sym_column_major] = ACTIONS(2232),
    [anon_sym_globallycoherent] = ACTIONS(2232),
    [anon_sym_centroid] = ACTIONS(2232),
    [anon_sym_noperspective] = ACTIONS(2232),
    [anon_sym_nointerpolation] = ACTIONS(2232),
    [anon_sym_sample] = ACTIONS(2232),
    [anon_sym_linear] = ACTIONS(2232),
    [anon_sym_snorm] = ACTIONS(2232),
    [anon_sym_unorm] = ACTIONS(2232),
    [anon_sym_point] = ACTIONS(2232),
    [anon_sym_line] = ACTIONS(2232),
    [anon_sym_triangleadj] = ACTIONS(2232),
    [anon_sym_lineadj] = ACTIONS(2232),
    [anon_sym_triangle] = ACTIONS(2232),
    [anon_sym_cbuffer] = ACTIONS(2232),
  },
  [427] = {
    [sym_identifier] = ACTIONS(2280),
    [aux_sym_preproc_include_token1] = ACTIONS(2280),
    [aux_sym_preproc_def_token1] = ACTIONS(2280),
    [aux_sym_preproc_if_token1] = ACTIONS(2280),
    [aux_sym_preproc_if_token2] = ACTIONS(2280),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2280),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2280),
    [sym_preproc_directive] = ACTIONS(2280),
    [anon_sym_LPAREN2] = ACTIONS(2282),
    [anon_sym_BANG] = ACTIONS(2282),
    [anon_sym_TILDE] = ACTIONS(2282),
    [anon_sym_DASH] = ACTIONS(2280),
    [anon_sym_PLUS] = ACTIONS(2280),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_AMP_AMP] = ACTIONS(2282),
    [anon_sym_AMP] = ACTIONS(2280),
    [anon_sym_SEMI] = ACTIONS(2282),
    [anon_sym___extension__] = ACTIONS(2280),
    [anon_sym_typedef] = ACTIONS(2280),
    [anon_sym_in] = ACTIONS(2280),
    [anon_sym_out] = ACTIONS(2280),
    [anon_sym_inout] = ACTIONS(2280),
    [anon_sym_extern] = ACTIONS(2280),
    [anon_sym___attribute__] = ACTIONS(2280),
    [anon_sym_COLON_COLON] = ACTIONS(2282),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2282),
    [anon_sym___declspec] = ACTIONS(2280),
    [anon_sym___based] = ACTIONS(2280),
    [anon_sym___cdecl] = ACTIONS(2280),
    [anon_sym___clrcall] = ACTIONS(2280),
    [anon_sym___stdcall] = ACTIONS(2280),
    [anon_sym___fastcall] = ACTIONS(2280),
    [anon_sym___thiscall] = ACTIONS(2280),
    [anon_sym___vectorcall] = ACTIONS(2280),
    [anon_sym_LBRACE] = ACTIONS(2282),
    [anon_sym_signed] = ACTIONS(2280),
    [anon_sym_unsigned] = ACTIONS(2280),
    [anon_sym_long] = ACTIONS(2280),
    [anon_sym_short] = ACTIONS(2280),
    [anon_sym_LBRACK] = ACTIONS(2280),
    [anon_sym_static] = ACTIONS(2280),
    [anon_sym_register] = ACTIONS(2280),
    [anon_sym_inline] = ACTIONS(2280),
    [anon_sym___inline] = ACTIONS(2280),
    [anon_sym___inline__] = ACTIONS(2280),
    [anon_sym___forceinline] = ACTIONS(2280),
    [anon_sym_thread_local] = ACTIONS(2280),
    [anon_sym___thread] = ACTIONS(2280),
    [anon_sym_const] = ACTIONS(2280),
    [anon_sym_constexpr] = ACTIONS(2280),
    [anon_sym_volatile] = ACTIONS(2280),
    [anon_sym_restrict] = ACTIONS(2280),
    [anon_sym___restrict__] = ACTIONS(2280),
    [anon_sym__Atomic] = ACTIONS(2280),
    [anon_sym__Noreturn] = ACTIONS(2280),
    [anon_sym_noreturn] = ACTIONS(2280),
    [anon_sym_mutable] = ACTIONS(2280),
    [anon_sym_constinit] = ACTIONS(2280),
    [anon_sym_consteval] = ACTIONS(2280),
    [anon_sym_alignas] = ACTIONS(2280),
    [anon_sym__Alignas] = ACTIONS(2280),
    [sym_primitive_type] = ACTIONS(2280),
    [anon_sym_enum] = ACTIONS(2280),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2280),
    [anon_sym_union] = ACTIONS(2280),
    [anon_sym_if] = ACTIONS(2280),
    [anon_sym_else] = ACTIONS(2280),
    [anon_sym_switch] = ACTIONS(2280),
    [anon_sym_case] = ACTIONS(2280),
    [anon_sym_default] = ACTIONS(2280),
    [anon_sym_while] = ACTIONS(2280),
    [anon_sym_do] = ACTIONS(2280),
    [anon_sym_for] = ACTIONS(2280),
    [anon_sym_return] = ACTIONS(2280),
    [anon_sym_break] = ACTIONS(2280),
    [anon_sym_continue] = ACTIONS(2280),
    [anon_sym_goto] = ACTIONS(2280),
    [anon_sym___try] = ACTIONS(2280),
    [anon_sym___leave] = ACTIONS(2280),
    [anon_sym_not] = ACTIONS(2280),
    [anon_sym_compl] = ACTIONS(2280),
    [anon_sym_DASH_DASH] = ACTIONS(2282),
    [anon_sym_PLUS_PLUS] = ACTIONS(2282),
    [anon_sym_sizeof] = ACTIONS(2280),
    [anon_sym___alignof__] = ACTIONS(2280),
    [anon_sym___alignof] = ACTIONS(2280),
    [anon_sym__alignof] = ACTIONS(2280),
    [anon_sym_alignof] = ACTIONS(2280),
    [anon_sym__Alignof] = ACTIONS(2280),
    [anon_sym_offsetof] = ACTIONS(2280),
    [anon_sym__Generic] = ACTIONS(2280),
    [anon_sym_asm] = ACTIONS(2280),
    [anon_sym___asm__] = ACTIONS(2280),
    [sym_number_literal] = ACTIONS(2282),
    [anon_sym_L_SQUOTE] = ACTIONS(2282),
    [anon_sym_u_SQUOTE] = ACTIONS(2282),
    [anon_sym_U_SQUOTE] = ACTIONS(2282),
    [anon_sym_u8_SQUOTE] = ACTIONS(2282),
    [anon_sym_SQUOTE] = ACTIONS(2282),
    [anon_sym_L_DQUOTE] = ACTIONS(2282),
    [anon_sym_u_DQUOTE] = ACTIONS(2282),
    [anon_sym_U_DQUOTE] = ACTIONS(2282),
    [anon_sym_u8_DQUOTE] = ACTIONS(2282),
    [anon_sym_DQUOTE] = ACTIONS(2282),
    [sym_true] = ACTIONS(2280),
    [sym_false] = ACTIONS(2280),
    [anon_sym_NULL] = ACTIONS(2280),
    [anon_sym_nullptr] = ACTIONS(2280),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2280),
    [anon_sym_decltype] = ACTIONS(2280),
    [sym_virtual] = ACTIONS(2280),
    [anon_sym_explicit] = ACTIONS(2280),
    [anon_sym_typename] = ACTIONS(2280),
    [anon_sym_template] = ACTIONS(2280),
    [anon_sym_operator] = ACTIONS(2280),
    [anon_sym_try] = ACTIONS(2280),
    [anon_sym_delete] = ACTIONS(2280),
    [anon_sym_throw] = ACTIONS(2280),
    [anon_sym_namespace] = ACTIONS(2280),
    [anon_sym_using] = ACTIONS(2280),
    [anon_sym_static_assert] = ACTIONS(2280),
    [anon_sym_concept] = ACTIONS(2280),
    [anon_sym_co_return] = ACTIONS(2280),
    [anon_sym_co_yield] = ACTIONS(2280),
    [anon_sym_R_DQUOTE] = ACTIONS(2282),
    [anon_sym_LR_DQUOTE] = ACTIONS(2282),
    [anon_sym_uR_DQUOTE] = ACTIONS(2282),
    [anon_sym_UR_DQUOTE] = ACTIONS(2282),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2282),
    [anon_sym_co_await] = ACTIONS(2280),
    [anon_sym_new] = ACTIONS(2280),
    [anon_sym_requires] = ACTIONS(2280),
    [sym_this] = ACTIONS(2280),
    [anon_sym_discard] = ACTIONS(2280),
    [anon_sym_precise] = ACTIONS(2280),
    [anon_sym_shared] = ACTIONS(2280),
    [anon_sym_groupshared] = ACTIONS(2280),
    [anon_sym_uniform] = ACTIONS(2280),
    [anon_sym_row_major] = ACTIONS(2280),
    [anon_sym_column_major] = ACTIONS(2280),
    [anon_sym_globallycoherent] = ACTIONS(2280),
    [anon_sym_centroid] = ACTIONS(2280),
    [anon_sym_noperspective] = ACTIONS(2280),
    [anon_sym_nointerpolation] = ACTIONS(2280),
    [anon_sym_sample] = ACTIONS(2280),
    [anon_sym_linear] = ACTIONS(2280),
    [anon_sym_snorm] = ACTIONS(2280),
    [anon_sym_unorm] = ACTIONS(2280),
    [anon_sym_point] = ACTIONS(2280),
    [anon_sym_line] = ACTIONS(2280),
    [anon_sym_triangleadj] = ACTIONS(2280),
    [anon_sym_lineadj] = ACTIONS(2280),
    [anon_sym_triangle] = ACTIONS(2280),
    [anon_sym_cbuffer] = ACTIONS(2280),
  },
  [428] = {
    [sym_identifier] = ACTIONS(2248),
    [aux_sym_preproc_include_token1] = ACTIONS(2248),
    [aux_sym_preproc_def_token1] = ACTIONS(2248),
    [aux_sym_preproc_if_token1] = ACTIONS(2248),
    [aux_sym_preproc_if_token2] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2248),
    [sym_preproc_directive] = ACTIONS(2248),
    [anon_sym_LPAREN2] = ACTIONS(2250),
    [anon_sym_BANG] = ACTIONS(2250),
    [anon_sym_TILDE] = ACTIONS(2250),
    [anon_sym_DASH] = ACTIONS(2248),
    [anon_sym_PLUS] = ACTIONS(2248),
    [anon_sym_STAR] = ACTIONS(2250),
    [anon_sym_AMP_AMP] = ACTIONS(2250),
    [anon_sym_AMP] = ACTIONS(2248),
    [anon_sym_SEMI] = ACTIONS(2250),
    [anon_sym___extension__] = ACTIONS(2248),
    [anon_sym_typedef] = ACTIONS(2248),
    [anon_sym_in] = ACTIONS(2248),
    [anon_sym_out] = ACTIONS(2248),
    [anon_sym_inout] = ACTIONS(2248),
    [anon_sym_extern] = ACTIONS(2248),
    [anon_sym___attribute__] = ACTIONS(2248),
    [anon_sym_COLON_COLON] = ACTIONS(2250),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2250),
    [anon_sym___declspec] = ACTIONS(2248),
    [anon_sym___based] = ACTIONS(2248),
    [anon_sym___cdecl] = ACTIONS(2248),
    [anon_sym___clrcall] = ACTIONS(2248),
    [anon_sym___stdcall] = ACTIONS(2248),
    [anon_sym___fastcall] = ACTIONS(2248),
    [anon_sym___thiscall] = ACTIONS(2248),
    [anon_sym___vectorcall] = ACTIONS(2248),
    [anon_sym_LBRACE] = ACTIONS(2250),
    [anon_sym_signed] = ACTIONS(2248),
    [anon_sym_unsigned] = ACTIONS(2248),
    [anon_sym_long] = ACTIONS(2248),
    [anon_sym_short] = ACTIONS(2248),
    [anon_sym_LBRACK] = ACTIONS(2248),
    [anon_sym_static] = ACTIONS(2248),
    [anon_sym_register] = ACTIONS(2248),
    [anon_sym_inline] = ACTIONS(2248),
    [anon_sym___inline] = ACTIONS(2248),
    [anon_sym___inline__] = ACTIONS(2248),
    [anon_sym___forceinline] = ACTIONS(2248),
    [anon_sym_thread_local] = ACTIONS(2248),
    [anon_sym___thread] = ACTIONS(2248),
    [anon_sym_const] = ACTIONS(2248),
    [anon_sym_constexpr] = ACTIONS(2248),
    [anon_sym_volatile] = ACTIONS(2248),
    [anon_sym_restrict] = ACTIONS(2248),
    [anon_sym___restrict__] = ACTIONS(2248),
    [anon_sym__Atomic] = ACTIONS(2248),
    [anon_sym__Noreturn] = ACTIONS(2248),
    [anon_sym_noreturn] = ACTIONS(2248),
    [anon_sym_mutable] = ACTIONS(2248),
    [anon_sym_constinit] = ACTIONS(2248),
    [anon_sym_consteval] = ACTIONS(2248),
    [anon_sym_alignas] = ACTIONS(2248),
    [anon_sym__Alignas] = ACTIONS(2248),
    [sym_primitive_type] = ACTIONS(2248),
    [anon_sym_enum] = ACTIONS(2248),
    [anon_sym_class] = ACTIONS(2248),
    [anon_sym_struct] = ACTIONS(2248),
    [anon_sym_union] = ACTIONS(2248),
    [anon_sym_if] = ACTIONS(2248),
    [anon_sym_else] = ACTIONS(2248),
    [anon_sym_switch] = ACTIONS(2248),
    [anon_sym_case] = ACTIONS(2248),
    [anon_sym_default] = ACTIONS(2248),
    [anon_sym_while] = ACTIONS(2248),
    [anon_sym_do] = ACTIONS(2248),
    [anon_sym_for] = ACTIONS(2248),
    [anon_sym_return] = ACTIONS(2248),
    [anon_sym_break] = ACTIONS(2248),
    [anon_sym_continue] = ACTIONS(2248),
    [anon_sym_goto] = ACTIONS(2248),
    [anon_sym___try] = ACTIONS(2248),
    [anon_sym___leave] = ACTIONS(2248),
    [anon_sym_not] = ACTIONS(2248),
    [anon_sym_compl] = ACTIONS(2248),
    [anon_sym_DASH_DASH] = ACTIONS(2250),
    [anon_sym_PLUS_PLUS] = ACTIONS(2250),
    [anon_sym_sizeof] = ACTIONS(2248),
    [anon_sym___alignof__] = ACTIONS(2248),
    [anon_sym___alignof] = ACTIONS(2248),
    [anon_sym__alignof] = ACTIONS(2248),
    [anon_sym_alignof] = ACTIONS(2248),
    [anon_sym__Alignof] = ACTIONS(2248),
    [anon_sym_offsetof] = ACTIONS(2248),
    [anon_sym__Generic] = ACTIONS(2248),
    [anon_sym_asm] = ACTIONS(2248),
    [anon_sym___asm__] = ACTIONS(2248),
    [sym_number_literal] = ACTIONS(2250),
    [anon_sym_L_SQUOTE] = ACTIONS(2250),
    [anon_sym_u_SQUOTE] = ACTIONS(2250),
    [anon_sym_U_SQUOTE] = ACTIONS(2250),
    [anon_sym_u8_SQUOTE] = ACTIONS(2250),
    [anon_sym_SQUOTE] = ACTIONS(2250),
    [anon_sym_L_DQUOTE] = ACTIONS(2250),
    [anon_sym_u_DQUOTE] = ACTIONS(2250),
    [anon_sym_U_DQUOTE] = ACTIONS(2250),
    [anon_sym_u8_DQUOTE] = ACTIONS(2250),
    [anon_sym_DQUOTE] = ACTIONS(2250),
    [sym_true] = ACTIONS(2248),
    [sym_false] = ACTIONS(2248),
    [anon_sym_NULL] = ACTIONS(2248),
    [anon_sym_nullptr] = ACTIONS(2248),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2248),
    [anon_sym_decltype] = ACTIONS(2248),
    [sym_virtual] = ACTIONS(2248),
    [anon_sym_explicit] = ACTIONS(2248),
    [anon_sym_typename] = ACTIONS(2248),
    [anon_sym_template] = ACTIONS(2248),
    [anon_sym_operator] = ACTIONS(2248),
    [anon_sym_try] = ACTIONS(2248),
    [anon_sym_delete] = ACTIONS(2248),
    [anon_sym_throw] = ACTIONS(2248),
    [anon_sym_namespace] = ACTIONS(2248),
    [anon_sym_using] = ACTIONS(2248),
    [anon_sym_static_assert] = ACTIONS(2248),
    [anon_sym_concept] = ACTIONS(2248),
    [anon_sym_co_return] = ACTIONS(2248),
    [anon_sym_co_yield] = ACTIONS(2248),
    [anon_sym_R_DQUOTE] = ACTIONS(2250),
    [anon_sym_LR_DQUOTE] = ACTIONS(2250),
    [anon_sym_uR_DQUOTE] = ACTIONS(2250),
    [anon_sym_UR_DQUOTE] = ACTIONS(2250),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2250),
    [anon_sym_co_await] = ACTIONS(2248),
    [anon_sym_new] = ACTIONS(2248),
    [anon_sym_requires] = ACTIONS(2248),
    [sym_this] = ACTIONS(2248),
    [anon_sym_discard] = ACTIONS(2248),
    [anon_sym_precise] = ACTIONS(2248),
    [anon_sym_shared] = ACTIONS(2248),
    [anon_sym_groupshared] = ACTIONS(2248),
    [anon_sym_uniform] = ACTIONS(2248),
    [anon_sym_row_major] = ACTIONS(2248),
    [anon_sym_column_major] = ACTIONS(2248),
    [anon_sym_globallycoherent] = ACTIONS(2248),
    [anon_sym_centroid] = ACTIONS(2248),
    [anon_sym_noperspective] = ACTIONS(2248),
    [anon_sym_nointerpolation] = ACTIONS(2248),
    [anon_sym_sample] = ACTIONS(2248),
    [anon_sym_linear] = ACTIONS(2248),
    [anon_sym_snorm] = ACTIONS(2248),
    [anon_sym_unorm] = ACTIONS(2248),
    [anon_sym_point] = ACTIONS(2248),
    [anon_sym_line] = ACTIONS(2248),
    [anon_sym_triangleadj] = ACTIONS(2248),
    [anon_sym_lineadj] = ACTIONS(2248),
    [anon_sym_triangle] = ACTIONS(2248),
    [anon_sym_cbuffer] = ACTIONS(2248),
  },
  [429] = {
    [sym_identifier] = ACTIONS(2248),
    [aux_sym_preproc_include_token1] = ACTIONS(2248),
    [aux_sym_preproc_def_token1] = ACTIONS(2248),
    [aux_sym_preproc_if_token1] = ACTIONS(2248),
    [aux_sym_preproc_if_token2] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2248),
    [sym_preproc_directive] = ACTIONS(2248),
    [anon_sym_LPAREN2] = ACTIONS(2250),
    [anon_sym_BANG] = ACTIONS(2250),
    [anon_sym_TILDE] = ACTIONS(2250),
    [anon_sym_DASH] = ACTIONS(2248),
    [anon_sym_PLUS] = ACTIONS(2248),
    [anon_sym_STAR] = ACTIONS(2250),
    [anon_sym_AMP_AMP] = ACTIONS(2250),
    [anon_sym_AMP] = ACTIONS(2248),
    [anon_sym_SEMI] = ACTIONS(2250),
    [anon_sym___extension__] = ACTIONS(2248),
    [anon_sym_typedef] = ACTIONS(2248),
    [anon_sym_in] = ACTIONS(2248),
    [anon_sym_out] = ACTIONS(2248),
    [anon_sym_inout] = ACTIONS(2248),
    [anon_sym_extern] = ACTIONS(2248),
    [anon_sym___attribute__] = ACTIONS(2248),
    [anon_sym_COLON_COLON] = ACTIONS(2250),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2250),
    [anon_sym___declspec] = ACTIONS(2248),
    [anon_sym___based] = ACTIONS(2248),
    [anon_sym___cdecl] = ACTIONS(2248),
    [anon_sym___clrcall] = ACTIONS(2248),
    [anon_sym___stdcall] = ACTIONS(2248),
    [anon_sym___fastcall] = ACTIONS(2248),
    [anon_sym___thiscall] = ACTIONS(2248),
    [anon_sym___vectorcall] = ACTIONS(2248),
    [anon_sym_LBRACE] = ACTIONS(2250),
    [anon_sym_signed] = ACTIONS(2248),
    [anon_sym_unsigned] = ACTIONS(2248),
    [anon_sym_long] = ACTIONS(2248),
    [anon_sym_short] = ACTIONS(2248),
    [anon_sym_LBRACK] = ACTIONS(2248),
    [anon_sym_static] = ACTIONS(2248),
    [anon_sym_register] = ACTIONS(2248),
    [anon_sym_inline] = ACTIONS(2248),
    [anon_sym___inline] = ACTIONS(2248),
    [anon_sym___inline__] = ACTIONS(2248),
    [anon_sym___forceinline] = ACTIONS(2248),
    [anon_sym_thread_local] = ACTIONS(2248),
    [anon_sym___thread] = ACTIONS(2248),
    [anon_sym_const] = ACTIONS(2248),
    [anon_sym_constexpr] = ACTIONS(2248),
    [anon_sym_volatile] = ACTIONS(2248),
    [anon_sym_restrict] = ACTIONS(2248),
    [anon_sym___restrict__] = ACTIONS(2248),
    [anon_sym__Atomic] = ACTIONS(2248),
    [anon_sym__Noreturn] = ACTIONS(2248),
    [anon_sym_noreturn] = ACTIONS(2248),
    [anon_sym_mutable] = ACTIONS(2248),
    [anon_sym_constinit] = ACTIONS(2248),
    [anon_sym_consteval] = ACTIONS(2248),
    [anon_sym_alignas] = ACTIONS(2248),
    [anon_sym__Alignas] = ACTIONS(2248),
    [sym_primitive_type] = ACTIONS(2248),
    [anon_sym_enum] = ACTIONS(2248),
    [anon_sym_class] = ACTIONS(2248),
    [anon_sym_struct] = ACTIONS(2248),
    [anon_sym_union] = ACTIONS(2248),
    [anon_sym_if] = ACTIONS(2248),
    [anon_sym_else] = ACTIONS(2248),
    [anon_sym_switch] = ACTIONS(2248),
    [anon_sym_case] = ACTIONS(2248),
    [anon_sym_default] = ACTIONS(2248),
    [anon_sym_while] = ACTIONS(2248),
    [anon_sym_do] = ACTIONS(2248),
    [anon_sym_for] = ACTIONS(2248),
    [anon_sym_return] = ACTIONS(2248),
    [anon_sym_break] = ACTIONS(2248),
    [anon_sym_continue] = ACTIONS(2248),
    [anon_sym_goto] = ACTIONS(2248),
    [anon_sym___try] = ACTIONS(2248),
    [anon_sym___leave] = ACTIONS(2248),
    [anon_sym_not] = ACTIONS(2248),
    [anon_sym_compl] = ACTIONS(2248),
    [anon_sym_DASH_DASH] = ACTIONS(2250),
    [anon_sym_PLUS_PLUS] = ACTIONS(2250),
    [anon_sym_sizeof] = ACTIONS(2248),
    [anon_sym___alignof__] = ACTIONS(2248),
    [anon_sym___alignof] = ACTIONS(2248),
    [anon_sym__alignof] = ACTIONS(2248),
    [anon_sym_alignof] = ACTIONS(2248),
    [anon_sym__Alignof] = ACTIONS(2248),
    [anon_sym_offsetof] = ACTIONS(2248),
    [anon_sym__Generic] = ACTIONS(2248),
    [anon_sym_asm] = ACTIONS(2248),
    [anon_sym___asm__] = ACTIONS(2248),
    [sym_number_literal] = ACTIONS(2250),
    [anon_sym_L_SQUOTE] = ACTIONS(2250),
    [anon_sym_u_SQUOTE] = ACTIONS(2250),
    [anon_sym_U_SQUOTE] = ACTIONS(2250),
    [anon_sym_u8_SQUOTE] = ACTIONS(2250),
    [anon_sym_SQUOTE] = ACTIONS(2250),
    [anon_sym_L_DQUOTE] = ACTIONS(2250),
    [anon_sym_u_DQUOTE] = ACTIONS(2250),
    [anon_sym_U_DQUOTE] = ACTIONS(2250),
    [anon_sym_u8_DQUOTE] = ACTIONS(2250),
    [anon_sym_DQUOTE] = ACTIONS(2250),
    [sym_true] = ACTIONS(2248),
    [sym_false] = ACTIONS(2248),
    [anon_sym_NULL] = ACTIONS(2248),
    [anon_sym_nullptr] = ACTIONS(2248),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2248),
    [anon_sym_decltype] = ACTIONS(2248),
    [sym_virtual] = ACTIONS(2248),
    [anon_sym_explicit] = ACTIONS(2248),
    [anon_sym_typename] = ACTIONS(2248),
    [anon_sym_template] = ACTIONS(2248),
    [anon_sym_operator] = ACTIONS(2248),
    [anon_sym_try] = ACTIONS(2248),
    [anon_sym_delete] = ACTIONS(2248),
    [anon_sym_throw] = ACTIONS(2248),
    [anon_sym_namespace] = ACTIONS(2248),
    [anon_sym_using] = ACTIONS(2248),
    [anon_sym_static_assert] = ACTIONS(2248),
    [anon_sym_concept] = ACTIONS(2248),
    [anon_sym_co_return] = ACTIONS(2248),
    [anon_sym_co_yield] = ACTIONS(2248),
    [anon_sym_R_DQUOTE] = ACTIONS(2250),
    [anon_sym_LR_DQUOTE] = ACTIONS(2250),
    [anon_sym_uR_DQUOTE] = ACTIONS(2250),
    [anon_sym_UR_DQUOTE] = ACTIONS(2250),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2250),
    [anon_sym_co_await] = ACTIONS(2248),
    [anon_sym_new] = ACTIONS(2248),
    [anon_sym_requires] = ACTIONS(2248),
    [sym_this] = ACTIONS(2248),
    [anon_sym_discard] = ACTIONS(2248),
    [anon_sym_precise] = ACTIONS(2248),
    [anon_sym_shared] = ACTIONS(2248),
    [anon_sym_groupshared] = ACTIONS(2248),
    [anon_sym_uniform] = ACTIONS(2248),
    [anon_sym_row_major] = ACTIONS(2248),
    [anon_sym_column_major] = ACTIONS(2248),
    [anon_sym_globallycoherent] = ACTIONS(2248),
    [anon_sym_centroid] = ACTIONS(2248),
    [anon_sym_noperspective] = ACTIONS(2248),
    [anon_sym_nointerpolation] = ACTIONS(2248),
    [anon_sym_sample] = ACTIONS(2248),
    [anon_sym_linear] = ACTIONS(2248),
    [anon_sym_snorm] = ACTIONS(2248),
    [anon_sym_unorm] = ACTIONS(2248),
    [anon_sym_point] = ACTIONS(2248),
    [anon_sym_line] = ACTIONS(2248),
    [anon_sym_triangleadj] = ACTIONS(2248),
    [anon_sym_lineadj] = ACTIONS(2248),
    [anon_sym_triangle] = ACTIONS(2248),
    [anon_sym_cbuffer] = ACTIONS(2248),
  },
  [430] = {
    [sym_identifier] = ACTIONS(2284),
    [aux_sym_preproc_include_token1] = ACTIONS(2284),
    [aux_sym_preproc_def_token1] = ACTIONS(2284),
    [aux_sym_preproc_if_token1] = ACTIONS(2284),
    [aux_sym_preproc_if_token2] = ACTIONS(2284),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2284),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2284),
    [sym_preproc_directive] = ACTIONS(2284),
    [anon_sym_LPAREN2] = ACTIONS(2286),
    [anon_sym_BANG] = ACTIONS(2286),
    [anon_sym_TILDE] = ACTIONS(2286),
    [anon_sym_DASH] = ACTIONS(2284),
    [anon_sym_PLUS] = ACTIONS(2284),
    [anon_sym_STAR] = ACTIONS(2286),
    [anon_sym_AMP_AMP] = ACTIONS(2286),
    [anon_sym_AMP] = ACTIONS(2284),
    [anon_sym_SEMI] = ACTIONS(2286),
    [anon_sym___extension__] = ACTIONS(2284),
    [anon_sym_typedef] = ACTIONS(2284),
    [anon_sym_in] = ACTIONS(2284),
    [anon_sym_out] = ACTIONS(2284),
    [anon_sym_inout] = ACTIONS(2284),
    [anon_sym_extern] = ACTIONS(2284),
    [anon_sym___attribute__] = ACTIONS(2284),
    [anon_sym_COLON_COLON] = ACTIONS(2286),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2286),
    [anon_sym___declspec] = ACTIONS(2284),
    [anon_sym___based] = ACTIONS(2284),
    [anon_sym___cdecl] = ACTIONS(2284),
    [anon_sym___clrcall] = ACTIONS(2284),
    [anon_sym___stdcall] = ACTIONS(2284),
    [anon_sym___fastcall] = ACTIONS(2284),
    [anon_sym___thiscall] = ACTIONS(2284),
    [anon_sym___vectorcall] = ACTIONS(2284),
    [anon_sym_LBRACE] = ACTIONS(2286),
    [anon_sym_signed] = ACTIONS(2284),
    [anon_sym_unsigned] = ACTIONS(2284),
    [anon_sym_long] = ACTIONS(2284),
    [anon_sym_short] = ACTIONS(2284),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [anon_sym_static] = ACTIONS(2284),
    [anon_sym_register] = ACTIONS(2284),
    [anon_sym_inline] = ACTIONS(2284),
    [anon_sym___inline] = ACTIONS(2284),
    [anon_sym___inline__] = ACTIONS(2284),
    [anon_sym___forceinline] = ACTIONS(2284),
    [anon_sym_thread_local] = ACTIONS(2284),
    [anon_sym___thread] = ACTIONS(2284),
    [anon_sym_const] = ACTIONS(2284),
    [anon_sym_constexpr] = ACTIONS(2284),
    [anon_sym_volatile] = ACTIONS(2284),
    [anon_sym_restrict] = ACTIONS(2284),
    [anon_sym___restrict__] = ACTIONS(2284),
    [anon_sym__Atomic] = ACTIONS(2284),
    [anon_sym__Noreturn] = ACTIONS(2284),
    [anon_sym_noreturn] = ACTIONS(2284),
    [anon_sym_mutable] = ACTIONS(2284),
    [anon_sym_constinit] = ACTIONS(2284),
    [anon_sym_consteval] = ACTIONS(2284),
    [anon_sym_alignas] = ACTIONS(2284),
    [anon_sym__Alignas] = ACTIONS(2284),
    [sym_primitive_type] = ACTIONS(2284),
    [anon_sym_enum] = ACTIONS(2284),
    [anon_sym_class] = ACTIONS(2284),
    [anon_sym_struct] = ACTIONS(2284),
    [anon_sym_union] = ACTIONS(2284),
    [anon_sym_if] = ACTIONS(2284),
    [anon_sym_else] = ACTIONS(2284),
    [anon_sym_switch] = ACTIONS(2284),
    [anon_sym_case] = ACTIONS(2284),
    [anon_sym_default] = ACTIONS(2284),
    [anon_sym_while] = ACTIONS(2284),
    [anon_sym_do] = ACTIONS(2284),
    [anon_sym_for] = ACTIONS(2284),
    [anon_sym_return] = ACTIONS(2284),
    [anon_sym_break] = ACTIONS(2284),
    [anon_sym_continue] = ACTIONS(2284),
    [anon_sym_goto] = ACTIONS(2284),
    [anon_sym___try] = ACTIONS(2284),
    [anon_sym___leave] = ACTIONS(2284),
    [anon_sym_not] = ACTIONS(2284),
    [anon_sym_compl] = ACTIONS(2284),
    [anon_sym_DASH_DASH] = ACTIONS(2286),
    [anon_sym_PLUS_PLUS] = ACTIONS(2286),
    [anon_sym_sizeof] = ACTIONS(2284),
    [anon_sym___alignof__] = ACTIONS(2284),
    [anon_sym___alignof] = ACTIONS(2284),
    [anon_sym__alignof] = ACTIONS(2284),
    [anon_sym_alignof] = ACTIONS(2284),
    [anon_sym__Alignof] = ACTIONS(2284),
    [anon_sym_offsetof] = ACTIONS(2284),
    [anon_sym__Generic] = ACTIONS(2284),
    [anon_sym_asm] = ACTIONS(2284),
    [anon_sym___asm__] = ACTIONS(2284),
    [sym_number_literal] = ACTIONS(2286),
    [anon_sym_L_SQUOTE] = ACTIONS(2286),
    [anon_sym_u_SQUOTE] = ACTIONS(2286),
    [anon_sym_U_SQUOTE] = ACTIONS(2286),
    [anon_sym_u8_SQUOTE] = ACTIONS(2286),
    [anon_sym_SQUOTE] = ACTIONS(2286),
    [anon_sym_L_DQUOTE] = ACTIONS(2286),
    [anon_sym_u_DQUOTE] = ACTIONS(2286),
    [anon_sym_U_DQUOTE] = ACTIONS(2286),
    [anon_sym_u8_DQUOTE] = ACTIONS(2286),
    [anon_sym_DQUOTE] = ACTIONS(2286),
    [sym_true] = ACTIONS(2284),
    [sym_false] = ACTIONS(2284),
    [anon_sym_NULL] = ACTIONS(2284),
    [anon_sym_nullptr] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2284),
    [anon_sym_decltype] = ACTIONS(2284),
    [sym_virtual] = ACTIONS(2284),
    [anon_sym_explicit] = ACTIONS(2284),
    [anon_sym_typename] = ACTIONS(2284),
    [anon_sym_template] = ACTIONS(2284),
    [anon_sym_operator] = ACTIONS(2284),
    [anon_sym_try] = ACTIONS(2284),
    [anon_sym_delete] = ACTIONS(2284),
    [anon_sym_throw] = ACTIONS(2284),
    [anon_sym_namespace] = ACTIONS(2284),
    [anon_sym_using] = ACTIONS(2284),
    [anon_sym_static_assert] = ACTIONS(2284),
    [anon_sym_concept] = ACTIONS(2284),
    [anon_sym_co_return] = ACTIONS(2284),
    [anon_sym_co_yield] = ACTIONS(2284),
    [anon_sym_R_DQUOTE] = ACTIONS(2286),
    [anon_sym_LR_DQUOTE] = ACTIONS(2286),
    [anon_sym_uR_DQUOTE] = ACTIONS(2286),
    [anon_sym_UR_DQUOTE] = ACTIONS(2286),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2286),
    [anon_sym_co_await] = ACTIONS(2284),
    [anon_sym_new] = ACTIONS(2284),
    [anon_sym_requires] = ACTIONS(2284),
    [sym_this] = ACTIONS(2284),
    [anon_sym_discard] = ACTIONS(2284),
    [anon_sym_precise] = ACTIONS(2284),
    [anon_sym_shared] = ACTIONS(2284),
    [anon_sym_groupshared] = ACTIONS(2284),
    [anon_sym_uniform] = ACTIONS(2284),
    [anon_sym_row_major] = ACTIONS(2284),
    [anon_sym_column_major] = ACTIONS(2284),
    [anon_sym_globallycoherent] = ACTIONS(2284),
    [anon_sym_centroid] = ACTIONS(2284),
    [anon_sym_noperspective] = ACTIONS(2284),
    [anon_sym_nointerpolation] = ACTIONS(2284),
    [anon_sym_sample] = ACTIONS(2284),
    [anon_sym_linear] = ACTIONS(2284),
    [anon_sym_snorm] = ACTIONS(2284),
    [anon_sym_unorm] = ACTIONS(2284),
    [anon_sym_point] = ACTIONS(2284),
    [anon_sym_line] = ACTIONS(2284),
    [anon_sym_triangleadj] = ACTIONS(2284),
    [anon_sym_lineadj] = ACTIONS(2284),
    [anon_sym_triangle] = ACTIONS(2284),
    [anon_sym_cbuffer] = ACTIONS(2284),
  },
  [431] = {
    [sym_identifier] = ACTIONS(2268),
    [aux_sym_preproc_include_token1] = ACTIONS(2268),
    [aux_sym_preproc_def_token1] = ACTIONS(2268),
    [aux_sym_preproc_if_token1] = ACTIONS(2268),
    [aux_sym_preproc_if_token2] = ACTIONS(2268),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2268),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2268),
    [sym_preproc_directive] = ACTIONS(2268),
    [anon_sym_LPAREN2] = ACTIONS(2270),
    [anon_sym_BANG] = ACTIONS(2270),
    [anon_sym_TILDE] = ACTIONS(2270),
    [anon_sym_DASH] = ACTIONS(2268),
    [anon_sym_PLUS] = ACTIONS(2268),
    [anon_sym_STAR] = ACTIONS(2270),
    [anon_sym_AMP_AMP] = ACTIONS(2270),
    [anon_sym_AMP] = ACTIONS(2268),
    [anon_sym_SEMI] = ACTIONS(2270),
    [anon_sym___extension__] = ACTIONS(2268),
    [anon_sym_typedef] = ACTIONS(2268),
    [anon_sym_in] = ACTIONS(2268),
    [anon_sym_out] = ACTIONS(2268),
    [anon_sym_inout] = ACTIONS(2268),
    [anon_sym_extern] = ACTIONS(2268),
    [anon_sym___attribute__] = ACTIONS(2268),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2270),
    [anon_sym___declspec] = ACTIONS(2268),
    [anon_sym___based] = ACTIONS(2268),
    [anon_sym___cdecl] = ACTIONS(2268),
    [anon_sym___clrcall] = ACTIONS(2268),
    [anon_sym___stdcall] = ACTIONS(2268),
    [anon_sym___fastcall] = ACTIONS(2268),
    [anon_sym___thiscall] = ACTIONS(2268),
    [anon_sym___vectorcall] = ACTIONS(2268),
    [anon_sym_LBRACE] = ACTIONS(2270),
    [anon_sym_signed] = ACTIONS(2268),
    [anon_sym_unsigned] = ACTIONS(2268),
    [anon_sym_long] = ACTIONS(2268),
    [anon_sym_short] = ACTIONS(2268),
    [anon_sym_LBRACK] = ACTIONS(2268),
    [anon_sym_static] = ACTIONS(2268),
    [anon_sym_register] = ACTIONS(2268),
    [anon_sym_inline] = ACTIONS(2268),
    [anon_sym___inline] = ACTIONS(2268),
    [anon_sym___inline__] = ACTIONS(2268),
    [anon_sym___forceinline] = ACTIONS(2268),
    [anon_sym_thread_local] = ACTIONS(2268),
    [anon_sym___thread] = ACTIONS(2268),
    [anon_sym_const] = ACTIONS(2268),
    [anon_sym_constexpr] = ACTIONS(2268),
    [anon_sym_volatile] = ACTIONS(2268),
    [anon_sym_restrict] = ACTIONS(2268),
    [anon_sym___restrict__] = ACTIONS(2268),
    [anon_sym__Atomic] = ACTIONS(2268),
    [anon_sym__Noreturn] = ACTIONS(2268),
    [anon_sym_noreturn] = ACTIONS(2268),
    [anon_sym_mutable] = ACTIONS(2268),
    [anon_sym_constinit] = ACTIONS(2268),
    [anon_sym_consteval] = ACTIONS(2268),
    [anon_sym_alignas] = ACTIONS(2268),
    [anon_sym__Alignas] = ACTIONS(2268),
    [sym_primitive_type] = ACTIONS(2268),
    [anon_sym_enum] = ACTIONS(2268),
    [anon_sym_class] = ACTIONS(2268),
    [anon_sym_struct] = ACTIONS(2268),
    [anon_sym_union] = ACTIONS(2268),
    [anon_sym_if] = ACTIONS(2268),
    [anon_sym_else] = ACTIONS(2268),
    [anon_sym_switch] = ACTIONS(2268),
    [anon_sym_case] = ACTIONS(2268),
    [anon_sym_default] = ACTIONS(2268),
    [anon_sym_while] = ACTIONS(2268),
    [anon_sym_do] = ACTIONS(2268),
    [anon_sym_for] = ACTIONS(2268),
    [anon_sym_return] = ACTIONS(2268),
    [anon_sym_break] = ACTIONS(2268),
    [anon_sym_continue] = ACTIONS(2268),
    [anon_sym_goto] = ACTIONS(2268),
    [anon_sym___try] = ACTIONS(2268),
    [anon_sym___leave] = ACTIONS(2268),
    [anon_sym_not] = ACTIONS(2268),
    [anon_sym_compl] = ACTIONS(2268),
    [anon_sym_DASH_DASH] = ACTIONS(2270),
    [anon_sym_PLUS_PLUS] = ACTIONS(2270),
    [anon_sym_sizeof] = ACTIONS(2268),
    [anon_sym___alignof__] = ACTIONS(2268),
    [anon_sym___alignof] = ACTIONS(2268),
    [anon_sym__alignof] = ACTIONS(2268),
    [anon_sym_alignof] = ACTIONS(2268),
    [anon_sym__Alignof] = ACTIONS(2268),
    [anon_sym_offsetof] = ACTIONS(2268),
    [anon_sym__Generic] = ACTIONS(2268),
    [anon_sym_asm] = ACTIONS(2268),
    [anon_sym___asm__] = ACTIONS(2268),
    [sym_number_literal] = ACTIONS(2270),
    [anon_sym_L_SQUOTE] = ACTIONS(2270),
    [anon_sym_u_SQUOTE] = ACTIONS(2270),
    [anon_sym_U_SQUOTE] = ACTIONS(2270),
    [anon_sym_u8_SQUOTE] = ACTIONS(2270),
    [anon_sym_SQUOTE] = ACTIONS(2270),
    [anon_sym_L_DQUOTE] = ACTIONS(2270),
    [anon_sym_u_DQUOTE] = ACTIONS(2270),
    [anon_sym_U_DQUOTE] = ACTIONS(2270),
    [anon_sym_u8_DQUOTE] = ACTIONS(2270),
    [anon_sym_DQUOTE] = ACTIONS(2270),
    [sym_true] = ACTIONS(2268),
    [sym_false] = ACTIONS(2268),
    [anon_sym_NULL] = ACTIONS(2268),
    [anon_sym_nullptr] = ACTIONS(2268),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2268),
    [anon_sym_decltype] = ACTIONS(2268),
    [sym_virtual] = ACTIONS(2268),
    [anon_sym_explicit] = ACTIONS(2268),
    [anon_sym_typename] = ACTIONS(2268),
    [anon_sym_template] = ACTIONS(2268),
    [anon_sym_operator] = ACTIONS(2268),
    [anon_sym_try] = ACTIONS(2268),
    [anon_sym_delete] = ACTIONS(2268),
    [anon_sym_throw] = ACTIONS(2268),
    [anon_sym_namespace] = ACTIONS(2268),
    [anon_sym_using] = ACTIONS(2268),
    [anon_sym_static_assert] = ACTIONS(2268),
    [anon_sym_concept] = ACTIONS(2268),
    [anon_sym_co_return] = ACTIONS(2268),
    [anon_sym_co_yield] = ACTIONS(2268),
    [anon_sym_R_DQUOTE] = ACTIONS(2270),
    [anon_sym_LR_DQUOTE] = ACTIONS(2270),
    [anon_sym_uR_DQUOTE] = ACTIONS(2270),
    [anon_sym_UR_DQUOTE] = ACTIONS(2270),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2270),
    [anon_sym_co_await] = ACTIONS(2268),
    [anon_sym_new] = ACTIONS(2268),
    [anon_sym_requires] = ACTIONS(2268),
    [sym_this] = ACTIONS(2268),
    [anon_sym_discard] = ACTIONS(2268),
    [anon_sym_precise] = ACTIONS(2268),
    [anon_sym_shared] = ACTIONS(2268),
    [anon_sym_groupshared] = ACTIONS(2268),
    [anon_sym_uniform] = ACTIONS(2268),
    [anon_sym_row_major] = ACTIONS(2268),
    [anon_sym_column_major] = ACTIONS(2268),
    [anon_sym_globallycoherent] = ACTIONS(2268),
    [anon_sym_centroid] = ACTIONS(2268),
    [anon_sym_noperspective] = ACTIONS(2268),
    [anon_sym_nointerpolation] = ACTIONS(2268),
    [anon_sym_sample] = ACTIONS(2268),
    [anon_sym_linear] = ACTIONS(2268),
    [anon_sym_snorm] = ACTIONS(2268),
    [anon_sym_unorm] = ACTIONS(2268),
    [anon_sym_point] = ACTIONS(2268),
    [anon_sym_line] = ACTIONS(2268),
    [anon_sym_triangleadj] = ACTIONS(2268),
    [anon_sym_lineadj] = ACTIONS(2268),
    [anon_sym_triangle] = ACTIONS(2268),
    [anon_sym_cbuffer] = ACTIONS(2268),
  },
  [432] = {
    [sym_identifier] = ACTIONS(2244),
    [aux_sym_preproc_include_token1] = ACTIONS(2244),
    [aux_sym_preproc_def_token1] = ACTIONS(2244),
    [aux_sym_preproc_if_token1] = ACTIONS(2244),
    [aux_sym_preproc_if_token2] = ACTIONS(2244),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2244),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2244),
    [sym_preproc_directive] = ACTIONS(2244),
    [anon_sym_LPAREN2] = ACTIONS(2246),
    [anon_sym_BANG] = ACTIONS(2246),
    [anon_sym_TILDE] = ACTIONS(2246),
    [anon_sym_DASH] = ACTIONS(2244),
    [anon_sym_PLUS] = ACTIONS(2244),
    [anon_sym_STAR] = ACTIONS(2246),
    [anon_sym_AMP_AMP] = ACTIONS(2246),
    [anon_sym_AMP] = ACTIONS(2244),
    [anon_sym_SEMI] = ACTIONS(2246),
    [anon_sym___extension__] = ACTIONS(2244),
    [anon_sym_typedef] = ACTIONS(2244),
    [anon_sym_in] = ACTIONS(2244),
    [anon_sym_out] = ACTIONS(2244),
    [anon_sym_inout] = ACTIONS(2244),
    [anon_sym_extern] = ACTIONS(2244),
    [anon_sym___attribute__] = ACTIONS(2244),
    [anon_sym_COLON_COLON] = ACTIONS(2246),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2246),
    [anon_sym___declspec] = ACTIONS(2244),
    [anon_sym___based] = ACTIONS(2244),
    [anon_sym___cdecl] = ACTIONS(2244),
    [anon_sym___clrcall] = ACTIONS(2244),
    [anon_sym___stdcall] = ACTIONS(2244),
    [anon_sym___fastcall] = ACTIONS(2244),
    [anon_sym___thiscall] = ACTIONS(2244),
    [anon_sym___vectorcall] = ACTIONS(2244),
    [anon_sym_LBRACE] = ACTIONS(2246),
    [anon_sym_signed] = ACTIONS(2244),
    [anon_sym_unsigned] = ACTIONS(2244),
    [anon_sym_long] = ACTIONS(2244),
    [anon_sym_short] = ACTIONS(2244),
    [anon_sym_LBRACK] = ACTIONS(2244),
    [anon_sym_static] = ACTIONS(2244),
    [anon_sym_register] = ACTIONS(2244),
    [anon_sym_inline] = ACTIONS(2244),
    [anon_sym___inline] = ACTIONS(2244),
    [anon_sym___inline__] = ACTIONS(2244),
    [anon_sym___forceinline] = ACTIONS(2244),
    [anon_sym_thread_local] = ACTIONS(2244),
    [anon_sym___thread] = ACTIONS(2244),
    [anon_sym_const] = ACTIONS(2244),
    [anon_sym_constexpr] = ACTIONS(2244),
    [anon_sym_volatile] = ACTIONS(2244),
    [anon_sym_restrict] = ACTIONS(2244),
    [anon_sym___restrict__] = ACTIONS(2244),
    [anon_sym__Atomic] = ACTIONS(2244),
    [anon_sym__Noreturn] = ACTIONS(2244),
    [anon_sym_noreturn] = ACTIONS(2244),
    [anon_sym_mutable] = ACTIONS(2244),
    [anon_sym_constinit] = ACTIONS(2244),
    [anon_sym_consteval] = ACTIONS(2244),
    [anon_sym_alignas] = ACTIONS(2244),
    [anon_sym__Alignas] = ACTIONS(2244),
    [sym_primitive_type] = ACTIONS(2244),
    [anon_sym_enum] = ACTIONS(2244),
    [anon_sym_class] = ACTIONS(2244),
    [anon_sym_struct] = ACTIONS(2244),
    [anon_sym_union] = ACTIONS(2244),
    [anon_sym_if] = ACTIONS(2244),
    [anon_sym_else] = ACTIONS(2244),
    [anon_sym_switch] = ACTIONS(2244),
    [anon_sym_case] = ACTIONS(2244),
    [anon_sym_default] = ACTIONS(2244),
    [anon_sym_while] = ACTIONS(2244),
    [anon_sym_do] = ACTIONS(2244),
    [anon_sym_for] = ACTIONS(2244),
    [anon_sym_return] = ACTIONS(2244),
    [anon_sym_break] = ACTIONS(2244),
    [anon_sym_continue] = ACTIONS(2244),
    [anon_sym_goto] = ACTIONS(2244),
    [anon_sym___try] = ACTIONS(2244),
    [anon_sym___leave] = ACTIONS(2244),
    [anon_sym_not] = ACTIONS(2244),
    [anon_sym_compl] = ACTIONS(2244),
    [anon_sym_DASH_DASH] = ACTIONS(2246),
    [anon_sym_PLUS_PLUS] = ACTIONS(2246),
    [anon_sym_sizeof] = ACTIONS(2244),
    [anon_sym___alignof__] = ACTIONS(2244),
    [anon_sym___alignof] = ACTIONS(2244),
    [anon_sym__alignof] = ACTIONS(2244),
    [anon_sym_alignof] = ACTIONS(2244),
    [anon_sym__Alignof] = ACTIONS(2244),
    [anon_sym_offsetof] = ACTIONS(2244),
    [anon_sym__Generic] = ACTIONS(2244),
    [anon_sym_asm] = ACTIONS(2244),
    [anon_sym___asm__] = ACTIONS(2244),
    [sym_number_literal] = ACTIONS(2246),
    [anon_sym_L_SQUOTE] = ACTIONS(2246),
    [anon_sym_u_SQUOTE] = ACTIONS(2246),
    [anon_sym_U_SQUOTE] = ACTIONS(2246),
    [anon_sym_u8_SQUOTE] = ACTIONS(2246),
    [anon_sym_SQUOTE] = ACTIONS(2246),
    [anon_sym_L_DQUOTE] = ACTIONS(2246),
    [anon_sym_u_DQUOTE] = ACTIONS(2246),
    [anon_sym_U_DQUOTE] = ACTIONS(2246),
    [anon_sym_u8_DQUOTE] = ACTIONS(2246),
    [anon_sym_DQUOTE] = ACTIONS(2246),
    [sym_true] = ACTIONS(2244),
    [sym_false] = ACTIONS(2244),
    [anon_sym_NULL] = ACTIONS(2244),
    [anon_sym_nullptr] = ACTIONS(2244),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2244),
    [anon_sym_decltype] = ACTIONS(2244),
    [sym_virtual] = ACTIONS(2244),
    [anon_sym_explicit] = ACTIONS(2244),
    [anon_sym_typename] = ACTIONS(2244),
    [anon_sym_template] = ACTIONS(2244),
    [anon_sym_operator] = ACTIONS(2244),
    [anon_sym_try] = ACTIONS(2244),
    [anon_sym_delete] = ACTIONS(2244),
    [anon_sym_throw] = ACTIONS(2244),
    [anon_sym_namespace] = ACTIONS(2244),
    [anon_sym_using] = ACTIONS(2244),
    [anon_sym_static_assert] = ACTIONS(2244),
    [anon_sym_concept] = ACTIONS(2244),
    [anon_sym_co_return] = ACTIONS(2244),
    [anon_sym_co_yield] = ACTIONS(2244),
    [anon_sym_R_DQUOTE] = ACTIONS(2246),
    [anon_sym_LR_DQUOTE] = ACTIONS(2246),
    [anon_sym_uR_DQUOTE] = ACTIONS(2246),
    [anon_sym_UR_DQUOTE] = ACTIONS(2246),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2246),
    [anon_sym_co_await] = ACTIONS(2244),
    [anon_sym_new] = ACTIONS(2244),
    [anon_sym_requires] = ACTIONS(2244),
    [sym_this] = ACTIONS(2244),
    [anon_sym_discard] = ACTIONS(2244),
    [anon_sym_precise] = ACTIONS(2244),
    [anon_sym_shared] = ACTIONS(2244),
    [anon_sym_groupshared] = ACTIONS(2244),
    [anon_sym_uniform] = ACTIONS(2244),
    [anon_sym_row_major] = ACTIONS(2244),
    [anon_sym_column_major] = ACTIONS(2244),
    [anon_sym_globallycoherent] = ACTIONS(2244),
    [anon_sym_centroid] = ACTIONS(2244),
    [anon_sym_noperspective] = ACTIONS(2244),
    [anon_sym_nointerpolation] = ACTIONS(2244),
    [anon_sym_sample] = ACTIONS(2244),
    [anon_sym_linear] = ACTIONS(2244),
    [anon_sym_snorm] = ACTIONS(2244),
    [anon_sym_unorm] = ACTIONS(2244),
    [anon_sym_point] = ACTIONS(2244),
    [anon_sym_line] = ACTIONS(2244),
    [anon_sym_triangleadj] = ACTIONS(2244),
    [anon_sym_lineadj] = ACTIONS(2244),
    [anon_sym_triangle] = ACTIONS(2244),
    [anon_sym_cbuffer] = ACTIONS(2244),
  },
  [433] = {
    [ts_builtin_sym_end] = ACTIONS(2116),
    [sym_identifier] = ACTIONS(2114),
    [aux_sym_preproc_include_token1] = ACTIONS(2114),
    [aux_sym_preproc_def_token1] = ACTIONS(2114),
    [aux_sym_preproc_if_token1] = ACTIONS(2114),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2114),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2114),
    [sym_preproc_directive] = ACTIONS(2114),
    [anon_sym_LPAREN2] = ACTIONS(2116),
    [anon_sym_BANG] = ACTIONS(2116),
    [anon_sym_TILDE] = ACTIONS(2116),
    [anon_sym_DASH] = ACTIONS(2114),
    [anon_sym_PLUS] = ACTIONS(2114),
    [anon_sym_STAR] = ACTIONS(2116),
    [anon_sym_AMP_AMP] = ACTIONS(2116),
    [anon_sym_AMP] = ACTIONS(2114),
    [anon_sym_SEMI] = ACTIONS(2116),
    [anon_sym___extension__] = ACTIONS(2114),
    [anon_sym_typedef] = ACTIONS(2114),
    [anon_sym_in] = ACTIONS(2114),
    [anon_sym_out] = ACTIONS(2114),
    [anon_sym_inout] = ACTIONS(2114),
    [anon_sym_extern] = ACTIONS(2114),
    [anon_sym___attribute__] = ACTIONS(2114),
    [anon_sym_COLON_COLON] = ACTIONS(2116),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2116),
    [anon_sym___declspec] = ACTIONS(2114),
    [anon_sym___based] = ACTIONS(2114),
    [anon_sym___cdecl] = ACTIONS(2114),
    [anon_sym___clrcall] = ACTIONS(2114),
    [anon_sym___stdcall] = ACTIONS(2114),
    [anon_sym___fastcall] = ACTIONS(2114),
    [anon_sym___thiscall] = ACTIONS(2114),
    [anon_sym___vectorcall] = ACTIONS(2114),
    [anon_sym_LBRACE] = ACTIONS(2116),
    [anon_sym_signed] = ACTIONS(2114),
    [anon_sym_unsigned] = ACTIONS(2114),
    [anon_sym_long] = ACTIONS(2114),
    [anon_sym_short] = ACTIONS(2114),
    [anon_sym_LBRACK] = ACTIONS(2114),
    [anon_sym_static] = ACTIONS(2114),
    [anon_sym_register] = ACTIONS(2114),
    [anon_sym_inline] = ACTIONS(2114),
    [anon_sym___inline] = ACTIONS(2114),
    [anon_sym___inline__] = ACTIONS(2114),
    [anon_sym___forceinline] = ACTIONS(2114),
    [anon_sym_thread_local] = ACTIONS(2114),
    [anon_sym___thread] = ACTIONS(2114),
    [anon_sym_const] = ACTIONS(2114),
    [anon_sym_constexpr] = ACTIONS(2114),
    [anon_sym_volatile] = ACTIONS(2114),
    [anon_sym_restrict] = ACTIONS(2114),
    [anon_sym___restrict__] = ACTIONS(2114),
    [anon_sym__Atomic] = ACTIONS(2114),
    [anon_sym__Noreturn] = ACTIONS(2114),
    [anon_sym_noreturn] = ACTIONS(2114),
    [anon_sym_mutable] = ACTIONS(2114),
    [anon_sym_constinit] = ACTIONS(2114),
    [anon_sym_consteval] = ACTIONS(2114),
    [anon_sym_alignas] = ACTIONS(2114),
    [anon_sym__Alignas] = ACTIONS(2114),
    [sym_primitive_type] = ACTIONS(2114),
    [anon_sym_enum] = ACTIONS(2114),
    [anon_sym_class] = ACTIONS(2114),
    [anon_sym_struct] = ACTIONS(2114),
    [anon_sym_union] = ACTIONS(2114),
    [anon_sym_if] = ACTIONS(2114),
    [anon_sym_else] = ACTIONS(2114),
    [anon_sym_switch] = ACTIONS(2114),
    [anon_sym_case] = ACTIONS(2114),
    [anon_sym_default] = ACTIONS(2114),
    [anon_sym_while] = ACTIONS(2114),
    [anon_sym_do] = ACTIONS(2114),
    [anon_sym_for] = ACTIONS(2114),
    [anon_sym_return] = ACTIONS(2114),
    [anon_sym_break] = ACTIONS(2114),
    [anon_sym_continue] = ACTIONS(2114),
    [anon_sym_goto] = ACTIONS(2114),
    [anon_sym___try] = ACTIONS(2114),
    [anon_sym___leave] = ACTIONS(2114),
    [anon_sym_not] = ACTIONS(2114),
    [anon_sym_compl] = ACTIONS(2114),
    [anon_sym_DASH_DASH] = ACTIONS(2116),
    [anon_sym_PLUS_PLUS] = ACTIONS(2116),
    [anon_sym_sizeof] = ACTIONS(2114),
    [anon_sym___alignof__] = ACTIONS(2114),
    [anon_sym___alignof] = ACTIONS(2114),
    [anon_sym__alignof] = ACTIONS(2114),
    [anon_sym_alignof] = ACTIONS(2114),
    [anon_sym__Alignof] = ACTIONS(2114),
    [anon_sym_offsetof] = ACTIONS(2114),
    [anon_sym__Generic] = ACTIONS(2114),
    [anon_sym_asm] = ACTIONS(2114),
    [anon_sym___asm__] = ACTIONS(2114),
    [sym_number_literal] = ACTIONS(2116),
    [anon_sym_L_SQUOTE] = ACTIONS(2116),
    [anon_sym_u_SQUOTE] = ACTIONS(2116),
    [anon_sym_U_SQUOTE] = ACTIONS(2116),
    [anon_sym_u8_SQUOTE] = ACTIONS(2116),
    [anon_sym_SQUOTE] = ACTIONS(2116),
    [anon_sym_L_DQUOTE] = ACTIONS(2116),
    [anon_sym_u_DQUOTE] = ACTIONS(2116),
    [anon_sym_U_DQUOTE] = ACTIONS(2116),
    [anon_sym_u8_DQUOTE] = ACTIONS(2116),
    [anon_sym_DQUOTE] = ACTIONS(2116),
    [sym_true] = ACTIONS(2114),
    [sym_false] = ACTIONS(2114),
    [anon_sym_NULL] = ACTIONS(2114),
    [anon_sym_nullptr] = ACTIONS(2114),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2114),
    [anon_sym_decltype] = ACTIONS(2114),
    [sym_virtual] = ACTIONS(2114),
    [anon_sym_explicit] = ACTIONS(2114),
    [anon_sym_typename] = ACTIONS(2114),
    [anon_sym_template] = ACTIONS(2114),
    [anon_sym_operator] = ACTIONS(2114),
    [anon_sym_try] = ACTIONS(2114),
    [anon_sym_delete] = ACTIONS(2114),
    [anon_sym_throw] = ACTIONS(2114),
    [anon_sym_namespace] = ACTIONS(2114),
    [anon_sym_using] = ACTIONS(2114),
    [anon_sym_static_assert] = ACTIONS(2114),
    [anon_sym_concept] = ACTIONS(2114),
    [anon_sym_co_return] = ACTIONS(2114),
    [anon_sym_co_yield] = ACTIONS(2114),
    [anon_sym_R_DQUOTE] = ACTIONS(2116),
    [anon_sym_LR_DQUOTE] = ACTIONS(2116),
    [anon_sym_uR_DQUOTE] = ACTIONS(2116),
    [anon_sym_UR_DQUOTE] = ACTIONS(2116),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2116),
    [anon_sym_co_await] = ACTIONS(2114),
    [anon_sym_new] = ACTIONS(2114),
    [anon_sym_requires] = ACTIONS(2114),
    [sym_this] = ACTIONS(2114),
    [anon_sym_discard] = ACTIONS(2114),
    [anon_sym_precise] = ACTIONS(2114),
    [anon_sym_shared] = ACTIONS(2114),
    [anon_sym_groupshared] = ACTIONS(2114),
    [anon_sym_uniform] = ACTIONS(2114),
    [anon_sym_row_major] = ACTIONS(2114),
    [anon_sym_column_major] = ACTIONS(2114),
    [anon_sym_globallycoherent] = ACTIONS(2114),
    [anon_sym_centroid] = ACTIONS(2114),
    [anon_sym_noperspective] = ACTIONS(2114),
    [anon_sym_nointerpolation] = ACTIONS(2114),
    [anon_sym_sample] = ACTIONS(2114),
    [anon_sym_linear] = ACTIONS(2114),
    [anon_sym_snorm] = ACTIONS(2114),
    [anon_sym_unorm] = ACTIONS(2114),
    [anon_sym_point] = ACTIONS(2114),
    [anon_sym_line] = ACTIONS(2114),
    [anon_sym_triangleadj] = ACTIONS(2114),
    [anon_sym_lineadj] = ACTIONS(2114),
    [anon_sym_triangle] = ACTIONS(2114),
    [anon_sym_cbuffer] = ACTIONS(2114),
  },
  [434] = {
    [sym_identifier] = ACTIONS(2240),
    [aux_sym_preproc_include_token1] = ACTIONS(2240),
    [aux_sym_preproc_def_token1] = ACTIONS(2240),
    [aux_sym_preproc_if_token1] = ACTIONS(2240),
    [aux_sym_preproc_if_token2] = ACTIONS(2240),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2240),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2240),
    [sym_preproc_directive] = ACTIONS(2240),
    [anon_sym_LPAREN2] = ACTIONS(2242),
    [anon_sym_BANG] = ACTIONS(2242),
    [anon_sym_TILDE] = ACTIONS(2242),
    [anon_sym_DASH] = ACTIONS(2240),
    [anon_sym_PLUS] = ACTIONS(2240),
    [anon_sym_STAR] = ACTIONS(2242),
    [anon_sym_AMP_AMP] = ACTIONS(2242),
    [anon_sym_AMP] = ACTIONS(2240),
    [anon_sym_SEMI] = ACTIONS(2242),
    [anon_sym___extension__] = ACTIONS(2240),
    [anon_sym_typedef] = ACTIONS(2240),
    [anon_sym_in] = ACTIONS(2240),
    [anon_sym_out] = ACTIONS(2240),
    [anon_sym_inout] = ACTIONS(2240),
    [anon_sym_extern] = ACTIONS(2240),
    [anon_sym___attribute__] = ACTIONS(2240),
    [anon_sym_COLON_COLON] = ACTIONS(2242),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2242),
    [anon_sym___declspec] = ACTIONS(2240),
    [anon_sym___based] = ACTIONS(2240),
    [anon_sym___cdecl] = ACTIONS(2240),
    [anon_sym___clrcall] = ACTIONS(2240),
    [anon_sym___stdcall] = ACTIONS(2240),
    [anon_sym___fastcall] = ACTIONS(2240),
    [anon_sym___thiscall] = ACTIONS(2240),
    [anon_sym___vectorcall] = ACTIONS(2240),
    [anon_sym_LBRACE] = ACTIONS(2242),
    [anon_sym_signed] = ACTIONS(2240),
    [anon_sym_unsigned] = ACTIONS(2240),
    [anon_sym_long] = ACTIONS(2240),
    [anon_sym_short] = ACTIONS(2240),
    [anon_sym_LBRACK] = ACTIONS(2240),
    [anon_sym_static] = ACTIONS(2240),
    [anon_sym_register] = ACTIONS(2240),
    [anon_sym_inline] = ACTIONS(2240),
    [anon_sym___inline] = ACTIONS(2240),
    [anon_sym___inline__] = ACTIONS(2240),
    [anon_sym___forceinline] = ACTIONS(2240),
    [anon_sym_thread_local] = ACTIONS(2240),
    [anon_sym___thread] = ACTIONS(2240),
    [anon_sym_const] = ACTIONS(2240),
    [anon_sym_constexpr] = ACTIONS(2240),
    [anon_sym_volatile] = ACTIONS(2240),
    [anon_sym_restrict] = ACTIONS(2240),
    [anon_sym___restrict__] = ACTIONS(2240),
    [anon_sym__Atomic] = ACTIONS(2240),
    [anon_sym__Noreturn] = ACTIONS(2240),
    [anon_sym_noreturn] = ACTIONS(2240),
    [anon_sym_mutable] = ACTIONS(2240),
    [anon_sym_constinit] = ACTIONS(2240),
    [anon_sym_consteval] = ACTIONS(2240),
    [anon_sym_alignas] = ACTIONS(2240),
    [anon_sym__Alignas] = ACTIONS(2240),
    [sym_primitive_type] = ACTIONS(2240),
    [anon_sym_enum] = ACTIONS(2240),
    [anon_sym_class] = ACTIONS(2240),
    [anon_sym_struct] = ACTIONS(2240),
    [anon_sym_union] = ACTIONS(2240),
    [anon_sym_if] = ACTIONS(2240),
    [anon_sym_else] = ACTIONS(2240),
    [anon_sym_switch] = ACTIONS(2240),
    [anon_sym_case] = ACTIONS(2240),
    [anon_sym_default] = ACTIONS(2240),
    [anon_sym_while] = ACTIONS(2240),
    [anon_sym_do] = ACTIONS(2240),
    [anon_sym_for] = ACTIONS(2240),
    [anon_sym_return] = ACTIONS(2240),
    [anon_sym_break] = ACTIONS(2240),
    [anon_sym_continue] = ACTIONS(2240),
    [anon_sym_goto] = ACTIONS(2240),
    [anon_sym___try] = ACTIONS(2240),
    [anon_sym___leave] = ACTIONS(2240),
    [anon_sym_not] = ACTIONS(2240),
    [anon_sym_compl] = ACTIONS(2240),
    [anon_sym_DASH_DASH] = ACTIONS(2242),
    [anon_sym_PLUS_PLUS] = ACTIONS(2242),
    [anon_sym_sizeof] = ACTIONS(2240),
    [anon_sym___alignof__] = ACTIONS(2240),
    [anon_sym___alignof] = ACTIONS(2240),
    [anon_sym__alignof] = ACTIONS(2240),
    [anon_sym_alignof] = ACTIONS(2240),
    [anon_sym__Alignof] = ACTIONS(2240),
    [anon_sym_offsetof] = ACTIONS(2240),
    [anon_sym__Generic] = ACTIONS(2240),
    [anon_sym_asm] = ACTIONS(2240),
    [anon_sym___asm__] = ACTIONS(2240),
    [sym_number_literal] = ACTIONS(2242),
    [anon_sym_L_SQUOTE] = ACTIONS(2242),
    [anon_sym_u_SQUOTE] = ACTIONS(2242),
    [anon_sym_U_SQUOTE] = ACTIONS(2242),
    [anon_sym_u8_SQUOTE] = ACTIONS(2242),
    [anon_sym_SQUOTE] = ACTIONS(2242),
    [anon_sym_L_DQUOTE] = ACTIONS(2242),
    [anon_sym_u_DQUOTE] = ACTIONS(2242),
    [anon_sym_U_DQUOTE] = ACTIONS(2242),
    [anon_sym_u8_DQUOTE] = ACTIONS(2242),
    [anon_sym_DQUOTE] = ACTIONS(2242),
    [sym_true] = ACTIONS(2240),
    [sym_false] = ACTIONS(2240),
    [anon_sym_NULL] = ACTIONS(2240),
    [anon_sym_nullptr] = ACTIONS(2240),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2240),
    [anon_sym_decltype] = ACTIONS(2240),
    [sym_virtual] = ACTIONS(2240),
    [anon_sym_explicit] = ACTIONS(2240),
    [anon_sym_typename] = ACTIONS(2240),
    [anon_sym_template] = ACTIONS(2240),
    [anon_sym_operator] = ACTIONS(2240),
    [anon_sym_try] = ACTIONS(2240),
    [anon_sym_delete] = ACTIONS(2240),
    [anon_sym_throw] = ACTIONS(2240),
    [anon_sym_namespace] = ACTIONS(2240),
    [anon_sym_using] = ACTIONS(2240),
    [anon_sym_static_assert] = ACTIONS(2240),
    [anon_sym_concept] = ACTIONS(2240),
    [anon_sym_co_return] = ACTIONS(2240),
    [anon_sym_co_yield] = ACTIONS(2240),
    [anon_sym_R_DQUOTE] = ACTIONS(2242),
    [anon_sym_LR_DQUOTE] = ACTIONS(2242),
    [anon_sym_uR_DQUOTE] = ACTIONS(2242),
    [anon_sym_UR_DQUOTE] = ACTIONS(2242),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2242),
    [anon_sym_co_await] = ACTIONS(2240),
    [anon_sym_new] = ACTIONS(2240),
    [anon_sym_requires] = ACTIONS(2240),
    [sym_this] = ACTIONS(2240),
    [anon_sym_discard] = ACTIONS(2240),
    [anon_sym_precise] = ACTIONS(2240),
    [anon_sym_shared] = ACTIONS(2240),
    [anon_sym_groupshared] = ACTIONS(2240),
    [anon_sym_uniform] = ACTIONS(2240),
    [anon_sym_row_major] = ACTIONS(2240),
    [anon_sym_column_major] = ACTIONS(2240),
    [anon_sym_globallycoherent] = ACTIONS(2240),
    [anon_sym_centroid] = ACTIONS(2240),
    [anon_sym_noperspective] = ACTIONS(2240),
    [anon_sym_nointerpolation] = ACTIONS(2240),
    [anon_sym_sample] = ACTIONS(2240),
    [anon_sym_linear] = ACTIONS(2240),
    [anon_sym_snorm] = ACTIONS(2240),
    [anon_sym_unorm] = ACTIONS(2240),
    [anon_sym_point] = ACTIONS(2240),
    [anon_sym_line] = ACTIONS(2240),
    [anon_sym_triangleadj] = ACTIONS(2240),
    [anon_sym_lineadj] = ACTIONS(2240),
    [anon_sym_triangle] = ACTIONS(2240),
    [anon_sym_cbuffer] = ACTIONS(2240),
  },
  [435] = {
    [ts_builtin_sym_end] = ACTIONS(2278),
    [sym_identifier] = ACTIONS(2276),
    [aux_sym_preproc_include_token1] = ACTIONS(2276),
    [aux_sym_preproc_def_token1] = ACTIONS(2276),
    [aux_sym_preproc_if_token1] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2276),
    [sym_preproc_directive] = ACTIONS(2276),
    [anon_sym_LPAREN2] = ACTIONS(2278),
    [anon_sym_BANG] = ACTIONS(2278),
    [anon_sym_TILDE] = ACTIONS(2278),
    [anon_sym_DASH] = ACTIONS(2276),
    [anon_sym_PLUS] = ACTIONS(2276),
    [anon_sym_STAR] = ACTIONS(2278),
    [anon_sym_AMP_AMP] = ACTIONS(2278),
    [anon_sym_AMP] = ACTIONS(2276),
    [anon_sym_SEMI] = ACTIONS(2278),
    [anon_sym___extension__] = ACTIONS(2276),
    [anon_sym_typedef] = ACTIONS(2276),
    [anon_sym_in] = ACTIONS(2276),
    [anon_sym_out] = ACTIONS(2276),
    [anon_sym_inout] = ACTIONS(2276),
    [anon_sym_extern] = ACTIONS(2276),
    [anon_sym___attribute__] = ACTIONS(2276),
    [anon_sym_COLON_COLON] = ACTIONS(2278),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2278),
    [anon_sym___declspec] = ACTIONS(2276),
    [anon_sym___based] = ACTIONS(2276),
    [anon_sym___cdecl] = ACTIONS(2276),
    [anon_sym___clrcall] = ACTIONS(2276),
    [anon_sym___stdcall] = ACTIONS(2276),
    [anon_sym___fastcall] = ACTIONS(2276),
    [anon_sym___thiscall] = ACTIONS(2276),
    [anon_sym___vectorcall] = ACTIONS(2276),
    [anon_sym_LBRACE] = ACTIONS(2278),
    [anon_sym_signed] = ACTIONS(2276),
    [anon_sym_unsigned] = ACTIONS(2276),
    [anon_sym_long] = ACTIONS(2276),
    [anon_sym_short] = ACTIONS(2276),
    [anon_sym_LBRACK] = ACTIONS(2276),
    [anon_sym_static] = ACTIONS(2276),
    [anon_sym_register] = ACTIONS(2276),
    [anon_sym_inline] = ACTIONS(2276),
    [anon_sym___inline] = ACTIONS(2276),
    [anon_sym___inline__] = ACTIONS(2276),
    [anon_sym___forceinline] = ACTIONS(2276),
    [anon_sym_thread_local] = ACTIONS(2276),
    [anon_sym___thread] = ACTIONS(2276),
    [anon_sym_const] = ACTIONS(2276),
    [anon_sym_constexpr] = ACTIONS(2276),
    [anon_sym_volatile] = ACTIONS(2276),
    [anon_sym_restrict] = ACTIONS(2276),
    [anon_sym___restrict__] = ACTIONS(2276),
    [anon_sym__Atomic] = ACTIONS(2276),
    [anon_sym__Noreturn] = ACTIONS(2276),
    [anon_sym_noreturn] = ACTIONS(2276),
    [anon_sym_mutable] = ACTIONS(2276),
    [anon_sym_constinit] = ACTIONS(2276),
    [anon_sym_consteval] = ACTIONS(2276),
    [anon_sym_alignas] = ACTIONS(2276),
    [anon_sym__Alignas] = ACTIONS(2276),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2276),
    [anon_sym_class] = ACTIONS(2276),
    [anon_sym_struct] = ACTIONS(2276),
    [anon_sym_union] = ACTIONS(2276),
    [anon_sym_if] = ACTIONS(2276),
    [anon_sym_else] = ACTIONS(2276),
    [anon_sym_switch] = ACTIONS(2276),
    [anon_sym_case] = ACTIONS(2276),
    [anon_sym_default] = ACTIONS(2276),
    [anon_sym_while] = ACTIONS(2276),
    [anon_sym_do] = ACTIONS(2276),
    [anon_sym_for] = ACTIONS(2276),
    [anon_sym_return] = ACTIONS(2276),
    [anon_sym_break] = ACTIONS(2276),
    [anon_sym_continue] = ACTIONS(2276),
    [anon_sym_goto] = ACTIONS(2276),
    [anon_sym___try] = ACTIONS(2276),
    [anon_sym___leave] = ACTIONS(2276),
    [anon_sym_not] = ACTIONS(2276),
    [anon_sym_compl] = ACTIONS(2276),
    [anon_sym_DASH_DASH] = ACTIONS(2278),
    [anon_sym_PLUS_PLUS] = ACTIONS(2278),
    [anon_sym_sizeof] = ACTIONS(2276),
    [anon_sym___alignof__] = ACTIONS(2276),
    [anon_sym___alignof] = ACTIONS(2276),
    [anon_sym__alignof] = ACTIONS(2276),
    [anon_sym_alignof] = ACTIONS(2276),
    [anon_sym__Alignof] = ACTIONS(2276),
    [anon_sym_offsetof] = ACTIONS(2276),
    [anon_sym__Generic] = ACTIONS(2276),
    [anon_sym_asm] = ACTIONS(2276),
    [anon_sym___asm__] = ACTIONS(2276),
    [sym_number_literal] = ACTIONS(2278),
    [anon_sym_L_SQUOTE] = ACTIONS(2278),
    [anon_sym_u_SQUOTE] = ACTIONS(2278),
    [anon_sym_U_SQUOTE] = ACTIONS(2278),
    [anon_sym_u8_SQUOTE] = ACTIONS(2278),
    [anon_sym_SQUOTE] = ACTIONS(2278),
    [anon_sym_L_DQUOTE] = ACTIONS(2278),
    [anon_sym_u_DQUOTE] = ACTIONS(2278),
    [anon_sym_U_DQUOTE] = ACTIONS(2278),
    [anon_sym_u8_DQUOTE] = ACTIONS(2278),
    [anon_sym_DQUOTE] = ACTIONS(2278),
    [sym_true] = ACTIONS(2276),
    [sym_false] = ACTIONS(2276),
    [anon_sym_NULL] = ACTIONS(2276),
    [anon_sym_nullptr] = ACTIONS(2276),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2276),
    [anon_sym_decltype] = ACTIONS(2276),
    [sym_virtual] = ACTIONS(2276),
    [anon_sym_explicit] = ACTIONS(2276),
    [anon_sym_typename] = ACTIONS(2276),
    [anon_sym_template] = ACTIONS(2276),
    [anon_sym_operator] = ACTIONS(2276),
    [anon_sym_try] = ACTIONS(2276),
    [anon_sym_delete] = ACTIONS(2276),
    [anon_sym_throw] = ACTIONS(2276),
    [anon_sym_namespace] = ACTIONS(2276),
    [anon_sym_using] = ACTIONS(2276),
    [anon_sym_static_assert] = ACTIONS(2276),
    [anon_sym_concept] = ACTIONS(2276),
    [anon_sym_co_return] = ACTIONS(2276),
    [anon_sym_co_yield] = ACTIONS(2276),
    [anon_sym_R_DQUOTE] = ACTIONS(2278),
    [anon_sym_LR_DQUOTE] = ACTIONS(2278),
    [anon_sym_uR_DQUOTE] = ACTIONS(2278),
    [anon_sym_UR_DQUOTE] = ACTIONS(2278),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2278),
    [anon_sym_co_await] = ACTIONS(2276),
    [anon_sym_new] = ACTIONS(2276),
    [anon_sym_requires] = ACTIONS(2276),
    [sym_this] = ACTIONS(2276),
    [anon_sym_discard] = ACTIONS(2276),
    [anon_sym_precise] = ACTIONS(2276),
    [anon_sym_shared] = ACTIONS(2276),
    [anon_sym_groupshared] = ACTIONS(2276),
    [anon_sym_uniform] = ACTIONS(2276),
    [anon_sym_row_major] = ACTIONS(2276),
    [anon_sym_column_major] = ACTIONS(2276),
    [anon_sym_globallycoherent] = ACTIONS(2276),
    [anon_sym_centroid] = ACTIONS(2276),
    [anon_sym_noperspective] = ACTIONS(2276),
    [anon_sym_nointerpolation] = ACTIONS(2276),
    [anon_sym_sample] = ACTIONS(2276),
    [anon_sym_linear] = ACTIONS(2276),
    [anon_sym_snorm] = ACTIONS(2276),
    [anon_sym_unorm] = ACTIONS(2276),
    [anon_sym_point] = ACTIONS(2276),
    [anon_sym_line] = ACTIONS(2276),
    [anon_sym_triangleadj] = ACTIONS(2276),
    [anon_sym_lineadj] = ACTIONS(2276),
    [anon_sym_triangle] = ACTIONS(2276),
    [anon_sym_cbuffer] = ACTIONS(2276),
  },
  [436] = {
    [ts_builtin_sym_end] = ACTIONS(2278),
    [sym_identifier] = ACTIONS(2276),
    [aux_sym_preproc_include_token1] = ACTIONS(2276),
    [aux_sym_preproc_def_token1] = ACTIONS(2276),
    [aux_sym_preproc_if_token1] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2276),
    [sym_preproc_directive] = ACTIONS(2276),
    [anon_sym_LPAREN2] = ACTIONS(2278),
    [anon_sym_BANG] = ACTIONS(2278),
    [anon_sym_TILDE] = ACTIONS(2278),
    [anon_sym_DASH] = ACTIONS(2276),
    [anon_sym_PLUS] = ACTIONS(2276),
    [anon_sym_STAR] = ACTIONS(2278),
    [anon_sym_AMP_AMP] = ACTIONS(2278),
    [anon_sym_AMP] = ACTIONS(2276),
    [anon_sym_SEMI] = ACTIONS(2278),
    [anon_sym___extension__] = ACTIONS(2276),
    [anon_sym_typedef] = ACTIONS(2276),
    [anon_sym_in] = ACTIONS(2276),
    [anon_sym_out] = ACTIONS(2276),
    [anon_sym_inout] = ACTIONS(2276),
    [anon_sym_extern] = ACTIONS(2276),
    [anon_sym___attribute__] = ACTIONS(2276),
    [anon_sym_COLON_COLON] = ACTIONS(2278),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2278),
    [anon_sym___declspec] = ACTIONS(2276),
    [anon_sym___based] = ACTIONS(2276),
    [anon_sym___cdecl] = ACTIONS(2276),
    [anon_sym___clrcall] = ACTIONS(2276),
    [anon_sym___stdcall] = ACTIONS(2276),
    [anon_sym___fastcall] = ACTIONS(2276),
    [anon_sym___thiscall] = ACTIONS(2276),
    [anon_sym___vectorcall] = ACTIONS(2276),
    [anon_sym_LBRACE] = ACTIONS(2278),
    [anon_sym_signed] = ACTIONS(2276),
    [anon_sym_unsigned] = ACTIONS(2276),
    [anon_sym_long] = ACTIONS(2276),
    [anon_sym_short] = ACTIONS(2276),
    [anon_sym_LBRACK] = ACTIONS(2276),
    [anon_sym_static] = ACTIONS(2276),
    [anon_sym_register] = ACTIONS(2276),
    [anon_sym_inline] = ACTIONS(2276),
    [anon_sym___inline] = ACTIONS(2276),
    [anon_sym___inline__] = ACTIONS(2276),
    [anon_sym___forceinline] = ACTIONS(2276),
    [anon_sym_thread_local] = ACTIONS(2276),
    [anon_sym___thread] = ACTIONS(2276),
    [anon_sym_const] = ACTIONS(2276),
    [anon_sym_constexpr] = ACTIONS(2276),
    [anon_sym_volatile] = ACTIONS(2276),
    [anon_sym_restrict] = ACTIONS(2276),
    [anon_sym___restrict__] = ACTIONS(2276),
    [anon_sym__Atomic] = ACTIONS(2276),
    [anon_sym__Noreturn] = ACTIONS(2276),
    [anon_sym_noreturn] = ACTIONS(2276),
    [anon_sym_mutable] = ACTIONS(2276),
    [anon_sym_constinit] = ACTIONS(2276),
    [anon_sym_consteval] = ACTIONS(2276),
    [anon_sym_alignas] = ACTIONS(2276),
    [anon_sym__Alignas] = ACTIONS(2276),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2276),
    [anon_sym_class] = ACTIONS(2276),
    [anon_sym_struct] = ACTIONS(2276),
    [anon_sym_union] = ACTIONS(2276),
    [anon_sym_if] = ACTIONS(2276),
    [anon_sym_else] = ACTIONS(2276),
    [anon_sym_switch] = ACTIONS(2276),
    [anon_sym_case] = ACTIONS(2276),
    [anon_sym_default] = ACTIONS(2276),
    [anon_sym_while] = ACTIONS(2276),
    [anon_sym_do] = ACTIONS(2276),
    [anon_sym_for] = ACTIONS(2276),
    [anon_sym_return] = ACTIONS(2276),
    [anon_sym_break] = ACTIONS(2276),
    [anon_sym_continue] = ACTIONS(2276),
    [anon_sym_goto] = ACTIONS(2276),
    [anon_sym___try] = ACTIONS(2276),
    [anon_sym___leave] = ACTIONS(2276),
    [anon_sym_not] = ACTIONS(2276),
    [anon_sym_compl] = ACTIONS(2276),
    [anon_sym_DASH_DASH] = ACTIONS(2278),
    [anon_sym_PLUS_PLUS] = ACTIONS(2278),
    [anon_sym_sizeof] = ACTIONS(2276),
    [anon_sym___alignof__] = ACTIONS(2276),
    [anon_sym___alignof] = ACTIONS(2276),
    [anon_sym__alignof] = ACTIONS(2276),
    [anon_sym_alignof] = ACTIONS(2276),
    [anon_sym__Alignof] = ACTIONS(2276),
    [anon_sym_offsetof] = ACTIONS(2276),
    [anon_sym__Generic] = ACTIONS(2276),
    [anon_sym_asm] = ACTIONS(2276),
    [anon_sym___asm__] = ACTIONS(2276),
    [sym_number_literal] = ACTIONS(2278),
    [anon_sym_L_SQUOTE] = ACTIONS(2278),
    [anon_sym_u_SQUOTE] = ACTIONS(2278),
    [anon_sym_U_SQUOTE] = ACTIONS(2278),
    [anon_sym_u8_SQUOTE] = ACTIONS(2278),
    [anon_sym_SQUOTE] = ACTIONS(2278),
    [anon_sym_L_DQUOTE] = ACTIONS(2278),
    [anon_sym_u_DQUOTE] = ACTIONS(2278),
    [anon_sym_U_DQUOTE] = ACTIONS(2278),
    [anon_sym_u8_DQUOTE] = ACTIONS(2278),
    [anon_sym_DQUOTE] = ACTIONS(2278),
    [sym_true] = ACTIONS(2276),
    [sym_false] = ACTIONS(2276),
    [anon_sym_NULL] = ACTIONS(2276),
    [anon_sym_nullptr] = ACTIONS(2276),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2276),
    [anon_sym_decltype] = ACTIONS(2276),
    [sym_virtual] = ACTIONS(2276),
    [anon_sym_explicit] = ACTIONS(2276),
    [anon_sym_typename] = ACTIONS(2276),
    [anon_sym_template] = ACTIONS(2276),
    [anon_sym_operator] = ACTIONS(2276),
    [anon_sym_try] = ACTIONS(2276),
    [anon_sym_delete] = ACTIONS(2276),
    [anon_sym_throw] = ACTIONS(2276),
    [anon_sym_namespace] = ACTIONS(2276),
    [anon_sym_using] = ACTIONS(2276),
    [anon_sym_static_assert] = ACTIONS(2276),
    [anon_sym_concept] = ACTIONS(2276),
    [anon_sym_co_return] = ACTIONS(2276),
    [anon_sym_co_yield] = ACTIONS(2276),
    [anon_sym_R_DQUOTE] = ACTIONS(2278),
    [anon_sym_LR_DQUOTE] = ACTIONS(2278),
    [anon_sym_uR_DQUOTE] = ACTIONS(2278),
    [anon_sym_UR_DQUOTE] = ACTIONS(2278),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2278),
    [anon_sym_co_await] = ACTIONS(2276),
    [anon_sym_new] = ACTIONS(2276),
    [anon_sym_requires] = ACTIONS(2276),
    [sym_this] = ACTIONS(2276),
    [anon_sym_discard] = ACTIONS(2276),
    [anon_sym_precise] = ACTIONS(2276),
    [anon_sym_shared] = ACTIONS(2276),
    [anon_sym_groupshared] = ACTIONS(2276),
    [anon_sym_uniform] = ACTIONS(2276),
    [anon_sym_row_major] = ACTIONS(2276),
    [anon_sym_column_major] = ACTIONS(2276),
    [anon_sym_globallycoherent] = ACTIONS(2276),
    [anon_sym_centroid] = ACTIONS(2276),
    [anon_sym_noperspective] = ACTIONS(2276),
    [anon_sym_nointerpolation] = ACTIONS(2276),
    [anon_sym_sample] = ACTIONS(2276),
    [anon_sym_linear] = ACTIONS(2276),
    [anon_sym_snorm] = ACTIONS(2276),
    [anon_sym_unorm] = ACTIONS(2276),
    [anon_sym_point] = ACTIONS(2276),
    [anon_sym_line] = ACTIONS(2276),
    [anon_sym_triangleadj] = ACTIONS(2276),
    [anon_sym_lineadj] = ACTIONS(2276),
    [anon_sym_triangle] = ACTIONS(2276),
    [anon_sym_cbuffer] = ACTIONS(2276),
  },
  [437] = {
    [sym_identifier] = ACTIONS(2236),
    [aux_sym_preproc_include_token1] = ACTIONS(2236),
    [aux_sym_preproc_def_token1] = ACTIONS(2236),
    [aux_sym_preproc_if_token1] = ACTIONS(2236),
    [aux_sym_preproc_if_token2] = ACTIONS(2236),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2236),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2236),
    [sym_preproc_directive] = ACTIONS(2236),
    [anon_sym_LPAREN2] = ACTIONS(2238),
    [anon_sym_BANG] = ACTIONS(2238),
    [anon_sym_TILDE] = ACTIONS(2238),
    [anon_sym_DASH] = ACTIONS(2236),
    [anon_sym_PLUS] = ACTIONS(2236),
    [anon_sym_STAR] = ACTIONS(2238),
    [anon_sym_AMP_AMP] = ACTIONS(2238),
    [anon_sym_AMP] = ACTIONS(2236),
    [anon_sym_SEMI] = ACTIONS(2238),
    [anon_sym___extension__] = ACTIONS(2236),
    [anon_sym_typedef] = ACTIONS(2236),
    [anon_sym_in] = ACTIONS(2236),
    [anon_sym_out] = ACTIONS(2236),
    [anon_sym_inout] = ACTIONS(2236),
    [anon_sym_extern] = ACTIONS(2236),
    [anon_sym___attribute__] = ACTIONS(2236),
    [anon_sym_COLON_COLON] = ACTIONS(2238),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2238),
    [anon_sym___declspec] = ACTIONS(2236),
    [anon_sym___based] = ACTIONS(2236),
    [anon_sym___cdecl] = ACTIONS(2236),
    [anon_sym___clrcall] = ACTIONS(2236),
    [anon_sym___stdcall] = ACTIONS(2236),
    [anon_sym___fastcall] = ACTIONS(2236),
    [anon_sym___thiscall] = ACTIONS(2236),
    [anon_sym___vectorcall] = ACTIONS(2236),
    [anon_sym_LBRACE] = ACTIONS(2238),
    [anon_sym_signed] = ACTIONS(2236),
    [anon_sym_unsigned] = ACTIONS(2236),
    [anon_sym_long] = ACTIONS(2236),
    [anon_sym_short] = ACTIONS(2236),
    [anon_sym_LBRACK] = ACTIONS(2236),
    [anon_sym_static] = ACTIONS(2236),
    [anon_sym_register] = ACTIONS(2236),
    [anon_sym_inline] = ACTIONS(2236),
    [anon_sym___inline] = ACTIONS(2236),
    [anon_sym___inline__] = ACTIONS(2236),
    [anon_sym___forceinline] = ACTIONS(2236),
    [anon_sym_thread_local] = ACTIONS(2236),
    [anon_sym___thread] = ACTIONS(2236),
    [anon_sym_const] = ACTIONS(2236),
    [anon_sym_constexpr] = ACTIONS(2236),
    [anon_sym_volatile] = ACTIONS(2236),
    [anon_sym_restrict] = ACTIONS(2236),
    [anon_sym___restrict__] = ACTIONS(2236),
    [anon_sym__Atomic] = ACTIONS(2236),
    [anon_sym__Noreturn] = ACTIONS(2236),
    [anon_sym_noreturn] = ACTIONS(2236),
    [anon_sym_mutable] = ACTIONS(2236),
    [anon_sym_constinit] = ACTIONS(2236),
    [anon_sym_consteval] = ACTIONS(2236),
    [anon_sym_alignas] = ACTIONS(2236),
    [anon_sym__Alignas] = ACTIONS(2236),
    [sym_primitive_type] = ACTIONS(2236),
    [anon_sym_enum] = ACTIONS(2236),
    [anon_sym_class] = ACTIONS(2236),
    [anon_sym_struct] = ACTIONS(2236),
    [anon_sym_union] = ACTIONS(2236),
    [anon_sym_if] = ACTIONS(2236),
    [anon_sym_else] = ACTIONS(2236),
    [anon_sym_switch] = ACTIONS(2236),
    [anon_sym_case] = ACTIONS(2236),
    [anon_sym_default] = ACTIONS(2236),
    [anon_sym_while] = ACTIONS(2236),
    [anon_sym_do] = ACTIONS(2236),
    [anon_sym_for] = ACTIONS(2236),
    [anon_sym_return] = ACTIONS(2236),
    [anon_sym_break] = ACTIONS(2236),
    [anon_sym_continue] = ACTIONS(2236),
    [anon_sym_goto] = ACTIONS(2236),
    [anon_sym___try] = ACTIONS(2236),
    [anon_sym___leave] = ACTIONS(2236),
    [anon_sym_not] = ACTIONS(2236),
    [anon_sym_compl] = ACTIONS(2236),
    [anon_sym_DASH_DASH] = ACTIONS(2238),
    [anon_sym_PLUS_PLUS] = ACTIONS(2238),
    [anon_sym_sizeof] = ACTIONS(2236),
    [anon_sym___alignof__] = ACTIONS(2236),
    [anon_sym___alignof] = ACTIONS(2236),
    [anon_sym__alignof] = ACTIONS(2236),
    [anon_sym_alignof] = ACTIONS(2236),
    [anon_sym__Alignof] = ACTIONS(2236),
    [anon_sym_offsetof] = ACTIONS(2236),
    [anon_sym__Generic] = ACTIONS(2236),
    [anon_sym_asm] = ACTIONS(2236),
    [anon_sym___asm__] = ACTIONS(2236),
    [sym_number_literal] = ACTIONS(2238),
    [anon_sym_L_SQUOTE] = ACTIONS(2238),
    [anon_sym_u_SQUOTE] = ACTIONS(2238),
    [anon_sym_U_SQUOTE] = ACTIONS(2238),
    [anon_sym_u8_SQUOTE] = ACTIONS(2238),
    [anon_sym_SQUOTE] = ACTIONS(2238),
    [anon_sym_L_DQUOTE] = ACTIONS(2238),
    [anon_sym_u_DQUOTE] = ACTIONS(2238),
    [anon_sym_U_DQUOTE] = ACTIONS(2238),
    [anon_sym_u8_DQUOTE] = ACTIONS(2238),
    [anon_sym_DQUOTE] = ACTIONS(2238),
    [sym_true] = ACTIONS(2236),
    [sym_false] = ACTIONS(2236),
    [anon_sym_NULL] = ACTIONS(2236),
    [anon_sym_nullptr] = ACTIONS(2236),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2236),
    [anon_sym_decltype] = ACTIONS(2236),
    [sym_virtual] = ACTIONS(2236),
    [anon_sym_explicit] = ACTIONS(2236),
    [anon_sym_typename] = ACTIONS(2236),
    [anon_sym_template] = ACTIONS(2236),
    [anon_sym_operator] = ACTIONS(2236),
    [anon_sym_try] = ACTIONS(2236),
    [anon_sym_delete] = ACTIONS(2236),
    [anon_sym_throw] = ACTIONS(2236),
    [anon_sym_namespace] = ACTIONS(2236),
    [anon_sym_using] = ACTIONS(2236),
    [anon_sym_static_assert] = ACTIONS(2236),
    [anon_sym_concept] = ACTIONS(2236),
    [anon_sym_co_return] = ACTIONS(2236),
    [anon_sym_co_yield] = ACTIONS(2236),
    [anon_sym_R_DQUOTE] = ACTIONS(2238),
    [anon_sym_LR_DQUOTE] = ACTIONS(2238),
    [anon_sym_uR_DQUOTE] = ACTIONS(2238),
    [anon_sym_UR_DQUOTE] = ACTIONS(2238),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2238),
    [anon_sym_co_await] = ACTIONS(2236),
    [anon_sym_new] = ACTIONS(2236),
    [anon_sym_requires] = ACTIONS(2236),
    [sym_this] = ACTIONS(2236),
    [anon_sym_discard] = ACTIONS(2236),
    [anon_sym_precise] = ACTIONS(2236),
    [anon_sym_shared] = ACTIONS(2236),
    [anon_sym_groupshared] = ACTIONS(2236),
    [anon_sym_uniform] = ACTIONS(2236),
    [anon_sym_row_major] = ACTIONS(2236),
    [anon_sym_column_major] = ACTIONS(2236),
    [anon_sym_globallycoherent] = ACTIONS(2236),
    [anon_sym_centroid] = ACTIONS(2236),
    [anon_sym_noperspective] = ACTIONS(2236),
    [anon_sym_nointerpolation] = ACTIONS(2236),
    [anon_sym_sample] = ACTIONS(2236),
    [anon_sym_linear] = ACTIONS(2236),
    [anon_sym_snorm] = ACTIONS(2236),
    [anon_sym_unorm] = ACTIONS(2236),
    [anon_sym_point] = ACTIONS(2236),
    [anon_sym_line] = ACTIONS(2236),
    [anon_sym_triangleadj] = ACTIONS(2236),
    [anon_sym_lineadj] = ACTIONS(2236),
    [anon_sym_triangle] = ACTIONS(2236),
    [anon_sym_cbuffer] = ACTIONS(2236),
  },
  [438] = {
    [sym_identifier] = ACTIONS(2228),
    [aux_sym_preproc_include_token1] = ACTIONS(2228),
    [aux_sym_preproc_def_token1] = ACTIONS(2228),
    [aux_sym_preproc_if_token1] = ACTIONS(2228),
    [aux_sym_preproc_if_token2] = ACTIONS(2228),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2228),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2228),
    [sym_preproc_directive] = ACTIONS(2228),
    [anon_sym_LPAREN2] = ACTIONS(2230),
    [anon_sym_BANG] = ACTIONS(2230),
    [anon_sym_TILDE] = ACTIONS(2230),
    [anon_sym_DASH] = ACTIONS(2228),
    [anon_sym_PLUS] = ACTIONS(2228),
    [anon_sym_STAR] = ACTIONS(2230),
    [anon_sym_AMP_AMP] = ACTIONS(2230),
    [anon_sym_AMP] = ACTIONS(2228),
    [anon_sym_SEMI] = ACTIONS(2230),
    [anon_sym___extension__] = ACTIONS(2228),
    [anon_sym_typedef] = ACTIONS(2228),
    [anon_sym_in] = ACTIONS(2228),
    [anon_sym_out] = ACTIONS(2228),
    [anon_sym_inout] = ACTIONS(2228),
    [anon_sym_extern] = ACTIONS(2228),
    [anon_sym___attribute__] = ACTIONS(2228),
    [anon_sym_COLON_COLON] = ACTIONS(2230),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2230),
    [anon_sym___declspec] = ACTIONS(2228),
    [anon_sym___based] = ACTIONS(2228),
    [anon_sym___cdecl] = ACTIONS(2228),
    [anon_sym___clrcall] = ACTIONS(2228),
    [anon_sym___stdcall] = ACTIONS(2228),
    [anon_sym___fastcall] = ACTIONS(2228),
    [anon_sym___thiscall] = ACTIONS(2228),
    [anon_sym___vectorcall] = ACTIONS(2228),
    [anon_sym_LBRACE] = ACTIONS(2230),
    [anon_sym_signed] = ACTIONS(2228),
    [anon_sym_unsigned] = ACTIONS(2228),
    [anon_sym_long] = ACTIONS(2228),
    [anon_sym_short] = ACTIONS(2228),
    [anon_sym_LBRACK] = ACTIONS(2228),
    [anon_sym_static] = ACTIONS(2228),
    [anon_sym_register] = ACTIONS(2228),
    [anon_sym_inline] = ACTIONS(2228),
    [anon_sym___inline] = ACTIONS(2228),
    [anon_sym___inline__] = ACTIONS(2228),
    [anon_sym___forceinline] = ACTIONS(2228),
    [anon_sym_thread_local] = ACTIONS(2228),
    [anon_sym___thread] = ACTIONS(2228),
    [anon_sym_const] = ACTIONS(2228),
    [anon_sym_constexpr] = ACTIONS(2228),
    [anon_sym_volatile] = ACTIONS(2228),
    [anon_sym_restrict] = ACTIONS(2228),
    [anon_sym___restrict__] = ACTIONS(2228),
    [anon_sym__Atomic] = ACTIONS(2228),
    [anon_sym__Noreturn] = ACTIONS(2228),
    [anon_sym_noreturn] = ACTIONS(2228),
    [anon_sym_mutable] = ACTIONS(2228),
    [anon_sym_constinit] = ACTIONS(2228),
    [anon_sym_consteval] = ACTIONS(2228),
    [anon_sym_alignas] = ACTIONS(2228),
    [anon_sym__Alignas] = ACTIONS(2228),
    [sym_primitive_type] = ACTIONS(2228),
    [anon_sym_enum] = ACTIONS(2228),
    [anon_sym_class] = ACTIONS(2228),
    [anon_sym_struct] = ACTIONS(2228),
    [anon_sym_union] = ACTIONS(2228),
    [anon_sym_if] = ACTIONS(2228),
    [anon_sym_else] = ACTIONS(2228),
    [anon_sym_switch] = ACTIONS(2228),
    [anon_sym_case] = ACTIONS(2228),
    [anon_sym_default] = ACTIONS(2228),
    [anon_sym_while] = ACTIONS(2228),
    [anon_sym_do] = ACTIONS(2228),
    [anon_sym_for] = ACTIONS(2228),
    [anon_sym_return] = ACTIONS(2228),
    [anon_sym_break] = ACTIONS(2228),
    [anon_sym_continue] = ACTIONS(2228),
    [anon_sym_goto] = ACTIONS(2228),
    [anon_sym___try] = ACTIONS(2228),
    [anon_sym___leave] = ACTIONS(2228),
    [anon_sym_not] = ACTIONS(2228),
    [anon_sym_compl] = ACTIONS(2228),
    [anon_sym_DASH_DASH] = ACTIONS(2230),
    [anon_sym_PLUS_PLUS] = ACTIONS(2230),
    [anon_sym_sizeof] = ACTIONS(2228),
    [anon_sym___alignof__] = ACTIONS(2228),
    [anon_sym___alignof] = ACTIONS(2228),
    [anon_sym__alignof] = ACTIONS(2228),
    [anon_sym_alignof] = ACTIONS(2228),
    [anon_sym__Alignof] = ACTIONS(2228),
    [anon_sym_offsetof] = ACTIONS(2228),
    [anon_sym__Generic] = ACTIONS(2228),
    [anon_sym_asm] = ACTIONS(2228),
    [anon_sym___asm__] = ACTIONS(2228),
    [sym_number_literal] = ACTIONS(2230),
    [anon_sym_L_SQUOTE] = ACTIONS(2230),
    [anon_sym_u_SQUOTE] = ACTIONS(2230),
    [anon_sym_U_SQUOTE] = ACTIONS(2230),
    [anon_sym_u8_SQUOTE] = ACTIONS(2230),
    [anon_sym_SQUOTE] = ACTIONS(2230),
    [anon_sym_L_DQUOTE] = ACTIONS(2230),
    [anon_sym_u_DQUOTE] = ACTIONS(2230),
    [anon_sym_U_DQUOTE] = ACTIONS(2230),
    [anon_sym_u8_DQUOTE] = ACTIONS(2230),
    [anon_sym_DQUOTE] = ACTIONS(2230),
    [sym_true] = ACTIONS(2228),
    [sym_false] = ACTIONS(2228),
    [anon_sym_NULL] = ACTIONS(2228),
    [anon_sym_nullptr] = ACTIONS(2228),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2228),
    [anon_sym_decltype] = ACTIONS(2228),
    [sym_virtual] = ACTIONS(2228),
    [anon_sym_explicit] = ACTIONS(2228),
    [anon_sym_typename] = ACTIONS(2228),
    [anon_sym_template] = ACTIONS(2228),
    [anon_sym_operator] = ACTIONS(2228),
    [anon_sym_try] = ACTIONS(2228),
    [anon_sym_delete] = ACTIONS(2228),
    [anon_sym_throw] = ACTIONS(2228),
    [anon_sym_namespace] = ACTIONS(2228),
    [anon_sym_using] = ACTIONS(2228),
    [anon_sym_static_assert] = ACTIONS(2228),
    [anon_sym_concept] = ACTIONS(2228),
    [anon_sym_co_return] = ACTIONS(2228),
    [anon_sym_co_yield] = ACTIONS(2228),
    [anon_sym_R_DQUOTE] = ACTIONS(2230),
    [anon_sym_LR_DQUOTE] = ACTIONS(2230),
    [anon_sym_uR_DQUOTE] = ACTIONS(2230),
    [anon_sym_UR_DQUOTE] = ACTIONS(2230),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2230),
    [anon_sym_co_await] = ACTIONS(2228),
    [anon_sym_new] = ACTIONS(2228),
    [anon_sym_requires] = ACTIONS(2228),
    [sym_this] = ACTIONS(2228),
    [anon_sym_discard] = ACTIONS(2228),
    [anon_sym_precise] = ACTIONS(2228),
    [anon_sym_shared] = ACTIONS(2228),
    [anon_sym_groupshared] = ACTIONS(2228),
    [anon_sym_uniform] = ACTIONS(2228),
    [anon_sym_row_major] = ACTIONS(2228),
    [anon_sym_column_major] = ACTIONS(2228),
    [anon_sym_globallycoherent] = ACTIONS(2228),
    [anon_sym_centroid] = ACTIONS(2228),
    [anon_sym_noperspective] = ACTIONS(2228),
    [anon_sym_nointerpolation] = ACTIONS(2228),
    [anon_sym_sample] = ACTIONS(2228),
    [anon_sym_linear] = ACTIONS(2228),
    [anon_sym_snorm] = ACTIONS(2228),
    [anon_sym_unorm] = ACTIONS(2228),
    [anon_sym_point] = ACTIONS(2228),
    [anon_sym_line] = ACTIONS(2228),
    [anon_sym_triangleadj] = ACTIONS(2228),
    [anon_sym_lineadj] = ACTIONS(2228),
    [anon_sym_triangle] = ACTIONS(2228),
    [anon_sym_cbuffer] = ACTIONS(2228),
  },
  [439] = {
    [sym_identifier] = ACTIONS(2224),
    [aux_sym_preproc_include_token1] = ACTIONS(2224),
    [aux_sym_preproc_def_token1] = ACTIONS(2224),
    [aux_sym_preproc_if_token1] = ACTIONS(2224),
    [aux_sym_preproc_if_token2] = ACTIONS(2224),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2224),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2224),
    [sym_preproc_directive] = ACTIONS(2224),
    [anon_sym_LPAREN2] = ACTIONS(2226),
    [anon_sym_BANG] = ACTIONS(2226),
    [anon_sym_TILDE] = ACTIONS(2226),
    [anon_sym_DASH] = ACTIONS(2224),
    [anon_sym_PLUS] = ACTIONS(2224),
    [anon_sym_STAR] = ACTIONS(2226),
    [anon_sym_AMP_AMP] = ACTIONS(2226),
    [anon_sym_AMP] = ACTIONS(2224),
    [anon_sym_SEMI] = ACTIONS(2226),
    [anon_sym___extension__] = ACTIONS(2224),
    [anon_sym_typedef] = ACTIONS(2224),
    [anon_sym_in] = ACTIONS(2224),
    [anon_sym_out] = ACTIONS(2224),
    [anon_sym_inout] = ACTIONS(2224),
    [anon_sym_extern] = ACTIONS(2224),
    [anon_sym___attribute__] = ACTIONS(2224),
    [anon_sym_COLON_COLON] = ACTIONS(2226),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2226),
    [anon_sym___declspec] = ACTIONS(2224),
    [anon_sym___based] = ACTIONS(2224),
    [anon_sym___cdecl] = ACTIONS(2224),
    [anon_sym___clrcall] = ACTIONS(2224),
    [anon_sym___stdcall] = ACTIONS(2224),
    [anon_sym___fastcall] = ACTIONS(2224),
    [anon_sym___thiscall] = ACTIONS(2224),
    [anon_sym___vectorcall] = ACTIONS(2224),
    [anon_sym_LBRACE] = ACTIONS(2226),
    [anon_sym_signed] = ACTIONS(2224),
    [anon_sym_unsigned] = ACTIONS(2224),
    [anon_sym_long] = ACTIONS(2224),
    [anon_sym_short] = ACTIONS(2224),
    [anon_sym_LBRACK] = ACTIONS(2224),
    [anon_sym_static] = ACTIONS(2224),
    [anon_sym_register] = ACTIONS(2224),
    [anon_sym_inline] = ACTIONS(2224),
    [anon_sym___inline] = ACTIONS(2224),
    [anon_sym___inline__] = ACTIONS(2224),
    [anon_sym___forceinline] = ACTIONS(2224),
    [anon_sym_thread_local] = ACTIONS(2224),
    [anon_sym___thread] = ACTIONS(2224),
    [anon_sym_const] = ACTIONS(2224),
    [anon_sym_constexpr] = ACTIONS(2224),
    [anon_sym_volatile] = ACTIONS(2224),
    [anon_sym_restrict] = ACTIONS(2224),
    [anon_sym___restrict__] = ACTIONS(2224),
    [anon_sym__Atomic] = ACTIONS(2224),
    [anon_sym__Noreturn] = ACTIONS(2224),
    [anon_sym_noreturn] = ACTIONS(2224),
    [anon_sym_mutable] = ACTIONS(2224),
    [anon_sym_constinit] = ACTIONS(2224),
    [anon_sym_consteval] = ACTIONS(2224),
    [anon_sym_alignas] = ACTIONS(2224),
    [anon_sym__Alignas] = ACTIONS(2224),
    [sym_primitive_type] = ACTIONS(2224),
    [anon_sym_enum] = ACTIONS(2224),
    [anon_sym_class] = ACTIONS(2224),
    [anon_sym_struct] = ACTIONS(2224),
    [anon_sym_union] = ACTIONS(2224),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_else] = ACTIONS(2224),
    [anon_sym_switch] = ACTIONS(2224),
    [anon_sym_case] = ACTIONS(2224),
    [anon_sym_default] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(2224),
    [anon_sym_do] = ACTIONS(2224),
    [anon_sym_for] = ACTIONS(2224),
    [anon_sym_return] = ACTIONS(2224),
    [anon_sym_break] = ACTIONS(2224),
    [anon_sym_continue] = ACTIONS(2224),
    [anon_sym_goto] = ACTIONS(2224),
    [anon_sym___try] = ACTIONS(2224),
    [anon_sym___leave] = ACTIONS(2224),
    [anon_sym_not] = ACTIONS(2224),
    [anon_sym_compl] = ACTIONS(2224),
    [anon_sym_DASH_DASH] = ACTIONS(2226),
    [anon_sym_PLUS_PLUS] = ACTIONS(2226),
    [anon_sym_sizeof] = ACTIONS(2224),
    [anon_sym___alignof__] = ACTIONS(2224),
    [anon_sym___alignof] = ACTIONS(2224),
    [anon_sym__alignof] = ACTIONS(2224),
    [anon_sym_alignof] = ACTIONS(2224),
    [anon_sym__Alignof] = ACTIONS(2224),
    [anon_sym_offsetof] = ACTIONS(2224),
    [anon_sym__Generic] = ACTIONS(2224),
    [anon_sym_asm] = ACTIONS(2224),
    [anon_sym___asm__] = ACTIONS(2224),
    [sym_number_literal] = ACTIONS(2226),
    [anon_sym_L_SQUOTE] = ACTIONS(2226),
    [anon_sym_u_SQUOTE] = ACTIONS(2226),
    [anon_sym_U_SQUOTE] = ACTIONS(2226),
    [anon_sym_u8_SQUOTE] = ACTIONS(2226),
    [anon_sym_SQUOTE] = ACTIONS(2226),
    [anon_sym_L_DQUOTE] = ACTIONS(2226),
    [anon_sym_u_DQUOTE] = ACTIONS(2226),
    [anon_sym_U_DQUOTE] = ACTIONS(2226),
    [anon_sym_u8_DQUOTE] = ACTIONS(2226),
    [anon_sym_DQUOTE] = ACTIONS(2226),
    [sym_true] = ACTIONS(2224),
    [sym_false] = ACTIONS(2224),
    [anon_sym_NULL] = ACTIONS(2224),
    [anon_sym_nullptr] = ACTIONS(2224),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2224),
    [anon_sym_decltype] = ACTIONS(2224),
    [sym_virtual] = ACTIONS(2224),
    [anon_sym_explicit] = ACTIONS(2224),
    [anon_sym_typename] = ACTIONS(2224),
    [anon_sym_template] = ACTIONS(2224),
    [anon_sym_operator] = ACTIONS(2224),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_delete] = ACTIONS(2224),
    [anon_sym_throw] = ACTIONS(2224),
    [anon_sym_namespace] = ACTIONS(2224),
    [anon_sym_using] = ACTIONS(2224),
    [anon_sym_static_assert] = ACTIONS(2224),
    [anon_sym_concept] = ACTIONS(2224),
    [anon_sym_co_return] = ACTIONS(2224),
    [anon_sym_co_yield] = ACTIONS(2224),
    [anon_sym_R_DQUOTE] = ACTIONS(2226),
    [anon_sym_LR_DQUOTE] = ACTIONS(2226),
    [anon_sym_uR_DQUOTE] = ACTIONS(2226),
    [anon_sym_UR_DQUOTE] = ACTIONS(2226),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2226),
    [anon_sym_co_await] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(2224),
    [anon_sym_requires] = ACTIONS(2224),
    [sym_this] = ACTIONS(2224),
    [anon_sym_discard] = ACTIONS(2224),
    [anon_sym_precise] = ACTIONS(2224),
    [anon_sym_shared] = ACTIONS(2224),
    [anon_sym_groupshared] = ACTIONS(2224),
    [anon_sym_uniform] = ACTIONS(2224),
    [anon_sym_row_major] = ACTIONS(2224),
    [anon_sym_column_major] = ACTIONS(2224),
    [anon_sym_globallycoherent] = ACTIONS(2224),
    [anon_sym_centroid] = ACTIONS(2224),
    [anon_sym_noperspective] = ACTIONS(2224),
    [anon_sym_nointerpolation] = ACTIONS(2224),
    [anon_sym_sample] = ACTIONS(2224),
    [anon_sym_linear] = ACTIONS(2224),
    [anon_sym_snorm] = ACTIONS(2224),
    [anon_sym_unorm] = ACTIONS(2224),
    [anon_sym_point] = ACTIONS(2224),
    [anon_sym_line] = ACTIONS(2224),
    [anon_sym_triangleadj] = ACTIONS(2224),
    [anon_sym_lineadj] = ACTIONS(2224),
    [anon_sym_triangle] = ACTIONS(2224),
    [anon_sym_cbuffer] = ACTIONS(2224),
  },
  [440] = {
    [sym_identifier] = ACTIONS(2216),
    [aux_sym_preproc_include_token1] = ACTIONS(2216),
    [aux_sym_preproc_def_token1] = ACTIONS(2216),
    [aux_sym_preproc_if_token1] = ACTIONS(2216),
    [aux_sym_preproc_if_token2] = ACTIONS(2216),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2216),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2216),
    [sym_preproc_directive] = ACTIONS(2216),
    [anon_sym_LPAREN2] = ACTIONS(2218),
    [anon_sym_BANG] = ACTIONS(2218),
    [anon_sym_TILDE] = ACTIONS(2218),
    [anon_sym_DASH] = ACTIONS(2216),
    [anon_sym_PLUS] = ACTIONS(2216),
    [anon_sym_STAR] = ACTIONS(2218),
    [anon_sym_AMP_AMP] = ACTIONS(2218),
    [anon_sym_AMP] = ACTIONS(2216),
    [anon_sym_SEMI] = ACTIONS(2218),
    [anon_sym___extension__] = ACTIONS(2216),
    [anon_sym_typedef] = ACTIONS(2216),
    [anon_sym_in] = ACTIONS(2216),
    [anon_sym_out] = ACTIONS(2216),
    [anon_sym_inout] = ACTIONS(2216),
    [anon_sym_extern] = ACTIONS(2216),
    [anon_sym___attribute__] = ACTIONS(2216),
    [anon_sym_COLON_COLON] = ACTIONS(2218),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2218),
    [anon_sym___declspec] = ACTIONS(2216),
    [anon_sym___based] = ACTIONS(2216),
    [anon_sym___cdecl] = ACTIONS(2216),
    [anon_sym___clrcall] = ACTIONS(2216),
    [anon_sym___stdcall] = ACTIONS(2216),
    [anon_sym___fastcall] = ACTIONS(2216),
    [anon_sym___thiscall] = ACTIONS(2216),
    [anon_sym___vectorcall] = ACTIONS(2216),
    [anon_sym_LBRACE] = ACTIONS(2218),
    [anon_sym_signed] = ACTIONS(2216),
    [anon_sym_unsigned] = ACTIONS(2216),
    [anon_sym_long] = ACTIONS(2216),
    [anon_sym_short] = ACTIONS(2216),
    [anon_sym_LBRACK] = ACTIONS(2216),
    [anon_sym_static] = ACTIONS(2216),
    [anon_sym_register] = ACTIONS(2216),
    [anon_sym_inline] = ACTIONS(2216),
    [anon_sym___inline] = ACTIONS(2216),
    [anon_sym___inline__] = ACTIONS(2216),
    [anon_sym___forceinline] = ACTIONS(2216),
    [anon_sym_thread_local] = ACTIONS(2216),
    [anon_sym___thread] = ACTIONS(2216),
    [anon_sym_const] = ACTIONS(2216),
    [anon_sym_constexpr] = ACTIONS(2216),
    [anon_sym_volatile] = ACTIONS(2216),
    [anon_sym_restrict] = ACTIONS(2216),
    [anon_sym___restrict__] = ACTIONS(2216),
    [anon_sym__Atomic] = ACTIONS(2216),
    [anon_sym__Noreturn] = ACTIONS(2216),
    [anon_sym_noreturn] = ACTIONS(2216),
    [anon_sym_mutable] = ACTIONS(2216),
    [anon_sym_constinit] = ACTIONS(2216),
    [anon_sym_consteval] = ACTIONS(2216),
    [anon_sym_alignas] = ACTIONS(2216),
    [anon_sym__Alignas] = ACTIONS(2216),
    [sym_primitive_type] = ACTIONS(2216),
    [anon_sym_enum] = ACTIONS(2216),
    [anon_sym_class] = ACTIONS(2216),
    [anon_sym_struct] = ACTIONS(2216),
    [anon_sym_union] = ACTIONS(2216),
    [anon_sym_if] = ACTIONS(2216),
    [anon_sym_else] = ACTIONS(2216),
    [anon_sym_switch] = ACTIONS(2216),
    [anon_sym_case] = ACTIONS(2216),
    [anon_sym_default] = ACTIONS(2216),
    [anon_sym_while] = ACTIONS(2216),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_for] = ACTIONS(2216),
    [anon_sym_return] = ACTIONS(2216),
    [anon_sym_break] = ACTIONS(2216),
    [anon_sym_continue] = ACTIONS(2216),
    [anon_sym_goto] = ACTIONS(2216),
    [anon_sym___try] = ACTIONS(2216),
    [anon_sym___leave] = ACTIONS(2216),
    [anon_sym_not] = ACTIONS(2216),
    [anon_sym_compl] = ACTIONS(2216),
    [anon_sym_DASH_DASH] = ACTIONS(2218),
    [anon_sym_PLUS_PLUS] = ACTIONS(2218),
    [anon_sym_sizeof] = ACTIONS(2216),
    [anon_sym___alignof__] = ACTIONS(2216),
    [anon_sym___alignof] = ACTIONS(2216),
    [anon_sym__alignof] = ACTIONS(2216),
    [anon_sym_alignof] = ACTIONS(2216),
    [anon_sym__Alignof] = ACTIONS(2216),
    [anon_sym_offsetof] = ACTIONS(2216),
    [anon_sym__Generic] = ACTIONS(2216),
    [anon_sym_asm] = ACTIONS(2216),
    [anon_sym___asm__] = ACTIONS(2216),
    [sym_number_literal] = ACTIONS(2218),
    [anon_sym_L_SQUOTE] = ACTIONS(2218),
    [anon_sym_u_SQUOTE] = ACTIONS(2218),
    [anon_sym_U_SQUOTE] = ACTIONS(2218),
    [anon_sym_u8_SQUOTE] = ACTIONS(2218),
    [anon_sym_SQUOTE] = ACTIONS(2218),
    [anon_sym_L_DQUOTE] = ACTIONS(2218),
    [anon_sym_u_DQUOTE] = ACTIONS(2218),
    [anon_sym_U_DQUOTE] = ACTIONS(2218),
    [anon_sym_u8_DQUOTE] = ACTIONS(2218),
    [anon_sym_DQUOTE] = ACTIONS(2218),
    [sym_true] = ACTIONS(2216),
    [sym_false] = ACTIONS(2216),
    [anon_sym_NULL] = ACTIONS(2216),
    [anon_sym_nullptr] = ACTIONS(2216),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2216),
    [anon_sym_decltype] = ACTIONS(2216),
    [sym_virtual] = ACTIONS(2216),
    [anon_sym_explicit] = ACTIONS(2216),
    [anon_sym_typename] = ACTIONS(2216),
    [anon_sym_template] = ACTIONS(2216),
    [anon_sym_operator] = ACTIONS(2216),
    [anon_sym_try] = ACTIONS(2216),
    [anon_sym_delete] = ACTIONS(2216),
    [anon_sym_throw] = ACTIONS(2216),
    [anon_sym_namespace] = ACTIONS(2216),
    [anon_sym_using] = ACTIONS(2216),
    [anon_sym_static_assert] = ACTIONS(2216),
    [anon_sym_concept] = ACTIONS(2216),
    [anon_sym_co_return] = ACTIONS(2216),
    [anon_sym_co_yield] = ACTIONS(2216),
    [anon_sym_R_DQUOTE] = ACTIONS(2218),
    [anon_sym_LR_DQUOTE] = ACTIONS(2218),
    [anon_sym_uR_DQUOTE] = ACTIONS(2218),
    [anon_sym_UR_DQUOTE] = ACTIONS(2218),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2218),
    [anon_sym_co_await] = ACTIONS(2216),
    [anon_sym_new] = ACTIONS(2216),
    [anon_sym_requires] = ACTIONS(2216),
    [sym_this] = ACTIONS(2216),
    [anon_sym_discard] = ACTIONS(2216),
    [anon_sym_precise] = ACTIONS(2216),
    [anon_sym_shared] = ACTIONS(2216),
    [anon_sym_groupshared] = ACTIONS(2216),
    [anon_sym_uniform] = ACTIONS(2216),
    [anon_sym_row_major] = ACTIONS(2216),
    [anon_sym_column_major] = ACTIONS(2216),
    [anon_sym_globallycoherent] = ACTIONS(2216),
    [anon_sym_centroid] = ACTIONS(2216),
    [anon_sym_noperspective] = ACTIONS(2216),
    [anon_sym_nointerpolation] = ACTIONS(2216),
    [anon_sym_sample] = ACTIONS(2216),
    [anon_sym_linear] = ACTIONS(2216),
    [anon_sym_snorm] = ACTIONS(2216),
    [anon_sym_unorm] = ACTIONS(2216),
    [anon_sym_point] = ACTIONS(2216),
    [anon_sym_line] = ACTIONS(2216),
    [anon_sym_triangleadj] = ACTIONS(2216),
    [anon_sym_lineadj] = ACTIONS(2216),
    [anon_sym_triangle] = ACTIONS(2216),
    [anon_sym_cbuffer] = ACTIONS(2216),
  },
  [441] = {
    [sym_identifier] = ACTIONS(2198),
    [aux_sym_preproc_include_token1] = ACTIONS(2198),
    [aux_sym_preproc_def_token1] = ACTIONS(2198),
    [aux_sym_preproc_if_token1] = ACTIONS(2198),
    [aux_sym_preproc_if_token2] = ACTIONS(2198),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2198),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2198),
    [sym_preproc_directive] = ACTIONS(2198),
    [anon_sym_LPAREN2] = ACTIONS(2200),
    [anon_sym_BANG] = ACTIONS(2200),
    [anon_sym_TILDE] = ACTIONS(2200),
    [anon_sym_DASH] = ACTIONS(2198),
    [anon_sym_PLUS] = ACTIONS(2198),
    [anon_sym_STAR] = ACTIONS(2200),
    [anon_sym_AMP_AMP] = ACTIONS(2200),
    [anon_sym_AMP] = ACTIONS(2198),
    [anon_sym_SEMI] = ACTIONS(2200),
    [anon_sym___extension__] = ACTIONS(2198),
    [anon_sym_typedef] = ACTIONS(2198),
    [anon_sym_in] = ACTIONS(2198),
    [anon_sym_out] = ACTIONS(2198),
    [anon_sym_inout] = ACTIONS(2198),
    [anon_sym_extern] = ACTIONS(2198),
    [anon_sym___attribute__] = ACTIONS(2198),
    [anon_sym_COLON_COLON] = ACTIONS(2200),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2200),
    [anon_sym___declspec] = ACTIONS(2198),
    [anon_sym___based] = ACTIONS(2198),
    [anon_sym___cdecl] = ACTIONS(2198),
    [anon_sym___clrcall] = ACTIONS(2198),
    [anon_sym___stdcall] = ACTIONS(2198),
    [anon_sym___fastcall] = ACTIONS(2198),
    [anon_sym___thiscall] = ACTIONS(2198),
    [anon_sym___vectorcall] = ACTIONS(2198),
    [anon_sym_LBRACE] = ACTIONS(2200),
    [anon_sym_signed] = ACTIONS(2198),
    [anon_sym_unsigned] = ACTIONS(2198),
    [anon_sym_long] = ACTIONS(2198),
    [anon_sym_short] = ACTIONS(2198),
    [anon_sym_LBRACK] = ACTIONS(2198),
    [anon_sym_static] = ACTIONS(2198),
    [anon_sym_register] = ACTIONS(2198),
    [anon_sym_inline] = ACTIONS(2198),
    [anon_sym___inline] = ACTIONS(2198),
    [anon_sym___inline__] = ACTIONS(2198),
    [anon_sym___forceinline] = ACTIONS(2198),
    [anon_sym_thread_local] = ACTIONS(2198),
    [anon_sym___thread] = ACTIONS(2198),
    [anon_sym_const] = ACTIONS(2198),
    [anon_sym_constexpr] = ACTIONS(2198),
    [anon_sym_volatile] = ACTIONS(2198),
    [anon_sym_restrict] = ACTIONS(2198),
    [anon_sym___restrict__] = ACTIONS(2198),
    [anon_sym__Atomic] = ACTIONS(2198),
    [anon_sym__Noreturn] = ACTIONS(2198),
    [anon_sym_noreturn] = ACTIONS(2198),
    [anon_sym_mutable] = ACTIONS(2198),
    [anon_sym_constinit] = ACTIONS(2198),
    [anon_sym_consteval] = ACTIONS(2198),
    [anon_sym_alignas] = ACTIONS(2198),
    [anon_sym__Alignas] = ACTIONS(2198),
    [sym_primitive_type] = ACTIONS(2198),
    [anon_sym_enum] = ACTIONS(2198),
    [anon_sym_class] = ACTIONS(2198),
    [anon_sym_struct] = ACTIONS(2198),
    [anon_sym_union] = ACTIONS(2198),
    [anon_sym_if] = ACTIONS(2198),
    [anon_sym_else] = ACTIONS(2198),
    [anon_sym_switch] = ACTIONS(2198),
    [anon_sym_case] = ACTIONS(2198),
    [anon_sym_default] = ACTIONS(2198),
    [anon_sym_while] = ACTIONS(2198),
    [anon_sym_do] = ACTIONS(2198),
    [anon_sym_for] = ACTIONS(2198),
    [anon_sym_return] = ACTIONS(2198),
    [anon_sym_break] = ACTIONS(2198),
    [anon_sym_continue] = ACTIONS(2198),
    [anon_sym_goto] = ACTIONS(2198),
    [anon_sym___try] = ACTIONS(2198),
    [anon_sym___leave] = ACTIONS(2198),
    [anon_sym_not] = ACTIONS(2198),
    [anon_sym_compl] = ACTIONS(2198),
    [anon_sym_DASH_DASH] = ACTIONS(2200),
    [anon_sym_PLUS_PLUS] = ACTIONS(2200),
    [anon_sym_sizeof] = ACTIONS(2198),
    [anon_sym___alignof__] = ACTIONS(2198),
    [anon_sym___alignof] = ACTIONS(2198),
    [anon_sym__alignof] = ACTIONS(2198),
    [anon_sym_alignof] = ACTIONS(2198),
    [anon_sym__Alignof] = ACTIONS(2198),
    [anon_sym_offsetof] = ACTIONS(2198),
    [anon_sym__Generic] = ACTIONS(2198),
    [anon_sym_asm] = ACTIONS(2198),
    [anon_sym___asm__] = ACTIONS(2198),
    [sym_number_literal] = ACTIONS(2200),
    [anon_sym_L_SQUOTE] = ACTIONS(2200),
    [anon_sym_u_SQUOTE] = ACTIONS(2200),
    [anon_sym_U_SQUOTE] = ACTIONS(2200),
    [anon_sym_u8_SQUOTE] = ACTIONS(2200),
    [anon_sym_SQUOTE] = ACTIONS(2200),
    [anon_sym_L_DQUOTE] = ACTIONS(2200),
    [anon_sym_u_DQUOTE] = ACTIONS(2200),
    [anon_sym_U_DQUOTE] = ACTIONS(2200),
    [anon_sym_u8_DQUOTE] = ACTIONS(2200),
    [anon_sym_DQUOTE] = ACTIONS(2200),
    [sym_true] = ACTIONS(2198),
    [sym_false] = ACTIONS(2198),
    [anon_sym_NULL] = ACTIONS(2198),
    [anon_sym_nullptr] = ACTIONS(2198),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2198),
    [anon_sym_decltype] = ACTIONS(2198),
    [sym_virtual] = ACTIONS(2198),
    [anon_sym_explicit] = ACTIONS(2198),
    [anon_sym_typename] = ACTIONS(2198),
    [anon_sym_template] = ACTIONS(2198),
    [anon_sym_operator] = ACTIONS(2198),
    [anon_sym_try] = ACTIONS(2198),
    [anon_sym_delete] = ACTIONS(2198),
    [anon_sym_throw] = ACTIONS(2198),
    [anon_sym_namespace] = ACTIONS(2198),
    [anon_sym_using] = ACTIONS(2198),
    [anon_sym_static_assert] = ACTIONS(2198),
    [anon_sym_concept] = ACTIONS(2198),
    [anon_sym_co_return] = ACTIONS(2198),
    [anon_sym_co_yield] = ACTIONS(2198),
    [anon_sym_R_DQUOTE] = ACTIONS(2200),
    [anon_sym_LR_DQUOTE] = ACTIONS(2200),
    [anon_sym_uR_DQUOTE] = ACTIONS(2200),
    [anon_sym_UR_DQUOTE] = ACTIONS(2200),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2200),
    [anon_sym_co_await] = ACTIONS(2198),
    [anon_sym_new] = ACTIONS(2198),
    [anon_sym_requires] = ACTIONS(2198),
    [sym_this] = ACTIONS(2198),
    [anon_sym_discard] = ACTIONS(2198),
    [anon_sym_precise] = ACTIONS(2198),
    [anon_sym_shared] = ACTIONS(2198),
    [anon_sym_groupshared] = ACTIONS(2198),
    [anon_sym_uniform] = ACTIONS(2198),
    [anon_sym_row_major] = ACTIONS(2198),
    [anon_sym_column_major] = ACTIONS(2198),
    [anon_sym_globallycoherent] = ACTIONS(2198),
    [anon_sym_centroid] = ACTIONS(2198),
    [anon_sym_noperspective] = ACTIONS(2198),
    [anon_sym_nointerpolation] = ACTIONS(2198),
    [anon_sym_sample] = ACTIONS(2198),
    [anon_sym_linear] = ACTIONS(2198),
    [anon_sym_snorm] = ACTIONS(2198),
    [anon_sym_unorm] = ACTIONS(2198),
    [anon_sym_point] = ACTIONS(2198),
    [anon_sym_line] = ACTIONS(2198),
    [anon_sym_triangleadj] = ACTIONS(2198),
    [anon_sym_lineadj] = ACTIONS(2198),
    [anon_sym_triangle] = ACTIONS(2198),
    [anon_sym_cbuffer] = ACTIONS(2198),
  },
  [442] = {
    [ts_builtin_sym_end] = ACTIONS(2112),
    [sym_identifier] = ACTIONS(2110),
    [aux_sym_preproc_include_token1] = ACTIONS(2110),
    [aux_sym_preproc_def_token1] = ACTIONS(2110),
    [aux_sym_preproc_if_token1] = ACTIONS(2110),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2110),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2110),
    [sym_preproc_directive] = ACTIONS(2110),
    [anon_sym_LPAREN2] = ACTIONS(2112),
    [anon_sym_BANG] = ACTIONS(2112),
    [anon_sym_TILDE] = ACTIONS(2112),
    [anon_sym_DASH] = ACTIONS(2110),
    [anon_sym_PLUS] = ACTIONS(2110),
    [anon_sym_STAR] = ACTIONS(2112),
    [anon_sym_AMP_AMP] = ACTIONS(2112),
    [anon_sym_AMP] = ACTIONS(2110),
    [anon_sym_SEMI] = ACTIONS(2112),
    [anon_sym___extension__] = ACTIONS(2110),
    [anon_sym_typedef] = ACTIONS(2110),
    [anon_sym_in] = ACTIONS(2110),
    [anon_sym_out] = ACTIONS(2110),
    [anon_sym_inout] = ACTIONS(2110),
    [anon_sym_extern] = ACTIONS(2110),
    [anon_sym___attribute__] = ACTIONS(2110),
    [anon_sym_COLON_COLON] = ACTIONS(2112),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2112),
    [anon_sym___declspec] = ACTIONS(2110),
    [anon_sym___based] = ACTIONS(2110),
    [anon_sym___cdecl] = ACTIONS(2110),
    [anon_sym___clrcall] = ACTIONS(2110),
    [anon_sym___stdcall] = ACTIONS(2110),
    [anon_sym___fastcall] = ACTIONS(2110),
    [anon_sym___thiscall] = ACTIONS(2110),
    [anon_sym___vectorcall] = ACTIONS(2110),
    [anon_sym_LBRACE] = ACTIONS(2112),
    [anon_sym_signed] = ACTIONS(2110),
    [anon_sym_unsigned] = ACTIONS(2110),
    [anon_sym_long] = ACTIONS(2110),
    [anon_sym_short] = ACTIONS(2110),
    [anon_sym_LBRACK] = ACTIONS(2110),
    [anon_sym_static] = ACTIONS(2110),
    [anon_sym_register] = ACTIONS(2110),
    [anon_sym_inline] = ACTIONS(2110),
    [anon_sym___inline] = ACTIONS(2110),
    [anon_sym___inline__] = ACTIONS(2110),
    [anon_sym___forceinline] = ACTIONS(2110),
    [anon_sym_thread_local] = ACTIONS(2110),
    [anon_sym___thread] = ACTIONS(2110),
    [anon_sym_const] = ACTIONS(2110),
    [anon_sym_constexpr] = ACTIONS(2110),
    [anon_sym_volatile] = ACTIONS(2110),
    [anon_sym_restrict] = ACTIONS(2110),
    [anon_sym___restrict__] = ACTIONS(2110),
    [anon_sym__Atomic] = ACTIONS(2110),
    [anon_sym__Noreturn] = ACTIONS(2110),
    [anon_sym_noreturn] = ACTIONS(2110),
    [anon_sym_mutable] = ACTIONS(2110),
    [anon_sym_constinit] = ACTIONS(2110),
    [anon_sym_consteval] = ACTIONS(2110),
    [anon_sym_alignas] = ACTIONS(2110),
    [anon_sym__Alignas] = ACTIONS(2110),
    [sym_primitive_type] = ACTIONS(2110),
    [anon_sym_enum] = ACTIONS(2110),
    [anon_sym_class] = ACTIONS(2110),
    [anon_sym_struct] = ACTIONS(2110),
    [anon_sym_union] = ACTIONS(2110),
    [anon_sym_if] = ACTIONS(2110),
    [anon_sym_else] = ACTIONS(2110),
    [anon_sym_switch] = ACTIONS(2110),
    [anon_sym_case] = ACTIONS(2110),
    [anon_sym_default] = ACTIONS(2110),
    [anon_sym_while] = ACTIONS(2110),
    [anon_sym_do] = ACTIONS(2110),
    [anon_sym_for] = ACTIONS(2110),
    [anon_sym_return] = ACTIONS(2110),
    [anon_sym_break] = ACTIONS(2110),
    [anon_sym_continue] = ACTIONS(2110),
    [anon_sym_goto] = ACTIONS(2110),
    [anon_sym___try] = ACTIONS(2110),
    [anon_sym___leave] = ACTIONS(2110),
    [anon_sym_not] = ACTIONS(2110),
    [anon_sym_compl] = ACTIONS(2110),
    [anon_sym_DASH_DASH] = ACTIONS(2112),
    [anon_sym_PLUS_PLUS] = ACTIONS(2112),
    [anon_sym_sizeof] = ACTIONS(2110),
    [anon_sym___alignof__] = ACTIONS(2110),
    [anon_sym___alignof] = ACTIONS(2110),
    [anon_sym__alignof] = ACTIONS(2110),
    [anon_sym_alignof] = ACTIONS(2110),
    [anon_sym__Alignof] = ACTIONS(2110),
    [anon_sym_offsetof] = ACTIONS(2110),
    [anon_sym__Generic] = ACTIONS(2110),
    [anon_sym_asm] = ACTIONS(2110),
    [anon_sym___asm__] = ACTIONS(2110),
    [sym_number_literal] = ACTIONS(2112),
    [anon_sym_L_SQUOTE] = ACTIONS(2112),
    [anon_sym_u_SQUOTE] = ACTIONS(2112),
    [anon_sym_U_SQUOTE] = ACTIONS(2112),
    [anon_sym_u8_SQUOTE] = ACTIONS(2112),
    [anon_sym_SQUOTE] = ACTIONS(2112),
    [anon_sym_L_DQUOTE] = ACTIONS(2112),
    [anon_sym_u_DQUOTE] = ACTIONS(2112),
    [anon_sym_U_DQUOTE] = ACTIONS(2112),
    [anon_sym_u8_DQUOTE] = ACTIONS(2112),
    [anon_sym_DQUOTE] = ACTIONS(2112),
    [sym_true] = ACTIONS(2110),
    [sym_false] = ACTIONS(2110),
    [anon_sym_NULL] = ACTIONS(2110),
    [anon_sym_nullptr] = ACTIONS(2110),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2110),
    [anon_sym_decltype] = ACTIONS(2110),
    [sym_virtual] = ACTIONS(2110),
    [anon_sym_explicit] = ACTIONS(2110),
    [anon_sym_typename] = ACTIONS(2110),
    [anon_sym_template] = ACTIONS(2110),
    [anon_sym_operator] = ACTIONS(2110),
    [anon_sym_try] = ACTIONS(2110),
    [anon_sym_delete] = ACTIONS(2110),
    [anon_sym_throw] = ACTIONS(2110),
    [anon_sym_namespace] = ACTIONS(2110),
    [anon_sym_using] = ACTIONS(2110),
    [anon_sym_static_assert] = ACTIONS(2110),
    [anon_sym_concept] = ACTIONS(2110),
    [anon_sym_co_return] = ACTIONS(2110),
    [anon_sym_co_yield] = ACTIONS(2110),
    [anon_sym_R_DQUOTE] = ACTIONS(2112),
    [anon_sym_LR_DQUOTE] = ACTIONS(2112),
    [anon_sym_uR_DQUOTE] = ACTIONS(2112),
    [anon_sym_UR_DQUOTE] = ACTIONS(2112),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2112),
    [anon_sym_co_await] = ACTIONS(2110),
    [anon_sym_new] = ACTIONS(2110),
    [anon_sym_requires] = ACTIONS(2110),
    [sym_this] = ACTIONS(2110),
    [anon_sym_discard] = ACTIONS(2110),
    [anon_sym_precise] = ACTIONS(2110),
    [anon_sym_shared] = ACTIONS(2110),
    [anon_sym_groupshared] = ACTIONS(2110),
    [anon_sym_uniform] = ACTIONS(2110),
    [anon_sym_row_major] = ACTIONS(2110),
    [anon_sym_column_major] = ACTIONS(2110),
    [anon_sym_globallycoherent] = ACTIONS(2110),
    [anon_sym_centroid] = ACTIONS(2110),
    [anon_sym_noperspective] = ACTIONS(2110),
    [anon_sym_nointerpolation] = ACTIONS(2110),
    [anon_sym_sample] = ACTIONS(2110),
    [anon_sym_linear] = ACTIONS(2110),
    [anon_sym_snorm] = ACTIONS(2110),
    [anon_sym_unorm] = ACTIONS(2110),
    [anon_sym_point] = ACTIONS(2110),
    [anon_sym_line] = ACTIONS(2110),
    [anon_sym_triangleadj] = ACTIONS(2110),
    [anon_sym_lineadj] = ACTIONS(2110),
    [anon_sym_triangle] = ACTIONS(2110),
    [anon_sym_cbuffer] = ACTIONS(2110),
  },
  [443] = {
    [sym_identifier] = ACTIONS(2194),
    [aux_sym_preproc_include_token1] = ACTIONS(2194),
    [aux_sym_preproc_def_token1] = ACTIONS(2194),
    [aux_sym_preproc_if_token1] = ACTIONS(2194),
    [aux_sym_preproc_if_token2] = ACTIONS(2194),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2194),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2194),
    [sym_preproc_directive] = ACTIONS(2194),
    [anon_sym_LPAREN2] = ACTIONS(2196),
    [anon_sym_BANG] = ACTIONS(2196),
    [anon_sym_TILDE] = ACTIONS(2196),
    [anon_sym_DASH] = ACTIONS(2194),
    [anon_sym_PLUS] = ACTIONS(2194),
    [anon_sym_STAR] = ACTIONS(2196),
    [anon_sym_AMP_AMP] = ACTIONS(2196),
    [anon_sym_AMP] = ACTIONS(2194),
    [anon_sym_SEMI] = ACTIONS(2196),
    [anon_sym___extension__] = ACTIONS(2194),
    [anon_sym_typedef] = ACTIONS(2194),
    [anon_sym_in] = ACTIONS(2194),
    [anon_sym_out] = ACTIONS(2194),
    [anon_sym_inout] = ACTIONS(2194),
    [anon_sym_extern] = ACTIONS(2194),
    [anon_sym___attribute__] = ACTIONS(2194),
    [anon_sym_COLON_COLON] = ACTIONS(2196),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2196),
    [anon_sym___declspec] = ACTIONS(2194),
    [anon_sym___based] = ACTIONS(2194),
    [anon_sym___cdecl] = ACTIONS(2194),
    [anon_sym___clrcall] = ACTIONS(2194),
    [anon_sym___stdcall] = ACTIONS(2194),
    [anon_sym___fastcall] = ACTIONS(2194),
    [anon_sym___thiscall] = ACTIONS(2194),
    [anon_sym___vectorcall] = ACTIONS(2194),
    [anon_sym_LBRACE] = ACTIONS(2196),
    [anon_sym_signed] = ACTIONS(2194),
    [anon_sym_unsigned] = ACTIONS(2194),
    [anon_sym_long] = ACTIONS(2194),
    [anon_sym_short] = ACTIONS(2194),
    [anon_sym_LBRACK] = ACTIONS(2194),
    [anon_sym_static] = ACTIONS(2194),
    [anon_sym_register] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(2194),
    [anon_sym___inline] = ACTIONS(2194),
    [anon_sym___inline__] = ACTIONS(2194),
    [anon_sym___forceinline] = ACTIONS(2194),
    [anon_sym_thread_local] = ACTIONS(2194),
    [anon_sym___thread] = ACTIONS(2194),
    [anon_sym_const] = ACTIONS(2194),
    [anon_sym_constexpr] = ACTIONS(2194),
    [anon_sym_volatile] = ACTIONS(2194),
    [anon_sym_restrict] = ACTIONS(2194),
    [anon_sym___restrict__] = ACTIONS(2194),
    [anon_sym__Atomic] = ACTIONS(2194),
    [anon_sym__Noreturn] = ACTIONS(2194),
    [anon_sym_noreturn] = ACTIONS(2194),
    [anon_sym_mutable] = ACTIONS(2194),
    [anon_sym_constinit] = ACTIONS(2194),
    [anon_sym_consteval] = ACTIONS(2194),
    [anon_sym_alignas] = ACTIONS(2194),
    [anon_sym__Alignas] = ACTIONS(2194),
    [sym_primitive_type] = ACTIONS(2194),
    [anon_sym_enum] = ACTIONS(2194),
    [anon_sym_class] = ACTIONS(2194),
    [anon_sym_struct] = ACTIONS(2194),
    [anon_sym_union] = ACTIONS(2194),
    [anon_sym_if] = ACTIONS(2194),
    [anon_sym_else] = ACTIONS(2194),
    [anon_sym_switch] = ACTIONS(2194),
    [anon_sym_case] = ACTIONS(2194),
    [anon_sym_default] = ACTIONS(2194),
    [anon_sym_while] = ACTIONS(2194),
    [anon_sym_do] = ACTIONS(2194),
    [anon_sym_for] = ACTIONS(2194),
    [anon_sym_return] = ACTIONS(2194),
    [anon_sym_break] = ACTIONS(2194),
    [anon_sym_continue] = ACTIONS(2194),
    [anon_sym_goto] = ACTIONS(2194),
    [anon_sym___try] = ACTIONS(2194),
    [anon_sym___leave] = ACTIONS(2194),
    [anon_sym_not] = ACTIONS(2194),
    [anon_sym_compl] = ACTIONS(2194),
    [anon_sym_DASH_DASH] = ACTIONS(2196),
    [anon_sym_PLUS_PLUS] = ACTIONS(2196),
    [anon_sym_sizeof] = ACTIONS(2194),
    [anon_sym___alignof__] = ACTIONS(2194),
    [anon_sym___alignof] = ACTIONS(2194),
    [anon_sym__alignof] = ACTIONS(2194),
    [anon_sym_alignof] = ACTIONS(2194),
    [anon_sym__Alignof] = ACTIONS(2194),
    [anon_sym_offsetof] = ACTIONS(2194),
    [anon_sym__Generic] = ACTIONS(2194),
    [anon_sym_asm] = ACTIONS(2194),
    [anon_sym___asm__] = ACTIONS(2194),
    [sym_number_literal] = ACTIONS(2196),
    [anon_sym_L_SQUOTE] = ACTIONS(2196),
    [anon_sym_u_SQUOTE] = ACTIONS(2196),
    [anon_sym_U_SQUOTE] = ACTIONS(2196),
    [anon_sym_u8_SQUOTE] = ACTIONS(2196),
    [anon_sym_SQUOTE] = ACTIONS(2196),
    [anon_sym_L_DQUOTE] = ACTIONS(2196),
    [anon_sym_u_DQUOTE] = ACTIONS(2196),
    [anon_sym_U_DQUOTE] = ACTIONS(2196),
    [anon_sym_u8_DQUOTE] = ACTIONS(2196),
    [anon_sym_DQUOTE] = ACTIONS(2196),
    [sym_true] = ACTIONS(2194),
    [sym_false] = ACTIONS(2194),
    [anon_sym_NULL] = ACTIONS(2194),
    [anon_sym_nullptr] = ACTIONS(2194),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2194),
    [anon_sym_decltype] = ACTIONS(2194),
    [sym_virtual] = ACTIONS(2194),
    [anon_sym_explicit] = ACTIONS(2194),
    [anon_sym_typename] = ACTIONS(2194),
    [anon_sym_template] = ACTIONS(2194),
    [anon_sym_operator] = ACTIONS(2194),
    [anon_sym_try] = ACTIONS(2194),
    [anon_sym_delete] = ACTIONS(2194),
    [anon_sym_throw] = ACTIONS(2194),
    [anon_sym_namespace] = ACTIONS(2194),
    [anon_sym_using] = ACTIONS(2194),
    [anon_sym_static_assert] = ACTIONS(2194),
    [anon_sym_concept] = ACTIONS(2194),
    [anon_sym_co_return] = ACTIONS(2194),
    [anon_sym_co_yield] = ACTIONS(2194),
    [anon_sym_R_DQUOTE] = ACTIONS(2196),
    [anon_sym_LR_DQUOTE] = ACTIONS(2196),
    [anon_sym_uR_DQUOTE] = ACTIONS(2196),
    [anon_sym_UR_DQUOTE] = ACTIONS(2196),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2196),
    [anon_sym_co_await] = ACTIONS(2194),
    [anon_sym_new] = ACTIONS(2194),
    [anon_sym_requires] = ACTIONS(2194),
    [sym_this] = ACTIONS(2194),
    [anon_sym_discard] = ACTIONS(2194),
    [anon_sym_precise] = ACTIONS(2194),
    [anon_sym_shared] = ACTIONS(2194),
    [anon_sym_groupshared] = ACTIONS(2194),
    [anon_sym_uniform] = ACTIONS(2194),
    [anon_sym_row_major] = ACTIONS(2194),
    [anon_sym_column_major] = ACTIONS(2194),
    [anon_sym_globallycoherent] = ACTIONS(2194),
    [anon_sym_centroid] = ACTIONS(2194),
    [anon_sym_noperspective] = ACTIONS(2194),
    [anon_sym_nointerpolation] = ACTIONS(2194),
    [anon_sym_sample] = ACTIONS(2194),
    [anon_sym_linear] = ACTIONS(2194),
    [anon_sym_snorm] = ACTIONS(2194),
    [anon_sym_unorm] = ACTIONS(2194),
    [anon_sym_point] = ACTIONS(2194),
    [anon_sym_line] = ACTIONS(2194),
    [anon_sym_triangleadj] = ACTIONS(2194),
    [anon_sym_lineadj] = ACTIONS(2194),
    [anon_sym_triangle] = ACTIONS(2194),
    [anon_sym_cbuffer] = ACTIONS(2194),
  },
  [444] = {
    [ts_builtin_sym_end] = ACTIONS(2144),
    [sym_identifier] = ACTIONS(2142),
    [aux_sym_preproc_include_token1] = ACTIONS(2142),
    [aux_sym_preproc_def_token1] = ACTIONS(2142),
    [aux_sym_preproc_if_token1] = ACTIONS(2142),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2142),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2142),
    [sym_preproc_directive] = ACTIONS(2142),
    [anon_sym_LPAREN2] = ACTIONS(2144),
    [anon_sym_BANG] = ACTIONS(2144),
    [anon_sym_TILDE] = ACTIONS(2144),
    [anon_sym_DASH] = ACTIONS(2142),
    [anon_sym_PLUS] = ACTIONS(2142),
    [anon_sym_STAR] = ACTIONS(2144),
    [anon_sym_AMP_AMP] = ACTIONS(2144),
    [anon_sym_AMP] = ACTIONS(2142),
    [anon_sym_SEMI] = ACTIONS(2144),
    [anon_sym___extension__] = ACTIONS(2142),
    [anon_sym_typedef] = ACTIONS(2142),
    [anon_sym_in] = ACTIONS(2142),
    [anon_sym_out] = ACTIONS(2142),
    [anon_sym_inout] = ACTIONS(2142),
    [anon_sym_extern] = ACTIONS(2142),
    [anon_sym___attribute__] = ACTIONS(2142),
    [anon_sym_COLON_COLON] = ACTIONS(2144),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2144),
    [anon_sym___declspec] = ACTIONS(2142),
    [anon_sym___based] = ACTIONS(2142),
    [anon_sym___cdecl] = ACTIONS(2142),
    [anon_sym___clrcall] = ACTIONS(2142),
    [anon_sym___stdcall] = ACTIONS(2142),
    [anon_sym___fastcall] = ACTIONS(2142),
    [anon_sym___thiscall] = ACTIONS(2142),
    [anon_sym___vectorcall] = ACTIONS(2142),
    [anon_sym_LBRACE] = ACTIONS(2144),
    [anon_sym_signed] = ACTIONS(2142),
    [anon_sym_unsigned] = ACTIONS(2142),
    [anon_sym_long] = ACTIONS(2142),
    [anon_sym_short] = ACTIONS(2142),
    [anon_sym_LBRACK] = ACTIONS(2142),
    [anon_sym_static] = ACTIONS(2142),
    [anon_sym_register] = ACTIONS(2142),
    [anon_sym_inline] = ACTIONS(2142),
    [anon_sym___inline] = ACTIONS(2142),
    [anon_sym___inline__] = ACTIONS(2142),
    [anon_sym___forceinline] = ACTIONS(2142),
    [anon_sym_thread_local] = ACTIONS(2142),
    [anon_sym___thread] = ACTIONS(2142),
    [anon_sym_const] = ACTIONS(2142),
    [anon_sym_constexpr] = ACTIONS(2142),
    [anon_sym_volatile] = ACTIONS(2142),
    [anon_sym_restrict] = ACTIONS(2142),
    [anon_sym___restrict__] = ACTIONS(2142),
    [anon_sym__Atomic] = ACTIONS(2142),
    [anon_sym__Noreturn] = ACTIONS(2142),
    [anon_sym_noreturn] = ACTIONS(2142),
    [anon_sym_mutable] = ACTIONS(2142),
    [anon_sym_constinit] = ACTIONS(2142),
    [anon_sym_consteval] = ACTIONS(2142),
    [anon_sym_alignas] = ACTIONS(2142),
    [anon_sym__Alignas] = ACTIONS(2142),
    [sym_primitive_type] = ACTIONS(2142),
    [anon_sym_enum] = ACTIONS(2142),
    [anon_sym_class] = ACTIONS(2142),
    [anon_sym_struct] = ACTIONS(2142),
    [anon_sym_union] = ACTIONS(2142),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_else] = ACTIONS(2142),
    [anon_sym_switch] = ACTIONS(2142),
    [anon_sym_case] = ACTIONS(2142),
    [anon_sym_default] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2142),
    [anon_sym_do] = ACTIONS(2142),
    [anon_sym_for] = ACTIONS(2142),
    [anon_sym_return] = ACTIONS(2142),
    [anon_sym_break] = ACTIONS(2142),
    [anon_sym_continue] = ACTIONS(2142),
    [anon_sym_goto] = ACTIONS(2142),
    [anon_sym___try] = ACTIONS(2142),
    [anon_sym___leave] = ACTIONS(2142),
    [anon_sym_not] = ACTIONS(2142),
    [anon_sym_compl] = ACTIONS(2142),
    [anon_sym_DASH_DASH] = ACTIONS(2144),
    [anon_sym_PLUS_PLUS] = ACTIONS(2144),
    [anon_sym_sizeof] = ACTIONS(2142),
    [anon_sym___alignof__] = ACTIONS(2142),
    [anon_sym___alignof] = ACTIONS(2142),
    [anon_sym__alignof] = ACTIONS(2142),
    [anon_sym_alignof] = ACTIONS(2142),
    [anon_sym__Alignof] = ACTIONS(2142),
    [anon_sym_offsetof] = ACTIONS(2142),
    [anon_sym__Generic] = ACTIONS(2142),
    [anon_sym_asm] = ACTIONS(2142),
    [anon_sym___asm__] = ACTIONS(2142),
    [sym_number_literal] = ACTIONS(2144),
    [anon_sym_L_SQUOTE] = ACTIONS(2144),
    [anon_sym_u_SQUOTE] = ACTIONS(2144),
    [anon_sym_U_SQUOTE] = ACTIONS(2144),
    [anon_sym_u8_SQUOTE] = ACTIONS(2144),
    [anon_sym_SQUOTE] = ACTIONS(2144),
    [anon_sym_L_DQUOTE] = ACTIONS(2144),
    [anon_sym_u_DQUOTE] = ACTIONS(2144),
    [anon_sym_U_DQUOTE] = ACTIONS(2144),
    [anon_sym_u8_DQUOTE] = ACTIONS(2144),
    [anon_sym_DQUOTE] = ACTIONS(2144),
    [sym_true] = ACTIONS(2142),
    [sym_false] = ACTIONS(2142),
    [anon_sym_NULL] = ACTIONS(2142),
    [anon_sym_nullptr] = ACTIONS(2142),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2142),
    [anon_sym_decltype] = ACTIONS(2142),
    [sym_virtual] = ACTIONS(2142),
    [anon_sym_explicit] = ACTIONS(2142),
    [anon_sym_typename] = ACTIONS(2142),
    [anon_sym_template] = ACTIONS(2142),
    [anon_sym_operator] = ACTIONS(2142),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_delete] = ACTIONS(2142),
    [anon_sym_throw] = ACTIONS(2142),
    [anon_sym_namespace] = ACTIONS(2142),
    [anon_sym_using] = ACTIONS(2142),
    [anon_sym_static_assert] = ACTIONS(2142),
    [anon_sym_concept] = ACTIONS(2142),
    [anon_sym_co_return] = ACTIONS(2142),
    [anon_sym_co_yield] = ACTIONS(2142),
    [anon_sym_R_DQUOTE] = ACTIONS(2144),
    [anon_sym_LR_DQUOTE] = ACTIONS(2144),
    [anon_sym_uR_DQUOTE] = ACTIONS(2144),
    [anon_sym_UR_DQUOTE] = ACTIONS(2144),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2144),
    [anon_sym_co_await] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(2142),
    [anon_sym_requires] = ACTIONS(2142),
    [sym_this] = ACTIONS(2142),
    [anon_sym_discard] = ACTIONS(2142),
    [anon_sym_precise] = ACTIONS(2142),
    [anon_sym_shared] = ACTIONS(2142),
    [anon_sym_groupshared] = ACTIONS(2142),
    [anon_sym_uniform] = ACTIONS(2142),
    [anon_sym_row_major] = ACTIONS(2142),
    [anon_sym_column_major] = ACTIONS(2142),
    [anon_sym_globallycoherent] = ACTIONS(2142),
    [anon_sym_centroid] = ACTIONS(2142),
    [anon_sym_noperspective] = ACTIONS(2142),
    [anon_sym_nointerpolation] = ACTIONS(2142),
    [anon_sym_sample] = ACTIONS(2142),
    [anon_sym_linear] = ACTIONS(2142),
    [anon_sym_snorm] = ACTIONS(2142),
    [anon_sym_unorm] = ACTIONS(2142),
    [anon_sym_point] = ACTIONS(2142),
    [anon_sym_line] = ACTIONS(2142),
    [anon_sym_triangleadj] = ACTIONS(2142),
    [anon_sym_lineadj] = ACTIONS(2142),
    [anon_sym_triangle] = ACTIONS(2142),
    [anon_sym_cbuffer] = ACTIONS(2142),
  },
  [445] = {
    [ts_builtin_sym_end] = ACTIONS(2290),
    [sym_identifier] = ACTIONS(2288),
    [aux_sym_preproc_include_token1] = ACTIONS(2288),
    [aux_sym_preproc_def_token1] = ACTIONS(2288),
    [aux_sym_preproc_if_token1] = ACTIONS(2288),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2288),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2288),
    [sym_preproc_directive] = ACTIONS(2288),
    [anon_sym_LPAREN2] = ACTIONS(2290),
    [anon_sym_BANG] = ACTIONS(2290),
    [anon_sym_TILDE] = ACTIONS(2290),
    [anon_sym_DASH] = ACTIONS(2288),
    [anon_sym_PLUS] = ACTIONS(2288),
    [anon_sym_STAR] = ACTIONS(2290),
    [anon_sym_AMP_AMP] = ACTIONS(2290),
    [anon_sym_AMP] = ACTIONS(2288),
    [anon_sym_SEMI] = ACTIONS(2290),
    [anon_sym___extension__] = ACTIONS(2288),
    [anon_sym_typedef] = ACTIONS(2288),
    [anon_sym_in] = ACTIONS(2288),
    [anon_sym_out] = ACTIONS(2288),
    [anon_sym_inout] = ACTIONS(2288),
    [anon_sym_extern] = ACTIONS(2288),
    [anon_sym___attribute__] = ACTIONS(2288),
    [anon_sym_COLON_COLON] = ACTIONS(2290),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2290),
    [anon_sym___declspec] = ACTIONS(2288),
    [anon_sym___based] = ACTIONS(2288),
    [anon_sym___cdecl] = ACTIONS(2288),
    [anon_sym___clrcall] = ACTIONS(2288),
    [anon_sym___stdcall] = ACTIONS(2288),
    [anon_sym___fastcall] = ACTIONS(2288),
    [anon_sym___thiscall] = ACTIONS(2288),
    [anon_sym___vectorcall] = ACTIONS(2288),
    [anon_sym_LBRACE] = ACTIONS(2290),
    [anon_sym_signed] = ACTIONS(2288),
    [anon_sym_unsigned] = ACTIONS(2288),
    [anon_sym_long] = ACTIONS(2288),
    [anon_sym_short] = ACTIONS(2288),
    [anon_sym_LBRACK] = ACTIONS(2288),
    [anon_sym_static] = ACTIONS(2288),
    [anon_sym_register] = ACTIONS(2288),
    [anon_sym_inline] = ACTIONS(2288),
    [anon_sym___inline] = ACTIONS(2288),
    [anon_sym___inline__] = ACTIONS(2288),
    [anon_sym___forceinline] = ACTIONS(2288),
    [anon_sym_thread_local] = ACTIONS(2288),
    [anon_sym___thread] = ACTIONS(2288),
    [anon_sym_const] = ACTIONS(2288),
    [anon_sym_constexpr] = ACTIONS(2288),
    [anon_sym_volatile] = ACTIONS(2288),
    [anon_sym_restrict] = ACTIONS(2288),
    [anon_sym___restrict__] = ACTIONS(2288),
    [anon_sym__Atomic] = ACTIONS(2288),
    [anon_sym__Noreturn] = ACTIONS(2288),
    [anon_sym_noreturn] = ACTIONS(2288),
    [anon_sym_mutable] = ACTIONS(2288),
    [anon_sym_constinit] = ACTIONS(2288),
    [anon_sym_consteval] = ACTIONS(2288),
    [anon_sym_alignas] = ACTIONS(2288),
    [anon_sym__Alignas] = ACTIONS(2288),
    [sym_primitive_type] = ACTIONS(2288),
    [anon_sym_enum] = ACTIONS(2288),
    [anon_sym_class] = ACTIONS(2288),
    [anon_sym_struct] = ACTIONS(2288),
    [anon_sym_union] = ACTIONS(2288),
    [anon_sym_if] = ACTIONS(2288),
    [anon_sym_else] = ACTIONS(2288),
    [anon_sym_switch] = ACTIONS(2288),
    [anon_sym_case] = ACTIONS(2288),
    [anon_sym_default] = ACTIONS(2288),
    [anon_sym_while] = ACTIONS(2288),
    [anon_sym_do] = ACTIONS(2288),
    [anon_sym_for] = ACTIONS(2288),
    [anon_sym_return] = ACTIONS(2288),
    [anon_sym_break] = ACTIONS(2288),
    [anon_sym_continue] = ACTIONS(2288),
    [anon_sym_goto] = ACTIONS(2288),
    [anon_sym___try] = ACTIONS(2288),
    [anon_sym___leave] = ACTIONS(2288),
    [anon_sym_not] = ACTIONS(2288),
    [anon_sym_compl] = ACTIONS(2288),
    [anon_sym_DASH_DASH] = ACTIONS(2290),
    [anon_sym_PLUS_PLUS] = ACTIONS(2290),
    [anon_sym_sizeof] = ACTIONS(2288),
    [anon_sym___alignof__] = ACTIONS(2288),
    [anon_sym___alignof] = ACTIONS(2288),
    [anon_sym__alignof] = ACTIONS(2288),
    [anon_sym_alignof] = ACTIONS(2288),
    [anon_sym__Alignof] = ACTIONS(2288),
    [anon_sym_offsetof] = ACTIONS(2288),
    [anon_sym__Generic] = ACTIONS(2288),
    [anon_sym_asm] = ACTIONS(2288),
    [anon_sym___asm__] = ACTIONS(2288),
    [sym_number_literal] = ACTIONS(2290),
    [anon_sym_L_SQUOTE] = ACTIONS(2290),
    [anon_sym_u_SQUOTE] = ACTIONS(2290),
    [anon_sym_U_SQUOTE] = ACTIONS(2290),
    [anon_sym_u8_SQUOTE] = ACTIONS(2290),
    [anon_sym_SQUOTE] = ACTIONS(2290),
    [anon_sym_L_DQUOTE] = ACTIONS(2290),
    [anon_sym_u_DQUOTE] = ACTIONS(2290),
    [anon_sym_U_DQUOTE] = ACTIONS(2290),
    [anon_sym_u8_DQUOTE] = ACTIONS(2290),
    [anon_sym_DQUOTE] = ACTIONS(2290),
    [sym_true] = ACTIONS(2288),
    [sym_false] = ACTIONS(2288),
    [anon_sym_NULL] = ACTIONS(2288),
    [anon_sym_nullptr] = ACTIONS(2288),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2288),
    [anon_sym_decltype] = ACTIONS(2288),
    [sym_virtual] = ACTIONS(2288),
    [anon_sym_explicit] = ACTIONS(2288),
    [anon_sym_typename] = ACTIONS(2288),
    [anon_sym_template] = ACTIONS(2288),
    [anon_sym_operator] = ACTIONS(2288),
    [anon_sym_try] = ACTIONS(2288),
    [anon_sym_delete] = ACTIONS(2288),
    [anon_sym_throw] = ACTIONS(2288),
    [anon_sym_namespace] = ACTIONS(2288),
    [anon_sym_using] = ACTIONS(2288),
    [anon_sym_static_assert] = ACTIONS(2288),
    [anon_sym_concept] = ACTIONS(2288),
    [anon_sym_co_return] = ACTIONS(2288),
    [anon_sym_co_yield] = ACTIONS(2288),
    [anon_sym_R_DQUOTE] = ACTIONS(2290),
    [anon_sym_LR_DQUOTE] = ACTIONS(2290),
    [anon_sym_uR_DQUOTE] = ACTIONS(2290),
    [anon_sym_UR_DQUOTE] = ACTIONS(2290),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2290),
    [anon_sym_co_await] = ACTIONS(2288),
    [anon_sym_new] = ACTIONS(2288),
    [anon_sym_requires] = ACTIONS(2288),
    [sym_this] = ACTIONS(2288),
    [anon_sym_discard] = ACTIONS(2288),
    [anon_sym_precise] = ACTIONS(2288),
    [anon_sym_shared] = ACTIONS(2288),
    [anon_sym_groupshared] = ACTIONS(2288),
    [anon_sym_uniform] = ACTIONS(2288),
    [anon_sym_row_major] = ACTIONS(2288),
    [anon_sym_column_major] = ACTIONS(2288),
    [anon_sym_globallycoherent] = ACTIONS(2288),
    [anon_sym_centroid] = ACTIONS(2288),
    [anon_sym_noperspective] = ACTIONS(2288),
    [anon_sym_nointerpolation] = ACTIONS(2288),
    [anon_sym_sample] = ACTIONS(2288),
    [anon_sym_linear] = ACTIONS(2288),
    [anon_sym_snorm] = ACTIONS(2288),
    [anon_sym_unorm] = ACTIONS(2288),
    [anon_sym_point] = ACTIONS(2288),
    [anon_sym_line] = ACTIONS(2288),
    [anon_sym_triangleadj] = ACTIONS(2288),
    [anon_sym_lineadj] = ACTIONS(2288),
    [anon_sym_triangle] = ACTIONS(2288),
    [anon_sym_cbuffer] = ACTIONS(2288),
  },
  [446] = {
    [sym_identifier] = ACTIONS(2138),
    [aux_sym_preproc_include_token1] = ACTIONS(2138),
    [aux_sym_preproc_def_token1] = ACTIONS(2138),
    [aux_sym_preproc_if_token1] = ACTIONS(2138),
    [aux_sym_preproc_if_token2] = ACTIONS(2138),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2138),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2138),
    [sym_preproc_directive] = ACTIONS(2138),
    [anon_sym_LPAREN2] = ACTIONS(2140),
    [anon_sym_BANG] = ACTIONS(2140),
    [anon_sym_TILDE] = ACTIONS(2140),
    [anon_sym_DASH] = ACTIONS(2138),
    [anon_sym_PLUS] = ACTIONS(2138),
    [anon_sym_STAR] = ACTIONS(2140),
    [anon_sym_AMP_AMP] = ACTIONS(2140),
    [anon_sym_AMP] = ACTIONS(2138),
    [anon_sym_SEMI] = ACTIONS(2140),
    [anon_sym___extension__] = ACTIONS(2138),
    [anon_sym_typedef] = ACTIONS(2138),
    [anon_sym_in] = ACTIONS(2138),
    [anon_sym_out] = ACTIONS(2138),
    [anon_sym_inout] = ACTIONS(2138),
    [anon_sym_extern] = ACTIONS(2138),
    [anon_sym___attribute__] = ACTIONS(2138),
    [anon_sym_COLON_COLON] = ACTIONS(2140),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2140),
    [anon_sym___declspec] = ACTIONS(2138),
    [anon_sym___based] = ACTIONS(2138),
    [anon_sym___cdecl] = ACTIONS(2138),
    [anon_sym___clrcall] = ACTIONS(2138),
    [anon_sym___stdcall] = ACTIONS(2138),
    [anon_sym___fastcall] = ACTIONS(2138),
    [anon_sym___thiscall] = ACTIONS(2138),
    [anon_sym___vectorcall] = ACTIONS(2138),
    [anon_sym_LBRACE] = ACTIONS(2140),
    [anon_sym_signed] = ACTIONS(2138),
    [anon_sym_unsigned] = ACTIONS(2138),
    [anon_sym_long] = ACTIONS(2138),
    [anon_sym_short] = ACTIONS(2138),
    [anon_sym_LBRACK] = ACTIONS(2138),
    [anon_sym_static] = ACTIONS(2138),
    [anon_sym_register] = ACTIONS(2138),
    [anon_sym_inline] = ACTIONS(2138),
    [anon_sym___inline] = ACTIONS(2138),
    [anon_sym___inline__] = ACTIONS(2138),
    [anon_sym___forceinline] = ACTIONS(2138),
    [anon_sym_thread_local] = ACTIONS(2138),
    [anon_sym___thread] = ACTIONS(2138),
    [anon_sym_const] = ACTIONS(2138),
    [anon_sym_constexpr] = ACTIONS(2138),
    [anon_sym_volatile] = ACTIONS(2138),
    [anon_sym_restrict] = ACTIONS(2138),
    [anon_sym___restrict__] = ACTIONS(2138),
    [anon_sym__Atomic] = ACTIONS(2138),
    [anon_sym__Noreturn] = ACTIONS(2138),
    [anon_sym_noreturn] = ACTIONS(2138),
    [anon_sym_mutable] = ACTIONS(2138),
    [anon_sym_constinit] = ACTIONS(2138),
    [anon_sym_consteval] = ACTIONS(2138),
    [anon_sym_alignas] = ACTIONS(2138),
    [anon_sym__Alignas] = ACTIONS(2138),
    [sym_primitive_type] = ACTIONS(2138),
    [anon_sym_enum] = ACTIONS(2138),
    [anon_sym_class] = ACTIONS(2138),
    [anon_sym_struct] = ACTIONS(2138),
    [anon_sym_union] = ACTIONS(2138),
    [anon_sym_if] = ACTIONS(2138),
    [anon_sym_else] = ACTIONS(2138),
    [anon_sym_switch] = ACTIONS(2138),
    [anon_sym_case] = ACTIONS(2138),
    [anon_sym_default] = ACTIONS(2138),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_do] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2138),
    [anon_sym_return] = ACTIONS(2138),
    [anon_sym_break] = ACTIONS(2138),
    [anon_sym_continue] = ACTIONS(2138),
    [anon_sym_goto] = ACTIONS(2138),
    [anon_sym___try] = ACTIONS(2138),
    [anon_sym___leave] = ACTIONS(2138),
    [anon_sym_not] = ACTIONS(2138),
    [anon_sym_compl] = ACTIONS(2138),
    [anon_sym_DASH_DASH] = ACTIONS(2140),
    [anon_sym_PLUS_PLUS] = ACTIONS(2140),
    [anon_sym_sizeof] = ACTIONS(2138),
    [anon_sym___alignof__] = ACTIONS(2138),
    [anon_sym___alignof] = ACTIONS(2138),
    [anon_sym__alignof] = ACTIONS(2138),
    [anon_sym_alignof] = ACTIONS(2138),
    [anon_sym__Alignof] = ACTIONS(2138),
    [anon_sym_offsetof] = ACTIONS(2138),
    [anon_sym__Generic] = ACTIONS(2138),
    [anon_sym_asm] = ACTIONS(2138),
    [anon_sym___asm__] = ACTIONS(2138),
    [sym_number_literal] = ACTIONS(2140),
    [anon_sym_L_SQUOTE] = ACTIONS(2140),
    [anon_sym_u_SQUOTE] = ACTIONS(2140),
    [anon_sym_U_SQUOTE] = ACTIONS(2140),
    [anon_sym_u8_SQUOTE] = ACTIONS(2140),
    [anon_sym_SQUOTE] = ACTIONS(2140),
    [anon_sym_L_DQUOTE] = ACTIONS(2140),
    [anon_sym_u_DQUOTE] = ACTIONS(2140),
    [anon_sym_U_DQUOTE] = ACTIONS(2140),
    [anon_sym_u8_DQUOTE] = ACTIONS(2140),
    [anon_sym_DQUOTE] = ACTIONS(2140),
    [sym_true] = ACTIONS(2138),
    [sym_false] = ACTIONS(2138),
    [anon_sym_NULL] = ACTIONS(2138),
    [anon_sym_nullptr] = ACTIONS(2138),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2138),
    [anon_sym_decltype] = ACTIONS(2138),
    [sym_virtual] = ACTIONS(2138),
    [anon_sym_explicit] = ACTIONS(2138),
    [anon_sym_typename] = ACTIONS(2138),
    [anon_sym_template] = ACTIONS(2138),
    [anon_sym_operator] = ACTIONS(2138),
    [anon_sym_try] = ACTIONS(2138),
    [anon_sym_delete] = ACTIONS(2138),
    [anon_sym_throw] = ACTIONS(2138),
    [anon_sym_namespace] = ACTIONS(2138),
    [anon_sym_using] = ACTIONS(2138),
    [anon_sym_static_assert] = ACTIONS(2138),
    [anon_sym_concept] = ACTIONS(2138),
    [anon_sym_co_return] = ACTIONS(2138),
    [anon_sym_co_yield] = ACTIONS(2138),
    [anon_sym_R_DQUOTE] = ACTIONS(2140),
    [anon_sym_LR_DQUOTE] = ACTIONS(2140),
    [anon_sym_uR_DQUOTE] = ACTIONS(2140),
    [anon_sym_UR_DQUOTE] = ACTIONS(2140),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2140),
    [anon_sym_co_await] = ACTIONS(2138),
    [anon_sym_new] = ACTIONS(2138),
    [anon_sym_requires] = ACTIONS(2138),
    [sym_this] = ACTIONS(2138),
    [anon_sym_discard] = ACTIONS(2138),
    [anon_sym_precise] = ACTIONS(2138),
    [anon_sym_shared] = ACTIONS(2138),
    [anon_sym_groupshared] = ACTIONS(2138),
    [anon_sym_uniform] = ACTIONS(2138),
    [anon_sym_row_major] = ACTIONS(2138),
    [anon_sym_column_major] = ACTIONS(2138),
    [anon_sym_globallycoherent] = ACTIONS(2138),
    [anon_sym_centroid] = ACTIONS(2138),
    [anon_sym_noperspective] = ACTIONS(2138),
    [anon_sym_nointerpolation] = ACTIONS(2138),
    [anon_sym_sample] = ACTIONS(2138),
    [anon_sym_linear] = ACTIONS(2138),
    [anon_sym_snorm] = ACTIONS(2138),
    [anon_sym_unorm] = ACTIONS(2138),
    [anon_sym_point] = ACTIONS(2138),
    [anon_sym_line] = ACTIONS(2138),
    [anon_sym_triangleadj] = ACTIONS(2138),
    [anon_sym_lineadj] = ACTIONS(2138),
    [anon_sym_triangle] = ACTIONS(2138),
    [anon_sym_cbuffer] = ACTIONS(2138),
  },
  [447] = {
    [sym_identifier] = ACTIONS(2162),
    [aux_sym_preproc_include_token1] = ACTIONS(2162),
    [aux_sym_preproc_def_token1] = ACTIONS(2162),
    [aux_sym_preproc_if_token1] = ACTIONS(2162),
    [aux_sym_preproc_if_token2] = ACTIONS(2162),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2162),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2162),
    [sym_preproc_directive] = ACTIONS(2162),
    [anon_sym_LPAREN2] = ACTIONS(2164),
    [anon_sym_BANG] = ACTIONS(2164),
    [anon_sym_TILDE] = ACTIONS(2164),
    [anon_sym_DASH] = ACTIONS(2162),
    [anon_sym_PLUS] = ACTIONS(2162),
    [anon_sym_STAR] = ACTIONS(2164),
    [anon_sym_AMP_AMP] = ACTIONS(2164),
    [anon_sym_AMP] = ACTIONS(2162),
    [anon_sym_SEMI] = ACTIONS(2164),
    [anon_sym___extension__] = ACTIONS(2162),
    [anon_sym_typedef] = ACTIONS(2162),
    [anon_sym_in] = ACTIONS(2162),
    [anon_sym_out] = ACTIONS(2162),
    [anon_sym_inout] = ACTIONS(2162),
    [anon_sym_extern] = ACTIONS(2162),
    [anon_sym___attribute__] = ACTIONS(2162),
    [anon_sym_COLON_COLON] = ACTIONS(2164),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2164),
    [anon_sym___declspec] = ACTIONS(2162),
    [anon_sym___based] = ACTIONS(2162),
    [anon_sym___cdecl] = ACTIONS(2162),
    [anon_sym___clrcall] = ACTIONS(2162),
    [anon_sym___stdcall] = ACTIONS(2162),
    [anon_sym___fastcall] = ACTIONS(2162),
    [anon_sym___thiscall] = ACTIONS(2162),
    [anon_sym___vectorcall] = ACTIONS(2162),
    [anon_sym_LBRACE] = ACTIONS(2164),
    [anon_sym_signed] = ACTIONS(2162),
    [anon_sym_unsigned] = ACTIONS(2162),
    [anon_sym_long] = ACTIONS(2162),
    [anon_sym_short] = ACTIONS(2162),
    [anon_sym_LBRACK] = ACTIONS(2162),
    [anon_sym_static] = ACTIONS(2162),
    [anon_sym_register] = ACTIONS(2162),
    [anon_sym_inline] = ACTIONS(2162),
    [anon_sym___inline] = ACTIONS(2162),
    [anon_sym___inline__] = ACTIONS(2162),
    [anon_sym___forceinline] = ACTIONS(2162),
    [anon_sym_thread_local] = ACTIONS(2162),
    [anon_sym___thread] = ACTIONS(2162),
    [anon_sym_const] = ACTIONS(2162),
    [anon_sym_constexpr] = ACTIONS(2162),
    [anon_sym_volatile] = ACTIONS(2162),
    [anon_sym_restrict] = ACTIONS(2162),
    [anon_sym___restrict__] = ACTIONS(2162),
    [anon_sym__Atomic] = ACTIONS(2162),
    [anon_sym__Noreturn] = ACTIONS(2162),
    [anon_sym_noreturn] = ACTIONS(2162),
    [anon_sym_mutable] = ACTIONS(2162),
    [anon_sym_constinit] = ACTIONS(2162),
    [anon_sym_consteval] = ACTIONS(2162),
    [anon_sym_alignas] = ACTIONS(2162),
    [anon_sym__Alignas] = ACTIONS(2162),
    [sym_primitive_type] = ACTIONS(2162),
    [anon_sym_enum] = ACTIONS(2162),
    [anon_sym_class] = ACTIONS(2162),
    [anon_sym_struct] = ACTIONS(2162),
    [anon_sym_union] = ACTIONS(2162),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_else] = ACTIONS(2162),
    [anon_sym_switch] = ACTIONS(2162),
    [anon_sym_case] = ACTIONS(2162),
    [anon_sym_default] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(2162),
    [anon_sym_do] = ACTIONS(2162),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_return] = ACTIONS(2162),
    [anon_sym_break] = ACTIONS(2162),
    [anon_sym_continue] = ACTIONS(2162),
    [anon_sym_goto] = ACTIONS(2162),
    [anon_sym___try] = ACTIONS(2162),
    [anon_sym___leave] = ACTIONS(2162),
    [anon_sym_not] = ACTIONS(2162),
    [anon_sym_compl] = ACTIONS(2162),
    [anon_sym_DASH_DASH] = ACTIONS(2164),
    [anon_sym_PLUS_PLUS] = ACTIONS(2164),
    [anon_sym_sizeof] = ACTIONS(2162),
    [anon_sym___alignof__] = ACTIONS(2162),
    [anon_sym___alignof] = ACTIONS(2162),
    [anon_sym__alignof] = ACTIONS(2162),
    [anon_sym_alignof] = ACTIONS(2162),
    [anon_sym__Alignof] = ACTIONS(2162),
    [anon_sym_offsetof] = ACTIONS(2162),
    [anon_sym__Generic] = ACTIONS(2162),
    [anon_sym_asm] = ACTIONS(2162),
    [anon_sym___asm__] = ACTIONS(2162),
    [sym_number_literal] = ACTIONS(2164),
    [anon_sym_L_SQUOTE] = ACTIONS(2164),
    [anon_sym_u_SQUOTE] = ACTIONS(2164),
    [anon_sym_U_SQUOTE] = ACTIONS(2164),
    [anon_sym_u8_SQUOTE] = ACTIONS(2164),
    [anon_sym_SQUOTE] = ACTIONS(2164),
    [anon_sym_L_DQUOTE] = ACTIONS(2164),
    [anon_sym_u_DQUOTE] = ACTIONS(2164),
    [anon_sym_U_DQUOTE] = ACTIONS(2164),
    [anon_sym_u8_DQUOTE] = ACTIONS(2164),
    [anon_sym_DQUOTE] = ACTIONS(2164),
    [sym_true] = ACTIONS(2162),
    [sym_false] = ACTIONS(2162),
    [anon_sym_NULL] = ACTIONS(2162),
    [anon_sym_nullptr] = ACTIONS(2162),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2162),
    [anon_sym_decltype] = ACTIONS(2162),
    [sym_virtual] = ACTIONS(2162),
    [anon_sym_explicit] = ACTIONS(2162),
    [anon_sym_typename] = ACTIONS(2162),
    [anon_sym_template] = ACTIONS(2162),
    [anon_sym_operator] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2162),
    [anon_sym_delete] = ACTIONS(2162),
    [anon_sym_throw] = ACTIONS(2162),
    [anon_sym_namespace] = ACTIONS(2162),
    [anon_sym_using] = ACTIONS(2162),
    [anon_sym_static_assert] = ACTIONS(2162),
    [anon_sym_concept] = ACTIONS(2162),
    [anon_sym_co_return] = ACTIONS(2162),
    [anon_sym_co_yield] = ACTIONS(2162),
    [anon_sym_R_DQUOTE] = ACTIONS(2164),
    [anon_sym_LR_DQUOTE] = ACTIONS(2164),
    [anon_sym_uR_DQUOTE] = ACTIONS(2164),
    [anon_sym_UR_DQUOTE] = ACTIONS(2164),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2164),
    [anon_sym_co_await] = ACTIONS(2162),
    [anon_sym_new] = ACTIONS(2162),
    [anon_sym_requires] = ACTIONS(2162),
    [sym_this] = ACTIONS(2162),
    [anon_sym_discard] = ACTIONS(2162),
    [anon_sym_precise] = ACTIONS(2162),
    [anon_sym_shared] = ACTIONS(2162),
    [anon_sym_groupshared] = ACTIONS(2162),
    [anon_sym_uniform] = ACTIONS(2162),
    [anon_sym_row_major] = ACTIONS(2162),
    [anon_sym_column_major] = ACTIONS(2162),
    [anon_sym_globallycoherent] = ACTIONS(2162),
    [anon_sym_centroid] = ACTIONS(2162),
    [anon_sym_noperspective] = ACTIONS(2162),
    [anon_sym_nointerpolation] = ACTIONS(2162),
    [anon_sym_sample] = ACTIONS(2162),
    [anon_sym_linear] = ACTIONS(2162),
    [anon_sym_snorm] = ACTIONS(2162),
    [anon_sym_unorm] = ACTIONS(2162),
    [anon_sym_point] = ACTIONS(2162),
    [anon_sym_line] = ACTIONS(2162),
    [anon_sym_triangleadj] = ACTIONS(2162),
    [anon_sym_lineadj] = ACTIONS(2162),
    [anon_sym_triangle] = ACTIONS(2162),
    [anon_sym_cbuffer] = ACTIONS(2162),
  },
  [448] = {
    [sym_identifier] = ACTIONS(2150),
    [aux_sym_preproc_include_token1] = ACTIONS(2150),
    [aux_sym_preproc_def_token1] = ACTIONS(2150),
    [aux_sym_preproc_if_token1] = ACTIONS(2150),
    [aux_sym_preproc_if_token2] = ACTIONS(2150),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2150),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2150),
    [sym_preproc_directive] = ACTIONS(2150),
    [anon_sym_LPAREN2] = ACTIONS(2152),
    [anon_sym_BANG] = ACTIONS(2152),
    [anon_sym_TILDE] = ACTIONS(2152),
    [anon_sym_DASH] = ACTIONS(2150),
    [anon_sym_PLUS] = ACTIONS(2150),
    [anon_sym_STAR] = ACTIONS(2152),
    [anon_sym_AMP_AMP] = ACTIONS(2152),
    [anon_sym_AMP] = ACTIONS(2150),
    [anon_sym_SEMI] = ACTIONS(2152),
    [anon_sym___extension__] = ACTIONS(2150),
    [anon_sym_typedef] = ACTIONS(2150),
    [anon_sym_in] = ACTIONS(2150),
    [anon_sym_out] = ACTIONS(2150),
    [anon_sym_inout] = ACTIONS(2150),
    [anon_sym_extern] = ACTIONS(2150),
    [anon_sym___attribute__] = ACTIONS(2150),
    [anon_sym_COLON_COLON] = ACTIONS(2152),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2152),
    [anon_sym___declspec] = ACTIONS(2150),
    [anon_sym___based] = ACTIONS(2150),
    [anon_sym___cdecl] = ACTIONS(2150),
    [anon_sym___clrcall] = ACTIONS(2150),
    [anon_sym___stdcall] = ACTIONS(2150),
    [anon_sym___fastcall] = ACTIONS(2150),
    [anon_sym___thiscall] = ACTIONS(2150),
    [anon_sym___vectorcall] = ACTIONS(2150),
    [anon_sym_LBRACE] = ACTIONS(2152),
    [anon_sym_signed] = ACTIONS(2150),
    [anon_sym_unsigned] = ACTIONS(2150),
    [anon_sym_long] = ACTIONS(2150),
    [anon_sym_short] = ACTIONS(2150),
    [anon_sym_LBRACK] = ACTIONS(2150),
    [anon_sym_static] = ACTIONS(2150),
    [anon_sym_register] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(2150),
    [anon_sym___inline] = ACTIONS(2150),
    [anon_sym___inline__] = ACTIONS(2150),
    [anon_sym___forceinline] = ACTIONS(2150),
    [anon_sym_thread_local] = ACTIONS(2150),
    [anon_sym___thread] = ACTIONS(2150),
    [anon_sym_const] = ACTIONS(2150),
    [anon_sym_constexpr] = ACTIONS(2150),
    [anon_sym_volatile] = ACTIONS(2150),
    [anon_sym_restrict] = ACTIONS(2150),
    [anon_sym___restrict__] = ACTIONS(2150),
    [anon_sym__Atomic] = ACTIONS(2150),
    [anon_sym__Noreturn] = ACTIONS(2150),
    [anon_sym_noreturn] = ACTIONS(2150),
    [anon_sym_mutable] = ACTIONS(2150),
    [anon_sym_constinit] = ACTIONS(2150),
    [anon_sym_consteval] = ACTIONS(2150),
    [anon_sym_alignas] = ACTIONS(2150),
    [anon_sym__Alignas] = ACTIONS(2150),
    [sym_primitive_type] = ACTIONS(2150),
    [anon_sym_enum] = ACTIONS(2150),
    [anon_sym_class] = ACTIONS(2150),
    [anon_sym_struct] = ACTIONS(2150),
    [anon_sym_union] = ACTIONS(2150),
    [anon_sym_if] = ACTIONS(2150),
    [anon_sym_else] = ACTIONS(2150),
    [anon_sym_switch] = ACTIONS(2150),
    [anon_sym_case] = ACTIONS(2150),
    [anon_sym_default] = ACTIONS(2150),
    [anon_sym_while] = ACTIONS(2150),
    [anon_sym_do] = ACTIONS(2150),
    [anon_sym_for] = ACTIONS(2150),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_break] = ACTIONS(2150),
    [anon_sym_continue] = ACTIONS(2150),
    [anon_sym_goto] = ACTIONS(2150),
    [anon_sym___try] = ACTIONS(2150),
    [anon_sym___leave] = ACTIONS(2150),
    [anon_sym_not] = ACTIONS(2150),
    [anon_sym_compl] = ACTIONS(2150),
    [anon_sym_DASH_DASH] = ACTIONS(2152),
    [anon_sym_PLUS_PLUS] = ACTIONS(2152),
    [anon_sym_sizeof] = ACTIONS(2150),
    [anon_sym___alignof__] = ACTIONS(2150),
    [anon_sym___alignof] = ACTIONS(2150),
    [anon_sym__alignof] = ACTIONS(2150),
    [anon_sym_alignof] = ACTIONS(2150),
    [anon_sym__Alignof] = ACTIONS(2150),
    [anon_sym_offsetof] = ACTIONS(2150),
    [anon_sym__Generic] = ACTIONS(2150),
    [anon_sym_asm] = ACTIONS(2150),
    [anon_sym___asm__] = ACTIONS(2150),
    [sym_number_literal] = ACTIONS(2152),
    [anon_sym_L_SQUOTE] = ACTIONS(2152),
    [anon_sym_u_SQUOTE] = ACTIONS(2152),
    [anon_sym_U_SQUOTE] = ACTIONS(2152),
    [anon_sym_u8_SQUOTE] = ACTIONS(2152),
    [anon_sym_SQUOTE] = ACTIONS(2152),
    [anon_sym_L_DQUOTE] = ACTIONS(2152),
    [anon_sym_u_DQUOTE] = ACTIONS(2152),
    [anon_sym_U_DQUOTE] = ACTIONS(2152),
    [anon_sym_u8_DQUOTE] = ACTIONS(2152),
    [anon_sym_DQUOTE] = ACTIONS(2152),
    [sym_true] = ACTIONS(2150),
    [sym_false] = ACTIONS(2150),
    [anon_sym_NULL] = ACTIONS(2150),
    [anon_sym_nullptr] = ACTIONS(2150),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2150),
    [anon_sym_decltype] = ACTIONS(2150),
    [sym_virtual] = ACTIONS(2150),
    [anon_sym_explicit] = ACTIONS(2150),
    [anon_sym_typename] = ACTIONS(2150),
    [anon_sym_template] = ACTIONS(2150),
    [anon_sym_operator] = ACTIONS(2150),
    [anon_sym_try] = ACTIONS(2150),
    [anon_sym_delete] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2150),
    [anon_sym_namespace] = ACTIONS(2150),
    [anon_sym_using] = ACTIONS(2150),
    [anon_sym_static_assert] = ACTIONS(2150),
    [anon_sym_concept] = ACTIONS(2150),
    [anon_sym_co_return] = ACTIONS(2150),
    [anon_sym_co_yield] = ACTIONS(2150),
    [anon_sym_R_DQUOTE] = ACTIONS(2152),
    [anon_sym_LR_DQUOTE] = ACTIONS(2152),
    [anon_sym_uR_DQUOTE] = ACTIONS(2152),
    [anon_sym_UR_DQUOTE] = ACTIONS(2152),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2152),
    [anon_sym_co_await] = ACTIONS(2150),
    [anon_sym_new] = ACTIONS(2150),
    [anon_sym_requires] = ACTIONS(2150),
    [sym_this] = ACTIONS(2150),
    [anon_sym_discard] = ACTIONS(2150),
    [anon_sym_precise] = ACTIONS(2150),
    [anon_sym_shared] = ACTIONS(2150),
    [anon_sym_groupshared] = ACTIONS(2150),
    [anon_sym_uniform] = ACTIONS(2150),
    [anon_sym_row_major] = ACTIONS(2150),
    [anon_sym_column_major] = ACTIONS(2150),
    [anon_sym_globallycoherent] = ACTIONS(2150),
    [anon_sym_centroid] = ACTIONS(2150),
    [anon_sym_noperspective] = ACTIONS(2150),
    [anon_sym_nointerpolation] = ACTIONS(2150),
    [anon_sym_sample] = ACTIONS(2150),
    [anon_sym_linear] = ACTIONS(2150),
    [anon_sym_snorm] = ACTIONS(2150),
    [anon_sym_unorm] = ACTIONS(2150),
    [anon_sym_point] = ACTIONS(2150),
    [anon_sym_line] = ACTIONS(2150),
    [anon_sym_triangleadj] = ACTIONS(2150),
    [anon_sym_lineadj] = ACTIONS(2150),
    [anon_sym_triangle] = ACTIONS(2150),
    [anon_sym_cbuffer] = ACTIONS(2150),
  },
  [449] = {
    [sym_identifier] = ACTIONS(2276),
    [aux_sym_preproc_include_token1] = ACTIONS(2276),
    [aux_sym_preproc_def_token1] = ACTIONS(2276),
    [aux_sym_preproc_if_token1] = ACTIONS(2276),
    [aux_sym_preproc_if_token2] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2276),
    [sym_preproc_directive] = ACTIONS(2276),
    [anon_sym_LPAREN2] = ACTIONS(2278),
    [anon_sym_BANG] = ACTIONS(2278),
    [anon_sym_TILDE] = ACTIONS(2278),
    [anon_sym_DASH] = ACTIONS(2276),
    [anon_sym_PLUS] = ACTIONS(2276),
    [anon_sym_STAR] = ACTIONS(2278),
    [anon_sym_AMP_AMP] = ACTIONS(2278),
    [anon_sym_AMP] = ACTIONS(2276),
    [anon_sym_SEMI] = ACTIONS(2278),
    [anon_sym___extension__] = ACTIONS(2276),
    [anon_sym_typedef] = ACTIONS(2276),
    [anon_sym_in] = ACTIONS(2276),
    [anon_sym_out] = ACTIONS(2276),
    [anon_sym_inout] = ACTIONS(2276),
    [anon_sym_extern] = ACTIONS(2276),
    [anon_sym___attribute__] = ACTIONS(2276),
    [anon_sym_COLON_COLON] = ACTIONS(2278),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2278),
    [anon_sym___declspec] = ACTIONS(2276),
    [anon_sym___based] = ACTIONS(2276),
    [anon_sym___cdecl] = ACTIONS(2276),
    [anon_sym___clrcall] = ACTIONS(2276),
    [anon_sym___stdcall] = ACTIONS(2276),
    [anon_sym___fastcall] = ACTIONS(2276),
    [anon_sym___thiscall] = ACTIONS(2276),
    [anon_sym___vectorcall] = ACTIONS(2276),
    [anon_sym_LBRACE] = ACTIONS(2278),
    [anon_sym_signed] = ACTIONS(2276),
    [anon_sym_unsigned] = ACTIONS(2276),
    [anon_sym_long] = ACTIONS(2276),
    [anon_sym_short] = ACTIONS(2276),
    [anon_sym_LBRACK] = ACTIONS(2276),
    [anon_sym_static] = ACTIONS(2276),
    [anon_sym_register] = ACTIONS(2276),
    [anon_sym_inline] = ACTIONS(2276),
    [anon_sym___inline] = ACTIONS(2276),
    [anon_sym___inline__] = ACTIONS(2276),
    [anon_sym___forceinline] = ACTIONS(2276),
    [anon_sym_thread_local] = ACTIONS(2276),
    [anon_sym___thread] = ACTIONS(2276),
    [anon_sym_const] = ACTIONS(2276),
    [anon_sym_constexpr] = ACTIONS(2276),
    [anon_sym_volatile] = ACTIONS(2276),
    [anon_sym_restrict] = ACTIONS(2276),
    [anon_sym___restrict__] = ACTIONS(2276),
    [anon_sym__Atomic] = ACTIONS(2276),
    [anon_sym__Noreturn] = ACTIONS(2276),
    [anon_sym_noreturn] = ACTIONS(2276),
    [anon_sym_mutable] = ACTIONS(2276),
    [anon_sym_constinit] = ACTIONS(2276),
    [anon_sym_consteval] = ACTIONS(2276),
    [anon_sym_alignas] = ACTIONS(2276),
    [anon_sym__Alignas] = ACTIONS(2276),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2276),
    [anon_sym_class] = ACTIONS(2276),
    [anon_sym_struct] = ACTIONS(2276),
    [anon_sym_union] = ACTIONS(2276),
    [anon_sym_if] = ACTIONS(2276),
    [anon_sym_else] = ACTIONS(2276),
    [anon_sym_switch] = ACTIONS(2276),
    [anon_sym_case] = ACTIONS(2276),
    [anon_sym_default] = ACTIONS(2276),
    [anon_sym_while] = ACTIONS(2276),
    [anon_sym_do] = ACTIONS(2276),
    [anon_sym_for] = ACTIONS(2276),
    [anon_sym_return] = ACTIONS(2276),
    [anon_sym_break] = ACTIONS(2276),
    [anon_sym_continue] = ACTIONS(2276),
    [anon_sym_goto] = ACTIONS(2276),
    [anon_sym___try] = ACTIONS(2276),
    [anon_sym___leave] = ACTIONS(2276),
    [anon_sym_not] = ACTIONS(2276),
    [anon_sym_compl] = ACTIONS(2276),
    [anon_sym_DASH_DASH] = ACTIONS(2278),
    [anon_sym_PLUS_PLUS] = ACTIONS(2278),
    [anon_sym_sizeof] = ACTIONS(2276),
    [anon_sym___alignof__] = ACTIONS(2276),
    [anon_sym___alignof] = ACTIONS(2276),
    [anon_sym__alignof] = ACTIONS(2276),
    [anon_sym_alignof] = ACTIONS(2276),
    [anon_sym__Alignof] = ACTIONS(2276),
    [anon_sym_offsetof] = ACTIONS(2276),
    [anon_sym__Generic] = ACTIONS(2276),
    [anon_sym_asm] = ACTIONS(2276),
    [anon_sym___asm__] = ACTIONS(2276),
    [sym_number_literal] = ACTIONS(2278),
    [anon_sym_L_SQUOTE] = ACTIONS(2278),
    [anon_sym_u_SQUOTE] = ACTIONS(2278),
    [anon_sym_U_SQUOTE] = ACTIONS(2278),
    [anon_sym_u8_SQUOTE] = ACTIONS(2278),
    [anon_sym_SQUOTE] = ACTIONS(2278),
    [anon_sym_L_DQUOTE] = ACTIONS(2278),
    [anon_sym_u_DQUOTE] = ACTIONS(2278),
    [anon_sym_U_DQUOTE] = ACTIONS(2278),
    [anon_sym_u8_DQUOTE] = ACTIONS(2278),
    [anon_sym_DQUOTE] = ACTIONS(2278),
    [sym_true] = ACTIONS(2276),
    [sym_false] = ACTIONS(2276),
    [anon_sym_NULL] = ACTIONS(2276),
    [anon_sym_nullptr] = ACTIONS(2276),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2276),
    [anon_sym_decltype] = ACTIONS(2276),
    [sym_virtual] = ACTIONS(2276),
    [anon_sym_explicit] = ACTIONS(2276),
    [anon_sym_typename] = ACTIONS(2276),
    [anon_sym_template] = ACTIONS(2276),
    [anon_sym_operator] = ACTIONS(2276),
    [anon_sym_try] = ACTIONS(2276),
    [anon_sym_delete] = ACTIONS(2276),
    [anon_sym_throw] = ACTIONS(2276),
    [anon_sym_namespace] = ACTIONS(2276),
    [anon_sym_using] = ACTIONS(2276),
    [anon_sym_static_assert] = ACTIONS(2276),
    [anon_sym_concept] = ACTIONS(2276),
    [anon_sym_co_return] = ACTIONS(2276),
    [anon_sym_co_yield] = ACTIONS(2276),
    [anon_sym_R_DQUOTE] = ACTIONS(2278),
    [anon_sym_LR_DQUOTE] = ACTIONS(2278),
    [anon_sym_uR_DQUOTE] = ACTIONS(2278),
    [anon_sym_UR_DQUOTE] = ACTIONS(2278),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2278),
    [anon_sym_co_await] = ACTIONS(2276),
    [anon_sym_new] = ACTIONS(2276),
    [anon_sym_requires] = ACTIONS(2276),
    [sym_this] = ACTIONS(2276),
    [anon_sym_discard] = ACTIONS(2276),
    [anon_sym_precise] = ACTIONS(2276),
    [anon_sym_shared] = ACTIONS(2276),
    [anon_sym_groupshared] = ACTIONS(2276),
    [anon_sym_uniform] = ACTIONS(2276),
    [anon_sym_row_major] = ACTIONS(2276),
    [anon_sym_column_major] = ACTIONS(2276),
    [anon_sym_globallycoherent] = ACTIONS(2276),
    [anon_sym_centroid] = ACTIONS(2276),
    [anon_sym_noperspective] = ACTIONS(2276),
    [anon_sym_nointerpolation] = ACTIONS(2276),
    [anon_sym_sample] = ACTIONS(2276),
    [anon_sym_linear] = ACTIONS(2276),
    [anon_sym_snorm] = ACTIONS(2276),
    [anon_sym_unorm] = ACTIONS(2276),
    [anon_sym_point] = ACTIONS(2276),
    [anon_sym_line] = ACTIONS(2276),
    [anon_sym_triangleadj] = ACTIONS(2276),
    [anon_sym_lineadj] = ACTIONS(2276),
    [anon_sym_triangle] = ACTIONS(2276),
    [anon_sym_cbuffer] = ACTIONS(2276),
  },
  [450] = {
    [sym_identifier] = ACTIONS(2276),
    [aux_sym_preproc_include_token1] = ACTIONS(2276),
    [aux_sym_preproc_def_token1] = ACTIONS(2276),
    [aux_sym_preproc_if_token1] = ACTIONS(2276),
    [aux_sym_preproc_if_token2] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2276),
    [sym_preproc_directive] = ACTIONS(2276),
    [anon_sym_LPAREN2] = ACTIONS(2278),
    [anon_sym_BANG] = ACTIONS(2278),
    [anon_sym_TILDE] = ACTIONS(2278),
    [anon_sym_DASH] = ACTIONS(2276),
    [anon_sym_PLUS] = ACTIONS(2276),
    [anon_sym_STAR] = ACTIONS(2278),
    [anon_sym_AMP_AMP] = ACTIONS(2278),
    [anon_sym_AMP] = ACTIONS(2276),
    [anon_sym_SEMI] = ACTIONS(2278),
    [anon_sym___extension__] = ACTIONS(2276),
    [anon_sym_typedef] = ACTIONS(2276),
    [anon_sym_in] = ACTIONS(2276),
    [anon_sym_out] = ACTIONS(2276),
    [anon_sym_inout] = ACTIONS(2276),
    [anon_sym_extern] = ACTIONS(2276),
    [anon_sym___attribute__] = ACTIONS(2276),
    [anon_sym_COLON_COLON] = ACTIONS(2278),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2278),
    [anon_sym___declspec] = ACTIONS(2276),
    [anon_sym___based] = ACTIONS(2276),
    [anon_sym___cdecl] = ACTIONS(2276),
    [anon_sym___clrcall] = ACTIONS(2276),
    [anon_sym___stdcall] = ACTIONS(2276),
    [anon_sym___fastcall] = ACTIONS(2276),
    [anon_sym___thiscall] = ACTIONS(2276),
    [anon_sym___vectorcall] = ACTIONS(2276),
    [anon_sym_LBRACE] = ACTIONS(2278),
    [anon_sym_signed] = ACTIONS(2276),
    [anon_sym_unsigned] = ACTIONS(2276),
    [anon_sym_long] = ACTIONS(2276),
    [anon_sym_short] = ACTIONS(2276),
    [anon_sym_LBRACK] = ACTIONS(2276),
    [anon_sym_static] = ACTIONS(2276),
    [anon_sym_register] = ACTIONS(2276),
    [anon_sym_inline] = ACTIONS(2276),
    [anon_sym___inline] = ACTIONS(2276),
    [anon_sym___inline__] = ACTIONS(2276),
    [anon_sym___forceinline] = ACTIONS(2276),
    [anon_sym_thread_local] = ACTIONS(2276),
    [anon_sym___thread] = ACTIONS(2276),
    [anon_sym_const] = ACTIONS(2276),
    [anon_sym_constexpr] = ACTIONS(2276),
    [anon_sym_volatile] = ACTIONS(2276),
    [anon_sym_restrict] = ACTIONS(2276),
    [anon_sym___restrict__] = ACTIONS(2276),
    [anon_sym__Atomic] = ACTIONS(2276),
    [anon_sym__Noreturn] = ACTIONS(2276),
    [anon_sym_noreturn] = ACTIONS(2276),
    [anon_sym_mutable] = ACTIONS(2276),
    [anon_sym_constinit] = ACTIONS(2276),
    [anon_sym_consteval] = ACTIONS(2276),
    [anon_sym_alignas] = ACTIONS(2276),
    [anon_sym__Alignas] = ACTIONS(2276),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2276),
    [anon_sym_class] = ACTIONS(2276),
    [anon_sym_struct] = ACTIONS(2276),
    [anon_sym_union] = ACTIONS(2276),
    [anon_sym_if] = ACTIONS(2276),
    [anon_sym_else] = ACTIONS(2276),
    [anon_sym_switch] = ACTIONS(2276),
    [anon_sym_case] = ACTIONS(2276),
    [anon_sym_default] = ACTIONS(2276),
    [anon_sym_while] = ACTIONS(2276),
    [anon_sym_do] = ACTIONS(2276),
    [anon_sym_for] = ACTIONS(2276),
    [anon_sym_return] = ACTIONS(2276),
    [anon_sym_break] = ACTIONS(2276),
    [anon_sym_continue] = ACTIONS(2276),
    [anon_sym_goto] = ACTIONS(2276),
    [anon_sym___try] = ACTIONS(2276),
    [anon_sym___leave] = ACTIONS(2276),
    [anon_sym_not] = ACTIONS(2276),
    [anon_sym_compl] = ACTIONS(2276),
    [anon_sym_DASH_DASH] = ACTIONS(2278),
    [anon_sym_PLUS_PLUS] = ACTIONS(2278),
    [anon_sym_sizeof] = ACTIONS(2276),
    [anon_sym___alignof__] = ACTIONS(2276),
    [anon_sym___alignof] = ACTIONS(2276),
    [anon_sym__alignof] = ACTIONS(2276),
    [anon_sym_alignof] = ACTIONS(2276),
    [anon_sym__Alignof] = ACTIONS(2276),
    [anon_sym_offsetof] = ACTIONS(2276),
    [anon_sym__Generic] = ACTIONS(2276),
    [anon_sym_asm] = ACTIONS(2276),
    [anon_sym___asm__] = ACTIONS(2276),
    [sym_number_literal] = ACTIONS(2278),
    [anon_sym_L_SQUOTE] = ACTIONS(2278),
    [anon_sym_u_SQUOTE] = ACTIONS(2278),
    [anon_sym_U_SQUOTE] = ACTIONS(2278),
    [anon_sym_u8_SQUOTE] = ACTIONS(2278),
    [anon_sym_SQUOTE] = ACTIONS(2278),
    [anon_sym_L_DQUOTE] = ACTIONS(2278),
    [anon_sym_u_DQUOTE] = ACTIONS(2278),
    [anon_sym_U_DQUOTE] = ACTIONS(2278),
    [anon_sym_u8_DQUOTE] = ACTIONS(2278),
    [anon_sym_DQUOTE] = ACTIONS(2278),
    [sym_true] = ACTIONS(2276),
    [sym_false] = ACTIONS(2276),
    [anon_sym_NULL] = ACTIONS(2276),
    [anon_sym_nullptr] = ACTIONS(2276),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2276),
    [anon_sym_decltype] = ACTIONS(2276),
    [sym_virtual] = ACTIONS(2276),
    [anon_sym_explicit] = ACTIONS(2276),
    [anon_sym_typename] = ACTIONS(2276),
    [anon_sym_template] = ACTIONS(2276),
    [anon_sym_operator] = ACTIONS(2276),
    [anon_sym_try] = ACTIONS(2276),
    [anon_sym_delete] = ACTIONS(2276),
    [anon_sym_throw] = ACTIONS(2276),
    [anon_sym_namespace] = ACTIONS(2276),
    [anon_sym_using] = ACTIONS(2276),
    [anon_sym_static_assert] = ACTIONS(2276),
    [anon_sym_concept] = ACTIONS(2276),
    [anon_sym_co_return] = ACTIONS(2276),
    [anon_sym_co_yield] = ACTIONS(2276),
    [anon_sym_R_DQUOTE] = ACTIONS(2278),
    [anon_sym_LR_DQUOTE] = ACTIONS(2278),
    [anon_sym_uR_DQUOTE] = ACTIONS(2278),
    [anon_sym_UR_DQUOTE] = ACTIONS(2278),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2278),
    [anon_sym_co_await] = ACTIONS(2276),
    [anon_sym_new] = ACTIONS(2276),
    [anon_sym_requires] = ACTIONS(2276),
    [sym_this] = ACTIONS(2276),
    [anon_sym_discard] = ACTIONS(2276),
    [anon_sym_precise] = ACTIONS(2276),
    [anon_sym_shared] = ACTIONS(2276),
    [anon_sym_groupshared] = ACTIONS(2276),
    [anon_sym_uniform] = ACTIONS(2276),
    [anon_sym_row_major] = ACTIONS(2276),
    [anon_sym_column_major] = ACTIONS(2276),
    [anon_sym_globallycoherent] = ACTIONS(2276),
    [anon_sym_centroid] = ACTIONS(2276),
    [anon_sym_noperspective] = ACTIONS(2276),
    [anon_sym_nointerpolation] = ACTIONS(2276),
    [anon_sym_sample] = ACTIONS(2276),
    [anon_sym_linear] = ACTIONS(2276),
    [anon_sym_snorm] = ACTIONS(2276),
    [anon_sym_unorm] = ACTIONS(2276),
    [anon_sym_point] = ACTIONS(2276),
    [anon_sym_line] = ACTIONS(2276),
    [anon_sym_triangleadj] = ACTIONS(2276),
    [anon_sym_lineadj] = ACTIONS(2276),
    [anon_sym_triangle] = ACTIONS(2276),
    [anon_sym_cbuffer] = ACTIONS(2276),
  },
  [451] = {
    [sym_expression] = STATE(4562),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8189),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2673),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(2676),
    [anon_sym___extension__] = ACTIONS(2182),
    [anon_sym_in] = ACTIONS(2182),
    [anon_sym_out] = ACTIONS(2182),
    [anon_sym_inout] = ACTIONS(2182),
    [anon_sym_extern] = ACTIONS(2182),
    [anon_sym___attribute__] = ACTIONS(2182),
    [anon_sym_COLON_COLON] = ACTIONS(2678),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2184),
    [anon_sym___declspec] = ACTIONS(2182),
    [anon_sym_signed] = ACTIONS(2182),
    [anon_sym_unsigned] = ACTIONS(2182),
    [anon_sym_long] = ACTIONS(2182),
    [anon_sym_short] = ACTIONS(2182),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(2182),
    [anon_sym_register] = ACTIONS(2182),
    [anon_sym_inline] = ACTIONS(2182),
    [anon_sym___inline] = ACTIONS(2182),
    [anon_sym___inline__] = ACTIONS(2182),
    [anon_sym___forceinline] = ACTIONS(2182),
    [anon_sym_thread_local] = ACTIONS(2182),
    [anon_sym___thread] = ACTIONS(2182),
    [anon_sym_const] = ACTIONS(2182),
    [anon_sym_constexpr] = ACTIONS(2182),
    [anon_sym_volatile] = ACTIONS(2182),
    [anon_sym_restrict] = ACTIONS(2182),
    [anon_sym___restrict__] = ACTIONS(2182),
    [anon_sym__Atomic] = ACTIONS(2182),
    [anon_sym__Noreturn] = ACTIONS(2182),
    [anon_sym_noreturn] = ACTIONS(2182),
    [anon_sym_mutable] = ACTIONS(2182),
    [anon_sym_constinit] = ACTIONS(2182),
    [anon_sym_consteval] = ACTIONS(2182),
    [anon_sym_alignas] = ACTIONS(2182),
    [anon_sym__Alignas] = ACTIONS(2182),
    [sym_primitive_type] = ACTIONS(2681),
    [anon_sym_enum] = ACTIONS(2182),
    [anon_sym_class] = ACTIONS(2182),
    [anon_sym_struct] = ACTIONS(2182),
    [anon_sym_union] = ACTIONS(2182),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2182),
    [anon_sym_decltype] = ACTIONS(2684),
    [sym_virtual] = ACTIONS(2182),
    [anon_sym_typename] = ACTIONS(2182),
    [anon_sym_template] = ACTIONS(2687),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_precise] = ACTIONS(2182),
    [anon_sym_shared] = ACTIONS(2182),
    [anon_sym_groupshared] = ACTIONS(2182),
    [anon_sym_uniform] = ACTIONS(2182),
    [anon_sym_row_major] = ACTIONS(2182),
    [anon_sym_column_major] = ACTIONS(2182),
    [anon_sym_globallycoherent] = ACTIONS(2182),
    [anon_sym_centroid] = ACTIONS(2182),
    [anon_sym_noperspective] = ACTIONS(2182),
    [anon_sym_nointerpolation] = ACTIONS(2182),
    [anon_sym_sample] = ACTIONS(2182),
    [anon_sym_linear] = ACTIONS(2182),
    [anon_sym_snorm] = ACTIONS(2182),
    [anon_sym_unorm] = ACTIONS(2182),
    [anon_sym_point] = ACTIONS(2182),
    [anon_sym_line] = ACTIONS(2182),
    [anon_sym_triangleadj] = ACTIONS(2182),
    [anon_sym_lineadj] = ACTIONS(2182),
    [anon_sym_triangle] = ACTIONS(2182),
  },
  [452] = {
    [sym_identifier] = ACTIONS(2130),
    [aux_sym_preproc_include_token1] = ACTIONS(2130),
    [aux_sym_preproc_def_token1] = ACTIONS(2130),
    [aux_sym_preproc_if_token1] = ACTIONS(2130),
    [aux_sym_preproc_if_token2] = ACTIONS(2130),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2130),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2130),
    [sym_preproc_directive] = ACTIONS(2130),
    [anon_sym_LPAREN2] = ACTIONS(2132),
    [anon_sym_BANG] = ACTIONS(2132),
    [anon_sym_TILDE] = ACTIONS(2132),
    [anon_sym_DASH] = ACTIONS(2130),
    [anon_sym_PLUS] = ACTIONS(2130),
    [anon_sym_STAR] = ACTIONS(2132),
    [anon_sym_AMP_AMP] = ACTIONS(2132),
    [anon_sym_AMP] = ACTIONS(2130),
    [anon_sym_SEMI] = ACTIONS(2132),
    [anon_sym___extension__] = ACTIONS(2130),
    [anon_sym_typedef] = ACTIONS(2130),
    [anon_sym_in] = ACTIONS(2130),
    [anon_sym_out] = ACTIONS(2130),
    [anon_sym_inout] = ACTIONS(2130),
    [anon_sym_extern] = ACTIONS(2130),
    [anon_sym___attribute__] = ACTIONS(2130),
    [anon_sym_COLON_COLON] = ACTIONS(2132),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2132),
    [anon_sym___declspec] = ACTIONS(2130),
    [anon_sym___based] = ACTIONS(2130),
    [anon_sym___cdecl] = ACTIONS(2130),
    [anon_sym___clrcall] = ACTIONS(2130),
    [anon_sym___stdcall] = ACTIONS(2130),
    [anon_sym___fastcall] = ACTIONS(2130),
    [anon_sym___thiscall] = ACTIONS(2130),
    [anon_sym___vectorcall] = ACTIONS(2130),
    [anon_sym_LBRACE] = ACTIONS(2132),
    [anon_sym_signed] = ACTIONS(2130),
    [anon_sym_unsigned] = ACTIONS(2130),
    [anon_sym_long] = ACTIONS(2130),
    [anon_sym_short] = ACTIONS(2130),
    [anon_sym_LBRACK] = ACTIONS(2130),
    [anon_sym_static] = ACTIONS(2130),
    [anon_sym_register] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(2130),
    [anon_sym___inline] = ACTIONS(2130),
    [anon_sym___inline__] = ACTIONS(2130),
    [anon_sym___forceinline] = ACTIONS(2130),
    [anon_sym_thread_local] = ACTIONS(2130),
    [anon_sym___thread] = ACTIONS(2130),
    [anon_sym_const] = ACTIONS(2130),
    [anon_sym_constexpr] = ACTIONS(2130),
    [anon_sym_volatile] = ACTIONS(2130),
    [anon_sym_restrict] = ACTIONS(2130),
    [anon_sym___restrict__] = ACTIONS(2130),
    [anon_sym__Atomic] = ACTIONS(2130),
    [anon_sym__Noreturn] = ACTIONS(2130),
    [anon_sym_noreturn] = ACTIONS(2130),
    [anon_sym_mutable] = ACTIONS(2130),
    [anon_sym_constinit] = ACTIONS(2130),
    [anon_sym_consteval] = ACTIONS(2130),
    [anon_sym_alignas] = ACTIONS(2130),
    [anon_sym__Alignas] = ACTIONS(2130),
    [sym_primitive_type] = ACTIONS(2130),
    [anon_sym_enum] = ACTIONS(2130),
    [anon_sym_class] = ACTIONS(2130),
    [anon_sym_struct] = ACTIONS(2130),
    [anon_sym_union] = ACTIONS(2130),
    [anon_sym_if] = ACTIONS(2130),
    [anon_sym_else] = ACTIONS(2130),
    [anon_sym_switch] = ACTIONS(2130),
    [anon_sym_case] = ACTIONS(2130),
    [anon_sym_default] = ACTIONS(2130),
    [anon_sym_while] = ACTIONS(2130),
    [anon_sym_do] = ACTIONS(2130),
    [anon_sym_for] = ACTIONS(2130),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_break] = ACTIONS(2130),
    [anon_sym_continue] = ACTIONS(2130),
    [anon_sym_goto] = ACTIONS(2130),
    [anon_sym___try] = ACTIONS(2130),
    [anon_sym___leave] = ACTIONS(2130),
    [anon_sym_not] = ACTIONS(2130),
    [anon_sym_compl] = ACTIONS(2130),
    [anon_sym_DASH_DASH] = ACTIONS(2132),
    [anon_sym_PLUS_PLUS] = ACTIONS(2132),
    [anon_sym_sizeof] = ACTIONS(2130),
    [anon_sym___alignof__] = ACTIONS(2130),
    [anon_sym___alignof] = ACTIONS(2130),
    [anon_sym__alignof] = ACTIONS(2130),
    [anon_sym_alignof] = ACTIONS(2130),
    [anon_sym__Alignof] = ACTIONS(2130),
    [anon_sym_offsetof] = ACTIONS(2130),
    [anon_sym__Generic] = ACTIONS(2130),
    [anon_sym_asm] = ACTIONS(2130),
    [anon_sym___asm__] = ACTIONS(2130),
    [sym_number_literal] = ACTIONS(2132),
    [anon_sym_L_SQUOTE] = ACTIONS(2132),
    [anon_sym_u_SQUOTE] = ACTIONS(2132),
    [anon_sym_U_SQUOTE] = ACTIONS(2132),
    [anon_sym_u8_SQUOTE] = ACTIONS(2132),
    [anon_sym_SQUOTE] = ACTIONS(2132),
    [anon_sym_L_DQUOTE] = ACTIONS(2132),
    [anon_sym_u_DQUOTE] = ACTIONS(2132),
    [anon_sym_U_DQUOTE] = ACTIONS(2132),
    [anon_sym_u8_DQUOTE] = ACTIONS(2132),
    [anon_sym_DQUOTE] = ACTIONS(2132),
    [sym_true] = ACTIONS(2130),
    [sym_false] = ACTIONS(2130),
    [anon_sym_NULL] = ACTIONS(2130),
    [anon_sym_nullptr] = ACTIONS(2130),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2130),
    [anon_sym_decltype] = ACTIONS(2130),
    [sym_virtual] = ACTIONS(2130),
    [anon_sym_explicit] = ACTIONS(2130),
    [anon_sym_typename] = ACTIONS(2130),
    [anon_sym_template] = ACTIONS(2130),
    [anon_sym_operator] = ACTIONS(2130),
    [anon_sym_try] = ACTIONS(2130),
    [anon_sym_delete] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2130),
    [anon_sym_namespace] = ACTIONS(2130),
    [anon_sym_using] = ACTIONS(2130),
    [anon_sym_static_assert] = ACTIONS(2130),
    [anon_sym_concept] = ACTIONS(2130),
    [anon_sym_co_return] = ACTIONS(2130),
    [anon_sym_co_yield] = ACTIONS(2130),
    [anon_sym_R_DQUOTE] = ACTIONS(2132),
    [anon_sym_LR_DQUOTE] = ACTIONS(2132),
    [anon_sym_uR_DQUOTE] = ACTIONS(2132),
    [anon_sym_UR_DQUOTE] = ACTIONS(2132),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2132),
    [anon_sym_co_await] = ACTIONS(2130),
    [anon_sym_new] = ACTIONS(2130),
    [anon_sym_requires] = ACTIONS(2130),
    [sym_this] = ACTIONS(2130),
    [anon_sym_discard] = ACTIONS(2130),
    [anon_sym_precise] = ACTIONS(2130),
    [anon_sym_shared] = ACTIONS(2130),
    [anon_sym_groupshared] = ACTIONS(2130),
    [anon_sym_uniform] = ACTIONS(2130),
    [anon_sym_row_major] = ACTIONS(2130),
    [anon_sym_column_major] = ACTIONS(2130),
    [anon_sym_globallycoherent] = ACTIONS(2130),
    [anon_sym_centroid] = ACTIONS(2130),
    [anon_sym_noperspective] = ACTIONS(2130),
    [anon_sym_nointerpolation] = ACTIONS(2130),
    [anon_sym_sample] = ACTIONS(2130),
    [anon_sym_linear] = ACTIONS(2130),
    [anon_sym_snorm] = ACTIONS(2130),
    [anon_sym_unorm] = ACTIONS(2130),
    [anon_sym_point] = ACTIONS(2130),
    [anon_sym_line] = ACTIONS(2130),
    [anon_sym_triangleadj] = ACTIONS(2130),
    [anon_sym_lineadj] = ACTIONS(2130),
    [anon_sym_triangle] = ACTIONS(2130),
    [anon_sym_cbuffer] = ACTIONS(2130),
  },
  [453] = {
    [sym_identifier] = ACTIONS(2098),
    [aux_sym_preproc_include_token1] = ACTIONS(2098),
    [aux_sym_preproc_def_token1] = ACTIONS(2098),
    [aux_sym_preproc_if_token1] = ACTIONS(2098),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2098),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2098),
    [sym_preproc_directive] = ACTIONS(2098),
    [anon_sym_LPAREN2] = ACTIONS(2100),
    [anon_sym_BANG] = ACTIONS(2100),
    [anon_sym_TILDE] = ACTIONS(2100),
    [anon_sym_DASH] = ACTIONS(2098),
    [anon_sym_PLUS] = ACTIONS(2098),
    [anon_sym_STAR] = ACTIONS(2100),
    [anon_sym_AMP_AMP] = ACTIONS(2100),
    [anon_sym_AMP] = ACTIONS(2098),
    [anon_sym_SEMI] = ACTIONS(2100),
    [anon_sym___extension__] = ACTIONS(2098),
    [anon_sym_typedef] = ACTIONS(2098),
    [anon_sym_in] = ACTIONS(2098),
    [anon_sym_out] = ACTIONS(2098),
    [anon_sym_inout] = ACTIONS(2098),
    [anon_sym_extern] = ACTIONS(2098),
    [anon_sym___attribute__] = ACTIONS(2098),
    [anon_sym_COLON_COLON] = ACTIONS(2100),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2100),
    [anon_sym___declspec] = ACTIONS(2098),
    [anon_sym___based] = ACTIONS(2098),
    [anon_sym___cdecl] = ACTIONS(2098),
    [anon_sym___clrcall] = ACTIONS(2098),
    [anon_sym___stdcall] = ACTIONS(2098),
    [anon_sym___fastcall] = ACTIONS(2098),
    [anon_sym___thiscall] = ACTIONS(2098),
    [anon_sym___vectorcall] = ACTIONS(2098),
    [anon_sym_LBRACE] = ACTIONS(2100),
    [anon_sym_RBRACE] = ACTIONS(2100),
    [anon_sym_signed] = ACTIONS(2098),
    [anon_sym_unsigned] = ACTIONS(2098),
    [anon_sym_long] = ACTIONS(2098),
    [anon_sym_short] = ACTIONS(2098),
    [anon_sym_LBRACK] = ACTIONS(2098),
    [anon_sym_static] = ACTIONS(2098),
    [anon_sym_register] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(2098),
    [anon_sym___inline] = ACTIONS(2098),
    [anon_sym___inline__] = ACTIONS(2098),
    [anon_sym___forceinline] = ACTIONS(2098),
    [anon_sym_thread_local] = ACTIONS(2098),
    [anon_sym___thread] = ACTIONS(2098),
    [anon_sym_const] = ACTIONS(2098),
    [anon_sym_constexpr] = ACTIONS(2098),
    [anon_sym_volatile] = ACTIONS(2098),
    [anon_sym_restrict] = ACTIONS(2098),
    [anon_sym___restrict__] = ACTIONS(2098),
    [anon_sym__Atomic] = ACTIONS(2098),
    [anon_sym__Noreturn] = ACTIONS(2098),
    [anon_sym_noreturn] = ACTIONS(2098),
    [anon_sym_mutable] = ACTIONS(2098),
    [anon_sym_constinit] = ACTIONS(2098),
    [anon_sym_consteval] = ACTIONS(2098),
    [anon_sym_alignas] = ACTIONS(2098),
    [anon_sym__Alignas] = ACTIONS(2098),
    [sym_primitive_type] = ACTIONS(2098),
    [anon_sym_enum] = ACTIONS(2098),
    [anon_sym_class] = ACTIONS(2098),
    [anon_sym_struct] = ACTIONS(2098),
    [anon_sym_union] = ACTIONS(2098),
    [anon_sym_if] = ACTIONS(2098),
    [anon_sym_else] = ACTIONS(2098),
    [anon_sym_switch] = ACTIONS(2098),
    [anon_sym_case] = ACTIONS(2098),
    [anon_sym_default] = ACTIONS(2098),
    [anon_sym_while] = ACTIONS(2098),
    [anon_sym_do] = ACTIONS(2098),
    [anon_sym_for] = ACTIONS(2098),
    [anon_sym_return] = ACTIONS(2098),
    [anon_sym_break] = ACTIONS(2098),
    [anon_sym_continue] = ACTIONS(2098),
    [anon_sym_goto] = ACTIONS(2098),
    [anon_sym___try] = ACTIONS(2098),
    [anon_sym___leave] = ACTIONS(2098),
    [anon_sym_not] = ACTIONS(2098),
    [anon_sym_compl] = ACTIONS(2098),
    [anon_sym_DASH_DASH] = ACTIONS(2100),
    [anon_sym_PLUS_PLUS] = ACTIONS(2100),
    [anon_sym_sizeof] = ACTIONS(2098),
    [anon_sym___alignof__] = ACTIONS(2098),
    [anon_sym___alignof] = ACTIONS(2098),
    [anon_sym__alignof] = ACTIONS(2098),
    [anon_sym_alignof] = ACTIONS(2098),
    [anon_sym__Alignof] = ACTIONS(2098),
    [anon_sym_offsetof] = ACTIONS(2098),
    [anon_sym__Generic] = ACTIONS(2098),
    [anon_sym_asm] = ACTIONS(2098),
    [anon_sym___asm__] = ACTIONS(2098),
    [sym_number_literal] = ACTIONS(2100),
    [anon_sym_L_SQUOTE] = ACTIONS(2100),
    [anon_sym_u_SQUOTE] = ACTIONS(2100),
    [anon_sym_U_SQUOTE] = ACTIONS(2100),
    [anon_sym_u8_SQUOTE] = ACTIONS(2100),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [anon_sym_L_DQUOTE] = ACTIONS(2100),
    [anon_sym_u_DQUOTE] = ACTIONS(2100),
    [anon_sym_U_DQUOTE] = ACTIONS(2100),
    [anon_sym_u8_DQUOTE] = ACTIONS(2100),
    [anon_sym_DQUOTE] = ACTIONS(2100),
    [sym_true] = ACTIONS(2098),
    [sym_false] = ACTIONS(2098),
    [anon_sym_NULL] = ACTIONS(2098),
    [anon_sym_nullptr] = ACTIONS(2098),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2098),
    [anon_sym_decltype] = ACTIONS(2098),
    [sym_virtual] = ACTIONS(2098),
    [anon_sym_explicit] = ACTIONS(2098),
    [anon_sym_typename] = ACTIONS(2098),
    [anon_sym_template] = ACTIONS(2098),
    [anon_sym_operator] = ACTIONS(2098),
    [anon_sym_try] = ACTIONS(2098),
    [anon_sym_delete] = ACTIONS(2098),
    [anon_sym_throw] = ACTIONS(2098),
    [anon_sym_namespace] = ACTIONS(2098),
    [anon_sym_using] = ACTIONS(2098),
    [anon_sym_static_assert] = ACTIONS(2098),
    [anon_sym_concept] = ACTIONS(2098),
    [anon_sym_co_return] = ACTIONS(2098),
    [anon_sym_co_yield] = ACTIONS(2098),
    [anon_sym_R_DQUOTE] = ACTIONS(2100),
    [anon_sym_LR_DQUOTE] = ACTIONS(2100),
    [anon_sym_uR_DQUOTE] = ACTIONS(2100),
    [anon_sym_UR_DQUOTE] = ACTIONS(2100),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2100),
    [anon_sym_co_await] = ACTIONS(2098),
    [anon_sym_new] = ACTIONS(2098),
    [anon_sym_requires] = ACTIONS(2098),
    [sym_this] = ACTIONS(2098),
    [anon_sym_discard] = ACTIONS(2098),
    [anon_sym_precise] = ACTIONS(2098),
    [anon_sym_shared] = ACTIONS(2098),
    [anon_sym_groupshared] = ACTIONS(2098),
    [anon_sym_uniform] = ACTIONS(2098),
    [anon_sym_row_major] = ACTIONS(2098),
    [anon_sym_column_major] = ACTIONS(2098),
    [anon_sym_globallycoherent] = ACTIONS(2098),
    [anon_sym_centroid] = ACTIONS(2098),
    [anon_sym_noperspective] = ACTIONS(2098),
    [anon_sym_nointerpolation] = ACTIONS(2098),
    [anon_sym_sample] = ACTIONS(2098),
    [anon_sym_linear] = ACTIONS(2098),
    [anon_sym_snorm] = ACTIONS(2098),
    [anon_sym_unorm] = ACTIONS(2098),
    [anon_sym_point] = ACTIONS(2098),
    [anon_sym_line] = ACTIONS(2098),
    [anon_sym_triangleadj] = ACTIONS(2098),
    [anon_sym_lineadj] = ACTIONS(2098),
    [anon_sym_triangle] = ACTIONS(2098),
    [anon_sym_cbuffer] = ACTIONS(2098),
  },
  [454] = {
    [ts_builtin_sym_end] = ACTIONS(2092),
    [sym_identifier] = ACTIONS(2090),
    [aux_sym_preproc_include_token1] = ACTIONS(2090),
    [aux_sym_preproc_def_token1] = ACTIONS(2090),
    [aux_sym_preproc_if_token1] = ACTIONS(2090),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2090),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2090),
    [sym_preproc_directive] = ACTIONS(2090),
    [anon_sym_LPAREN2] = ACTIONS(2092),
    [anon_sym_BANG] = ACTIONS(2092),
    [anon_sym_TILDE] = ACTIONS(2092),
    [anon_sym_DASH] = ACTIONS(2090),
    [anon_sym_PLUS] = ACTIONS(2090),
    [anon_sym_STAR] = ACTIONS(2092),
    [anon_sym_AMP_AMP] = ACTIONS(2092),
    [anon_sym_AMP] = ACTIONS(2090),
    [anon_sym_SEMI] = ACTIONS(2092),
    [anon_sym___extension__] = ACTIONS(2090),
    [anon_sym_typedef] = ACTIONS(2090),
    [anon_sym_in] = ACTIONS(2090),
    [anon_sym_out] = ACTIONS(2090),
    [anon_sym_inout] = ACTIONS(2090),
    [anon_sym_extern] = ACTIONS(2090),
    [anon_sym___attribute__] = ACTIONS(2090),
    [anon_sym_COLON_COLON] = ACTIONS(2092),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2092),
    [anon_sym___declspec] = ACTIONS(2090),
    [anon_sym___based] = ACTIONS(2090),
    [anon_sym___cdecl] = ACTIONS(2090),
    [anon_sym___clrcall] = ACTIONS(2090),
    [anon_sym___stdcall] = ACTIONS(2090),
    [anon_sym___fastcall] = ACTIONS(2090),
    [anon_sym___thiscall] = ACTIONS(2090),
    [anon_sym___vectorcall] = ACTIONS(2090),
    [anon_sym_LBRACE] = ACTIONS(2092),
    [anon_sym_signed] = ACTIONS(2090),
    [anon_sym_unsigned] = ACTIONS(2090),
    [anon_sym_long] = ACTIONS(2090),
    [anon_sym_short] = ACTIONS(2090),
    [anon_sym_LBRACK] = ACTIONS(2090),
    [anon_sym_static] = ACTIONS(2090),
    [anon_sym_register] = ACTIONS(2090),
    [anon_sym_inline] = ACTIONS(2090),
    [anon_sym___inline] = ACTIONS(2090),
    [anon_sym___inline__] = ACTIONS(2090),
    [anon_sym___forceinline] = ACTIONS(2090),
    [anon_sym_thread_local] = ACTIONS(2090),
    [anon_sym___thread] = ACTIONS(2090),
    [anon_sym_const] = ACTIONS(2090),
    [anon_sym_constexpr] = ACTIONS(2090),
    [anon_sym_volatile] = ACTIONS(2090),
    [anon_sym_restrict] = ACTIONS(2090),
    [anon_sym___restrict__] = ACTIONS(2090),
    [anon_sym__Atomic] = ACTIONS(2090),
    [anon_sym__Noreturn] = ACTIONS(2090),
    [anon_sym_noreturn] = ACTIONS(2090),
    [anon_sym_mutable] = ACTIONS(2090),
    [anon_sym_constinit] = ACTIONS(2090),
    [anon_sym_consteval] = ACTIONS(2090),
    [anon_sym_alignas] = ACTIONS(2090),
    [anon_sym__Alignas] = ACTIONS(2090),
    [sym_primitive_type] = ACTIONS(2090),
    [anon_sym_enum] = ACTIONS(2090),
    [anon_sym_class] = ACTIONS(2090),
    [anon_sym_struct] = ACTIONS(2090),
    [anon_sym_union] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(2090),
    [anon_sym_else] = ACTIONS(2090),
    [anon_sym_switch] = ACTIONS(2090),
    [anon_sym_case] = ACTIONS(2090),
    [anon_sym_default] = ACTIONS(2090),
    [anon_sym_while] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(2090),
    [anon_sym_for] = ACTIONS(2090),
    [anon_sym_return] = ACTIONS(2090),
    [anon_sym_break] = ACTIONS(2090),
    [anon_sym_continue] = ACTIONS(2090),
    [anon_sym_goto] = ACTIONS(2090),
    [anon_sym___try] = ACTIONS(2090),
    [anon_sym___leave] = ACTIONS(2090),
    [anon_sym_not] = ACTIONS(2090),
    [anon_sym_compl] = ACTIONS(2090),
    [anon_sym_DASH_DASH] = ACTIONS(2092),
    [anon_sym_PLUS_PLUS] = ACTIONS(2092),
    [anon_sym_sizeof] = ACTIONS(2090),
    [anon_sym___alignof__] = ACTIONS(2090),
    [anon_sym___alignof] = ACTIONS(2090),
    [anon_sym__alignof] = ACTIONS(2090),
    [anon_sym_alignof] = ACTIONS(2090),
    [anon_sym__Alignof] = ACTIONS(2090),
    [anon_sym_offsetof] = ACTIONS(2090),
    [anon_sym__Generic] = ACTIONS(2090),
    [anon_sym_asm] = ACTIONS(2090),
    [anon_sym___asm__] = ACTIONS(2090),
    [sym_number_literal] = ACTIONS(2092),
    [anon_sym_L_SQUOTE] = ACTIONS(2092),
    [anon_sym_u_SQUOTE] = ACTIONS(2092),
    [anon_sym_U_SQUOTE] = ACTIONS(2092),
    [anon_sym_u8_SQUOTE] = ACTIONS(2092),
    [anon_sym_SQUOTE] = ACTIONS(2092),
    [anon_sym_L_DQUOTE] = ACTIONS(2092),
    [anon_sym_u_DQUOTE] = ACTIONS(2092),
    [anon_sym_U_DQUOTE] = ACTIONS(2092),
    [anon_sym_u8_DQUOTE] = ACTIONS(2092),
    [anon_sym_DQUOTE] = ACTIONS(2092),
    [sym_true] = ACTIONS(2090),
    [sym_false] = ACTIONS(2090),
    [anon_sym_NULL] = ACTIONS(2090),
    [anon_sym_nullptr] = ACTIONS(2090),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2090),
    [anon_sym_decltype] = ACTIONS(2090),
    [sym_virtual] = ACTIONS(2090),
    [anon_sym_explicit] = ACTIONS(2090),
    [anon_sym_typename] = ACTIONS(2090),
    [anon_sym_template] = ACTIONS(2090),
    [anon_sym_operator] = ACTIONS(2090),
    [anon_sym_try] = ACTIONS(2090),
    [anon_sym_delete] = ACTIONS(2090),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_namespace] = ACTIONS(2090),
    [anon_sym_using] = ACTIONS(2090),
    [anon_sym_static_assert] = ACTIONS(2090),
    [anon_sym_concept] = ACTIONS(2090),
    [anon_sym_co_return] = ACTIONS(2090),
    [anon_sym_co_yield] = ACTIONS(2090),
    [anon_sym_R_DQUOTE] = ACTIONS(2092),
    [anon_sym_LR_DQUOTE] = ACTIONS(2092),
    [anon_sym_uR_DQUOTE] = ACTIONS(2092),
    [anon_sym_UR_DQUOTE] = ACTIONS(2092),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2092),
    [anon_sym_co_await] = ACTIONS(2090),
    [anon_sym_new] = ACTIONS(2090),
    [anon_sym_requires] = ACTIONS(2090),
    [sym_this] = ACTIONS(2090),
    [anon_sym_discard] = ACTIONS(2090),
    [anon_sym_precise] = ACTIONS(2090),
    [anon_sym_shared] = ACTIONS(2090),
    [anon_sym_groupshared] = ACTIONS(2090),
    [anon_sym_uniform] = ACTIONS(2090),
    [anon_sym_row_major] = ACTIONS(2090),
    [anon_sym_column_major] = ACTIONS(2090),
    [anon_sym_globallycoherent] = ACTIONS(2090),
    [anon_sym_centroid] = ACTIONS(2090),
    [anon_sym_noperspective] = ACTIONS(2090),
    [anon_sym_nointerpolation] = ACTIONS(2090),
    [anon_sym_sample] = ACTIONS(2090),
    [anon_sym_linear] = ACTIONS(2090),
    [anon_sym_snorm] = ACTIONS(2090),
    [anon_sym_unorm] = ACTIONS(2090),
    [anon_sym_point] = ACTIONS(2090),
    [anon_sym_line] = ACTIONS(2090),
    [anon_sym_triangleadj] = ACTIONS(2090),
    [anon_sym_lineadj] = ACTIONS(2090),
    [anon_sym_triangle] = ACTIONS(2090),
    [anon_sym_cbuffer] = ACTIONS(2090),
  },
  [455] = {
    [sym_identifier] = ACTIONS(2102),
    [aux_sym_preproc_include_token1] = ACTIONS(2102),
    [aux_sym_preproc_def_token1] = ACTIONS(2102),
    [aux_sym_preproc_if_token1] = ACTIONS(2102),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2102),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2102),
    [sym_preproc_directive] = ACTIONS(2102),
    [anon_sym_LPAREN2] = ACTIONS(2104),
    [anon_sym_BANG] = ACTIONS(2104),
    [anon_sym_TILDE] = ACTIONS(2104),
    [anon_sym_DASH] = ACTIONS(2102),
    [anon_sym_PLUS] = ACTIONS(2102),
    [anon_sym_STAR] = ACTIONS(2104),
    [anon_sym_AMP_AMP] = ACTIONS(2104),
    [anon_sym_AMP] = ACTIONS(2102),
    [anon_sym_SEMI] = ACTIONS(2104),
    [anon_sym___extension__] = ACTIONS(2102),
    [anon_sym_typedef] = ACTIONS(2102),
    [anon_sym_in] = ACTIONS(2102),
    [anon_sym_out] = ACTIONS(2102),
    [anon_sym_inout] = ACTIONS(2102),
    [anon_sym_extern] = ACTIONS(2102),
    [anon_sym___attribute__] = ACTIONS(2102),
    [anon_sym_COLON_COLON] = ACTIONS(2104),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2104),
    [anon_sym___declspec] = ACTIONS(2102),
    [anon_sym___based] = ACTIONS(2102),
    [anon_sym___cdecl] = ACTIONS(2102),
    [anon_sym___clrcall] = ACTIONS(2102),
    [anon_sym___stdcall] = ACTIONS(2102),
    [anon_sym___fastcall] = ACTIONS(2102),
    [anon_sym___thiscall] = ACTIONS(2102),
    [anon_sym___vectorcall] = ACTIONS(2102),
    [anon_sym_LBRACE] = ACTIONS(2104),
    [anon_sym_RBRACE] = ACTIONS(2104),
    [anon_sym_signed] = ACTIONS(2102),
    [anon_sym_unsigned] = ACTIONS(2102),
    [anon_sym_long] = ACTIONS(2102),
    [anon_sym_short] = ACTIONS(2102),
    [anon_sym_LBRACK] = ACTIONS(2102),
    [anon_sym_static] = ACTIONS(2102),
    [anon_sym_register] = ACTIONS(2102),
    [anon_sym_inline] = ACTIONS(2102),
    [anon_sym___inline] = ACTIONS(2102),
    [anon_sym___inline__] = ACTIONS(2102),
    [anon_sym___forceinline] = ACTIONS(2102),
    [anon_sym_thread_local] = ACTIONS(2102),
    [anon_sym___thread] = ACTIONS(2102),
    [anon_sym_const] = ACTIONS(2102),
    [anon_sym_constexpr] = ACTIONS(2102),
    [anon_sym_volatile] = ACTIONS(2102),
    [anon_sym_restrict] = ACTIONS(2102),
    [anon_sym___restrict__] = ACTIONS(2102),
    [anon_sym__Atomic] = ACTIONS(2102),
    [anon_sym__Noreturn] = ACTIONS(2102),
    [anon_sym_noreturn] = ACTIONS(2102),
    [anon_sym_mutable] = ACTIONS(2102),
    [anon_sym_constinit] = ACTIONS(2102),
    [anon_sym_consteval] = ACTIONS(2102),
    [anon_sym_alignas] = ACTIONS(2102),
    [anon_sym__Alignas] = ACTIONS(2102),
    [sym_primitive_type] = ACTIONS(2102),
    [anon_sym_enum] = ACTIONS(2102),
    [anon_sym_class] = ACTIONS(2102),
    [anon_sym_struct] = ACTIONS(2102),
    [anon_sym_union] = ACTIONS(2102),
    [anon_sym_if] = ACTIONS(2102),
    [anon_sym_else] = ACTIONS(2102),
    [anon_sym_switch] = ACTIONS(2102),
    [anon_sym_case] = ACTIONS(2102),
    [anon_sym_default] = ACTIONS(2102),
    [anon_sym_while] = ACTIONS(2102),
    [anon_sym_do] = ACTIONS(2102),
    [anon_sym_for] = ACTIONS(2102),
    [anon_sym_return] = ACTIONS(2102),
    [anon_sym_break] = ACTIONS(2102),
    [anon_sym_continue] = ACTIONS(2102),
    [anon_sym_goto] = ACTIONS(2102),
    [anon_sym___try] = ACTIONS(2102),
    [anon_sym___leave] = ACTIONS(2102),
    [anon_sym_not] = ACTIONS(2102),
    [anon_sym_compl] = ACTIONS(2102),
    [anon_sym_DASH_DASH] = ACTIONS(2104),
    [anon_sym_PLUS_PLUS] = ACTIONS(2104),
    [anon_sym_sizeof] = ACTIONS(2102),
    [anon_sym___alignof__] = ACTIONS(2102),
    [anon_sym___alignof] = ACTIONS(2102),
    [anon_sym__alignof] = ACTIONS(2102),
    [anon_sym_alignof] = ACTIONS(2102),
    [anon_sym__Alignof] = ACTIONS(2102),
    [anon_sym_offsetof] = ACTIONS(2102),
    [anon_sym__Generic] = ACTIONS(2102),
    [anon_sym_asm] = ACTIONS(2102),
    [anon_sym___asm__] = ACTIONS(2102),
    [sym_number_literal] = ACTIONS(2104),
    [anon_sym_L_SQUOTE] = ACTIONS(2104),
    [anon_sym_u_SQUOTE] = ACTIONS(2104),
    [anon_sym_U_SQUOTE] = ACTIONS(2104),
    [anon_sym_u8_SQUOTE] = ACTIONS(2104),
    [anon_sym_SQUOTE] = ACTIONS(2104),
    [anon_sym_L_DQUOTE] = ACTIONS(2104),
    [anon_sym_u_DQUOTE] = ACTIONS(2104),
    [anon_sym_U_DQUOTE] = ACTIONS(2104),
    [anon_sym_u8_DQUOTE] = ACTIONS(2104),
    [anon_sym_DQUOTE] = ACTIONS(2104),
    [sym_true] = ACTIONS(2102),
    [sym_false] = ACTIONS(2102),
    [anon_sym_NULL] = ACTIONS(2102),
    [anon_sym_nullptr] = ACTIONS(2102),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2102),
    [anon_sym_decltype] = ACTIONS(2102),
    [sym_virtual] = ACTIONS(2102),
    [anon_sym_explicit] = ACTIONS(2102),
    [anon_sym_typename] = ACTIONS(2102),
    [anon_sym_template] = ACTIONS(2102),
    [anon_sym_operator] = ACTIONS(2102),
    [anon_sym_try] = ACTIONS(2102),
    [anon_sym_delete] = ACTIONS(2102),
    [anon_sym_throw] = ACTIONS(2102),
    [anon_sym_namespace] = ACTIONS(2102),
    [anon_sym_using] = ACTIONS(2102),
    [anon_sym_static_assert] = ACTIONS(2102),
    [anon_sym_concept] = ACTIONS(2102),
    [anon_sym_co_return] = ACTIONS(2102),
    [anon_sym_co_yield] = ACTIONS(2102),
    [anon_sym_R_DQUOTE] = ACTIONS(2104),
    [anon_sym_LR_DQUOTE] = ACTIONS(2104),
    [anon_sym_uR_DQUOTE] = ACTIONS(2104),
    [anon_sym_UR_DQUOTE] = ACTIONS(2104),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2104),
    [anon_sym_co_await] = ACTIONS(2102),
    [anon_sym_new] = ACTIONS(2102),
    [anon_sym_requires] = ACTIONS(2102),
    [sym_this] = ACTIONS(2102),
    [anon_sym_discard] = ACTIONS(2102),
    [anon_sym_precise] = ACTIONS(2102),
    [anon_sym_shared] = ACTIONS(2102),
    [anon_sym_groupshared] = ACTIONS(2102),
    [anon_sym_uniform] = ACTIONS(2102),
    [anon_sym_row_major] = ACTIONS(2102),
    [anon_sym_column_major] = ACTIONS(2102),
    [anon_sym_globallycoherent] = ACTIONS(2102),
    [anon_sym_centroid] = ACTIONS(2102),
    [anon_sym_noperspective] = ACTIONS(2102),
    [anon_sym_nointerpolation] = ACTIONS(2102),
    [anon_sym_sample] = ACTIONS(2102),
    [anon_sym_linear] = ACTIONS(2102),
    [anon_sym_snorm] = ACTIONS(2102),
    [anon_sym_unorm] = ACTIONS(2102),
    [anon_sym_point] = ACTIONS(2102),
    [anon_sym_line] = ACTIONS(2102),
    [anon_sym_triangleadj] = ACTIONS(2102),
    [anon_sym_lineadj] = ACTIONS(2102),
    [anon_sym_triangle] = ACTIONS(2102),
    [anon_sym_cbuffer] = ACTIONS(2102),
  },
  [456] = {
    [sym_identifier] = ACTIONS(2106),
    [aux_sym_preproc_include_token1] = ACTIONS(2106),
    [aux_sym_preproc_def_token1] = ACTIONS(2106),
    [aux_sym_preproc_if_token1] = ACTIONS(2106),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2106),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2106),
    [sym_preproc_directive] = ACTIONS(2106),
    [anon_sym_LPAREN2] = ACTIONS(2108),
    [anon_sym_BANG] = ACTIONS(2108),
    [anon_sym_TILDE] = ACTIONS(2108),
    [anon_sym_DASH] = ACTIONS(2106),
    [anon_sym_PLUS] = ACTIONS(2106),
    [anon_sym_STAR] = ACTIONS(2108),
    [anon_sym_AMP_AMP] = ACTIONS(2108),
    [anon_sym_AMP] = ACTIONS(2106),
    [anon_sym_SEMI] = ACTIONS(2108),
    [anon_sym___extension__] = ACTIONS(2106),
    [anon_sym_typedef] = ACTIONS(2106),
    [anon_sym_in] = ACTIONS(2106),
    [anon_sym_out] = ACTIONS(2106),
    [anon_sym_inout] = ACTIONS(2106),
    [anon_sym_extern] = ACTIONS(2106),
    [anon_sym___attribute__] = ACTIONS(2106),
    [anon_sym_COLON_COLON] = ACTIONS(2108),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2108),
    [anon_sym___declspec] = ACTIONS(2106),
    [anon_sym___based] = ACTIONS(2106),
    [anon_sym___cdecl] = ACTIONS(2106),
    [anon_sym___clrcall] = ACTIONS(2106),
    [anon_sym___stdcall] = ACTIONS(2106),
    [anon_sym___fastcall] = ACTIONS(2106),
    [anon_sym___thiscall] = ACTIONS(2106),
    [anon_sym___vectorcall] = ACTIONS(2106),
    [anon_sym_LBRACE] = ACTIONS(2108),
    [anon_sym_RBRACE] = ACTIONS(2108),
    [anon_sym_signed] = ACTIONS(2106),
    [anon_sym_unsigned] = ACTIONS(2106),
    [anon_sym_long] = ACTIONS(2106),
    [anon_sym_short] = ACTIONS(2106),
    [anon_sym_LBRACK] = ACTIONS(2106),
    [anon_sym_static] = ACTIONS(2106),
    [anon_sym_register] = ACTIONS(2106),
    [anon_sym_inline] = ACTIONS(2106),
    [anon_sym___inline] = ACTIONS(2106),
    [anon_sym___inline__] = ACTIONS(2106),
    [anon_sym___forceinline] = ACTIONS(2106),
    [anon_sym_thread_local] = ACTIONS(2106),
    [anon_sym___thread] = ACTIONS(2106),
    [anon_sym_const] = ACTIONS(2106),
    [anon_sym_constexpr] = ACTIONS(2106),
    [anon_sym_volatile] = ACTIONS(2106),
    [anon_sym_restrict] = ACTIONS(2106),
    [anon_sym___restrict__] = ACTIONS(2106),
    [anon_sym__Atomic] = ACTIONS(2106),
    [anon_sym__Noreturn] = ACTIONS(2106),
    [anon_sym_noreturn] = ACTIONS(2106),
    [anon_sym_mutable] = ACTIONS(2106),
    [anon_sym_constinit] = ACTIONS(2106),
    [anon_sym_consteval] = ACTIONS(2106),
    [anon_sym_alignas] = ACTIONS(2106),
    [anon_sym__Alignas] = ACTIONS(2106),
    [sym_primitive_type] = ACTIONS(2106),
    [anon_sym_enum] = ACTIONS(2106),
    [anon_sym_class] = ACTIONS(2106),
    [anon_sym_struct] = ACTIONS(2106),
    [anon_sym_union] = ACTIONS(2106),
    [anon_sym_if] = ACTIONS(2106),
    [anon_sym_else] = ACTIONS(2106),
    [anon_sym_switch] = ACTIONS(2106),
    [anon_sym_case] = ACTIONS(2106),
    [anon_sym_default] = ACTIONS(2106),
    [anon_sym_while] = ACTIONS(2106),
    [anon_sym_do] = ACTIONS(2106),
    [anon_sym_for] = ACTIONS(2106),
    [anon_sym_return] = ACTIONS(2106),
    [anon_sym_break] = ACTIONS(2106),
    [anon_sym_continue] = ACTIONS(2106),
    [anon_sym_goto] = ACTIONS(2106),
    [anon_sym___try] = ACTIONS(2106),
    [anon_sym___leave] = ACTIONS(2106),
    [anon_sym_not] = ACTIONS(2106),
    [anon_sym_compl] = ACTIONS(2106),
    [anon_sym_DASH_DASH] = ACTIONS(2108),
    [anon_sym_PLUS_PLUS] = ACTIONS(2108),
    [anon_sym_sizeof] = ACTIONS(2106),
    [anon_sym___alignof__] = ACTIONS(2106),
    [anon_sym___alignof] = ACTIONS(2106),
    [anon_sym__alignof] = ACTIONS(2106),
    [anon_sym_alignof] = ACTIONS(2106),
    [anon_sym__Alignof] = ACTIONS(2106),
    [anon_sym_offsetof] = ACTIONS(2106),
    [anon_sym__Generic] = ACTIONS(2106),
    [anon_sym_asm] = ACTIONS(2106),
    [anon_sym___asm__] = ACTIONS(2106),
    [sym_number_literal] = ACTIONS(2108),
    [anon_sym_L_SQUOTE] = ACTIONS(2108),
    [anon_sym_u_SQUOTE] = ACTIONS(2108),
    [anon_sym_U_SQUOTE] = ACTIONS(2108),
    [anon_sym_u8_SQUOTE] = ACTIONS(2108),
    [anon_sym_SQUOTE] = ACTIONS(2108),
    [anon_sym_L_DQUOTE] = ACTIONS(2108),
    [anon_sym_u_DQUOTE] = ACTIONS(2108),
    [anon_sym_U_DQUOTE] = ACTIONS(2108),
    [anon_sym_u8_DQUOTE] = ACTIONS(2108),
    [anon_sym_DQUOTE] = ACTIONS(2108),
    [sym_true] = ACTIONS(2106),
    [sym_false] = ACTIONS(2106),
    [anon_sym_NULL] = ACTIONS(2106),
    [anon_sym_nullptr] = ACTIONS(2106),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2106),
    [anon_sym_decltype] = ACTIONS(2106),
    [sym_virtual] = ACTIONS(2106),
    [anon_sym_explicit] = ACTIONS(2106),
    [anon_sym_typename] = ACTIONS(2106),
    [anon_sym_template] = ACTIONS(2106),
    [anon_sym_operator] = ACTIONS(2106),
    [anon_sym_try] = ACTIONS(2106),
    [anon_sym_delete] = ACTIONS(2106),
    [anon_sym_throw] = ACTIONS(2106),
    [anon_sym_namespace] = ACTIONS(2106),
    [anon_sym_using] = ACTIONS(2106),
    [anon_sym_static_assert] = ACTIONS(2106),
    [anon_sym_concept] = ACTIONS(2106),
    [anon_sym_co_return] = ACTIONS(2106),
    [anon_sym_co_yield] = ACTIONS(2106),
    [anon_sym_R_DQUOTE] = ACTIONS(2108),
    [anon_sym_LR_DQUOTE] = ACTIONS(2108),
    [anon_sym_uR_DQUOTE] = ACTIONS(2108),
    [anon_sym_UR_DQUOTE] = ACTIONS(2108),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2108),
    [anon_sym_co_await] = ACTIONS(2106),
    [anon_sym_new] = ACTIONS(2106),
    [anon_sym_requires] = ACTIONS(2106),
    [sym_this] = ACTIONS(2106),
    [anon_sym_discard] = ACTIONS(2106),
    [anon_sym_precise] = ACTIONS(2106),
    [anon_sym_shared] = ACTIONS(2106),
    [anon_sym_groupshared] = ACTIONS(2106),
    [anon_sym_uniform] = ACTIONS(2106),
    [anon_sym_row_major] = ACTIONS(2106),
    [anon_sym_column_major] = ACTIONS(2106),
    [anon_sym_globallycoherent] = ACTIONS(2106),
    [anon_sym_centroid] = ACTIONS(2106),
    [anon_sym_noperspective] = ACTIONS(2106),
    [anon_sym_nointerpolation] = ACTIONS(2106),
    [anon_sym_sample] = ACTIONS(2106),
    [anon_sym_linear] = ACTIONS(2106),
    [anon_sym_snorm] = ACTIONS(2106),
    [anon_sym_unorm] = ACTIONS(2106),
    [anon_sym_point] = ACTIONS(2106),
    [anon_sym_line] = ACTIONS(2106),
    [anon_sym_triangleadj] = ACTIONS(2106),
    [anon_sym_lineadj] = ACTIONS(2106),
    [anon_sym_triangle] = ACTIONS(2106),
    [anon_sym_cbuffer] = ACTIONS(2106),
  },
  [457] = {
    [sym_identifier] = ACTIONS(2110),
    [aux_sym_preproc_include_token1] = ACTIONS(2110),
    [aux_sym_preproc_def_token1] = ACTIONS(2110),
    [aux_sym_preproc_if_token1] = ACTIONS(2110),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2110),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2110),
    [sym_preproc_directive] = ACTIONS(2110),
    [anon_sym_LPAREN2] = ACTIONS(2112),
    [anon_sym_BANG] = ACTIONS(2112),
    [anon_sym_TILDE] = ACTIONS(2112),
    [anon_sym_DASH] = ACTIONS(2110),
    [anon_sym_PLUS] = ACTIONS(2110),
    [anon_sym_STAR] = ACTIONS(2112),
    [anon_sym_AMP_AMP] = ACTIONS(2112),
    [anon_sym_AMP] = ACTIONS(2110),
    [anon_sym_SEMI] = ACTIONS(2112),
    [anon_sym___extension__] = ACTIONS(2110),
    [anon_sym_typedef] = ACTIONS(2110),
    [anon_sym_in] = ACTIONS(2110),
    [anon_sym_out] = ACTIONS(2110),
    [anon_sym_inout] = ACTIONS(2110),
    [anon_sym_extern] = ACTIONS(2110),
    [anon_sym___attribute__] = ACTIONS(2110),
    [anon_sym_COLON_COLON] = ACTIONS(2112),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2112),
    [anon_sym___declspec] = ACTIONS(2110),
    [anon_sym___based] = ACTIONS(2110),
    [anon_sym___cdecl] = ACTIONS(2110),
    [anon_sym___clrcall] = ACTIONS(2110),
    [anon_sym___stdcall] = ACTIONS(2110),
    [anon_sym___fastcall] = ACTIONS(2110),
    [anon_sym___thiscall] = ACTIONS(2110),
    [anon_sym___vectorcall] = ACTIONS(2110),
    [anon_sym_LBRACE] = ACTIONS(2112),
    [anon_sym_RBRACE] = ACTIONS(2112),
    [anon_sym_signed] = ACTIONS(2110),
    [anon_sym_unsigned] = ACTIONS(2110),
    [anon_sym_long] = ACTIONS(2110),
    [anon_sym_short] = ACTIONS(2110),
    [anon_sym_LBRACK] = ACTIONS(2110),
    [anon_sym_static] = ACTIONS(2110),
    [anon_sym_register] = ACTIONS(2110),
    [anon_sym_inline] = ACTIONS(2110),
    [anon_sym___inline] = ACTIONS(2110),
    [anon_sym___inline__] = ACTIONS(2110),
    [anon_sym___forceinline] = ACTIONS(2110),
    [anon_sym_thread_local] = ACTIONS(2110),
    [anon_sym___thread] = ACTIONS(2110),
    [anon_sym_const] = ACTIONS(2110),
    [anon_sym_constexpr] = ACTIONS(2110),
    [anon_sym_volatile] = ACTIONS(2110),
    [anon_sym_restrict] = ACTIONS(2110),
    [anon_sym___restrict__] = ACTIONS(2110),
    [anon_sym__Atomic] = ACTIONS(2110),
    [anon_sym__Noreturn] = ACTIONS(2110),
    [anon_sym_noreturn] = ACTIONS(2110),
    [anon_sym_mutable] = ACTIONS(2110),
    [anon_sym_constinit] = ACTIONS(2110),
    [anon_sym_consteval] = ACTIONS(2110),
    [anon_sym_alignas] = ACTIONS(2110),
    [anon_sym__Alignas] = ACTIONS(2110),
    [sym_primitive_type] = ACTIONS(2110),
    [anon_sym_enum] = ACTIONS(2110),
    [anon_sym_class] = ACTIONS(2110),
    [anon_sym_struct] = ACTIONS(2110),
    [anon_sym_union] = ACTIONS(2110),
    [anon_sym_if] = ACTIONS(2110),
    [anon_sym_else] = ACTIONS(2110),
    [anon_sym_switch] = ACTIONS(2110),
    [anon_sym_case] = ACTIONS(2110),
    [anon_sym_default] = ACTIONS(2110),
    [anon_sym_while] = ACTIONS(2110),
    [anon_sym_do] = ACTIONS(2110),
    [anon_sym_for] = ACTIONS(2110),
    [anon_sym_return] = ACTIONS(2110),
    [anon_sym_break] = ACTIONS(2110),
    [anon_sym_continue] = ACTIONS(2110),
    [anon_sym_goto] = ACTIONS(2110),
    [anon_sym___try] = ACTIONS(2110),
    [anon_sym___leave] = ACTIONS(2110),
    [anon_sym_not] = ACTIONS(2110),
    [anon_sym_compl] = ACTIONS(2110),
    [anon_sym_DASH_DASH] = ACTIONS(2112),
    [anon_sym_PLUS_PLUS] = ACTIONS(2112),
    [anon_sym_sizeof] = ACTIONS(2110),
    [anon_sym___alignof__] = ACTIONS(2110),
    [anon_sym___alignof] = ACTIONS(2110),
    [anon_sym__alignof] = ACTIONS(2110),
    [anon_sym_alignof] = ACTIONS(2110),
    [anon_sym__Alignof] = ACTIONS(2110),
    [anon_sym_offsetof] = ACTIONS(2110),
    [anon_sym__Generic] = ACTIONS(2110),
    [anon_sym_asm] = ACTIONS(2110),
    [anon_sym___asm__] = ACTIONS(2110),
    [sym_number_literal] = ACTIONS(2112),
    [anon_sym_L_SQUOTE] = ACTIONS(2112),
    [anon_sym_u_SQUOTE] = ACTIONS(2112),
    [anon_sym_U_SQUOTE] = ACTIONS(2112),
    [anon_sym_u8_SQUOTE] = ACTIONS(2112),
    [anon_sym_SQUOTE] = ACTIONS(2112),
    [anon_sym_L_DQUOTE] = ACTIONS(2112),
    [anon_sym_u_DQUOTE] = ACTIONS(2112),
    [anon_sym_U_DQUOTE] = ACTIONS(2112),
    [anon_sym_u8_DQUOTE] = ACTIONS(2112),
    [anon_sym_DQUOTE] = ACTIONS(2112),
    [sym_true] = ACTIONS(2110),
    [sym_false] = ACTIONS(2110),
    [anon_sym_NULL] = ACTIONS(2110),
    [anon_sym_nullptr] = ACTIONS(2110),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2110),
    [anon_sym_decltype] = ACTIONS(2110),
    [sym_virtual] = ACTIONS(2110),
    [anon_sym_explicit] = ACTIONS(2110),
    [anon_sym_typename] = ACTIONS(2110),
    [anon_sym_template] = ACTIONS(2110),
    [anon_sym_operator] = ACTIONS(2110),
    [anon_sym_try] = ACTIONS(2110),
    [anon_sym_delete] = ACTIONS(2110),
    [anon_sym_throw] = ACTIONS(2110),
    [anon_sym_namespace] = ACTIONS(2110),
    [anon_sym_using] = ACTIONS(2110),
    [anon_sym_static_assert] = ACTIONS(2110),
    [anon_sym_concept] = ACTIONS(2110),
    [anon_sym_co_return] = ACTIONS(2110),
    [anon_sym_co_yield] = ACTIONS(2110),
    [anon_sym_R_DQUOTE] = ACTIONS(2112),
    [anon_sym_LR_DQUOTE] = ACTIONS(2112),
    [anon_sym_uR_DQUOTE] = ACTIONS(2112),
    [anon_sym_UR_DQUOTE] = ACTIONS(2112),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2112),
    [anon_sym_co_await] = ACTIONS(2110),
    [anon_sym_new] = ACTIONS(2110),
    [anon_sym_requires] = ACTIONS(2110),
    [sym_this] = ACTIONS(2110),
    [anon_sym_discard] = ACTIONS(2110),
    [anon_sym_precise] = ACTIONS(2110),
    [anon_sym_shared] = ACTIONS(2110),
    [anon_sym_groupshared] = ACTIONS(2110),
    [anon_sym_uniform] = ACTIONS(2110),
    [anon_sym_row_major] = ACTIONS(2110),
    [anon_sym_column_major] = ACTIONS(2110),
    [anon_sym_globallycoherent] = ACTIONS(2110),
    [anon_sym_centroid] = ACTIONS(2110),
    [anon_sym_noperspective] = ACTIONS(2110),
    [anon_sym_nointerpolation] = ACTIONS(2110),
    [anon_sym_sample] = ACTIONS(2110),
    [anon_sym_linear] = ACTIONS(2110),
    [anon_sym_snorm] = ACTIONS(2110),
    [anon_sym_unorm] = ACTIONS(2110),
    [anon_sym_point] = ACTIONS(2110),
    [anon_sym_line] = ACTIONS(2110),
    [anon_sym_triangleadj] = ACTIONS(2110),
    [anon_sym_lineadj] = ACTIONS(2110),
    [anon_sym_triangle] = ACTIONS(2110),
    [anon_sym_cbuffer] = ACTIONS(2110),
  },
  [458] = {
    [sym_identifier] = ACTIONS(2114),
    [aux_sym_preproc_include_token1] = ACTIONS(2114),
    [aux_sym_preproc_def_token1] = ACTIONS(2114),
    [aux_sym_preproc_if_token1] = ACTIONS(2114),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2114),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2114),
    [sym_preproc_directive] = ACTIONS(2114),
    [anon_sym_LPAREN2] = ACTIONS(2116),
    [anon_sym_BANG] = ACTIONS(2116),
    [anon_sym_TILDE] = ACTIONS(2116),
    [anon_sym_DASH] = ACTIONS(2114),
    [anon_sym_PLUS] = ACTIONS(2114),
    [anon_sym_STAR] = ACTIONS(2116),
    [anon_sym_AMP_AMP] = ACTIONS(2116),
    [anon_sym_AMP] = ACTIONS(2114),
    [anon_sym_SEMI] = ACTIONS(2116),
    [anon_sym___extension__] = ACTIONS(2114),
    [anon_sym_typedef] = ACTIONS(2114),
    [anon_sym_in] = ACTIONS(2114),
    [anon_sym_out] = ACTIONS(2114),
    [anon_sym_inout] = ACTIONS(2114),
    [anon_sym_extern] = ACTIONS(2114),
    [anon_sym___attribute__] = ACTIONS(2114),
    [anon_sym_COLON_COLON] = ACTIONS(2116),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2116),
    [anon_sym___declspec] = ACTIONS(2114),
    [anon_sym___based] = ACTIONS(2114),
    [anon_sym___cdecl] = ACTIONS(2114),
    [anon_sym___clrcall] = ACTIONS(2114),
    [anon_sym___stdcall] = ACTIONS(2114),
    [anon_sym___fastcall] = ACTIONS(2114),
    [anon_sym___thiscall] = ACTIONS(2114),
    [anon_sym___vectorcall] = ACTIONS(2114),
    [anon_sym_LBRACE] = ACTIONS(2116),
    [anon_sym_RBRACE] = ACTIONS(2116),
    [anon_sym_signed] = ACTIONS(2114),
    [anon_sym_unsigned] = ACTIONS(2114),
    [anon_sym_long] = ACTIONS(2114),
    [anon_sym_short] = ACTIONS(2114),
    [anon_sym_LBRACK] = ACTIONS(2114),
    [anon_sym_static] = ACTIONS(2114),
    [anon_sym_register] = ACTIONS(2114),
    [anon_sym_inline] = ACTIONS(2114),
    [anon_sym___inline] = ACTIONS(2114),
    [anon_sym___inline__] = ACTIONS(2114),
    [anon_sym___forceinline] = ACTIONS(2114),
    [anon_sym_thread_local] = ACTIONS(2114),
    [anon_sym___thread] = ACTIONS(2114),
    [anon_sym_const] = ACTIONS(2114),
    [anon_sym_constexpr] = ACTIONS(2114),
    [anon_sym_volatile] = ACTIONS(2114),
    [anon_sym_restrict] = ACTIONS(2114),
    [anon_sym___restrict__] = ACTIONS(2114),
    [anon_sym__Atomic] = ACTIONS(2114),
    [anon_sym__Noreturn] = ACTIONS(2114),
    [anon_sym_noreturn] = ACTIONS(2114),
    [anon_sym_mutable] = ACTIONS(2114),
    [anon_sym_constinit] = ACTIONS(2114),
    [anon_sym_consteval] = ACTIONS(2114),
    [anon_sym_alignas] = ACTIONS(2114),
    [anon_sym__Alignas] = ACTIONS(2114),
    [sym_primitive_type] = ACTIONS(2114),
    [anon_sym_enum] = ACTIONS(2114),
    [anon_sym_class] = ACTIONS(2114),
    [anon_sym_struct] = ACTIONS(2114),
    [anon_sym_union] = ACTIONS(2114),
    [anon_sym_if] = ACTIONS(2114),
    [anon_sym_else] = ACTIONS(2114),
    [anon_sym_switch] = ACTIONS(2114),
    [anon_sym_case] = ACTIONS(2114),
    [anon_sym_default] = ACTIONS(2114),
    [anon_sym_while] = ACTIONS(2114),
    [anon_sym_do] = ACTIONS(2114),
    [anon_sym_for] = ACTIONS(2114),
    [anon_sym_return] = ACTIONS(2114),
    [anon_sym_break] = ACTIONS(2114),
    [anon_sym_continue] = ACTIONS(2114),
    [anon_sym_goto] = ACTIONS(2114),
    [anon_sym___try] = ACTIONS(2114),
    [anon_sym___leave] = ACTIONS(2114),
    [anon_sym_not] = ACTIONS(2114),
    [anon_sym_compl] = ACTIONS(2114),
    [anon_sym_DASH_DASH] = ACTIONS(2116),
    [anon_sym_PLUS_PLUS] = ACTIONS(2116),
    [anon_sym_sizeof] = ACTIONS(2114),
    [anon_sym___alignof__] = ACTIONS(2114),
    [anon_sym___alignof] = ACTIONS(2114),
    [anon_sym__alignof] = ACTIONS(2114),
    [anon_sym_alignof] = ACTIONS(2114),
    [anon_sym__Alignof] = ACTIONS(2114),
    [anon_sym_offsetof] = ACTIONS(2114),
    [anon_sym__Generic] = ACTIONS(2114),
    [anon_sym_asm] = ACTIONS(2114),
    [anon_sym___asm__] = ACTIONS(2114),
    [sym_number_literal] = ACTIONS(2116),
    [anon_sym_L_SQUOTE] = ACTIONS(2116),
    [anon_sym_u_SQUOTE] = ACTIONS(2116),
    [anon_sym_U_SQUOTE] = ACTIONS(2116),
    [anon_sym_u8_SQUOTE] = ACTIONS(2116),
    [anon_sym_SQUOTE] = ACTIONS(2116),
    [anon_sym_L_DQUOTE] = ACTIONS(2116),
    [anon_sym_u_DQUOTE] = ACTIONS(2116),
    [anon_sym_U_DQUOTE] = ACTIONS(2116),
    [anon_sym_u8_DQUOTE] = ACTIONS(2116),
    [anon_sym_DQUOTE] = ACTIONS(2116),
    [sym_true] = ACTIONS(2114),
    [sym_false] = ACTIONS(2114),
    [anon_sym_NULL] = ACTIONS(2114),
    [anon_sym_nullptr] = ACTIONS(2114),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2114),
    [anon_sym_decltype] = ACTIONS(2114),
    [sym_virtual] = ACTIONS(2114),
    [anon_sym_explicit] = ACTIONS(2114),
    [anon_sym_typename] = ACTIONS(2114),
    [anon_sym_template] = ACTIONS(2114),
    [anon_sym_operator] = ACTIONS(2114),
    [anon_sym_try] = ACTIONS(2114),
    [anon_sym_delete] = ACTIONS(2114),
    [anon_sym_throw] = ACTIONS(2114),
    [anon_sym_namespace] = ACTIONS(2114),
    [anon_sym_using] = ACTIONS(2114),
    [anon_sym_static_assert] = ACTIONS(2114),
    [anon_sym_concept] = ACTIONS(2114),
    [anon_sym_co_return] = ACTIONS(2114),
    [anon_sym_co_yield] = ACTIONS(2114),
    [anon_sym_R_DQUOTE] = ACTIONS(2116),
    [anon_sym_LR_DQUOTE] = ACTIONS(2116),
    [anon_sym_uR_DQUOTE] = ACTIONS(2116),
    [anon_sym_UR_DQUOTE] = ACTIONS(2116),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2116),
    [anon_sym_co_await] = ACTIONS(2114),
    [anon_sym_new] = ACTIONS(2114),
    [anon_sym_requires] = ACTIONS(2114),
    [sym_this] = ACTIONS(2114),
    [anon_sym_discard] = ACTIONS(2114),
    [anon_sym_precise] = ACTIONS(2114),
    [anon_sym_shared] = ACTIONS(2114),
    [anon_sym_groupshared] = ACTIONS(2114),
    [anon_sym_uniform] = ACTIONS(2114),
    [anon_sym_row_major] = ACTIONS(2114),
    [anon_sym_column_major] = ACTIONS(2114),
    [anon_sym_globallycoherent] = ACTIONS(2114),
    [anon_sym_centroid] = ACTIONS(2114),
    [anon_sym_noperspective] = ACTIONS(2114),
    [anon_sym_nointerpolation] = ACTIONS(2114),
    [anon_sym_sample] = ACTIONS(2114),
    [anon_sym_linear] = ACTIONS(2114),
    [anon_sym_snorm] = ACTIONS(2114),
    [anon_sym_unorm] = ACTIONS(2114),
    [anon_sym_point] = ACTIONS(2114),
    [anon_sym_line] = ACTIONS(2114),
    [anon_sym_triangleadj] = ACTIONS(2114),
    [anon_sym_lineadj] = ACTIONS(2114),
    [anon_sym_triangle] = ACTIONS(2114),
    [anon_sym_cbuffer] = ACTIONS(2114),
  },
  [459] = {
    [sym_identifier] = ACTIONS(2114),
    [aux_sym_preproc_include_token1] = ACTIONS(2114),
    [aux_sym_preproc_def_token1] = ACTIONS(2114),
    [aux_sym_preproc_if_token1] = ACTIONS(2114),
    [aux_sym_preproc_if_token2] = ACTIONS(2114),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2114),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2114),
    [sym_preproc_directive] = ACTIONS(2114),
    [anon_sym_LPAREN2] = ACTIONS(2116),
    [anon_sym_BANG] = ACTIONS(2116),
    [anon_sym_TILDE] = ACTIONS(2116),
    [anon_sym_DASH] = ACTIONS(2114),
    [anon_sym_PLUS] = ACTIONS(2114),
    [anon_sym_STAR] = ACTIONS(2116),
    [anon_sym_AMP_AMP] = ACTIONS(2116),
    [anon_sym_AMP] = ACTIONS(2114),
    [anon_sym_SEMI] = ACTIONS(2116),
    [anon_sym___extension__] = ACTIONS(2114),
    [anon_sym_typedef] = ACTIONS(2114),
    [anon_sym_in] = ACTIONS(2114),
    [anon_sym_out] = ACTIONS(2114),
    [anon_sym_inout] = ACTIONS(2114),
    [anon_sym_extern] = ACTIONS(2114),
    [anon_sym___attribute__] = ACTIONS(2114),
    [anon_sym_COLON_COLON] = ACTIONS(2116),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2116),
    [anon_sym___declspec] = ACTIONS(2114),
    [anon_sym___based] = ACTIONS(2114),
    [anon_sym___cdecl] = ACTIONS(2114),
    [anon_sym___clrcall] = ACTIONS(2114),
    [anon_sym___stdcall] = ACTIONS(2114),
    [anon_sym___fastcall] = ACTIONS(2114),
    [anon_sym___thiscall] = ACTIONS(2114),
    [anon_sym___vectorcall] = ACTIONS(2114),
    [anon_sym_LBRACE] = ACTIONS(2116),
    [anon_sym_signed] = ACTIONS(2114),
    [anon_sym_unsigned] = ACTIONS(2114),
    [anon_sym_long] = ACTIONS(2114),
    [anon_sym_short] = ACTIONS(2114),
    [anon_sym_LBRACK] = ACTIONS(2114),
    [anon_sym_static] = ACTIONS(2114),
    [anon_sym_register] = ACTIONS(2114),
    [anon_sym_inline] = ACTIONS(2114),
    [anon_sym___inline] = ACTIONS(2114),
    [anon_sym___inline__] = ACTIONS(2114),
    [anon_sym___forceinline] = ACTIONS(2114),
    [anon_sym_thread_local] = ACTIONS(2114),
    [anon_sym___thread] = ACTIONS(2114),
    [anon_sym_const] = ACTIONS(2114),
    [anon_sym_constexpr] = ACTIONS(2114),
    [anon_sym_volatile] = ACTIONS(2114),
    [anon_sym_restrict] = ACTIONS(2114),
    [anon_sym___restrict__] = ACTIONS(2114),
    [anon_sym__Atomic] = ACTIONS(2114),
    [anon_sym__Noreturn] = ACTIONS(2114),
    [anon_sym_noreturn] = ACTIONS(2114),
    [anon_sym_mutable] = ACTIONS(2114),
    [anon_sym_constinit] = ACTIONS(2114),
    [anon_sym_consteval] = ACTIONS(2114),
    [anon_sym_alignas] = ACTIONS(2114),
    [anon_sym__Alignas] = ACTIONS(2114),
    [sym_primitive_type] = ACTIONS(2114),
    [anon_sym_enum] = ACTIONS(2114),
    [anon_sym_class] = ACTIONS(2114),
    [anon_sym_struct] = ACTIONS(2114),
    [anon_sym_union] = ACTIONS(2114),
    [anon_sym_if] = ACTIONS(2114),
    [anon_sym_else] = ACTIONS(2114),
    [anon_sym_switch] = ACTIONS(2114),
    [anon_sym_case] = ACTIONS(2114),
    [anon_sym_default] = ACTIONS(2114),
    [anon_sym_while] = ACTIONS(2114),
    [anon_sym_do] = ACTIONS(2114),
    [anon_sym_for] = ACTIONS(2114),
    [anon_sym_return] = ACTIONS(2114),
    [anon_sym_break] = ACTIONS(2114),
    [anon_sym_continue] = ACTIONS(2114),
    [anon_sym_goto] = ACTIONS(2114),
    [anon_sym___try] = ACTIONS(2114),
    [anon_sym___leave] = ACTIONS(2114),
    [anon_sym_not] = ACTIONS(2114),
    [anon_sym_compl] = ACTIONS(2114),
    [anon_sym_DASH_DASH] = ACTIONS(2116),
    [anon_sym_PLUS_PLUS] = ACTIONS(2116),
    [anon_sym_sizeof] = ACTIONS(2114),
    [anon_sym___alignof__] = ACTIONS(2114),
    [anon_sym___alignof] = ACTIONS(2114),
    [anon_sym__alignof] = ACTIONS(2114),
    [anon_sym_alignof] = ACTIONS(2114),
    [anon_sym__Alignof] = ACTIONS(2114),
    [anon_sym_offsetof] = ACTIONS(2114),
    [anon_sym__Generic] = ACTIONS(2114),
    [anon_sym_asm] = ACTIONS(2114),
    [anon_sym___asm__] = ACTIONS(2114),
    [sym_number_literal] = ACTIONS(2116),
    [anon_sym_L_SQUOTE] = ACTIONS(2116),
    [anon_sym_u_SQUOTE] = ACTIONS(2116),
    [anon_sym_U_SQUOTE] = ACTIONS(2116),
    [anon_sym_u8_SQUOTE] = ACTIONS(2116),
    [anon_sym_SQUOTE] = ACTIONS(2116),
    [anon_sym_L_DQUOTE] = ACTIONS(2116),
    [anon_sym_u_DQUOTE] = ACTIONS(2116),
    [anon_sym_U_DQUOTE] = ACTIONS(2116),
    [anon_sym_u8_DQUOTE] = ACTIONS(2116),
    [anon_sym_DQUOTE] = ACTIONS(2116),
    [sym_true] = ACTIONS(2114),
    [sym_false] = ACTIONS(2114),
    [anon_sym_NULL] = ACTIONS(2114),
    [anon_sym_nullptr] = ACTIONS(2114),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2114),
    [anon_sym_decltype] = ACTIONS(2114),
    [sym_virtual] = ACTIONS(2114),
    [anon_sym_explicit] = ACTIONS(2114),
    [anon_sym_typename] = ACTIONS(2114),
    [anon_sym_template] = ACTIONS(2114),
    [anon_sym_operator] = ACTIONS(2114),
    [anon_sym_try] = ACTIONS(2114),
    [anon_sym_delete] = ACTIONS(2114),
    [anon_sym_throw] = ACTIONS(2114),
    [anon_sym_namespace] = ACTIONS(2114),
    [anon_sym_using] = ACTIONS(2114),
    [anon_sym_static_assert] = ACTIONS(2114),
    [anon_sym_concept] = ACTIONS(2114),
    [anon_sym_co_return] = ACTIONS(2114),
    [anon_sym_co_yield] = ACTIONS(2114),
    [anon_sym_R_DQUOTE] = ACTIONS(2116),
    [anon_sym_LR_DQUOTE] = ACTIONS(2116),
    [anon_sym_uR_DQUOTE] = ACTIONS(2116),
    [anon_sym_UR_DQUOTE] = ACTIONS(2116),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2116),
    [anon_sym_co_await] = ACTIONS(2114),
    [anon_sym_new] = ACTIONS(2114),
    [anon_sym_requires] = ACTIONS(2114),
    [sym_this] = ACTIONS(2114),
    [anon_sym_discard] = ACTIONS(2114),
    [anon_sym_precise] = ACTIONS(2114),
    [anon_sym_shared] = ACTIONS(2114),
    [anon_sym_groupshared] = ACTIONS(2114),
    [anon_sym_uniform] = ACTIONS(2114),
    [anon_sym_row_major] = ACTIONS(2114),
    [anon_sym_column_major] = ACTIONS(2114),
    [anon_sym_globallycoherent] = ACTIONS(2114),
    [anon_sym_centroid] = ACTIONS(2114),
    [anon_sym_noperspective] = ACTIONS(2114),
    [anon_sym_nointerpolation] = ACTIONS(2114),
    [anon_sym_sample] = ACTIONS(2114),
    [anon_sym_linear] = ACTIONS(2114),
    [anon_sym_snorm] = ACTIONS(2114),
    [anon_sym_unorm] = ACTIONS(2114),
    [anon_sym_point] = ACTIONS(2114),
    [anon_sym_line] = ACTIONS(2114),
    [anon_sym_triangleadj] = ACTIONS(2114),
    [anon_sym_lineadj] = ACTIONS(2114),
    [anon_sym_triangle] = ACTIONS(2114),
    [anon_sym_cbuffer] = ACTIONS(2114),
  },
  [460] = {
    [sym_identifier] = ACTIONS(2110),
    [aux_sym_preproc_include_token1] = ACTIONS(2110),
    [aux_sym_preproc_def_token1] = ACTIONS(2110),
    [aux_sym_preproc_if_token1] = ACTIONS(2110),
    [aux_sym_preproc_if_token2] = ACTIONS(2110),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2110),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2110),
    [sym_preproc_directive] = ACTIONS(2110),
    [anon_sym_LPAREN2] = ACTIONS(2112),
    [anon_sym_BANG] = ACTIONS(2112),
    [anon_sym_TILDE] = ACTIONS(2112),
    [anon_sym_DASH] = ACTIONS(2110),
    [anon_sym_PLUS] = ACTIONS(2110),
    [anon_sym_STAR] = ACTIONS(2112),
    [anon_sym_AMP_AMP] = ACTIONS(2112),
    [anon_sym_AMP] = ACTIONS(2110),
    [anon_sym_SEMI] = ACTIONS(2112),
    [anon_sym___extension__] = ACTIONS(2110),
    [anon_sym_typedef] = ACTIONS(2110),
    [anon_sym_in] = ACTIONS(2110),
    [anon_sym_out] = ACTIONS(2110),
    [anon_sym_inout] = ACTIONS(2110),
    [anon_sym_extern] = ACTIONS(2110),
    [anon_sym___attribute__] = ACTIONS(2110),
    [anon_sym_COLON_COLON] = ACTIONS(2112),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2112),
    [anon_sym___declspec] = ACTIONS(2110),
    [anon_sym___based] = ACTIONS(2110),
    [anon_sym___cdecl] = ACTIONS(2110),
    [anon_sym___clrcall] = ACTIONS(2110),
    [anon_sym___stdcall] = ACTIONS(2110),
    [anon_sym___fastcall] = ACTIONS(2110),
    [anon_sym___thiscall] = ACTIONS(2110),
    [anon_sym___vectorcall] = ACTIONS(2110),
    [anon_sym_LBRACE] = ACTIONS(2112),
    [anon_sym_signed] = ACTIONS(2110),
    [anon_sym_unsigned] = ACTIONS(2110),
    [anon_sym_long] = ACTIONS(2110),
    [anon_sym_short] = ACTIONS(2110),
    [anon_sym_LBRACK] = ACTIONS(2110),
    [anon_sym_static] = ACTIONS(2110),
    [anon_sym_register] = ACTIONS(2110),
    [anon_sym_inline] = ACTIONS(2110),
    [anon_sym___inline] = ACTIONS(2110),
    [anon_sym___inline__] = ACTIONS(2110),
    [anon_sym___forceinline] = ACTIONS(2110),
    [anon_sym_thread_local] = ACTIONS(2110),
    [anon_sym___thread] = ACTIONS(2110),
    [anon_sym_const] = ACTIONS(2110),
    [anon_sym_constexpr] = ACTIONS(2110),
    [anon_sym_volatile] = ACTIONS(2110),
    [anon_sym_restrict] = ACTIONS(2110),
    [anon_sym___restrict__] = ACTIONS(2110),
    [anon_sym__Atomic] = ACTIONS(2110),
    [anon_sym__Noreturn] = ACTIONS(2110),
    [anon_sym_noreturn] = ACTIONS(2110),
    [anon_sym_mutable] = ACTIONS(2110),
    [anon_sym_constinit] = ACTIONS(2110),
    [anon_sym_consteval] = ACTIONS(2110),
    [anon_sym_alignas] = ACTIONS(2110),
    [anon_sym__Alignas] = ACTIONS(2110),
    [sym_primitive_type] = ACTIONS(2110),
    [anon_sym_enum] = ACTIONS(2110),
    [anon_sym_class] = ACTIONS(2110),
    [anon_sym_struct] = ACTIONS(2110),
    [anon_sym_union] = ACTIONS(2110),
    [anon_sym_if] = ACTIONS(2110),
    [anon_sym_else] = ACTIONS(2110),
    [anon_sym_switch] = ACTIONS(2110),
    [anon_sym_case] = ACTIONS(2110),
    [anon_sym_default] = ACTIONS(2110),
    [anon_sym_while] = ACTIONS(2110),
    [anon_sym_do] = ACTIONS(2110),
    [anon_sym_for] = ACTIONS(2110),
    [anon_sym_return] = ACTIONS(2110),
    [anon_sym_break] = ACTIONS(2110),
    [anon_sym_continue] = ACTIONS(2110),
    [anon_sym_goto] = ACTIONS(2110),
    [anon_sym___try] = ACTIONS(2110),
    [anon_sym___leave] = ACTIONS(2110),
    [anon_sym_not] = ACTIONS(2110),
    [anon_sym_compl] = ACTIONS(2110),
    [anon_sym_DASH_DASH] = ACTIONS(2112),
    [anon_sym_PLUS_PLUS] = ACTIONS(2112),
    [anon_sym_sizeof] = ACTIONS(2110),
    [anon_sym___alignof__] = ACTIONS(2110),
    [anon_sym___alignof] = ACTIONS(2110),
    [anon_sym__alignof] = ACTIONS(2110),
    [anon_sym_alignof] = ACTIONS(2110),
    [anon_sym__Alignof] = ACTIONS(2110),
    [anon_sym_offsetof] = ACTIONS(2110),
    [anon_sym__Generic] = ACTIONS(2110),
    [anon_sym_asm] = ACTIONS(2110),
    [anon_sym___asm__] = ACTIONS(2110),
    [sym_number_literal] = ACTIONS(2112),
    [anon_sym_L_SQUOTE] = ACTIONS(2112),
    [anon_sym_u_SQUOTE] = ACTIONS(2112),
    [anon_sym_U_SQUOTE] = ACTIONS(2112),
    [anon_sym_u8_SQUOTE] = ACTIONS(2112),
    [anon_sym_SQUOTE] = ACTIONS(2112),
    [anon_sym_L_DQUOTE] = ACTIONS(2112),
    [anon_sym_u_DQUOTE] = ACTIONS(2112),
    [anon_sym_U_DQUOTE] = ACTIONS(2112),
    [anon_sym_u8_DQUOTE] = ACTIONS(2112),
    [anon_sym_DQUOTE] = ACTIONS(2112),
    [sym_true] = ACTIONS(2110),
    [sym_false] = ACTIONS(2110),
    [anon_sym_NULL] = ACTIONS(2110),
    [anon_sym_nullptr] = ACTIONS(2110),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2110),
    [anon_sym_decltype] = ACTIONS(2110),
    [sym_virtual] = ACTIONS(2110),
    [anon_sym_explicit] = ACTIONS(2110),
    [anon_sym_typename] = ACTIONS(2110),
    [anon_sym_template] = ACTIONS(2110),
    [anon_sym_operator] = ACTIONS(2110),
    [anon_sym_try] = ACTIONS(2110),
    [anon_sym_delete] = ACTIONS(2110),
    [anon_sym_throw] = ACTIONS(2110),
    [anon_sym_namespace] = ACTIONS(2110),
    [anon_sym_using] = ACTIONS(2110),
    [anon_sym_static_assert] = ACTIONS(2110),
    [anon_sym_concept] = ACTIONS(2110),
    [anon_sym_co_return] = ACTIONS(2110),
    [anon_sym_co_yield] = ACTIONS(2110),
    [anon_sym_R_DQUOTE] = ACTIONS(2112),
    [anon_sym_LR_DQUOTE] = ACTIONS(2112),
    [anon_sym_uR_DQUOTE] = ACTIONS(2112),
    [anon_sym_UR_DQUOTE] = ACTIONS(2112),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2112),
    [anon_sym_co_await] = ACTIONS(2110),
    [anon_sym_new] = ACTIONS(2110),
    [anon_sym_requires] = ACTIONS(2110),
    [sym_this] = ACTIONS(2110),
    [anon_sym_discard] = ACTIONS(2110),
    [anon_sym_precise] = ACTIONS(2110),
    [anon_sym_shared] = ACTIONS(2110),
    [anon_sym_groupshared] = ACTIONS(2110),
    [anon_sym_uniform] = ACTIONS(2110),
    [anon_sym_row_major] = ACTIONS(2110),
    [anon_sym_column_major] = ACTIONS(2110),
    [anon_sym_globallycoherent] = ACTIONS(2110),
    [anon_sym_centroid] = ACTIONS(2110),
    [anon_sym_noperspective] = ACTIONS(2110),
    [anon_sym_nointerpolation] = ACTIONS(2110),
    [anon_sym_sample] = ACTIONS(2110),
    [anon_sym_linear] = ACTIONS(2110),
    [anon_sym_snorm] = ACTIONS(2110),
    [anon_sym_unorm] = ACTIONS(2110),
    [anon_sym_point] = ACTIONS(2110),
    [anon_sym_line] = ACTIONS(2110),
    [anon_sym_triangleadj] = ACTIONS(2110),
    [anon_sym_lineadj] = ACTIONS(2110),
    [anon_sym_triangle] = ACTIONS(2110),
    [anon_sym_cbuffer] = ACTIONS(2110),
  },
  [461] = {
    [sym_identifier] = ACTIONS(2106),
    [aux_sym_preproc_include_token1] = ACTIONS(2106),
    [aux_sym_preproc_def_token1] = ACTIONS(2106),
    [aux_sym_preproc_if_token1] = ACTIONS(2106),
    [aux_sym_preproc_if_token2] = ACTIONS(2106),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2106),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2106),
    [sym_preproc_directive] = ACTIONS(2106),
    [anon_sym_LPAREN2] = ACTIONS(2108),
    [anon_sym_BANG] = ACTIONS(2108),
    [anon_sym_TILDE] = ACTIONS(2108),
    [anon_sym_DASH] = ACTIONS(2106),
    [anon_sym_PLUS] = ACTIONS(2106),
    [anon_sym_STAR] = ACTIONS(2108),
    [anon_sym_AMP_AMP] = ACTIONS(2108),
    [anon_sym_AMP] = ACTIONS(2106),
    [anon_sym_SEMI] = ACTIONS(2108),
    [anon_sym___extension__] = ACTIONS(2106),
    [anon_sym_typedef] = ACTIONS(2106),
    [anon_sym_in] = ACTIONS(2106),
    [anon_sym_out] = ACTIONS(2106),
    [anon_sym_inout] = ACTIONS(2106),
    [anon_sym_extern] = ACTIONS(2106),
    [anon_sym___attribute__] = ACTIONS(2106),
    [anon_sym_COLON_COLON] = ACTIONS(2108),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2108),
    [anon_sym___declspec] = ACTIONS(2106),
    [anon_sym___based] = ACTIONS(2106),
    [anon_sym___cdecl] = ACTIONS(2106),
    [anon_sym___clrcall] = ACTIONS(2106),
    [anon_sym___stdcall] = ACTIONS(2106),
    [anon_sym___fastcall] = ACTIONS(2106),
    [anon_sym___thiscall] = ACTIONS(2106),
    [anon_sym___vectorcall] = ACTIONS(2106),
    [anon_sym_LBRACE] = ACTIONS(2108),
    [anon_sym_signed] = ACTIONS(2106),
    [anon_sym_unsigned] = ACTIONS(2106),
    [anon_sym_long] = ACTIONS(2106),
    [anon_sym_short] = ACTIONS(2106),
    [anon_sym_LBRACK] = ACTIONS(2106),
    [anon_sym_static] = ACTIONS(2106),
    [anon_sym_register] = ACTIONS(2106),
    [anon_sym_inline] = ACTIONS(2106),
    [anon_sym___inline] = ACTIONS(2106),
    [anon_sym___inline__] = ACTIONS(2106),
    [anon_sym___forceinline] = ACTIONS(2106),
    [anon_sym_thread_local] = ACTIONS(2106),
    [anon_sym___thread] = ACTIONS(2106),
    [anon_sym_const] = ACTIONS(2106),
    [anon_sym_constexpr] = ACTIONS(2106),
    [anon_sym_volatile] = ACTIONS(2106),
    [anon_sym_restrict] = ACTIONS(2106),
    [anon_sym___restrict__] = ACTIONS(2106),
    [anon_sym__Atomic] = ACTIONS(2106),
    [anon_sym__Noreturn] = ACTIONS(2106),
    [anon_sym_noreturn] = ACTIONS(2106),
    [anon_sym_mutable] = ACTIONS(2106),
    [anon_sym_constinit] = ACTIONS(2106),
    [anon_sym_consteval] = ACTIONS(2106),
    [anon_sym_alignas] = ACTIONS(2106),
    [anon_sym__Alignas] = ACTIONS(2106),
    [sym_primitive_type] = ACTIONS(2106),
    [anon_sym_enum] = ACTIONS(2106),
    [anon_sym_class] = ACTIONS(2106),
    [anon_sym_struct] = ACTIONS(2106),
    [anon_sym_union] = ACTIONS(2106),
    [anon_sym_if] = ACTIONS(2106),
    [anon_sym_else] = ACTIONS(2106),
    [anon_sym_switch] = ACTIONS(2106),
    [anon_sym_case] = ACTIONS(2106),
    [anon_sym_default] = ACTIONS(2106),
    [anon_sym_while] = ACTIONS(2106),
    [anon_sym_do] = ACTIONS(2106),
    [anon_sym_for] = ACTIONS(2106),
    [anon_sym_return] = ACTIONS(2106),
    [anon_sym_break] = ACTIONS(2106),
    [anon_sym_continue] = ACTIONS(2106),
    [anon_sym_goto] = ACTIONS(2106),
    [anon_sym___try] = ACTIONS(2106),
    [anon_sym___leave] = ACTIONS(2106),
    [anon_sym_not] = ACTIONS(2106),
    [anon_sym_compl] = ACTIONS(2106),
    [anon_sym_DASH_DASH] = ACTIONS(2108),
    [anon_sym_PLUS_PLUS] = ACTIONS(2108),
    [anon_sym_sizeof] = ACTIONS(2106),
    [anon_sym___alignof__] = ACTIONS(2106),
    [anon_sym___alignof] = ACTIONS(2106),
    [anon_sym__alignof] = ACTIONS(2106),
    [anon_sym_alignof] = ACTIONS(2106),
    [anon_sym__Alignof] = ACTIONS(2106),
    [anon_sym_offsetof] = ACTIONS(2106),
    [anon_sym__Generic] = ACTIONS(2106),
    [anon_sym_asm] = ACTIONS(2106),
    [anon_sym___asm__] = ACTIONS(2106),
    [sym_number_literal] = ACTIONS(2108),
    [anon_sym_L_SQUOTE] = ACTIONS(2108),
    [anon_sym_u_SQUOTE] = ACTIONS(2108),
    [anon_sym_U_SQUOTE] = ACTIONS(2108),
    [anon_sym_u8_SQUOTE] = ACTIONS(2108),
    [anon_sym_SQUOTE] = ACTIONS(2108),
    [anon_sym_L_DQUOTE] = ACTIONS(2108),
    [anon_sym_u_DQUOTE] = ACTIONS(2108),
    [anon_sym_U_DQUOTE] = ACTIONS(2108),
    [anon_sym_u8_DQUOTE] = ACTIONS(2108),
    [anon_sym_DQUOTE] = ACTIONS(2108),
    [sym_true] = ACTIONS(2106),
    [sym_false] = ACTIONS(2106),
    [anon_sym_NULL] = ACTIONS(2106),
    [anon_sym_nullptr] = ACTIONS(2106),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2106),
    [anon_sym_decltype] = ACTIONS(2106),
    [sym_virtual] = ACTIONS(2106),
    [anon_sym_explicit] = ACTIONS(2106),
    [anon_sym_typename] = ACTIONS(2106),
    [anon_sym_template] = ACTIONS(2106),
    [anon_sym_operator] = ACTIONS(2106),
    [anon_sym_try] = ACTIONS(2106),
    [anon_sym_delete] = ACTIONS(2106),
    [anon_sym_throw] = ACTIONS(2106),
    [anon_sym_namespace] = ACTIONS(2106),
    [anon_sym_using] = ACTIONS(2106),
    [anon_sym_static_assert] = ACTIONS(2106),
    [anon_sym_concept] = ACTIONS(2106),
    [anon_sym_co_return] = ACTIONS(2106),
    [anon_sym_co_yield] = ACTIONS(2106),
    [anon_sym_R_DQUOTE] = ACTIONS(2108),
    [anon_sym_LR_DQUOTE] = ACTIONS(2108),
    [anon_sym_uR_DQUOTE] = ACTIONS(2108),
    [anon_sym_UR_DQUOTE] = ACTIONS(2108),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2108),
    [anon_sym_co_await] = ACTIONS(2106),
    [anon_sym_new] = ACTIONS(2106),
    [anon_sym_requires] = ACTIONS(2106),
    [sym_this] = ACTIONS(2106),
    [anon_sym_discard] = ACTIONS(2106),
    [anon_sym_precise] = ACTIONS(2106),
    [anon_sym_shared] = ACTIONS(2106),
    [anon_sym_groupshared] = ACTIONS(2106),
    [anon_sym_uniform] = ACTIONS(2106),
    [anon_sym_row_major] = ACTIONS(2106),
    [anon_sym_column_major] = ACTIONS(2106),
    [anon_sym_globallycoherent] = ACTIONS(2106),
    [anon_sym_centroid] = ACTIONS(2106),
    [anon_sym_noperspective] = ACTIONS(2106),
    [anon_sym_nointerpolation] = ACTIONS(2106),
    [anon_sym_sample] = ACTIONS(2106),
    [anon_sym_linear] = ACTIONS(2106),
    [anon_sym_snorm] = ACTIONS(2106),
    [anon_sym_unorm] = ACTIONS(2106),
    [anon_sym_point] = ACTIONS(2106),
    [anon_sym_line] = ACTIONS(2106),
    [anon_sym_triangleadj] = ACTIONS(2106),
    [anon_sym_lineadj] = ACTIONS(2106),
    [anon_sym_triangle] = ACTIONS(2106),
    [anon_sym_cbuffer] = ACTIONS(2106),
  },
  [462] = {
    [sym_identifier] = ACTIONS(2102),
    [aux_sym_preproc_include_token1] = ACTIONS(2102),
    [aux_sym_preproc_def_token1] = ACTIONS(2102),
    [aux_sym_preproc_if_token1] = ACTIONS(2102),
    [aux_sym_preproc_if_token2] = ACTIONS(2102),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2102),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2102),
    [sym_preproc_directive] = ACTIONS(2102),
    [anon_sym_LPAREN2] = ACTIONS(2104),
    [anon_sym_BANG] = ACTIONS(2104),
    [anon_sym_TILDE] = ACTIONS(2104),
    [anon_sym_DASH] = ACTIONS(2102),
    [anon_sym_PLUS] = ACTIONS(2102),
    [anon_sym_STAR] = ACTIONS(2104),
    [anon_sym_AMP_AMP] = ACTIONS(2104),
    [anon_sym_AMP] = ACTIONS(2102),
    [anon_sym_SEMI] = ACTIONS(2104),
    [anon_sym___extension__] = ACTIONS(2102),
    [anon_sym_typedef] = ACTIONS(2102),
    [anon_sym_in] = ACTIONS(2102),
    [anon_sym_out] = ACTIONS(2102),
    [anon_sym_inout] = ACTIONS(2102),
    [anon_sym_extern] = ACTIONS(2102),
    [anon_sym___attribute__] = ACTIONS(2102),
    [anon_sym_COLON_COLON] = ACTIONS(2104),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2104),
    [anon_sym___declspec] = ACTIONS(2102),
    [anon_sym___based] = ACTIONS(2102),
    [anon_sym___cdecl] = ACTIONS(2102),
    [anon_sym___clrcall] = ACTIONS(2102),
    [anon_sym___stdcall] = ACTIONS(2102),
    [anon_sym___fastcall] = ACTIONS(2102),
    [anon_sym___thiscall] = ACTIONS(2102),
    [anon_sym___vectorcall] = ACTIONS(2102),
    [anon_sym_LBRACE] = ACTIONS(2104),
    [anon_sym_signed] = ACTIONS(2102),
    [anon_sym_unsigned] = ACTIONS(2102),
    [anon_sym_long] = ACTIONS(2102),
    [anon_sym_short] = ACTIONS(2102),
    [anon_sym_LBRACK] = ACTIONS(2102),
    [anon_sym_static] = ACTIONS(2102),
    [anon_sym_register] = ACTIONS(2102),
    [anon_sym_inline] = ACTIONS(2102),
    [anon_sym___inline] = ACTIONS(2102),
    [anon_sym___inline__] = ACTIONS(2102),
    [anon_sym___forceinline] = ACTIONS(2102),
    [anon_sym_thread_local] = ACTIONS(2102),
    [anon_sym___thread] = ACTIONS(2102),
    [anon_sym_const] = ACTIONS(2102),
    [anon_sym_constexpr] = ACTIONS(2102),
    [anon_sym_volatile] = ACTIONS(2102),
    [anon_sym_restrict] = ACTIONS(2102),
    [anon_sym___restrict__] = ACTIONS(2102),
    [anon_sym__Atomic] = ACTIONS(2102),
    [anon_sym__Noreturn] = ACTIONS(2102),
    [anon_sym_noreturn] = ACTIONS(2102),
    [anon_sym_mutable] = ACTIONS(2102),
    [anon_sym_constinit] = ACTIONS(2102),
    [anon_sym_consteval] = ACTIONS(2102),
    [anon_sym_alignas] = ACTIONS(2102),
    [anon_sym__Alignas] = ACTIONS(2102),
    [sym_primitive_type] = ACTIONS(2102),
    [anon_sym_enum] = ACTIONS(2102),
    [anon_sym_class] = ACTIONS(2102),
    [anon_sym_struct] = ACTIONS(2102),
    [anon_sym_union] = ACTIONS(2102),
    [anon_sym_if] = ACTIONS(2102),
    [anon_sym_else] = ACTIONS(2102),
    [anon_sym_switch] = ACTIONS(2102),
    [anon_sym_case] = ACTIONS(2102),
    [anon_sym_default] = ACTIONS(2102),
    [anon_sym_while] = ACTIONS(2102),
    [anon_sym_do] = ACTIONS(2102),
    [anon_sym_for] = ACTIONS(2102),
    [anon_sym_return] = ACTIONS(2102),
    [anon_sym_break] = ACTIONS(2102),
    [anon_sym_continue] = ACTIONS(2102),
    [anon_sym_goto] = ACTIONS(2102),
    [anon_sym___try] = ACTIONS(2102),
    [anon_sym___leave] = ACTIONS(2102),
    [anon_sym_not] = ACTIONS(2102),
    [anon_sym_compl] = ACTIONS(2102),
    [anon_sym_DASH_DASH] = ACTIONS(2104),
    [anon_sym_PLUS_PLUS] = ACTIONS(2104),
    [anon_sym_sizeof] = ACTIONS(2102),
    [anon_sym___alignof__] = ACTIONS(2102),
    [anon_sym___alignof] = ACTIONS(2102),
    [anon_sym__alignof] = ACTIONS(2102),
    [anon_sym_alignof] = ACTIONS(2102),
    [anon_sym__Alignof] = ACTIONS(2102),
    [anon_sym_offsetof] = ACTIONS(2102),
    [anon_sym__Generic] = ACTIONS(2102),
    [anon_sym_asm] = ACTIONS(2102),
    [anon_sym___asm__] = ACTIONS(2102),
    [sym_number_literal] = ACTIONS(2104),
    [anon_sym_L_SQUOTE] = ACTIONS(2104),
    [anon_sym_u_SQUOTE] = ACTIONS(2104),
    [anon_sym_U_SQUOTE] = ACTIONS(2104),
    [anon_sym_u8_SQUOTE] = ACTIONS(2104),
    [anon_sym_SQUOTE] = ACTIONS(2104),
    [anon_sym_L_DQUOTE] = ACTIONS(2104),
    [anon_sym_u_DQUOTE] = ACTIONS(2104),
    [anon_sym_U_DQUOTE] = ACTIONS(2104),
    [anon_sym_u8_DQUOTE] = ACTIONS(2104),
    [anon_sym_DQUOTE] = ACTIONS(2104),
    [sym_true] = ACTIONS(2102),
    [sym_false] = ACTIONS(2102),
    [anon_sym_NULL] = ACTIONS(2102),
    [anon_sym_nullptr] = ACTIONS(2102),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2102),
    [anon_sym_decltype] = ACTIONS(2102),
    [sym_virtual] = ACTIONS(2102),
    [anon_sym_explicit] = ACTIONS(2102),
    [anon_sym_typename] = ACTIONS(2102),
    [anon_sym_template] = ACTIONS(2102),
    [anon_sym_operator] = ACTIONS(2102),
    [anon_sym_try] = ACTIONS(2102),
    [anon_sym_delete] = ACTIONS(2102),
    [anon_sym_throw] = ACTIONS(2102),
    [anon_sym_namespace] = ACTIONS(2102),
    [anon_sym_using] = ACTIONS(2102),
    [anon_sym_static_assert] = ACTIONS(2102),
    [anon_sym_concept] = ACTIONS(2102),
    [anon_sym_co_return] = ACTIONS(2102),
    [anon_sym_co_yield] = ACTIONS(2102),
    [anon_sym_R_DQUOTE] = ACTIONS(2104),
    [anon_sym_LR_DQUOTE] = ACTIONS(2104),
    [anon_sym_uR_DQUOTE] = ACTIONS(2104),
    [anon_sym_UR_DQUOTE] = ACTIONS(2104),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2104),
    [anon_sym_co_await] = ACTIONS(2102),
    [anon_sym_new] = ACTIONS(2102),
    [anon_sym_requires] = ACTIONS(2102),
    [sym_this] = ACTIONS(2102),
    [anon_sym_discard] = ACTIONS(2102),
    [anon_sym_precise] = ACTIONS(2102),
    [anon_sym_shared] = ACTIONS(2102),
    [anon_sym_groupshared] = ACTIONS(2102),
    [anon_sym_uniform] = ACTIONS(2102),
    [anon_sym_row_major] = ACTIONS(2102),
    [anon_sym_column_major] = ACTIONS(2102),
    [anon_sym_globallycoherent] = ACTIONS(2102),
    [anon_sym_centroid] = ACTIONS(2102),
    [anon_sym_noperspective] = ACTIONS(2102),
    [anon_sym_nointerpolation] = ACTIONS(2102),
    [anon_sym_sample] = ACTIONS(2102),
    [anon_sym_linear] = ACTIONS(2102),
    [anon_sym_snorm] = ACTIONS(2102),
    [anon_sym_unorm] = ACTIONS(2102),
    [anon_sym_point] = ACTIONS(2102),
    [anon_sym_line] = ACTIONS(2102),
    [anon_sym_triangleadj] = ACTIONS(2102),
    [anon_sym_lineadj] = ACTIONS(2102),
    [anon_sym_triangle] = ACTIONS(2102),
    [anon_sym_cbuffer] = ACTIONS(2102),
  },
  [463] = {
    [sym_identifier] = ACTIONS(2280),
    [aux_sym_preproc_include_token1] = ACTIONS(2280),
    [aux_sym_preproc_def_token1] = ACTIONS(2280),
    [aux_sym_preproc_if_token1] = ACTIONS(2280),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2280),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2280),
    [sym_preproc_directive] = ACTIONS(2280),
    [anon_sym_LPAREN2] = ACTIONS(2282),
    [anon_sym_BANG] = ACTIONS(2282),
    [anon_sym_TILDE] = ACTIONS(2282),
    [anon_sym_DASH] = ACTIONS(2280),
    [anon_sym_PLUS] = ACTIONS(2280),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_AMP_AMP] = ACTIONS(2282),
    [anon_sym_AMP] = ACTIONS(2280),
    [anon_sym_SEMI] = ACTIONS(2282),
    [anon_sym___extension__] = ACTIONS(2280),
    [anon_sym_typedef] = ACTIONS(2280),
    [anon_sym_in] = ACTIONS(2280),
    [anon_sym_out] = ACTIONS(2280),
    [anon_sym_inout] = ACTIONS(2280),
    [anon_sym_extern] = ACTIONS(2280),
    [anon_sym___attribute__] = ACTIONS(2280),
    [anon_sym_COLON_COLON] = ACTIONS(2282),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2282),
    [anon_sym___declspec] = ACTIONS(2280),
    [anon_sym___based] = ACTIONS(2280),
    [anon_sym___cdecl] = ACTIONS(2280),
    [anon_sym___clrcall] = ACTIONS(2280),
    [anon_sym___stdcall] = ACTIONS(2280),
    [anon_sym___fastcall] = ACTIONS(2280),
    [anon_sym___thiscall] = ACTIONS(2280),
    [anon_sym___vectorcall] = ACTIONS(2280),
    [anon_sym_LBRACE] = ACTIONS(2282),
    [anon_sym_RBRACE] = ACTIONS(2282),
    [anon_sym_signed] = ACTIONS(2280),
    [anon_sym_unsigned] = ACTIONS(2280),
    [anon_sym_long] = ACTIONS(2280),
    [anon_sym_short] = ACTIONS(2280),
    [anon_sym_LBRACK] = ACTIONS(2280),
    [anon_sym_static] = ACTIONS(2280),
    [anon_sym_register] = ACTIONS(2280),
    [anon_sym_inline] = ACTIONS(2280),
    [anon_sym___inline] = ACTIONS(2280),
    [anon_sym___inline__] = ACTIONS(2280),
    [anon_sym___forceinline] = ACTIONS(2280),
    [anon_sym_thread_local] = ACTIONS(2280),
    [anon_sym___thread] = ACTIONS(2280),
    [anon_sym_const] = ACTIONS(2280),
    [anon_sym_constexpr] = ACTIONS(2280),
    [anon_sym_volatile] = ACTIONS(2280),
    [anon_sym_restrict] = ACTIONS(2280),
    [anon_sym___restrict__] = ACTIONS(2280),
    [anon_sym__Atomic] = ACTIONS(2280),
    [anon_sym__Noreturn] = ACTIONS(2280),
    [anon_sym_noreturn] = ACTIONS(2280),
    [anon_sym_mutable] = ACTIONS(2280),
    [anon_sym_constinit] = ACTIONS(2280),
    [anon_sym_consteval] = ACTIONS(2280),
    [anon_sym_alignas] = ACTIONS(2280),
    [anon_sym__Alignas] = ACTIONS(2280),
    [sym_primitive_type] = ACTIONS(2280),
    [anon_sym_enum] = ACTIONS(2280),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2280),
    [anon_sym_union] = ACTIONS(2280),
    [anon_sym_if] = ACTIONS(2280),
    [anon_sym_else] = ACTIONS(2280),
    [anon_sym_switch] = ACTIONS(2280),
    [anon_sym_case] = ACTIONS(2280),
    [anon_sym_default] = ACTIONS(2280),
    [anon_sym_while] = ACTIONS(2280),
    [anon_sym_do] = ACTIONS(2280),
    [anon_sym_for] = ACTIONS(2280),
    [anon_sym_return] = ACTIONS(2280),
    [anon_sym_break] = ACTIONS(2280),
    [anon_sym_continue] = ACTIONS(2280),
    [anon_sym_goto] = ACTIONS(2280),
    [anon_sym___try] = ACTIONS(2280),
    [anon_sym___leave] = ACTIONS(2280),
    [anon_sym_not] = ACTIONS(2280),
    [anon_sym_compl] = ACTIONS(2280),
    [anon_sym_DASH_DASH] = ACTIONS(2282),
    [anon_sym_PLUS_PLUS] = ACTIONS(2282),
    [anon_sym_sizeof] = ACTIONS(2280),
    [anon_sym___alignof__] = ACTIONS(2280),
    [anon_sym___alignof] = ACTIONS(2280),
    [anon_sym__alignof] = ACTIONS(2280),
    [anon_sym_alignof] = ACTIONS(2280),
    [anon_sym__Alignof] = ACTIONS(2280),
    [anon_sym_offsetof] = ACTIONS(2280),
    [anon_sym__Generic] = ACTIONS(2280),
    [anon_sym_asm] = ACTIONS(2280),
    [anon_sym___asm__] = ACTIONS(2280),
    [sym_number_literal] = ACTIONS(2282),
    [anon_sym_L_SQUOTE] = ACTIONS(2282),
    [anon_sym_u_SQUOTE] = ACTIONS(2282),
    [anon_sym_U_SQUOTE] = ACTIONS(2282),
    [anon_sym_u8_SQUOTE] = ACTIONS(2282),
    [anon_sym_SQUOTE] = ACTIONS(2282),
    [anon_sym_L_DQUOTE] = ACTIONS(2282),
    [anon_sym_u_DQUOTE] = ACTIONS(2282),
    [anon_sym_U_DQUOTE] = ACTIONS(2282),
    [anon_sym_u8_DQUOTE] = ACTIONS(2282),
    [anon_sym_DQUOTE] = ACTIONS(2282),
    [sym_true] = ACTIONS(2280),
    [sym_false] = ACTIONS(2280),
    [anon_sym_NULL] = ACTIONS(2280),
    [anon_sym_nullptr] = ACTIONS(2280),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2280),
    [anon_sym_decltype] = ACTIONS(2280),
    [sym_virtual] = ACTIONS(2280),
    [anon_sym_explicit] = ACTIONS(2280),
    [anon_sym_typename] = ACTIONS(2280),
    [anon_sym_template] = ACTIONS(2280),
    [anon_sym_operator] = ACTIONS(2280),
    [anon_sym_try] = ACTIONS(2280),
    [anon_sym_delete] = ACTIONS(2280),
    [anon_sym_throw] = ACTIONS(2280),
    [anon_sym_namespace] = ACTIONS(2280),
    [anon_sym_using] = ACTIONS(2280),
    [anon_sym_static_assert] = ACTIONS(2280),
    [anon_sym_concept] = ACTIONS(2280),
    [anon_sym_co_return] = ACTIONS(2280),
    [anon_sym_co_yield] = ACTIONS(2280),
    [anon_sym_R_DQUOTE] = ACTIONS(2282),
    [anon_sym_LR_DQUOTE] = ACTIONS(2282),
    [anon_sym_uR_DQUOTE] = ACTIONS(2282),
    [anon_sym_UR_DQUOTE] = ACTIONS(2282),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2282),
    [anon_sym_co_await] = ACTIONS(2280),
    [anon_sym_new] = ACTIONS(2280),
    [anon_sym_requires] = ACTIONS(2280),
    [sym_this] = ACTIONS(2280),
    [anon_sym_discard] = ACTIONS(2280),
    [anon_sym_precise] = ACTIONS(2280),
    [anon_sym_shared] = ACTIONS(2280),
    [anon_sym_groupshared] = ACTIONS(2280),
    [anon_sym_uniform] = ACTIONS(2280),
    [anon_sym_row_major] = ACTIONS(2280),
    [anon_sym_column_major] = ACTIONS(2280),
    [anon_sym_globallycoherent] = ACTIONS(2280),
    [anon_sym_centroid] = ACTIONS(2280),
    [anon_sym_noperspective] = ACTIONS(2280),
    [anon_sym_nointerpolation] = ACTIONS(2280),
    [anon_sym_sample] = ACTIONS(2280),
    [anon_sym_linear] = ACTIONS(2280),
    [anon_sym_snorm] = ACTIONS(2280),
    [anon_sym_unorm] = ACTIONS(2280),
    [anon_sym_point] = ACTIONS(2280),
    [anon_sym_line] = ACTIONS(2280),
    [anon_sym_triangleadj] = ACTIONS(2280),
    [anon_sym_lineadj] = ACTIONS(2280),
    [anon_sym_triangle] = ACTIONS(2280),
    [anon_sym_cbuffer] = ACTIONS(2280),
  },
  [464] = {
    [sym_identifier] = ACTIONS(2098),
    [aux_sym_preproc_include_token1] = ACTIONS(2098),
    [aux_sym_preproc_def_token1] = ACTIONS(2098),
    [aux_sym_preproc_if_token1] = ACTIONS(2098),
    [aux_sym_preproc_if_token2] = ACTIONS(2098),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2098),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2098),
    [sym_preproc_directive] = ACTIONS(2098),
    [anon_sym_LPAREN2] = ACTIONS(2100),
    [anon_sym_BANG] = ACTIONS(2100),
    [anon_sym_TILDE] = ACTIONS(2100),
    [anon_sym_DASH] = ACTIONS(2098),
    [anon_sym_PLUS] = ACTIONS(2098),
    [anon_sym_STAR] = ACTIONS(2100),
    [anon_sym_AMP_AMP] = ACTIONS(2100),
    [anon_sym_AMP] = ACTIONS(2098),
    [anon_sym_SEMI] = ACTIONS(2100),
    [anon_sym___extension__] = ACTIONS(2098),
    [anon_sym_typedef] = ACTIONS(2098),
    [anon_sym_in] = ACTIONS(2098),
    [anon_sym_out] = ACTIONS(2098),
    [anon_sym_inout] = ACTIONS(2098),
    [anon_sym_extern] = ACTIONS(2098),
    [anon_sym___attribute__] = ACTIONS(2098),
    [anon_sym_COLON_COLON] = ACTIONS(2100),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2100),
    [anon_sym___declspec] = ACTIONS(2098),
    [anon_sym___based] = ACTIONS(2098),
    [anon_sym___cdecl] = ACTIONS(2098),
    [anon_sym___clrcall] = ACTIONS(2098),
    [anon_sym___stdcall] = ACTIONS(2098),
    [anon_sym___fastcall] = ACTIONS(2098),
    [anon_sym___thiscall] = ACTIONS(2098),
    [anon_sym___vectorcall] = ACTIONS(2098),
    [anon_sym_LBRACE] = ACTIONS(2100),
    [anon_sym_signed] = ACTIONS(2098),
    [anon_sym_unsigned] = ACTIONS(2098),
    [anon_sym_long] = ACTIONS(2098),
    [anon_sym_short] = ACTIONS(2098),
    [anon_sym_LBRACK] = ACTIONS(2098),
    [anon_sym_static] = ACTIONS(2098),
    [anon_sym_register] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(2098),
    [anon_sym___inline] = ACTIONS(2098),
    [anon_sym___inline__] = ACTIONS(2098),
    [anon_sym___forceinline] = ACTIONS(2098),
    [anon_sym_thread_local] = ACTIONS(2098),
    [anon_sym___thread] = ACTIONS(2098),
    [anon_sym_const] = ACTIONS(2098),
    [anon_sym_constexpr] = ACTIONS(2098),
    [anon_sym_volatile] = ACTIONS(2098),
    [anon_sym_restrict] = ACTIONS(2098),
    [anon_sym___restrict__] = ACTIONS(2098),
    [anon_sym__Atomic] = ACTIONS(2098),
    [anon_sym__Noreturn] = ACTIONS(2098),
    [anon_sym_noreturn] = ACTIONS(2098),
    [anon_sym_mutable] = ACTIONS(2098),
    [anon_sym_constinit] = ACTIONS(2098),
    [anon_sym_consteval] = ACTIONS(2098),
    [anon_sym_alignas] = ACTIONS(2098),
    [anon_sym__Alignas] = ACTIONS(2098),
    [sym_primitive_type] = ACTIONS(2098),
    [anon_sym_enum] = ACTIONS(2098),
    [anon_sym_class] = ACTIONS(2098),
    [anon_sym_struct] = ACTIONS(2098),
    [anon_sym_union] = ACTIONS(2098),
    [anon_sym_if] = ACTIONS(2098),
    [anon_sym_else] = ACTIONS(2098),
    [anon_sym_switch] = ACTIONS(2098),
    [anon_sym_case] = ACTIONS(2098),
    [anon_sym_default] = ACTIONS(2098),
    [anon_sym_while] = ACTIONS(2098),
    [anon_sym_do] = ACTIONS(2098),
    [anon_sym_for] = ACTIONS(2098),
    [anon_sym_return] = ACTIONS(2098),
    [anon_sym_break] = ACTIONS(2098),
    [anon_sym_continue] = ACTIONS(2098),
    [anon_sym_goto] = ACTIONS(2098),
    [anon_sym___try] = ACTIONS(2098),
    [anon_sym___leave] = ACTIONS(2098),
    [anon_sym_not] = ACTIONS(2098),
    [anon_sym_compl] = ACTIONS(2098),
    [anon_sym_DASH_DASH] = ACTIONS(2100),
    [anon_sym_PLUS_PLUS] = ACTIONS(2100),
    [anon_sym_sizeof] = ACTIONS(2098),
    [anon_sym___alignof__] = ACTIONS(2098),
    [anon_sym___alignof] = ACTIONS(2098),
    [anon_sym__alignof] = ACTIONS(2098),
    [anon_sym_alignof] = ACTIONS(2098),
    [anon_sym__Alignof] = ACTIONS(2098),
    [anon_sym_offsetof] = ACTIONS(2098),
    [anon_sym__Generic] = ACTIONS(2098),
    [anon_sym_asm] = ACTIONS(2098),
    [anon_sym___asm__] = ACTIONS(2098),
    [sym_number_literal] = ACTIONS(2100),
    [anon_sym_L_SQUOTE] = ACTIONS(2100),
    [anon_sym_u_SQUOTE] = ACTIONS(2100),
    [anon_sym_U_SQUOTE] = ACTIONS(2100),
    [anon_sym_u8_SQUOTE] = ACTIONS(2100),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [anon_sym_L_DQUOTE] = ACTIONS(2100),
    [anon_sym_u_DQUOTE] = ACTIONS(2100),
    [anon_sym_U_DQUOTE] = ACTIONS(2100),
    [anon_sym_u8_DQUOTE] = ACTIONS(2100),
    [anon_sym_DQUOTE] = ACTIONS(2100),
    [sym_true] = ACTIONS(2098),
    [sym_false] = ACTIONS(2098),
    [anon_sym_NULL] = ACTIONS(2098),
    [anon_sym_nullptr] = ACTIONS(2098),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2098),
    [anon_sym_decltype] = ACTIONS(2098),
    [sym_virtual] = ACTIONS(2098),
    [anon_sym_explicit] = ACTIONS(2098),
    [anon_sym_typename] = ACTIONS(2098),
    [anon_sym_template] = ACTIONS(2098),
    [anon_sym_operator] = ACTIONS(2098),
    [anon_sym_try] = ACTIONS(2098),
    [anon_sym_delete] = ACTIONS(2098),
    [anon_sym_throw] = ACTIONS(2098),
    [anon_sym_namespace] = ACTIONS(2098),
    [anon_sym_using] = ACTIONS(2098),
    [anon_sym_static_assert] = ACTIONS(2098),
    [anon_sym_concept] = ACTIONS(2098),
    [anon_sym_co_return] = ACTIONS(2098),
    [anon_sym_co_yield] = ACTIONS(2098),
    [anon_sym_R_DQUOTE] = ACTIONS(2100),
    [anon_sym_LR_DQUOTE] = ACTIONS(2100),
    [anon_sym_uR_DQUOTE] = ACTIONS(2100),
    [anon_sym_UR_DQUOTE] = ACTIONS(2100),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2100),
    [anon_sym_co_await] = ACTIONS(2098),
    [anon_sym_new] = ACTIONS(2098),
    [anon_sym_requires] = ACTIONS(2098),
    [sym_this] = ACTIONS(2098),
    [anon_sym_discard] = ACTIONS(2098),
    [anon_sym_precise] = ACTIONS(2098),
    [anon_sym_shared] = ACTIONS(2098),
    [anon_sym_groupshared] = ACTIONS(2098),
    [anon_sym_uniform] = ACTIONS(2098),
    [anon_sym_row_major] = ACTIONS(2098),
    [anon_sym_column_major] = ACTIONS(2098),
    [anon_sym_globallycoherent] = ACTIONS(2098),
    [anon_sym_centroid] = ACTIONS(2098),
    [anon_sym_noperspective] = ACTIONS(2098),
    [anon_sym_nointerpolation] = ACTIONS(2098),
    [anon_sym_sample] = ACTIONS(2098),
    [anon_sym_linear] = ACTIONS(2098),
    [anon_sym_snorm] = ACTIONS(2098),
    [anon_sym_unorm] = ACTIONS(2098),
    [anon_sym_point] = ACTIONS(2098),
    [anon_sym_line] = ACTIONS(2098),
    [anon_sym_triangleadj] = ACTIONS(2098),
    [anon_sym_lineadj] = ACTIONS(2098),
    [anon_sym_triangle] = ACTIONS(2098),
    [anon_sym_cbuffer] = ACTIONS(2098),
  },
  [465] = {
    [sym_identifier] = ACTIONS(2272),
    [aux_sym_preproc_include_token1] = ACTIONS(2272),
    [aux_sym_preproc_def_token1] = ACTIONS(2272),
    [aux_sym_preproc_if_token1] = ACTIONS(2272),
    [aux_sym_preproc_if_token2] = ACTIONS(2272),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2272),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2272),
    [sym_preproc_directive] = ACTIONS(2272),
    [anon_sym_LPAREN2] = ACTIONS(2274),
    [anon_sym_BANG] = ACTIONS(2274),
    [anon_sym_TILDE] = ACTIONS(2274),
    [anon_sym_DASH] = ACTIONS(2272),
    [anon_sym_PLUS] = ACTIONS(2272),
    [anon_sym_STAR] = ACTIONS(2274),
    [anon_sym_AMP_AMP] = ACTIONS(2274),
    [anon_sym_AMP] = ACTIONS(2272),
    [anon_sym_SEMI] = ACTIONS(2274),
    [anon_sym___extension__] = ACTIONS(2272),
    [anon_sym_typedef] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2272),
    [anon_sym_out] = ACTIONS(2272),
    [anon_sym_inout] = ACTIONS(2272),
    [anon_sym_extern] = ACTIONS(2272),
    [anon_sym___attribute__] = ACTIONS(2272),
    [anon_sym_COLON_COLON] = ACTIONS(2274),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2274),
    [anon_sym___declspec] = ACTIONS(2272),
    [anon_sym___based] = ACTIONS(2272),
    [anon_sym___cdecl] = ACTIONS(2272),
    [anon_sym___clrcall] = ACTIONS(2272),
    [anon_sym___stdcall] = ACTIONS(2272),
    [anon_sym___fastcall] = ACTIONS(2272),
    [anon_sym___thiscall] = ACTIONS(2272),
    [anon_sym___vectorcall] = ACTIONS(2272),
    [anon_sym_LBRACE] = ACTIONS(2274),
    [anon_sym_signed] = ACTIONS(2272),
    [anon_sym_unsigned] = ACTIONS(2272),
    [anon_sym_long] = ACTIONS(2272),
    [anon_sym_short] = ACTIONS(2272),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(2272),
    [anon_sym_register] = ACTIONS(2272),
    [anon_sym_inline] = ACTIONS(2272),
    [anon_sym___inline] = ACTIONS(2272),
    [anon_sym___inline__] = ACTIONS(2272),
    [anon_sym___forceinline] = ACTIONS(2272),
    [anon_sym_thread_local] = ACTIONS(2272),
    [anon_sym___thread] = ACTIONS(2272),
    [anon_sym_const] = ACTIONS(2272),
    [anon_sym_constexpr] = ACTIONS(2272),
    [anon_sym_volatile] = ACTIONS(2272),
    [anon_sym_restrict] = ACTIONS(2272),
    [anon_sym___restrict__] = ACTIONS(2272),
    [anon_sym__Atomic] = ACTIONS(2272),
    [anon_sym__Noreturn] = ACTIONS(2272),
    [anon_sym_noreturn] = ACTIONS(2272),
    [anon_sym_mutable] = ACTIONS(2272),
    [anon_sym_constinit] = ACTIONS(2272),
    [anon_sym_consteval] = ACTIONS(2272),
    [anon_sym_alignas] = ACTIONS(2272),
    [anon_sym__Alignas] = ACTIONS(2272),
    [sym_primitive_type] = ACTIONS(2272),
    [anon_sym_enum] = ACTIONS(2272),
    [anon_sym_class] = ACTIONS(2272),
    [anon_sym_struct] = ACTIONS(2272),
    [anon_sym_union] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2272),
    [anon_sym_else] = ACTIONS(2272),
    [anon_sym_switch] = ACTIONS(2272),
    [anon_sym_case] = ACTIONS(2272),
    [anon_sym_default] = ACTIONS(2272),
    [anon_sym_while] = ACTIONS(2272),
    [anon_sym_do] = ACTIONS(2272),
    [anon_sym_for] = ACTIONS(2272),
    [anon_sym_return] = ACTIONS(2272),
    [anon_sym_break] = ACTIONS(2272),
    [anon_sym_continue] = ACTIONS(2272),
    [anon_sym_goto] = ACTIONS(2272),
    [anon_sym___try] = ACTIONS(2272),
    [anon_sym___leave] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2272),
    [anon_sym_compl] = ACTIONS(2272),
    [anon_sym_DASH_DASH] = ACTIONS(2274),
    [anon_sym_PLUS_PLUS] = ACTIONS(2274),
    [anon_sym_sizeof] = ACTIONS(2272),
    [anon_sym___alignof__] = ACTIONS(2272),
    [anon_sym___alignof] = ACTIONS(2272),
    [anon_sym__alignof] = ACTIONS(2272),
    [anon_sym_alignof] = ACTIONS(2272),
    [anon_sym__Alignof] = ACTIONS(2272),
    [anon_sym_offsetof] = ACTIONS(2272),
    [anon_sym__Generic] = ACTIONS(2272),
    [anon_sym_asm] = ACTIONS(2272),
    [anon_sym___asm__] = ACTIONS(2272),
    [sym_number_literal] = ACTIONS(2274),
    [anon_sym_L_SQUOTE] = ACTIONS(2274),
    [anon_sym_u_SQUOTE] = ACTIONS(2274),
    [anon_sym_U_SQUOTE] = ACTIONS(2274),
    [anon_sym_u8_SQUOTE] = ACTIONS(2274),
    [anon_sym_SQUOTE] = ACTIONS(2274),
    [anon_sym_L_DQUOTE] = ACTIONS(2274),
    [anon_sym_u_DQUOTE] = ACTIONS(2274),
    [anon_sym_U_DQUOTE] = ACTIONS(2274),
    [anon_sym_u8_DQUOTE] = ACTIONS(2274),
    [anon_sym_DQUOTE] = ACTIONS(2274),
    [sym_true] = ACTIONS(2272),
    [sym_false] = ACTIONS(2272),
    [anon_sym_NULL] = ACTIONS(2272),
    [anon_sym_nullptr] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2272),
    [anon_sym_decltype] = ACTIONS(2272),
    [sym_virtual] = ACTIONS(2272),
    [anon_sym_explicit] = ACTIONS(2272),
    [anon_sym_typename] = ACTIONS(2272),
    [anon_sym_template] = ACTIONS(2272),
    [anon_sym_operator] = ACTIONS(2272),
    [anon_sym_try] = ACTIONS(2272),
    [anon_sym_delete] = ACTIONS(2272),
    [anon_sym_throw] = ACTIONS(2272),
    [anon_sym_namespace] = ACTIONS(2272),
    [anon_sym_using] = ACTIONS(2272),
    [anon_sym_static_assert] = ACTIONS(2272),
    [anon_sym_concept] = ACTIONS(2272),
    [anon_sym_co_return] = ACTIONS(2272),
    [anon_sym_co_yield] = ACTIONS(2272),
    [anon_sym_R_DQUOTE] = ACTIONS(2274),
    [anon_sym_LR_DQUOTE] = ACTIONS(2274),
    [anon_sym_uR_DQUOTE] = ACTIONS(2274),
    [anon_sym_UR_DQUOTE] = ACTIONS(2274),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2274),
    [anon_sym_co_await] = ACTIONS(2272),
    [anon_sym_new] = ACTIONS(2272),
    [anon_sym_requires] = ACTIONS(2272),
    [sym_this] = ACTIONS(2272),
    [anon_sym_discard] = ACTIONS(2272),
    [anon_sym_precise] = ACTIONS(2272),
    [anon_sym_shared] = ACTIONS(2272),
    [anon_sym_groupshared] = ACTIONS(2272),
    [anon_sym_uniform] = ACTIONS(2272),
    [anon_sym_row_major] = ACTIONS(2272),
    [anon_sym_column_major] = ACTIONS(2272),
    [anon_sym_globallycoherent] = ACTIONS(2272),
    [anon_sym_centroid] = ACTIONS(2272),
    [anon_sym_noperspective] = ACTIONS(2272),
    [anon_sym_nointerpolation] = ACTIONS(2272),
    [anon_sym_sample] = ACTIONS(2272),
    [anon_sym_linear] = ACTIONS(2272),
    [anon_sym_snorm] = ACTIONS(2272),
    [anon_sym_unorm] = ACTIONS(2272),
    [anon_sym_point] = ACTIONS(2272),
    [anon_sym_line] = ACTIONS(2272),
    [anon_sym_triangleadj] = ACTIONS(2272),
    [anon_sym_lineadj] = ACTIONS(2272),
    [anon_sym_triangle] = ACTIONS(2272),
    [anon_sym_cbuffer] = ACTIONS(2272),
  },
  [466] = {
    [sym_identifier] = ACTIONS(2284),
    [aux_sym_preproc_include_token1] = ACTIONS(2284),
    [aux_sym_preproc_def_token1] = ACTIONS(2284),
    [aux_sym_preproc_if_token1] = ACTIONS(2284),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2284),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2284),
    [sym_preproc_directive] = ACTIONS(2284),
    [anon_sym_LPAREN2] = ACTIONS(2286),
    [anon_sym_BANG] = ACTIONS(2286),
    [anon_sym_TILDE] = ACTIONS(2286),
    [anon_sym_DASH] = ACTIONS(2284),
    [anon_sym_PLUS] = ACTIONS(2284),
    [anon_sym_STAR] = ACTIONS(2286),
    [anon_sym_AMP_AMP] = ACTIONS(2286),
    [anon_sym_AMP] = ACTIONS(2284),
    [anon_sym_SEMI] = ACTIONS(2286),
    [anon_sym___extension__] = ACTIONS(2284),
    [anon_sym_typedef] = ACTIONS(2284),
    [anon_sym_in] = ACTIONS(2284),
    [anon_sym_out] = ACTIONS(2284),
    [anon_sym_inout] = ACTIONS(2284),
    [anon_sym_extern] = ACTIONS(2284),
    [anon_sym___attribute__] = ACTIONS(2284),
    [anon_sym_COLON_COLON] = ACTIONS(2286),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2286),
    [anon_sym___declspec] = ACTIONS(2284),
    [anon_sym___based] = ACTIONS(2284),
    [anon_sym___cdecl] = ACTIONS(2284),
    [anon_sym___clrcall] = ACTIONS(2284),
    [anon_sym___stdcall] = ACTIONS(2284),
    [anon_sym___fastcall] = ACTIONS(2284),
    [anon_sym___thiscall] = ACTIONS(2284),
    [anon_sym___vectorcall] = ACTIONS(2284),
    [anon_sym_LBRACE] = ACTIONS(2286),
    [anon_sym_RBRACE] = ACTIONS(2286),
    [anon_sym_signed] = ACTIONS(2284),
    [anon_sym_unsigned] = ACTIONS(2284),
    [anon_sym_long] = ACTIONS(2284),
    [anon_sym_short] = ACTIONS(2284),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [anon_sym_static] = ACTIONS(2284),
    [anon_sym_register] = ACTIONS(2284),
    [anon_sym_inline] = ACTIONS(2284),
    [anon_sym___inline] = ACTIONS(2284),
    [anon_sym___inline__] = ACTIONS(2284),
    [anon_sym___forceinline] = ACTIONS(2284),
    [anon_sym_thread_local] = ACTIONS(2284),
    [anon_sym___thread] = ACTIONS(2284),
    [anon_sym_const] = ACTIONS(2284),
    [anon_sym_constexpr] = ACTIONS(2284),
    [anon_sym_volatile] = ACTIONS(2284),
    [anon_sym_restrict] = ACTIONS(2284),
    [anon_sym___restrict__] = ACTIONS(2284),
    [anon_sym__Atomic] = ACTIONS(2284),
    [anon_sym__Noreturn] = ACTIONS(2284),
    [anon_sym_noreturn] = ACTIONS(2284),
    [anon_sym_mutable] = ACTIONS(2284),
    [anon_sym_constinit] = ACTIONS(2284),
    [anon_sym_consteval] = ACTIONS(2284),
    [anon_sym_alignas] = ACTIONS(2284),
    [anon_sym__Alignas] = ACTIONS(2284),
    [sym_primitive_type] = ACTIONS(2284),
    [anon_sym_enum] = ACTIONS(2284),
    [anon_sym_class] = ACTIONS(2284),
    [anon_sym_struct] = ACTIONS(2284),
    [anon_sym_union] = ACTIONS(2284),
    [anon_sym_if] = ACTIONS(2284),
    [anon_sym_else] = ACTIONS(2284),
    [anon_sym_switch] = ACTIONS(2284),
    [anon_sym_case] = ACTIONS(2284),
    [anon_sym_default] = ACTIONS(2284),
    [anon_sym_while] = ACTIONS(2284),
    [anon_sym_do] = ACTIONS(2284),
    [anon_sym_for] = ACTIONS(2284),
    [anon_sym_return] = ACTIONS(2284),
    [anon_sym_break] = ACTIONS(2284),
    [anon_sym_continue] = ACTIONS(2284),
    [anon_sym_goto] = ACTIONS(2284),
    [anon_sym___try] = ACTIONS(2284),
    [anon_sym___leave] = ACTIONS(2284),
    [anon_sym_not] = ACTIONS(2284),
    [anon_sym_compl] = ACTIONS(2284),
    [anon_sym_DASH_DASH] = ACTIONS(2286),
    [anon_sym_PLUS_PLUS] = ACTIONS(2286),
    [anon_sym_sizeof] = ACTIONS(2284),
    [anon_sym___alignof__] = ACTIONS(2284),
    [anon_sym___alignof] = ACTIONS(2284),
    [anon_sym__alignof] = ACTIONS(2284),
    [anon_sym_alignof] = ACTIONS(2284),
    [anon_sym__Alignof] = ACTIONS(2284),
    [anon_sym_offsetof] = ACTIONS(2284),
    [anon_sym__Generic] = ACTIONS(2284),
    [anon_sym_asm] = ACTIONS(2284),
    [anon_sym___asm__] = ACTIONS(2284),
    [sym_number_literal] = ACTIONS(2286),
    [anon_sym_L_SQUOTE] = ACTIONS(2286),
    [anon_sym_u_SQUOTE] = ACTIONS(2286),
    [anon_sym_U_SQUOTE] = ACTIONS(2286),
    [anon_sym_u8_SQUOTE] = ACTIONS(2286),
    [anon_sym_SQUOTE] = ACTIONS(2286),
    [anon_sym_L_DQUOTE] = ACTIONS(2286),
    [anon_sym_u_DQUOTE] = ACTIONS(2286),
    [anon_sym_U_DQUOTE] = ACTIONS(2286),
    [anon_sym_u8_DQUOTE] = ACTIONS(2286),
    [anon_sym_DQUOTE] = ACTIONS(2286),
    [sym_true] = ACTIONS(2284),
    [sym_false] = ACTIONS(2284),
    [anon_sym_NULL] = ACTIONS(2284),
    [anon_sym_nullptr] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2284),
    [anon_sym_decltype] = ACTIONS(2284),
    [sym_virtual] = ACTIONS(2284),
    [anon_sym_explicit] = ACTIONS(2284),
    [anon_sym_typename] = ACTIONS(2284),
    [anon_sym_template] = ACTIONS(2284),
    [anon_sym_operator] = ACTIONS(2284),
    [anon_sym_try] = ACTIONS(2284),
    [anon_sym_delete] = ACTIONS(2284),
    [anon_sym_throw] = ACTIONS(2284),
    [anon_sym_namespace] = ACTIONS(2284),
    [anon_sym_using] = ACTIONS(2284),
    [anon_sym_static_assert] = ACTIONS(2284),
    [anon_sym_concept] = ACTIONS(2284),
    [anon_sym_co_return] = ACTIONS(2284),
    [anon_sym_co_yield] = ACTIONS(2284),
    [anon_sym_R_DQUOTE] = ACTIONS(2286),
    [anon_sym_LR_DQUOTE] = ACTIONS(2286),
    [anon_sym_uR_DQUOTE] = ACTIONS(2286),
    [anon_sym_UR_DQUOTE] = ACTIONS(2286),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2286),
    [anon_sym_co_await] = ACTIONS(2284),
    [anon_sym_new] = ACTIONS(2284),
    [anon_sym_requires] = ACTIONS(2284),
    [sym_this] = ACTIONS(2284),
    [anon_sym_discard] = ACTIONS(2284),
    [anon_sym_precise] = ACTIONS(2284),
    [anon_sym_shared] = ACTIONS(2284),
    [anon_sym_groupshared] = ACTIONS(2284),
    [anon_sym_uniform] = ACTIONS(2284),
    [anon_sym_row_major] = ACTIONS(2284),
    [anon_sym_column_major] = ACTIONS(2284),
    [anon_sym_globallycoherent] = ACTIONS(2284),
    [anon_sym_centroid] = ACTIONS(2284),
    [anon_sym_noperspective] = ACTIONS(2284),
    [anon_sym_nointerpolation] = ACTIONS(2284),
    [anon_sym_sample] = ACTIONS(2284),
    [anon_sym_linear] = ACTIONS(2284),
    [anon_sym_snorm] = ACTIONS(2284),
    [anon_sym_unorm] = ACTIONS(2284),
    [anon_sym_point] = ACTIONS(2284),
    [anon_sym_line] = ACTIONS(2284),
    [anon_sym_triangleadj] = ACTIONS(2284),
    [anon_sym_lineadj] = ACTIONS(2284),
    [anon_sym_triangle] = ACTIONS(2284),
    [anon_sym_cbuffer] = ACTIONS(2284),
  },
  [467] = {
    [sym_identifier] = ACTIONS(2268),
    [aux_sym_preproc_include_token1] = ACTIONS(2268),
    [aux_sym_preproc_def_token1] = ACTIONS(2268),
    [aux_sym_preproc_if_token1] = ACTIONS(2268),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2268),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2268),
    [sym_preproc_directive] = ACTIONS(2268),
    [anon_sym_LPAREN2] = ACTIONS(2270),
    [anon_sym_BANG] = ACTIONS(2270),
    [anon_sym_TILDE] = ACTIONS(2270),
    [anon_sym_DASH] = ACTIONS(2268),
    [anon_sym_PLUS] = ACTIONS(2268),
    [anon_sym_STAR] = ACTIONS(2270),
    [anon_sym_AMP_AMP] = ACTIONS(2270),
    [anon_sym_AMP] = ACTIONS(2268),
    [anon_sym_SEMI] = ACTIONS(2270),
    [anon_sym___extension__] = ACTIONS(2268),
    [anon_sym_typedef] = ACTIONS(2268),
    [anon_sym_in] = ACTIONS(2268),
    [anon_sym_out] = ACTIONS(2268),
    [anon_sym_inout] = ACTIONS(2268),
    [anon_sym_extern] = ACTIONS(2268),
    [anon_sym___attribute__] = ACTIONS(2268),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2270),
    [anon_sym___declspec] = ACTIONS(2268),
    [anon_sym___based] = ACTIONS(2268),
    [anon_sym___cdecl] = ACTIONS(2268),
    [anon_sym___clrcall] = ACTIONS(2268),
    [anon_sym___stdcall] = ACTIONS(2268),
    [anon_sym___fastcall] = ACTIONS(2268),
    [anon_sym___thiscall] = ACTIONS(2268),
    [anon_sym___vectorcall] = ACTIONS(2268),
    [anon_sym_LBRACE] = ACTIONS(2270),
    [anon_sym_RBRACE] = ACTIONS(2270),
    [anon_sym_signed] = ACTIONS(2268),
    [anon_sym_unsigned] = ACTIONS(2268),
    [anon_sym_long] = ACTIONS(2268),
    [anon_sym_short] = ACTIONS(2268),
    [anon_sym_LBRACK] = ACTIONS(2268),
    [anon_sym_static] = ACTIONS(2268),
    [anon_sym_register] = ACTIONS(2268),
    [anon_sym_inline] = ACTIONS(2268),
    [anon_sym___inline] = ACTIONS(2268),
    [anon_sym___inline__] = ACTIONS(2268),
    [anon_sym___forceinline] = ACTIONS(2268),
    [anon_sym_thread_local] = ACTIONS(2268),
    [anon_sym___thread] = ACTIONS(2268),
    [anon_sym_const] = ACTIONS(2268),
    [anon_sym_constexpr] = ACTIONS(2268),
    [anon_sym_volatile] = ACTIONS(2268),
    [anon_sym_restrict] = ACTIONS(2268),
    [anon_sym___restrict__] = ACTIONS(2268),
    [anon_sym__Atomic] = ACTIONS(2268),
    [anon_sym__Noreturn] = ACTIONS(2268),
    [anon_sym_noreturn] = ACTIONS(2268),
    [anon_sym_mutable] = ACTIONS(2268),
    [anon_sym_constinit] = ACTIONS(2268),
    [anon_sym_consteval] = ACTIONS(2268),
    [anon_sym_alignas] = ACTIONS(2268),
    [anon_sym__Alignas] = ACTIONS(2268),
    [sym_primitive_type] = ACTIONS(2268),
    [anon_sym_enum] = ACTIONS(2268),
    [anon_sym_class] = ACTIONS(2268),
    [anon_sym_struct] = ACTIONS(2268),
    [anon_sym_union] = ACTIONS(2268),
    [anon_sym_if] = ACTIONS(2268),
    [anon_sym_else] = ACTIONS(2268),
    [anon_sym_switch] = ACTIONS(2268),
    [anon_sym_case] = ACTIONS(2268),
    [anon_sym_default] = ACTIONS(2268),
    [anon_sym_while] = ACTIONS(2268),
    [anon_sym_do] = ACTIONS(2268),
    [anon_sym_for] = ACTIONS(2268),
    [anon_sym_return] = ACTIONS(2268),
    [anon_sym_break] = ACTIONS(2268),
    [anon_sym_continue] = ACTIONS(2268),
    [anon_sym_goto] = ACTIONS(2268),
    [anon_sym___try] = ACTIONS(2268),
    [anon_sym___leave] = ACTIONS(2268),
    [anon_sym_not] = ACTIONS(2268),
    [anon_sym_compl] = ACTIONS(2268),
    [anon_sym_DASH_DASH] = ACTIONS(2270),
    [anon_sym_PLUS_PLUS] = ACTIONS(2270),
    [anon_sym_sizeof] = ACTIONS(2268),
    [anon_sym___alignof__] = ACTIONS(2268),
    [anon_sym___alignof] = ACTIONS(2268),
    [anon_sym__alignof] = ACTIONS(2268),
    [anon_sym_alignof] = ACTIONS(2268),
    [anon_sym__Alignof] = ACTIONS(2268),
    [anon_sym_offsetof] = ACTIONS(2268),
    [anon_sym__Generic] = ACTIONS(2268),
    [anon_sym_asm] = ACTIONS(2268),
    [anon_sym___asm__] = ACTIONS(2268),
    [sym_number_literal] = ACTIONS(2270),
    [anon_sym_L_SQUOTE] = ACTIONS(2270),
    [anon_sym_u_SQUOTE] = ACTIONS(2270),
    [anon_sym_U_SQUOTE] = ACTIONS(2270),
    [anon_sym_u8_SQUOTE] = ACTIONS(2270),
    [anon_sym_SQUOTE] = ACTIONS(2270),
    [anon_sym_L_DQUOTE] = ACTIONS(2270),
    [anon_sym_u_DQUOTE] = ACTIONS(2270),
    [anon_sym_U_DQUOTE] = ACTIONS(2270),
    [anon_sym_u8_DQUOTE] = ACTIONS(2270),
    [anon_sym_DQUOTE] = ACTIONS(2270),
    [sym_true] = ACTIONS(2268),
    [sym_false] = ACTIONS(2268),
    [anon_sym_NULL] = ACTIONS(2268),
    [anon_sym_nullptr] = ACTIONS(2268),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2268),
    [anon_sym_decltype] = ACTIONS(2268),
    [sym_virtual] = ACTIONS(2268),
    [anon_sym_explicit] = ACTIONS(2268),
    [anon_sym_typename] = ACTIONS(2268),
    [anon_sym_template] = ACTIONS(2268),
    [anon_sym_operator] = ACTIONS(2268),
    [anon_sym_try] = ACTIONS(2268),
    [anon_sym_delete] = ACTIONS(2268),
    [anon_sym_throw] = ACTIONS(2268),
    [anon_sym_namespace] = ACTIONS(2268),
    [anon_sym_using] = ACTIONS(2268),
    [anon_sym_static_assert] = ACTIONS(2268),
    [anon_sym_concept] = ACTIONS(2268),
    [anon_sym_co_return] = ACTIONS(2268),
    [anon_sym_co_yield] = ACTIONS(2268),
    [anon_sym_R_DQUOTE] = ACTIONS(2270),
    [anon_sym_LR_DQUOTE] = ACTIONS(2270),
    [anon_sym_uR_DQUOTE] = ACTIONS(2270),
    [anon_sym_UR_DQUOTE] = ACTIONS(2270),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2270),
    [anon_sym_co_await] = ACTIONS(2268),
    [anon_sym_new] = ACTIONS(2268),
    [anon_sym_requires] = ACTIONS(2268),
    [sym_this] = ACTIONS(2268),
    [anon_sym_discard] = ACTIONS(2268),
    [anon_sym_precise] = ACTIONS(2268),
    [anon_sym_shared] = ACTIONS(2268),
    [anon_sym_groupshared] = ACTIONS(2268),
    [anon_sym_uniform] = ACTIONS(2268),
    [anon_sym_row_major] = ACTIONS(2268),
    [anon_sym_column_major] = ACTIONS(2268),
    [anon_sym_globallycoherent] = ACTIONS(2268),
    [anon_sym_centroid] = ACTIONS(2268),
    [anon_sym_noperspective] = ACTIONS(2268),
    [anon_sym_nointerpolation] = ACTIONS(2268),
    [anon_sym_sample] = ACTIONS(2268),
    [anon_sym_linear] = ACTIONS(2268),
    [anon_sym_snorm] = ACTIONS(2268),
    [anon_sym_unorm] = ACTIONS(2268),
    [anon_sym_point] = ACTIONS(2268),
    [anon_sym_line] = ACTIONS(2268),
    [anon_sym_triangleadj] = ACTIONS(2268),
    [anon_sym_lineadj] = ACTIONS(2268),
    [anon_sym_triangle] = ACTIONS(2268),
    [anon_sym_cbuffer] = ACTIONS(2268),
  },
  [468] = {
    [sym_identifier] = ACTIONS(2094),
    [aux_sym_preproc_include_token1] = ACTIONS(2094),
    [aux_sym_preproc_def_token1] = ACTIONS(2094),
    [aux_sym_preproc_if_token1] = ACTIONS(2094),
    [aux_sym_preproc_if_token2] = ACTIONS(2094),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2094),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2094),
    [sym_preproc_directive] = ACTIONS(2094),
    [anon_sym_LPAREN2] = ACTIONS(2096),
    [anon_sym_BANG] = ACTIONS(2096),
    [anon_sym_TILDE] = ACTIONS(2096),
    [anon_sym_DASH] = ACTIONS(2094),
    [anon_sym_PLUS] = ACTIONS(2094),
    [anon_sym_STAR] = ACTIONS(2096),
    [anon_sym_AMP_AMP] = ACTIONS(2096),
    [anon_sym_AMP] = ACTIONS(2094),
    [anon_sym_SEMI] = ACTIONS(2096),
    [anon_sym___extension__] = ACTIONS(2094),
    [anon_sym_typedef] = ACTIONS(2094),
    [anon_sym_in] = ACTIONS(2094),
    [anon_sym_out] = ACTIONS(2094),
    [anon_sym_inout] = ACTIONS(2094),
    [anon_sym_extern] = ACTIONS(2094),
    [anon_sym___attribute__] = ACTIONS(2094),
    [anon_sym_COLON_COLON] = ACTIONS(2096),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2096),
    [anon_sym___declspec] = ACTIONS(2094),
    [anon_sym___based] = ACTIONS(2094),
    [anon_sym___cdecl] = ACTIONS(2094),
    [anon_sym___clrcall] = ACTIONS(2094),
    [anon_sym___stdcall] = ACTIONS(2094),
    [anon_sym___fastcall] = ACTIONS(2094),
    [anon_sym___thiscall] = ACTIONS(2094),
    [anon_sym___vectorcall] = ACTIONS(2094),
    [anon_sym_LBRACE] = ACTIONS(2096),
    [anon_sym_signed] = ACTIONS(2094),
    [anon_sym_unsigned] = ACTIONS(2094),
    [anon_sym_long] = ACTIONS(2094),
    [anon_sym_short] = ACTIONS(2094),
    [anon_sym_LBRACK] = ACTIONS(2094),
    [anon_sym_static] = ACTIONS(2094),
    [anon_sym_register] = ACTIONS(2094),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym___inline] = ACTIONS(2094),
    [anon_sym___inline__] = ACTIONS(2094),
    [anon_sym___forceinline] = ACTIONS(2094),
    [anon_sym_thread_local] = ACTIONS(2094),
    [anon_sym___thread] = ACTIONS(2094),
    [anon_sym_const] = ACTIONS(2094),
    [anon_sym_constexpr] = ACTIONS(2094),
    [anon_sym_volatile] = ACTIONS(2094),
    [anon_sym_restrict] = ACTIONS(2094),
    [anon_sym___restrict__] = ACTIONS(2094),
    [anon_sym__Atomic] = ACTIONS(2094),
    [anon_sym__Noreturn] = ACTIONS(2094),
    [anon_sym_noreturn] = ACTIONS(2094),
    [anon_sym_mutable] = ACTIONS(2094),
    [anon_sym_constinit] = ACTIONS(2094),
    [anon_sym_consteval] = ACTIONS(2094),
    [anon_sym_alignas] = ACTIONS(2094),
    [anon_sym__Alignas] = ACTIONS(2094),
    [sym_primitive_type] = ACTIONS(2094),
    [anon_sym_enum] = ACTIONS(2094),
    [anon_sym_class] = ACTIONS(2094),
    [anon_sym_struct] = ACTIONS(2094),
    [anon_sym_union] = ACTIONS(2094),
    [anon_sym_if] = ACTIONS(2094),
    [anon_sym_else] = ACTIONS(2094),
    [anon_sym_switch] = ACTIONS(2094),
    [anon_sym_case] = ACTIONS(2094),
    [anon_sym_default] = ACTIONS(2094),
    [anon_sym_while] = ACTIONS(2094),
    [anon_sym_do] = ACTIONS(2094),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_return] = ACTIONS(2094),
    [anon_sym_break] = ACTIONS(2094),
    [anon_sym_continue] = ACTIONS(2094),
    [anon_sym_goto] = ACTIONS(2094),
    [anon_sym___try] = ACTIONS(2094),
    [anon_sym___leave] = ACTIONS(2094),
    [anon_sym_not] = ACTIONS(2094),
    [anon_sym_compl] = ACTIONS(2094),
    [anon_sym_DASH_DASH] = ACTIONS(2096),
    [anon_sym_PLUS_PLUS] = ACTIONS(2096),
    [anon_sym_sizeof] = ACTIONS(2094),
    [anon_sym___alignof__] = ACTIONS(2094),
    [anon_sym___alignof] = ACTIONS(2094),
    [anon_sym__alignof] = ACTIONS(2094),
    [anon_sym_alignof] = ACTIONS(2094),
    [anon_sym__Alignof] = ACTIONS(2094),
    [anon_sym_offsetof] = ACTIONS(2094),
    [anon_sym__Generic] = ACTIONS(2094),
    [anon_sym_asm] = ACTIONS(2094),
    [anon_sym___asm__] = ACTIONS(2094),
    [sym_number_literal] = ACTIONS(2096),
    [anon_sym_L_SQUOTE] = ACTIONS(2096),
    [anon_sym_u_SQUOTE] = ACTIONS(2096),
    [anon_sym_U_SQUOTE] = ACTIONS(2096),
    [anon_sym_u8_SQUOTE] = ACTIONS(2096),
    [anon_sym_SQUOTE] = ACTIONS(2096),
    [anon_sym_L_DQUOTE] = ACTIONS(2096),
    [anon_sym_u_DQUOTE] = ACTIONS(2096),
    [anon_sym_U_DQUOTE] = ACTIONS(2096),
    [anon_sym_u8_DQUOTE] = ACTIONS(2096),
    [anon_sym_DQUOTE] = ACTIONS(2096),
    [sym_true] = ACTIONS(2094),
    [sym_false] = ACTIONS(2094),
    [anon_sym_NULL] = ACTIONS(2094),
    [anon_sym_nullptr] = ACTIONS(2094),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2094),
    [anon_sym_decltype] = ACTIONS(2094),
    [sym_virtual] = ACTIONS(2094),
    [anon_sym_explicit] = ACTIONS(2094),
    [anon_sym_typename] = ACTIONS(2094),
    [anon_sym_template] = ACTIONS(2094),
    [anon_sym_operator] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2094),
    [anon_sym_delete] = ACTIONS(2094),
    [anon_sym_throw] = ACTIONS(2094),
    [anon_sym_namespace] = ACTIONS(2094),
    [anon_sym_using] = ACTIONS(2094),
    [anon_sym_static_assert] = ACTIONS(2094),
    [anon_sym_concept] = ACTIONS(2094),
    [anon_sym_co_return] = ACTIONS(2094),
    [anon_sym_co_yield] = ACTIONS(2094),
    [anon_sym_R_DQUOTE] = ACTIONS(2096),
    [anon_sym_LR_DQUOTE] = ACTIONS(2096),
    [anon_sym_uR_DQUOTE] = ACTIONS(2096),
    [anon_sym_UR_DQUOTE] = ACTIONS(2096),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2096),
    [anon_sym_co_await] = ACTIONS(2094),
    [anon_sym_new] = ACTIONS(2094),
    [anon_sym_requires] = ACTIONS(2094),
    [sym_this] = ACTIONS(2094),
    [anon_sym_discard] = ACTIONS(2094),
    [anon_sym_precise] = ACTIONS(2094),
    [anon_sym_shared] = ACTIONS(2094),
    [anon_sym_groupshared] = ACTIONS(2094),
    [anon_sym_uniform] = ACTIONS(2094),
    [anon_sym_row_major] = ACTIONS(2094),
    [anon_sym_column_major] = ACTIONS(2094),
    [anon_sym_globallycoherent] = ACTIONS(2094),
    [anon_sym_centroid] = ACTIONS(2094),
    [anon_sym_noperspective] = ACTIONS(2094),
    [anon_sym_nointerpolation] = ACTIONS(2094),
    [anon_sym_sample] = ACTIONS(2094),
    [anon_sym_linear] = ACTIONS(2094),
    [anon_sym_snorm] = ACTIONS(2094),
    [anon_sym_unorm] = ACTIONS(2094),
    [anon_sym_point] = ACTIONS(2094),
    [anon_sym_line] = ACTIONS(2094),
    [anon_sym_triangleadj] = ACTIONS(2094),
    [anon_sym_lineadj] = ACTIONS(2094),
    [anon_sym_triangle] = ACTIONS(2094),
    [anon_sym_cbuffer] = ACTIONS(2094),
  },
  [469] = {
    [ts_builtin_sym_end] = ACTIONS(2274),
    [sym_identifier] = ACTIONS(2272),
    [aux_sym_preproc_include_token1] = ACTIONS(2272),
    [aux_sym_preproc_def_token1] = ACTIONS(2272),
    [aux_sym_preproc_if_token1] = ACTIONS(2272),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2272),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2272),
    [sym_preproc_directive] = ACTIONS(2272),
    [anon_sym_LPAREN2] = ACTIONS(2274),
    [anon_sym_BANG] = ACTIONS(2274),
    [anon_sym_TILDE] = ACTIONS(2274),
    [anon_sym_DASH] = ACTIONS(2272),
    [anon_sym_PLUS] = ACTIONS(2272),
    [anon_sym_STAR] = ACTIONS(2274),
    [anon_sym_AMP_AMP] = ACTIONS(2274),
    [anon_sym_AMP] = ACTIONS(2272),
    [anon_sym_SEMI] = ACTIONS(2274),
    [anon_sym___extension__] = ACTIONS(2272),
    [anon_sym_typedef] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2272),
    [anon_sym_out] = ACTIONS(2272),
    [anon_sym_inout] = ACTIONS(2272),
    [anon_sym_extern] = ACTIONS(2272),
    [anon_sym___attribute__] = ACTIONS(2272),
    [anon_sym_COLON_COLON] = ACTIONS(2274),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2274),
    [anon_sym___declspec] = ACTIONS(2272),
    [anon_sym___based] = ACTIONS(2272),
    [anon_sym___cdecl] = ACTIONS(2272),
    [anon_sym___clrcall] = ACTIONS(2272),
    [anon_sym___stdcall] = ACTIONS(2272),
    [anon_sym___fastcall] = ACTIONS(2272),
    [anon_sym___thiscall] = ACTIONS(2272),
    [anon_sym___vectorcall] = ACTIONS(2272),
    [anon_sym_LBRACE] = ACTIONS(2274),
    [anon_sym_signed] = ACTIONS(2272),
    [anon_sym_unsigned] = ACTIONS(2272),
    [anon_sym_long] = ACTIONS(2272),
    [anon_sym_short] = ACTIONS(2272),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(2272),
    [anon_sym_register] = ACTIONS(2272),
    [anon_sym_inline] = ACTIONS(2272),
    [anon_sym___inline] = ACTIONS(2272),
    [anon_sym___inline__] = ACTIONS(2272),
    [anon_sym___forceinline] = ACTIONS(2272),
    [anon_sym_thread_local] = ACTIONS(2272),
    [anon_sym___thread] = ACTIONS(2272),
    [anon_sym_const] = ACTIONS(2272),
    [anon_sym_constexpr] = ACTIONS(2272),
    [anon_sym_volatile] = ACTIONS(2272),
    [anon_sym_restrict] = ACTIONS(2272),
    [anon_sym___restrict__] = ACTIONS(2272),
    [anon_sym__Atomic] = ACTIONS(2272),
    [anon_sym__Noreturn] = ACTIONS(2272),
    [anon_sym_noreturn] = ACTIONS(2272),
    [anon_sym_mutable] = ACTIONS(2272),
    [anon_sym_constinit] = ACTIONS(2272),
    [anon_sym_consteval] = ACTIONS(2272),
    [anon_sym_alignas] = ACTIONS(2272),
    [anon_sym__Alignas] = ACTIONS(2272),
    [sym_primitive_type] = ACTIONS(2272),
    [anon_sym_enum] = ACTIONS(2272),
    [anon_sym_class] = ACTIONS(2272),
    [anon_sym_struct] = ACTIONS(2272),
    [anon_sym_union] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2272),
    [anon_sym_else] = ACTIONS(2272),
    [anon_sym_switch] = ACTIONS(2272),
    [anon_sym_case] = ACTIONS(2272),
    [anon_sym_default] = ACTIONS(2272),
    [anon_sym_while] = ACTIONS(2272),
    [anon_sym_do] = ACTIONS(2272),
    [anon_sym_for] = ACTIONS(2272),
    [anon_sym_return] = ACTIONS(2272),
    [anon_sym_break] = ACTIONS(2272),
    [anon_sym_continue] = ACTIONS(2272),
    [anon_sym_goto] = ACTIONS(2272),
    [anon_sym___try] = ACTIONS(2272),
    [anon_sym___leave] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2272),
    [anon_sym_compl] = ACTIONS(2272),
    [anon_sym_DASH_DASH] = ACTIONS(2274),
    [anon_sym_PLUS_PLUS] = ACTIONS(2274),
    [anon_sym_sizeof] = ACTIONS(2272),
    [anon_sym___alignof__] = ACTIONS(2272),
    [anon_sym___alignof] = ACTIONS(2272),
    [anon_sym__alignof] = ACTIONS(2272),
    [anon_sym_alignof] = ACTIONS(2272),
    [anon_sym__Alignof] = ACTIONS(2272),
    [anon_sym_offsetof] = ACTIONS(2272),
    [anon_sym__Generic] = ACTIONS(2272),
    [anon_sym_asm] = ACTIONS(2272),
    [anon_sym___asm__] = ACTIONS(2272),
    [sym_number_literal] = ACTIONS(2274),
    [anon_sym_L_SQUOTE] = ACTIONS(2274),
    [anon_sym_u_SQUOTE] = ACTIONS(2274),
    [anon_sym_U_SQUOTE] = ACTIONS(2274),
    [anon_sym_u8_SQUOTE] = ACTIONS(2274),
    [anon_sym_SQUOTE] = ACTIONS(2274),
    [anon_sym_L_DQUOTE] = ACTIONS(2274),
    [anon_sym_u_DQUOTE] = ACTIONS(2274),
    [anon_sym_U_DQUOTE] = ACTIONS(2274),
    [anon_sym_u8_DQUOTE] = ACTIONS(2274),
    [anon_sym_DQUOTE] = ACTIONS(2274),
    [sym_true] = ACTIONS(2272),
    [sym_false] = ACTIONS(2272),
    [anon_sym_NULL] = ACTIONS(2272),
    [anon_sym_nullptr] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2272),
    [anon_sym_decltype] = ACTIONS(2272),
    [sym_virtual] = ACTIONS(2272),
    [anon_sym_explicit] = ACTIONS(2272),
    [anon_sym_typename] = ACTIONS(2272),
    [anon_sym_template] = ACTIONS(2272),
    [anon_sym_operator] = ACTIONS(2272),
    [anon_sym_try] = ACTIONS(2272),
    [anon_sym_delete] = ACTIONS(2272),
    [anon_sym_throw] = ACTIONS(2272),
    [anon_sym_namespace] = ACTIONS(2272),
    [anon_sym_using] = ACTIONS(2272),
    [anon_sym_static_assert] = ACTIONS(2272),
    [anon_sym_concept] = ACTIONS(2272),
    [anon_sym_co_return] = ACTIONS(2272),
    [anon_sym_co_yield] = ACTIONS(2272),
    [anon_sym_R_DQUOTE] = ACTIONS(2274),
    [anon_sym_LR_DQUOTE] = ACTIONS(2274),
    [anon_sym_uR_DQUOTE] = ACTIONS(2274),
    [anon_sym_UR_DQUOTE] = ACTIONS(2274),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2274),
    [anon_sym_co_await] = ACTIONS(2272),
    [anon_sym_new] = ACTIONS(2272),
    [anon_sym_requires] = ACTIONS(2272),
    [sym_this] = ACTIONS(2272),
    [anon_sym_discard] = ACTIONS(2272),
    [anon_sym_precise] = ACTIONS(2272),
    [anon_sym_shared] = ACTIONS(2272),
    [anon_sym_groupshared] = ACTIONS(2272),
    [anon_sym_uniform] = ACTIONS(2272),
    [anon_sym_row_major] = ACTIONS(2272),
    [anon_sym_column_major] = ACTIONS(2272),
    [anon_sym_globallycoherent] = ACTIONS(2272),
    [anon_sym_centroid] = ACTIONS(2272),
    [anon_sym_noperspective] = ACTIONS(2272),
    [anon_sym_nointerpolation] = ACTIONS(2272),
    [anon_sym_sample] = ACTIONS(2272),
    [anon_sym_linear] = ACTIONS(2272),
    [anon_sym_snorm] = ACTIONS(2272),
    [anon_sym_unorm] = ACTIONS(2272),
    [anon_sym_point] = ACTIONS(2272),
    [anon_sym_line] = ACTIONS(2272),
    [anon_sym_triangleadj] = ACTIONS(2272),
    [anon_sym_lineadj] = ACTIONS(2272),
    [anon_sym_triangle] = ACTIONS(2272),
    [anon_sym_cbuffer] = ACTIONS(2272),
  },
  [470] = {
    [sym_identifier] = ACTIONS(2130),
    [aux_sym_preproc_include_token1] = ACTIONS(2130),
    [aux_sym_preproc_def_token1] = ACTIONS(2130),
    [aux_sym_preproc_if_token1] = ACTIONS(2130),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2130),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2130),
    [sym_preproc_directive] = ACTIONS(2130),
    [anon_sym_LPAREN2] = ACTIONS(2132),
    [anon_sym_BANG] = ACTIONS(2132),
    [anon_sym_TILDE] = ACTIONS(2132),
    [anon_sym_DASH] = ACTIONS(2130),
    [anon_sym_PLUS] = ACTIONS(2130),
    [anon_sym_STAR] = ACTIONS(2132),
    [anon_sym_AMP_AMP] = ACTIONS(2132),
    [anon_sym_AMP] = ACTIONS(2130),
    [anon_sym_SEMI] = ACTIONS(2132),
    [anon_sym___extension__] = ACTIONS(2130),
    [anon_sym_typedef] = ACTIONS(2130),
    [anon_sym_in] = ACTIONS(2130),
    [anon_sym_out] = ACTIONS(2130),
    [anon_sym_inout] = ACTIONS(2130),
    [anon_sym_extern] = ACTIONS(2130),
    [anon_sym___attribute__] = ACTIONS(2130),
    [anon_sym_COLON_COLON] = ACTIONS(2132),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2132),
    [anon_sym___declspec] = ACTIONS(2130),
    [anon_sym___based] = ACTIONS(2130),
    [anon_sym___cdecl] = ACTIONS(2130),
    [anon_sym___clrcall] = ACTIONS(2130),
    [anon_sym___stdcall] = ACTIONS(2130),
    [anon_sym___fastcall] = ACTIONS(2130),
    [anon_sym___thiscall] = ACTIONS(2130),
    [anon_sym___vectorcall] = ACTIONS(2130),
    [anon_sym_LBRACE] = ACTIONS(2132),
    [anon_sym_RBRACE] = ACTIONS(2132),
    [anon_sym_signed] = ACTIONS(2130),
    [anon_sym_unsigned] = ACTIONS(2130),
    [anon_sym_long] = ACTIONS(2130),
    [anon_sym_short] = ACTIONS(2130),
    [anon_sym_LBRACK] = ACTIONS(2130),
    [anon_sym_static] = ACTIONS(2130),
    [anon_sym_register] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(2130),
    [anon_sym___inline] = ACTIONS(2130),
    [anon_sym___inline__] = ACTIONS(2130),
    [anon_sym___forceinline] = ACTIONS(2130),
    [anon_sym_thread_local] = ACTIONS(2130),
    [anon_sym___thread] = ACTIONS(2130),
    [anon_sym_const] = ACTIONS(2130),
    [anon_sym_constexpr] = ACTIONS(2130),
    [anon_sym_volatile] = ACTIONS(2130),
    [anon_sym_restrict] = ACTIONS(2130),
    [anon_sym___restrict__] = ACTIONS(2130),
    [anon_sym__Atomic] = ACTIONS(2130),
    [anon_sym__Noreturn] = ACTIONS(2130),
    [anon_sym_noreturn] = ACTIONS(2130),
    [anon_sym_mutable] = ACTIONS(2130),
    [anon_sym_constinit] = ACTIONS(2130),
    [anon_sym_consteval] = ACTIONS(2130),
    [anon_sym_alignas] = ACTIONS(2130),
    [anon_sym__Alignas] = ACTIONS(2130),
    [sym_primitive_type] = ACTIONS(2130),
    [anon_sym_enum] = ACTIONS(2130),
    [anon_sym_class] = ACTIONS(2130),
    [anon_sym_struct] = ACTIONS(2130),
    [anon_sym_union] = ACTIONS(2130),
    [anon_sym_if] = ACTIONS(2130),
    [anon_sym_else] = ACTIONS(2130),
    [anon_sym_switch] = ACTIONS(2130),
    [anon_sym_case] = ACTIONS(2130),
    [anon_sym_default] = ACTIONS(2130),
    [anon_sym_while] = ACTIONS(2130),
    [anon_sym_do] = ACTIONS(2130),
    [anon_sym_for] = ACTIONS(2130),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_break] = ACTIONS(2130),
    [anon_sym_continue] = ACTIONS(2130),
    [anon_sym_goto] = ACTIONS(2130),
    [anon_sym___try] = ACTIONS(2130),
    [anon_sym___leave] = ACTIONS(2130),
    [anon_sym_not] = ACTIONS(2130),
    [anon_sym_compl] = ACTIONS(2130),
    [anon_sym_DASH_DASH] = ACTIONS(2132),
    [anon_sym_PLUS_PLUS] = ACTIONS(2132),
    [anon_sym_sizeof] = ACTIONS(2130),
    [anon_sym___alignof__] = ACTIONS(2130),
    [anon_sym___alignof] = ACTIONS(2130),
    [anon_sym__alignof] = ACTIONS(2130),
    [anon_sym_alignof] = ACTIONS(2130),
    [anon_sym__Alignof] = ACTIONS(2130),
    [anon_sym_offsetof] = ACTIONS(2130),
    [anon_sym__Generic] = ACTIONS(2130),
    [anon_sym_asm] = ACTIONS(2130),
    [anon_sym___asm__] = ACTIONS(2130),
    [sym_number_literal] = ACTIONS(2132),
    [anon_sym_L_SQUOTE] = ACTIONS(2132),
    [anon_sym_u_SQUOTE] = ACTIONS(2132),
    [anon_sym_U_SQUOTE] = ACTIONS(2132),
    [anon_sym_u8_SQUOTE] = ACTIONS(2132),
    [anon_sym_SQUOTE] = ACTIONS(2132),
    [anon_sym_L_DQUOTE] = ACTIONS(2132),
    [anon_sym_u_DQUOTE] = ACTIONS(2132),
    [anon_sym_U_DQUOTE] = ACTIONS(2132),
    [anon_sym_u8_DQUOTE] = ACTIONS(2132),
    [anon_sym_DQUOTE] = ACTIONS(2132),
    [sym_true] = ACTIONS(2130),
    [sym_false] = ACTIONS(2130),
    [anon_sym_NULL] = ACTIONS(2130),
    [anon_sym_nullptr] = ACTIONS(2130),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2130),
    [anon_sym_decltype] = ACTIONS(2130),
    [sym_virtual] = ACTIONS(2130),
    [anon_sym_explicit] = ACTIONS(2130),
    [anon_sym_typename] = ACTIONS(2130),
    [anon_sym_template] = ACTIONS(2130),
    [anon_sym_operator] = ACTIONS(2130),
    [anon_sym_try] = ACTIONS(2130),
    [anon_sym_delete] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2130),
    [anon_sym_namespace] = ACTIONS(2130),
    [anon_sym_using] = ACTIONS(2130),
    [anon_sym_static_assert] = ACTIONS(2130),
    [anon_sym_concept] = ACTIONS(2130),
    [anon_sym_co_return] = ACTIONS(2130),
    [anon_sym_co_yield] = ACTIONS(2130),
    [anon_sym_R_DQUOTE] = ACTIONS(2132),
    [anon_sym_LR_DQUOTE] = ACTIONS(2132),
    [anon_sym_uR_DQUOTE] = ACTIONS(2132),
    [anon_sym_UR_DQUOTE] = ACTIONS(2132),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2132),
    [anon_sym_co_await] = ACTIONS(2130),
    [anon_sym_new] = ACTIONS(2130),
    [anon_sym_requires] = ACTIONS(2130),
    [sym_this] = ACTIONS(2130),
    [anon_sym_discard] = ACTIONS(2130),
    [anon_sym_precise] = ACTIONS(2130),
    [anon_sym_shared] = ACTIONS(2130),
    [anon_sym_groupshared] = ACTIONS(2130),
    [anon_sym_uniform] = ACTIONS(2130),
    [anon_sym_row_major] = ACTIONS(2130),
    [anon_sym_column_major] = ACTIONS(2130),
    [anon_sym_globallycoherent] = ACTIONS(2130),
    [anon_sym_centroid] = ACTIONS(2130),
    [anon_sym_noperspective] = ACTIONS(2130),
    [anon_sym_nointerpolation] = ACTIONS(2130),
    [anon_sym_sample] = ACTIONS(2130),
    [anon_sym_linear] = ACTIONS(2130),
    [anon_sym_snorm] = ACTIONS(2130),
    [anon_sym_unorm] = ACTIONS(2130),
    [anon_sym_point] = ACTIONS(2130),
    [anon_sym_line] = ACTIONS(2130),
    [anon_sym_triangleadj] = ACTIONS(2130),
    [anon_sym_lineadj] = ACTIONS(2130),
    [anon_sym_triangle] = ACTIONS(2130),
    [anon_sym_cbuffer] = ACTIONS(2130),
  },
  [471] = {
    [ts_builtin_sym_end] = ACTIONS(2108),
    [sym_identifier] = ACTIONS(2106),
    [aux_sym_preproc_include_token1] = ACTIONS(2106),
    [aux_sym_preproc_def_token1] = ACTIONS(2106),
    [aux_sym_preproc_if_token1] = ACTIONS(2106),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2106),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2106),
    [sym_preproc_directive] = ACTIONS(2106),
    [anon_sym_LPAREN2] = ACTIONS(2108),
    [anon_sym_BANG] = ACTIONS(2108),
    [anon_sym_TILDE] = ACTIONS(2108),
    [anon_sym_DASH] = ACTIONS(2106),
    [anon_sym_PLUS] = ACTIONS(2106),
    [anon_sym_STAR] = ACTIONS(2108),
    [anon_sym_AMP_AMP] = ACTIONS(2108),
    [anon_sym_AMP] = ACTIONS(2106),
    [anon_sym_SEMI] = ACTIONS(2108),
    [anon_sym___extension__] = ACTIONS(2106),
    [anon_sym_typedef] = ACTIONS(2106),
    [anon_sym_in] = ACTIONS(2106),
    [anon_sym_out] = ACTIONS(2106),
    [anon_sym_inout] = ACTIONS(2106),
    [anon_sym_extern] = ACTIONS(2106),
    [anon_sym___attribute__] = ACTIONS(2106),
    [anon_sym_COLON_COLON] = ACTIONS(2108),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2108),
    [anon_sym___declspec] = ACTIONS(2106),
    [anon_sym___based] = ACTIONS(2106),
    [anon_sym___cdecl] = ACTIONS(2106),
    [anon_sym___clrcall] = ACTIONS(2106),
    [anon_sym___stdcall] = ACTIONS(2106),
    [anon_sym___fastcall] = ACTIONS(2106),
    [anon_sym___thiscall] = ACTIONS(2106),
    [anon_sym___vectorcall] = ACTIONS(2106),
    [anon_sym_LBRACE] = ACTIONS(2108),
    [anon_sym_signed] = ACTIONS(2106),
    [anon_sym_unsigned] = ACTIONS(2106),
    [anon_sym_long] = ACTIONS(2106),
    [anon_sym_short] = ACTIONS(2106),
    [anon_sym_LBRACK] = ACTIONS(2106),
    [anon_sym_static] = ACTIONS(2106),
    [anon_sym_register] = ACTIONS(2106),
    [anon_sym_inline] = ACTIONS(2106),
    [anon_sym___inline] = ACTIONS(2106),
    [anon_sym___inline__] = ACTIONS(2106),
    [anon_sym___forceinline] = ACTIONS(2106),
    [anon_sym_thread_local] = ACTIONS(2106),
    [anon_sym___thread] = ACTIONS(2106),
    [anon_sym_const] = ACTIONS(2106),
    [anon_sym_constexpr] = ACTIONS(2106),
    [anon_sym_volatile] = ACTIONS(2106),
    [anon_sym_restrict] = ACTIONS(2106),
    [anon_sym___restrict__] = ACTIONS(2106),
    [anon_sym__Atomic] = ACTIONS(2106),
    [anon_sym__Noreturn] = ACTIONS(2106),
    [anon_sym_noreturn] = ACTIONS(2106),
    [anon_sym_mutable] = ACTIONS(2106),
    [anon_sym_constinit] = ACTIONS(2106),
    [anon_sym_consteval] = ACTIONS(2106),
    [anon_sym_alignas] = ACTIONS(2106),
    [anon_sym__Alignas] = ACTIONS(2106),
    [sym_primitive_type] = ACTIONS(2106),
    [anon_sym_enum] = ACTIONS(2106),
    [anon_sym_class] = ACTIONS(2106),
    [anon_sym_struct] = ACTIONS(2106),
    [anon_sym_union] = ACTIONS(2106),
    [anon_sym_if] = ACTIONS(2106),
    [anon_sym_else] = ACTIONS(2106),
    [anon_sym_switch] = ACTIONS(2106),
    [anon_sym_case] = ACTIONS(2106),
    [anon_sym_default] = ACTIONS(2106),
    [anon_sym_while] = ACTIONS(2106),
    [anon_sym_do] = ACTIONS(2106),
    [anon_sym_for] = ACTIONS(2106),
    [anon_sym_return] = ACTIONS(2106),
    [anon_sym_break] = ACTIONS(2106),
    [anon_sym_continue] = ACTIONS(2106),
    [anon_sym_goto] = ACTIONS(2106),
    [anon_sym___try] = ACTIONS(2106),
    [anon_sym___leave] = ACTIONS(2106),
    [anon_sym_not] = ACTIONS(2106),
    [anon_sym_compl] = ACTIONS(2106),
    [anon_sym_DASH_DASH] = ACTIONS(2108),
    [anon_sym_PLUS_PLUS] = ACTIONS(2108),
    [anon_sym_sizeof] = ACTIONS(2106),
    [anon_sym___alignof__] = ACTIONS(2106),
    [anon_sym___alignof] = ACTIONS(2106),
    [anon_sym__alignof] = ACTIONS(2106),
    [anon_sym_alignof] = ACTIONS(2106),
    [anon_sym__Alignof] = ACTIONS(2106),
    [anon_sym_offsetof] = ACTIONS(2106),
    [anon_sym__Generic] = ACTIONS(2106),
    [anon_sym_asm] = ACTIONS(2106),
    [anon_sym___asm__] = ACTIONS(2106),
    [sym_number_literal] = ACTIONS(2108),
    [anon_sym_L_SQUOTE] = ACTIONS(2108),
    [anon_sym_u_SQUOTE] = ACTIONS(2108),
    [anon_sym_U_SQUOTE] = ACTIONS(2108),
    [anon_sym_u8_SQUOTE] = ACTIONS(2108),
    [anon_sym_SQUOTE] = ACTIONS(2108),
    [anon_sym_L_DQUOTE] = ACTIONS(2108),
    [anon_sym_u_DQUOTE] = ACTIONS(2108),
    [anon_sym_U_DQUOTE] = ACTIONS(2108),
    [anon_sym_u8_DQUOTE] = ACTIONS(2108),
    [anon_sym_DQUOTE] = ACTIONS(2108),
    [sym_true] = ACTIONS(2106),
    [sym_false] = ACTIONS(2106),
    [anon_sym_NULL] = ACTIONS(2106),
    [anon_sym_nullptr] = ACTIONS(2106),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2106),
    [anon_sym_decltype] = ACTIONS(2106),
    [sym_virtual] = ACTIONS(2106),
    [anon_sym_explicit] = ACTIONS(2106),
    [anon_sym_typename] = ACTIONS(2106),
    [anon_sym_template] = ACTIONS(2106),
    [anon_sym_operator] = ACTIONS(2106),
    [anon_sym_try] = ACTIONS(2106),
    [anon_sym_delete] = ACTIONS(2106),
    [anon_sym_throw] = ACTIONS(2106),
    [anon_sym_namespace] = ACTIONS(2106),
    [anon_sym_using] = ACTIONS(2106),
    [anon_sym_static_assert] = ACTIONS(2106),
    [anon_sym_concept] = ACTIONS(2106),
    [anon_sym_co_return] = ACTIONS(2106),
    [anon_sym_co_yield] = ACTIONS(2106),
    [anon_sym_R_DQUOTE] = ACTIONS(2108),
    [anon_sym_LR_DQUOTE] = ACTIONS(2108),
    [anon_sym_uR_DQUOTE] = ACTIONS(2108),
    [anon_sym_UR_DQUOTE] = ACTIONS(2108),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2108),
    [anon_sym_co_await] = ACTIONS(2106),
    [anon_sym_new] = ACTIONS(2106),
    [anon_sym_requires] = ACTIONS(2106),
    [sym_this] = ACTIONS(2106),
    [anon_sym_discard] = ACTIONS(2106),
    [anon_sym_precise] = ACTIONS(2106),
    [anon_sym_shared] = ACTIONS(2106),
    [anon_sym_groupshared] = ACTIONS(2106),
    [anon_sym_uniform] = ACTIONS(2106),
    [anon_sym_row_major] = ACTIONS(2106),
    [anon_sym_column_major] = ACTIONS(2106),
    [anon_sym_globallycoherent] = ACTIONS(2106),
    [anon_sym_centroid] = ACTIONS(2106),
    [anon_sym_noperspective] = ACTIONS(2106),
    [anon_sym_nointerpolation] = ACTIONS(2106),
    [anon_sym_sample] = ACTIONS(2106),
    [anon_sym_linear] = ACTIONS(2106),
    [anon_sym_snorm] = ACTIONS(2106),
    [anon_sym_unorm] = ACTIONS(2106),
    [anon_sym_point] = ACTIONS(2106),
    [anon_sym_line] = ACTIONS(2106),
    [anon_sym_triangleadj] = ACTIONS(2106),
    [anon_sym_lineadj] = ACTIONS(2106),
    [anon_sym_triangle] = ACTIONS(2106),
    [anon_sym_cbuffer] = ACTIONS(2106),
  },
  [472] = {
    [ts_builtin_sym_end] = ACTIONS(2104),
    [sym_identifier] = ACTIONS(2102),
    [aux_sym_preproc_include_token1] = ACTIONS(2102),
    [aux_sym_preproc_def_token1] = ACTIONS(2102),
    [aux_sym_preproc_if_token1] = ACTIONS(2102),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2102),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2102),
    [sym_preproc_directive] = ACTIONS(2102),
    [anon_sym_LPAREN2] = ACTIONS(2104),
    [anon_sym_BANG] = ACTIONS(2104),
    [anon_sym_TILDE] = ACTIONS(2104),
    [anon_sym_DASH] = ACTIONS(2102),
    [anon_sym_PLUS] = ACTIONS(2102),
    [anon_sym_STAR] = ACTIONS(2104),
    [anon_sym_AMP_AMP] = ACTIONS(2104),
    [anon_sym_AMP] = ACTIONS(2102),
    [anon_sym_SEMI] = ACTIONS(2104),
    [anon_sym___extension__] = ACTIONS(2102),
    [anon_sym_typedef] = ACTIONS(2102),
    [anon_sym_in] = ACTIONS(2102),
    [anon_sym_out] = ACTIONS(2102),
    [anon_sym_inout] = ACTIONS(2102),
    [anon_sym_extern] = ACTIONS(2102),
    [anon_sym___attribute__] = ACTIONS(2102),
    [anon_sym_COLON_COLON] = ACTIONS(2104),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2104),
    [anon_sym___declspec] = ACTIONS(2102),
    [anon_sym___based] = ACTIONS(2102),
    [anon_sym___cdecl] = ACTIONS(2102),
    [anon_sym___clrcall] = ACTIONS(2102),
    [anon_sym___stdcall] = ACTIONS(2102),
    [anon_sym___fastcall] = ACTIONS(2102),
    [anon_sym___thiscall] = ACTIONS(2102),
    [anon_sym___vectorcall] = ACTIONS(2102),
    [anon_sym_LBRACE] = ACTIONS(2104),
    [anon_sym_signed] = ACTIONS(2102),
    [anon_sym_unsigned] = ACTIONS(2102),
    [anon_sym_long] = ACTIONS(2102),
    [anon_sym_short] = ACTIONS(2102),
    [anon_sym_LBRACK] = ACTIONS(2102),
    [anon_sym_static] = ACTIONS(2102),
    [anon_sym_register] = ACTIONS(2102),
    [anon_sym_inline] = ACTIONS(2102),
    [anon_sym___inline] = ACTIONS(2102),
    [anon_sym___inline__] = ACTIONS(2102),
    [anon_sym___forceinline] = ACTIONS(2102),
    [anon_sym_thread_local] = ACTIONS(2102),
    [anon_sym___thread] = ACTIONS(2102),
    [anon_sym_const] = ACTIONS(2102),
    [anon_sym_constexpr] = ACTIONS(2102),
    [anon_sym_volatile] = ACTIONS(2102),
    [anon_sym_restrict] = ACTIONS(2102),
    [anon_sym___restrict__] = ACTIONS(2102),
    [anon_sym__Atomic] = ACTIONS(2102),
    [anon_sym__Noreturn] = ACTIONS(2102),
    [anon_sym_noreturn] = ACTIONS(2102),
    [anon_sym_mutable] = ACTIONS(2102),
    [anon_sym_constinit] = ACTIONS(2102),
    [anon_sym_consteval] = ACTIONS(2102),
    [anon_sym_alignas] = ACTIONS(2102),
    [anon_sym__Alignas] = ACTIONS(2102),
    [sym_primitive_type] = ACTIONS(2102),
    [anon_sym_enum] = ACTIONS(2102),
    [anon_sym_class] = ACTIONS(2102),
    [anon_sym_struct] = ACTIONS(2102),
    [anon_sym_union] = ACTIONS(2102),
    [anon_sym_if] = ACTIONS(2102),
    [anon_sym_else] = ACTIONS(2102),
    [anon_sym_switch] = ACTIONS(2102),
    [anon_sym_case] = ACTIONS(2102),
    [anon_sym_default] = ACTIONS(2102),
    [anon_sym_while] = ACTIONS(2102),
    [anon_sym_do] = ACTIONS(2102),
    [anon_sym_for] = ACTIONS(2102),
    [anon_sym_return] = ACTIONS(2102),
    [anon_sym_break] = ACTIONS(2102),
    [anon_sym_continue] = ACTIONS(2102),
    [anon_sym_goto] = ACTIONS(2102),
    [anon_sym___try] = ACTIONS(2102),
    [anon_sym___leave] = ACTIONS(2102),
    [anon_sym_not] = ACTIONS(2102),
    [anon_sym_compl] = ACTIONS(2102),
    [anon_sym_DASH_DASH] = ACTIONS(2104),
    [anon_sym_PLUS_PLUS] = ACTIONS(2104),
    [anon_sym_sizeof] = ACTIONS(2102),
    [anon_sym___alignof__] = ACTIONS(2102),
    [anon_sym___alignof] = ACTIONS(2102),
    [anon_sym__alignof] = ACTIONS(2102),
    [anon_sym_alignof] = ACTIONS(2102),
    [anon_sym__Alignof] = ACTIONS(2102),
    [anon_sym_offsetof] = ACTIONS(2102),
    [anon_sym__Generic] = ACTIONS(2102),
    [anon_sym_asm] = ACTIONS(2102),
    [anon_sym___asm__] = ACTIONS(2102),
    [sym_number_literal] = ACTIONS(2104),
    [anon_sym_L_SQUOTE] = ACTIONS(2104),
    [anon_sym_u_SQUOTE] = ACTIONS(2104),
    [anon_sym_U_SQUOTE] = ACTIONS(2104),
    [anon_sym_u8_SQUOTE] = ACTIONS(2104),
    [anon_sym_SQUOTE] = ACTIONS(2104),
    [anon_sym_L_DQUOTE] = ACTIONS(2104),
    [anon_sym_u_DQUOTE] = ACTIONS(2104),
    [anon_sym_U_DQUOTE] = ACTIONS(2104),
    [anon_sym_u8_DQUOTE] = ACTIONS(2104),
    [anon_sym_DQUOTE] = ACTIONS(2104),
    [sym_true] = ACTIONS(2102),
    [sym_false] = ACTIONS(2102),
    [anon_sym_NULL] = ACTIONS(2102),
    [anon_sym_nullptr] = ACTIONS(2102),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2102),
    [anon_sym_decltype] = ACTIONS(2102),
    [sym_virtual] = ACTIONS(2102),
    [anon_sym_explicit] = ACTIONS(2102),
    [anon_sym_typename] = ACTIONS(2102),
    [anon_sym_template] = ACTIONS(2102),
    [anon_sym_operator] = ACTIONS(2102),
    [anon_sym_try] = ACTIONS(2102),
    [anon_sym_delete] = ACTIONS(2102),
    [anon_sym_throw] = ACTIONS(2102),
    [anon_sym_namespace] = ACTIONS(2102),
    [anon_sym_using] = ACTIONS(2102),
    [anon_sym_static_assert] = ACTIONS(2102),
    [anon_sym_concept] = ACTIONS(2102),
    [anon_sym_co_return] = ACTIONS(2102),
    [anon_sym_co_yield] = ACTIONS(2102),
    [anon_sym_R_DQUOTE] = ACTIONS(2104),
    [anon_sym_LR_DQUOTE] = ACTIONS(2104),
    [anon_sym_uR_DQUOTE] = ACTIONS(2104),
    [anon_sym_UR_DQUOTE] = ACTIONS(2104),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2104),
    [anon_sym_co_await] = ACTIONS(2102),
    [anon_sym_new] = ACTIONS(2102),
    [anon_sym_requires] = ACTIONS(2102),
    [sym_this] = ACTIONS(2102),
    [anon_sym_discard] = ACTIONS(2102),
    [anon_sym_precise] = ACTIONS(2102),
    [anon_sym_shared] = ACTIONS(2102),
    [anon_sym_groupshared] = ACTIONS(2102),
    [anon_sym_uniform] = ACTIONS(2102),
    [anon_sym_row_major] = ACTIONS(2102),
    [anon_sym_column_major] = ACTIONS(2102),
    [anon_sym_globallycoherent] = ACTIONS(2102),
    [anon_sym_centroid] = ACTIONS(2102),
    [anon_sym_noperspective] = ACTIONS(2102),
    [anon_sym_nointerpolation] = ACTIONS(2102),
    [anon_sym_sample] = ACTIONS(2102),
    [anon_sym_linear] = ACTIONS(2102),
    [anon_sym_snorm] = ACTIONS(2102),
    [anon_sym_unorm] = ACTIONS(2102),
    [anon_sym_point] = ACTIONS(2102),
    [anon_sym_line] = ACTIONS(2102),
    [anon_sym_triangleadj] = ACTIONS(2102),
    [anon_sym_lineadj] = ACTIONS(2102),
    [anon_sym_triangle] = ACTIONS(2102),
    [anon_sym_cbuffer] = ACTIONS(2102),
  },
  [473] = {
    [ts_builtin_sym_end] = ACTIONS(2100),
    [sym_identifier] = ACTIONS(2098),
    [aux_sym_preproc_include_token1] = ACTIONS(2098),
    [aux_sym_preproc_def_token1] = ACTIONS(2098),
    [aux_sym_preproc_if_token1] = ACTIONS(2098),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2098),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2098),
    [sym_preproc_directive] = ACTIONS(2098),
    [anon_sym_LPAREN2] = ACTIONS(2100),
    [anon_sym_BANG] = ACTIONS(2100),
    [anon_sym_TILDE] = ACTIONS(2100),
    [anon_sym_DASH] = ACTIONS(2098),
    [anon_sym_PLUS] = ACTIONS(2098),
    [anon_sym_STAR] = ACTIONS(2100),
    [anon_sym_AMP_AMP] = ACTIONS(2100),
    [anon_sym_AMP] = ACTIONS(2098),
    [anon_sym_SEMI] = ACTIONS(2100),
    [anon_sym___extension__] = ACTIONS(2098),
    [anon_sym_typedef] = ACTIONS(2098),
    [anon_sym_in] = ACTIONS(2098),
    [anon_sym_out] = ACTIONS(2098),
    [anon_sym_inout] = ACTIONS(2098),
    [anon_sym_extern] = ACTIONS(2098),
    [anon_sym___attribute__] = ACTIONS(2098),
    [anon_sym_COLON_COLON] = ACTIONS(2100),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2100),
    [anon_sym___declspec] = ACTIONS(2098),
    [anon_sym___based] = ACTIONS(2098),
    [anon_sym___cdecl] = ACTIONS(2098),
    [anon_sym___clrcall] = ACTIONS(2098),
    [anon_sym___stdcall] = ACTIONS(2098),
    [anon_sym___fastcall] = ACTIONS(2098),
    [anon_sym___thiscall] = ACTIONS(2098),
    [anon_sym___vectorcall] = ACTIONS(2098),
    [anon_sym_LBRACE] = ACTIONS(2100),
    [anon_sym_signed] = ACTIONS(2098),
    [anon_sym_unsigned] = ACTIONS(2098),
    [anon_sym_long] = ACTIONS(2098),
    [anon_sym_short] = ACTIONS(2098),
    [anon_sym_LBRACK] = ACTIONS(2098),
    [anon_sym_static] = ACTIONS(2098),
    [anon_sym_register] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(2098),
    [anon_sym___inline] = ACTIONS(2098),
    [anon_sym___inline__] = ACTIONS(2098),
    [anon_sym___forceinline] = ACTIONS(2098),
    [anon_sym_thread_local] = ACTIONS(2098),
    [anon_sym___thread] = ACTIONS(2098),
    [anon_sym_const] = ACTIONS(2098),
    [anon_sym_constexpr] = ACTIONS(2098),
    [anon_sym_volatile] = ACTIONS(2098),
    [anon_sym_restrict] = ACTIONS(2098),
    [anon_sym___restrict__] = ACTIONS(2098),
    [anon_sym__Atomic] = ACTIONS(2098),
    [anon_sym__Noreturn] = ACTIONS(2098),
    [anon_sym_noreturn] = ACTIONS(2098),
    [anon_sym_mutable] = ACTIONS(2098),
    [anon_sym_constinit] = ACTIONS(2098),
    [anon_sym_consteval] = ACTIONS(2098),
    [anon_sym_alignas] = ACTIONS(2098),
    [anon_sym__Alignas] = ACTIONS(2098),
    [sym_primitive_type] = ACTIONS(2098),
    [anon_sym_enum] = ACTIONS(2098),
    [anon_sym_class] = ACTIONS(2098),
    [anon_sym_struct] = ACTIONS(2098),
    [anon_sym_union] = ACTIONS(2098),
    [anon_sym_if] = ACTIONS(2098),
    [anon_sym_else] = ACTIONS(2098),
    [anon_sym_switch] = ACTIONS(2098),
    [anon_sym_case] = ACTIONS(2098),
    [anon_sym_default] = ACTIONS(2098),
    [anon_sym_while] = ACTIONS(2098),
    [anon_sym_do] = ACTIONS(2098),
    [anon_sym_for] = ACTIONS(2098),
    [anon_sym_return] = ACTIONS(2098),
    [anon_sym_break] = ACTIONS(2098),
    [anon_sym_continue] = ACTIONS(2098),
    [anon_sym_goto] = ACTIONS(2098),
    [anon_sym___try] = ACTIONS(2098),
    [anon_sym___leave] = ACTIONS(2098),
    [anon_sym_not] = ACTIONS(2098),
    [anon_sym_compl] = ACTIONS(2098),
    [anon_sym_DASH_DASH] = ACTIONS(2100),
    [anon_sym_PLUS_PLUS] = ACTIONS(2100),
    [anon_sym_sizeof] = ACTIONS(2098),
    [anon_sym___alignof__] = ACTIONS(2098),
    [anon_sym___alignof] = ACTIONS(2098),
    [anon_sym__alignof] = ACTIONS(2098),
    [anon_sym_alignof] = ACTIONS(2098),
    [anon_sym__Alignof] = ACTIONS(2098),
    [anon_sym_offsetof] = ACTIONS(2098),
    [anon_sym__Generic] = ACTIONS(2098),
    [anon_sym_asm] = ACTIONS(2098),
    [anon_sym___asm__] = ACTIONS(2098),
    [sym_number_literal] = ACTIONS(2100),
    [anon_sym_L_SQUOTE] = ACTIONS(2100),
    [anon_sym_u_SQUOTE] = ACTIONS(2100),
    [anon_sym_U_SQUOTE] = ACTIONS(2100),
    [anon_sym_u8_SQUOTE] = ACTIONS(2100),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [anon_sym_L_DQUOTE] = ACTIONS(2100),
    [anon_sym_u_DQUOTE] = ACTIONS(2100),
    [anon_sym_U_DQUOTE] = ACTIONS(2100),
    [anon_sym_u8_DQUOTE] = ACTIONS(2100),
    [anon_sym_DQUOTE] = ACTIONS(2100),
    [sym_true] = ACTIONS(2098),
    [sym_false] = ACTIONS(2098),
    [anon_sym_NULL] = ACTIONS(2098),
    [anon_sym_nullptr] = ACTIONS(2098),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2098),
    [anon_sym_decltype] = ACTIONS(2098),
    [sym_virtual] = ACTIONS(2098),
    [anon_sym_explicit] = ACTIONS(2098),
    [anon_sym_typename] = ACTIONS(2098),
    [anon_sym_template] = ACTIONS(2098),
    [anon_sym_operator] = ACTIONS(2098),
    [anon_sym_try] = ACTIONS(2098),
    [anon_sym_delete] = ACTIONS(2098),
    [anon_sym_throw] = ACTIONS(2098),
    [anon_sym_namespace] = ACTIONS(2098),
    [anon_sym_using] = ACTIONS(2098),
    [anon_sym_static_assert] = ACTIONS(2098),
    [anon_sym_concept] = ACTIONS(2098),
    [anon_sym_co_return] = ACTIONS(2098),
    [anon_sym_co_yield] = ACTIONS(2098),
    [anon_sym_R_DQUOTE] = ACTIONS(2100),
    [anon_sym_LR_DQUOTE] = ACTIONS(2100),
    [anon_sym_uR_DQUOTE] = ACTIONS(2100),
    [anon_sym_UR_DQUOTE] = ACTIONS(2100),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2100),
    [anon_sym_co_await] = ACTIONS(2098),
    [anon_sym_new] = ACTIONS(2098),
    [anon_sym_requires] = ACTIONS(2098),
    [sym_this] = ACTIONS(2098),
    [anon_sym_discard] = ACTIONS(2098),
    [anon_sym_precise] = ACTIONS(2098),
    [anon_sym_shared] = ACTIONS(2098),
    [anon_sym_groupshared] = ACTIONS(2098),
    [anon_sym_uniform] = ACTIONS(2098),
    [anon_sym_row_major] = ACTIONS(2098),
    [anon_sym_column_major] = ACTIONS(2098),
    [anon_sym_globallycoherent] = ACTIONS(2098),
    [anon_sym_centroid] = ACTIONS(2098),
    [anon_sym_noperspective] = ACTIONS(2098),
    [anon_sym_nointerpolation] = ACTIONS(2098),
    [anon_sym_sample] = ACTIONS(2098),
    [anon_sym_linear] = ACTIONS(2098),
    [anon_sym_snorm] = ACTIONS(2098),
    [anon_sym_unorm] = ACTIONS(2098),
    [anon_sym_point] = ACTIONS(2098),
    [anon_sym_line] = ACTIONS(2098),
    [anon_sym_triangleadj] = ACTIONS(2098),
    [anon_sym_lineadj] = ACTIONS(2098),
    [anon_sym_triangle] = ACTIONS(2098),
    [anon_sym_cbuffer] = ACTIONS(2098),
  },
  [474] = {
    [ts_builtin_sym_end] = ACTIONS(2152),
    [sym_identifier] = ACTIONS(2150),
    [aux_sym_preproc_include_token1] = ACTIONS(2150),
    [aux_sym_preproc_def_token1] = ACTIONS(2150),
    [aux_sym_preproc_if_token1] = ACTIONS(2150),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2150),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2150),
    [sym_preproc_directive] = ACTIONS(2150),
    [anon_sym_LPAREN2] = ACTIONS(2152),
    [anon_sym_BANG] = ACTIONS(2152),
    [anon_sym_TILDE] = ACTIONS(2152),
    [anon_sym_DASH] = ACTIONS(2150),
    [anon_sym_PLUS] = ACTIONS(2150),
    [anon_sym_STAR] = ACTIONS(2152),
    [anon_sym_AMP_AMP] = ACTIONS(2152),
    [anon_sym_AMP] = ACTIONS(2150),
    [anon_sym_SEMI] = ACTIONS(2152),
    [anon_sym___extension__] = ACTIONS(2150),
    [anon_sym_typedef] = ACTIONS(2150),
    [anon_sym_in] = ACTIONS(2150),
    [anon_sym_out] = ACTIONS(2150),
    [anon_sym_inout] = ACTIONS(2150),
    [anon_sym_extern] = ACTIONS(2150),
    [anon_sym___attribute__] = ACTIONS(2150),
    [anon_sym_COLON_COLON] = ACTIONS(2152),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2152),
    [anon_sym___declspec] = ACTIONS(2150),
    [anon_sym___based] = ACTIONS(2150),
    [anon_sym___cdecl] = ACTIONS(2150),
    [anon_sym___clrcall] = ACTIONS(2150),
    [anon_sym___stdcall] = ACTIONS(2150),
    [anon_sym___fastcall] = ACTIONS(2150),
    [anon_sym___thiscall] = ACTIONS(2150),
    [anon_sym___vectorcall] = ACTIONS(2150),
    [anon_sym_LBRACE] = ACTIONS(2152),
    [anon_sym_signed] = ACTIONS(2150),
    [anon_sym_unsigned] = ACTIONS(2150),
    [anon_sym_long] = ACTIONS(2150),
    [anon_sym_short] = ACTIONS(2150),
    [anon_sym_LBRACK] = ACTIONS(2150),
    [anon_sym_static] = ACTIONS(2150),
    [anon_sym_register] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(2150),
    [anon_sym___inline] = ACTIONS(2150),
    [anon_sym___inline__] = ACTIONS(2150),
    [anon_sym___forceinline] = ACTIONS(2150),
    [anon_sym_thread_local] = ACTIONS(2150),
    [anon_sym___thread] = ACTIONS(2150),
    [anon_sym_const] = ACTIONS(2150),
    [anon_sym_constexpr] = ACTIONS(2150),
    [anon_sym_volatile] = ACTIONS(2150),
    [anon_sym_restrict] = ACTIONS(2150),
    [anon_sym___restrict__] = ACTIONS(2150),
    [anon_sym__Atomic] = ACTIONS(2150),
    [anon_sym__Noreturn] = ACTIONS(2150),
    [anon_sym_noreturn] = ACTIONS(2150),
    [anon_sym_mutable] = ACTIONS(2150),
    [anon_sym_constinit] = ACTIONS(2150),
    [anon_sym_consteval] = ACTIONS(2150),
    [anon_sym_alignas] = ACTIONS(2150),
    [anon_sym__Alignas] = ACTIONS(2150),
    [sym_primitive_type] = ACTIONS(2150),
    [anon_sym_enum] = ACTIONS(2150),
    [anon_sym_class] = ACTIONS(2150),
    [anon_sym_struct] = ACTIONS(2150),
    [anon_sym_union] = ACTIONS(2150),
    [anon_sym_if] = ACTIONS(2150),
    [anon_sym_else] = ACTIONS(2150),
    [anon_sym_switch] = ACTIONS(2150),
    [anon_sym_case] = ACTIONS(2150),
    [anon_sym_default] = ACTIONS(2150),
    [anon_sym_while] = ACTIONS(2150),
    [anon_sym_do] = ACTIONS(2150),
    [anon_sym_for] = ACTIONS(2150),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_break] = ACTIONS(2150),
    [anon_sym_continue] = ACTIONS(2150),
    [anon_sym_goto] = ACTIONS(2150),
    [anon_sym___try] = ACTIONS(2150),
    [anon_sym___leave] = ACTIONS(2150),
    [anon_sym_not] = ACTIONS(2150),
    [anon_sym_compl] = ACTIONS(2150),
    [anon_sym_DASH_DASH] = ACTIONS(2152),
    [anon_sym_PLUS_PLUS] = ACTIONS(2152),
    [anon_sym_sizeof] = ACTIONS(2150),
    [anon_sym___alignof__] = ACTIONS(2150),
    [anon_sym___alignof] = ACTIONS(2150),
    [anon_sym__alignof] = ACTIONS(2150),
    [anon_sym_alignof] = ACTIONS(2150),
    [anon_sym__Alignof] = ACTIONS(2150),
    [anon_sym_offsetof] = ACTIONS(2150),
    [anon_sym__Generic] = ACTIONS(2150),
    [anon_sym_asm] = ACTIONS(2150),
    [anon_sym___asm__] = ACTIONS(2150),
    [sym_number_literal] = ACTIONS(2152),
    [anon_sym_L_SQUOTE] = ACTIONS(2152),
    [anon_sym_u_SQUOTE] = ACTIONS(2152),
    [anon_sym_U_SQUOTE] = ACTIONS(2152),
    [anon_sym_u8_SQUOTE] = ACTIONS(2152),
    [anon_sym_SQUOTE] = ACTIONS(2152),
    [anon_sym_L_DQUOTE] = ACTIONS(2152),
    [anon_sym_u_DQUOTE] = ACTIONS(2152),
    [anon_sym_U_DQUOTE] = ACTIONS(2152),
    [anon_sym_u8_DQUOTE] = ACTIONS(2152),
    [anon_sym_DQUOTE] = ACTIONS(2152),
    [sym_true] = ACTIONS(2150),
    [sym_false] = ACTIONS(2150),
    [anon_sym_NULL] = ACTIONS(2150),
    [anon_sym_nullptr] = ACTIONS(2150),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2150),
    [anon_sym_decltype] = ACTIONS(2150),
    [sym_virtual] = ACTIONS(2150),
    [anon_sym_explicit] = ACTIONS(2150),
    [anon_sym_typename] = ACTIONS(2150),
    [anon_sym_template] = ACTIONS(2150),
    [anon_sym_operator] = ACTIONS(2150),
    [anon_sym_try] = ACTIONS(2150),
    [anon_sym_delete] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2150),
    [anon_sym_namespace] = ACTIONS(2150),
    [anon_sym_using] = ACTIONS(2150),
    [anon_sym_static_assert] = ACTIONS(2150),
    [anon_sym_concept] = ACTIONS(2150),
    [anon_sym_co_return] = ACTIONS(2150),
    [anon_sym_co_yield] = ACTIONS(2150),
    [anon_sym_R_DQUOTE] = ACTIONS(2152),
    [anon_sym_LR_DQUOTE] = ACTIONS(2152),
    [anon_sym_uR_DQUOTE] = ACTIONS(2152),
    [anon_sym_UR_DQUOTE] = ACTIONS(2152),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2152),
    [anon_sym_co_await] = ACTIONS(2150),
    [anon_sym_new] = ACTIONS(2150),
    [anon_sym_requires] = ACTIONS(2150),
    [sym_this] = ACTIONS(2150),
    [anon_sym_discard] = ACTIONS(2150),
    [anon_sym_precise] = ACTIONS(2150),
    [anon_sym_shared] = ACTIONS(2150),
    [anon_sym_groupshared] = ACTIONS(2150),
    [anon_sym_uniform] = ACTIONS(2150),
    [anon_sym_row_major] = ACTIONS(2150),
    [anon_sym_column_major] = ACTIONS(2150),
    [anon_sym_globallycoherent] = ACTIONS(2150),
    [anon_sym_centroid] = ACTIONS(2150),
    [anon_sym_noperspective] = ACTIONS(2150),
    [anon_sym_nointerpolation] = ACTIONS(2150),
    [anon_sym_sample] = ACTIONS(2150),
    [anon_sym_linear] = ACTIONS(2150),
    [anon_sym_snorm] = ACTIONS(2150),
    [anon_sym_unorm] = ACTIONS(2150),
    [anon_sym_point] = ACTIONS(2150),
    [anon_sym_line] = ACTIONS(2150),
    [anon_sym_triangleadj] = ACTIONS(2150),
    [anon_sym_lineadj] = ACTIONS(2150),
    [anon_sym_triangle] = ACTIONS(2150),
    [anon_sym_cbuffer] = ACTIONS(2150),
  },
  [475] = {
    [ts_builtin_sym_end] = ACTIONS(2164),
    [sym_identifier] = ACTIONS(2162),
    [aux_sym_preproc_include_token1] = ACTIONS(2162),
    [aux_sym_preproc_def_token1] = ACTIONS(2162),
    [aux_sym_preproc_if_token1] = ACTIONS(2162),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2162),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2162),
    [sym_preproc_directive] = ACTIONS(2162),
    [anon_sym_LPAREN2] = ACTIONS(2164),
    [anon_sym_BANG] = ACTIONS(2164),
    [anon_sym_TILDE] = ACTIONS(2164),
    [anon_sym_DASH] = ACTIONS(2162),
    [anon_sym_PLUS] = ACTIONS(2162),
    [anon_sym_STAR] = ACTIONS(2164),
    [anon_sym_AMP_AMP] = ACTIONS(2164),
    [anon_sym_AMP] = ACTIONS(2162),
    [anon_sym_SEMI] = ACTIONS(2164),
    [anon_sym___extension__] = ACTIONS(2162),
    [anon_sym_typedef] = ACTIONS(2162),
    [anon_sym_in] = ACTIONS(2162),
    [anon_sym_out] = ACTIONS(2162),
    [anon_sym_inout] = ACTIONS(2162),
    [anon_sym_extern] = ACTIONS(2162),
    [anon_sym___attribute__] = ACTIONS(2162),
    [anon_sym_COLON_COLON] = ACTIONS(2164),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2164),
    [anon_sym___declspec] = ACTIONS(2162),
    [anon_sym___based] = ACTIONS(2162),
    [anon_sym___cdecl] = ACTIONS(2162),
    [anon_sym___clrcall] = ACTIONS(2162),
    [anon_sym___stdcall] = ACTIONS(2162),
    [anon_sym___fastcall] = ACTIONS(2162),
    [anon_sym___thiscall] = ACTIONS(2162),
    [anon_sym___vectorcall] = ACTIONS(2162),
    [anon_sym_LBRACE] = ACTIONS(2164),
    [anon_sym_signed] = ACTIONS(2162),
    [anon_sym_unsigned] = ACTIONS(2162),
    [anon_sym_long] = ACTIONS(2162),
    [anon_sym_short] = ACTIONS(2162),
    [anon_sym_LBRACK] = ACTIONS(2162),
    [anon_sym_static] = ACTIONS(2162),
    [anon_sym_register] = ACTIONS(2162),
    [anon_sym_inline] = ACTIONS(2162),
    [anon_sym___inline] = ACTIONS(2162),
    [anon_sym___inline__] = ACTIONS(2162),
    [anon_sym___forceinline] = ACTIONS(2162),
    [anon_sym_thread_local] = ACTIONS(2162),
    [anon_sym___thread] = ACTIONS(2162),
    [anon_sym_const] = ACTIONS(2162),
    [anon_sym_constexpr] = ACTIONS(2162),
    [anon_sym_volatile] = ACTIONS(2162),
    [anon_sym_restrict] = ACTIONS(2162),
    [anon_sym___restrict__] = ACTIONS(2162),
    [anon_sym__Atomic] = ACTIONS(2162),
    [anon_sym__Noreturn] = ACTIONS(2162),
    [anon_sym_noreturn] = ACTIONS(2162),
    [anon_sym_mutable] = ACTIONS(2162),
    [anon_sym_constinit] = ACTIONS(2162),
    [anon_sym_consteval] = ACTIONS(2162),
    [anon_sym_alignas] = ACTIONS(2162),
    [anon_sym__Alignas] = ACTIONS(2162),
    [sym_primitive_type] = ACTIONS(2162),
    [anon_sym_enum] = ACTIONS(2162),
    [anon_sym_class] = ACTIONS(2162),
    [anon_sym_struct] = ACTIONS(2162),
    [anon_sym_union] = ACTIONS(2162),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_else] = ACTIONS(2162),
    [anon_sym_switch] = ACTIONS(2162),
    [anon_sym_case] = ACTIONS(2162),
    [anon_sym_default] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(2162),
    [anon_sym_do] = ACTIONS(2162),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_return] = ACTIONS(2162),
    [anon_sym_break] = ACTIONS(2162),
    [anon_sym_continue] = ACTIONS(2162),
    [anon_sym_goto] = ACTIONS(2162),
    [anon_sym___try] = ACTIONS(2162),
    [anon_sym___leave] = ACTIONS(2162),
    [anon_sym_not] = ACTIONS(2162),
    [anon_sym_compl] = ACTIONS(2162),
    [anon_sym_DASH_DASH] = ACTIONS(2164),
    [anon_sym_PLUS_PLUS] = ACTIONS(2164),
    [anon_sym_sizeof] = ACTIONS(2162),
    [anon_sym___alignof__] = ACTIONS(2162),
    [anon_sym___alignof] = ACTIONS(2162),
    [anon_sym__alignof] = ACTIONS(2162),
    [anon_sym_alignof] = ACTIONS(2162),
    [anon_sym__Alignof] = ACTIONS(2162),
    [anon_sym_offsetof] = ACTIONS(2162),
    [anon_sym__Generic] = ACTIONS(2162),
    [anon_sym_asm] = ACTIONS(2162),
    [anon_sym___asm__] = ACTIONS(2162),
    [sym_number_literal] = ACTIONS(2164),
    [anon_sym_L_SQUOTE] = ACTIONS(2164),
    [anon_sym_u_SQUOTE] = ACTIONS(2164),
    [anon_sym_U_SQUOTE] = ACTIONS(2164),
    [anon_sym_u8_SQUOTE] = ACTIONS(2164),
    [anon_sym_SQUOTE] = ACTIONS(2164),
    [anon_sym_L_DQUOTE] = ACTIONS(2164),
    [anon_sym_u_DQUOTE] = ACTIONS(2164),
    [anon_sym_U_DQUOTE] = ACTIONS(2164),
    [anon_sym_u8_DQUOTE] = ACTIONS(2164),
    [anon_sym_DQUOTE] = ACTIONS(2164),
    [sym_true] = ACTIONS(2162),
    [sym_false] = ACTIONS(2162),
    [anon_sym_NULL] = ACTIONS(2162),
    [anon_sym_nullptr] = ACTIONS(2162),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2162),
    [anon_sym_decltype] = ACTIONS(2162),
    [sym_virtual] = ACTIONS(2162),
    [anon_sym_explicit] = ACTIONS(2162),
    [anon_sym_typename] = ACTIONS(2162),
    [anon_sym_template] = ACTIONS(2162),
    [anon_sym_operator] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2162),
    [anon_sym_delete] = ACTIONS(2162),
    [anon_sym_throw] = ACTIONS(2162),
    [anon_sym_namespace] = ACTIONS(2162),
    [anon_sym_using] = ACTIONS(2162),
    [anon_sym_static_assert] = ACTIONS(2162),
    [anon_sym_concept] = ACTIONS(2162),
    [anon_sym_co_return] = ACTIONS(2162),
    [anon_sym_co_yield] = ACTIONS(2162),
    [anon_sym_R_DQUOTE] = ACTIONS(2164),
    [anon_sym_LR_DQUOTE] = ACTIONS(2164),
    [anon_sym_uR_DQUOTE] = ACTIONS(2164),
    [anon_sym_UR_DQUOTE] = ACTIONS(2164),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2164),
    [anon_sym_co_await] = ACTIONS(2162),
    [anon_sym_new] = ACTIONS(2162),
    [anon_sym_requires] = ACTIONS(2162),
    [sym_this] = ACTIONS(2162),
    [anon_sym_discard] = ACTIONS(2162),
    [anon_sym_precise] = ACTIONS(2162),
    [anon_sym_shared] = ACTIONS(2162),
    [anon_sym_groupshared] = ACTIONS(2162),
    [anon_sym_uniform] = ACTIONS(2162),
    [anon_sym_row_major] = ACTIONS(2162),
    [anon_sym_column_major] = ACTIONS(2162),
    [anon_sym_globallycoherent] = ACTIONS(2162),
    [anon_sym_centroid] = ACTIONS(2162),
    [anon_sym_noperspective] = ACTIONS(2162),
    [anon_sym_nointerpolation] = ACTIONS(2162),
    [anon_sym_sample] = ACTIONS(2162),
    [anon_sym_linear] = ACTIONS(2162),
    [anon_sym_snorm] = ACTIONS(2162),
    [anon_sym_unorm] = ACTIONS(2162),
    [anon_sym_point] = ACTIONS(2162),
    [anon_sym_line] = ACTIONS(2162),
    [anon_sym_triangleadj] = ACTIONS(2162),
    [anon_sym_lineadj] = ACTIONS(2162),
    [anon_sym_triangle] = ACTIONS(2162),
    [anon_sym_cbuffer] = ACTIONS(2162),
  },
  [476] = {
    [ts_builtin_sym_end] = ACTIONS(2180),
    [sym_identifier] = ACTIONS(2178),
    [aux_sym_preproc_include_token1] = ACTIONS(2178),
    [aux_sym_preproc_def_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2178),
    [sym_preproc_directive] = ACTIONS(2178),
    [anon_sym_LPAREN2] = ACTIONS(2180),
    [anon_sym_BANG] = ACTIONS(2180),
    [anon_sym_TILDE] = ACTIONS(2180),
    [anon_sym_DASH] = ACTIONS(2178),
    [anon_sym_PLUS] = ACTIONS(2178),
    [anon_sym_STAR] = ACTIONS(2180),
    [anon_sym_AMP_AMP] = ACTIONS(2180),
    [anon_sym_AMP] = ACTIONS(2178),
    [anon_sym_SEMI] = ACTIONS(2180),
    [anon_sym___extension__] = ACTIONS(2178),
    [anon_sym_typedef] = ACTIONS(2178),
    [anon_sym_in] = ACTIONS(2178),
    [anon_sym_out] = ACTIONS(2178),
    [anon_sym_inout] = ACTIONS(2178),
    [anon_sym_extern] = ACTIONS(2178),
    [anon_sym___attribute__] = ACTIONS(2178),
    [anon_sym_COLON_COLON] = ACTIONS(2180),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2180),
    [anon_sym___declspec] = ACTIONS(2178),
    [anon_sym___based] = ACTIONS(2178),
    [anon_sym___cdecl] = ACTIONS(2178),
    [anon_sym___clrcall] = ACTIONS(2178),
    [anon_sym___stdcall] = ACTIONS(2178),
    [anon_sym___fastcall] = ACTIONS(2178),
    [anon_sym___thiscall] = ACTIONS(2178),
    [anon_sym___vectorcall] = ACTIONS(2178),
    [anon_sym_LBRACE] = ACTIONS(2180),
    [anon_sym_signed] = ACTIONS(2178),
    [anon_sym_unsigned] = ACTIONS(2178),
    [anon_sym_long] = ACTIONS(2178),
    [anon_sym_short] = ACTIONS(2178),
    [anon_sym_LBRACK] = ACTIONS(2178),
    [anon_sym_static] = ACTIONS(2178),
    [anon_sym_register] = ACTIONS(2178),
    [anon_sym_inline] = ACTIONS(2178),
    [anon_sym___inline] = ACTIONS(2178),
    [anon_sym___inline__] = ACTIONS(2178),
    [anon_sym___forceinline] = ACTIONS(2178),
    [anon_sym_thread_local] = ACTIONS(2178),
    [anon_sym___thread] = ACTIONS(2178),
    [anon_sym_const] = ACTIONS(2178),
    [anon_sym_constexpr] = ACTIONS(2178),
    [anon_sym_volatile] = ACTIONS(2178),
    [anon_sym_restrict] = ACTIONS(2178),
    [anon_sym___restrict__] = ACTIONS(2178),
    [anon_sym__Atomic] = ACTIONS(2178),
    [anon_sym__Noreturn] = ACTIONS(2178),
    [anon_sym_noreturn] = ACTIONS(2178),
    [anon_sym_mutable] = ACTIONS(2178),
    [anon_sym_constinit] = ACTIONS(2178),
    [anon_sym_consteval] = ACTIONS(2178),
    [anon_sym_alignas] = ACTIONS(2178),
    [anon_sym__Alignas] = ACTIONS(2178),
    [sym_primitive_type] = ACTIONS(2178),
    [anon_sym_enum] = ACTIONS(2178),
    [anon_sym_class] = ACTIONS(2178),
    [anon_sym_struct] = ACTIONS(2178),
    [anon_sym_union] = ACTIONS(2178),
    [anon_sym_if] = ACTIONS(2178),
    [anon_sym_else] = ACTIONS(2178),
    [anon_sym_switch] = ACTIONS(2178),
    [anon_sym_case] = ACTIONS(2178),
    [anon_sym_default] = ACTIONS(2178),
    [anon_sym_while] = ACTIONS(2178),
    [anon_sym_do] = ACTIONS(2178),
    [anon_sym_for] = ACTIONS(2178),
    [anon_sym_return] = ACTIONS(2178),
    [anon_sym_break] = ACTIONS(2178),
    [anon_sym_continue] = ACTIONS(2178),
    [anon_sym_goto] = ACTIONS(2178),
    [anon_sym___try] = ACTIONS(2178),
    [anon_sym___leave] = ACTIONS(2178),
    [anon_sym_not] = ACTIONS(2178),
    [anon_sym_compl] = ACTIONS(2178),
    [anon_sym_DASH_DASH] = ACTIONS(2180),
    [anon_sym_PLUS_PLUS] = ACTIONS(2180),
    [anon_sym_sizeof] = ACTIONS(2178),
    [anon_sym___alignof__] = ACTIONS(2178),
    [anon_sym___alignof] = ACTIONS(2178),
    [anon_sym__alignof] = ACTIONS(2178),
    [anon_sym_alignof] = ACTIONS(2178),
    [anon_sym__Alignof] = ACTIONS(2178),
    [anon_sym_offsetof] = ACTIONS(2178),
    [anon_sym__Generic] = ACTIONS(2178),
    [anon_sym_asm] = ACTIONS(2178),
    [anon_sym___asm__] = ACTIONS(2178),
    [sym_number_literal] = ACTIONS(2180),
    [anon_sym_L_SQUOTE] = ACTIONS(2180),
    [anon_sym_u_SQUOTE] = ACTIONS(2180),
    [anon_sym_U_SQUOTE] = ACTIONS(2180),
    [anon_sym_u8_SQUOTE] = ACTIONS(2180),
    [anon_sym_SQUOTE] = ACTIONS(2180),
    [anon_sym_L_DQUOTE] = ACTIONS(2180),
    [anon_sym_u_DQUOTE] = ACTIONS(2180),
    [anon_sym_U_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8_DQUOTE] = ACTIONS(2180),
    [anon_sym_DQUOTE] = ACTIONS(2180),
    [sym_true] = ACTIONS(2178),
    [sym_false] = ACTIONS(2178),
    [anon_sym_NULL] = ACTIONS(2178),
    [anon_sym_nullptr] = ACTIONS(2178),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2178),
    [anon_sym_decltype] = ACTIONS(2178),
    [sym_virtual] = ACTIONS(2178),
    [anon_sym_explicit] = ACTIONS(2178),
    [anon_sym_typename] = ACTIONS(2178),
    [anon_sym_template] = ACTIONS(2178),
    [anon_sym_operator] = ACTIONS(2178),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_delete] = ACTIONS(2178),
    [anon_sym_throw] = ACTIONS(2178),
    [anon_sym_namespace] = ACTIONS(2178),
    [anon_sym_using] = ACTIONS(2178),
    [anon_sym_static_assert] = ACTIONS(2178),
    [anon_sym_concept] = ACTIONS(2178),
    [anon_sym_co_return] = ACTIONS(2178),
    [anon_sym_co_yield] = ACTIONS(2178),
    [anon_sym_R_DQUOTE] = ACTIONS(2180),
    [anon_sym_LR_DQUOTE] = ACTIONS(2180),
    [anon_sym_uR_DQUOTE] = ACTIONS(2180),
    [anon_sym_UR_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2180),
    [anon_sym_co_await] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2178),
    [anon_sym_requires] = ACTIONS(2178),
    [sym_this] = ACTIONS(2178),
    [anon_sym_discard] = ACTIONS(2178),
    [anon_sym_precise] = ACTIONS(2178),
    [anon_sym_shared] = ACTIONS(2178),
    [anon_sym_groupshared] = ACTIONS(2178),
    [anon_sym_uniform] = ACTIONS(2178),
    [anon_sym_row_major] = ACTIONS(2178),
    [anon_sym_column_major] = ACTIONS(2178),
    [anon_sym_globallycoherent] = ACTIONS(2178),
    [anon_sym_centroid] = ACTIONS(2178),
    [anon_sym_noperspective] = ACTIONS(2178),
    [anon_sym_nointerpolation] = ACTIONS(2178),
    [anon_sym_sample] = ACTIONS(2178),
    [anon_sym_linear] = ACTIONS(2178),
    [anon_sym_snorm] = ACTIONS(2178),
    [anon_sym_unorm] = ACTIONS(2178),
    [anon_sym_point] = ACTIONS(2178),
    [anon_sym_line] = ACTIONS(2178),
    [anon_sym_triangleadj] = ACTIONS(2178),
    [anon_sym_lineadj] = ACTIONS(2178),
    [anon_sym_triangle] = ACTIONS(2178),
    [anon_sym_cbuffer] = ACTIONS(2178),
  },
  [477] = {
    [ts_builtin_sym_end] = ACTIONS(2184),
    [sym_identifier] = ACTIONS(2182),
    [aux_sym_preproc_include_token1] = ACTIONS(2182),
    [aux_sym_preproc_def_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2182),
    [sym_preproc_directive] = ACTIONS(2182),
    [anon_sym_LPAREN2] = ACTIONS(2184),
    [anon_sym_BANG] = ACTIONS(2184),
    [anon_sym_TILDE] = ACTIONS(2184),
    [anon_sym_DASH] = ACTIONS(2182),
    [anon_sym_PLUS] = ACTIONS(2182),
    [anon_sym_STAR] = ACTIONS(2184),
    [anon_sym_AMP_AMP] = ACTIONS(2184),
    [anon_sym_AMP] = ACTIONS(2182),
    [anon_sym_SEMI] = ACTIONS(2184),
    [anon_sym___extension__] = ACTIONS(2182),
    [anon_sym_typedef] = ACTIONS(2182),
    [anon_sym_in] = ACTIONS(2182),
    [anon_sym_out] = ACTIONS(2182),
    [anon_sym_inout] = ACTIONS(2182),
    [anon_sym_extern] = ACTIONS(2182),
    [anon_sym___attribute__] = ACTIONS(2182),
    [anon_sym_COLON_COLON] = ACTIONS(2184),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2184),
    [anon_sym___declspec] = ACTIONS(2182),
    [anon_sym___based] = ACTIONS(2182),
    [anon_sym___cdecl] = ACTIONS(2182),
    [anon_sym___clrcall] = ACTIONS(2182),
    [anon_sym___stdcall] = ACTIONS(2182),
    [anon_sym___fastcall] = ACTIONS(2182),
    [anon_sym___thiscall] = ACTIONS(2182),
    [anon_sym___vectorcall] = ACTIONS(2182),
    [anon_sym_LBRACE] = ACTIONS(2184),
    [anon_sym_signed] = ACTIONS(2182),
    [anon_sym_unsigned] = ACTIONS(2182),
    [anon_sym_long] = ACTIONS(2182),
    [anon_sym_short] = ACTIONS(2182),
    [anon_sym_LBRACK] = ACTIONS(2182),
    [anon_sym_static] = ACTIONS(2182),
    [anon_sym_register] = ACTIONS(2182),
    [anon_sym_inline] = ACTIONS(2182),
    [anon_sym___inline] = ACTIONS(2182),
    [anon_sym___inline__] = ACTIONS(2182),
    [anon_sym___forceinline] = ACTIONS(2182),
    [anon_sym_thread_local] = ACTIONS(2182),
    [anon_sym___thread] = ACTIONS(2182),
    [anon_sym_const] = ACTIONS(2182),
    [anon_sym_constexpr] = ACTIONS(2182),
    [anon_sym_volatile] = ACTIONS(2182),
    [anon_sym_restrict] = ACTIONS(2182),
    [anon_sym___restrict__] = ACTIONS(2182),
    [anon_sym__Atomic] = ACTIONS(2182),
    [anon_sym__Noreturn] = ACTIONS(2182),
    [anon_sym_noreturn] = ACTIONS(2182),
    [anon_sym_mutable] = ACTIONS(2182),
    [anon_sym_constinit] = ACTIONS(2182),
    [anon_sym_consteval] = ACTIONS(2182),
    [anon_sym_alignas] = ACTIONS(2182),
    [anon_sym__Alignas] = ACTIONS(2182),
    [sym_primitive_type] = ACTIONS(2182),
    [anon_sym_enum] = ACTIONS(2182),
    [anon_sym_class] = ACTIONS(2182),
    [anon_sym_struct] = ACTIONS(2182),
    [anon_sym_union] = ACTIONS(2182),
    [anon_sym_if] = ACTIONS(2182),
    [anon_sym_else] = ACTIONS(2182),
    [anon_sym_switch] = ACTIONS(2182),
    [anon_sym_case] = ACTIONS(2182),
    [anon_sym_default] = ACTIONS(2182),
    [anon_sym_while] = ACTIONS(2182),
    [anon_sym_do] = ACTIONS(2182),
    [anon_sym_for] = ACTIONS(2182),
    [anon_sym_return] = ACTIONS(2182),
    [anon_sym_break] = ACTIONS(2182),
    [anon_sym_continue] = ACTIONS(2182),
    [anon_sym_goto] = ACTIONS(2182),
    [anon_sym___try] = ACTIONS(2182),
    [anon_sym___leave] = ACTIONS(2182),
    [anon_sym_not] = ACTIONS(2182),
    [anon_sym_compl] = ACTIONS(2182),
    [anon_sym_DASH_DASH] = ACTIONS(2184),
    [anon_sym_PLUS_PLUS] = ACTIONS(2184),
    [anon_sym_sizeof] = ACTIONS(2182),
    [anon_sym___alignof__] = ACTIONS(2182),
    [anon_sym___alignof] = ACTIONS(2182),
    [anon_sym__alignof] = ACTIONS(2182),
    [anon_sym_alignof] = ACTIONS(2182),
    [anon_sym__Alignof] = ACTIONS(2182),
    [anon_sym_offsetof] = ACTIONS(2182),
    [anon_sym__Generic] = ACTIONS(2182),
    [anon_sym_asm] = ACTIONS(2182),
    [anon_sym___asm__] = ACTIONS(2182),
    [sym_number_literal] = ACTIONS(2184),
    [anon_sym_L_SQUOTE] = ACTIONS(2184),
    [anon_sym_u_SQUOTE] = ACTIONS(2184),
    [anon_sym_U_SQUOTE] = ACTIONS(2184),
    [anon_sym_u8_SQUOTE] = ACTIONS(2184),
    [anon_sym_SQUOTE] = ACTIONS(2184),
    [anon_sym_L_DQUOTE] = ACTIONS(2184),
    [anon_sym_u_DQUOTE] = ACTIONS(2184),
    [anon_sym_U_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8_DQUOTE] = ACTIONS(2184),
    [anon_sym_DQUOTE] = ACTIONS(2184),
    [sym_true] = ACTIONS(2182),
    [sym_false] = ACTIONS(2182),
    [anon_sym_NULL] = ACTIONS(2182),
    [anon_sym_nullptr] = ACTIONS(2182),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2182),
    [anon_sym_decltype] = ACTIONS(2182),
    [sym_virtual] = ACTIONS(2182),
    [anon_sym_explicit] = ACTIONS(2182),
    [anon_sym_typename] = ACTIONS(2182),
    [anon_sym_template] = ACTIONS(2182),
    [anon_sym_operator] = ACTIONS(2182),
    [anon_sym_try] = ACTIONS(2182),
    [anon_sym_delete] = ACTIONS(2182),
    [anon_sym_throw] = ACTIONS(2182),
    [anon_sym_namespace] = ACTIONS(2182),
    [anon_sym_using] = ACTIONS(2182),
    [anon_sym_static_assert] = ACTIONS(2182),
    [anon_sym_concept] = ACTIONS(2182),
    [anon_sym_co_return] = ACTIONS(2182),
    [anon_sym_co_yield] = ACTIONS(2182),
    [anon_sym_R_DQUOTE] = ACTIONS(2184),
    [anon_sym_LR_DQUOTE] = ACTIONS(2184),
    [anon_sym_uR_DQUOTE] = ACTIONS(2184),
    [anon_sym_UR_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2184),
    [anon_sym_co_await] = ACTIONS(2182),
    [anon_sym_new] = ACTIONS(2182),
    [anon_sym_requires] = ACTIONS(2182),
    [sym_this] = ACTIONS(2182),
    [anon_sym_discard] = ACTIONS(2182),
    [anon_sym_precise] = ACTIONS(2182),
    [anon_sym_shared] = ACTIONS(2182),
    [anon_sym_groupshared] = ACTIONS(2182),
    [anon_sym_uniform] = ACTIONS(2182),
    [anon_sym_row_major] = ACTIONS(2182),
    [anon_sym_column_major] = ACTIONS(2182),
    [anon_sym_globallycoherent] = ACTIONS(2182),
    [anon_sym_centroid] = ACTIONS(2182),
    [anon_sym_noperspective] = ACTIONS(2182),
    [anon_sym_nointerpolation] = ACTIONS(2182),
    [anon_sym_sample] = ACTIONS(2182),
    [anon_sym_linear] = ACTIONS(2182),
    [anon_sym_snorm] = ACTIONS(2182),
    [anon_sym_unorm] = ACTIONS(2182),
    [anon_sym_point] = ACTIONS(2182),
    [anon_sym_line] = ACTIONS(2182),
    [anon_sym_triangleadj] = ACTIONS(2182),
    [anon_sym_lineadj] = ACTIONS(2182),
    [anon_sym_triangle] = ACTIONS(2182),
    [anon_sym_cbuffer] = ACTIONS(2182),
  },
  [478] = {
    [sym_identifier] = ACTIONS(2194),
    [aux_sym_preproc_include_token1] = ACTIONS(2194),
    [aux_sym_preproc_def_token1] = ACTIONS(2194),
    [aux_sym_preproc_if_token1] = ACTIONS(2194),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2194),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2194),
    [sym_preproc_directive] = ACTIONS(2194),
    [anon_sym_LPAREN2] = ACTIONS(2196),
    [anon_sym_BANG] = ACTIONS(2196),
    [anon_sym_TILDE] = ACTIONS(2196),
    [anon_sym_DASH] = ACTIONS(2194),
    [anon_sym_PLUS] = ACTIONS(2194),
    [anon_sym_STAR] = ACTIONS(2196),
    [anon_sym_AMP_AMP] = ACTIONS(2196),
    [anon_sym_AMP] = ACTIONS(2194),
    [anon_sym_SEMI] = ACTIONS(2196),
    [anon_sym___extension__] = ACTIONS(2194),
    [anon_sym_typedef] = ACTIONS(2194),
    [anon_sym_in] = ACTIONS(2194),
    [anon_sym_out] = ACTIONS(2194),
    [anon_sym_inout] = ACTIONS(2194),
    [anon_sym_extern] = ACTIONS(2194),
    [anon_sym___attribute__] = ACTIONS(2194),
    [anon_sym_COLON_COLON] = ACTIONS(2196),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2196),
    [anon_sym___declspec] = ACTIONS(2194),
    [anon_sym___based] = ACTIONS(2194),
    [anon_sym___cdecl] = ACTIONS(2194),
    [anon_sym___clrcall] = ACTIONS(2194),
    [anon_sym___stdcall] = ACTIONS(2194),
    [anon_sym___fastcall] = ACTIONS(2194),
    [anon_sym___thiscall] = ACTIONS(2194),
    [anon_sym___vectorcall] = ACTIONS(2194),
    [anon_sym_LBRACE] = ACTIONS(2196),
    [anon_sym_RBRACE] = ACTIONS(2196),
    [anon_sym_signed] = ACTIONS(2194),
    [anon_sym_unsigned] = ACTIONS(2194),
    [anon_sym_long] = ACTIONS(2194),
    [anon_sym_short] = ACTIONS(2194),
    [anon_sym_LBRACK] = ACTIONS(2194),
    [anon_sym_static] = ACTIONS(2194),
    [anon_sym_register] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(2194),
    [anon_sym___inline] = ACTIONS(2194),
    [anon_sym___inline__] = ACTIONS(2194),
    [anon_sym___forceinline] = ACTIONS(2194),
    [anon_sym_thread_local] = ACTIONS(2194),
    [anon_sym___thread] = ACTIONS(2194),
    [anon_sym_const] = ACTIONS(2194),
    [anon_sym_constexpr] = ACTIONS(2194),
    [anon_sym_volatile] = ACTIONS(2194),
    [anon_sym_restrict] = ACTIONS(2194),
    [anon_sym___restrict__] = ACTIONS(2194),
    [anon_sym__Atomic] = ACTIONS(2194),
    [anon_sym__Noreturn] = ACTIONS(2194),
    [anon_sym_noreturn] = ACTIONS(2194),
    [anon_sym_mutable] = ACTIONS(2194),
    [anon_sym_constinit] = ACTIONS(2194),
    [anon_sym_consteval] = ACTIONS(2194),
    [anon_sym_alignas] = ACTIONS(2194),
    [anon_sym__Alignas] = ACTIONS(2194),
    [sym_primitive_type] = ACTIONS(2194),
    [anon_sym_enum] = ACTIONS(2194),
    [anon_sym_class] = ACTIONS(2194),
    [anon_sym_struct] = ACTIONS(2194),
    [anon_sym_union] = ACTIONS(2194),
    [anon_sym_if] = ACTIONS(2194),
    [anon_sym_else] = ACTIONS(2194),
    [anon_sym_switch] = ACTIONS(2194),
    [anon_sym_case] = ACTIONS(2194),
    [anon_sym_default] = ACTIONS(2194),
    [anon_sym_while] = ACTIONS(2194),
    [anon_sym_do] = ACTIONS(2194),
    [anon_sym_for] = ACTIONS(2194),
    [anon_sym_return] = ACTIONS(2194),
    [anon_sym_break] = ACTIONS(2194),
    [anon_sym_continue] = ACTIONS(2194),
    [anon_sym_goto] = ACTIONS(2194),
    [anon_sym___try] = ACTIONS(2194),
    [anon_sym___leave] = ACTIONS(2194),
    [anon_sym_not] = ACTIONS(2194),
    [anon_sym_compl] = ACTIONS(2194),
    [anon_sym_DASH_DASH] = ACTIONS(2196),
    [anon_sym_PLUS_PLUS] = ACTIONS(2196),
    [anon_sym_sizeof] = ACTIONS(2194),
    [anon_sym___alignof__] = ACTIONS(2194),
    [anon_sym___alignof] = ACTIONS(2194),
    [anon_sym__alignof] = ACTIONS(2194),
    [anon_sym_alignof] = ACTIONS(2194),
    [anon_sym__Alignof] = ACTIONS(2194),
    [anon_sym_offsetof] = ACTIONS(2194),
    [anon_sym__Generic] = ACTIONS(2194),
    [anon_sym_asm] = ACTIONS(2194),
    [anon_sym___asm__] = ACTIONS(2194),
    [sym_number_literal] = ACTIONS(2196),
    [anon_sym_L_SQUOTE] = ACTIONS(2196),
    [anon_sym_u_SQUOTE] = ACTIONS(2196),
    [anon_sym_U_SQUOTE] = ACTIONS(2196),
    [anon_sym_u8_SQUOTE] = ACTIONS(2196),
    [anon_sym_SQUOTE] = ACTIONS(2196),
    [anon_sym_L_DQUOTE] = ACTIONS(2196),
    [anon_sym_u_DQUOTE] = ACTIONS(2196),
    [anon_sym_U_DQUOTE] = ACTIONS(2196),
    [anon_sym_u8_DQUOTE] = ACTIONS(2196),
    [anon_sym_DQUOTE] = ACTIONS(2196),
    [sym_true] = ACTIONS(2194),
    [sym_false] = ACTIONS(2194),
    [anon_sym_NULL] = ACTIONS(2194),
    [anon_sym_nullptr] = ACTIONS(2194),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2194),
    [anon_sym_decltype] = ACTIONS(2194),
    [sym_virtual] = ACTIONS(2194),
    [anon_sym_explicit] = ACTIONS(2194),
    [anon_sym_typename] = ACTIONS(2194),
    [anon_sym_template] = ACTIONS(2194),
    [anon_sym_operator] = ACTIONS(2194),
    [anon_sym_try] = ACTIONS(2194),
    [anon_sym_delete] = ACTIONS(2194),
    [anon_sym_throw] = ACTIONS(2194),
    [anon_sym_namespace] = ACTIONS(2194),
    [anon_sym_using] = ACTIONS(2194),
    [anon_sym_static_assert] = ACTIONS(2194),
    [anon_sym_concept] = ACTIONS(2194),
    [anon_sym_co_return] = ACTIONS(2194),
    [anon_sym_co_yield] = ACTIONS(2194),
    [anon_sym_R_DQUOTE] = ACTIONS(2196),
    [anon_sym_LR_DQUOTE] = ACTIONS(2196),
    [anon_sym_uR_DQUOTE] = ACTIONS(2196),
    [anon_sym_UR_DQUOTE] = ACTIONS(2196),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2196),
    [anon_sym_co_await] = ACTIONS(2194),
    [anon_sym_new] = ACTIONS(2194),
    [anon_sym_requires] = ACTIONS(2194),
    [sym_this] = ACTIONS(2194),
    [anon_sym_discard] = ACTIONS(2194),
    [anon_sym_precise] = ACTIONS(2194),
    [anon_sym_shared] = ACTIONS(2194),
    [anon_sym_groupshared] = ACTIONS(2194),
    [anon_sym_uniform] = ACTIONS(2194),
    [anon_sym_row_major] = ACTIONS(2194),
    [anon_sym_column_major] = ACTIONS(2194),
    [anon_sym_globallycoherent] = ACTIONS(2194),
    [anon_sym_centroid] = ACTIONS(2194),
    [anon_sym_noperspective] = ACTIONS(2194),
    [anon_sym_nointerpolation] = ACTIONS(2194),
    [anon_sym_sample] = ACTIONS(2194),
    [anon_sym_linear] = ACTIONS(2194),
    [anon_sym_snorm] = ACTIONS(2194),
    [anon_sym_unorm] = ACTIONS(2194),
    [anon_sym_point] = ACTIONS(2194),
    [anon_sym_line] = ACTIONS(2194),
    [anon_sym_triangleadj] = ACTIONS(2194),
    [anon_sym_lineadj] = ACTIONS(2194),
    [anon_sym_triangle] = ACTIONS(2194),
    [anon_sym_cbuffer] = ACTIONS(2194),
  },
  [479] = {
    [sym_identifier] = ACTIONS(2198),
    [aux_sym_preproc_include_token1] = ACTIONS(2198),
    [aux_sym_preproc_def_token1] = ACTIONS(2198),
    [aux_sym_preproc_if_token1] = ACTIONS(2198),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2198),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2198),
    [sym_preproc_directive] = ACTIONS(2198),
    [anon_sym_LPAREN2] = ACTIONS(2200),
    [anon_sym_BANG] = ACTIONS(2200),
    [anon_sym_TILDE] = ACTIONS(2200),
    [anon_sym_DASH] = ACTIONS(2198),
    [anon_sym_PLUS] = ACTIONS(2198),
    [anon_sym_STAR] = ACTIONS(2200),
    [anon_sym_AMP_AMP] = ACTIONS(2200),
    [anon_sym_AMP] = ACTIONS(2198),
    [anon_sym_SEMI] = ACTIONS(2200),
    [anon_sym___extension__] = ACTIONS(2198),
    [anon_sym_typedef] = ACTIONS(2198),
    [anon_sym_in] = ACTIONS(2198),
    [anon_sym_out] = ACTIONS(2198),
    [anon_sym_inout] = ACTIONS(2198),
    [anon_sym_extern] = ACTIONS(2198),
    [anon_sym___attribute__] = ACTIONS(2198),
    [anon_sym_COLON_COLON] = ACTIONS(2200),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2200),
    [anon_sym___declspec] = ACTIONS(2198),
    [anon_sym___based] = ACTIONS(2198),
    [anon_sym___cdecl] = ACTIONS(2198),
    [anon_sym___clrcall] = ACTIONS(2198),
    [anon_sym___stdcall] = ACTIONS(2198),
    [anon_sym___fastcall] = ACTIONS(2198),
    [anon_sym___thiscall] = ACTIONS(2198),
    [anon_sym___vectorcall] = ACTIONS(2198),
    [anon_sym_LBRACE] = ACTIONS(2200),
    [anon_sym_RBRACE] = ACTIONS(2200),
    [anon_sym_signed] = ACTIONS(2198),
    [anon_sym_unsigned] = ACTIONS(2198),
    [anon_sym_long] = ACTIONS(2198),
    [anon_sym_short] = ACTIONS(2198),
    [anon_sym_LBRACK] = ACTIONS(2198),
    [anon_sym_static] = ACTIONS(2198),
    [anon_sym_register] = ACTIONS(2198),
    [anon_sym_inline] = ACTIONS(2198),
    [anon_sym___inline] = ACTIONS(2198),
    [anon_sym___inline__] = ACTIONS(2198),
    [anon_sym___forceinline] = ACTIONS(2198),
    [anon_sym_thread_local] = ACTIONS(2198),
    [anon_sym___thread] = ACTIONS(2198),
    [anon_sym_const] = ACTIONS(2198),
    [anon_sym_constexpr] = ACTIONS(2198),
    [anon_sym_volatile] = ACTIONS(2198),
    [anon_sym_restrict] = ACTIONS(2198),
    [anon_sym___restrict__] = ACTIONS(2198),
    [anon_sym__Atomic] = ACTIONS(2198),
    [anon_sym__Noreturn] = ACTIONS(2198),
    [anon_sym_noreturn] = ACTIONS(2198),
    [anon_sym_mutable] = ACTIONS(2198),
    [anon_sym_constinit] = ACTIONS(2198),
    [anon_sym_consteval] = ACTIONS(2198),
    [anon_sym_alignas] = ACTIONS(2198),
    [anon_sym__Alignas] = ACTIONS(2198),
    [sym_primitive_type] = ACTIONS(2198),
    [anon_sym_enum] = ACTIONS(2198),
    [anon_sym_class] = ACTIONS(2198),
    [anon_sym_struct] = ACTIONS(2198),
    [anon_sym_union] = ACTIONS(2198),
    [anon_sym_if] = ACTIONS(2198),
    [anon_sym_else] = ACTIONS(2198),
    [anon_sym_switch] = ACTIONS(2198),
    [anon_sym_case] = ACTIONS(2198),
    [anon_sym_default] = ACTIONS(2198),
    [anon_sym_while] = ACTIONS(2198),
    [anon_sym_do] = ACTIONS(2198),
    [anon_sym_for] = ACTIONS(2198),
    [anon_sym_return] = ACTIONS(2198),
    [anon_sym_break] = ACTIONS(2198),
    [anon_sym_continue] = ACTIONS(2198),
    [anon_sym_goto] = ACTIONS(2198),
    [anon_sym___try] = ACTIONS(2198),
    [anon_sym___leave] = ACTIONS(2198),
    [anon_sym_not] = ACTIONS(2198),
    [anon_sym_compl] = ACTIONS(2198),
    [anon_sym_DASH_DASH] = ACTIONS(2200),
    [anon_sym_PLUS_PLUS] = ACTIONS(2200),
    [anon_sym_sizeof] = ACTIONS(2198),
    [anon_sym___alignof__] = ACTIONS(2198),
    [anon_sym___alignof] = ACTIONS(2198),
    [anon_sym__alignof] = ACTIONS(2198),
    [anon_sym_alignof] = ACTIONS(2198),
    [anon_sym__Alignof] = ACTIONS(2198),
    [anon_sym_offsetof] = ACTIONS(2198),
    [anon_sym__Generic] = ACTIONS(2198),
    [anon_sym_asm] = ACTIONS(2198),
    [anon_sym___asm__] = ACTIONS(2198),
    [sym_number_literal] = ACTIONS(2200),
    [anon_sym_L_SQUOTE] = ACTIONS(2200),
    [anon_sym_u_SQUOTE] = ACTIONS(2200),
    [anon_sym_U_SQUOTE] = ACTIONS(2200),
    [anon_sym_u8_SQUOTE] = ACTIONS(2200),
    [anon_sym_SQUOTE] = ACTIONS(2200),
    [anon_sym_L_DQUOTE] = ACTIONS(2200),
    [anon_sym_u_DQUOTE] = ACTIONS(2200),
    [anon_sym_U_DQUOTE] = ACTIONS(2200),
    [anon_sym_u8_DQUOTE] = ACTIONS(2200),
    [anon_sym_DQUOTE] = ACTIONS(2200),
    [sym_true] = ACTIONS(2198),
    [sym_false] = ACTIONS(2198),
    [anon_sym_NULL] = ACTIONS(2198),
    [anon_sym_nullptr] = ACTIONS(2198),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2198),
    [anon_sym_decltype] = ACTIONS(2198),
    [sym_virtual] = ACTIONS(2198),
    [anon_sym_explicit] = ACTIONS(2198),
    [anon_sym_typename] = ACTIONS(2198),
    [anon_sym_template] = ACTIONS(2198),
    [anon_sym_operator] = ACTIONS(2198),
    [anon_sym_try] = ACTIONS(2198),
    [anon_sym_delete] = ACTIONS(2198),
    [anon_sym_throw] = ACTIONS(2198),
    [anon_sym_namespace] = ACTIONS(2198),
    [anon_sym_using] = ACTIONS(2198),
    [anon_sym_static_assert] = ACTIONS(2198),
    [anon_sym_concept] = ACTIONS(2198),
    [anon_sym_co_return] = ACTIONS(2198),
    [anon_sym_co_yield] = ACTIONS(2198),
    [anon_sym_R_DQUOTE] = ACTIONS(2200),
    [anon_sym_LR_DQUOTE] = ACTIONS(2200),
    [anon_sym_uR_DQUOTE] = ACTIONS(2200),
    [anon_sym_UR_DQUOTE] = ACTIONS(2200),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2200),
    [anon_sym_co_await] = ACTIONS(2198),
    [anon_sym_new] = ACTIONS(2198),
    [anon_sym_requires] = ACTIONS(2198),
    [sym_this] = ACTIONS(2198),
    [anon_sym_discard] = ACTIONS(2198),
    [anon_sym_precise] = ACTIONS(2198),
    [anon_sym_shared] = ACTIONS(2198),
    [anon_sym_groupshared] = ACTIONS(2198),
    [anon_sym_uniform] = ACTIONS(2198),
    [anon_sym_row_major] = ACTIONS(2198),
    [anon_sym_column_major] = ACTIONS(2198),
    [anon_sym_globallycoherent] = ACTIONS(2198),
    [anon_sym_centroid] = ACTIONS(2198),
    [anon_sym_noperspective] = ACTIONS(2198),
    [anon_sym_nointerpolation] = ACTIONS(2198),
    [anon_sym_sample] = ACTIONS(2198),
    [anon_sym_linear] = ACTIONS(2198),
    [anon_sym_snorm] = ACTIONS(2198),
    [anon_sym_unorm] = ACTIONS(2198),
    [anon_sym_point] = ACTIONS(2198),
    [anon_sym_line] = ACTIONS(2198),
    [anon_sym_triangleadj] = ACTIONS(2198),
    [anon_sym_lineadj] = ACTIONS(2198),
    [anon_sym_triangle] = ACTIONS(2198),
    [anon_sym_cbuffer] = ACTIONS(2198),
  },
  [480] = {
    [sym_identifier] = ACTIONS(2216),
    [aux_sym_preproc_include_token1] = ACTIONS(2216),
    [aux_sym_preproc_def_token1] = ACTIONS(2216),
    [aux_sym_preproc_if_token1] = ACTIONS(2216),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2216),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2216),
    [sym_preproc_directive] = ACTIONS(2216),
    [anon_sym_LPAREN2] = ACTIONS(2218),
    [anon_sym_BANG] = ACTIONS(2218),
    [anon_sym_TILDE] = ACTIONS(2218),
    [anon_sym_DASH] = ACTIONS(2216),
    [anon_sym_PLUS] = ACTIONS(2216),
    [anon_sym_STAR] = ACTIONS(2218),
    [anon_sym_AMP_AMP] = ACTIONS(2218),
    [anon_sym_AMP] = ACTIONS(2216),
    [anon_sym_SEMI] = ACTIONS(2218),
    [anon_sym___extension__] = ACTIONS(2216),
    [anon_sym_typedef] = ACTIONS(2216),
    [anon_sym_in] = ACTIONS(2216),
    [anon_sym_out] = ACTIONS(2216),
    [anon_sym_inout] = ACTIONS(2216),
    [anon_sym_extern] = ACTIONS(2216),
    [anon_sym___attribute__] = ACTIONS(2216),
    [anon_sym_COLON_COLON] = ACTIONS(2218),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2218),
    [anon_sym___declspec] = ACTIONS(2216),
    [anon_sym___based] = ACTIONS(2216),
    [anon_sym___cdecl] = ACTIONS(2216),
    [anon_sym___clrcall] = ACTIONS(2216),
    [anon_sym___stdcall] = ACTIONS(2216),
    [anon_sym___fastcall] = ACTIONS(2216),
    [anon_sym___thiscall] = ACTIONS(2216),
    [anon_sym___vectorcall] = ACTIONS(2216),
    [anon_sym_LBRACE] = ACTIONS(2218),
    [anon_sym_RBRACE] = ACTIONS(2218),
    [anon_sym_signed] = ACTIONS(2216),
    [anon_sym_unsigned] = ACTIONS(2216),
    [anon_sym_long] = ACTIONS(2216),
    [anon_sym_short] = ACTIONS(2216),
    [anon_sym_LBRACK] = ACTIONS(2216),
    [anon_sym_static] = ACTIONS(2216),
    [anon_sym_register] = ACTIONS(2216),
    [anon_sym_inline] = ACTIONS(2216),
    [anon_sym___inline] = ACTIONS(2216),
    [anon_sym___inline__] = ACTIONS(2216),
    [anon_sym___forceinline] = ACTIONS(2216),
    [anon_sym_thread_local] = ACTIONS(2216),
    [anon_sym___thread] = ACTIONS(2216),
    [anon_sym_const] = ACTIONS(2216),
    [anon_sym_constexpr] = ACTIONS(2216),
    [anon_sym_volatile] = ACTIONS(2216),
    [anon_sym_restrict] = ACTIONS(2216),
    [anon_sym___restrict__] = ACTIONS(2216),
    [anon_sym__Atomic] = ACTIONS(2216),
    [anon_sym__Noreturn] = ACTIONS(2216),
    [anon_sym_noreturn] = ACTIONS(2216),
    [anon_sym_mutable] = ACTIONS(2216),
    [anon_sym_constinit] = ACTIONS(2216),
    [anon_sym_consteval] = ACTIONS(2216),
    [anon_sym_alignas] = ACTIONS(2216),
    [anon_sym__Alignas] = ACTIONS(2216),
    [sym_primitive_type] = ACTIONS(2216),
    [anon_sym_enum] = ACTIONS(2216),
    [anon_sym_class] = ACTIONS(2216),
    [anon_sym_struct] = ACTIONS(2216),
    [anon_sym_union] = ACTIONS(2216),
    [anon_sym_if] = ACTIONS(2216),
    [anon_sym_else] = ACTIONS(2216),
    [anon_sym_switch] = ACTIONS(2216),
    [anon_sym_case] = ACTIONS(2216),
    [anon_sym_default] = ACTIONS(2216),
    [anon_sym_while] = ACTIONS(2216),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_for] = ACTIONS(2216),
    [anon_sym_return] = ACTIONS(2216),
    [anon_sym_break] = ACTIONS(2216),
    [anon_sym_continue] = ACTIONS(2216),
    [anon_sym_goto] = ACTIONS(2216),
    [anon_sym___try] = ACTIONS(2216),
    [anon_sym___leave] = ACTIONS(2216),
    [anon_sym_not] = ACTIONS(2216),
    [anon_sym_compl] = ACTIONS(2216),
    [anon_sym_DASH_DASH] = ACTIONS(2218),
    [anon_sym_PLUS_PLUS] = ACTIONS(2218),
    [anon_sym_sizeof] = ACTIONS(2216),
    [anon_sym___alignof__] = ACTIONS(2216),
    [anon_sym___alignof] = ACTIONS(2216),
    [anon_sym__alignof] = ACTIONS(2216),
    [anon_sym_alignof] = ACTIONS(2216),
    [anon_sym__Alignof] = ACTIONS(2216),
    [anon_sym_offsetof] = ACTIONS(2216),
    [anon_sym__Generic] = ACTIONS(2216),
    [anon_sym_asm] = ACTIONS(2216),
    [anon_sym___asm__] = ACTIONS(2216),
    [sym_number_literal] = ACTIONS(2218),
    [anon_sym_L_SQUOTE] = ACTIONS(2218),
    [anon_sym_u_SQUOTE] = ACTIONS(2218),
    [anon_sym_U_SQUOTE] = ACTIONS(2218),
    [anon_sym_u8_SQUOTE] = ACTIONS(2218),
    [anon_sym_SQUOTE] = ACTIONS(2218),
    [anon_sym_L_DQUOTE] = ACTIONS(2218),
    [anon_sym_u_DQUOTE] = ACTIONS(2218),
    [anon_sym_U_DQUOTE] = ACTIONS(2218),
    [anon_sym_u8_DQUOTE] = ACTIONS(2218),
    [anon_sym_DQUOTE] = ACTIONS(2218),
    [sym_true] = ACTIONS(2216),
    [sym_false] = ACTIONS(2216),
    [anon_sym_NULL] = ACTIONS(2216),
    [anon_sym_nullptr] = ACTIONS(2216),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2216),
    [anon_sym_decltype] = ACTIONS(2216),
    [sym_virtual] = ACTIONS(2216),
    [anon_sym_explicit] = ACTIONS(2216),
    [anon_sym_typename] = ACTIONS(2216),
    [anon_sym_template] = ACTIONS(2216),
    [anon_sym_operator] = ACTIONS(2216),
    [anon_sym_try] = ACTIONS(2216),
    [anon_sym_delete] = ACTIONS(2216),
    [anon_sym_throw] = ACTIONS(2216),
    [anon_sym_namespace] = ACTIONS(2216),
    [anon_sym_using] = ACTIONS(2216),
    [anon_sym_static_assert] = ACTIONS(2216),
    [anon_sym_concept] = ACTIONS(2216),
    [anon_sym_co_return] = ACTIONS(2216),
    [anon_sym_co_yield] = ACTIONS(2216),
    [anon_sym_R_DQUOTE] = ACTIONS(2218),
    [anon_sym_LR_DQUOTE] = ACTIONS(2218),
    [anon_sym_uR_DQUOTE] = ACTIONS(2218),
    [anon_sym_UR_DQUOTE] = ACTIONS(2218),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2218),
    [anon_sym_co_await] = ACTIONS(2216),
    [anon_sym_new] = ACTIONS(2216),
    [anon_sym_requires] = ACTIONS(2216),
    [sym_this] = ACTIONS(2216),
    [anon_sym_discard] = ACTIONS(2216),
    [anon_sym_precise] = ACTIONS(2216),
    [anon_sym_shared] = ACTIONS(2216),
    [anon_sym_groupshared] = ACTIONS(2216),
    [anon_sym_uniform] = ACTIONS(2216),
    [anon_sym_row_major] = ACTIONS(2216),
    [anon_sym_column_major] = ACTIONS(2216),
    [anon_sym_globallycoherent] = ACTIONS(2216),
    [anon_sym_centroid] = ACTIONS(2216),
    [anon_sym_noperspective] = ACTIONS(2216),
    [anon_sym_nointerpolation] = ACTIONS(2216),
    [anon_sym_sample] = ACTIONS(2216),
    [anon_sym_linear] = ACTIONS(2216),
    [anon_sym_snorm] = ACTIONS(2216),
    [anon_sym_unorm] = ACTIONS(2216),
    [anon_sym_point] = ACTIONS(2216),
    [anon_sym_line] = ACTIONS(2216),
    [anon_sym_triangleadj] = ACTIONS(2216),
    [anon_sym_lineadj] = ACTIONS(2216),
    [anon_sym_triangle] = ACTIONS(2216),
    [anon_sym_cbuffer] = ACTIONS(2216),
  },
  [481] = {
    [sym_identifier] = ACTIONS(2224),
    [aux_sym_preproc_include_token1] = ACTIONS(2224),
    [aux_sym_preproc_def_token1] = ACTIONS(2224),
    [aux_sym_preproc_if_token1] = ACTIONS(2224),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2224),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2224),
    [sym_preproc_directive] = ACTIONS(2224),
    [anon_sym_LPAREN2] = ACTIONS(2226),
    [anon_sym_BANG] = ACTIONS(2226),
    [anon_sym_TILDE] = ACTIONS(2226),
    [anon_sym_DASH] = ACTIONS(2224),
    [anon_sym_PLUS] = ACTIONS(2224),
    [anon_sym_STAR] = ACTIONS(2226),
    [anon_sym_AMP_AMP] = ACTIONS(2226),
    [anon_sym_AMP] = ACTIONS(2224),
    [anon_sym_SEMI] = ACTIONS(2226),
    [anon_sym___extension__] = ACTIONS(2224),
    [anon_sym_typedef] = ACTIONS(2224),
    [anon_sym_in] = ACTIONS(2224),
    [anon_sym_out] = ACTIONS(2224),
    [anon_sym_inout] = ACTIONS(2224),
    [anon_sym_extern] = ACTIONS(2224),
    [anon_sym___attribute__] = ACTIONS(2224),
    [anon_sym_COLON_COLON] = ACTIONS(2226),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2226),
    [anon_sym___declspec] = ACTIONS(2224),
    [anon_sym___based] = ACTIONS(2224),
    [anon_sym___cdecl] = ACTIONS(2224),
    [anon_sym___clrcall] = ACTIONS(2224),
    [anon_sym___stdcall] = ACTIONS(2224),
    [anon_sym___fastcall] = ACTIONS(2224),
    [anon_sym___thiscall] = ACTIONS(2224),
    [anon_sym___vectorcall] = ACTIONS(2224),
    [anon_sym_LBRACE] = ACTIONS(2226),
    [anon_sym_RBRACE] = ACTIONS(2226),
    [anon_sym_signed] = ACTIONS(2224),
    [anon_sym_unsigned] = ACTIONS(2224),
    [anon_sym_long] = ACTIONS(2224),
    [anon_sym_short] = ACTIONS(2224),
    [anon_sym_LBRACK] = ACTIONS(2224),
    [anon_sym_static] = ACTIONS(2224),
    [anon_sym_register] = ACTIONS(2224),
    [anon_sym_inline] = ACTIONS(2224),
    [anon_sym___inline] = ACTIONS(2224),
    [anon_sym___inline__] = ACTIONS(2224),
    [anon_sym___forceinline] = ACTIONS(2224),
    [anon_sym_thread_local] = ACTIONS(2224),
    [anon_sym___thread] = ACTIONS(2224),
    [anon_sym_const] = ACTIONS(2224),
    [anon_sym_constexpr] = ACTIONS(2224),
    [anon_sym_volatile] = ACTIONS(2224),
    [anon_sym_restrict] = ACTIONS(2224),
    [anon_sym___restrict__] = ACTIONS(2224),
    [anon_sym__Atomic] = ACTIONS(2224),
    [anon_sym__Noreturn] = ACTIONS(2224),
    [anon_sym_noreturn] = ACTIONS(2224),
    [anon_sym_mutable] = ACTIONS(2224),
    [anon_sym_constinit] = ACTIONS(2224),
    [anon_sym_consteval] = ACTIONS(2224),
    [anon_sym_alignas] = ACTIONS(2224),
    [anon_sym__Alignas] = ACTIONS(2224),
    [sym_primitive_type] = ACTIONS(2224),
    [anon_sym_enum] = ACTIONS(2224),
    [anon_sym_class] = ACTIONS(2224),
    [anon_sym_struct] = ACTIONS(2224),
    [anon_sym_union] = ACTIONS(2224),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_else] = ACTIONS(2224),
    [anon_sym_switch] = ACTIONS(2224),
    [anon_sym_case] = ACTIONS(2224),
    [anon_sym_default] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(2224),
    [anon_sym_do] = ACTIONS(2224),
    [anon_sym_for] = ACTIONS(2224),
    [anon_sym_return] = ACTIONS(2224),
    [anon_sym_break] = ACTIONS(2224),
    [anon_sym_continue] = ACTIONS(2224),
    [anon_sym_goto] = ACTIONS(2224),
    [anon_sym___try] = ACTIONS(2224),
    [anon_sym___leave] = ACTIONS(2224),
    [anon_sym_not] = ACTIONS(2224),
    [anon_sym_compl] = ACTIONS(2224),
    [anon_sym_DASH_DASH] = ACTIONS(2226),
    [anon_sym_PLUS_PLUS] = ACTIONS(2226),
    [anon_sym_sizeof] = ACTIONS(2224),
    [anon_sym___alignof__] = ACTIONS(2224),
    [anon_sym___alignof] = ACTIONS(2224),
    [anon_sym__alignof] = ACTIONS(2224),
    [anon_sym_alignof] = ACTIONS(2224),
    [anon_sym__Alignof] = ACTIONS(2224),
    [anon_sym_offsetof] = ACTIONS(2224),
    [anon_sym__Generic] = ACTIONS(2224),
    [anon_sym_asm] = ACTIONS(2224),
    [anon_sym___asm__] = ACTIONS(2224),
    [sym_number_literal] = ACTIONS(2226),
    [anon_sym_L_SQUOTE] = ACTIONS(2226),
    [anon_sym_u_SQUOTE] = ACTIONS(2226),
    [anon_sym_U_SQUOTE] = ACTIONS(2226),
    [anon_sym_u8_SQUOTE] = ACTIONS(2226),
    [anon_sym_SQUOTE] = ACTIONS(2226),
    [anon_sym_L_DQUOTE] = ACTIONS(2226),
    [anon_sym_u_DQUOTE] = ACTIONS(2226),
    [anon_sym_U_DQUOTE] = ACTIONS(2226),
    [anon_sym_u8_DQUOTE] = ACTIONS(2226),
    [anon_sym_DQUOTE] = ACTIONS(2226),
    [sym_true] = ACTIONS(2224),
    [sym_false] = ACTIONS(2224),
    [anon_sym_NULL] = ACTIONS(2224),
    [anon_sym_nullptr] = ACTIONS(2224),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2224),
    [anon_sym_decltype] = ACTIONS(2224),
    [sym_virtual] = ACTIONS(2224),
    [anon_sym_explicit] = ACTIONS(2224),
    [anon_sym_typename] = ACTIONS(2224),
    [anon_sym_template] = ACTIONS(2224),
    [anon_sym_operator] = ACTIONS(2224),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_delete] = ACTIONS(2224),
    [anon_sym_throw] = ACTIONS(2224),
    [anon_sym_namespace] = ACTIONS(2224),
    [anon_sym_using] = ACTIONS(2224),
    [anon_sym_static_assert] = ACTIONS(2224),
    [anon_sym_concept] = ACTIONS(2224),
    [anon_sym_co_return] = ACTIONS(2224),
    [anon_sym_co_yield] = ACTIONS(2224),
    [anon_sym_R_DQUOTE] = ACTIONS(2226),
    [anon_sym_LR_DQUOTE] = ACTIONS(2226),
    [anon_sym_uR_DQUOTE] = ACTIONS(2226),
    [anon_sym_UR_DQUOTE] = ACTIONS(2226),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2226),
    [anon_sym_co_await] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(2224),
    [anon_sym_requires] = ACTIONS(2224),
    [sym_this] = ACTIONS(2224),
    [anon_sym_discard] = ACTIONS(2224),
    [anon_sym_precise] = ACTIONS(2224),
    [anon_sym_shared] = ACTIONS(2224),
    [anon_sym_groupshared] = ACTIONS(2224),
    [anon_sym_uniform] = ACTIONS(2224),
    [anon_sym_row_major] = ACTIONS(2224),
    [anon_sym_column_major] = ACTIONS(2224),
    [anon_sym_globallycoherent] = ACTIONS(2224),
    [anon_sym_centroid] = ACTIONS(2224),
    [anon_sym_noperspective] = ACTIONS(2224),
    [anon_sym_nointerpolation] = ACTIONS(2224),
    [anon_sym_sample] = ACTIONS(2224),
    [anon_sym_linear] = ACTIONS(2224),
    [anon_sym_snorm] = ACTIONS(2224),
    [anon_sym_unorm] = ACTIONS(2224),
    [anon_sym_point] = ACTIONS(2224),
    [anon_sym_line] = ACTIONS(2224),
    [anon_sym_triangleadj] = ACTIONS(2224),
    [anon_sym_lineadj] = ACTIONS(2224),
    [anon_sym_triangle] = ACTIONS(2224),
    [anon_sym_cbuffer] = ACTIONS(2224),
  },
  [482] = {
    [sym_identifier] = ACTIONS(2228),
    [aux_sym_preproc_include_token1] = ACTIONS(2228),
    [aux_sym_preproc_def_token1] = ACTIONS(2228),
    [aux_sym_preproc_if_token1] = ACTIONS(2228),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2228),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2228),
    [sym_preproc_directive] = ACTIONS(2228),
    [anon_sym_LPAREN2] = ACTIONS(2230),
    [anon_sym_BANG] = ACTIONS(2230),
    [anon_sym_TILDE] = ACTIONS(2230),
    [anon_sym_DASH] = ACTIONS(2228),
    [anon_sym_PLUS] = ACTIONS(2228),
    [anon_sym_STAR] = ACTIONS(2230),
    [anon_sym_AMP_AMP] = ACTIONS(2230),
    [anon_sym_AMP] = ACTIONS(2228),
    [anon_sym_SEMI] = ACTIONS(2230),
    [anon_sym___extension__] = ACTIONS(2228),
    [anon_sym_typedef] = ACTIONS(2228),
    [anon_sym_in] = ACTIONS(2228),
    [anon_sym_out] = ACTIONS(2228),
    [anon_sym_inout] = ACTIONS(2228),
    [anon_sym_extern] = ACTIONS(2228),
    [anon_sym___attribute__] = ACTIONS(2228),
    [anon_sym_COLON_COLON] = ACTIONS(2230),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2230),
    [anon_sym___declspec] = ACTIONS(2228),
    [anon_sym___based] = ACTIONS(2228),
    [anon_sym___cdecl] = ACTIONS(2228),
    [anon_sym___clrcall] = ACTIONS(2228),
    [anon_sym___stdcall] = ACTIONS(2228),
    [anon_sym___fastcall] = ACTIONS(2228),
    [anon_sym___thiscall] = ACTIONS(2228),
    [anon_sym___vectorcall] = ACTIONS(2228),
    [anon_sym_LBRACE] = ACTIONS(2230),
    [anon_sym_RBRACE] = ACTIONS(2230),
    [anon_sym_signed] = ACTIONS(2228),
    [anon_sym_unsigned] = ACTIONS(2228),
    [anon_sym_long] = ACTIONS(2228),
    [anon_sym_short] = ACTIONS(2228),
    [anon_sym_LBRACK] = ACTIONS(2228),
    [anon_sym_static] = ACTIONS(2228),
    [anon_sym_register] = ACTIONS(2228),
    [anon_sym_inline] = ACTIONS(2228),
    [anon_sym___inline] = ACTIONS(2228),
    [anon_sym___inline__] = ACTIONS(2228),
    [anon_sym___forceinline] = ACTIONS(2228),
    [anon_sym_thread_local] = ACTIONS(2228),
    [anon_sym___thread] = ACTIONS(2228),
    [anon_sym_const] = ACTIONS(2228),
    [anon_sym_constexpr] = ACTIONS(2228),
    [anon_sym_volatile] = ACTIONS(2228),
    [anon_sym_restrict] = ACTIONS(2228),
    [anon_sym___restrict__] = ACTIONS(2228),
    [anon_sym__Atomic] = ACTIONS(2228),
    [anon_sym__Noreturn] = ACTIONS(2228),
    [anon_sym_noreturn] = ACTIONS(2228),
    [anon_sym_mutable] = ACTIONS(2228),
    [anon_sym_constinit] = ACTIONS(2228),
    [anon_sym_consteval] = ACTIONS(2228),
    [anon_sym_alignas] = ACTIONS(2228),
    [anon_sym__Alignas] = ACTIONS(2228),
    [sym_primitive_type] = ACTIONS(2228),
    [anon_sym_enum] = ACTIONS(2228),
    [anon_sym_class] = ACTIONS(2228),
    [anon_sym_struct] = ACTIONS(2228),
    [anon_sym_union] = ACTIONS(2228),
    [anon_sym_if] = ACTIONS(2228),
    [anon_sym_else] = ACTIONS(2228),
    [anon_sym_switch] = ACTIONS(2228),
    [anon_sym_case] = ACTIONS(2228),
    [anon_sym_default] = ACTIONS(2228),
    [anon_sym_while] = ACTIONS(2228),
    [anon_sym_do] = ACTIONS(2228),
    [anon_sym_for] = ACTIONS(2228),
    [anon_sym_return] = ACTIONS(2228),
    [anon_sym_break] = ACTIONS(2228),
    [anon_sym_continue] = ACTIONS(2228),
    [anon_sym_goto] = ACTIONS(2228),
    [anon_sym___try] = ACTIONS(2228),
    [anon_sym___leave] = ACTIONS(2228),
    [anon_sym_not] = ACTIONS(2228),
    [anon_sym_compl] = ACTIONS(2228),
    [anon_sym_DASH_DASH] = ACTIONS(2230),
    [anon_sym_PLUS_PLUS] = ACTIONS(2230),
    [anon_sym_sizeof] = ACTIONS(2228),
    [anon_sym___alignof__] = ACTIONS(2228),
    [anon_sym___alignof] = ACTIONS(2228),
    [anon_sym__alignof] = ACTIONS(2228),
    [anon_sym_alignof] = ACTIONS(2228),
    [anon_sym__Alignof] = ACTIONS(2228),
    [anon_sym_offsetof] = ACTIONS(2228),
    [anon_sym__Generic] = ACTIONS(2228),
    [anon_sym_asm] = ACTIONS(2228),
    [anon_sym___asm__] = ACTIONS(2228),
    [sym_number_literal] = ACTIONS(2230),
    [anon_sym_L_SQUOTE] = ACTIONS(2230),
    [anon_sym_u_SQUOTE] = ACTIONS(2230),
    [anon_sym_U_SQUOTE] = ACTIONS(2230),
    [anon_sym_u8_SQUOTE] = ACTIONS(2230),
    [anon_sym_SQUOTE] = ACTIONS(2230),
    [anon_sym_L_DQUOTE] = ACTIONS(2230),
    [anon_sym_u_DQUOTE] = ACTIONS(2230),
    [anon_sym_U_DQUOTE] = ACTIONS(2230),
    [anon_sym_u8_DQUOTE] = ACTIONS(2230),
    [anon_sym_DQUOTE] = ACTIONS(2230),
    [sym_true] = ACTIONS(2228),
    [sym_false] = ACTIONS(2228),
    [anon_sym_NULL] = ACTIONS(2228),
    [anon_sym_nullptr] = ACTIONS(2228),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2228),
    [anon_sym_decltype] = ACTIONS(2228),
    [sym_virtual] = ACTIONS(2228),
    [anon_sym_explicit] = ACTIONS(2228),
    [anon_sym_typename] = ACTIONS(2228),
    [anon_sym_template] = ACTIONS(2228),
    [anon_sym_operator] = ACTIONS(2228),
    [anon_sym_try] = ACTIONS(2228),
    [anon_sym_delete] = ACTIONS(2228),
    [anon_sym_throw] = ACTIONS(2228),
    [anon_sym_namespace] = ACTIONS(2228),
    [anon_sym_using] = ACTIONS(2228),
    [anon_sym_static_assert] = ACTIONS(2228),
    [anon_sym_concept] = ACTIONS(2228),
    [anon_sym_co_return] = ACTIONS(2228),
    [anon_sym_co_yield] = ACTIONS(2228),
    [anon_sym_R_DQUOTE] = ACTIONS(2230),
    [anon_sym_LR_DQUOTE] = ACTIONS(2230),
    [anon_sym_uR_DQUOTE] = ACTIONS(2230),
    [anon_sym_UR_DQUOTE] = ACTIONS(2230),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2230),
    [anon_sym_co_await] = ACTIONS(2228),
    [anon_sym_new] = ACTIONS(2228),
    [anon_sym_requires] = ACTIONS(2228),
    [sym_this] = ACTIONS(2228),
    [anon_sym_discard] = ACTIONS(2228),
    [anon_sym_precise] = ACTIONS(2228),
    [anon_sym_shared] = ACTIONS(2228),
    [anon_sym_groupshared] = ACTIONS(2228),
    [anon_sym_uniform] = ACTIONS(2228),
    [anon_sym_row_major] = ACTIONS(2228),
    [anon_sym_column_major] = ACTIONS(2228),
    [anon_sym_globallycoherent] = ACTIONS(2228),
    [anon_sym_centroid] = ACTIONS(2228),
    [anon_sym_noperspective] = ACTIONS(2228),
    [anon_sym_nointerpolation] = ACTIONS(2228),
    [anon_sym_sample] = ACTIONS(2228),
    [anon_sym_linear] = ACTIONS(2228),
    [anon_sym_snorm] = ACTIONS(2228),
    [anon_sym_unorm] = ACTIONS(2228),
    [anon_sym_point] = ACTIONS(2228),
    [anon_sym_line] = ACTIONS(2228),
    [anon_sym_triangleadj] = ACTIONS(2228),
    [anon_sym_lineadj] = ACTIONS(2228),
    [anon_sym_triangle] = ACTIONS(2228),
    [anon_sym_cbuffer] = ACTIONS(2228),
  },
  [483] = {
    [sym_identifier] = ACTIONS(2236),
    [aux_sym_preproc_include_token1] = ACTIONS(2236),
    [aux_sym_preproc_def_token1] = ACTIONS(2236),
    [aux_sym_preproc_if_token1] = ACTIONS(2236),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2236),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2236),
    [sym_preproc_directive] = ACTIONS(2236),
    [anon_sym_LPAREN2] = ACTIONS(2238),
    [anon_sym_BANG] = ACTIONS(2238),
    [anon_sym_TILDE] = ACTIONS(2238),
    [anon_sym_DASH] = ACTIONS(2236),
    [anon_sym_PLUS] = ACTIONS(2236),
    [anon_sym_STAR] = ACTIONS(2238),
    [anon_sym_AMP_AMP] = ACTIONS(2238),
    [anon_sym_AMP] = ACTIONS(2236),
    [anon_sym_SEMI] = ACTIONS(2238),
    [anon_sym___extension__] = ACTIONS(2236),
    [anon_sym_typedef] = ACTIONS(2236),
    [anon_sym_in] = ACTIONS(2236),
    [anon_sym_out] = ACTIONS(2236),
    [anon_sym_inout] = ACTIONS(2236),
    [anon_sym_extern] = ACTIONS(2236),
    [anon_sym___attribute__] = ACTIONS(2236),
    [anon_sym_COLON_COLON] = ACTIONS(2238),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2238),
    [anon_sym___declspec] = ACTIONS(2236),
    [anon_sym___based] = ACTIONS(2236),
    [anon_sym___cdecl] = ACTIONS(2236),
    [anon_sym___clrcall] = ACTIONS(2236),
    [anon_sym___stdcall] = ACTIONS(2236),
    [anon_sym___fastcall] = ACTIONS(2236),
    [anon_sym___thiscall] = ACTIONS(2236),
    [anon_sym___vectorcall] = ACTIONS(2236),
    [anon_sym_LBRACE] = ACTIONS(2238),
    [anon_sym_RBRACE] = ACTIONS(2238),
    [anon_sym_signed] = ACTIONS(2236),
    [anon_sym_unsigned] = ACTIONS(2236),
    [anon_sym_long] = ACTIONS(2236),
    [anon_sym_short] = ACTIONS(2236),
    [anon_sym_LBRACK] = ACTIONS(2236),
    [anon_sym_static] = ACTIONS(2236),
    [anon_sym_register] = ACTIONS(2236),
    [anon_sym_inline] = ACTIONS(2236),
    [anon_sym___inline] = ACTIONS(2236),
    [anon_sym___inline__] = ACTIONS(2236),
    [anon_sym___forceinline] = ACTIONS(2236),
    [anon_sym_thread_local] = ACTIONS(2236),
    [anon_sym___thread] = ACTIONS(2236),
    [anon_sym_const] = ACTIONS(2236),
    [anon_sym_constexpr] = ACTIONS(2236),
    [anon_sym_volatile] = ACTIONS(2236),
    [anon_sym_restrict] = ACTIONS(2236),
    [anon_sym___restrict__] = ACTIONS(2236),
    [anon_sym__Atomic] = ACTIONS(2236),
    [anon_sym__Noreturn] = ACTIONS(2236),
    [anon_sym_noreturn] = ACTIONS(2236),
    [anon_sym_mutable] = ACTIONS(2236),
    [anon_sym_constinit] = ACTIONS(2236),
    [anon_sym_consteval] = ACTIONS(2236),
    [anon_sym_alignas] = ACTIONS(2236),
    [anon_sym__Alignas] = ACTIONS(2236),
    [sym_primitive_type] = ACTIONS(2236),
    [anon_sym_enum] = ACTIONS(2236),
    [anon_sym_class] = ACTIONS(2236),
    [anon_sym_struct] = ACTIONS(2236),
    [anon_sym_union] = ACTIONS(2236),
    [anon_sym_if] = ACTIONS(2236),
    [anon_sym_else] = ACTIONS(2236),
    [anon_sym_switch] = ACTIONS(2236),
    [anon_sym_case] = ACTIONS(2236),
    [anon_sym_default] = ACTIONS(2236),
    [anon_sym_while] = ACTIONS(2236),
    [anon_sym_do] = ACTIONS(2236),
    [anon_sym_for] = ACTIONS(2236),
    [anon_sym_return] = ACTIONS(2236),
    [anon_sym_break] = ACTIONS(2236),
    [anon_sym_continue] = ACTIONS(2236),
    [anon_sym_goto] = ACTIONS(2236),
    [anon_sym___try] = ACTIONS(2236),
    [anon_sym___leave] = ACTIONS(2236),
    [anon_sym_not] = ACTIONS(2236),
    [anon_sym_compl] = ACTIONS(2236),
    [anon_sym_DASH_DASH] = ACTIONS(2238),
    [anon_sym_PLUS_PLUS] = ACTIONS(2238),
    [anon_sym_sizeof] = ACTIONS(2236),
    [anon_sym___alignof__] = ACTIONS(2236),
    [anon_sym___alignof] = ACTIONS(2236),
    [anon_sym__alignof] = ACTIONS(2236),
    [anon_sym_alignof] = ACTIONS(2236),
    [anon_sym__Alignof] = ACTIONS(2236),
    [anon_sym_offsetof] = ACTIONS(2236),
    [anon_sym__Generic] = ACTIONS(2236),
    [anon_sym_asm] = ACTIONS(2236),
    [anon_sym___asm__] = ACTIONS(2236),
    [sym_number_literal] = ACTIONS(2238),
    [anon_sym_L_SQUOTE] = ACTIONS(2238),
    [anon_sym_u_SQUOTE] = ACTIONS(2238),
    [anon_sym_U_SQUOTE] = ACTIONS(2238),
    [anon_sym_u8_SQUOTE] = ACTIONS(2238),
    [anon_sym_SQUOTE] = ACTIONS(2238),
    [anon_sym_L_DQUOTE] = ACTIONS(2238),
    [anon_sym_u_DQUOTE] = ACTIONS(2238),
    [anon_sym_U_DQUOTE] = ACTIONS(2238),
    [anon_sym_u8_DQUOTE] = ACTIONS(2238),
    [anon_sym_DQUOTE] = ACTIONS(2238),
    [sym_true] = ACTIONS(2236),
    [sym_false] = ACTIONS(2236),
    [anon_sym_NULL] = ACTIONS(2236),
    [anon_sym_nullptr] = ACTIONS(2236),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2236),
    [anon_sym_decltype] = ACTIONS(2236),
    [sym_virtual] = ACTIONS(2236),
    [anon_sym_explicit] = ACTIONS(2236),
    [anon_sym_typename] = ACTIONS(2236),
    [anon_sym_template] = ACTIONS(2236),
    [anon_sym_operator] = ACTIONS(2236),
    [anon_sym_try] = ACTIONS(2236),
    [anon_sym_delete] = ACTIONS(2236),
    [anon_sym_throw] = ACTIONS(2236),
    [anon_sym_namespace] = ACTIONS(2236),
    [anon_sym_using] = ACTIONS(2236),
    [anon_sym_static_assert] = ACTIONS(2236),
    [anon_sym_concept] = ACTIONS(2236),
    [anon_sym_co_return] = ACTIONS(2236),
    [anon_sym_co_yield] = ACTIONS(2236),
    [anon_sym_R_DQUOTE] = ACTIONS(2238),
    [anon_sym_LR_DQUOTE] = ACTIONS(2238),
    [anon_sym_uR_DQUOTE] = ACTIONS(2238),
    [anon_sym_UR_DQUOTE] = ACTIONS(2238),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2238),
    [anon_sym_co_await] = ACTIONS(2236),
    [anon_sym_new] = ACTIONS(2236),
    [anon_sym_requires] = ACTIONS(2236),
    [sym_this] = ACTIONS(2236),
    [anon_sym_discard] = ACTIONS(2236),
    [anon_sym_precise] = ACTIONS(2236),
    [anon_sym_shared] = ACTIONS(2236),
    [anon_sym_groupshared] = ACTIONS(2236),
    [anon_sym_uniform] = ACTIONS(2236),
    [anon_sym_row_major] = ACTIONS(2236),
    [anon_sym_column_major] = ACTIONS(2236),
    [anon_sym_globallycoherent] = ACTIONS(2236),
    [anon_sym_centroid] = ACTIONS(2236),
    [anon_sym_noperspective] = ACTIONS(2236),
    [anon_sym_nointerpolation] = ACTIONS(2236),
    [anon_sym_sample] = ACTIONS(2236),
    [anon_sym_linear] = ACTIONS(2236),
    [anon_sym_snorm] = ACTIONS(2236),
    [anon_sym_unorm] = ACTIONS(2236),
    [anon_sym_point] = ACTIONS(2236),
    [anon_sym_line] = ACTIONS(2236),
    [anon_sym_triangleadj] = ACTIONS(2236),
    [anon_sym_lineadj] = ACTIONS(2236),
    [anon_sym_triangle] = ACTIONS(2236),
    [anon_sym_cbuffer] = ACTIONS(2236),
  },
  [484] = {
    [sym_identifier] = ACTIONS(2094),
    [aux_sym_preproc_include_token1] = ACTIONS(2094),
    [aux_sym_preproc_def_token1] = ACTIONS(2094),
    [aux_sym_preproc_if_token1] = ACTIONS(2094),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2094),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2094),
    [sym_preproc_directive] = ACTIONS(2094),
    [anon_sym_LPAREN2] = ACTIONS(2096),
    [anon_sym_BANG] = ACTIONS(2096),
    [anon_sym_TILDE] = ACTIONS(2096),
    [anon_sym_DASH] = ACTIONS(2094),
    [anon_sym_PLUS] = ACTIONS(2094),
    [anon_sym_STAR] = ACTIONS(2096),
    [anon_sym_AMP_AMP] = ACTIONS(2096),
    [anon_sym_AMP] = ACTIONS(2094),
    [anon_sym_SEMI] = ACTIONS(2096),
    [anon_sym___extension__] = ACTIONS(2094),
    [anon_sym_typedef] = ACTIONS(2094),
    [anon_sym_in] = ACTIONS(2094),
    [anon_sym_out] = ACTIONS(2094),
    [anon_sym_inout] = ACTIONS(2094),
    [anon_sym_extern] = ACTIONS(2094),
    [anon_sym___attribute__] = ACTIONS(2094),
    [anon_sym_COLON_COLON] = ACTIONS(2096),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2096),
    [anon_sym___declspec] = ACTIONS(2094),
    [anon_sym___based] = ACTIONS(2094),
    [anon_sym___cdecl] = ACTIONS(2094),
    [anon_sym___clrcall] = ACTIONS(2094),
    [anon_sym___stdcall] = ACTIONS(2094),
    [anon_sym___fastcall] = ACTIONS(2094),
    [anon_sym___thiscall] = ACTIONS(2094),
    [anon_sym___vectorcall] = ACTIONS(2094),
    [anon_sym_LBRACE] = ACTIONS(2096),
    [anon_sym_RBRACE] = ACTIONS(2096),
    [anon_sym_signed] = ACTIONS(2094),
    [anon_sym_unsigned] = ACTIONS(2094),
    [anon_sym_long] = ACTIONS(2094),
    [anon_sym_short] = ACTIONS(2094),
    [anon_sym_LBRACK] = ACTIONS(2094),
    [anon_sym_static] = ACTIONS(2094),
    [anon_sym_register] = ACTIONS(2094),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym___inline] = ACTIONS(2094),
    [anon_sym___inline__] = ACTIONS(2094),
    [anon_sym___forceinline] = ACTIONS(2094),
    [anon_sym_thread_local] = ACTIONS(2094),
    [anon_sym___thread] = ACTIONS(2094),
    [anon_sym_const] = ACTIONS(2094),
    [anon_sym_constexpr] = ACTIONS(2094),
    [anon_sym_volatile] = ACTIONS(2094),
    [anon_sym_restrict] = ACTIONS(2094),
    [anon_sym___restrict__] = ACTIONS(2094),
    [anon_sym__Atomic] = ACTIONS(2094),
    [anon_sym__Noreturn] = ACTIONS(2094),
    [anon_sym_noreturn] = ACTIONS(2094),
    [anon_sym_mutable] = ACTIONS(2094),
    [anon_sym_constinit] = ACTIONS(2094),
    [anon_sym_consteval] = ACTIONS(2094),
    [anon_sym_alignas] = ACTIONS(2094),
    [anon_sym__Alignas] = ACTIONS(2094),
    [sym_primitive_type] = ACTIONS(2094),
    [anon_sym_enum] = ACTIONS(2094),
    [anon_sym_class] = ACTIONS(2094),
    [anon_sym_struct] = ACTIONS(2094),
    [anon_sym_union] = ACTIONS(2094),
    [anon_sym_if] = ACTIONS(2094),
    [anon_sym_else] = ACTIONS(2094),
    [anon_sym_switch] = ACTIONS(2094),
    [anon_sym_case] = ACTIONS(2094),
    [anon_sym_default] = ACTIONS(2094),
    [anon_sym_while] = ACTIONS(2094),
    [anon_sym_do] = ACTIONS(2094),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_return] = ACTIONS(2094),
    [anon_sym_break] = ACTIONS(2094),
    [anon_sym_continue] = ACTIONS(2094),
    [anon_sym_goto] = ACTIONS(2094),
    [anon_sym___try] = ACTIONS(2094),
    [anon_sym___leave] = ACTIONS(2094),
    [anon_sym_not] = ACTIONS(2094),
    [anon_sym_compl] = ACTIONS(2094),
    [anon_sym_DASH_DASH] = ACTIONS(2096),
    [anon_sym_PLUS_PLUS] = ACTIONS(2096),
    [anon_sym_sizeof] = ACTIONS(2094),
    [anon_sym___alignof__] = ACTIONS(2094),
    [anon_sym___alignof] = ACTIONS(2094),
    [anon_sym__alignof] = ACTIONS(2094),
    [anon_sym_alignof] = ACTIONS(2094),
    [anon_sym__Alignof] = ACTIONS(2094),
    [anon_sym_offsetof] = ACTIONS(2094),
    [anon_sym__Generic] = ACTIONS(2094),
    [anon_sym_asm] = ACTIONS(2094),
    [anon_sym___asm__] = ACTIONS(2094),
    [sym_number_literal] = ACTIONS(2096),
    [anon_sym_L_SQUOTE] = ACTIONS(2096),
    [anon_sym_u_SQUOTE] = ACTIONS(2096),
    [anon_sym_U_SQUOTE] = ACTIONS(2096),
    [anon_sym_u8_SQUOTE] = ACTIONS(2096),
    [anon_sym_SQUOTE] = ACTIONS(2096),
    [anon_sym_L_DQUOTE] = ACTIONS(2096),
    [anon_sym_u_DQUOTE] = ACTIONS(2096),
    [anon_sym_U_DQUOTE] = ACTIONS(2096),
    [anon_sym_u8_DQUOTE] = ACTIONS(2096),
    [anon_sym_DQUOTE] = ACTIONS(2096),
    [sym_true] = ACTIONS(2094),
    [sym_false] = ACTIONS(2094),
    [anon_sym_NULL] = ACTIONS(2094),
    [anon_sym_nullptr] = ACTIONS(2094),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2094),
    [anon_sym_decltype] = ACTIONS(2094),
    [sym_virtual] = ACTIONS(2094),
    [anon_sym_explicit] = ACTIONS(2094),
    [anon_sym_typename] = ACTIONS(2094),
    [anon_sym_template] = ACTIONS(2094),
    [anon_sym_operator] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2094),
    [anon_sym_delete] = ACTIONS(2094),
    [anon_sym_throw] = ACTIONS(2094),
    [anon_sym_namespace] = ACTIONS(2094),
    [anon_sym_using] = ACTIONS(2094),
    [anon_sym_static_assert] = ACTIONS(2094),
    [anon_sym_concept] = ACTIONS(2094),
    [anon_sym_co_return] = ACTIONS(2094),
    [anon_sym_co_yield] = ACTIONS(2094),
    [anon_sym_R_DQUOTE] = ACTIONS(2096),
    [anon_sym_LR_DQUOTE] = ACTIONS(2096),
    [anon_sym_uR_DQUOTE] = ACTIONS(2096),
    [anon_sym_UR_DQUOTE] = ACTIONS(2096),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2096),
    [anon_sym_co_await] = ACTIONS(2094),
    [anon_sym_new] = ACTIONS(2094),
    [anon_sym_requires] = ACTIONS(2094),
    [sym_this] = ACTIONS(2094),
    [anon_sym_discard] = ACTIONS(2094),
    [anon_sym_precise] = ACTIONS(2094),
    [anon_sym_shared] = ACTIONS(2094),
    [anon_sym_groupshared] = ACTIONS(2094),
    [anon_sym_uniform] = ACTIONS(2094),
    [anon_sym_row_major] = ACTIONS(2094),
    [anon_sym_column_major] = ACTIONS(2094),
    [anon_sym_globallycoherent] = ACTIONS(2094),
    [anon_sym_centroid] = ACTIONS(2094),
    [anon_sym_noperspective] = ACTIONS(2094),
    [anon_sym_nointerpolation] = ACTIONS(2094),
    [anon_sym_sample] = ACTIONS(2094),
    [anon_sym_linear] = ACTIONS(2094),
    [anon_sym_snorm] = ACTIONS(2094),
    [anon_sym_unorm] = ACTIONS(2094),
    [anon_sym_point] = ACTIONS(2094),
    [anon_sym_line] = ACTIONS(2094),
    [anon_sym_triangleadj] = ACTIONS(2094),
    [anon_sym_lineadj] = ACTIONS(2094),
    [anon_sym_triangle] = ACTIONS(2094),
    [anon_sym_cbuffer] = ACTIONS(2094),
  },
  [485] = {
    [sym_identifier] = ACTIONS(2240),
    [aux_sym_preproc_include_token1] = ACTIONS(2240),
    [aux_sym_preproc_def_token1] = ACTIONS(2240),
    [aux_sym_preproc_if_token1] = ACTIONS(2240),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2240),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2240),
    [sym_preproc_directive] = ACTIONS(2240),
    [anon_sym_LPAREN2] = ACTIONS(2242),
    [anon_sym_BANG] = ACTIONS(2242),
    [anon_sym_TILDE] = ACTIONS(2242),
    [anon_sym_DASH] = ACTIONS(2240),
    [anon_sym_PLUS] = ACTIONS(2240),
    [anon_sym_STAR] = ACTIONS(2242),
    [anon_sym_AMP_AMP] = ACTIONS(2242),
    [anon_sym_AMP] = ACTIONS(2240),
    [anon_sym_SEMI] = ACTIONS(2242),
    [anon_sym___extension__] = ACTIONS(2240),
    [anon_sym_typedef] = ACTIONS(2240),
    [anon_sym_in] = ACTIONS(2240),
    [anon_sym_out] = ACTIONS(2240),
    [anon_sym_inout] = ACTIONS(2240),
    [anon_sym_extern] = ACTIONS(2240),
    [anon_sym___attribute__] = ACTIONS(2240),
    [anon_sym_COLON_COLON] = ACTIONS(2242),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2242),
    [anon_sym___declspec] = ACTIONS(2240),
    [anon_sym___based] = ACTIONS(2240),
    [anon_sym___cdecl] = ACTIONS(2240),
    [anon_sym___clrcall] = ACTIONS(2240),
    [anon_sym___stdcall] = ACTIONS(2240),
    [anon_sym___fastcall] = ACTIONS(2240),
    [anon_sym___thiscall] = ACTIONS(2240),
    [anon_sym___vectorcall] = ACTIONS(2240),
    [anon_sym_LBRACE] = ACTIONS(2242),
    [anon_sym_RBRACE] = ACTIONS(2242),
    [anon_sym_signed] = ACTIONS(2240),
    [anon_sym_unsigned] = ACTIONS(2240),
    [anon_sym_long] = ACTIONS(2240),
    [anon_sym_short] = ACTIONS(2240),
    [anon_sym_LBRACK] = ACTIONS(2240),
    [anon_sym_static] = ACTIONS(2240),
    [anon_sym_register] = ACTIONS(2240),
    [anon_sym_inline] = ACTIONS(2240),
    [anon_sym___inline] = ACTIONS(2240),
    [anon_sym___inline__] = ACTIONS(2240),
    [anon_sym___forceinline] = ACTIONS(2240),
    [anon_sym_thread_local] = ACTIONS(2240),
    [anon_sym___thread] = ACTIONS(2240),
    [anon_sym_const] = ACTIONS(2240),
    [anon_sym_constexpr] = ACTIONS(2240),
    [anon_sym_volatile] = ACTIONS(2240),
    [anon_sym_restrict] = ACTIONS(2240),
    [anon_sym___restrict__] = ACTIONS(2240),
    [anon_sym__Atomic] = ACTIONS(2240),
    [anon_sym__Noreturn] = ACTIONS(2240),
    [anon_sym_noreturn] = ACTIONS(2240),
    [anon_sym_mutable] = ACTIONS(2240),
    [anon_sym_constinit] = ACTIONS(2240),
    [anon_sym_consteval] = ACTIONS(2240),
    [anon_sym_alignas] = ACTIONS(2240),
    [anon_sym__Alignas] = ACTIONS(2240),
    [sym_primitive_type] = ACTIONS(2240),
    [anon_sym_enum] = ACTIONS(2240),
    [anon_sym_class] = ACTIONS(2240),
    [anon_sym_struct] = ACTIONS(2240),
    [anon_sym_union] = ACTIONS(2240),
    [anon_sym_if] = ACTIONS(2240),
    [anon_sym_else] = ACTIONS(2240),
    [anon_sym_switch] = ACTIONS(2240),
    [anon_sym_case] = ACTIONS(2240),
    [anon_sym_default] = ACTIONS(2240),
    [anon_sym_while] = ACTIONS(2240),
    [anon_sym_do] = ACTIONS(2240),
    [anon_sym_for] = ACTIONS(2240),
    [anon_sym_return] = ACTIONS(2240),
    [anon_sym_break] = ACTIONS(2240),
    [anon_sym_continue] = ACTIONS(2240),
    [anon_sym_goto] = ACTIONS(2240),
    [anon_sym___try] = ACTIONS(2240),
    [anon_sym___leave] = ACTIONS(2240),
    [anon_sym_not] = ACTIONS(2240),
    [anon_sym_compl] = ACTIONS(2240),
    [anon_sym_DASH_DASH] = ACTIONS(2242),
    [anon_sym_PLUS_PLUS] = ACTIONS(2242),
    [anon_sym_sizeof] = ACTIONS(2240),
    [anon_sym___alignof__] = ACTIONS(2240),
    [anon_sym___alignof] = ACTIONS(2240),
    [anon_sym__alignof] = ACTIONS(2240),
    [anon_sym_alignof] = ACTIONS(2240),
    [anon_sym__Alignof] = ACTIONS(2240),
    [anon_sym_offsetof] = ACTIONS(2240),
    [anon_sym__Generic] = ACTIONS(2240),
    [anon_sym_asm] = ACTIONS(2240),
    [anon_sym___asm__] = ACTIONS(2240),
    [sym_number_literal] = ACTIONS(2242),
    [anon_sym_L_SQUOTE] = ACTIONS(2242),
    [anon_sym_u_SQUOTE] = ACTIONS(2242),
    [anon_sym_U_SQUOTE] = ACTIONS(2242),
    [anon_sym_u8_SQUOTE] = ACTIONS(2242),
    [anon_sym_SQUOTE] = ACTIONS(2242),
    [anon_sym_L_DQUOTE] = ACTIONS(2242),
    [anon_sym_u_DQUOTE] = ACTIONS(2242),
    [anon_sym_U_DQUOTE] = ACTIONS(2242),
    [anon_sym_u8_DQUOTE] = ACTIONS(2242),
    [anon_sym_DQUOTE] = ACTIONS(2242),
    [sym_true] = ACTIONS(2240),
    [sym_false] = ACTIONS(2240),
    [anon_sym_NULL] = ACTIONS(2240),
    [anon_sym_nullptr] = ACTIONS(2240),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2240),
    [anon_sym_decltype] = ACTIONS(2240),
    [sym_virtual] = ACTIONS(2240),
    [anon_sym_explicit] = ACTIONS(2240),
    [anon_sym_typename] = ACTIONS(2240),
    [anon_sym_template] = ACTIONS(2240),
    [anon_sym_operator] = ACTIONS(2240),
    [anon_sym_try] = ACTIONS(2240),
    [anon_sym_delete] = ACTIONS(2240),
    [anon_sym_throw] = ACTIONS(2240),
    [anon_sym_namespace] = ACTIONS(2240),
    [anon_sym_using] = ACTIONS(2240),
    [anon_sym_static_assert] = ACTIONS(2240),
    [anon_sym_concept] = ACTIONS(2240),
    [anon_sym_co_return] = ACTIONS(2240),
    [anon_sym_co_yield] = ACTIONS(2240),
    [anon_sym_R_DQUOTE] = ACTIONS(2242),
    [anon_sym_LR_DQUOTE] = ACTIONS(2242),
    [anon_sym_uR_DQUOTE] = ACTIONS(2242),
    [anon_sym_UR_DQUOTE] = ACTIONS(2242),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2242),
    [anon_sym_co_await] = ACTIONS(2240),
    [anon_sym_new] = ACTIONS(2240),
    [anon_sym_requires] = ACTIONS(2240),
    [sym_this] = ACTIONS(2240),
    [anon_sym_discard] = ACTIONS(2240),
    [anon_sym_precise] = ACTIONS(2240),
    [anon_sym_shared] = ACTIONS(2240),
    [anon_sym_groupshared] = ACTIONS(2240),
    [anon_sym_uniform] = ACTIONS(2240),
    [anon_sym_row_major] = ACTIONS(2240),
    [anon_sym_column_major] = ACTIONS(2240),
    [anon_sym_globallycoherent] = ACTIONS(2240),
    [anon_sym_centroid] = ACTIONS(2240),
    [anon_sym_noperspective] = ACTIONS(2240),
    [anon_sym_nointerpolation] = ACTIONS(2240),
    [anon_sym_sample] = ACTIONS(2240),
    [anon_sym_linear] = ACTIONS(2240),
    [anon_sym_snorm] = ACTIONS(2240),
    [anon_sym_unorm] = ACTIONS(2240),
    [anon_sym_point] = ACTIONS(2240),
    [anon_sym_line] = ACTIONS(2240),
    [anon_sym_triangleadj] = ACTIONS(2240),
    [anon_sym_lineadj] = ACTIONS(2240),
    [anon_sym_triangle] = ACTIONS(2240),
    [anon_sym_cbuffer] = ACTIONS(2240),
  },
  [486] = {
    [sym_identifier] = ACTIONS(2244),
    [aux_sym_preproc_include_token1] = ACTIONS(2244),
    [aux_sym_preproc_def_token1] = ACTIONS(2244),
    [aux_sym_preproc_if_token1] = ACTIONS(2244),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2244),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2244),
    [sym_preproc_directive] = ACTIONS(2244),
    [anon_sym_LPAREN2] = ACTIONS(2246),
    [anon_sym_BANG] = ACTIONS(2246),
    [anon_sym_TILDE] = ACTIONS(2246),
    [anon_sym_DASH] = ACTIONS(2244),
    [anon_sym_PLUS] = ACTIONS(2244),
    [anon_sym_STAR] = ACTIONS(2246),
    [anon_sym_AMP_AMP] = ACTIONS(2246),
    [anon_sym_AMP] = ACTIONS(2244),
    [anon_sym_SEMI] = ACTIONS(2246),
    [anon_sym___extension__] = ACTIONS(2244),
    [anon_sym_typedef] = ACTIONS(2244),
    [anon_sym_in] = ACTIONS(2244),
    [anon_sym_out] = ACTIONS(2244),
    [anon_sym_inout] = ACTIONS(2244),
    [anon_sym_extern] = ACTIONS(2244),
    [anon_sym___attribute__] = ACTIONS(2244),
    [anon_sym_COLON_COLON] = ACTIONS(2246),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2246),
    [anon_sym___declspec] = ACTIONS(2244),
    [anon_sym___based] = ACTIONS(2244),
    [anon_sym___cdecl] = ACTIONS(2244),
    [anon_sym___clrcall] = ACTIONS(2244),
    [anon_sym___stdcall] = ACTIONS(2244),
    [anon_sym___fastcall] = ACTIONS(2244),
    [anon_sym___thiscall] = ACTIONS(2244),
    [anon_sym___vectorcall] = ACTIONS(2244),
    [anon_sym_LBRACE] = ACTIONS(2246),
    [anon_sym_RBRACE] = ACTIONS(2246),
    [anon_sym_signed] = ACTIONS(2244),
    [anon_sym_unsigned] = ACTIONS(2244),
    [anon_sym_long] = ACTIONS(2244),
    [anon_sym_short] = ACTIONS(2244),
    [anon_sym_LBRACK] = ACTIONS(2244),
    [anon_sym_static] = ACTIONS(2244),
    [anon_sym_register] = ACTIONS(2244),
    [anon_sym_inline] = ACTIONS(2244),
    [anon_sym___inline] = ACTIONS(2244),
    [anon_sym___inline__] = ACTIONS(2244),
    [anon_sym___forceinline] = ACTIONS(2244),
    [anon_sym_thread_local] = ACTIONS(2244),
    [anon_sym___thread] = ACTIONS(2244),
    [anon_sym_const] = ACTIONS(2244),
    [anon_sym_constexpr] = ACTIONS(2244),
    [anon_sym_volatile] = ACTIONS(2244),
    [anon_sym_restrict] = ACTIONS(2244),
    [anon_sym___restrict__] = ACTIONS(2244),
    [anon_sym__Atomic] = ACTIONS(2244),
    [anon_sym__Noreturn] = ACTIONS(2244),
    [anon_sym_noreturn] = ACTIONS(2244),
    [anon_sym_mutable] = ACTIONS(2244),
    [anon_sym_constinit] = ACTIONS(2244),
    [anon_sym_consteval] = ACTIONS(2244),
    [anon_sym_alignas] = ACTIONS(2244),
    [anon_sym__Alignas] = ACTIONS(2244),
    [sym_primitive_type] = ACTIONS(2244),
    [anon_sym_enum] = ACTIONS(2244),
    [anon_sym_class] = ACTIONS(2244),
    [anon_sym_struct] = ACTIONS(2244),
    [anon_sym_union] = ACTIONS(2244),
    [anon_sym_if] = ACTIONS(2244),
    [anon_sym_else] = ACTIONS(2244),
    [anon_sym_switch] = ACTIONS(2244),
    [anon_sym_case] = ACTIONS(2244),
    [anon_sym_default] = ACTIONS(2244),
    [anon_sym_while] = ACTIONS(2244),
    [anon_sym_do] = ACTIONS(2244),
    [anon_sym_for] = ACTIONS(2244),
    [anon_sym_return] = ACTIONS(2244),
    [anon_sym_break] = ACTIONS(2244),
    [anon_sym_continue] = ACTIONS(2244),
    [anon_sym_goto] = ACTIONS(2244),
    [anon_sym___try] = ACTIONS(2244),
    [anon_sym___leave] = ACTIONS(2244),
    [anon_sym_not] = ACTIONS(2244),
    [anon_sym_compl] = ACTIONS(2244),
    [anon_sym_DASH_DASH] = ACTIONS(2246),
    [anon_sym_PLUS_PLUS] = ACTIONS(2246),
    [anon_sym_sizeof] = ACTIONS(2244),
    [anon_sym___alignof__] = ACTIONS(2244),
    [anon_sym___alignof] = ACTIONS(2244),
    [anon_sym__alignof] = ACTIONS(2244),
    [anon_sym_alignof] = ACTIONS(2244),
    [anon_sym__Alignof] = ACTIONS(2244),
    [anon_sym_offsetof] = ACTIONS(2244),
    [anon_sym__Generic] = ACTIONS(2244),
    [anon_sym_asm] = ACTIONS(2244),
    [anon_sym___asm__] = ACTIONS(2244),
    [sym_number_literal] = ACTIONS(2246),
    [anon_sym_L_SQUOTE] = ACTIONS(2246),
    [anon_sym_u_SQUOTE] = ACTIONS(2246),
    [anon_sym_U_SQUOTE] = ACTIONS(2246),
    [anon_sym_u8_SQUOTE] = ACTIONS(2246),
    [anon_sym_SQUOTE] = ACTIONS(2246),
    [anon_sym_L_DQUOTE] = ACTIONS(2246),
    [anon_sym_u_DQUOTE] = ACTIONS(2246),
    [anon_sym_U_DQUOTE] = ACTIONS(2246),
    [anon_sym_u8_DQUOTE] = ACTIONS(2246),
    [anon_sym_DQUOTE] = ACTIONS(2246),
    [sym_true] = ACTIONS(2244),
    [sym_false] = ACTIONS(2244),
    [anon_sym_NULL] = ACTIONS(2244),
    [anon_sym_nullptr] = ACTIONS(2244),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2244),
    [anon_sym_decltype] = ACTIONS(2244),
    [sym_virtual] = ACTIONS(2244),
    [anon_sym_explicit] = ACTIONS(2244),
    [anon_sym_typename] = ACTIONS(2244),
    [anon_sym_template] = ACTIONS(2244),
    [anon_sym_operator] = ACTIONS(2244),
    [anon_sym_try] = ACTIONS(2244),
    [anon_sym_delete] = ACTIONS(2244),
    [anon_sym_throw] = ACTIONS(2244),
    [anon_sym_namespace] = ACTIONS(2244),
    [anon_sym_using] = ACTIONS(2244),
    [anon_sym_static_assert] = ACTIONS(2244),
    [anon_sym_concept] = ACTIONS(2244),
    [anon_sym_co_return] = ACTIONS(2244),
    [anon_sym_co_yield] = ACTIONS(2244),
    [anon_sym_R_DQUOTE] = ACTIONS(2246),
    [anon_sym_LR_DQUOTE] = ACTIONS(2246),
    [anon_sym_uR_DQUOTE] = ACTIONS(2246),
    [anon_sym_UR_DQUOTE] = ACTIONS(2246),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2246),
    [anon_sym_co_await] = ACTIONS(2244),
    [anon_sym_new] = ACTIONS(2244),
    [anon_sym_requires] = ACTIONS(2244),
    [sym_this] = ACTIONS(2244),
    [anon_sym_discard] = ACTIONS(2244),
    [anon_sym_precise] = ACTIONS(2244),
    [anon_sym_shared] = ACTIONS(2244),
    [anon_sym_groupshared] = ACTIONS(2244),
    [anon_sym_uniform] = ACTIONS(2244),
    [anon_sym_row_major] = ACTIONS(2244),
    [anon_sym_column_major] = ACTIONS(2244),
    [anon_sym_globallycoherent] = ACTIONS(2244),
    [anon_sym_centroid] = ACTIONS(2244),
    [anon_sym_noperspective] = ACTIONS(2244),
    [anon_sym_nointerpolation] = ACTIONS(2244),
    [anon_sym_sample] = ACTIONS(2244),
    [anon_sym_linear] = ACTIONS(2244),
    [anon_sym_snorm] = ACTIONS(2244),
    [anon_sym_unorm] = ACTIONS(2244),
    [anon_sym_point] = ACTIONS(2244),
    [anon_sym_line] = ACTIONS(2244),
    [anon_sym_triangleadj] = ACTIONS(2244),
    [anon_sym_lineadj] = ACTIONS(2244),
    [anon_sym_triangle] = ACTIONS(2244),
    [anon_sym_cbuffer] = ACTIONS(2244),
  },
  [487] = {
    [sym_identifier] = ACTIONS(2288),
    [aux_sym_preproc_include_token1] = ACTIONS(2288),
    [aux_sym_preproc_def_token1] = ACTIONS(2288),
    [aux_sym_preproc_if_token1] = ACTIONS(2288),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2288),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2288),
    [sym_preproc_directive] = ACTIONS(2288),
    [anon_sym_LPAREN2] = ACTIONS(2290),
    [anon_sym_BANG] = ACTIONS(2290),
    [anon_sym_TILDE] = ACTIONS(2290),
    [anon_sym_DASH] = ACTIONS(2288),
    [anon_sym_PLUS] = ACTIONS(2288),
    [anon_sym_STAR] = ACTIONS(2290),
    [anon_sym_AMP_AMP] = ACTIONS(2290),
    [anon_sym_AMP] = ACTIONS(2288),
    [anon_sym_SEMI] = ACTIONS(2290),
    [anon_sym___extension__] = ACTIONS(2288),
    [anon_sym_typedef] = ACTIONS(2288),
    [anon_sym_in] = ACTIONS(2288),
    [anon_sym_out] = ACTIONS(2288),
    [anon_sym_inout] = ACTIONS(2288),
    [anon_sym_extern] = ACTIONS(2288),
    [anon_sym___attribute__] = ACTIONS(2288),
    [anon_sym_COLON_COLON] = ACTIONS(2290),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2290),
    [anon_sym___declspec] = ACTIONS(2288),
    [anon_sym___based] = ACTIONS(2288),
    [anon_sym___cdecl] = ACTIONS(2288),
    [anon_sym___clrcall] = ACTIONS(2288),
    [anon_sym___stdcall] = ACTIONS(2288),
    [anon_sym___fastcall] = ACTIONS(2288),
    [anon_sym___thiscall] = ACTIONS(2288),
    [anon_sym___vectorcall] = ACTIONS(2288),
    [anon_sym_LBRACE] = ACTIONS(2290),
    [anon_sym_RBRACE] = ACTIONS(2290),
    [anon_sym_signed] = ACTIONS(2288),
    [anon_sym_unsigned] = ACTIONS(2288),
    [anon_sym_long] = ACTIONS(2288),
    [anon_sym_short] = ACTIONS(2288),
    [anon_sym_LBRACK] = ACTIONS(2288),
    [anon_sym_static] = ACTIONS(2288),
    [anon_sym_register] = ACTIONS(2288),
    [anon_sym_inline] = ACTIONS(2288),
    [anon_sym___inline] = ACTIONS(2288),
    [anon_sym___inline__] = ACTIONS(2288),
    [anon_sym___forceinline] = ACTIONS(2288),
    [anon_sym_thread_local] = ACTIONS(2288),
    [anon_sym___thread] = ACTIONS(2288),
    [anon_sym_const] = ACTIONS(2288),
    [anon_sym_constexpr] = ACTIONS(2288),
    [anon_sym_volatile] = ACTIONS(2288),
    [anon_sym_restrict] = ACTIONS(2288),
    [anon_sym___restrict__] = ACTIONS(2288),
    [anon_sym__Atomic] = ACTIONS(2288),
    [anon_sym__Noreturn] = ACTIONS(2288),
    [anon_sym_noreturn] = ACTIONS(2288),
    [anon_sym_mutable] = ACTIONS(2288),
    [anon_sym_constinit] = ACTIONS(2288),
    [anon_sym_consteval] = ACTIONS(2288),
    [anon_sym_alignas] = ACTIONS(2288),
    [anon_sym__Alignas] = ACTIONS(2288),
    [sym_primitive_type] = ACTIONS(2288),
    [anon_sym_enum] = ACTIONS(2288),
    [anon_sym_class] = ACTIONS(2288),
    [anon_sym_struct] = ACTIONS(2288),
    [anon_sym_union] = ACTIONS(2288),
    [anon_sym_if] = ACTIONS(2288),
    [anon_sym_else] = ACTIONS(2288),
    [anon_sym_switch] = ACTIONS(2288),
    [anon_sym_case] = ACTIONS(2288),
    [anon_sym_default] = ACTIONS(2288),
    [anon_sym_while] = ACTIONS(2288),
    [anon_sym_do] = ACTIONS(2288),
    [anon_sym_for] = ACTIONS(2288),
    [anon_sym_return] = ACTIONS(2288),
    [anon_sym_break] = ACTIONS(2288),
    [anon_sym_continue] = ACTIONS(2288),
    [anon_sym_goto] = ACTIONS(2288),
    [anon_sym___try] = ACTIONS(2288),
    [anon_sym___leave] = ACTIONS(2288),
    [anon_sym_not] = ACTIONS(2288),
    [anon_sym_compl] = ACTIONS(2288),
    [anon_sym_DASH_DASH] = ACTIONS(2290),
    [anon_sym_PLUS_PLUS] = ACTIONS(2290),
    [anon_sym_sizeof] = ACTIONS(2288),
    [anon_sym___alignof__] = ACTIONS(2288),
    [anon_sym___alignof] = ACTIONS(2288),
    [anon_sym__alignof] = ACTIONS(2288),
    [anon_sym_alignof] = ACTIONS(2288),
    [anon_sym__Alignof] = ACTIONS(2288),
    [anon_sym_offsetof] = ACTIONS(2288),
    [anon_sym__Generic] = ACTIONS(2288),
    [anon_sym_asm] = ACTIONS(2288),
    [anon_sym___asm__] = ACTIONS(2288),
    [sym_number_literal] = ACTIONS(2290),
    [anon_sym_L_SQUOTE] = ACTIONS(2290),
    [anon_sym_u_SQUOTE] = ACTIONS(2290),
    [anon_sym_U_SQUOTE] = ACTIONS(2290),
    [anon_sym_u8_SQUOTE] = ACTIONS(2290),
    [anon_sym_SQUOTE] = ACTIONS(2290),
    [anon_sym_L_DQUOTE] = ACTIONS(2290),
    [anon_sym_u_DQUOTE] = ACTIONS(2290),
    [anon_sym_U_DQUOTE] = ACTIONS(2290),
    [anon_sym_u8_DQUOTE] = ACTIONS(2290),
    [anon_sym_DQUOTE] = ACTIONS(2290),
    [sym_true] = ACTIONS(2288),
    [sym_false] = ACTIONS(2288),
    [anon_sym_NULL] = ACTIONS(2288),
    [anon_sym_nullptr] = ACTIONS(2288),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2288),
    [anon_sym_decltype] = ACTIONS(2288),
    [sym_virtual] = ACTIONS(2288),
    [anon_sym_explicit] = ACTIONS(2288),
    [anon_sym_typename] = ACTIONS(2288),
    [anon_sym_template] = ACTIONS(2288),
    [anon_sym_operator] = ACTIONS(2288),
    [anon_sym_try] = ACTIONS(2288),
    [anon_sym_delete] = ACTIONS(2288),
    [anon_sym_throw] = ACTIONS(2288),
    [anon_sym_namespace] = ACTIONS(2288),
    [anon_sym_using] = ACTIONS(2288),
    [anon_sym_static_assert] = ACTIONS(2288),
    [anon_sym_concept] = ACTIONS(2288),
    [anon_sym_co_return] = ACTIONS(2288),
    [anon_sym_co_yield] = ACTIONS(2288),
    [anon_sym_R_DQUOTE] = ACTIONS(2290),
    [anon_sym_LR_DQUOTE] = ACTIONS(2290),
    [anon_sym_uR_DQUOTE] = ACTIONS(2290),
    [anon_sym_UR_DQUOTE] = ACTIONS(2290),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2290),
    [anon_sym_co_await] = ACTIONS(2288),
    [anon_sym_new] = ACTIONS(2288),
    [anon_sym_requires] = ACTIONS(2288),
    [sym_this] = ACTIONS(2288),
    [anon_sym_discard] = ACTIONS(2288),
    [anon_sym_precise] = ACTIONS(2288),
    [anon_sym_shared] = ACTIONS(2288),
    [anon_sym_groupshared] = ACTIONS(2288),
    [anon_sym_uniform] = ACTIONS(2288),
    [anon_sym_row_major] = ACTIONS(2288),
    [anon_sym_column_major] = ACTIONS(2288),
    [anon_sym_globallycoherent] = ACTIONS(2288),
    [anon_sym_centroid] = ACTIONS(2288),
    [anon_sym_noperspective] = ACTIONS(2288),
    [anon_sym_nointerpolation] = ACTIONS(2288),
    [anon_sym_sample] = ACTIONS(2288),
    [anon_sym_linear] = ACTIONS(2288),
    [anon_sym_snorm] = ACTIONS(2288),
    [anon_sym_unorm] = ACTIONS(2288),
    [anon_sym_point] = ACTIONS(2288),
    [anon_sym_line] = ACTIONS(2288),
    [anon_sym_triangleadj] = ACTIONS(2288),
    [anon_sym_lineadj] = ACTIONS(2288),
    [anon_sym_triangle] = ACTIONS(2288),
    [anon_sym_cbuffer] = ACTIONS(2288),
  },
  [488] = {
    [sym_identifier] = ACTIONS(2248),
    [aux_sym_preproc_include_token1] = ACTIONS(2248),
    [aux_sym_preproc_def_token1] = ACTIONS(2248),
    [aux_sym_preproc_if_token1] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2248),
    [sym_preproc_directive] = ACTIONS(2248),
    [anon_sym_LPAREN2] = ACTIONS(2250),
    [anon_sym_BANG] = ACTIONS(2250),
    [anon_sym_TILDE] = ACTIONS(2250),
    [anon_sym_DASH] = ACTIONS(2248),
    [anon_sym_PLUS] = ACTIONS(2248),
    [anon_sym_STAR] = ACTIONS(2250),
    [anon_sym_AMP_AMP] = ACTIONS(2250),
    [anon_sym_AMP] = ACTIONS(2248),
    [anon_sym_SEMI] = ACTIONS(2250),
    [anon_sym___extension__] = ACTIONS(2248),
    [anon_sym_typedef] = ACTIONS(2248),
    [anon_sym_in] = ACTIONS(2248),
    [anon_sym_out] = ACTIONS(2248),
    [anon_sym_inout] = ACTIONS(2248),
    [anon_sym_extern] = ACTIONS(2248),
    [anon_sym___attribute__] = ACTIONS(2248),
    [anon_sym_COLON_COLON] = ACTIONS(2250),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2250),
    [anon_sym___declspec] = ACTIONS(2248),
    [anon_sym___based] = ACTIONS(2248),
    [anon_sym___cdecl] = ACTIONS(2248),
    [anon_sym___clrcall] = ACTIONS(2248),
    [anon_sym___stdcall] = ACTIONS(2248),
    [anon_sym___fastcall] = ACTIONS(2248),
    [anon_sym___thiscall] = ACTIONS(2248),
    [anon_sym___vectorcall] = ACTIONS(2248),
    [anon_sym_LBRACE] = ACTIONS(2250),
    [anon_sym_RBRACE] = ACTIONS(2250),
    [anon_sym_signed] = ACTIONS(2248),
    [anon_sym_unsigned] = ACTIONS(2248),
    [anon_sym_long] = ACTIONS(2248),
    [anon_sym_short] = ACTIONS(2248),
    [anon_sym_LBRACK] = ACTIONS(2248),
    [anon_sym_static] = ACTIONS(2248),
    [anon_sym_register] = ACTIONS(2248),
    [anon_sym_inline] = ACTIONS(2248),
    [anon_sym___inline] = ACTIONS(2248),
    [anon_sym___inline__] = ACTIONS(2248),
    [anon_sym___forceinline] = ACTIONS(2248),
    [anon_sym_thread_local] = ACTIONS(2248),
    [anon_sym___thread] = ACTIONS(2248),
    [anon_sym_const] = ACTIONS(2248),
    [anon_sym_constexpr] = ACTIONS(2248),
    [anon_sym_volatile] = ACTIONS(2248),
    [anon_sym_restrict] = ACTIONS(2248),
    [anon_sym___restrict__] = ACTIONS(2248),
    [anon_sym__Atomic] = ACTIONS(2248),
    [anon_sym__Noreturn] = ACTIONS(2248),
    [anon_sym_noreturn] = ACTIONS(2248),
    [anon_sym_mutable] = ACTIONS(2248),
    [anon_sym_constinit] = ACTIONS(2248),
    [anon_sym_consteval] = ACTIONS(2248),
    [anon_sym_alignas] = ACTIONS(2248),
    [anon_sym__Alignas] = ACTIONS(2248),
    [sym_primitive_type] = ACTIONS(2248),
    [anon_sym_enum] = ACTIONS(2248),
    [anon_sym_class] = ACTIONS(2248),
    [anon_sym_struct] = ACTIONS(2248),
    [anon_sym_union] = ACTIONS(2248),
    [anon_sym_if] = ACTIONS(2248),
    [anon_sym_else] = ACTIONS(2248),
    [anon_sym_switch] = ACTIONS(2248),
    [anon_sym_case] = ACTIONS(2248),
    [anon_sym_default] = ACTIONS(2248),
    [anon_sym_while] = ACTIONS(2248),
    [anon_sym_do] = ACTIONS(2248),
    [anon_sym_for] = ACTIONS(2248),
    [anon_sym_return] = ACTIONS(2248),
    [anon_sym_break] = ACTIONS(2248),
    [anon_sym_continue] = ACTIONS(2248),
    [anon_sym_goto] = ACTIONS(2248),
    [anon_sym___try] = ACTIONS(2248),
    [anon_sym___leave] = ACTIONS(2248),
    [anon_sym_not] = ACTIONS(2248),
    [anon_sym_compl] = ACTIONS(2248),
    [anon_sym_DASH_DASH] = ACTIONS(2250),
    [anon_sym_PLUS_PLUS] = ACTIONS(2250),
    [anon_sym_sizeof] = ACTIONS(2248),
    [anon_sym___alignof__] = ACTIONS(2248),
    [anon_sym___alignof] = ACTIONS(2248),
    [anon_sym__alignof] = ACTIONS(2248),
    [anon_sym_alignof] = ACTIONS(2248),
    [anon_sym__Alignof] = ACTIONS(2248),
    [anon_sym_offsetof] = ACTIONS(2248),
    [anon_sym__Generic] = ACTIONS(2248),
    [anon_sym_asm] = ACTIONS(2248),
    [anon_sym___asm__] = ACTIONS(2248),
    [sym_number_literal] = ACTIONS(2250),
    [anon_sym_L_SQUOTE] = ACTIONS(2250),
    [anon_sym_u_SQUOTE] = ACTIONS(2250),
    [anon_sym_U_SQUOTE] = ACTIONS(2250),
    [anon_sym_u8_SQUOTE] = ACTIONS(2250),
    [anon_sym_SQUOTE] = ACTIONS(2250),
    [anon_sym_L_DQUOTE] = ACTIONS(2250),
    [anon_sym_u_DQUOTE] = ACTIONS(2250),
    [anon_sym_U_DQUOTE] = ACTIONS(2250),
    [anon_sym_u8_DQUOTE] = ACTIONS(2250),
    [anon_sym_DQUOTE] = ACTIONS(2250),
    [sym_true] = ACTIONS(2248),
    [sym_false] = ACTIONS(2248),
    [anon_sym_NULL] = ACTIONS(2248),
    [anon_sym_nullptr] = ACTIONS(2248),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2248),
    [anon_sym_decltype] = ACTIONS(2248),
    [sym_virtual] = ACTIONS(2248),
    [anon_sym_explicit] = ACTIONS(2248),
    [anon_sym_typename] = ACTIONS(2248),
    [anon_sym_template] = ACTIONS(2248),
    [anon_sym_operator] = ACTIONS(2248),
    [anon_sym_try] = ACTIONS(2248),
    [anon_sym_delete] = ACTIONS(2248),
    [anon_sym_throw] = ACTIONS(2248),
    [anon_sym_namespace] = ACTIONS(2248),
    [anon_sym_using] = ACTIONS(2248),
    [anon_sym_static_assert] = ACTIONS(2248),
    [anon_sym_concept] = ACTIONS(2248),
    [anon_sym_co_return] = ACTIONS(2248),
    [anon_sym_co_yield] = ACTIONS(2248),
    [anon_sym_R_DQUOTE] = ACTIONS(2250),
    [anon_sym_LR_DQUOTE] = ACTIONS(2250),
    [anon_sym_uR_DQUOTE] = ACTIONS(2250),
    [anon_sym_UR_DQUOTE] = ACTIONS(2250),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2250),
    [anon_sym_co_await] = ACTIONS(2248),
    [anon_sym_new] = ACTIONS(2248),
    [anon_sym_requires] = ACTIONS(2248),
    [sym_this] = ACTIONS(2248),
    [anon_sym_discard] = ACTIONS(2248),
    [anon_sym_precise] = ACTIONS(2248),
    [anon_sym_shared] = ACTIONS(2248),
    [anon_sym_groupshared] = ACTIONS(2248),
    [anon_sym_uniform] = ACTIONS(2248),
    [anon_sym_row_major] = ACTIONS(2248),
    [anon_sym_column_major] = ACTIONS(2248),
    [anon_sym_globallycoherent] = ACTIONS(2248),
    [anon_sym_centroid] = ACTIONS(2248),
    [anon_sym_noperspective] = ACTIONS(2248),
    [anon_sym_nointerpolation] = ACTIONS(2248),
    [anon_sym_sample] = ACTIONS(2248),
    [anon_sym_linear] = ACTIONS(2248),
    [anon_sym_snorm] = ACTIONS(2248),
    [anon_sym_unorm] = ACTIONS(2248),
    [anon_sym_point] = ACTIONS(2248),
    [anon_sym_line] = ACTIONS(2248),
    [anon_sym_triangleadj] = ACTIONS(2248),
    [anon_sym_lineadj] = ACTIONS(2248),
    [anon_sym_triangle] = ACTIONS(2248),
    [anon_sym_cbuffer] = ACTIONS(2248),
  },
  [489] = {
    [sym_identifier] = ACTIONS(2248),
    [aux_sym_preproc_include_token1] = ACTIONS(2248),
    [aux_sym_preproc_def_token1] = ACTIONS(2248),
    [aux_sym_preproc_if_token1] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2248),
    [sym_preproc_directive] = ACTIONS(2248),
    [anon_sym_LPAREN2] = ACTIONS(2250),
    [anon_sym_BANG] = ACTIONS(2250),
    [anon_sym_TILDE] = ACTIONS(2250),
    [anon_sym_DASH] = ACTIONS(2248),
    [anon_sym_PLUS] = ACTIONS(2248),
    [anon_sym_STAR] = ACTIONS(2250),
    [anon_sym_AMP_AMP] = ACTIONS(2250),
    [anon_sym_AMP] = ACTIONS(2248),
    [anon_sym_SEMI] = ACTIONS(2250),
    [anon_sym___extension__] = ACTIONS(2248),
    [anon_sym_typedef] = ACTIONS(2248),
    [anon_sym_in] = ACTIONS(2248),
    [anon_sym_out] = ACTIONS(2248),
    [anon_sym_inout] = ACTIONS(2248),
    [anon_sym_extern] = ACTIONS(2248),
    [anon_sym___attribute__] = ACTIONS(2248),
    [anon_sym_COLON_COLON] = ACTIONS(2250),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2250),
    [anon_sym___declspec] = ACTIONS(2248),
    [anon_sym___based] = ACTIONS(2248),
    [anon_sym___cdecl] = ACTIONS(2248),
    [anon_sym___clrcall] = ACTIONS(2248),
    [anon_sym___stdcall] = ACTIONS(2248),
    [anon_sym___fastcall] = ACTIONS(2248),
    [anon_sym___thiscall] = ACTIONS(2248),
    [anon_sym___vectorcall] = ACTIONS(2248),
    [anon_sym_LBRACE] = ACTIONS(2250),
    [anon_sym_RBRACE] = ACTIONS(2250),
    [anon_sym_signed] = ACTIONS(2248),
    [anon_sym_unsigned] = ACTIONS(2248),
    [anon_sym_long] = ACTIONS(2248),
    [anon_sym_short] = ACTIONS(2248),
    [anon_sym_LBRACK] = ACTIONS(2248),
    [anon_sym_static] = ACTIONS(2248),
    [anon_sym_register] = ACTIONS(2248),
    [anon_sym_inline] = ACTIONS(2248),
    [anon_sym___inline] = ACTIONS(2248),
    [anon_sym___inline__] = ACTIONS(2248),
    [anon_sym___forceinline] = ACTIONS(2248),
    [anon_sym_thread_local] = ACTIONS(2248),
    [anon_sym___thread] = ACTIONS(2248),
    [anon_sym_const] = ACTIONS(2248),
    [anon_sym_constexpr] = ACTIONS(2248),
    [anon_sym_volatile] = ACTIONS(2248),
    [anon_sym_restrict] = ACTIONS(2248),
    [anon_sym___restrict__] = ACTIONS(2248),
    [anon_sym__Atomic] = ACTIONS(2248),
    [anon_sym__Noreturn] = ACTIONS(2248),
    [anon_sym_noreturn] = ACTIONS(2248),
    [anon_sym_mutable] = ACTIONS(2248),
    [anon_sym_constinit] = ACTIONS(2248),
    [anon_sym_consteval] = ACTIONS(2248),
    [anon_sym_alignas] = ACTIONS(2248),
    [anon_sym__Alignas] = ACTIONS(2248),
    [sym_primitive_type] = ACTIONS(2248),
    [anon_sym_enum] = ACTIONS(2248),
    [anon_sym_class] = ACTIONS(2248),
    [anon_sym_struct] = ACTIONS(2248),
    [anon_sym_union] = ACTIONS(2248),
    [anon_sym_if] = ACTIONS(2248),
    [anon_sym_else] = ACTIONS(2248),
    [anon_sym_switch] = ACTIONS(2248),
    [anon_sym_case] = ACTIONS(2248),
    [anon_sym_default] = ACTIONS(2248),
    [anon_sym_while] = ACTIONS(2248),
    [anon_sym_do] = ACTIONS(2248),
    [anon_sym_for] = ACTIONS(2248),
    [anon_sym_return] = ACTIONS(2248),
    [anon_sym_break] = ACTIONS(2248),
    [anon_sym_continue] = ACTIONS(2248),
    [anon_sym_goto] = ACTIONS(2248),
    [anon_sym___try] = ACTIONS(2248),
    [anon_sym___leave] = ACTIONS(2248),
    [anon_sym_not] = ACTIONS(2248),
    [anon_sym_compl] = ACTIONS(2248),
    [anon_sym_DASH_DASH] = ACTIONS(2250),
    [anon_sym_PLUS_PLUS] = ACTIONS(2250),
    [anon_sym_sizeof] = ACTIONS(2248),
    [anon_sym___alignof__] = ACTIONS(2248),
    [anon_sym___alignof] = ACTIONS(2248),
    [anon_sym__alignof] = ACTIONS(2248),
    [anon_sym_alignof] = ACTIONS(2248),
    [anon_sym__Alignof] = ACTIONS(2248),
    [anon_sym_offsetof] = ACTIONS(2248),
    [anon_sym__Generic] = ACTIONS(2248),
    [anon_sym_asm] = ACTIONS(2248),
    [anon_sym___asm__] = ACTIONS(2248),
    [sym_number_literal] = ACTIONS(2250),
    [anon_sym_L_SQUOTE] = ACTIONS(2250),
    [anon_sym_u_SQUOTE] = ACTIONS(2250),
    [anon_sym_U_SQUOTE] = ACTIONS(2250),
    [anon_sym_u8_SQUOTE] = ACTIONS(2250),
    [anon_sym_SQUOTE] = ACTIONS(2250),
    [anon_sym_L_DQUOTE] = ACTIONS(2250),
    [anon_sym_u_DQUOTE] = ACTIONS(2250),
    [anon_sym_U_DQUOTE] = ACTIONS(2250),
    [anon_sym_u8_DQUOTE] = ACTIONS(2250),
    [anon_sym_DQUOTE] = ACTIONS(2250),
    [sym_true] = ACTIONS(2248),
    [sym_false] = ACTIONS(2248),
    [anon_sym_NULL] = ACTIONS(2248),
    [anon_sym_nullptr] = ACTIONS(2248),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2248),
    [anon_sym_decltype] = ACTIONS(2248),
    [sym_virtual] = ACTIONS(2248),
    [anon_sym_explicit] = ACTIONS(2248),
    [anon_sym_typename] = ACTIONS(2248),
    [anon_sym_template] = ACTIONS(2248),
    [anon_sym_operator] = ACTIONS(2248),
    [anon_sym_try] = ACTIONS(2248),
    [anon_sym_delete] = ACTIONS(2248),
    [anon_sym_throw] = ACTIONS(2248),
    [anon_sym_namespace] = ACTIONS(2248),
    [anon_sym_using] = ACTIONS(2248),
    [anon_sym_static_assert] = ACTIONS(2248),
    [anon_sym_concept] = ACTIONS(2248),
    [anon_sym_co_return] = ACTIONS(2248),
    [anon_sym_co_yield] = ACTIONS(2248),
    [anon_sym_R_DQUOTE] = ACTIONS(2250),
    [anon_sym_LR_DQUOTE] = ACTIONS(2250),
    [anon_sym_uR_DQUOTE] = ACTIONS(2250),
    [anon_sym_UR_DQUOTE] = ACTIONS(2250),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2250),
    [anon_sym_co_await] = ACTIONS(2248),
    [anon_sym_new] = ACTIONS(2248),
    [anon_sym_requires] = ACTIONS(2248),
    [sym_this] = ACTIONS(2248),
    [anon_sym_discard] = ACTIONS(2248),
    [anon_sym_precise] = ACTIONS(2248),
    [anon_sym_shared] = ACTIONS(2248),
    [anon_sym_groupshared] = ACTIONS(2248),
    [anon_sym_uniform] = ACTIONS(2248),
    [anon_sym_row_major] = ACTIONS(2248),
    [anon_sym_column_major] = ACTIONS(2248),
    [anon_sym_globallycoherent] = ACTIONS(2248),
    [anon_sym_centroid] = ACTIONS(2248),
    [anon_sym_noperspective] = ACTIONS(2248),
    [anon_sym_nointerpolation] = ACTIONS(2248),
    [anon_sym_sample] = ACTIONS(2248),
    [anon_sym_linear] = ACTIONS(2248),
    [anon_sym_snorm] = ACTIONS(2248),
    [anon_sym_unorm] = ACTIONS(2248),
    [anon_sym_point] = ACTIONS(2248),
    [anon_sym_line] = ACTIONS(2248),
    [anon_sym_triangleadj] = ACTIONS(2248),
    [anon_sym_lineadj] = ACTIONS(2248),
    [anon_sym_triangle] = ACTIONS(2248),
    [anon_sym_cbuffer] = ACTIONS(2248),
  },
  [490] = {
    [sym_identifier] = ACTIONS(2142),
    [aux_sym_preproc_include_token1] = ACTIONS(2142),
    [aux_sym_preproc_def_token1] = ACTIONS(2142),
    [aux_sym_preproc_if_token1] = ACTIONS(2142),
    [aux_sym_preproc_if_token2] = ACTIONS(2142),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2142),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2142),
    [sym_preproc_directive] = ACTIONS(2142),
    [anon_sym_LPAREN2] = ACTIONS(2144),
    [anon_sym_BANG] = ACTIONS(2144),
    [anon_sym_TILDE] = ACTIONS(2144),
    [anon_sym_DASH] = ACTIONS(2142),
    [anon_sym_PLUS] = ACTIONS(2142),
    [anon_sym_STAR] = ACTIONS(2144),
    [anon_sym_AMP_AMP] = ACTIONS(2144),
    [anon_sym_AMP] = ACTIONS(2142),
    [anon_sym_SEMI] = ACTIONS(2144),
    [anon_sym___extension__] = ACTIONS(2142),
    [anon_sym_typedef] = ACTIONS(2142),
    [anon_sym_in] = ACTIONS(2142),
    [anon_sym_out] = ACTIONS(2142),
    [anon_sym_inout] = ACTIONS(2142),
    [anon_sym_extern] = ACTIONS(2142),
    [anon_sym___attribute__] = ACTIONS(2142),
    [anon_sym_COLON_COLON] = ACTIONS(2144),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2144),
    [anon_sym___declspec] = ACTIONS(2142),
    [anon_sym___based] = ACTIONS(2142),
    [anon_sym___cdecl] = ACTIONS(2142),
    [anon_sym___clrcall] = ACTIONS(2142),
    [anon_sym___stdcall] = ACTIONS(2142),
    [anon_sym___fastcall] = ACTIONS(2142),
    [anon_sym___thiscall] = ACTIONS(2142),
    [anon_sym___vectorcall] = ACTIONS(2142),
    [anon_sym_LBRACE] = ACTIONS(2144),
    [anon_sym_signed] = ACTIONS(2142),
    [anon_sym_unsigned] = ACTIONS(2142),
    [anon_sym_long] = ACTIONS(2142),
    [anon_sym_short] = ACTIONS(2142),
    [anon_sym_LBRACK] = ACTIONS(2142),
    [anon_sym_static] = ACTIONS(2142),
    [anon_sym_register] = ACTIONS(2142),
    [anon_sym_inline] = ACTIONS(2142),
    [anon_sym___inline] = ACTIONS(2142),
    [anon_sym___inline__] = ACTIONS(2142),
    [anon_sym___forceinline] = ACTIONS(2142),
    [anon_sym_thread_local] = ACTIONS(2142),
    [anon_sym___thread] = ACTIONS(2142),
    [anon_sym_const] = ACTIONS(2142),
    [anon_sym_constexpr] = ACTIONS(2142),
    [anon_sym_volatile] = ACTIONS(2142),
    [anon_sym_restrict] = ACTIONS(2142),
    [anon_sym___restrict__] = ACTIONS(2142),
    [anon_sym__Atomic] = ACTIONS(2142),
    [anon_sym__Noreturn] = ACTIONS(2142),
    [anon_sym_noreturn] = ACTIONS(2142),
    [anon_sym_mutable] = ACTIONS(2142),
    [anon_sym_constinit] = ACTIONS(2142),
    [anon_sym_consteval] = ACTIONS(2142),
    [anon_sym_alignas] = ACTIONS(2142),
    [anon_sym__Alignas] = ACTIONS(2142),
    [sym_primitive_type] = ACTIONS(2142),
    [anon_sym_enum] = ACTIONS(2142),
    [anon_sym_class] = ACTIONS(2142),
    [anon_sym_struct] = ACTIONS(2142),
    [anon_sym_union] = ACTIONS(2142),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_else] = ACTIONS(2142),
    [anon_sym_switch] = ACTIONS(2142),
    [anon_sym_case] = ACTIONS(2142),
    [anon_sym_default] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2142),
    [anon_sym_do] = ACTIONS(2142),
    [anon_sym_for] = ACTIONS(2142),
    [anon_sym_return] = ACTIONS(2142),
    [anon_sym_break] = ACTIONS(2142),
    [anon_sym_continue] = ACTIONS(2142),
    [anon_sym_goto] = ACTIONS(2142),
    [anon_sym___try] = ACTIONS(2142),
    [anon_sym___leave] = ACTIONS(2142),
    [anon_sym_not] = ACTIONS(2142),
    [anon_sym_compl] = ACTIONS(2142),
    [anon_sym_DASH_DASH] = ACTIONS(2144),
    [anon_sym_PLUS_PLUS] = ACTIONS(2144),
    [anon_sym_sizeof] = ACTIONS(2142),
    [anon_sym___alignof__] = ACTIONS(2142),
    [anon_sym___alignof] = ACTIONS(2142),
    [anon_sym__alignof] = ACTIONS(2142),
    [anon_sym_alignof] = ACTIONS(2142),
    [anon_sym__Alignof] = ACTIONS(2142),
    [anon_sym_offsetof] = ACTIONS(2142),
    [anon_sym__Generic] = ACTIONS(2142),
    [anon_sym_asm] = ACTIONS(2142),
    [anon_sym___asm__] = ACTIONS(2142),
    [sym_number_literal] = ACTIONS(2144),
    [anon_sym_L_SQUOTE] = ACTIONS(2144),
    [anon_sym_u_SQUOTE] = ACTIONS(2144),
    [anon_sym_U_SQUOTE] = ACTIONS(2144),
    [anon_sym_u8_SQUOTE] = ACTIONS(2144),
    [anon_sym_SQUOTE] = ACTIONS(2144),
    [anon_sym_L_DQUOTE] = ACTIONS(2144),
    [anon_sym_u_DQUOTE] = ACTIONS(2144),
    [anon_sym_U_DQUOTE] = ACTIONS(2144),
    [anon_sym_u8_DQUOTE] = ACTIONS(2144),
    [anon_sym_DQUOTE] = ACTIONS(2144),
    [sym_true] = ACTIONS(2142),
    [sym_false] = ACTIONS(2142),
    [anon_sym_NULL] = ACTIONS(2142),
    [anon_sym_nullptr] = ACTIONS(2142),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2142),
    [anon_sym_decltype] = ACTIONS(2142),
    [sym_virtual] = ACTIONS(2142),
    [anon_sym_explicit] = ACTIONS(2142),
    [anon_sym_typename] = ACTIONS(2142),
    [anon_sym_template] = ACTIONS(2142),
    [anon_sym_operator] = ACTIONS(2142),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_delete] = ACTIONS(2142),
    [anon_sym_throw] = ACTIONS(2142),
    [anon_sym_namespace] = ACTIONS(2142),
    [anon_sym_using] = ACTIONS(2142),
    [anon_sym_static_assert] = ACTIONS(2142),
    [anon_sym_concept] = ACTIONS(2142),
    [anon_sym_co_return] = ACTIONS(2142),
    [anon_sym_co_yield] = ACTIONS(2142),
    [anon_sym_R_DQUOTE] = ACTIONS(2144),
    [anon_sym_LR_DQUOTE] = ACTIONS(2144),
    [anon_sym_uR_DQUOTE] = ACTIONS(2144),
    [anon_sym_UR_DQUOTE] = ACTIONS(2144),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2144),
    [anon_sym_co_await] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(2142),
    [anon_sym_requires] = ACTIONS(2142),
    [sym_this] = ACTIONS(2142),
    [anon_sym_discard] = ACTIONS(2142),
    [anon_sym_precise] = ACTIONS(2142),
    [anon_sym_shared] = ACTIONS(2142),
    [anon_sym_groupshared] = ACTIONS(2142),
    [anon_sym_uniform] = ACTIONS(2142),
    [anon_sym_row_major] = ACTIONS(2142),
    [anon_sym_column_major] = ACTIONS(2142),
    [anon_sym_globallycoherent] = ACTIONS(2142),
    [anon_sym_centroid] = ACTIONS(2142),
    [anon_sym_noperspective] = ACTIONS(2142),
    [anon_sym_nointerpolation] = ACTIONS(2142),
    [anon_sym_sample] = ACTIONS(2142),
    [anon_sym_linear] = ACTIONS(2142),
    [anon_sym_snorm] = ACTIONS(2142),
    [anon_sym_unorm] = ACTIONS(2142),
    [anon_sym_point] = ACTIONS(2142),
    [anon_sym_line] = ACTIONS(2142),
    [anon_sym_triangleadj] = ACTIONS(2142),
    [anon_sym_lineadj] = ACTIONS(2142),
    [anon_sym_triangle] = ACTIONS(2142),
    [anon_sym_cbuffer] = ACTIONS(2142),
  },
  [491] = {
    [sym_identifier] = ACTIONS(2134),
    [aux_sym_preproc_include_token1] = ACTIONS(2134),
    [aux_sym_preproc_def_token1] = ACTIONS(2134),
    [aux_sym_preproc_if_token1] = ACTIONS(2134),
    [aux_sym_preproc_if_token2] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2134),
    [sym_preproc_directive] = ACTIONS(2134),
    [anon_sym_LPAREN2] = ACTIONS(2136),
    [anon_sym_BANG] = ACTIONS(2136),
    [anon_sym_TILDE] = ACTIONS(2136),
    [anon_sym_DASH] = ACTIONS(2134),
    [anon_sym_PLUS] = ACTIONS(2134),
    [anon_sym_STAR] = ACTIONS(2136),
    [anon_sym_AMP_AMP] = ACTIONS(2136),
    [anon_sym_AMP] = ACTIONS(2134),
    [anon_sym_SEMI] = ACTIONS(2136),
    [anon_sym___extension__] = ACTIONS(2134),
    [anon_sym_typedef] = ACTIONS(2134),
    [anon_sym_in] = ACTIONS(2134),
    [anon_sym_out] = ACTIONS(2134),
    [anon_sym_inout] = ACTIONS(2134),
    [anon_sym_extern] = ACTIONS(2134),
    [anon_sym___attribute__] = ACTIONS(2134),
    [anon_sym_COLON_COLON] = ACTIONS(2136),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2136),
    [anon_sym___declspec] = ACTIONS(2134),
    [anon_sym___based] = ACTIONS(2134),
    [anon_sym___cdecl] = ACTIONS(2134),
    [anon_sym___clrcall] = ACTIONS(2134),
    [anon_sym___stdcall] = ACTIONS(2134),
    [anon_sym___fastcall] = ACTIONS(2134),
    [anon_sym___thiscall] = ACTIONS(2134),
    [anon_sym___vectorcall] = ACTIONS(2134),
    [anon_sym_LBRACE] = ACTIONS(2136),
    [anon_sym_signed] = ACTIONS(2134),
    [anon_sym_unsigned] = ACTIONS(2134),
    [anon_sym_long] = ACTIONS(2134),
    [anon_sym_short] = ACTIONS(2134),
    [anon_sym_LBRACK] = ACTIONS(2134),
    [anon_sym_static] = ACTIONS(2134),
    [anon_sym_register] = ACTIONS(2134),
    [anon_sym_inline] = ACTIONS(2134),
    [anon_sym___inline] = ACTIONS(2134),
    [anon_sym___inline__] = ACTIONS(2134),
    [anon_sym___forceinline] = ACTIONS(2134),
    [anon_sym_thread_local] = ACTIONS(2134),
    [anon_sym___thread] = ACTIONS(2134),
    [anon_sym_const] = ACTIONS(2134),
    [anon_sym_constexpr] = ACTIONS(2134),
    [anon_sym_volatile] = ACTIONS(2134),
    [anon_sym_restrict] = ACTIONS(2134),
    [anon_sym___restrict__] = ACTIONS(2134),
    [anon_sym__Atomic] = ACTIONS(2134),
    [anon_sym__Noreturn] = ACTIONS(2134),
    [anon_sym_noreturn] = ACTIONS(2134),
    [anon_sym_mutable] = ACTIONS(2134),
    [anon_sym_constinit] = ACTIONS(2134),
    [anon_sym_consteval] = ACTIONS(2134),
    [anon_sym_alignas] = ACTIONS(2134),
    [anon_sym__Alignas] = ACTIONS(2134),
    [sym_primitive_type] = ACTIONS(2134),
    [anon_sym_enum] = ACTIONS(2134),
    [anon_sym_class] = ACTIONS(2134),
    [anon_sym_struct] = ACTIONS(2134),
    [anon_sym_union] = ACTIONS(2134),
    [anon_sym_if] = ACTIONS(2134),
    [anon_sym_else] = ACTIONS(2134),
    [anon_sym_switch] = ACTIONS(2134),
    [anon_sym_case] = ACTIONS(2134),
    [anon_sym_default] = ACTIONS(2134),
    [anon_sym_while] = ACTIONS(2134),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_for] = ACTIONS(2134),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_break] = ACTIONS(2134),
    [anon_sym_continue] = ACTIONS(2134),
    [anon_sym_goto] = ACTIONS(2134),
    [anon_sym___try] = ACTIONS(2134),
    [anon_sym___leave] = ACTIONS(2134),
    [anon_sym_not] = ACTIONS(2134),
    [anon_sym_compl] = ACTIONS(2134),
    [anon_sym_DASH_DASH] = ACTIONS(2136),
    [anon_sym_PLUS_PLUS] = ACTIONS(2136),
    [anon_sym_sizeof] = ACTIONS(2134),
    [anon_sym___alignof__] = ACTIONS(2134),
    [anon_sym___alignof] = ACTIONS(2134),
    [anon_sym__alignof] = ACTIONS(2134),
    [anon_sym_alignof] = ACTIONS(2134),
    [anon_sym__Alignof] = ACTIONS(2134),
    [anon_sym_offsetof] = ACTIONS(2134),
    [anon_sym__Generic] = ACTIONS(2134),
    [anon_sym_asm] = ACTIONS(2134),
    [anon_sym___asm__] = ACTIONS(2134),
    [sym_number_literal] = ACTIONS(2136),
    [anon_sym_L_SQUOTE] = ACTIONS(2136),
    [anon_sym_u_SQUOTE] = ACTIONS(2136),
    [anon_sym_U_SQUOTE] = ACTIONS(2136),
    [anon_sym_u8_SQUOTE] = ACTIONS(2136),
    [anon_sym_SQUOTE] = ACTIONS(2136),
    [anon_sym_L_DQUOTE] = ACTIONS(2136),
    [anon_sym_u_DQUOTE] = ACTIONS(2136),
    [anon_sym_U_DQUOTE] = ACTIONS(2136),
    [anon_sym_u8_DQUOTE] = ACTIONS(2136),
    [anon_sym_DQUOTE] = ACTIONS(2136),
    [sym_true] = ACTIONS(2134),
    [sym_false] = ACTIONS(2134),
    [anon_sym_NULL] = ACTIONS(2134),
    [anon_sym_nullptr] = ACTIONS(2134),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2134),
    [anon_sym_decltype] = ACTIONS(2134),
    [sym_virtual] = ACTIONS(2134),
    [anon_sym_explicit] = ACTIONS(2134),
    [anon_sym_typename] = ACTIONS(2134),
    [anon_sym_template] = ACTIONS(2134),
    [anon_sym_operator] = ACTIONS(2134),
    [anon_sym_try] = ACTIONS(2134),
    [anon_sym_delete] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2134),
    [anon_sym_namespace] = ACTIONS(2134),
    [anon_sym_using] = ACTIONS(2134),
    [anon_sym_static_assert] = ACTIONS(2134),
    [anon_sym_concept] = ACTIONS(2134),
    [anon_sym_co_return] = ACTIONS(2134),
    [anon_sym_co_yield] = ACTIONS(2134),
    [anon_sym_R_DQUOTE] = ACTIONS(2136),
    [anon_sym_LR_DQUOTE] = ACTIONS(2136),
    [anon_sym_uR_DQUOTE] = ACTIONS(2136),
    [anon_sym_UR_DQUOTE] = ACTIONS(2136),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2136),
    [anon_sym_co_await] = ACTIONS(2134),
    [anon_sym_new] = ACTIONS(2134),
    [anon_sym_requires] = ACTIONS(2134),
    [sym_this] = ACTIONS(2134),
    [anon_sym_discard] = ACTIONS(2134),
    [anon_sym_precise] = ACTIONS(2134),
    [anon_sym_shared] = ACTIONS(2134),
    [anon_sym_groupshared] = ACTIONS(2134),
    [anon_sym_uniform] = ACTIONS(2134),
    [anon_sym_row_major] = ACTIONS(2134),
    [anon_sym_column_major] = ACTIONS(2134),
    [anon_sym_globallycoherent] = ACTIONS(2134),
    [anon_sym_centroid] = ACTIONS(2134),
    [anon_sym_noperspective] = ACTIONS(2134),
    [anon_sym_nointerpolation] = ACTIONS(2134),
    [anon_sym_sample] = ACTIONS(2134),
    [anon_sym_linear] = ACTIONS(2134),
    [anon_sym_snorm] = ACTIONS(2134),
    [anon_sym_unorm] = ACTIONS(2134),
    [anon_sym_point] = ACTIONS(2134),
    [anon_sym_line] = ACTIONS(2134),
    [anon_sym_triangleadj] = ACTIONS(2134),
    [anon_sym_lineadj] = ACTIONS(2134),
    [anon_sym_triangle] = ACTIONS(2134),
    [anon_sym_cbuffer] = ACTIONS(2134),
  },
  [492] = {
    [ts_builtin_sym_end] = ACTIONS(2234),
    [sym_identifier] = ACTIONS(2232),
    [aux_sym_preproc_include_token1] = ACTIONS(2232),
    [aux_sym_preproc_def_token1] = ACTIONS(2232),
    [aux_sym_preproc_if_token1] = ACTIONS(2232),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2232),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2232),
    [sym_preproc_directive] = ACTIONS(2232),
    [anon_sym_LPAREN2] = ACTIONS(2234),
    [anon_sym_BANG] = ACTIONS(2234),
    [anon_sym_TILDE] = ACTIONS(2234),
    [anon_sym_DASH] = ACTIONS(2232),
    [anon_sym_PLUS] = ACTIONS(2232),
    [anon_sym_STAR] = ACTIONS(2234),
    [anon_sym_AMP_AMP] = ACTIONS(2234),
    [anon_sym_AMP] = ACTIONS(2232),
    [anon_sym_SEMI] = ACTIONS(2234),
    [anon_sym___extension__] = ACTIONS(2232),
    [anon_sym_typedef] = ACTIONS(2232),
    [anon_sym_in] = ACTIONS(2232),
    [anon_sym_out] = ACTIONS(2232),
    [anon_sym_inout] = ACTIONS(2232),
    [anon_sym_extern] = ACTIONS(2232),
    [anon_sym___attribute__] = ACTIONS(2232),
    [anon_sym_COLON_COLON] = ACTIONS(2234),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2234),
    [anon_sym___declspec] = ACTIONS(2232),
    [anon_sym___based] = ACTIONS(2232),
    [anon_sym___cdecl] = ACTIONS(2232),
    [anon_sym___clrcall] = ACTIONS(2232),
    [anon_sym___stdcall] = ACTIONS(2232),
    [anon_sym___fastcall] = ACTIONS(2232),
    [anon_sym___thiscall] = ACTIONS(2232),
    [anon_sym___vectorcall] = ACTIONS(2232),
    [anon_sym_LBRACE] = ACTIONS(2234),
    [anon_sym_signed] = ACTIONS(2232),
    [anon_sym_unsigned] = ACTIONS(2232),
    [anon_sym_long] = ACTIONS(2232),
    [anon_sym_short] = ACTIONS(2232),
    [anon_sym_LBRACK] = ACTIONS(2232),
    [anon_sym_static] = ACTIONS(2232),
    [anon_sym_register] = ACTIONS(2232),
    [anon_sym_inline] = ACTIONS(2232),
    [anon_sym___inline] = ACTIONS(2232),
    [anon_sym___inline__] = ACTIONS(2232),
    [anon_sym___forceinline] = ACTIONS(2232),
    [anon_sym_thread_local] = ACTIONS(2232),
    [anon_sym___thread] = ACTIONS(2232),
    [anon_sym_const] = ACTIONS(2232),
    [anon_sym_constexpr] = ACTIONS(2232),
    [anon_sym_volatile] = ACTIONS(2232),
    [anon_sym_restrict] = ACTIONS(2232),
    [anon_sym___restrict__] = ACTIONS(2232),
    [anon_sym__Atomic] = ACTIONS(2232),
    [anon_sym__Noreturn] = ACTIONS(2232),
    [anon_sym_noreturn] = ACTIONS(2232),
    [anon_sym_mutable] = ACTIONS(2232),
    [anon_sym_constinit] = ACTIONS(2232),
    [anon_sym_consteval] = ACTIONS(2232),
    [anon_sym_alignas] = ACTIONS(2232),
    [anon_sym__Alignas] = ACTIONS(2232),
    [sym_primitive_type] = ACTIONS(2232),
    [anon_sym_enum] = ACTIONS(2232),
    [anon_sym_class] = ACTIONS(2232),
    [anon_sym_struct] = ACTIONS(2232),
    [anon_sym_union] = ACTIONS(2232),
    [anon_sym_if] = ACTIONS(2232),
    [anon_sym_else] = ACTIONS(2232),
    [anon_sym_switch] = ACTIONS(2232),
    [anon_sym_case] = ACTIONS(2232),
    [anon_sym_default] = ACTIONS(2232),
    [anon_sym_while] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(2232),
    [anon_sym_for] = ACTIONS(2232),
    [anon_sym_return] = ACTIONS(2232),
    [anon_sym_break] = ACTIONS(2232),
    [anon_sym_continue] = ACTIONS(2232),
    [anon_sym_goto] = ACTIONS(2232),
    [anon_sym___try] = ACTIONS(2232),
    [anon_sym___leave] = ACTIONS(2232),
    [anon_sym_not] = ACTIONS(2232),
    [anon_sym_compl] = ACTIONS(2232),
    [anon_sym_DASH_DASH] = ACTIONS(2234),
    [anon_sym_PLUS_PLUS] = ACTIONS(2234),
    [anon_sym_sizeof] = ACTIONS(2232),
    [anon_sym___alignof__] = ACTIONS(2232),
    [anon_sym___alignof] = ACTIONS(2232),
    [anon_sym__alignof] = ACTIONS(2232),
    [anon_sym_alignof] = ACTIONS(2232),
    [anon_sym__Alignof] = ACTIONS(2232),
    [anon_sym_offsetof] = ACTIONS(2232),
    [anon_sym__Generic] = ACTIONS(2232),
    [anon_sym_asm] = ACTIONS(2232),
    [anon_sym___asm__] = ACTIONS(2232),
    [sym_number_literal] = ACTIONS(2234),
    [anon_sym_L_SQUOTE] = ACTIONS(2234),
    [anon_sym_u_SQUOTE] = ACTIONS(2234),
    [anon_sym_U_SQUOTE] = ACTIONS(2234),
    [anon_sym_u8_SQUOTE] = ACTIONS(2234),
    [anon_sym_SQUOTE] = ACTIONS(2234),
    [anon_sym_L_DQUOTE] = ACTIONS(2234),
    [anon_sym_u_DQUOTE] = ACTIONS(2234),
    [anon_sym_U_DQUOTE] = ACTIONS(2234),
    [anon_sym_u8_DQUOTE] = ACTIONS(2234),
    [anon_sym_DQUOTE] = ACTIONS(2234),
    [sym_true] = ACTIONS(2232),
    [sym_false] = ACTIONS(2232),
    [anon_sym_NULL] = ACTIONS(2232),
    [anon_sym_nullptr] = ACTIONS(2232),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2232),
    [anon_sym_decltype] = ACTIONS(2232),
    [sym_virtual] = ACTIONS(2232),
    [anon_sym_explicit] = ACTIONS(2232),
    [anon_sym_typename] = ACTIONS(2232),
    [anon_sym_template] = ACTIONS(2232),
    [anon_sym_operator] = ACTIONS(2232),
    [anon_sym_try] = ACTIONS(2232),
    [anon_sym_delete] = ACTIONS(2232),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_namespace] = ACTIONS(2232),
    [anon_sym_using] = ACTIONS(2232),
    [anon_sym_static_assert] = ACTIONS(2232),
    [anon_sym_concept] = ACTIONS(2232),
    [anon_sym_co_return] = ACTIONS(2232),
    [anon_sym_co_yield] = ACTIONS(2232),
    [anon_sym_R_DQUOTE] = ACTIONS(2234),
    [anon_sym_LR_DQUOTE] = ACTIONS(2234),
    [anon_sym_uR_DQUOTE] = ACTIONS(2234),
    [anon_sym_UR_DQUOTE] = ACTIONS(2234),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2234),
    [anon_sym_co_await] = ACTIONS(2232),
    [anon_sym_new] = ACTIONS(2232),
    [anon_sym_requires] = ACTIONS(2232),
    [sym_this] = ACTIONS(2232),
    [anon_sym_discard] = ACTIONS(2232),
    [anon_sym_precise] = ACTIONS(2232),
    [anon_sym_shared] = ACTIONS(2232),
    [anon_sym_groupshared] = ACTIONS(2232),
    [anon_sym_uniform] = ACTIONS(2232),
    [anon_sym_row_major] = ACTIONS(2232),
    [anon_sym_column_major] = ACTIONS(2232),
    [anon_sym_globallycoherent] = ACTIONS(2232),
    [anon_sym_centroid] = ACTIONS(2232),
    [anon_sym_noperspective] = ACTIONS(2232),
    [anon_sym_nointerpolation] = ACTIONS(2232),
    [anon_sym_sample] = ACTIONS(2232),
    [anon_sym_linear] = ACTIONS(2232),
    [anon_sym_snorm] = ACTIONS(2232),
    [anon_sym_unorm] = ACTIONS(2232),
    [anon_sym_point] = ACTIONS(2232),
    [anon_sym_line] = ACTIONS(2232),
    [anon_sym_triangleadj] = ACTIONS(2232),
    [anon_sym_lineadj] = ACTIONS(2232),
    [anon_sym_triangle] = ACTIONS(2232),
    [anon_sym_cbuffer] = ACTIONS(2232),
  },
  [493] = {
    [sym_identifier] = ACTIONS(2272),
    [aux_sym_preproc_include_token1] = ACTIONS(2272),
    [aux_sym_preproc_def_token1] = ACTIONS(2272),
    [aux_sym_preproc_if_token1] = ACTIONS(2272),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2272),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2272),
    [sym_preproc_directive] = ACTIONS(2272),
    [anon_sym_LPAREN2] = ACTIONS(2274),
    [anon_sym_BANG] = ACTIONS(2274),
    [anon_sym_TILDE] = ACTIONS(2274),
    [anon_sym_DASH] = ACTIONS(2272),
    [anon_sym_PLUS] = ACTIONS(2272),
    [anon_sym_STAR] = ACTIONS(2274),
    [anon_sym_AMP_AMP] = ACTIONS(2274),
    [anon_sym_AMP] = ACTIONS(2272),
    [anon_sym_SEMI] = ACTIONS(2274),
    [anon_sym___extension__] = ACTIONS(2272),
    [anon_sym_typedef] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2272),
    [anon_sym_out] = ACTIONS(2272),
    [anon_sym_inout] = ACTIONS(2272),
    [anon_sym_extern] = ACTIONS(2272),
    [anon_sym___attribute__] = ACTIONS(2272),
    [anon_sym_COLON_COLON] = ACTIONS(2274),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2274),
    [anon_sym___declspec] = ACTIONS(2272),
    [anon_sym___based] = ACTIONS(2272),
    [anon_sym___cdecl] = ACTIONS(2272),
    [anon_sym___clrcall] = ACTIONS(2272),
    [anon_sym___stdcall] = ACTIONS(2272),
    [anon_sym___fastcall] = ACTIONS(2272),
    [anon_sym___thiscall] = ACTIONS(2272),
    [anon_sym___vectorcall] = ACTIONS(2272),
    [anon_sym_LBRACE] = ACTIONS(2274),
    [anon_sym_RBRACE] = ACTIONS(2274),
    [anon_sym_signed] = ACTIONS(2272),
    [anon_sym_unsigned] = ACTIONS(2272),
    [anon_sym_long] = ACTIONS(2272),
    [anon_sym_short] = ACTIONS(2272),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(2272),
    [anon_sym_register] = ACTIONS(2272),
    [anon_sym_inline] = ACTIONS(2272),
    [anon_sym___inline] = ACTIONS(2272),
    [anon_sym___inline__] = ACTIONS(2272),
    [anon_sym___forceinline] = ACTIONS(2272),
    [anon_sym_thread_local] = ACTIONS(2272),
    [anon_sym___thread] = ACTIONS(2272),
    [anon_sym_const] = ACTIONS(2272),
    [anon_sym_constexpr] = ACTIONS(2272),
    [anon_sym_volatile] = ACTIONS(2272),
    [anon_sym_restrict] = ACTIONS(2272),
    [anon_sym___restrict__] = ACTIONS(2272),
    [anon_sym__Atomic] = ACTIONS(2272),
    [anon_sym__Noreturn] = ACTIONS(2272),
    [anon_sym_noreturn] = ACTIONS(2272),
    [anon_sym_mutable] = ACTIONS(2272),
    [anon_sym_constinit] = ACTIONS(2272),
    [anon_sym_consteval] = ACTIONS(2272),
    [anon_sym_alignas] = ACTIONS(2272),
    [anon_sym__Alignas] = ACTIONS(2272),
    [sym_primitive_type] = ACTIONS(2272),
    [anon_sym_enum] = ACTIONS(2272),
    [anon_sym_class] = ACTIONS(2272),
    [anon_sym_struct] = ACTIONS(2272),
    [anon_sym_union] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2272),
    [anon_sym_else] = ACTIONS(2272),
    [anon_sym_switch] = ACTIONS(2272),
    [anon_sym_case] = ACTIONS(2272),
    [anon_sym_default] = ACTIONS(2272),
    [anon_sym_while] = ACTIONS(2272),
    [anon_sym_do] = ACTIONS(2272),
    [anon_sym_for] = ACTIONS(2272),
    [anon_sym_return] = ACTIONS(2272),
    [anon_sym_break] = ACTIONS(2272),
    [anon_sym_continue] = ACTIONS(2272),
    [anon_sym_goto] = ACTIONS(2272),
    [anon_sym___try] = ACTIONS(2272),
    [anon_sym___leave] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2272),
    [anon_sym_compl] = ACTIONS(2272),
    [anon_sym_DASH_DASH] = ACTIONS(2274),
    [anon_sym_PLUS_PLUS] = ACTIONS(2274),
    [anon_sym_sizeof] = ACTIONS(2272),
    [anon_sym___alignof__] = ACTIONS(2272),
    [anon_sym___alignof] = ACTIONS(2272),
    [anon_sym__alignof] = ACTIONS(2272),
    [anon_sym_alignof] = ACTIONS(2272),
    [anon_sym__Alignof] = ACTIONS(2272),
    [anon_sym_offsetof] = ACTIONS(2272),
    [anon_sym__Generic] = ACTIONS(2272),
    [anon_sym_asm] = ACTIONS(2272),
    [anon_sym___asm__] = ACTIONS(2272),
    [sym_number_literal] = ACTIONS(2274),
    [anon_sym_L_SQUOTE] = ACTIONS(2274),
    [anon_sym_u_SQUOTE] = ACTIONS(2274),
    [anon_sym_U_SQUOTE] = ACTIONS(2274),
    [anon_sym_u8_SQUOTE] = ACTIONS(2274),
    [anon_sym_SQUOTE] = ACTIONS(2274),
    [anon_sym_L_DQUOTE] = ACTIONS(2274),
    [anon_sym_u_DQUOTE] = ACTIONS(2274),
    [anon_sym_U_DQUOTE] = ACTIONS(2274),
    [anon_sym_u8_DQUOTE] = ACTIONS(2274),
    [anon_sym_DQUOTE] = ACTIONS(2274),
    [sym_true] = ACTIONS(2272),
    [sym_false] = ACTIONS(2272),
    [anon_sym_NULL] = ACTIONS(2272),
    [anon_sym_nullptr] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2272),
    [anon_sym_decltype] = ACTIONS(2272),
    [sym_virtual] = ACTIONS(2272),
    [anon_sym_explicit] = ACTIONS(2272),
    [anon_sym_typename] = ACTIONS(2272),
    [anon_sym_template] = ACTIONS(2272),
    [anon_sym_operator] = ACTIONS(2272),
    [anon_sym_try] = ACTIONS(2272),
    [anon_sym_delete] = ACTIONS(2272),
    [anon_sym_throw] = ACTIONS(2272),
    [anon_sym_namespace] = ACTIONS(2272),
    [anon_sym_using] = ACTIONS(2272),
    [anon_sym_static_assert] = ACTIONS(2272),
    [anon_sym_concept] = ACTIONS(2272),
    [anon_sym_co_return] = ACTIONS(2272),
    [anon_sym_co_yield] = ACTIONS(2272),
    [anon_sym_R_DQUOTE] = ACTIONS(2274),
    [anon_sym_LR_DQUOTE] = ACTIONS(2274),
    [anon_sym_uR_DQUOTE] = ACTIONS(2274),
    [anon_sym_UR_DQUOTE] = ACTIONS(2274),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2274),
    [anon_sym_co_await] = ACTIONS(2272),
    [anon_sym_new] = ACTIONS(2272),
    [anon_sym_requires] = ACTIONS(2272),
    [sym_this] = ACTIONS(2272),
    [anon_sym_discard] = ACTIONS(2272),
    [anon_sym_precise] = ACTIONS(2272),
    [anon_sym_shared] = ACTIONS(2272),
    [anon_sym_groupshared] = ACTIONS(2272),
    [anon_sym_uniform] = ACTIONS(2272),
    [anon_sym_row_major] = ACTIONS(2272),
    [anon_sym_column_major] = ACTIONS(2272),
    [anon_sym_globallycoherent] = ACTIONS(2272),
    [anon_sym_centroid] = ACTIONS(2272),
    [anon_sym_noperspective] = ACTIONS(2272),
    [anon_sym_nointerpolation] = ACTIONS(2272),
    [anon_sym_sample] = ACTIONS(2272),
    [anon_sym_linear] = ACTIONS(2272),
    [anon_sym_snorm] = ACTIONS(2272),
    [anon_sym_unorm] = ACTIONS(2272),
    [anon_sym_point] = ACTIONS(2272),
    [anon_sym_line] = ACTIONS(2272),
    [anon_sym_triangleadj] = ACTIONS(2272),
    [anon_sym_lineadj] = ACTIONS(2272),
    [anon_sym_triangle] = ACTIONS(2272),
    [anon_sym_cbuffer] = ACTIONS(2272),
  },
  [494] = {
    [sym_identifier] = ACTIONS(1947),
    [aux_sym_preproc_include_token1] = ACTIONS(1947),
    [aux_sym_preproc_def_token1] = ACTIONS(1947),
    [anon_sym_COMMA] = ACTIONS(2202),
    [aux_sym_preproc_if_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1947),
    [sym_preproc_directive] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1945),
    [anon_sym_BANG] = ACTIONS(1945),
    [anon_sym_TILDE] = ACTIONS(1945),
    [anon_sym_DASH] = ACTIONS(1947),
    [anon_sym_PLUS] = ACTIONS(1947),
    [anon_sym_STAR] = ACTIONS(1945),
    [anon_sym_AMP_AMP] = ACTIONS(1945),
    [anon_sym_AMP] = ACTIONS(1947),
    [anon_sym_SEMI] = ACTIONS(1945),
    [anon_sym___extension__] = ACTIONS(1947),
    [anon_sym_typedef] = ACTIONS(1947),
    [anon_sym_in] = ACTIONS(1947),
    [anon_sym_out] = ACTIONS(1947),
    [anon_sym_inout] = ACTIONS(1947),
    [anon_sym_extern] = ACTIONS(1947),
    [anon_sym___attribute__] = ACTIONS(1947),
    [anon_sym_COLON_COLON] = ACTIONS(1945),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1945),
    [anon_sym___declspec] = ACTIONS(1947),
    [anon_sym___based] = ACTIONS(1947),
    [anon_sym___cdecl] = ACTIONS(1947),
    [anon_sym___clrcall] = ACTIONS(1947),
    [anon_sym___stdcall] = ACTIONS(1947),
    [anon_sym___fastcall] = ACTIONS(1947),
    [anon_sym___thiscall] = ACTIONS(1947),
    [anon_sym___vectorcall] = ACTIONS(1947),
    [anon_sym_LBRACE] = ACTIONS(1945),
    [anon_sym_RBRACE] = ACTIONS(2202),
    [anon_sym_signed] = ACTIONS(1947),
    [anon_sym_unsigned] = ACTIONS(1947),
    [anon_sym_long] = ACTIONS(1947),
    [anon_sym_short] = ACTIONS(1947),
    [anon_sym_LBRACK] = ACTIONS(1947),
    [anon_sym_static] = ACTIONS(1947),
    [anon_sym_register] = ACTIONS(1947),
    [anon_sym_inline] = ACTIONS(1947),
    [anon_sym___inline] = ACTIONS(1947),
    [anon_sym___inline__] = ACTIONS(1947),
    [anon_sym___forceinline] = ACTIONS(1947),
    [anon_sym_thread_local] = ACTIONS(1947),
    [anon_sym___thread] = ACTIONS(1947),
    [anon_sym_const] = ACTIONS(1947),
    [anon_sym_constexpr] = ACTIONS(1947),
    [anon_sym_volatile] = ACTIONS(1947),
    [anon_sym_restrict] = ACTIONS(1947),
    [anon_sym___restrict__] = ACTIONS(1947),
    [anon_sym__Atomic] = ACTIONS(1947),
    [anon_sym__Noreturn] = ACTIONS(1947),
    [anon_sym_noreturn] = ACTIONS(1947),
    [anon_sym_mutable] = ACTIONS(1947),
    [anon_sym_constinit] = ACTIONS(1947),
    [anon_sym_consteval] = ACTIONS(1947),
    [anon_sym_alignas] = ACTIONS(1947),
    [anon_sym__Alignas] = ACTIONS(1947),
    [sym_primitive_type] = ACTIONS(1947),
    [anon_sym_enum] = ACTIONS(1947),
    [anon_sym_class] = ACTIONS(1947),
    [anon_sym_struct] = ACTIONS(1947),
    [anon_sym_union] = ACTIONS(1947),
    [anon_sym_if] = ACTIONS(1947),
    [anon_sym_switch] = ACTIONS(1947),
    [anon_sym_case] = ACTIONS(1947),
    [anon_sym_default] = ACTIONS(1947),
    [anon_sym_while] = ACTIONS(1947),
    [anon_sym_do] = ACTIONS(1947),
    [anon_sym_for] = ACTIONS(1947),
    [anon_sym_return] = ACTIONS(1947),
    [anon_sym_break] = ACTIONS(1947),
    [anon_sym_continue] = ACTIONS(1947),
    [anon_sym_goto] = ACTIONS(1947),
    [anon_sym___try] = ACTIONS(1947),
    [anon_sym___leave] = ACTIONS(1947),
    [anon_sym_not] = ACTIONS(1947),
    [anon_sym_compl] = ACTIONS(1947),
    [anon_sym_DASH_DASH] = ACTIONS(1945),
    [anon_sym_PLUS_PLUS] = ACTIONS(1945),
    [anon_sym_sizeof] = ACTIONS(1947),
    [anon_sym___alignof__] = ACTIONS(1947),
    [anon_sym___alignof] = ACTIONS(1947),
    [anon_sym__alignof] = ACTIONS(1947),
    [anon_sym_alignof] = ACTIONS(1947),
    [anon_sym__Alignof] = ACTIONS(1947),
    [anon_sym_offsetof] = ACTIONS(1947),
    [anon_sym__Generic] = ACTIONS(1947),
    [anon_sym_asm] = ACTIONS(1947),
    [anon_sym___asm__] = ACTIONS(1947),
    [sym_number_literal] = ACTIONS(1945),
    [anon_sym_L_SQUOTE] = ACTIONS(1945),
    [anon_sym_u_SQUOTE] = ACTIONS(1945),
    [anon_sym_U_SQUOTE] = ACTIONS(1945),
    [anon_sym_u8_SQUOTE] = ACTIONS(1945),
    [anon_sym_SQUOTE] = ACTIONS(1945),
    [anon_sym_L_DQUOTE] = ACTIONS(1945),
    [anon_sym_u_DQUOTE] = ACTIONS(1945),
    [anon_sym_U_DQUOTE] = ACTIONS(1945),
    [anon_sym_u8_DQUOTE] = ACTIONS(1945),
    [anon_sym_DQUOTE] = ACTIONS(1945),
    [sym_true] = ACTIONS(1947),
    [sym_false] = ACTIONS(1947),
    [anon_sym_NULL] = ACTIONS(1947),
    [anon_sym_nullptr] = ACTIONS(1947),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1947),
    [anon_sym_decltype] = ACTIONS(1947),
    [sym_virtual] = ACTIONS(1947),
    [anon_sym_explicit] = ACTIONS(1947),
    [anon_sym_typename] = ACTIONS(1947),
    [anon_sym_template] = ACTIONS(1947),
    [anon_sym_operator] = ACTIONS(1947),
    [anon_sym_try] = ACTIONS(1947),
    [anon_sym_delete] = ACTIONS(1947),
    [anon_sym_throw] = ACTIONS(1947),
    [anon_sym_namespace] = ACTIONS(1947),
    [anon_sym_using] = ACTIONS(1947),
    [anon_sym_static_assert] = ACTIONS(1947),
    [anon_sym_concept] = ACTIONS(1947),
    [anon_sym_co_return] = ACTIONS(1947),
    [anon_sym_co_yield] = ACTIONS(1947),
    [anon_sym_R_DQUOTE] = ACTIONS(1945),
    [anon_sym_LR_DQUOTE] = ACTIONS(1945),
    [anon_sym_uR_DQUOTE] = ACTIONS(1945),
    [anon_sym_UR_DQUOTE] = ACTIONS(1945),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1945),
    [anon_sym_co_await] = ACTIONS(1947),
    [anon_sym_new] = ACTIONS(1947),
    [anon_sym_requires] = ACTIONS(1947),
    [sym_this] = ACTIONS(1947),
    [anon_sym_discard] = ACTIONS(1947),
    [anon_sym_precise] = ACTIONS(1947),
    [anon_sym_shared] = ACTIONS(1947),
    [anon_sym_groupshared] = ACTIONS(1947),
    [anon_sym_uniform] = ACTIONS(1947),
    [anon_sym_row_major] = ACTIONS(1947),
    [anon_sym_column_major] = ACTIONS(1947),
    [anon_sym_globallycoherent] = ACTIONS(1947),
    [anon_sym_centroid] = ACTIONS(1947),
    [anon_sym_noperspective] = ACTIONS(1947),
    [anon_sym_nointerpolation] = ACTIONS(1947),
    [anon_sym_sample] = ACTIONS(1947),
    [anon_sym_linear] = ACTIONS(1947),
    [anon_sym_snorm] = ACTIONS(1947),
    [anon_sym_unorm] = ACTIONS(1947),
    [anon_sym_point] = ACTIONS(1947),
    [anon_sym_line] = ACTIONS(1947),
    [anon_sym_triangleadj] = ACTIONS(1947),
    [anon_sym_lineadj] = ACTIONS(1947),
    [anon_sym_triangle] = ACTIONS(1947),
    [anon_sym_cbuffer] = ACTIONS(1947),
  },
  [495] = {
    [ts_builtin_sym_end] = ACTIONS(2270),
    [sym_identifier] = ACTIONS(2268),
    [aux_sym_preproc_include_token1] = ACTIONS(2268),
    [aux_sym_preproc_def_token1] = ACTIONS(2268),
    [aux_sym_preproc_if_token1] = ACTIONS(2268),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2268),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2268),
    [sym_preproc_directive] = ACTIONS(2268),
    [anon_sym_LPAREN2] = ACTIONS(2270),
    [anon_sym_BANG] = ACTIONS(2270),
    [anon_sym_TILDE] = ACTIONS(2270),
    [anon_sym_DASH] = ACTIONS(2268),
    [anon_sym_PLUS] = ACTIONS(2268),
    [anon_sym_STAR] = ACTIONS(2270),
    [anon_sym_AMP_AMP] = ACTIONS(2270),
    [anon_sym_AMP] = ACTIONS(2268),
    [anon_sym_SEMI] = ACTIONS(2270),
    [anon_sym___extension__] = ACTIONS(2268),
    [anon_sym_typedef] = ACTIONS(2268),
    [anon_sym_in] = ACTIONS(2268),
    [anon_sym_out] = ACTIONS(2268),
    [anon_sym_inout] = ACTIONS(2268),
    [anon_sym_extern] = ACTIONS(2268),
    [anon_sym___attribute__] = ACTIONS(2268),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2270),
    [anon_sym___declspec] = ACTIONS(2268),
    [anon_sym___based] = ACTIONS(2268),
    [anon_sym___cdecl] = ACTIONS(2268),
    [anon_sym___clrcall] = ACTIONS(2268),
    [anon_sym___stdcall] = ACTIONS(2268),
    [anon_sym___fastcall] = ACTIONS(2268),
    [anon_sym___thiscall] = ACTIONS(2268),
    [anon_sym___vectorcall] = ACTIONS(2268),
    [anon_sym_LBRACE] = ACTIONS(2270),
    [anon_sym_signed] = ACTIONS(2268),
    [anon_sym_unsigned] = ACTIONS(2268),
    [anon_sym_long] = ACTIONS(2268),
    [anon_sym_short] = ACTIONS(2268),
    [anon_sym_LBRACK] = ACTIONS(2268),
    [anon_sym_static] = ACTIONS(2268),
    [anon_sym_register] = ACTIONS(2268),
    [anon_sym_inline] = ACTIONS(2268),
    [anon_sym___inline] = ACTIONS(2268),
    [anon_sym___inline__] = ACTIONS(2268),
    [anon_sym___forceinline] = ACTIONS(2268),
    [anon_sym_thread_local] = ACTIONS(2268),
    [anon_sym___thread] = ACTIONS(2268),
    [anon_sym_const] = ACTIONS(2268),
    [anon_sym_constexpr] = ACTIONS(2268),
    [anon_sym_volatile] = ACTIONS(2268),
    [anon_sym_restrict] = ACTIONS(2268),
    [anon_sym___restrict__] = ACTIONS(2268),
    [anon_sym__Atomic] = ACTIONS(2268),
    [anon_sym__Noreturn] = ACTIONS(2268),
    [anon_sym_noreturn] = ACTIONS(2268),
    [anon_sym_mutable] = ACTIONS(2268),
    [anon_sym_constinit] = ACTIONS(2268),
    [anon_sym_consteval] = ACTIONS(2268),
    [anon_sym_alignas] = ACTIONS(2268),
    [anon_sym__Alignas] = ACTIONS(2268),
    [sym_primitive_type] = ACTIONS(2268),
    [anon_sym_enum] = ACTIONS(2268),
    [anon_sym_class] = ACTIONS(2268),
    [anon_sym_struct] = ACTIONS(2268),
    [anon_sym_union] = ACTIONS(2268),
    [anon_sym_if] = ACTIONS(2268),
    [anon_sym_else] = ACTIONS(2268),
    [anon_sym_switch] = ACTIONS(2268),
    [anon_sym_case] = ACTIONS(2268),
    [anon_sym_default] = ACTIONS(2268),
    [anon_sym_while] = ACTIONS(2268),
    [anon_sym_do] = ACTIONS(2268),
    [anon_sym_for] = ACTIONS(2268),
    [anon_sym_return] = ACTIONS(2268),
    [anon_sym_break] = ACTIONS(2268),
    [anon_sym_continue] = ACTIONS(2268),
    [anon_sym_goto] = ACTIONS(2268),
    [anon_sym___try] = ACTIONS(2268),
    [anon_sym___leave] = ACTIONS(2268),
    [anon_sym_not] = ACTIONS(2268),
    [anon_sym_compl] = ACTIONS(2268),
    [anon_sym_DASH_DASH] = ACTIONS(2270),
    [anon_sym_PLUS_PLUS] = ACTIONS(2270),
    [anon_sym_sizeof] = ACTIONS(2268),
    [anon_sym___alignof__] = ACTIONS(2268),
    [anon_sym___alignof] = ACTIONS(2268),
    [anon_sym__alignof] = ACTIONS(2268),
    [anon_sym_alignof] = ACTIONS(2268),
    [anon_sym__Alignof] = ACTIONS(2268),
    [anon_sym_offsetof] = ACTIONS(2268),
    [anon_sym__Generic] = ACTIONS(2268),
    [anon_sym_asm] = ACTIONS(2268),
    [anon_sym___asm__] = ACTIONS(2268),
    [sym_number_literal] = ACTIONS(2270),
    [anon_sym_L_SQUOTE] = ACTIONS(2270),
    [anon_sym_u_SQUOTE] = ACTIONS(2270),
    [anon_sym_U_SQUOTE] = ACTIONS(2270),
    [anon_sym_u8_SQUOTE] = ACTIONS(2270),
    [anon_sym_SQUOTE] = ACTIONS(2270),
    [anon_sym_L_DQUOTE] = ACTIONS(2270),
    [anon_sym_u_DQUOTE] = ACTIONS(2270),
    [anon_sym_U_DQUOTE] = ACTIONS(2270),
    [anon_sym_u8_DQUOTE] = ACTIONS(2270),
    [anon_sym_DQUOTE] = ACTIONS(2270),
    [sym_true] = ACTIONS(2268),
    [sym_false] = ACTIONS(2268),
    [anon_sym_NULL] = ACTIONS(2268),
    [anon_sym_nullptr] = ACTIONS(2268),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2268),
    [anon_sym_decltype] = ACTIONS(2268),
    [sym_virtual] = ACTIONS(2268),
    [anon_sym_explicit] = ACTIONS(2268),
    [anon_sym_typename] = ACTIONS(2268),
    [anon_sym_template] = ACTIONS(2268),
    [anon_sym_operator] = ACTIONS(2268),
    [anon_sym_try] = ACTIONS(2268),
    [anon_sym_delete] = ACTIONS(2268),
    [anon_sym_throw] = ACTIONS(2268),
    [anon_sym_namespace] = ACTIONS(2268),
    [anon_sym_using] = ACTIONS(2268),
    [anon_sym_static_assert] = ACTIONS(2268),
    [anon_sym_concept] = ACTIONS(2268),
    [anon_sym_co_return] = ACTIONS(2268),
    [anon_sym_co_yield] = ACTIONS(2268),
    [anon_sym_R_DQUOTE] = ACTIONS(2270),
    [anon_sym_LR_DQUOTE] = ACTIONS(2270),
    [anon_sym_uR_DQUOTE] = ACTIONS(2270),
    [anon_sym_UR_DQUOTE] = ACTIONS(2270),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2270),
    [anon_sym_co_await] = ACTIONS(2268),
    [anon_sym_new] = ACTIONS(2268),
    [anon_sym_requires] = ACTIONS(2268),
    [sym_this] = ACTIONS(2268),
    [anon_sym_discard] = ACTIONS(2268),
    [anon_sym_precise] = ACTIONS(2268),
    [anon_sym_shared] = ACTIONS(2268),
    [anon_sym_groupshared] = ACTIONS(2268),
    [anon_sym_uniform] = ACTIONS(2268),
    [anon_sym_row_major] = ACTIONS(2268),
    [anon_sym_column_major] = ACTIONS(2268),
    [anon_sym_globallycoherent] = ACTIONS(2268),
    [anon_sym_centroid] = ACTIONS(2268),
    [anon_sym_noperspective] = ACTIONS(2268),
    [anon_sym_nointerpolation] = ACTIONS(2268),
    [anon_sym_sample] = ACTIONS(2268),
    [anon_sym_linear] = ACTIONS(2268),
    [anon_sym_snorm] = ACTIONS(2268),
    [anon_sym_unorm] = ACTIONS(2268),
    [anon_sym_point] = ACTIONS(2268),
    [anon_sym_line] = ACTIONS(2268),
    [anon_sym_triangleadj] = ACTIONS(2268),
    [anon_sym_lineadj] = ACTIONS(2268),
    [anon_sym_triangle] = ACTIONS(2268),
    [anon_sym_cbuffer] = ACTIONS(2268),
  },
  [496] = {
    [ts_builtin_sym_end] = ACTIONS(2286),
    [sym_identifier] = ACTIONS(2284),
    [aux_sym_preproc_include_token1] = ACTIONS(2284),
    [aux_sym_preproc_def_token1] = ACTIONS(2284),
    [aux_sym_preproc_if_token1] = ACTIONS(2284),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2284),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2284),
    [sym_preproc_directive] = ACTIONS(2284),
    [anon_sym_LPAREN2] = ACTIONS(2286),
    [anon_sym_BANG] = ACTIONS(2286),
    [anon_sym_TILDE] = ACTIONS(2286),
    [anon_sym_DASH] = ACTIONS(2284),
    [anon_sym_PLUS] = ACTIONS(2284),
    [anon_sym_STAR] = ACTIONS(2286),
    [anon_sym_AMP_AMP] = ACTIONS(2286),
    [anon_sym_AMP] = ACTIONS(2284),
    [anon_sym_SEMI] = ACTIONS(2286),
    [anon_sym___extension__] = ACTIONS(2284),
    [anon_sym_typedef] = ACTIONS(2284),
    [anon_sym_in] = ACTIONS(2284),
    [anon_sym_out] = ACTIONS(2284),
    [anon_sym_inout] = ACTIONS(2284),
    [anon_sym_extern] = ACTIONS(2284),
    [anon_sym___attribute__] = ACTIONS(2284),
    [anon_sym_COLON_COLON] = ACTIONS(2286),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2286),
    [anon_sym___declspec] = ACTIONS(2284),
    [anon_sym___based] = ACTIONS(2284),
    [anon_sym___cdecl] = ACTIONS(2284),
    [anon_sym___clrcall] = ACTIONS(2284),
    [anon_sym___stdcall] = ACTIONS(2284),
    [anon_sym___fastcall] = ACTIONS(2284),
    [anon_sym___thiscall] = ACTIONS(2284),
    [anon_sym___vectorcall] = ACTIONS(2284),
    [anon_sym_LBRACE] = ACTIONS(2286),
    [anon_sym_signed] = ACTIONS(2284),
    [anon_sym_unsigned] = ACTIONS(2284),
    [anon_sym_long] = ACTIONS(2284),
    [anon_sym_short] = ACTIONS(2284),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [anon_sym_static] = ACTIONS(2284),
    [anon_sym_register] = ACTIONS(2284),
    [anon_sym_inline] = ACTIONS(2284),
    [anon_sym___inline] = ACTIONS(2284),
    [anon_sym___inline__] = ACTIONS(2284),
    [anon_sym___forceinline] = ACTIONS(2284),
    [anon_sym_thread_local] = ACTIONS(2284),
    [anon_sym___thread] = ACTIONS(2284),
    [anon_sym_const] = ACTIONS(2284),
    [anon_sym_constexpr] = ACTIONS(2284),
    [anon_sym_volatile] = ACTIONS(2284),
    [anon_sym_restrict] = ACTIONS(2284),
    [anon_sym___restrict__] = ACTIONS(2284),
    [anon_sym__Atomic] = ACTIONS(2284),
    [anon_sym__Noreturn] = ACTIONS(2284),
    [anon_sym_noreturn] = ACTIONS(2284),
    [anon_sym_mutable] = ACTIONS(2284),
    [anon_sym_constinit] = ACTIONS(2284),
    [anon_sym_consteval] = ACTIONS(2284),
    [anon_sym_alignas] = ACTIONS(2284),
    [anon_sym__Alignas] = ACTIONS(2284),
    [sym_primitive_type] = ACTIONS(2284),
    [anon_sym_enum] = ACTIONS(2284),
    [anon_sym_class] = ACTIONS(2284),
    [anon_sym_struct] = ACTIONS(2284),
    [anon_sym_union] = ACTIONS(2284),
    [anon_sym_if] = ACTIONS(2284),
    [anon_sym_else] = ACTIONS(2284),
    [anon_sym_switch] = ACTIONS(2284),
    [anon_sym_case] = ACTIONS(2284),
    [anon_sym_default] = ACTIONS(2284),
    [anon_sym_while] = ACTIONS(2284),
    [anon_sym_do] = ACTIONS(2284),
    [anon_sym_for] = ACTIONS(2284),
    [anon_sym_return] = ACTIONS(2284),
    [anon_sym_break] = ACTIONS(2284),
    [anon_sym_continue] = ACTIONS(2284),
    [anon_sym_goto] = ACTIONS(2284),
    [anon_sym___try] = ACTIONS(2284),
    [anon_sym___leave] = ACTIONS(2284),
    [anon_sym_not] = ACTIONS(2284),
    [anon_sym_compl] = ACTIONS(2284),
    [anon_sym_DASH_DASH] = ACTIONS(2286),
    [anon_sym_PLUS_PLUS] = ACTIONS(2286),
    [anon_sym_sizeof] = ACTIONS(2284),
    [anon_sym___alignof__] = ACTIONS(2284),
    [anon_sym___alignof] = ACTIONS(2284),
    [anon_sym__alignof] = ACTIONS(2284),
    [anon_sym_alignof] = ACTIONS(2284),
    [anon_sym__Alignof] = ACTIONS(2284),
    [anon_sym_offsetof] = ACTIONS(2284),
    [anon_sym__Generic] = ACTIONS(2284),
    [anon_sym_asm] = ACTIONS(2284),
    [anon_sym___asm__] = ACTIONS(2284),
    [sym_number_literal] = ACTIONS(2286),
    [anon_sym_L_SQUOTE] = ACTIONS(2286),
    [anon_sym_u_SQUOTE] = ACTIONS(2286),
    [anon_sym_U_SQUOTE] = ACTIONS(2286),
    [anon_sym_u8_SQUOTE] = ACTIONS(2286),
    [anon_sym_SQUOTE] = ACTIONS(2286),
    [anon_sym_L_DQUOTE] = ACTIONS(2286),
    [anon_sym_u_DQUOTE] = ACTIONS(2286),
    [anon_sym_U_DQUOTE] = ACTIONS(2286),
    [anon_sym_u8_DQUOTE] = ACTIONS(2286),
    [anon_sym_DQUOTE] = ACTIONS(2286),
    [sym_true] = ACTIONS(2284),
    [sym_false] = ACTIONS(2284),
    [anon_sym_NULL] = ACTIONS(2284),
    [anon_sym_nullptr] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2284),
    [anon_sym_decltype] = ACTIONS(2284),
    [sym_virtual] = ACTIONS(2284),
    [anon_sym_explicit] = ACTIONS(2284),
    [anon_sym_typename] = ACTIONS(2284),
    [anon_sym_template] = ACTIONS(2284),
    [anon_sym_operator] = ACTIONS(2284),
    [anon_sym_try] = ACTIONS(2284),
    [anon_sym_delete] = ACTIONS(2284),
    [anon_sym_throw] = ACTIONS(2284),
    [anon_sym_namespace] = ACTIONS(2284),
    [anon_sym_using] = ACTIONS(2284),
    [anon_sym_static_assert] = ACTIONS(2284),
    [anon_sym_concept] = ACTIONS(2284),
    [anon_sym_co_return] = ACTIONS(2284),
    [anon_sym_co_yield] = ACTIONS(2284),
    [anon_sym_R_DQUOTE] = ACTIONS(2286),
    [anon_sym_LR_DQUOTE] = ACTIONS(2286),
    [anon_sym_uR_DQUOTE] = ACTIONS(2286),
    [anon_sym_UR_DQUOTE] = ACTIONS(2286),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2286),
    [anon_sym_co_await] = ACTIONS(2284),
    [anon_sym_new] = ACTIONS(2284),
    [anon_sym_requires] = ACTIONS(2284),
    [sym_this] = ACTIONS(2284),
    [anon_sym_discard] = ACTIONS(2284),
    [anon_sym_precise] = ACTIONS(2284),
    [anon_sym_shared] = ACTIONS(2284),
    [anon_sym_groupshared] = ACTIONS(2284),
    [anon_sym_uniform] = ACTIONS(2284),
    [anon_sym_row_major] = ACTIONS(2284),
    [anon_sym_column_major] = ACTIONS(2284),
    [anon_sym_globallycoherent] = ACTIONS(2284),
    [anon_sym_centroid] = ACTIONS(2284),
    [anon_sym_noperspective] = ACTIONS(2284),
    [anon_sym_nointerpolation] = ACTIONS(2284),
    [anon_sym_sample] = ACTIONS(2284),
    [anon_sym_linear] = ACTIONS(2284),
    [anon_sym_snorm] = ACTIONS(2284),
    [anon_sym_unorm] = ACTIONS(2284),
    [anon_sym_point] = ACTIONS(2284),
    [anon_sym_line] = ACTIONS(2284),
    [anon_sym_triangleadj] = ACTIONS(2284),
    [anon_sym_lineadj] = ACTIONS(2284),
    [anon_sym_triangle] = ACTIONS(2284),
    [anon_sym_cbuffer] = ACTIONS(2284),
  },
  [497] = {
    [ts_builtin_sym_end] = ACTIONS(2282),
    [sym_identifier] = ACTIONS(2280),
    [aux_sym_preproc_include_token1] = ACTIONS(2280),
    [aux_sym_preproc_def_token1] = ACTIONS(2280),
    [aux_sym_preproc_if_token1] = ACTIONS(2280),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2280),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2280),
    [sym_preproc_directive] = ACTIONS(2280),
    [anon_sym_LPAREN2] = ACTIONS(2282),
    [anon_sym_BANG] = ACTIONS(2282),
    [anon_sym_TILDE] = ACTIONS(2282),
    [anon_sym_DASH] = ACTIONS(2280),
    [anon_sym_PLUS] = ACTIONS(2280),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_AMP_AMP] = ACTIONS(2282),
    [anon_sym_AMP] = ACTIONS(2280),
    [anon_sym_SEMI] = ACTIONS(2282),
    [anon_sym___extension__] = ACTIONS(2280),
    [anon_sym_typedef] = ACTIONS(2280),
    [anon_sym_in] = ACTIONS(2280),
    [anon_sym_out] = ACTIONS(2280),
    [anon_sym_inout] = ACTIONS(2280),
    [anon_sym_extern] = ACTIONS(2280),
    [anon_sym___attribute__] = ACTIONS(2280),
    [anon_sym_COLON_COLON] = ACTIONS(2282),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2282),
    [anon_sym___declspec] = ACTIONS(2280),
    [anon_sym___based] = ACTIONS(2280),
    [anon_sym___cdecl] = ACTIONS(2280),
    [anon_sym___clrcall] = ACTIONS(2280),
    [anon_sym___stdcall] = ACTIONS(2280),
    [anon_sym___fastcall] = ACTIONS(2280),
    [anon_sym___thiscall] = ACTIONS(2280),
    [anon_sym___vectorcall] = ACTIONS(2280),
    [anon_sym_LBRACE] = ACTIONS(2282),
    [anon_sym_signed] = ACTIONS(2280),
    [anon_sym_unsigned] = ACTIONS(2280),
    [anon_sym_long] = ACTIONS(2280),
    [anon_sym_short] = ACTIONS(2280),
    [anon_sym_LBRACK] = ACTIONS(2280),
    [anon_sym_static] = ACTIONS(2280),
    [anon_sym_register] = ACTIONS(2280),
    [anon_sym_inline] = ACTIONS(2280),
    [anon_sym___inline] = ACTIONS(2280),
    [anon_sym___inline__] = ACTIONS(2280),
    [anon_sym___forceinline] = ACTIONS(2280),
    [anon_sym_thread_local] = ACTIONS(2280),
    [anon_sym___thread] = ACTIONS(2280),
    [anon_sym_const] = ACTIONS(2280),
    [anon_sym_constexpr] = ACTIONS(2280),
    [anon_sym_volatile] = ACTIONS(2280),
    [anon_sym_restrict] = ACTIONS(2280),
    [anon_sym___restrict__] = ACTIONS(2280),
    [anon_sym__Atomic] = ACTIONS(2280),
    [anon_sym__Noreturn] = ACTIONS(2280),
    [anon_sym_noreturn] = ACTIONS(2280),
    [anon_sym_mutable] = ACTIONS(2280),
    [anon_sym_constinit] = ACTIONS(2280),
    [anon_sym_consteval] = ACTIONS(2280),
    [anon_sym_alignas] = ACTIONS(2280),
    [anon_sym__Alignas] = ACTIONS(2280),
    [sym_primitive_type] = ACTIONS(2280),
    [anon_sym_enum] = ACTIONS(2280),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2280),
    [anon_sym_union] = ACTIONS(2280),
    [anon_sym_if] = ACTIONS(2280),
    [anon_sym_else] = ACTIONS(2280),
    [anon_sym_switch] = ACTIONS(2280),
    [anon_sym_case] = ACTIONS(2280),
    [anon_sym_default] = ACTIONS(2280),
    [anon_sym_while] = ACTIONS(2280),
    [anon_sym_do] = ACTIONS(2280),
    [anon_sym_for] = ACTIONS(2280),
    [anon_sym_return] = ACTIONS(2280),
    [anon_sym_break] = ACTIONS(2280),
    [anon_sym_continue] = ACTIONS(2280),
    [anon_sym_goto] = ACTIONS(2280),
    [anon_sym___try] = ACTIONS(2280),
    [anon_sym___leave] = ACTIONS(2280),
    [anon_sym_not] = ACTIONS(2280),
    [anon_sym_compl] = ACTIONS(2280),
    [anon_sym_DASH_DASH] = ACTIONS(2282),
    [anon_sym_PLUS_PLUS] = ACTIONS(2282),
    [anon_sym_sizeof] = ACTIONS(2280),
    [anon_sym___alignof__] = ACTIONS(2280),
    [anon_sym___alignof] = ACTIONS(2280),
    [anon_sym__alignof] = ACTIONS(2280),
    [anon_sym_alignof] = ACTIONS(2280),
    [anon_sym__Alignof] = ACTIONS(2280),
    [anon_sym_offsetof] = ACTIONS(2280),
    [anon_sym__Generic] = ACTIONS(2280),
    [anon_sym_asm] = ACTIONS(2280),
    [anon_sym___asm__] = ACTIONS(2280),
    [sym_number_literal] = ACTIONS(2282),
    [anon_sym_L_SQUOTE] = ACTIONS(2282),
    [anon_sym_u_SQUOTE] = ACTIONS(2282),
    [anon_sym_U_SQUOTE] = ACTIONS(2282),
    [anon_sym_u8_SQUOTE] = ACTIONS(2282),
    [anon_sym_SQUOTE] = ACTIONS(2282),
    [anon_sym_L_DQUOTE] = ACTIONS(2282),
    [anon_sym_u_DQUOTE] = ACTIONS(2282),
    [anon_sym_U_DQUOTE] = ACTIONS(2282),
    [anon_sym_u8_DQUOTE] = ACTIONS(2282),
    [anon_sym_DQUOTE] = ACTIONS(2282),
    [sym_true] = ACTIONS(2280),
    [sym_false] = ACTIONS(2280),
    [anon_sym_NULL] = ACTIONS(2280),
    [anon_sym_nullptr] = ACTIONS(2280),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2280),
    [anon_sym_decltype] = ACTIONS(2280),
    [sym_virtual] = ACTIONS(2280),
    [anon_sym_explicit] = ACTIONS(2280),
    [anon_sym_typename] = ACTIONS(2280),
    [anon_sym_template] = ACTIONS(2280),
    [anon_sym_operator] = ACTIONS(2280),
    [anon_sym_try] = ACTIONS(2280),
    [anon_sym_delete] = ACTIONS(2280),
    [anon_sym_throw] = ACTIONS(2280),
    [anon_sym_namespace] = ACTIONS(2280),
    [anon_sym_using] = ACTIONS(2280),
    [anon_sym_static_assert] = ACTIONS(2280),
    [anon_sym_concept] = ACTIONS(2280),
    [anon_sym_co_return] = ACTIONS(2280),
    [anon_sym_co_yield] = ACTIONS(2280),
    [anon_sym_R_DQUOTE] = ACTIONS(2282),
    [anon_sym_LR_DQUOTE] = ACTIONS(2282),
    [anon_sym_uR_DQUOTE] = ACTIONS(2282),
    [anon_sym_UR_DQUOTE] = ACTIONS(2282),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2282),
    [anon_sym_co_await] = ACTIONS(2280),
    [anon_sym_new] = ACTIONS(2280),
    [anon_sym_requires] = ACTIONS(2280),
    [sym_this] = ACTIONS(2280),
    [anon_sym_discard] = ACTIONS(2280),
    [anon_sym_precise] = ACTIONS(2280),
    [anon_sym_shared] = ACTIONS(2280),
    [anon_sym_groupshared] = ACTIONS(2280),
    [anon_sym_uniform] = ACTIONS(2280),
    [anon_sym_row_major] = ACTIONS(2280),
    [anon_sym_column_major] = ACTIONS(2280),
    [anon_sym_globallycoherent] = ACTIONS(2280),
    [anon_sym_centroid] = ACTIONS(2280),
    [anon_sym_noperspective] = ACTIONS(2280),
    [anon_sym_nointerpolation] = ACTIONS(2280),
    [anon_sym_sample] = ACTIONS(2280),
    [anon_sym_linear] = ACTIONS(2280),
    [anon_sym_snorm] = ACTIONS(2280),
    [anon_sym_unorm] = ACTIONS(2280),
    [anon_sym_point] = ACTIONS(2280),
    [anon_sym_line] = ACTIONS(2280),
    [anon_sym_triangleadj] = ACTIONS(2280),
    [anon_sym_lineadj] = ACTIONS(2280),
    [anon_sym_triangle] = ACTIONS(2280),
    [anon_sym_cbuffer] = ACTIONS(2280),
  },
  [498] = {
    [sym_identifier] = ACTIONS(2090),
    [aux_sym_preproc_include_token1] = ACTIONS(2090),
    [aux_sym_preproc_def_token1] = ACTIONS(2090),
    [aux_sym_preproc_if_token1] = ACTIONS(2090),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2090),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2090),
    [sym_preproc_directive] = ACTIONS(2090),
    [anon_sym_LPAREN2] = ACTIONS(2092),
    [anon_sym_BANG] = ACTIONS(2092),
    [anon_sym_TILDE] = ACTIONS(2092),
    [anon_sym_DASH] = ACTIONS(2090),
    [anon_sym_PLUS] = ACTIONS(2090),
    [anon_sym_STAR] = ACTIONS(2092),
    [anon_sym_AMP_AMP] = ACTIONS(2092),
    [anon_sym_AMP] = ACTIONS(2090),
    [anon_sym_SEMI] = ACTIONS(2092),
    [anon_sym___extension__] = ACTIONS(2090),
    [anon_sym_typedef] = ACTIONS(2090),
    [anon_sym_in] = ACTIONS(2090),
    [anon_sym_out] = ACTIONS(2090),
    [anon_sym_inout] = ACTIONS(2090),
    [anon_sym_extern] = ACTIONS(2090),
    [anon_sym___attribute__] = ACTIONS(2090),
    [anon_sym_COLON_COLON] = ACTIONS(2092),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2092),
    [anon_sym___declspec] = ACTIONS(2090),
    [anon_sym___based] = ACTIONS(2090),
    [anon_sym___cdecl] = ACTIONS(2090),
    [anon_sym___clrcall] = ACTIONS(2090),
    [anon_sym___stdcall] = ACTIONS(2090),
    [anon_sym___fastcall] = ACTIONS(2090),
    [anon_sym___thiscall] = ACTIONS(2090),
    [anon_sym___vectorcall] = ACTIONS(2090),
    [anon_sym_LBRACE] = ACTIONS(2092),
    [anon_sym_RBRACE] = ACTIONS(2092),
    [anon_sym_signed] = ACTIONS(2090),
    [anon_sym_unsigned] = ACTIONS(2090),
    [anon_sym_long] = ACTIONS(2090),
    [anon_sym_short] = ACTIONS(2090),
    [anon_sym_LBRACK] = ACTIONS(2090),
    [anon_sym_static] = ACTIONS(2090),
    [anon_sym_register] = ACTIONS(2090),
    [anon_sym_inline] = ACTIONS(2090),
    [anon_sym___inline] = ACTIONS(2090),
    [anon_sym___inline__] = ACTIONS(2090),
    [anon_sym___forceinline] = ACTIONS(2090),
    [anon_sym_thread_local] = ACTIONS(2090),
    [anon_sym___thread] = ACTIONS(2090),
    [anon_sym_const] = ACTIONS(2090),
    [anon_sym_constexpr] = ACTIONS(2090),
    [anon_sym_volatile] = ACTIONS(2090),
    [anon_sym_restrict] = ACTIONS(2090),
    [anon_sym___restrict__] = ACTIONS(2090),
    [anon_sym__Atomic] = ACTIONS(2090),
    [anon_sym__Noreturn] = ACTIONS(2090),
    [anon_sym_noreturn] = ACTIONS(2090),
    [anon_sym_mutable] = ACTIONS(2090),
    [anon_sym_constinit] = ACTIONS(2090),
    [anon_sym_consteval] = ACTIONS(2090),
    [anon_sym_alignas] = ACTIONS(2090),
    [anon_sym__Alignas] = ACTIONS(2090),
    [sym_primitive_type] = ACTIONS(2090),
    [anon_sym_enum] = ACTIONS(2090),
    [anon_sym_class] = ACTIONS(2090),
    [anon_sym_struct] = ACTIONS(2090),
    [anon_sym_union] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(2090),
    [anon_sym_else] = ACTIONS(2090),
    [anon_sym_switch] = ACTIONS(2090),
    [anon_sym_case] = ACTIONS(2090),
    [anon_sym_default] = ACTIONS(2090),
    [anon_sym_while] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(2090),
    [anon_sym_for] = ACTIONS(2090),
    [anon_sym_return] = ACTIONS(2090),
    [anon_sym_break] = ACTIONS(2090),
    [anon_sym_continue] = ACTIONS(2090),
    [anon_sym_goto] = ACTIONS(2090),
    [anon_sym___try] = ACTIONS(2090),
    [anon_sym___leave] = ACTIONS(2090),
    [anon_sym_not] = ACTIONS(2090),
    [anon_sym_compl] = ACTIONS(2090),
    [anon_sym_DASH_DASH] = ACTIONS(2092),
    [anon_sym_PLUS_PLUS] = ACTIONS(2092),
    [anon_sym_sizeof] = ACTIONS(2090),
    [anon_sym___alignof__] = ACTIONS(2090),
    [anon_sym___alignof] = ACTIONS(2090),
    [anon_sym__alignof] = ACTIONS(2090),
    [anon_sym_alignof] = ACTIONS(2090),
    [anon_sym__Alignof] = ACTIONS(2090),
    [anon_sym_offsetof] = ACTIONS(2090),
    [anon_sym__Generic] = ACTIONS(2090),
    [anon_sym_asm] = ACTIONS(2090),
    [anon_sym___asm__] = ACTIONS(2090),
    [sym_number_literal] = ACTIONS(2092),
    [anon_sym_L_SQUOTE] = ACTIONS(2092),
    [anon_sym_u_SQUOTE] = ACTIONS(2092),
    [anon_sym_U_SQUOTE] = ACTIONS(2092),
    [anon_sym_u8_SQUOTE] = ACTIONS(2092),
    [anon_sym_SQUOTE] = ACTIONS(2092),
    [anon_sym_L_DQUOTE] = ACTIONS(2092),
    [anon_sym_u_DQUOTE] = ACTIONS(2092),
    [anon_sym_U_DQUOTE] = ACTIONS(2092),
    [anon_sym_u8_DQUOTE] = ACTIONS(2092),
    [anon_sym_DQUOTE] = ACTIONS(2092),
    [sym_true] = ACTIONS(2090),
    [sym_false] = ACTIONS(2090),
    [anon_sym_NULL] = ACTIONS(2090),
    [anon_sym_nullptr] = ACTIONS(2090),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2090),
    [anon_sym_decltype] = ACTIONS(2090),
    [sym_virtual] = ACTIONS(2090),
    [anon_sym_explicit] = ACTIONS(2090),
    [anon_sym_typename] = ACTIONS(2090),
    [anon_sym_template] = ACTIONS(2090),
    [anon_sym_operator] = ACTIONS(2090),
    [anon_sym_try] = ACTIONS(2090),
    [anon_sym_delete] = ACTIONS(2090),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_namespace] = ACTIONS(2090),
    [anon_sym_using] = ACTIONS(2090),
    [anon_sym_static_assert] = ACTIONS(2090),
    [anon_sym_concept] = ACTIONS(2090),
    [anon_sym_co_return] = ACTIONS(2090),
    [anon_sym_co_yield] = ACTIONS(2090),
    [anon_sym_R_DQUOTE] = ACTIONS(2092),
    [anon_sym_LR_DQUOTE] = ACTIONS(2092),
    [anon_sym_uR_DQUOTE] = ACTIONS(2092),
    [anon_sym_UR_DQUOTE] = ACTIONS(2092),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2092),
    [anon_sym_co_await] = ACTIONS(2090),
    [anon_sym_new] = ACTIONS(2090),
    [anon_sym_requires] = ACTIONS(2090),
    [sym_this] = ACTIONS(2090),
    [anon_sym_discard] = ACTIONS(2090),
    [anon_sym_precise] = ACTIONS(2090),
    [anon_sym_shared] = ACTIONS(2090),
    [anon_sym_groupshared] = ACTIONS(2090),
    [anon_sym_uniform] = ACTIONS(2090),
    [anon_sym_row_major] = ACTIONS(2090),
    [anon_sym_column_major] = ACTIONS(2090),
    [anon_sym_globallycoherent] = ACTIONS(2090),
    [anon_sym_centroid] = ACTIONS(2090),
    [anon_sym_noperspective] = ACTIONS(2090),
    [anon_sym_nointerpolation] = ACTIONS(2090),
    [anon_sym_sample] = ACTIONS(2090),
    [anon_sym_linear] = ACTIONS(2090),
    [anon_sym_snorm] = ACTIONS(2090),
    [anon_sym_unorm] = ACTIONS(2090),
    [anon_sym_point] = ACTIONS(2090),
    [anon_sym_line] = ACTIONS(2090),
    [anon_sym_triangleadj] = ACTIONS(2090),
    [anon_sym_lineadj] = ACTIONS(2090),
    [anon_sym_triangle] = ACTIONS(2090),
    [anon_sym_cbuffer] = ACTIONS(2090),
  },
  [499] = {
    [sym_identifier] = ACTIONS(2260),
    [aux_sym_preproc_include_token1] = ACTIONS(2260),
    [aux_sym_preproc_def_token1] = ACTIONS(2260),
    [aux_sym_preproc_if_token1] = ACTIONS(2260),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2260),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2260),
    [sym_preproc_directive] = ACTIONS(2260),
    [anon_sym_LPAREN2] = ACTIONS(2262),
    [anon_sym_BANG] = ACTIONS(2262),
    [anon_sym_TILDE] = ACTIONS(2262),
    [anon_sym_DASH] = ACTIONS(2260),
    [anon_sym_PLUS] = ACTIONS(2260),
    [anon_sym_STAR] = ACTIONS(2262),
    [anon_sym_AMP_AMP] = ACTIONS(2262),
    [anon_sym_AMP] = ACTIONS(2260),
    [anon_sym_SEMI] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(2260),
    [anon_sym_typedef] = ACTIONS(2260),
    [anon_sym_in] = ACTIONS(2260),
    [anon_sym_out] = ACTIONS(2260),
    [anon_sym_inout] = ACTIONS(2260),
    [anon_sym_extern] = ACTIONS(2260),
    [anon_sym___attribute__] = ACTIONS(2260),
    [anon_sym_COLON_COLON] = ACTIONS(2262),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2262),
    [anon_sym___declspec] = ACTIONS(2260),
    [anon_sym___based] = ACTIONS(2260),
    [anon_sym___cdecl] = ACTIONS(2260),
    [anon_sym___clrcall] = ACTIONS(2260),
    [anon_sym___stdcall] = ACTIONS(2260),
    [anon_sym___fastcall] = ACTIONS(2260),
    [anon_sym___thiscall] = ACTIONS(2260),
    [anon_sym___vectorcall] = ACTIONS(2260),
    [anon_sym_LBRACE] = ACTIONS(2262),
    [anon_sym_RBRACE] = ACTIONS(2262),
    [anon_sym_signed] = ACTIONS(2260),
    [anon_sym_unsigned] = ACTIONS(2260),
    [anon_sym_long] = ACTIONS(2260),
    [anon_sym_short] = ACTIONS(2260),
    [anon_sym_LBRACK] = ACTIONS(2260),
    [anon_sym_static] = ACTIONS(2260),
    [anon_sym_register] = ACTIONS(2260),
    [anon_sym_inline] = ACTIONS(2260),
    [anon_sym___inline] = ACTIONS(2260),
    [anon_sym___inline__] = ACTIONS(2260),
    [anon_sym___forceinline] = ACTIONS(2260),
    [anon_sym_thread_local] = ACTIONS(2260),
    [anon_sym___thread] = ACTIONS(2260),
    [anon_sym_const] = ACTIONS(2260),
    [anon_sym_constexpr] = ACTIONS(2260),
    [anon_sym_volatile] = ACTIONS(2260),
    [anon_sym_restrict] = ACTIONS(2260),
    [anon_sym___restrict__] = ACTIONS(2260),
    [anon_sym__Atomic] = ACTIONS(2260),
    [anon_sym__Noreturn] = ACTIONS(2260),
    [anon_sym_noreturn] = ACTIONS(2260),
    [anon_sym_mutable] = ACTIONS(2260),
    [anon_sym_constinit] = ACTIONS(2260),
    [anon_sym_consteval] = ACTIONS(2260),
    [anon_sym_alignas] = ACTIONS(2260),
    [anon_sym__Alignas] = ACTIONS(2260),
    [sym_primitive_type] = ACTIONS(2260),
    [anon_sym_enum] = ACTIONS(2260),
    [anon_sym_class] = ACTIONS(2260),
    [anon_sym_struct] = ACTIONS(2260),
    [anon_sym_union] = ACTIONS(2260),
    [anon_sym_if] = ACTIONS(2260),
    [anon_sym_else] = ACTIONS(2260),
    [anon_sym_switch] = ACTIONS(2260),
    [anon_sym_case] = ACTIONS(2260),
    [anon_sym_default] = ACTIONS(2260),
    [anon_sym_while] = ACTIONS(2260),
    [anon_sym_do] = ACTIONS(2260),
    [anon_sym_for] = ACTIONS(2260),
    [anon_sym_return] = ACTIONS(2260),
    [anon_sym_break] = ACTIONS(2260),
    [anon_sym_continue] = ACTIONS(2260),
    [anon_sym_goto] = ACTIONS(2260),
    [anon_sym___try] = ACTIONS(2260),
    [anon_sym___leave] = ACTIONS(2260),
    [anon_sym_not] = ACTIONS(2260),
    [anon_sym_compl] = ACTIONS(2260),
    [anon_sym_DASH_DASH] = ACTIONS(2262),
    [anon_sym_PLUS_PLUS] = ACTIONS(2262),
    [anon_sym_sizeof] = ACTIONS(2260),
    [anon_sym___alignof__] = ACTIONS(2260),
    [anon_sym___alignof] = ACTIONS(2260),
    [anon_sym__alignof] = ACTIONS(2260),
    [anon_sym_alignof] = ACTIONS(2260),
    [anon_sym__Alignof] = ACTIONS(2260),
    [anon_sym_offsetof] = ACTIONS(2260),
    [anon_sym__Generic] = ACTIONS(2260),
    [anon_sym_asm] = ACTIONS(2260),
    [anon_sym___asm__] = ACTIONS(2260),
    [sym_number_literal] = ACTIONS(2262),
    [anon_sym_L_SQUOTE] = ACTIONS(2262),
    [anon_sym_u_SQUOTE] = ACTIONS(2262),
    [anon_sym_U_SQUOTE] = ACTIONS(2262),
    [anon_sym_u8_SQUOTE] = ACTIONS(2262),
    [anon_sym_SQUOTE] = ACTIONS(2262),
    [anon_sym_L_DQUOTE] = ACTIONS(2262),
    [anon_sym_u_DQUOTE] = ACTIONS(2262),
    [anon_sym_U_DQUOTE] = ACTIONS(2262),
    [anon_sym_u8_DQUOTE] = ACTIONS(2262),
    [anon_sym_DQUOTE] = ACTIONS(2262),
    [sym_true] = ACTIONS(2260),
    [sym_false] = ACTIONS(2260),
    [anon_sym_NULL] = ACTIONS(2260),
    [anon_sym_nullptr] = ACTIONS(2260),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2260),
    [anon_sym_decltype] = ACTIONS(2260),
    [sym_virtual] = ACTIONS(2260),
    [anon_sym_explicit] = ACTIONS(2260),
    [anon_sym_typename] = ACTIONS(2260),
    [anon_sym_template] = ACTIONS(2260),
    [anon_sym_operator] = ACTIONS(2260),
    [anon_sym_try] = ACTIONS(2260),
    [anon_sym_delete] = ACTIONS(2260),
    [anon_sym_throw] = ACTIONS(2260),
    [anon_sym_namespace] = ACTIONS(2260),
    [anon_sym_using] = ACTIONS(2260),
    [anon_sym_static_assert] = ACTIONS(2260),
    [anon_sym_concept] = ACTIONS(2260),
    [anon_sym_co_return] = ACTIONS(2260),
    [anon_sym_co_yield] = ACTIONS(2260),
    [anon_sym_R_DQUOTE] = ACTIONS(2262),
    [anon_sym_LR_DQUOTE] = ACTIONS(2262),
    [anon_sym_uR_DQUOTE] = ACTIONS(2262),
    [anon_sym_UR_DQUOTE] = ACTIONS(2262),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2262),
    [anon_sym_co_await] = ACTIONS(2260),
    [anon_sym_new] = ACTIONS(2260),
    [anon_sym_requires] = ACTIONS(2260),
    [sym_this] = ACTIONS(2260),
    [anon_sym_discard] = ACTIONS(2260),
    [anon_sym_precise] = ACTIONS(2260),
    [anon_sym_shared] = ACTIONS(2260),
    [anon_sym_groupshared] = ACTIONS(2260),
    [anon_sym_uniform] = ACTIONS(2260),
    [anon_sym_row_major] = ACTIONS(2260),
    [anon_sym_column_major] = ACTIONS(2260),
    [anon_sym_globallycoherent] = ACTIONS(2260),
    [anon_sym_centroid] = ACTIONS(2260),
    [anon_sym_noperspective] = ACTIONS(2260),
    [anon_sym_nointerpolation] = ACTIONS(2260),
    [anon_sym_sample] = ACTIONS(2260),
    [anon_sym_linear] = ACTIONS(2260),
    [anon_sym_snorm] = ACTIONS(2260),
    [anon_sym_unorm] = ACTIONS(2260),
    [anon_sym_point] = ACTIONS(2260),
    [anon_sym_line] = ACTIONS(2260),
    [anon_sym_triangleadj] = ACTIONS(2260),
    [anon_sym_lineadj] = ACTIONS(2260),
    [anon_sym_triangle] = ACTIONS(2260),
    [anon_sym_cbuffer] = ACTIONS(2260),
  },
  [500] = {
    [sym_identifier] = ACTIONS(2276),
    [aux_sym_preproc_include_token1] = ACTIONS(2276),
    [aux_sym_preproc_def_token1] = ACTIONS(2276),
    [aux_sym_preproc_if_token1] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2276),
    [sym_preproc_directive] = ACTIONS(2276),
    [anon_sym_LPAREN2] = ACTIONS(2278),
    [anon_sym_BANG] = ACTIONS(2278),
    [anon_sym_TILDE] = ACTIONS(2278),
    [anon_sym_DASH] = ACTIONS(2276),
    [anon_sym_PLUS] = ACTIONS(2276),
    [anon_sym_STAR] = ACTIONS(2278),
    [anon_sym_AMP_AMP] = ACTIONS(2278),
    [anon_sym_AMP] = ACTIONS(2276),
    [anon_sym_SEMI] = ACTIONS(2278),
    [anon_sym___extension__] = ACTIONS(2276),
    [anon_sym_typedef] = ACTIONS(2276),
    [anon_sym_in] = ACTIONS(2276),
    [anon_sym_out] = ACTIONS(2276),
    [anon_sym_inout] = ACTIONS(2276),
    [anon_sym_extern] = ACTIONS(2276),
    [anon_sym___attribute__] = ACTIONS(2276),
    [anon_sym_COLON_COLON] = ACTIONS(2278),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2278),
    [anon_sym___declspec] = ACTIONS(2276),
    [anon_sym___based] = ACTIONS(2276),
    [anon_sym___cdecl] = ACTIONS(2276),
    [anon_sym___clrcall] = ACTIONS(2276),
    [anon_sym___stdcall] = ACTIONS(2276),
    [anon_sym___fastcall] = ACTIONS(2276),
    [anon_sym___thiscall] = ACTIONS(2276),
    [anon_sym___vectorcall] = ACTIONS(2276),
    [anon_sym_LBRACE] = ACTIONS(2278),
    [anon_sym_RBRACE] = ACTIONS(2278),
    [anon_sym_signed] = ACTIONS(2276),
    [anon_sym_unsigned] = ACTIONS(2276),
    [anon_sym_long] = ACTIONS(2276),
    [anon_sym_short] = ACTIONS(2276),
    [anon_sym_LBRACK] = ACTIONS(2276),
    [anon_sym_static] = ACTIONS(2276),
    [anon_sym_register] = ACTIONS(2276),
    [anon_sym_inline] = ACTIONS(2276),
    [anon_sym___inline] = ACTIONS(2276),
    [anon_sym___inline__] = ACTIONS(2276),
    [anon_sym___forceinline] = ACTIONS(2276),
    [anon_sym_thread_local] = ACTIONS(2276),
    [anon_sym___thread] = ACTIONS(2276),
    [anon_sym_const] = ACTIONS(2276),
    [anon_sym_constexpr] = ACTIONS(2276),
    [anon_sym_volatile] = ACTIONS(2276),
    [anon_sym_restrict] = ACTIONS(2276),
    [anon_sym___restrict__] = ACTIONS(2276),
    [anon_sym__Atomic] = ACTIONS(2276),
    [anon_sym__Noreturn] = ACTIONS(2276),
    [anon_sym_noreturn] = ACTIONS(2276),
    [anon_sym_mutable] = ACTIONS(2276),
    [anon_sym_constinit] = ACTIONS(2276),
    [anon_sym_consteval] = ACTIONS(2276),
    [anon_sym_alignas] = ACTIONS(2276),
    [anon_sym__Alignas] = ACTIONS(2276),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2276),
    [anon_sym_class] = ACTIONS(2276),
    [anon_sym_struct] = ACTIONS(2276),
    [anon_sym_union] = ACTIONS(2276),
    [anon_sym_if] = ACTIONS(2276),
    [anon_sym_else] = ACTIONS(2276),
    [anon_sym_switch] = ACTIONS(2276),
    [anon_sym_case] = ACTIONS(2276),
    [anon_sym_default] = ACTIONS(2276),
    [anon_sym_while] = ACTIONS(2276),
    [anon_sym_do] = ACTIONS(2276),
    [anon_sym_for] = ACTIONS(2276),
    [anon_sym_return] = ACTIONS(2276),
    [anon_sym_break] = ACTIONS(2276),
    [anon_sym_continue] = ACTIONS(2276),
    [anon_sym_goto] = ACTIONS(2276),
    [anon_sym___try] = ACTIONS(2276),
    [anon_sym___leave] = ACTIONS(2276),
    [anon_sym_not] = ACTIONS(2276),
    [anon_sym_compl] = ACTIONS(2276),
    [anon_sym_DASH_DASH] = ACTIONS(2278),
    [anon_sym_PLUS_PLUS] = ACTIONS(2278),
    [anon_sym_sizeof] = ACTIONS(2276),
    [anon_sym___alignof__] = ACTIONS(2276),
    [anon_sym___alignof] = ACTIONS(2276),
    [anon_sym__alignof] = ACTIONS(2276),
    [anon_sym_alignof] = ACTIONS(2276),
    [anon_sym__Alignof] = ACTIONS(2276),
    [anon_sym_offsetof] = ACTIONS(2276),
    [anon_sym__Generic] = ACTIONS(2276),
    [anon_sym_asm] = ACTIONS(2276),
    [anon_sym___asm__] = ACTIONS(2276),
    [sym_number_literal] = ACTIONS(2278),
    [anon_sym_L_SQUOTE] = ACTIONS(2278),
    [anon_sym_u_SQUOTE] = ACTIONS(2278),
    [anon_sym_U_SQUOTE] = ACTIONS(2278),
    [anon_sym_u8_SQUOTE] = ACTIONS(2278),
    [anon_sym_SQUOTE] = ACTIONS(2278),
    [anon_sym_L_DQUOTE] = ACTIONS(2278),
    [anon_sym_u_DQUOTE] = ACTIONS(2278),
    [anon_sym_U_DQUOTE] = ACTIONS(2278),
    [anon_sym_u8_DQUOTE] = ACTIONS(2278),
    [anon_sym_DQUOTE] = ACTIONS(2278),
    [sym_true] = ACTIONS(2276),
    [sym_false] = ACTIONS(2276),
    [anon_sym_NULL] = ACTIONS(2276),
    [anon_sym_nullptr] = ACTIONS(2276),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2276),
    [anon_sym_decltype] = ACTIONS(2276),
    [sym_virtual] = ACTIONS(2276),
    [anon_sym_explicit] = ACTIONS(2276),
    [anon_sym_typename] = ACTIONS(2276),
    [anon_sym_template] = ACTIONS(2276),
    [anon_sym_operator] = ACTIONS(2276),
    [anon_sym_try] = ACTIONS(2276),
    [anon_sym_delete] = ACTIONS(2276),
    [anon_sym_throw] = ACTIONS(2276),
    [anon_sym_namespace] = ACTIONS(2276),
    [anon_sym_using] = ACTIONS(2276),
    [anon_sym_static_assert] = ACTIONS(2276),
    [anon_sym_concept] = ACTIONS(2276),
    [anon_sym_co_return] = ACTIONS(2276),
    [anon_sym_co_yield] = ACTIONS(2276),
    [anon_sym_R_DQUOTE] = ACTIONS(2278),
    [anon_sym_LR_DQUOTE] = ACTIONS(2278),
    [anon_sym_uR_DQUOTE] = ACTIONS(2278),
    [anon_sym_UR_DQUOTE] = ACTIONS(2278),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2278),
    [anon_sym_co_await] = ACTIONS(2276),
    [anon_sym_new] = ACTIONS(2276),
    [anon_sym_requires] = ACTIONS(2276),
    [sym_this] = ACTIONS(2276),
    [anon_sym_discard] = ACTIONS(2276),
    [anon_sym_precise] = ACTIONS(2276),
    [anon_sym_shared] = ACTIONS(2276),
    [anon_sym_groupshared] = ACTIONS(2276),
    [anon_sym_uniform] = ACTIONS(2276),
    [anon_sym_row_major] = ACTIONS(2276),
    [anon_sym_column_major] = ACTIONS(2276),
    [anon_sym_globallycoherent] = ACTIONS(2276),
    [anon_sym_centroid] = ACTIONS(2276),
    [anon_sym_noperspective] = ACTIONS(2276),
    [anon_sym_nointerpolation] = ACTIONS(2276),
    [anon_sym_sample] = ACTIONS(2276),
    [anon_sym_linear] = ACTIONS(2276),
    [anon_sym_snorm] = ACTIONS(2276),
    [anon_sym_unorm] = ACTIONS(2276),
    [anon_sym_point] = ACTIONS(2276),
    [anon_sym_line] = ACTIONS(2276),
    [anon_sym_triangleadj] = ACTIONS(2276),
    [anon_sym_lineadj] = ACTIONS(2276),
    [anon_sym_triangle] = ACTIONS(2276),
    [anon_sym_cbuffer] = ACTIONS(2276),
  },
  [501] = {
    [sym_identifier] = ACTIONS(2276),
    [aux_sym_preproc_include_token1] = ACTIONS(2276),
    [aux_sym_preproc_def_token1] = ACTIONS(2276),
    [aux_sym_preproc_if_token1] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2276),
    [sym_preproc_directive] = ACTIONS(2276),
    [anon_sym_LPAREN2] = ACTIONS(2278),
    [anon_sym_BANG] = ACTIONS(2278),
    [anon_sym_TILDE] = ACTIONS(2278),
    [anon_sym_DASH] = ACTIONS(2276),
    [anon_sym_PLUS] = ACTIONS(2276),
    [anon_sym_STAR] = ACTIONS(2278),
    [anon_sym_AMP_AMP] = ACTIONS(2278),
    [anon_sym_AMP] = ACTIONS(2276),
    [anon_sym_SEMI] = ACTIONS(2278),
    [anon_sym___extension__] = ACTIONS(2276),
    [anon_sym_typedef] = ACTIONS(2276),
    [anon_sym_in] = ACTIONS(2276),
    [anon_sym_out] = ACTIONS(2276),
    [anon_sym_inout] = ACTIONS(2276),
    [anon_sym_extern] = ACTIONS(2276),
    [anon_sym___attribute__] = ACTIONS(2276),
    [anon_sym_COLON_COLON] = ACTIONS(2278),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2278),
    [anon_sym___declspec] = ACTIONS(2276),
    [anon_sym___based] = ACTIONS(2276),
    [anon_sym___cdecl] = ACTIONS(2276),
    [anon_sym___clrcall] = ACTIONS(2276),
    [anon_sym___stdcall] = ACTIONS(2276),
    [anon_sym___fastcall] = ACTIONS(2276),
    [anon_sym___thiscall] = ACTIONS(2276),
    [anon_sym___vectorcall] = ACTIONS(2276),
    [anon_sym_LBRACE] = ACTIONS(2278),
    [anon_sym_RBRACE] = ACTIONS(2278),
    [anon_sym_signed] = ACTIONS(2276),
    [anon_sym_unsigned] = ACTIONS(2276),
    [anon_sym_long] = ACTIONS(2276),
    [anon_sym_short] = ACTIONS(2276),
    [anon_sym_LBRACK] = ACTIONS(2276),
    [anon_sym_static] = ACTIONS(2276),
    [anon_sym_register] = ACTIONS(2276),
    [anon_sym_inline] = ACTIONS(2276),
    [anon_sym___inline] = ACTIONS(2276),
    [anon_sym___inline__] = ACTIONS(2276),
    [anon_sym___forceinline] = ACTIONS(2276),
    [anon_sym_thread_local] = ACTIONS(2276),
    [anon_sym___thread] = ACTIONS(2276),
    [anon_sym_const] = ACTIONS(2276),
    [anon_sym_constexpr] = ACTIONS(2276),
    [anon_sym_volatile] = ACTIONS(2276),
    [anon_sym_restrict] = ACTIONS(2276),
    [anon_sym___restrict__] = ACTIONS(2276),
    [anon_sym__Atomic] = ACTIONS(2276),
    [anon_sym__Noreturn] = ACTIONS(2276),
    [anon_sym_noreturn] = ACTIONS(2276),
    [anon_sym_mutable] = ACTIONS(2276),
    [anon_sym_constinit] = ACTIONS(2276),
    [anon_sym_consteval] = ACTIONS(2276),
    [anon_sym_alignas] = ACTIONS(2276),
    [anon_sym__Alignas] = ACTIONS(2276),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2276),
    [anon_sym_class] = ACTIONS(2276),
    [anon_sym_struct] = ACTIONS(2276),
    [anon_sym_union] = ACTIONS(2276),
    [anon_sym_if] = ACTIONS(2276),
    [anon_sym_else] = ACTIONS(2276),
    [anon_sym_switch] = ACTIONS(2276),
    [anon_sym_case] = ACTIONS(2276),
    [anon_sym_default] = ACTIONS(2276),
    [anon_sym_while] = ACTIONS(2276),
    [anon_sym_do] = ACTIONS(2276),
    [anon_sym_for] = ACTIONS(2276),
    [anon_sym_return] = ACTIONS(2276),
    [anon_sym_break] = ACTIONS(2276),
    [anon_sym_continue] = ACTIONS(2276),
    [anon_sym_goto] = ACTIONS(2276),
    [anon_sym___try] = ACTIONS(2276),
    [anon_sym___leave] = ACTIONS(2276),
    [anon_sym_not] = ACTIONS(2276),
    [anon_sym_compl] = ACTIONS(2276),
    [anon_sym_DASH_DASH] = ACTIONS(2278),
    [anon_sym_PLUS_PLUS] = ACTIONS(2278),
    [anon_sym_sizeof] = ACTIONS(2276),
    [anon_sym___alignof__] = ACTIONS(2276),
    [anon_sym___alignof] = ACTIONS(2276),
    [anon_sym__alignof] = ACTIONS(2276),
    [anon_sym_alignof] = ACTIONS(2276),
    [anon_sym__Alignof] = ACTIONS(2276),
    [anon_sym_offsetof] = ACTIONS(2276),
    [anon_sym__Generic] = ACTIONS(2276),
    [anon_sym_asm] = ACTIONS(2276),
    [anon_sym___asm__] = ACTIONS(2276),
    [sym_number_literal] = ACTIONS(2278),
    [anon_sym_L_SQUOTE] = ACTIONS(2278),
    [anon_sym_u_SQUOTE] = ACTIONS(2278),
    [anon_sym_U_SQUOTE] = ACTIONS(2278),
    [anon_sym_u8_SQUOTE] = ACTIONS(2278),
    [anon_sym_SQUOTE] = ACTIONS(2278),
    [anon_sym_L_DQUOTE] = ACTIONS(2278),
    [anon_sym_u_DQUOTE] = ACTIONS(2278),
    [anon_sym_U_DQUOTE] = ACTIONS(2278),
    [anon_sym_u8_DQUOTE] = ACTIONS(2278),
    [anon_sym_DQUOTE] = ACTIONS(2278),
    [sym_true] = ACTIONS(2276),
    [sym_false] = ACTIONS(2276),
    [anon_sym_NULL] = ACTIONS(2276),
    [anon_sym_nullptr] = ACTIONS(2276),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2276),
    [anon_sym_decltype] = ACTIONS(2276),
    [sym_virtual] = ACTIONS(2276),
    [anon_sym_explicit] = ACTIONS(2276),
    [anon_sym_typename] = ACTIONS(2276),
    [anon_sym_template] = ACTIONS(2276),
    [anon_sym_operator] = ACTIONS(2276),
    [anon_sym_try] = ACTIONS(2276),
    [anon_sym_delete] = ACTIONS(2276),
    [anon_sym_throw] = ACTIONS(2276),
    [anon_sym_namespace] = ACTIONS(2276),
    [anon_sym_using] = ACTIONS(2276),
    [anon_sym_static_assert] = ACTIONS(2276),
    [anon_sym_concept] = ACTIONS(2276),
    [anon_sym_co_return] = ACTIONS(2276),
    [anon_sym_co_yield] = ACTIONS(2276),
    [anon_sym_R_DQUOTE] = ACTIONS(2278),
    [anon_sym_LR_DQUOTE] = ACTIONS(2278),
    [anon_sym_uR_DQUOTE] = ACTIONS(2278),
    [anon_sym_UR_DQUOTE] = ACTIONS(2278),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2278),
    [anon_sym_co_await] = ACTIONS(2276),
    [anon_sym_new] = ACTIONS(2276),
    [anon_sym_requires] = ACTIONS(2276),
    [sym_this] = ACTIONS(2276),
    [anon_sym_discard] = ACTIONS(2276),
    [anon_sym_precise] = ACTIONS(2276),
    [anon_sym_shared] = ACTIONS(2276),
    [anon_sym_groupshared] = ACTIONS(2276),
    [anon_sym_uniform] = ACTIONS(2276),
    [anon_sym_row_major] = ACTIONS(2276),
    [anon_sym_column_major] = ACTIONS(2276),
    [anon_sym_globallycoherent] = ACTIONS(2276),
    [anon_sym_centroid] = ACTIONS(2276),
    [anon_sym_noperspective] = ACTIONS(2276),
    [anon_sym_nointerpolation] = ACTIONS(2276),
    [anon_sym_sample] = ACTIONS(2276),
    [anon_sym_linear] = ACTIONS(2276),
    [anon_sym_snorm] = ACTIONS(2276),
    [anon_sym_unorm] = ACTIONS(2276),
    [anon_sym_point] = ACTIONS(2276),
    [anon_sym_line] = ACTIONS(2276),
    [anon_sym_triangleadj] = ACTIONS(2276),
    [anon_sym_lineadj] = ACTIONS(2276),
    [anon_sym_triangle] = ACTIONS(2276),
    [anon_sym_cbuffer] = ACTIONS(2276),
  },
  [502] = {
    [sym_identifier] = ACTIONS(2264),
    [aux_sym_preproc_include_token1] = ACTIONS(2264),
    [aux_sym_preproc_def_token1] = ACTIONS(2264),
    [aux_sym_preproc_if_token1] = ACTIONS(2264),
    [aux_sym_preproc_if_token2] = ACTIONS(2264),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2264),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2264),
    [sym_preproc_directive] = ACTIONS(2264),
    [anon_sym_LPAREN2] = ACTIONS(2266),
    [anon_sym_BANG] = ACTIONS(2266),
    [anon_sym_TILDE] = ACTIONS(2266),
    [anon_sym_DASH] = ACTIONS(2264),
    [anon_sym_PLUS] = ACTIONS(2264),
    [anon_sym_STAR] = ACTIONS(2266),
    [anon_sym_AMP_AMP] = ACTIONS(2266),
    [anon_sym_AMP] = ACTIONS(2264),
    [anon_sym_SEMI] = ACTIONS(2266),
    [anon_sym___extension__] = ACTIONS(2264),
    [anon_sym_typedef] = ACTIONS(2264),
    [anon_sym_in] = ACTIONS(2264),
    [anon_sym_out] = ACTIONS(2264),
    [anon_sym_inout] = ACTIONS(2264),
    [anon_sym_extern] = ACTIONS(2264),
    [anon_sym___attribute__] = ACTIONS(2264),
    [anon_sym_COLON_COLON] = ACTIONS(2266),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2266),
    [anon_sym___declspec] = ACTIONS(2264),
    [anon_sym___based] = ACTIONS(2264),
    [anon_sym___cdecl] = ACTIONS(2264),
    [anon_sym___clrcall] = ACTIONS(2264),
    [anon_sym___stdcall] = ACTIONS(2264),
    [anon_sym___fastcall] = ACTIONS(2264),
    [anon_sym___thiscall] = ACTIONS(2264),
    [anon_sym___vectorcall] = ACTIONS(2264),
    [anon_sym_LBRACE] = ACTIONS(2266),
    [anon_sym_signed] = ACTIONS(2264),
    [anon_sym_unsigned] = ACTIONS(2264),
    [anon_sym_long] = ACTIONS(2264),
    [anon_sym_short] = ACTIONS(2264),
    [anon_sym_LBRACK] = ACTIONS(2264),
    [anon_sym_static] = ACTIONS(2264),
    [anon_sym_register] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(2264),
    [anon_sym___inline] = ACTIONS(2264),
    [anon_sym___inline__] = ACTIONS(2264),
    [anon_sym___forceinline] = ACTIONS(2264),
    [anon_sym_thread_local] = ACTIONS(2264),
    [anon_sym___thread] = ACTIONS(2264),
    [anon_sym_const] = ACTIONS(2264),
    [anon_sym_constexpr] = ACTIONS(2264),
    [anon_sym_volatile] = ACTIONS(2264),
    [anon_sym_restrict] = ACTIONS(2264),
    [anon_sym___restrict__] = ACTIONS(2264),
    [anon_sym__Atomic] = ACTIONS(2264),
    [anon_sym__Noreturn] = ACTIONS(2264),
    [anon_sym_noreturn] = ACTIONS(2264),
    [anon_sym_mutable] = ACTIONS(2264),
    [anon_sym_constinit] = ACTIONS(2264),
    [anon_sym_consteval] = ACTIONS(2264),
    [anon_sym_alignas] = ACTIONS(2264),
    [anon_sym__Alignas] = ACTIONS(2264),
    [sym_primitive_type] = ACTIONS(2264),
    [anon_sym_enum] = ACTIONS(2264),
    [anon_sym_class] = ACTIONS(2264),
    [anon_sym_struct] = ACTIONS(2264),
    [anon_sym_union] = ACTIONS(2264),
    [anon_sym_if] = ACTIONS(2264),
    [anon_sym_else] = ACTIONS(2264),
    [anon_sym_switch] = ACTIONS(2264),
    [anon_sym_case] = ACTIONS(2264),
    [anon_sym_default] = ACTIONS(2264),
    [anon_sym_while] = ACTIONS(2264),
    [anon_sym_do] = ACTIONS(2264),
    [anon_sym_for] = ACTIONS(2264),
    [anon_sym_return] = ACTIONS(2264),
    [anon_sym_break] = ACTIONS(2264),
    [anon_sym_continue] = ACTIONS(2264),
    [anon_sym_goto] = ACTIONS(2264),
    [anon_sym___try] = ACTIONS(2264),
    [anon_sym___leave] = ACTIONS(2264),
    [anon_sym_not] = ACTIONS(2264),
    [anon_sym_compl] = ACTIONS(2264),
    [anon_sym_DASH_DASH] = ACTIONS(2266),
    [anon_sym_PLUS_PLUS] = ACTIONS(2266),
    [anon_sym_sizeof] = ACTIONS(2264),
    [anon_sym___alignof__] = ACTIONS(2264),
    [anon_sym___alignof] = ACTIONS(2264),
    [anon_sym__alignof] = ACTIONS(2264),
    [anon_sym_alignof] = ACTIONS(2264),
    [anon_sym__Alignof] = ACTIONS(2264),
    [anon_sym_offsetof] = ACTIONS(2264),
    [anon_sym__Generic] = ACTIONS(2264),
    [anon_sym_asm] = ACTIONS(2264),
    [anon_sym___asm__] = ACTIONS(2264),
    [sym_number_literal] = ACTIONS(2266),
    [anon_sym_L_SQUOTE] = ACTIONS(2266),
    [anon_sym_u_SQUOTE] = ACTIONS(2266),
    [anon_sym_U_SQUOTE] = ACTIONS(2266),
    [anon_sym_u8_SQUOTE] = ACTIONS(2266),
    [anon_sym_SQUOTE] = ACTIONS(2266),
    [anon_sym_L_DQUOTE] = ACTIONS(2266),
    [anon_sym_u_DQUOTE] = ACTIONS(2266),
    [anon_sym_U_DQUOTE] = ACTIONS(2266),
    [anon_sym_u8_DQUOTE] = ACTIONS(2266),
    [anon_sym_DQUOTE] = ACTIONS(2266),
    [sym_true] = ACTIONS(2264),
    [sym_false] = ACTIONS(2264),
    [anon_sym_NULL] = ACTIONS(2264),
    [anon_sym_nullptr] = ACTIONS(2264),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2264),
    [anon_sym_decltype] = ACTIONS(2264),
    [sym_virtual] = ACTIONS(2264),
    [anon_sym_explicit] = ACTIONS(2264),
    [anon_sym_typename] = ACTIONS(2264),
    [anon_sym_template] = ACTIONS(2264),
    [anon_sym_operator] = ACTIONS(2264),
    [anon_sym_try] = ACTIONS(2264),
    [anon_sym_delete] = ACTIONS(2264),
    [anon_sym_throw] = ACTIONS(2264),
    [anon_sym_namespace] = ACTIONS(2264),
    [anon_sym_using] = ACTIONS(2264),
    [anon_sym_static_assert] = ACTIONS(2264),
    [anon_sym_concept] = ACTIONS(2264),
    [anon_sym_co_return] = ACTIONS(2264),
    [anon_sym_co_yield] = ACTIONS(2264),
    [anon_sym_R_DQUOTE] = ACTIONS(2266),
    [anon_sym_LR_DQUOTE] = ACTIONS(2266),
    [anon_sym_uR_DQUOTE] = ACTIONS(2266),
    [anon_sym_UR_DQUOTE] = ACTIONS(2266),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2266),
    [anon_sym_co_await] = ACTIONS(2264),
    [anon_sym_new] = ACTIONS(2264),
    [anon_sym_requires] = ACTIONS(2264),
    [sym_this] = ACTIONS(2264),
    [anon_sym_discard] = ACTIONS(2264),
    [anon_sym_precise] = ACTIONS(2264),
    [anon_sym_shared] = ACTIONS(2264),
    [anon_sym_groupshared] = ACTIONS(2264),
    [anon_sym_uniform] = ACTIONS(2264),
    [anon_sym_row_major] = ACTIONS(2264),
    [anon_sym_column_major] = ACTIONS(2264),
    [anon_sym_globallycoherent] = ACTIONS(2264),
    [anon_sym_centroid] = ACTIONS(2264),
    [anon_sym_noperspective] = ACTIONS(2264),
    [anon_sym_nointerpolation] = ACTIONS(2264),
    [anon_sym_sample] = ACTIONS(2264),
    [anon_sym_linear] = ACTIONS(2264),
    [anon_sym_snorm] = ACTIONS(2264),
    [anon_sym_unorm] = ACTIONS(2264),
    [anon_sym_point] = ACTIONS(2264),
    [anon_sym_line] = ACTIONS(2264),
    [anon_sym_triangleadj] = ACTIONS(2264),
    [anon_sym_lineadj] = ACTIONS(2264),
    [anon_sym_triangle] = ACTIONS(2264),
    [anon_sym_cbuffer] = ACTIONS(2264),
  },
  [503] = {
    [sym_identifier] = ACTIONS(1947),
    [aux_sym_preproc_include_token1] = ACTIONS(1947),
    [aux_sym_preproc_def_token1] = ACTIONS(1947),
    [anon_sym_COMMA] = ACTIONS(2202),
    [aux_sym_preproc_if_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1947),
    [sym_preproc_directive] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1945),
    [anon_sym_BANG] = ACTIONS(1945),
    [anon_sym_TILDE] = ACTIONS(1945),
    [anon_sym_DASH] = ACTIONS(1947),
    [anon_sym_PLUS] = ACTIONS(1947),
    [anon_sym_STAR] = ACTIONS(1945),
    [anon_sym_AMP_AMP] = ACTIONS(1945),
    [anon_sym_AMP] = ACTIONS(1947),
    [anon_sym_SEMI] = ACTIONS(2202),
    [anon_sym___extension__] = ACTIONS(1947),
    [anon_sym_typedef] = ACTIONS(1947),
    [anon_sym_in] = ACTIONS(1947),
    [anon_sym_out] = ACTIONS(1947),
    [anon_sym_inout] = ACTIONS(1947),
    [anon_sym_extern] = ACTIONS(1947),
    [anon_sym___attribute__] = ACTIONS(1947),
    [anon_sym_COLON_COLON] = ACTIONS(1945),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1945),
    [anon_sym___declspec] = ACTIONS(1947),
    [anon_sym___based] = ACTIONS(1947),
    [anon_sym___cdecl] = ACTIONS(1947),
    [anon_sym___clrcall] = ACTIONS(1947),
    [anon_sym___stdcall] = ACTIONS(1947),
    [anon_sym___fastcall] = ACTIONS(1947),
    [anon_sym___thiscall] = ACTIONS(1947),
    [anon_sym___vectorcall] = ACTIONS(1947),
    [anon_sym_LBRACE] = ACTIONS(1945),
    [anon_sym_RBRACE] = ACTIONS(1945),
    [anon_sym_signed] = ACTIONS(1947),
    [anon_sym_unsigned] = ACTIONS(1947),
    [anon_sym_long] = ACTIONS(1947),
    [anon_sym_short] = ACTIONS(1947),
    [anon_sym_LBRACK] = ACTIONS(1947),
    [anon_sym_static] = ACTIONS(1947),
    [anon_sym_register] = ACTIONS(1947),
    [anon_sym_inline] = ACTIONS(1947),
    [anon_sym___inline] = ACTIONS(1947),
    [anon_sym___inline__] = ACTIONS(1947),
    [anon_sym___forceinline] = ACTIONS(1947),
    [anon_sym_thread_local] = ACTIONS(1947),
    [anon_sym___thread] = ACTIONS(1947),
    [anon_sym_const] = ACTIONS(1947),
    [anon_sym_constexpr] = ACTIONS(1947),
    [anon_sym_volatile] = ACTIONS(1947),
    [anon_sym_restrict] = ACTIONS(1947),
    [anon_sym___restrict__] = ACTIONS(1947),
    [anon_sym__Atomic] = ACTIONS(1947),
    [anon_sym__Noreturn] = ACTIONS(1947),
    [anon_sym_noreturn] = ACTIONS(1947),
    [anon_sym_mutable] = ACTIONS(1947),
    [anon_sym_constinit] = ACTIONS(1947),
    [anon_sym_consteval] = ACTIONS(1947),
    [anon_sym_alignas] = ACTIONS(1947),
    [anon_sym__Alignas] = ACTIONS(1947),
    [sym_primitive_type] = ACTIONS(1947),
    [anon_sym_enum] = ACTIONS(1947),
    [anon_sym_class] = ACTIONS(1947),
    [anon_sym_struct] = ACTIONS(1947),
    [anon_sym_union] = ACTIONS(1947),
    [anon_sym_if] = ACTIONS(1947),
    [anon_sym_switch] = ACTIONS(1947),
    [anon_sym_case] = ACTIONS(1947),
    [anon_sym_default] = ACTIONS(1947),
    [anon_sym_while] = ACTIONS(1947),
    [anon_sym_do] = ACTIONS(1947),
    [anon_sym_for] = ACTIONS(1947),
    [anon_sym_return] = ACTIONS(1947),
    [anon_sym_break] = ACTIONS(1947),
    [anon_sym_continue] = ACTIONS(1947),
    [anon_sym_goto] = ACTIONS(1947),
    [anon_sym___try] = ACTIONS(1947),
    [anon_sym___leave] = ACTIONS(1947),
    [anon_sym_not] = ACTIONS(1947),
    [anon_sym_compl] = ACTIONS(1947),
    [anon_sym_DASH_DASH] = ACTIONS(1945),
    [anon_sym_PLUS_PLUS] = ACTIONS(1945),
    [anon_sym_sizeof] = ACTIONS(1947),
    [anon_sym___alignof__] = ACTIONS(1947),
    [anon_sym___alignof] = ACTIONS(1947),
    [anon_sym__alignof] = ACTIONS(1947),
    [anon_sym_alignof] = ACTIONS(1947),
    [anon_sym__Alignof] = ACTIONS(1947),
    [anon_sym_offsetof] = ACTIONS(1947),
    [anon_sym__Generic] = ACTIONS(1947),
    [anon_sym_asm] = ACTIONS(1947),
    [anon_sym___asm__] = ACTIONS(1947),
    [sym_number_literal] = ACTIONS(1945),
    [anon_sym_L_SQUOTE] = ACTIONS(1945),
    [anon_sym_u_SQUOTE] = ACTIONS(1945),
    [anon_sym_U_SQUOTE] = ACTIONS(1945),
    [anon_sym_u8_SQUOTE] = ACTIONS(1945),
    [anon_sym_SQUOTE] = ACTIONS(1945),
    [anon_sym_L_DQUOTE] = ACTIONS(1945),
    [anon_sym_u_DQUOTE] = ACTIONS(1945),
    [anon_sym_U_DQUOTE] = ACTIONS(1945),
    [anon_sym_u8_DQUOTE] = ACTIONS(1945),
    [anon_sym_DQUOTE] = ACTIONS(1945),
    [sym_true] = ACTIONS(1947),
    [sym_false] = ACTIONS(1947),
    [anon_sym_NULL] = ACTIONS(1947),
    [anon_sym_nullptr] = ACTIONS(1947),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1947),
    [anon_sym_decltype] = ACTIONS(1947),
    [sym_virtual] = ACTIONS(1947),
    [anon_sym_explicit] = ACTIONS(1947),
    [anon_sym_typename] = ACTIONS(1947),
    [anon_sym_template] = ACTIONS(1947),
    [anon_sym_operator] = ACTIONS(1947),
    [anon_sym_try] = ACTIONS(1947),
    [anon_sym_delete] = ACTIONS(1947),
    [anon_sym_throw] = ACTIONS(1947),
    [anon_sym_namespace] = ACTIONS(1947),
    [anon_sym_using] = ACTIONS(1947),
    [anon_sym_static_assert] = ACTIONS(1947),
    [anon_sym_concept] = ACTIONS(1947),
    [anon_sym_co_return] = ACTIONS(1947),
    [anon_sym_co_yield] = ACTIONS(1947),
    [anon_sym_R_DQUOTE] = ACTIONS(1945),
    [anon_sym_LR_DQUOTE] = ACTIONS(1945),
    [anon_sym_uR_DQUOTE] = ACTIONS(1945),
    [anon_sym_UR_DQUOTE] = ACTIONS(1945),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1945),
    [anon_sym_co_await] = ACTIONS(1947),
    [anon_sym_new] = ACTIONS(1947),
    [anon_sym_requires] = ACTIONS(1947),
    [sym_this] = ACTIONS(1947),
    [anon_sym_discard] = ACTIONS(1947),
    [anon_sym_precise] = ACTIONS(1947),
    [anon_sym_shared] = ACTIONS(1947),
    [anon_sym_groupshared] = ACTIONS(1947),
    [anon_sym_uniform] = ACTIONS(1947),
    [anon_sym_row_major] = ACTIONS(1947),
    [anon_sym_column_major] = ACTIONS(1947),
    [anon_sym_globallycoherent] = ACTIONS(1947),
    [anon_sym_centroid] = ACTIONS(1947),
    [anon_sym_noperspective] = ACTIONS(1947),
    [anon_sym_nointerpolation] = ACTIONS(1947),
    [anon_sym_sample] = ACTIONS(1947),
    [anon_sym_linear] = ACTIONS(1947),
    [anon_sym_snorm] = ACTIONS(1947),
    [anon_sym_unorm] = ACTIONS(1947),
    [anon_sym_point] = ACTIONS(1947),
    [anon_sym_line] = ACTIONS(1947),
    [anon_sym_triangleadj] = ACTIONS(1947),
    [anon_sym_lineadj] = ACTIONS(1947),
    [anon_sym_triangle] = ACTIONS(1947),
    [anon_sym_cbuffer] = ACTIONS(1947),
  },
  [504] = {
    [sym_identifier] = ACTIONS(2204),
    [aux_sym_preproc_include_token1] = ACTIONS(2204),
    [aux_sym_preproc_def_token1] = ACTIONS(2204),
    [aux_sym_preproc_if_token1] = ACTIONS(2204),
    [aux_sym_preproc_if_token2] = ACTIONS(2204),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2204),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2204),
    [sym_preproc_directive] = ACTIONS(2204),
    [anon_sym_LPAREN2] = ACTIONS(2206),
    [anon_sym_BANG] = ACTIONS(2206),
    [anon_sym_TILDE] = ACTIONS(2206),
    [anon_sym_DASH] = ACTIONS(2204),
    [anon_sym_PLUS] = ACTIONS(2204),
    [anon_sym_STAR] = ACTIONS(2206),
    [anon_sym_AMP_AMP] = ACTIONS(2206),
    [anon_sym_AMP] = ACTIONS(2204),
    [anon_sym_SEMI] = ACTIONS(2206),
    [anon_sym___extension__] = ACTIONS(2204),
    [anon_sym_typedef] = ACTIONS(2204),
    [anon_sym_in] = ACTIONS(2204),
    [anon_sym_out] = ACTIONS(2204),
    [anon_sym_inout] = ACTIONS(2204),
    [anon_sym_extern] = ACTIONS(2204),
    [anon_sym___attribute__] = ACTIONS(2204),
    [anon_sym_COLON_COLON] = ACTIONS(2206),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2206),
    [anon_sym___declspec] = ACTIONS(2204),
    [anon_sym___based] = ACTIONS(2204),
    [anon_sym___cdecl] = ACTIONS(2204),
    [anon_sym___clrcall] = ACTIONS(2204),
    [anon_sym___stdcall] = ACTIONS(2204),
    [anon_sym___fastcall] = ACTIONS(2204),
    [anon_sym___thiscall] = ACTIONS(2204),
    [anon_sym___vectorcall] = ACTIONS(2204),
    [anon_sym_LBRACE] = ACTIONS(2206),
    [anon_sym_signed] = ACTIONS(2204),
    [anon_sym_unsigned] = ACTIONS(2204),
    [anon_sym_long] = ACTIONS(2204),
    [anon_sym_short] = ACTIONS(2204),
    [anon_sym_LBRACK] = ACTIONS(2204),
    [anon_sym_static] = ACTIONS(2204),
    [anon_sym_register] = ACTIONS(2204),
    [anon_sym_inline] = ACTIONS(2204),
    [anon_sym___inline] = ACTIONS(2204),
    [anon_sym___inline__] = ACTIONS(2204),
    [anon_sym___forceinline] = ACTIONS(2204),
    [anon_sym_thread_local] = ACTIONS(2204),
    [anon_sym___thread] = ACTIONS(2204),
    [anon_sym_const] = ACTIONS(2204),
    [anon_sym_constexpr] = ACTIONS(2204),
    [anon_sym_volatile] = ACTIONS(2204),
    [anon_sym_restrict] = ACTIONS(2204),
    [anon_sym___restrict__] = ACTIONS(2204),
    [anon_sym__Atomic] = ACTIONS(2204),
    [anon_sym__Noreturn] = ACTIONS(2204),
    [anon_sym_noreturn] = ACTIONS(2204),
    [anon_sym_mutable] = ACTIONS(2204),
    [anon_sym_constinit] = ACTIONS(2204),
    [anon_sym_consteval] = ACTIONS(2204),
    [anon_sym_alignas] = ACTIONS(2204),
    [anon_sym__Alignas] = ACTIONS(2204),
    [sym_primitive_type] = ACTIONS(2204),
    [anon_sym_enum] = ACTIONS(2204),
    [anon_sym_class] = ACTIONS(2204),
    [anon_sym_struct] = ACTIONS(2204),
    [anon_sym_union] = ACTIONS(2204),
    [anon_sym_if] = ACTIONS(2204),
    [anon_sym_else] = ACTIONS(2204),
    [anon_sym_switch] = ACTIONS(2204),
    [anon_sym_case] = ACTIONS(2204),
    [anon_sym_default] = ACTIONS(2204),
    [anon_sym_while] = ACTIONS(2204),
    [anon_sym_do] = ACTIONS(2204),
    [anon_sym_for] = ACTIONS(2204),
    [anon_sym_return] = ACTIONS(2204),
    [anon_sym_break] = ACTIONS(2204),
    [anon_sym_continue] = ACTIONS(2204),
    [anon_sym_goto] = ACTIONS(2204),
    [anon_sym___try] = ACTIONS(2204),
    [anon_sym___leave] = ACTIONS(2204),
    [anon_sym_not] = ACTIONS(2204),
    [anon_sym_compl] = ACTIONS(2204),
    [anon_sym_DASH_DASH] = ACTIONS(2206),
    [anon_sym_PLUS_PLUS] = ACTIONS(2206),
    [anon_sym_sizeof] = ACTIONS(2204),
    [anon_sym___alignof__] = ACTIONS(2204),
    [anon_sym___alignof] = ACTIONS(2204),
    [anon_sym__alignof] = ACTIONS(2204),
    [anon_sym_alignof] = ACTIONS(2204),
    [anon_sym__Alignof] = ACTIONS(2204),
    [anon_sym_offsetof] = ACTIONS(2204),
    [anon_sym__Generic] = ACTIONS(2204),
    [anon_sym_asm] = ACTIONS(2204),
    [anon_sym___asm__] = ACTIONS(2204),
    [sym_number_literal] = ACTIONS(2206),
    [anon_sym_L_SQUOTE] = ACTIONS(2206),
    [anon_sym_u_SQUOTE] = ACTIONS(2206),
    [anon_sym_U_SQUOTE] = ACTIONS(2206),
    [anon_sym_u8_SQUOTE] = ACTIONS(2206),
    [anon_sym_SQUOTE] = ACTIONS(2206),
    [anon_sym_L_DQUOTE] = ACTIONS(2206),
    [anon_sym_u_DQUOTE] = ACTIONS(2206),
    [anon_sym_U_DQUOTE] = ACTIONS(2206),
    [anon_sym_u8_DQUOTE] = ACTIONS(2206),
    [anon_sym_DQUOTE] = ACTIONS(2206),
    [sym_true] = ACTIONS(2204),
    [sym_false] = ACTIONS(2204),
    [anon_sym_NULL] = ACTIONS(2204),
    [anon_sym_nullptr] = ACTIONS(2204),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2204),
    [anon_sym_decltype] = ACTIONS(2204),
    [sym_virtual] = ACTIONS(2204),
    [anon_sym_explicit] = ACTIONS(2204),
    [anon_sym_typename] = ACTIONS(2204),
    [anon_sym_template] = ACTIONS(2204),
    [anon_sym_operator] = ACTIONS(2204),
    [anon_sym_try] = ACTIONS(2204),
    [anon_sym_delete] = ACTIONS(2204),
    [anon_sym_throw] = ACTIONS(2204),
    [anon_sym_namespace] = ACTIONS(2204),
    [anon_sym_using] = ACTIONS(2204),
    [anon_sym_static_assert] = ACTIONS(2204),
    [anon_sym_concept] = ACTIONS(2204),
    [anon_sym_co_return] = ACTIONS(2204),
    [anon_sym_co_yield] = ACTIONS(2204),
    [anon_sym_R_DQUOTE] = ACTIONS(2206),
    [anon_sym_LR_DQUOTE] = ACTIONS(2206),
    [anon_sym_uR_DQUOTE] = ACTIONS(2206),
    [anon_sym_UR_DQUOTE] = ACTIONS(2206),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2206),
    [anon_sym_co_await] = ACTIONS(2204),
    [anon_sym_new] = ACTIONS(2204),
    [anon_sym_requires] = ACTIONS(2204),
    [sym_this] = ACTIONS(2204),
    [anon_sym_discard] = ACTIONS(2204),
    [anon_sym_precise] = ACTIONS(2204),
    [anon_sym_shared] = ACTIONS(2204),
    [anon_sym_groupshared] = ACTIONS(2204),
    [anon_sym_uniform] = ACTIONS(2204),
    [anon_sym_row_major] = ACTIONS(2204),
    [anon_sym_column_major] = ACTIONS(2204),
    [anon_sym_globallycoherent] = ACTIONS(2204),
    [anon_sym_centroid] = ACTIONS(2204),
    [anon_sym_noperspective] = ACTIONS(2204),
    [anon_sym_nointerpolation] = ACTIONS(2204),
    [anon_sym_sample] = ACTIONS(2204),
    [anon_sym_linear] = ACTIONS(2204),
    [anon_sym_snorm] = ACTIONS(2204),
    [anon_sym_unorm] = ACTIONS(2204),
    [anon_sym_point] = ACTIONS(2204),
    [anon_sym_line] = ACTIONS(2204),
    [anon_sym_triangleadj] = ACTIONS(2204),
    [anon_sym_lineadj] = ACTIONS(2204),
    [anon_sym_triangle] = ACTIONS(2204),
    [anon_sym_cbuffer] = ACTIONS(2204),
  },
  [505] = {
    [sym_identifier] = ACTIONS(2118),
    [aux_sym_preproc_include_token1] = ACTIONS(2118),
    [aux_sym_preproc_def_token1] = ACTIONS(2118),
    [aux_sym_preproc_if_token1] = ACTIONS(2118),
    [aux_sym_preproc_if_token2] = ACTIONS(2118),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2118),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2118),
    [sym_preproc_directive] = ACTIONS(2118),
    [anon_sym_LPAREN2] = ACTIONS(2120),
    [anon_sym_BANG] = ACTIONS(2120),
    [anon_sym_TILDE] = ACTIONS(2120),
    [anon_sym_DASH] = ACTIONS(2118),
    [anon_sym_PLUS] = ACTIONS(2118),
    [anon_sym_STAR] = ACTIONS(2120),
    [anon_sym_AMP_AMP] = ACTIONS(2120),
    [anon_sym_AMP] = ACTIONS(2118),
    [anon_sym_SEMI] = ACTIONS(2120),
    [anon_sym___extension__] = ACTIONS(2118),
    [anon_sym_typedef] = ACTIONS(2118),
    [anon_sym_in] = ACTIONS(2118),
    [anon_sym_out] = ACTIONS(2118),
    [anon_sym_inout] = ACTIONS(2118),
    [anon_sym_extern] = ACTIONS(2118),
    [anon_sym___attribute__] = ACTIONS(2118),
    [anon_sym_COLON_COLON] = ACTIONS(2120),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2120),
    [anon_sym___declspec] = ACTIONS(2118),
    [anon_sym___based] = ACTIONS(2118),
    [anon_sym___cdecl] = ACTIONS(2118),
    [anon_sym___clrcall] = ACTIONS(2118),
    [anon_sym___stdcall] = ACTIONS(2118),
    [anon_sym___fastcall] = ACTIONS(2118),
    [anon_sym___thiscall] = ACTIONS(2118),
    [anon_sym___vectorcall] = ACTIONS(2118),
    [anon_sym_LBRACE] = ACTIONS(2120),
    [anon_sym_signed] = ACTIONS(2118),
    [anon_sym_unsigned] = ACTIONS(2118),
    [anon_sym_long] = ACTIONS(2118),
    [anon_sym_short] = ACTIONS(2118),
    [anon_sym_LBRACK] = ACTIONS(2118),
    [anon_sym_static] = ACTIONS(2118),
    [anon_sym_register] = ACTIONS(2118),
    [anon_sym_inline] = ACTIONS(2118),
    [anon_sym___inline] = ACTIONS(2118),
    [anon_sym___inline__] = ACTIONS(2118),
    [anon_sym___forceinline] = ACTIONS(2118),
    [anon_sym_thread_local] = ACTIONS(2118),
    [anon_sym___thread] = ACTIONS(2118),
    [anon_sym_const] = ACTIONS(2118),
    [anon_sym_constexpr] = ACTIONS(2118),
    [anon_sym_volatile] = ACTIONS(2118),
    [anon_sym_restrict] = ACTIONS(2118),
    [anon_sym___restrict__] = ACTIONS(2118),
    [anon_sym__Atomic] = ACTIONS(2118),
    [anon_sym__Noreturn] = ACTIONS(2118),
    [anon_sym_noreturn] = ACTIONS(2118),
    [anon_sym_mutable] = ACTIONS(2118),
    [anon_sym_constinit] = ACTIONS(2118),
    [anon_sym_consteval] = ACTIONS(2118),
    [anon_sym_alignas] = ACTIONS(2118),
    [anon_sym__Alignas] = ACTIONS(2118),
    [sym_primitive_type] = ACTIONS(2118),
    [anon_sym_enum] = ACTIONS(2118),
    [anon_sym_class] = ACTIONS(2118),
    [anon_sym_struct] = ACTIONS(2118),
    [anon_sym_union] = ACTIONS(2118),
    [anon_sym_if] = ACTIONS(2118),
    [anon_sym_else] = ACTIONS(2118),
    [anon_sym_switch] = ACTIONS(2118),
    [anon_sym_case] = ACTIONS(2118),
    [anon_sym_default] = ACTIONS(2118),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_do] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2118),
    [anon_sym_return] = ACTIONS(2118),
    [anon_sym_break] = ACTIONS(2118),
    [anon_sym_continue] = ACTIONS(2118),
    [anon_sym_goto] = ACTIONS(2118),
    [anon_sym___try] = ACTIONS(2118),
    [anon_sym___leave] = ACTIONS(2118),
    [anon_sym_not] = ACTIONS(2118),
    [anon_sym_compl] = ACTIONS(2118),
    [anon_sym_DASH_DASH] = ACTIONS(2120),
    [anon_sym_PLUS_PLUS] = ACTIONS(2120),
    [anon_sym_sizeof] = ACTIONS(2118),
    [anon_sym___alignof__] = ACTIONS(2118),
    [anon_sym___alignof] = ACTIONS(2118),
    [anon_sym__alignof] = ACTIONS(2118),
    [anon_sym_alignof] = ACTIONS(2118),
    [anon_sym__Alignof] = ACTIONS(2118),
    [anon_sym_offsetof] = ACTIONS(2118),
    [anon_sym__Generic] = ACTIONS(2118),
    [anon_sym_asm] = ACTIONS(2118),
    [anon_sym___asm__] = ACTIONS(2118),
    [sym_number_literal] = ACTIONS(2120),
    [anon_sym_L_SQUOTE] = ACTIONS(2120),
    [anon_sym_u_SQUOTE] = ACTIONS(2120),
    [anon_sym_U_SQUOTE] = ACTIONS(2120),
    [anon_sym_u8_SQUOTE] = ACTIONS(2120),
    [anon_sym_SQUOTE] = ACTIONS(2120),
    [anon_sym_L_DQUOTE] = ACTIONS(2120),
    [anon_sym_u_DQUOTE] = ACTIONS(2120),
    [anon_sym_U_DQUOTE] = ACTIONS(2120),
    [anon_sym_u8_DQUOTE] = ACTIONS(2120),
    [anon_sym_DQUOTE] = ACTIONS(2120),
    [sym_true] = ACTIONS(2118),
    [sym_false] = ACTIONS(2118),
    [anon_sym_NULL] = ACTIONS(2118),
    [anon_sym_nullptr] = ACTIONS(2118),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2118),
    [anon_sym_decltype] = ACTIONS(2118),
    [sym_virtual] = ACTIONS(2118),
    [anon_sym_explicit] = ACTIONS(2118),
    [anon_sym_typename] = ACTIONS(2118),
    [anon_sym_template] = ACTIONS(2118),
    [anon_sym_operator] = ACTIONS(2118),
    [anon_sym_try] = ACTIONS(2118),
    [anon_sym_delete] = ACTIONS(2118),
    [anon_sym_throw] = ACTIONS(2118),
    [anon_sym_namespace] = ACTIONS(2118),
    [anon_sym_using] = ACTIONS(2118),
    [anon_sym_static_assert] = ACTIONS(2118),
    [anon_sym_concept] = ACTIONS(2118),
    [anon_sym_co_return] = ACTIONS(2118),
    [anon_sym_co_yield] = ACTIONS(2118),
    [anon_sym_R_DQUOTE] = ACTIONS(2120),
    [anon_sym_LR_DQUOTE] = ACTIONS(2120),
    [anon_sym_uR_DQUOTE] = ACTIONS(2120),
    [anon_sym_UR_DQUOTE] = ACTIONS(2120),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2120),
    [anon_sym_co_await] = ACTIONS(2118),
    [anon_sym_new] = ACTIONS(2118),
    [anon_sym_requires] = ACTIONS(2118),
    [sym_this] = ACTIONS(2118),
    [anon_sym_discard] = ACTIONS(2118),
    [anon_sym_precise] = ACTIONS(2118),
    [anon_sym_shared] = ACTIONS(2118),
    [anon_sym_groupshared] = ACTIONS(2118),
    [anon_sym_uniform] = ACTIONS(2118),
    [anon_sym_row_major] = ACTIONS(2118),
    [anon_sym_column_major] = ACTIONS(2118),
    [anon_sym_globallycoherent] = ACTIONS(2118),
    [anon_sym_centroid] = ACTIONS(2118),
    [anon_sym_noperspective] = ACTIONS(2118),
    [anon_sym_nointerpolation] = ACTIONS(2118),
    [anon_sym_sample] = ACTIONS(2118),
    [anon_sym_linear] = ACTIONS(2118),
    [anon_sym_snorm] = ACTIONS(2118),
    [anon_sym_unorm] = ACTIONS(2118),
    [anon_sym_point] = ACTIONS(2118),
    [anon_sym_line] = ACTIONS(2118),
    [anon_sym_triangleadj] = ACTIONS(2118),
    [anon_sym_lineadj] = ACTIONS(2118),
    [anon_sym_triangle] = ACTIONS(2118),
    [anon_sym_cbuffer] = ACTIONS(2118),
  },
  [506] = {
    [ts_builtin_sym_end] = ACTIONS(2250),
    [sym_identifier] = ACTIONS(2248),
    [aux_sym_preproc_include_token1] = ACTIONS(2248),
    [aux_sym_preproc_def_token1] = ACTIONS(2248),
    [aux_sym_preproc_if_token1] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2248),
    [sym_preproc_directive] = ACTIONS(2248),
    [anon_sym_LPAREN2] = ACTIONS(2250),
    [anon_sym_BANG] = ACTIONS(2250),
    [anon_sym_TILDE] = ACTIONS(2250),
    [anon_sym_DASH] = ACTIONS(2248),
    [anon_sym_PLUS] = ACTIONS(2248),
    [anon_sym_STAR] = ACTIONS(2250),
    [anon_sym_AMP_AMP] = ACTIONS(2250),
    [anon_sym_AMP] = ACTIONS(2248),
    [anon_sym_SEMI] = ACTIONS(2250),
    [anon_sym___extension__] = ACTIONS(2248),
    [anon_sym_typedef] = ACTIONS(2248),
    [anon_sym_in] = ACTIONS(2248),
    [anon_sym_out] = ACTIONS(2248),
    [anon_sym_inout] = ACTIONS(2248),
    [anon_sym_extern] = ACTIONS(2248),
    [anon_sym___attribute__] = ACTIONS(2248),
    [anon_sym_COLON_COLON] = ACTIONS(2250),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2250),
    [anon_sym___declspec] = ACTIONS(2248),
    [anon_sym___based] = ACTIONS(2248),
    [anon_sym___cdecl] = ACTIONS(2248),
    [anon_sym___clrcall] = ACTIONS(2248),
    [anon_sym___stdcall] = ACTIONS(2248),
    [anon_sym___fastcall] = ACTIONS(2248),
    [anon_sym___thiscall] = ACTIONS(2248),
    [anon_sym___vectorcall] = ACTIONS(2248),
    [anon_sym_LBRACE] = ACTIONS(2250),
    [anon_sym_signed] = ACTIONS(2248),
    [anon_sym_unsigned] = ACTIONS(2248),
    [anon_sym_long] = ACTIONS(2248),
    [anon_sym_short] = ACTIONS(2248),
    [anon_sym_LBRACK] = ACTIONS(2248),
    [anon_sym_static] = ACTIONS(2248),
    [anon_sym_register] = ACTIONS(2248),
    [anon_sym_inline] = ACTIONS(2248),
    [anon_sym___inline] = ACTIONS(2248),
    [anon_sym___inline__] = ACTIONS(2248),
    [anon_sym___forceinline] = ACTIONS(2248),
    [anon_sym_thread_local] = ACTIONS(2248),
    [anon_sym___thread] = ACTIONS(2248),
    [anon_sym_const] = ACTIONS(2248),
    [anon_sym_constexpr] = ACTIONS(2248),
    [anon_sym_volatile] = ACTIONS(2248),
    [anon_sym_restrict] = ACTIONS(2248),
    [anon_sym___restrict__] = ACTIONS(2248),
    [anon_sym__Atomic] = ACTIONS(2248),
    [anon_sym__Noreturn] = ACTIONS(2248),
    [anon_sym_noreturn] = ACTIONS(2248),
    [anon_sym_mutable] = ACTIONS(2248),
    [anon_sym_constinit] = ACTIONS(2248),
    [anon_sym_consteval] = ACTIONS(2248),
    [anon_sym_alignas] = ACTIONS(2248),
    [anon_sym__Alignas] = ACTIONS(2248),
    [sym_primitive_type] = ACTIONS(2248),
    [anon_sym_enum] = ACTIONS(2248),
    [anon_sym_class] = ACTIONS(2248),
    [anon_sym_struct] = ACTIONS(2248),
    [anon_sym_union] = ACTIONS(2248),
    [anon_sym_if] = ACTIONS(2248),
    [anon_sym_else] = ACTIONS(2248),
    [anon_sym_switch] = ACTIONS(2248),
    [anon_sym_case] = ACTIONS(2248),
    [anon_sym_default] = ACTIONS(2248),
    [anon_sym_while] = ACTIONS(2248),
    [anon_sym_do] = ACTIONS(2248),
    [anon_sym_for] = ACTIONS(2248),
    [anon_sym_return] = ACTIONS(2248),
    [anon_sym_break] = ACTIONS(2248),
    [anon_sym_continue] = ACTIONS(2248),
    [anon_sym_goto] = ACTIONS(2248),
    [anon_sym___try] = ACTIONS(2248),
    [anon_sym___leave] = ACTIONS(2248),
    [anon_sym_not] = ACTIONS(2248),
    [anon_sym_compl] = ACTIONS(2248),
    [anon_sym_DASH_DASH] = ACTIONS(2250),
    [anon_sym_PLUS_PLUS] = ACTIONS(2250),
    [anon_sym_sizeof] = ACTIONS(2248),
    [anon_sym___alignof__] = ACTIONS(2248),
    [anon_sym___alignof] = ACTIONS(2248),
    [anon_sym__alignof] = ACTIONS(2248),
    [anon_sym_alignof] = ACTIONS(2248),
    [anon_sym__Alignof] = ACTIONS(2248),
    [anon_sym_offsetof] = ACTIONS(2248),
    [anon_sym__Generic] = ACTIONS(2248),
    [anon_sym_asm] = ACTIONS(2248),
    [anon_sym___asm__] = ACTIONS(2248),
    [sym_number_literal] = ACTIONS(2250),
    [anon_sym_L_SQUOTE] = ACTIONS(2250),
    [anon_sym_u_SQUOTE] = ACTIONS(2250),
    [anon_sym_U_SQUOTE] = ACTIONS(2250),
    [anon_sym_u8_SQUOTE] = ACTIONS(2250),
    [anon_sym_SQUOTE] = ACTIONS(2250),
    [anon_sym_L_DQUOTE] = ACTIONS(2250),
    [anon_sym_u_DQUOTE] = ACTIONS(2250),
    [anon_sym_U_DQUOTE] = ACTIONS(2250),
    [anon_sym_u8_DQUOTE] = ACTIONS(2250),
    [anon_sym_DQUOTE] = ACTIONS(2250),
    [sym_true] = ACTIONS(2248),
    [sym_false] = ACTIONS(2248),
    [anon_sym_NULL] = ACTIONS(2248),
    [anon_sym_nullptr] = ACTIONS(2248),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2248),
    [anon_sym_decltype] = ACTIONS(2248),
    [sym_virtual] = ACTIONS(2248),
    [anon_sym_explicit] = ACTIONS(2248),
    [anon_sym_typename] = ACTIONS(2248),
    [anon_sym_template] = ACTIONS(2248),
    [anon_sym_operator] = ACTIONS(2248),
    [anon_sym_try] = ACTIONS(2248),
    [anon_sym_delete] = ACTIONS(2248),
    [anon_sym_throw] = ACTIONS(2248),
    [anon_sym_namespace] = ACTIONS(2248),
    [anon_sym_using] = ACTIONS(2248),
    [anon_sym_static_assert] = ACTIONS(2248),
    [anon_sym_concept] = ACTIONS(2248),
    [anon_sym_co_return] = ACTIONS(2248),
    [anon_sym_co_yield] = ACTIONS(2248),
    [anon_sym_R_DQUOTE] = ACTIONS(2250),
    [anon_sym_LR_DQUOTE] = ACTIONS(2250),
    [anon_sym_uR_DQUOTE] = ACTIONS(2250),
    [anon_sym_UR_DQUOTE] = ACTIONS(2250),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2250),
    [anon_sym_co_await] = ACTIONS(2248),
    [anon_sym_new] = ACTIONS(2248),
    [anon_sym_requires] = ACTIONS(2248),
    [sym_this] = ACTIONS(2248),
    [anon_sym_discard] = ACTIONS(2248),
    [anon_sym_precise] = ACTIONS(2248),
    [anon_sym_shared] = ACTIONS(2248),
    [anon_sym_groupshared] = ACTIONS(2248),
    [anon_sym_uniform] = ACTIONS(2248),
    [anon_sym_row_major] = ACTIONS(2248),
    [anon_sym_column_major] = ACTIONS(2248),
    [anon_sym_globallycoherent] = ACTIONS(2248),
    [anon_sym_centroid] = ACTIONS(2248),
    [anon_sym_noperspective] = ACTIONS(2248),
    [anon_sym_nointerpolation] = ACTIONS(2248),
    [anon_sym_sample] = ACTIONS(2248),
    [anon_sym_linear] = ACTIONS(2248),
    [anon_sym_snorm] = ACTIONS(2248),
    [anon_sym_unorm] = ACTIONS(2248),
    [anon_sym_point] = ACTIONS(2248),
    [anon_sym_line] = ACTIONS(2248),
    [anon_sym_triangleadj] = ACTIONS(2248),
    [anon_sym_lineadj] = ACTIONS(2248),
    [anon_sym_triangle] = ACTIONS(2248),
    [anon_sym_cbuffer] = ACTIONS(2248),
  },
  [507] = {
    [sym_identifier] = ACTIONS(2134),
    [aux_sym_preproc_include_token1] = ACTIONS(2134),
    [aux_sym_preproc_def_token1] = ACTIONS(2134),
    [aux_sym_preproc_if_token1] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2134),
    [sym_preproc_directive] = ACTIONS(2134),
    [anon_sym_LPAREN2] = ACTIONS(2136),
    [anon_sym_BANG] = ACTIONS(2136),
    [anon_sym_TILDE] = ACTIONS(2136),
    [anon_sym_DASH] = ACTIONS(2134),
    [anon_sym_PLUS] = ACTIONS(2134),
    [anon_sym_STAR] = ACTIONS(2136),
    [anon_sym_AMP_AMP] = ACTIONS(2136),
    [anon_sym_AMP] = ACTIONS(2134),
    [anon_sym_SEMI] = ACTIONS(2136),
    [anon_sym___extension__] = ACTIONS(2134),
    [anon_sym_typedef] = ACTIONS(2134),
    [anon_sym_in] = ACTIONS(2134),
    [anon_sym_out] = ACTIONS(2134),
    [anon_sym_inout] = ACTIONS(2134),
    [anon_sym_extern] = ACTIONS(2134),
    [anon_sym___attribute__] = ACTIONS(2134),
    [anon_sym_COLON_COLON] = ACTIONS(2136),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2136),
    [anon_sym___declspec] = ACTIONS(2134),
    [anon_sym___based] = ACTIONS(2134),
    [anon_sym___cdecl] = ACTIONS(2134),
    [anon_sym___clrcall] = ACTIONS(2134),
    [anon_sym___stdcall] = ACTIONS(2134),
    [anon_sym___fastcall] = ACTIONS(2134),
    [anon_sym___thiscall] = ACTIONS(2134),
    [anon_sym___vectorcall] = ACTIONS(2134),
    [anon_sym_LBRACE] = ACTIONS(2136),
    [anon_sym_RBRACE] = ACTIONS(2136),
    [anon_sym_signed] = ACTIONS(2134),
    [anon_sym_unsigned] = ACTIONS(2134),
    [anon_sym_long] = ACTIONS(2134),
    [anon_sym_short] = ACTIONS(2134),
    [anon_sym_LBRACK] = ACTIONS(2134),
    [anon_sym_static] = ACTIONS(2134),
    [anon_sym_register] = ACTIONS(2134),
    [anon_sym_inline] = ACTIONS(2134),
    [anon_sym___inline] = ACTIONS(2134),
    [anon_sym___inline__] = ACTIONS(2134),
    [anon_sym___forceinline] = ACTIONS(2134),
    [anon_sym_thread_local] = ACTIONS(2134),
    [anon_sym___thread] = ACTIONS(2134),
    [anon_sym_const] = ACTIONS(2134),
    [anon_sym_constexpr] = ACTIONS(2134),
    [anon_sym_volatile] = ACTIONS(2134),
    [anon_sym_restrict] = ACTIONS(2134),
    [anon_sym___restrict__] = ACTIONS(2134),
    [anon_sym__Atomic] = ACTIONS(2134),
    [anon_sym__Noreturn] = ACTIONS(2134),
    [anon_sym_noreturn] = ACTIONS(2134),
    [anon_sym_mutable] = ACTIONS(2134),
    [anon_sym_constinit] = ACTIONS(2134),
    [anon_sym_consteval] = ACTIONS(2134),
    [anon_sym_alignas] = ACTIONS(2134),
    [anon_sym__Alignas] = ACTIONS(2134),
    [sym_primitive_type] = ACTIONS(2134),
    [anon_sym_enum] = ACTIONS(2134),
    [anon_sym_class] = ACTIONS(2134),
    [anon_sym_struct] = ACTIONS(2134),
    [anon_sym_union] = ACTIONS(2134),
    [anon_sym_if] = ACTIONS(2134),
    [anon_sym_else] = ACTIONS(2134),
    [anon_sym_switch] = ACTIONS(2134),
    [anon_sym_case] = ACTIONS(2134),
    [anon_sym_default] = ACTIONS(2134),
    [anon_sym_while] = ACTIONS(2134),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_for] = ACTIONS(2134),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_break] = ACTIONS(2134),
    [anon_sym_continue] = ACTIONS(2134),
    [anon_sym_goto] = ACTIONS(2134),
    [anon_sym___try] = ACTIONS(2134),
    [anon_sym___leave] = ACTIONS(2134),
    [anon_sym_not] = ACTIONS(2134),
    [anon_sym_compl] = ACTIONS(2134),
    [anon_sym_DASH_DASH] = ACTIONS(2136),
    [anon_sym_PLUS_PLUS] = ACTIONS(2136),
    [anon_sym_sizeof] = ACTIONS(2134),
    [anon_sym___alignof__] = ACTIONS(2134),
    [anon_sym___alignof] = ACTIONS(2134),
    [anon_sym__alignof] = ACTIONS(2134),
    [anon_sym_alignof] = ACTIONS(2134),
    [anon_sym__Alignof] = ACTIONS(2134),
    [anon_sym_offsetof] = ACTIONS(2134),
    [anon_sym__Generic] = ACTIONS(2134),
    [anon_sym_asm] = ACTIONS(2134),
    [anon_sym___asm__] = ACTIONS(2134),
    [sym_number_literal] = ACTIONS(2136),
    [anon_sym_L_SQUOTE] = ACTIONS(2136),
    [anon_sym_u_SQUOTE] = ACTIONS(2136),
    [anon_sym_U_SQUOTE] = ACTIONS(2136),
    [anon_sym_u8_SQUOTE] = ACTIONS(2136),
    [anon_sym_SQUOTE] = ACTIONS(2136),
    [anon_sym_L_DQUOTE] = ACTIONS(2136),
    [anon_sym_u_DQUOTE] = ACTIONS(2136),
    [anon_sym_U_DQUOTE] = ACTIONS(2136),
    [anon_sym_u8_DQUOTE] = ACTIONS(2136),
    [anon_sym_DQUOTE] = ACTIONS(2136),
    [sym_true] = ACTIONS(2134),
    [sym_false] = ACTIONS(2134),
    [anon_sym_NULL] = ACTIONS(2134),
    [anon_sym_nullptr] = ACTIONS(2134),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2134),
    [anon_sym_decltype] = ACTIONS(2134),
    [sym_virtual] = ACTIONS(2134),
    [anon_sym_explicit] = ACTIONS(2134),
    [anon_sym_typename] = ACTIONS(2134),
    [anon_sym_template] = ACTIONS(2134),
    [anon_sym_operator] = ACTIONS(2134),
    [anon_sym_try] = ACTIONS(2134),
    [anon_sym_delete] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2134),
    [anon_sym_namespace] = ACTIONS(2134),
    [anon_sym_using] = ACTIONS(2134),
    [anon_sym_static_assert] = ACTIONS(2134),
    [anon_sym_concept] = ACTIONS(2134),
    [anon_sym_co_return] = ACTIONS(2134),
    [anon_sym_co_yield] = ACTIONS(2134),
    [anon_sym_R_DQUOTE] = ACTIONS(2136),
    [anon_sym_LR_DQUOTE] = ACTIONS(2136),
    [anon_sym_uR_DQUOTE] = ACTIONS(2136),
    [anon_sym_UR_DQUOTE] = ACTIONS(2136),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2136),
    [anon_sym_co_await] = ACTIONS(2134),
    [anon_sym_new] = ACTIONS(2134),
    [anon_sym_requires] = ACTIONS(2134),
    [sym_this] = ACTIONS(2134),
    [anon_sym_discard] = ACTIONS(2134),
    [anon_sym_precise] = ACTIONS(2134),
    [anon_sym_shared] = ACTIONS(2134),
    [anon_sym_groupshared] = ACTIONS(2134),
    [anon_sym_uniform] = ACTIONS(2134),
    [anon_sym_row_major] = ACTIONS(2134),
    [anon_sym_column_major] = ACTIONS(2134),
    [anon_sym_globallycoherent] = ACTIONS(2134),
    [anon_sym_centroid] = ACTIONS(2134),
    [anon_sym_noperspective] = ACTIONS(2134),
    [anon_sym_nointerpolation] = ACTIONS(2134),
    [anon_sym_sample] = ACTIONS(2134),
    [anon_sym_linear] = ACTIONS(2134),
    [anon_sym_snorm] = ACTIONS(2134),
    [anon_sym_unorm] = ACTIONS(2134),
    [anon_sym_point] = ACTIONS(2134),
    [anon_sym_line] = ACTIONS(2134),
    [anon_sym_triangleadj] = ACTIONS(2134),
    [anon_sym_lineadj] = ACTIONS(2134),
    [anon_sym_triangle] = ACTIONS(2134),
    [anon_sym_cbuffer] = ACTIONS(2134),
  },
  [508] = {
    [ts_builtin_sym_end] = ACTIONS(2250),
    [sym_identifier] = ACTIONS(2248),
    [aux_sym_preproc_include_token1] = ACTIONS(2248),
    [aux_sym_preproc_def_token1] = ACTIONS(2248),
    [aux_sym_preproc_if_token1] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2248),
    [sym_preproc_directive] = ACTIONS(2248),
    [anon_sym_LPAREN2] = ACTIONS(2250),
    [anon_sym_BANG] = ACTIONS(2250),
    [anon_sym_TILDE] = ACTIONS(2250),
    [anon_sym_DASH] = ACTIONS(2248),
    [anon_sym_PLUS] = ACTIONS(2248),
    [anon_sym_STAR] = ACTIONS(2250),
    [anon_sym_AMP_AMP] = ACTIONS(2250),
    [anon_sym_AMP] = ACTIONS(2248),
    [anon_sym_SEMI] = ACTIONS(2250),
    [anon_sym___extension__] = ACTIONS(2248),
    [anon_sym_typedef] = ACTIONS(2248),
    [anon_sym_in] = ACTIONS(2248),
    [anon_sym_out] = ACTIONS(2248),
    [anon_sym_inout] = ACTIONS(2248),
    [anon_sym_extern] = ACTIONS(2248),
    [anon_sym___attribute__] = ACTIONS(2248),
    [anon_sym_COLON_COLON] = ACTIONS(2250),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2250),
    [anon_sym___declspec] = ACTIONS(2248),
    [anon_sym___based] = ACTIONS(2248),
    [anon_sym___cdecl] = ACTIONS(2248),
    [anon_sym___clrcall] = ACTIONS(2248),
    [anon_sym___stdcall] = ACTIONS(2248),
    [anon_sym___fastcall] = ACTIONS(2248),
    [anon_sym___thiscall] = ACTIONS(2248),
    [anon_sym___vectorcall] = ACTIONS(2248),
    [anon_sym_LBRACE] = ACTIONS(2250),
    [anon_sym_signed] = ACTIONS(2248),
    [anon_sym_unsigned] = ACTIONS(2248),
    [anon_sym_long] = ACTIONS(2248),
    [anon_sym_short] = ACTIONS(2248),
    [anon_sym_LBRACK] = ACTIONS(2248),
    [anon_sym_static] = ACTIONS(2248),
    [anon_sym_register] = ACTIONS(2248),
    [anon_sym_inline] = ACTIONS(2248),
    [anon_sym___inline] = ACTIONS(2248),
    [anon_sym___inline__] = ACTIONS(2248),
    [anon_sym___forceinline] = ACTIONS(2248),
    [anon_sym_thread_local] = ACTIONS(2248),
    [anon_sym___thread] = ACTIONS(2248),
    [anon_sym_const] = ACTIONS(2248),
    [anon_sym_constexpr] = ACTIONS(2248),
    [anon_sym_volatile] = ACTIONS(2248),
    [anon_sym_restrict] = ACTIONS(2248),
    [anon_sym___restrict__] = ACTIONS(2248),
    [anon_sym__Atomic] = ACTIONS(2248),
    [anon_sym__Noreturn] = ACTIONS(2248),
    [anon_sym_noreturn] = ACTIONS(2248),
    [anon_sym_mutable] = ACTIONS(2248),
    [anon_sym_constinit] = ACTIONS(2248),
    [anon_sym_consteval] = ACTIONS(2248),
    [anon_sym_alignas] = ACTIONS(2248),
    [anon_sym__Alignas] = ACTIONS(2248),
    [sym_primitive_type] = ACTIONS(2248),
    [anon_sym_enum] = ACTIONS(2248),
    [anon_sym_class] = ACTIONS(2248),
    [anon_sym_struct] = ACTIONS(2248),
    [anon_sym_union] = ACTIONS(2248),
    [anon_sym_if] = ACTIONS(2248),
    [anon_sym_else] = ACTIONS(2248),
    [anon_sym_switch] = ACTIONS(2248),
    [anon_sym_case] = ACTIONS(2248),
    [anon_sym_default] = ACTIONS(2248),
    [anon_sym_while] = ACTIONS(2248),
    [anon_sym_do] = ACTIONS(2248),
    [anon_sym_for] = ACTIONS(2248),
    [anon_sym_return] = ACTIONS(2248),
    [anon_sym_break] = ACTIONS(2248),
    [anon_sym_continue] = ACTIONS(2248),
    [anon_sym_goto] = ACTIONS(2248),
    [anon_sym___try] = ACTIONS(2248),
    [anon_sym___leave] = ACTIONS(2248),
    [anon_sym_not] = ACTIONS(2248),
    [anon_sym_compl] = ACTIONS(2248),
    [anon_sym_DASH_DASH] = ACTIONS(2250),
    [anon_sym_PLUS_PLUS] = ACTIONS(2250),
    [anon_sym_sizeof] = ACTIONS(2248),
    [anon_sym___alignof__] = ACTIONS(2248),
    [anon_sym___alignof] = ACTIONS(2248),
    [anon_sym__alignof] = ACTIONS(2248),
    [anon_sym_alignof] = ACTIONS(2248),
    [anon_sym__Alignof] = ACTIONS(2248),
    [anon_sym_offsetof] = ACTIONS(2248),
    [anon_sym__Generic] = ACTIONS(2248),
    [anon_sym_asm] = ACTIONS(2248),
    [anon_sym___asm__] = ACTIONS(2248),
    [sym_number_literal] = ACTIONS(2250),
    [anon_sym_L_SQUOTE] = ACTIONS(2250),
    [anon_sym_u_SQUOTE] = ACTIONS(2250),
    [anon_sym_U_SQUOTE] = ACTIONS(2250),
    [anon_sym_u8_SQUOTE] = ACTIONS(2250),
    [anon_sym_SQUOTE] = ACTIONS(2250),
    [anon_sym_L_DQUOTE] = ACTIONS(2250),
    [anon_sym_u_DQUOTE] = ACTIONS(2250),
    [anon_sym_U_DQUOTE] = ACTIONS(2250),
    [anon_sym_u8_DQUOTE] = ACTIONS(2250),
    [anon_sym_DQUOTE] = ACTIONS(2250),
    [sym_true] = ACTIONS(2248),
    [sym_false] = ACTIONS(2248),
    [anon_sym_NULL] = ACTIONS(2248),
    [anon_sym_nullptr] = ACTIONS(2248),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2248),
    [anon_sym_decltype] = ACTIONS(2248),
    [sym_virtual] = ACTIONS(2248),
    [anon_sym_explicit] = ACTIONS(2248),
    [anon_sym_typename] = ACTIONS(2248),
    [anon_sym_template] = ACTIONS(2248),
    [anon_sym_operator] = ACTIONS(2248),
    [anon_sym_try] = ACTIONS(2248),
    [anon_sym_delete] = ACTIONS(2248),
    [anon_sym_throw] = ACTIONS(2248),
    [anon_sym_namespace] = ACTIONS(2248),
    [anon_sym_using] = ACTIONS(2248),
    [anon_sym_static_assert] = ACTIONS(2248),
    [anon_sym_concept] = ACTIONS(2248),
    [anon_sym_co_return] = ACTIONS(2248),
    [anon_sym_co_yield] = ACTIONS(2248),
    [anon_sym_R_DQUOTE] = ACTIONS(2250),
    [anon_sym_LR_DQUOTE] = ACTIONS(2250),
    [anon_sym_uR_DQUOTE] = ACTIONS(2250),
    [anon_sym_UR_DQUOTE] = ACTIONS(2250),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2250),
    [anon_sym_co_await] = ACTIONS(2248),
    [anon_sym_new] = ACTIONS(2248),
    [anon_sym_requires] = ACTIONS(2248),
    [sym_this] = ACTIONS(2248),
    [anon_sym_discard] = ACTIONS(2248),
    [anon_sym_precise] = ACTIONS(2248),
    [anon_sym_shared] = ACTIONS(2248),
    [anon_sym_groupshared] = ACTIONS(2248),
    [anon_sym_uniform] = ACTIONS(2248),
    [anon_sym_row_major] = ACTIONS(2248),
    [anon_sym_column_major] = ACTIONS(2248),
    [anon_sym_globallycoherent] = ACTIONS(2248),
    [anon_sym_centroid] = ACTIONS(2248),
    [anon_sym_noperspective] = ACTIONS(2248),
    [anon_sym_nointerpolation] = ACTIONS(2248),
    [anon_sym_sample] = ACTIONS(2248),
    [anon_sym_linear] = ACTIONS(2248),
    [anon_sym_snorm] = ACTIONS(2248),
    [anon_sym_unorm] = ACTIONS(2248),
    [anon_sym_point] = ACTIONS(2248),
    [anon_sym_line] = ACTIONS(2248),
    [anon_sym_triangleadj] = ACTIONS(2248),
    [anon_sym_lineadj] = ACTIONS(2248),
    [anon_sym_triangle] = ACTIONS(2248),
    [anon_sym_cbuffer] = ACTIONS(2248),
  },
  [509] = {
    [sym_identifier] = ACTIONS(2138),
    [aux_sym_preproc_include_token1] = ACTIONS(2138),
    [aux_sym_preproc_def_token1] = ACTIONS(2138),
    [aux_sym_preproc_if_token1] = ACTIONS(2138),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2138),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2138),
    [sym_preproc_directive] = ACTIONS(2138),
    [anon_sym_LPAREN2] = ACTIONS(2140),
    [anon_sym_BANG] = ACTIONS(2140),
    [anon_sym_TILDE] = ACTIONS(2140),
    [anon_sym_DASH] = ACTIONS(2138),
    [anon_sym_PLUS] = ACTIONS(2138),
    [anon_sym_STAR] = ACTIONS(2140),
    [anon_sym_AMP_AMP] = ACTIONS(2140),
    [anon_sym_AMP] = ACTIONS(2138),
    [anon_sym_SEMI] = ACTIONS(2140),
    [anon_sym___extension__] = ACTIONS(2138),
    [anon_sym_typedef] = ACTIONS(2138),
    [anon_sym_in] = ACTIONS(2138),
    [anon_sym_out] = ACTIONS(2138),
    [anon_sym_inout] = ACTIONS(2138),
    [anon_sym_extern] = ACTIONS(2138),
    [anon_sym___attribute__] = ACTIONS(2138),
    [anon_sym_COLON_COLON] = ACTIONS(2140),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2140),
    [anon_sym___declspec] = ACTIONS(2138),
    [anon_sym___based] = ACTIONS(2138),
    [anon_sym___cdecl] = ACTIONS(2138),
    [anon_sym___clrcall] = ACTIONS(2138),
    [anon_sym___stdcall] = ACTIONS(2138),
    [anon_sym___fastcall] = ACTIONS(2138),
    [anon_sym___thiscall] = ACTIONS(2138),
    [anon_sym___vectorcall] = ACTIONS(2138),
    [anon_sym_LBRACE] = ACTIONS(2140),
    [anon_sym_RBRACE] = ACTIONS(2140),
    [anon_sym_signed] = ACTIONS(2138),
    [anon_sym_unsigned] = ACTIONS(2138),
    [anon_sym_long] = ACTIONS(2138),
    [anon_sym_short] = ACTIONS(2138),
    [anon_sym_LBRACK] = ACTIONS(2138),
    [anon_sym_static] = ACTIONS(2138),
    [anon_sym_register] = ACTIONS(2138),
    [anon_sym_inline] = ACTIONS(2138),
    [anon_sym___inline] = ACTIONS(2138),
    [anon_sym___inline__] = ACTIONS(2138),
    [anon_sym___forceinline] = ACTIONS(2138),
    [anon_sym_thread_local] = ACTIONS(2138),
    [anon_sym___thread] = ACTIONS(2138),
    [anon_sym_const] = ACTIONS(2138),
    [anon_sym_constexpr] = ACTIONS(2138),
    [anon_sym_volatile] = ACTIONS(2138),
    [anon_sym_restrict] = ACTIONS(2138),
    [anon_sym___restrict__] = ACTIONS(2138),
    [anon_sym__Atomic] = ACTIONS(2138),
    [anon_sym__Noreturn] = ACTIONS(2138),
    [anon_sym_noreturn] = ACTIONS(2138),
    [anon_sym_mutable] = ACTIONS(2138),
    [anon_sym_constinit] = ACTIONS(2138),
    [anon_sym_consteval] = ACTIONS(2138),
    [anon_sym_alignas] = ACTIONS(2138),
    [anon_sym__Alignas] = ACTIONS(2138),
    [sym_primitive_type] = ACTIONS(2138),
    [anon_sym_enum] = ACTIONS(2138),
    [anon_sym_class] = ACTIONS(2138),
    [anon_sym_struct] = ACTIONS(2138),
    [anon_sym_union] = ACTIONS(2138),
    [anon_sym_if] = ACTIONS(2138),
    [anon_sym_else] = ACTIONS(2138),
    [anon_sym_switch] = ACTIONS(2138),
    [anon_sym_case] = ACTIONS(2138),
    [anon_sym_default] = ACTIONS(2138),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_do] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2138),
    [anon_sym_return] = ACTIONS(2138),
    [anon_sym_break] = ACTIONS(2138),
    [anon_sym_continue] = ACTIONS(2138),
    [anon_sym_goto] = ACTIONS(2138),
    [anon_sym___try] = ACTIONS(2138),
    [anon_sym___leave] = ACTIONS(2138),
    [anon_sym_not] = ACTIONS(2138),
    [anon_sym_compl] = ACTIONS(2138),
    [anon_sym_DASH_DASH] = ACTIONS(2140),
    [anon_sym_PLUS_PLUS] = ACTIONS(2140),
    [anon_sym_sizeof] = ACTIONS(2138),
    [anon_sym___alignof__] = ACTIONS(2138),
    [anon_sym___alignof] = ACTIONS(2138),
    [anon_sym__alignof] = ACTIONS(2138),
    [anon_sym_alignof] = ACTIONS(2138),
    [anon_sym__Alignof] = ACTIONS(2138),
    [anon_sym_offsetof] = ACTIONS(2138),
    [anon_sym__Generic] = ACTIONS(2138),
    [anon_sym_asm] = ACTIONS(2138),
    [anon_sym___asm__] = ACTIONS(2138),
    [sym_number_literal] = ACTIONS(2140),
    [anon_sym_L_SQUOTE] = ACTIONS(2140),
    [anon_sym_u_SQUOTE] = ACTIONS(2140),
    [anon_sym_U_SQUOTE] = ACTIONS(2140),
    [anon_sym_u8_SQUOTE] = ACTIONS(2140),
    [anon_sym_SQUOTE] = ACTIONS(2140),
    [anon_sym_L_DQUOTE] = ACTIONS(2140),
    [anon_sym_u_DQUOTE] = ACTIONS(2140),
    [anon_sym_U_DQUOTE] = ACTIONS(2140),
    [anon_sym_u8_DQUOTE] = ACTIONS(2140),
    [anon_sym_DQUOTE] = ACTIONS(2140),
    [sym_true] = ACTIONS(2138),
    [sym_false] = ACTIONS(2138),
    [anon_sym_NULL] = ACTIONS(2138),
    [anon_sym_nullptr] = ACTIONS(2138),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2138),
    [anon_sym_decltype] = ACTIONS(2138),
    [sym_virtual] = ACTIONS(2138),
    [anon_sym_explicit] = ACTIONS(2138),
    [anon_sym_typename] = ACTIONS(2138),
    [anon_sym_template] = ACTIONS(2138),
    [anon_sym_operator] = ACTIONS(2138),
    [anon_sym_try] = ACTIONS(2138),
    [anon_sym_delete] = ACTIONS(2138),
    [anon_sym_throw] = ACTIONS(2138),
    [anon_sym_namespace] = ACTIONS(2138),
    [anon_sym_using] = ACTIONS(2138),
    [anon_sym_static_assert] = ACTIONS(2138),
    [anon_sym_concept] = ACTIONS(2138),
    [anon_sym_co_return] = ACTIONS(2138),
    [anon_sym_co_yield] = ACTIONS(2138),
    [anon_sym_R_DQUOTE] = ACTIONS(2140),
    [anon_sym_LR_DQUOTE] = ACTIONS(2140),
    [anon_sym_uR_DQUOTE] = ACTIONS(2140),
    [anon_sym_UR_DQUOTE] = ACTIONS(2140),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2140),
    [anon_sym_co_await] = ACTIONS(2138),
    [anon_sym_new] = ACTIONS(2138),
    [anon_sym_requires] = ACTIONS(2138),
    [sym_this] = ACTIONS(2138),
    [anon_sym_discard] = ACTIONS(2138),
    [anon_sym_precise] = ACTIONS(2138),
    [anon_sym_shared] = ACTIONS(2138),
    [anon_sym_groupshared] = ACTIONS(2138),
    [anon_sym_uniform] = ACTIONS(2138),
    [anon_sym_row_major] = ACTIONS(2138),
    [anon_sym_column_major] = ACTIONS(2138),
    [anon_sym_globallycoherent] = ACTIONS(2138),
    [anon_sym_centroid] = ACTIONS(2138),
    [anon_sym_noperspective] = ACTIONS(2138),
    [anon_sym_nointerpolation] = ACTIONS(2138),
    [anon_sym_sample] = ACTIONS(2138),
    [anon_sym_linear] = ACTIONS(2138),
    [anon_sym_snorm] = ACTIONS(2138),
    [anon_sym_unorm] = ACTIONS(2138),
    [anon_sym_point] = ACTIONS(2138),
    [anon_sym_line] = ACTIONS(2138),
    [anon_sym_triangleadj] = ACTIONS(2138),
    [anon_sym_lineadj] = ACTIONS(2138),
    [anon_sym_triangle] = ACTIONS(2138),
    [anon_sym_cbuffer] = ACTIONS(2138),
  },
  [510] = {
    [sym_identifier] = ACTIONS(2288),
    [aux_sym_preproc_include_token1] = ACTIONS(2288),
    [aux_sym_preproc_def_token1] = ACTIONS(2288),
    [aux_sym_preproc_if_token1] = ACTIONS(2288),
    [aux_sym_preproc_if_token2] = ACTIONS(2288),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2288),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2288),
    [sym_preproc_directive] = ACTIONS(2288),
    [anon_sym_LPAREN2] = ACTIONS(2290),
    [anon_sym_BANG] = ACTIONS(2290),
    [anon_sym_TILDE] = ACTIONS(2290),
    [anon_sym_DASH] = ACTIONS(2288),
    [anon_sym_PLUS] = ACTIONS(2288),
    [anon_sym_STAR] = ACTIONS(2290),
    [anon_sym_AMP_AMP] = ACTIONS(2290),
    [anon_sym_AMP] = ACTIONS(2288),
    [anon_sym_SEMI] = ACTIONS(2290),
    [anon_sym___extension__] = ACTIONS(2288),
    [anon_sym_typedef] = ACTIONS(2288),
    [anon_sym_in] = ACTIONS(2288),
    [anon_sym_out] = ACTIONS(2288),
    [anon_sym_inout] = ACTIONS(2288),
    [anon_sym_extern] = ACTIONS(2288),
    [anon_sym___attribute__] = ACTIONS(2288),
    [anon_sym_COLON_COLON] = ACTIONS(2290),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2290),
    [anon_sym___declspec] = ACTIONS(2288),
    [anon_sym___based] = ACTIONS(2288),
    [anon_sym___cdecl] = ACTIONS(2288),
    [anon_sym___clrcall] = ACTIONS(2288),
    [anon_sym___stdcall] = ACTIONS(2288),
    [anon_sym___fastcall] = ACTIONS(2288),
    [anon_sym___thiscall] = ACTIONS(2288),
    [anon_sym___vectorcall] = ACTIONS(2288),
    [anon_sym_LBRACE] = ACTIONS(2290),
    [anon_sym_signed] = ACTIONS(2288),
    [anon_sym_unsigned] = ACTIONS(2288),
    [anon_sym_long] = ACTIONS(2288),
    [anon_sym_short] = ACTIONS(2288),
    [anon_sym_LBRACK] = ACTIONS(2288),
    [anon_sym_static] = ACTIONS(2288),
    [anon_sym_register] = ACTIONS(2288),
    [anon_sym_inline] = ACTIONS(2288),
    [anon_sym___inline] = ACTIONS(2288),
    [anon_sym___inline__] = ACTIONS(2288),
    [anon_sym___forceinline] = ACTIONS(2288),
    [anon_sym_thread_local] = ACTIONS(2288),
    [anon_sym___thread] = ACTIONS(2288),
    [anon_sym_const] = ACTIONS(2288),
    [anon_sym_constexpr] = ACTIONS(2288),
    [anon_sym_volatile] = ACTIONS(2288),
    [anon_sym_restrict] = ACTIONS(2288),
    [anon_sym___restrict__] = ACTIONS(2288),
    [anon_sym__Atomic] = ACTIONS(2288),
    [anon_sym__Noreturn] = ACTIONS(2288),
    [anon_sym_noreturn] = ACTIONS(2288),
    [anon_sym_mutable] = ACTIONS(2288),
    [anon_sym_constinit] = ACTIONS(2288),
    [anon_sym_consteval] = ACTIONS(2288),
    [anon_sym_alignas] = ACTIONS(2288),
    [anon_sym__Alignas] = ACTIONS(2288),
    [sym_primitive_type] = ACTIONS(2288),
    [anon_sym_enum] = ACTIONS(2288),
    [anon_sym_class] = ACTIONS(2288),
    [anon_sym_struct] = ACTIONS(2288),
    [anon_sym_union] = ACTIONS(2288),
    [anon_sym_if] = ACTIONS(2288),
    [anon_sym_else] = ACTIONS(2288),
    [anon_sym_switch] = ACTIONS(2288),
    [anon_sym_case] = ACTIONS(2288),
    [anon_sym_default] = ACTIONS(2288),
    [anon_sym_while] = ACTIONS(2288),
    [anon_sym_do] = ACTIONS(2288),
    [anon_sym_for] = ACTIONS(2288),
    [anon_sym_return] = ACTIONS(2288),
    [anon_sym_break] = ACTIONS(2288),
    [anon_sym_continue] = ACTIONS(2288),
    [anon_sym_goto] = ACTIONS(2288),
    [anon_sym___try] = ACTIONS(2288),
    [anon_sym___leave] = ACTIONS(2288),
    [anon_sym_not] = ACTIONS(2288),
    [anon_sym_compl] = ACTIONS(2288),
    [anon_sym_DASH_DASH] = ACTIONS(2290),
    [anon_sym_PLUS_PLUS] = ACTIONS(2290),
    [anon_sym_sizeof] = ACTIONS(2288),
    [anon_sym___alignof__] = ACTIONS(2288),
    [anon_sym___alignof] = ACTIONS(2288),
    [anon_sym__alignof] = ACTIONS(2288),
    [anon_sym_alignof] = ACTIONS(2288),
    [anon_sym__Alignof] = ACTIONS(2288),
    [anon_sym_offsetof] = ACTIONS(2288),
    [anon_sym__Generic] = ACTIONS(2288),
    [anon_sym_asm] = ACTIONS(2288),
    [anon_sym___asm__] = ACTIONS(2288),
    [sym_number_literal] = ACTIONS(2290),
    [anon_sym_L_SQUOTE] = ACTIONS(2290),
    [anon_sym_u_SQUOTE] = ACTIONS(2290),
    [anon_sym_U_SQUOTE] = ACTIONS(2290),
    [anon_sym_u8_SQUOTE] = ACTIONS(2290),
    [anon_sym_SQUOTE] = ACTIONS(2290),
    [anon_sym_L_DQUOTE] = ACTIONS(2290),
    [anon_sym_u_DQUOTE] = ACTIONS(2290),
    [anon_sym_U_DQUOTE] = ACTIONS(2290),
    [anon_sym_u8_DQUOTE] = ACTIONS(2290),
    [anon_sym_DQUOTE] = ACTIONS(2290),
    [sym_true] = ACTIONS(2288),
    [sym_false] = ACTIONS(2288),
    [anon_sym_NULL] = ACTIONS(2288),
    [anon_sym_nullptr] = ACTIONS(2288),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2288),
    [anon_sym_decltype] = ACTIONS(2288),
    [sym_virtual] = ACTIONS(2288),
    [anon_sym_explicit] = ACTIONS(2288),
    [anon_sym_typename] = ACTIONS(2288),
    [anon_sym_template] = ACTIONS(2288),
    [anon_sym_operator] = ACTIONS(2288),
    [anon_sym_try] = ACTIONS(2288),
    [anon_sym_delete] = ACTIONS(2288),
    [anon_sym_throw] = ACTIONS(2288),
    [anon_sym_namespace] = ACTIONS(2288),
    [anon_sym_using] = ACTIONS(2288),
    [anon_sym_static_assert] = ACTIONS(2288),
    [anon_sym_concept] = ACTIONS(2288),
    [anon_sym_co_return] = ACTIONS(2288),
    [anon_sym_co_yield] = ACTIONS(2288),
    [anon_sym_R_DQUOTE] = ACTIONS(2290),
    [anon_sym_LR_DQUOTE] = ACTIONS(2290),
    [anon_sym_uR_DQUOTE] = ACTIONS(2290),
    [anon_sym_UR_DQUOTE] = ACTIONS(2290),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2290),
    [anon_sym_co_await] = ACTIONS(2288),
    [anon_sym_new] = ACTIONS(2288),
    [anon_sym_requires] = ACTIONS(2288),
    [sym_this] = ACTIONS(2288),
    [anon_sym_discard] = ACTIONS(2288),
    [anon_sym_precise] = ACTIONS(2288),
    [anon_sym_shared] = ACTIONS(2288),
    [anon_sym_groupshared] = ACTIONS(2288),
    [anon_sym_uniform] = ACTIONS(2288),
    [anon_sym_row_major] = ACTIONS(2288),
    [anon_sym_column_major] = ACTIONS(2288),
    [anon_sym_globallycoherent] = ACTIONS(2288),
    [anon_sym_centroid] = ACTIONS(2288),
    [anon_sym_noperspective] = ACTIONS(2288),
    [anon_sym_nointerpolation] = ACTIONS(2288),
    [anon_sym_sample] = ACTIONS(2288),
    [anon_sym_linear] = ACTIONS(2288),
    [anon_sym_snorm] = ACTIONS(2288),
    [anon_sym_unorm] = ACTIONS(2288),
    [anon_sym_point] = ACTIONS(2288),
    [anon_sym_line] = ACTIONS(2288),
    [anon_sym_triangleadj] = ACTIONS(2288),
    [anon_sym_lineadj] = ACTIONS(2288),
    [anon_sym_triangle] = ACTIONS(2288),
    [anon_sym_cbuffer] = ACTIONS(2288),
  },
  [511] = {
    [ts_builtin_sym_end] = ACTIONS(2148),
    [sym_identifier] = ACTIONS(2146),
    [aux_sym_preproc_include_token1] = ACTIONS(2146),
    [aux_sym_preproc_def_token1] = ACTIONS(2146),
    [aux_sym_preproc_if_token1] = ACTIONS(2146),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2146),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2146),
    [sym_preproc_directive] = ACTIONS(2146),
    [anon_sym_LPAREN2] = ACTIONS(2148),
    [anon_sym_BANG] = ACTIONS(2148),
    [anon_sym_TILDE] = ACTIONS(2148),
    [anon_sym_DASH] = ACTIONS(2146),
    [anon_sym_PLUS] = ACTIONS(2146),
    [anon_sym_STAR] = ACTIONS(2148),
    [anon_sym_AMP_AMP] = ACTIONS(2148),
    [anon_sym_AMP] = ACTIONS(2146),
    [anon_sym_SEMI] = ACTIONS(2148),
    [anon_sym___extension__] = ACTIONS(2146),
    [anon_sym_typedef] = ACTIONS(2146),
    [anon_sym_in] = ACTIONS(2146),
    [anon_sym_out] = ACTIONS(2146),
    [anon_sym_inout] = ACTIONS(2146),
    [anon_sym_extern] = ACTIONS(2146),
    [anon_sym___attribute__] = ACTIONS(2146),
    [anon_sym_COLON_COLON] = ACTIONS(2148),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2148),
    [anon_sym___declspec] = ACTIONS(2146),
    [anon_sym___based] = ACTIONS(2146),
    [anon_sym___cdecl] = ACTIONS(2146),
    [anon_sym___clrcall] = ACTIONS(2146),
    [anon_sym___stdcall] = ACTIONS(2146),
    [anon_sym___fastcall] = ACTIONS(2146),
    [anon_sym___thiscall] = ACTIONS(2146),
    [anon_sym___vectorcall] = ACTIONS(2146),
    [anon_sym_LBRACE] = ACTIONS(2148),
    [anon_sym_signed] = ACTIONS(2146),
    [anon_sym_unsigned] = ACTIONS(2146),
    [anon_sym_long] = ACTIONS(2146),
    [anon_sym_short] = ACTIONS(2146),
    [anon_sym_LBRACK] = ACTIONS(2146),
    [anon_sym_static] = ACTIONS(2146),
    [anon_sym_register] = ACTIONS(2146),
    [anon_sym_inline] = ACTIONS(2146),
    [anon_sym___inline] = ACTIONS(2146),
    [anon_sym___inline__] = ACTIONS(2146),
    [anon_sym___forceinline] = ACTIONS(2146),
    [anon_sym_thread_local] = ACTIONS(2146),
    [anon_sym___thread] = ACTIONS(2146),
    [anon_sym_const] = ACTIONS(2146),
    [anon_sym_constexpr] = ACTIONS(2146),
    [anon_sym_volatile] = ACTIONS(2146),
    [anon_sym_restrict] = ACTIONS(2146),
    [anon_sym___restrict__] = ACTIONS(2146),
    [anon_sym__Atomic] = ACTIONS(2146),
    [anon_sym__Noreturn] = ACTIONS(2146),
    [anon_sym_noreturn] = ACTIONS(2146),
    [anon_sym_mutable] = ACTIONS(2146),
    [anon_sym_constinit] = ACTIONS(2146),
    [anon_sym_consteval] = ACTIONS(2146),
    [anon_sym_alignas] = ACTIONS(2146),
    [anon_sym__Alignas] = ACTIONS(2146),
    [sym_primitive_type] = ACTIONS(2146),
    [anon_sym_enum] = ACTIONS(2146),
    [anon_sym_class] = ACTIONS(2146),
    [anon_sym_struct] = ACTIONS(2146),
    [anon_sym_union] = ACTIONS(2146),
    [anon_sym_if] = ACTIONS(2146),
    [anon_sym_else] = ACTIONS(2146),
    [anon_sym_switch] = ACTIONS(2146),
    [anon_sym_case] = ACTIONS(2146),
    [anon_sym_default] = ACTIONS(2146),
    [anon_sym_while] = ACTIONS(2146),
    [anon_sym_do] = ACTIONS(2146),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_return] = ACTIONS(2146),
    [anon_sym_break] = ACTIONS(2146),
    [anon_sym_continue] = ACTIONS(2146),
    [anon_sym_goto] = ACTIONS(2146),
    [anon_sym___try] = ACTIONS(2146),
    [anon_sym___leave] = ACTIONS(2146),
    [anon_sym_not] = ACTIONS(2146),
    [anon_sym_compl] = ACTIONS(2146),
    [anon_sym_DASH_DASH] = ACTIONS(2148),
    [anon_sym_PLUS_PLUS] = ACTIONS(2148),
    [anon_sym_sizeof] = ACTIONS(2146),
    [anon_sym___alignof__] = ACTIONS(2146),
    [anon_sym___alignof] = ACTIONS(2146),
    [anon_sym__alignof] = ACTIONS(2146),
    [anon_sym_alignof] = ACTIONS(2146),
    [anon_sym__Alignof] = ACTIONS(2146),
    [anon_sym_offsetof] = ACTIONS(2146),
    [anon_sym__Generic] = ACTIONS(2146),
    [anon_sym_asm] = ACTIONS(2146),
    [anon_sym___asm__] = ACTIONS(2146),
    [sym_number_literal] = ACTIONS(2148),
    [anon_sym_L_SQUOTE] = ACTIONS(2148),
    [anon_sym_u_SQUOTE] = ACTIONS(2148),
    [anon_sym_U_SQUOTE] = ACTIONS(2148),
    [anon_sym_u8_SQUOTE] = ACTIONS(2148),
    [anon_sym_SQUOTE] = ACTIONS(2148),
    [anon_sym_L_DQUOTE] = ACTIONS(2148),
    [anon_sym_u_DQUOTE] = ACTIONS(2148),
    [anon_sym_U_DQUOTE] = ACTIONS(2148),
    [anon_sym_u8_DQUOTE] = ACTIONS(2148),
    [anon_sym_DQUOTE] = ACTIONS(2148),
    [sym_true] = ACTIONS(2146),
    [sym_false] = ACTIONS(2146),
    [anon_sym_NULL] = ACTIONS(2146),
    [anon_sym_nullptr] = ACTIONS(2146),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2146),
    [anon_sym_decltype] = ACTIONS(2146),
    [sym_virtual] = ACTIONS(2146),
    [anon_sym_explicit] = ACTIONS(2146),
    [anon_sym_typename] = ACTIONS(2146),
    [anon_sym_template] = ACTIONS(2146),
    [anon_sym_operator] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2146),
    [anon_sym_delete] = ACTIONS(2146),
    [anon_sym_throw] = ACTIONS(2146),
    [anon_sym_namespace] = ACTIONS(2146),
    [anon_sym_using] = ACTIONS(2146),
    [anon_sym_static_assert] = ACTIONS(2146),
    [anon_sym_concept] = ACTIONS(2146),
    [anon_sym_co_return] = ACTIONS(2146),
    [anon_sym_co_yield] = ACTIONS(2146),
    [anon_sym_R_DQUOTE] = ACTIONS(2148),
    [anon_sym_LR_DQUOTE] = ACTIONS(2148),
    [anon_sym_uR_DQUOTE] = ACTIONS(2148),
    [anon_sym_UR_DQUOTE] = ACTIONS(2148),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2148),
    [anon_sym_co_await] = ACTIONS(2146),
    [anon_sym_new] = ACTIONS(2146),
    [anon_sym_requires] = ACTIONS(2146),
    [sym_this] = ACTIONS(2146),
    [anon_sym_discard] = ACTIONS(2146),
    [anon_sym_precise] = ACTIONS(2146),
    [anon_sym_shared] = ACTIONS(2146),
    [anon_sym_groupshared] = ACTIONS(2146),
    [anon_sym_uniform] = ACTIONS(2146),
    [anon_sym_row_major] = ACTIONS(2146),
    [anon_sym_column_major] = ACTIONS(2146),
    [anon_sym_globallycoherent] = ACTIONS(2146),
    [anon_sym_centroid] = ACTIONS(2146),
    [anon_sym_noperspective] = ACTIONS(2146),
    [anon_sym_nointerpolation] = ACTIONS(2146),
    [anon_sym_sample] = ACTIONS(2146),
    [anon_sym_linear] = ACTIONS(2146),
    [anon_sym_snorm] = ACTIONS(2146),
    [anon_sym_unorm] = ACTIONS(2146),
    [anon_sym_point] = ACTIONS(2146),
    [anon_sym_line] = ACTIONS(2146),
    [anon_sym_triangleadj] = ACTIONS(2146),
    [anon_sym_lineadj] = ACTIONS(2146),
    [anon_sym_triangle] = ACTIONS(2146),
    [anon_sym_cbuffer] = ACTIONS(2146),
  },
  [512] = {
    [ts_builtin_sym_end] = ACTIONS(2168),
    [sym_identifier] = ACTIONS(2166),
    [aux_sym_preproc_include_token1] = ACTIONS(2166),
    [aux_sym_preproc_def_token1] = ACTIONS(2166),
    [aux_sym_preproc_if_token1] = ACTIONS(2166),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2166),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2166),
    [sym_preproc_directive] = ACTIONS(2166),
    [anon_sym_LPAREN2] = ACTIONS(2168),
    [anon_sym_BANG] = ACTIONS(2168),
    [anon_sym_TILDE] = ACTIONS(2168),
    [anon_sym_DASH] = ACTIONS(2166),
    [anon_sym_PLUS] = ACTIONS(2166),
    [anon_sym_STAR] = ACTIONS(2168),
    [anon_sym_AMP_AMP] = ACTIONS(2168),
    [anon_sym_AMP] = ACTIONS(2166),
    [anon_sym_SEMI] = ACTIONS(2168),
    [anon_sym___extension__] = ACTIONS(2166),
    [anon_sym_typedef] = ACTIONS(2166),
    [anon_sym_in] = ACTIONS(2166),
    [anon_sym_out] = ACTIONS(2166),
    [anon_sym_inout] = ACTIONS(2166),
    [anon_sym_extern] = ACTIONS(2166),
    [anon_sym___attribute__] = ACTIONS(2166),
    [anon_sym_COLON_COLON] = ACTIONS(2168),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2168),
    [anon_sym___declspec] = ACTIONS(2166),
    [anon_sym___based] = ACTIONS(2166),
    [anon_sym___cdecl] = ACTIONS(2166),
    [anon_sym___clrcall] = ACTIONS(2166),
    [anon_sym___stdcall] = ACTIONS(2166),
    [anon_sym___fastcall] = ACTIONS(2166),
    [anon_sym___thiscall] = ACTIONS(2166),
    [anon_sym___vectorcall] = ACTIONS(2166),
    [anon_sym_LBRACE] = ACTIONS(2168),
    [anon_sym_signed] = ACTIONS(2166),
    [anon_sym_unsigned] = ACTIONS(2166),
    [anon_sym_long] = ACTIONS(2166),
    [anon_sym_short] = ACTIONS(2166),
    [anon_sym_LBRACK] = ACTIONS(2166),
    [anon_sym_static] = ACTIONS(2166),
    [anon_sym_register] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(2166),
    [anon_sym___inline] = ACTIONS(2166),
    [anon_sym___inline__] = ACTIONS(2166),
    [anon_sym___forceinline] = ACTIONS(2166),
    [anon_sym_thread_local] = ACTIONS(2166),
    [anon_sym___thread] = ACTIONS(2166),
    [anon_sym_const] = ACTIONS(2166),
    [anon_sym_constexpr] = ACTIONS(2166),
    [anon_sym_volatile] = ACTIONS(2166),
    [anon_sym_restrict] = ACTIONS(2166),
    [anon_sym___restrict__] = ACTIONS(2166),
    [anon_sym__Atomic] = ACTIONS(2166),
    [anon_sym__Noreturn] = ACTIONS(2166),
    [anon_sym_noreturn] = ACTIONS(2166),
    [anon_sym_mutable] = ACTIONS(2166),
    [anon_sym_constinit] = ACTIONS(2166),
    [anon_sym_consteval] = ACTIONS(2166),
    [anon_sym_alignas] = ACTIONS(2166),
    [anon_sym__Alignas] = ACTIONS(2166),
    [sym_primitive_type] = ACTIONS(2166),
    [anon_sym_enum] = ACTIONS(2166),
    [anon_sym_class] = ACTIONS(2166),
    [anon_sym_struct] = ACTIONS(2166),
    [anon_sym_union] = ACTIONS(2166),
    [anon_sym_if] = ACTIONS(2166),
    [anon_sym_else] = ACTIONS(2166),
    [anon_sym_switch] = ACTIONS(2166),
    [anon_sym_case] = ACTIONS(2166),
    [anon_sym_default] = ACTIONS(2166),
    [anon_sym_while] = ACTIONS(2166),
    [anon_sym_do] = ACTIONS(2166),
    [anon_sym_for] = ACTIONS(2166),
    [anon_sym_return] = ACTIONS(2166),
    [anon_sym_break] = ACTIONS(2166),
    [anon_sym_continue] = ACTIONS(2166),
    [anon_sym_goto] = ACTIONS(2166),
    [anon_sym___try] = ACTIONS(2166),
    [anon_sym___leave] = ACTIONS(2166),
    [anon_sym_not] = ACTIONS(2166),
    [anon_sym_compl] = ACTIONS(2166),
    [anon_sym_DASH_DASH] = ACTIONS(2168),
    [anon_sym_PLUS_PLUS] = ACTIONS(2168),
    [anon_sym_sizeof] = ACTIONS(2166),
    [anon_sym___alignof__] = ACTIONS(2166),
    [anon_sym___alignof] = ACTIONS(2166),
    [anon_sym__alignof] = ACTIONS(2166),
    [anon_sym_alignof] = ACTIONS(2166),
    [anon_sym__Alignof] = ACTIONS(2166),
    [anon_sym_offsetof] = ACTIONS(2166),
    [anon_sym__Generic] = ACTIONS(2166),
    [anon_sym_asm] = ACTIONS(2166),
    [anon_sym___asm__] = ACTIONS(2166),
    [sym_number_literal] = ACTIONS(2168),
    [anon_sym_L_SQUOTE] = ACTIONS(2168),
    [anon_sym_u_SQUOTE] = ACTIONS(2168),
    [anon_sym_U_SQUOTE] = ACTIONS(2168),
    [anon_sym_u8_SQUOTE] = ACTIONS(2168),
    [anon_sym_SQUOTE] = ACTIONS(2168),
    [anon_sym_L_DQUOTE] = ACTIONS(2168),
    [anon_sym_u_DQUOTE] = ACTIONS(2168),
    [anon_sym_U_DQUOTE] = ACTIONS(2168),
    [anon_sym_u8_DQUOTE] = ACTIONS(2168),
    [anon_sym_DQUOTE] = ACTIONS(2168),
    [sym_true] = ACTIONS(2166),
    [sym_false] = ACTIONS(2166),
    [anon_sym_NULL] = ACTIONS(2166),
    [anon_sym_nullptr] = ACTIONS(2166),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2166),
    [anon_sym_decltype] = ACTIONS(2166),
    [sym_virtual] = ACTIONS(2166),
    [anon_sym_explicit] = ACTIONS(2166),
    [anon_sym_typename] = ACTIONS(2166),
    [anon_sym_template] = ACTIONS(2166),
    [anon_sym_operator] = ACTIONS(2166),
    [anon_sym_try] = ACTIONS(2166),
    [anon_sym_delete] = ACTIONS(2166),
    [anon_sym_throw] = ACTIONS(2166),
    [anon_sym_namespace] = ACTIONS(2166),
    [anon_sym_using] = ACTIONS(2166),
    [anon_sym_static_assert] = ACTIONS(2166),
    [anon_sym_concept] = ACTIONS(2166),
    [anon_sym_co_return] = ACTIONS(2166),
    [anon_sym_co_yield] = ACTIONS(2166),
    [anon_sym_R_DQUOTE] = ACTIONS(2168),
    [anon_sym_LR_DQUOTE] = ACTIONS(2168),
    [anon_sym_uR_DQUOTE] = ACTIONS(2168),
    [anon_sym_UR_DQUOTE] = ACTIONS(2168),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2168),
    [anon_sym_co_await] = ACTIONS(2166),
    [anon_sym_new] = ACTIONS(2166),
    [anon_sym_requires] = ACTIONS(2166),
    [sym_this] = ACTIONS(2166),
    [anon_sym_discard] = ACTIONS(2166),
    [anon_sym_precise] = ACTIONS(2166),
    [anon_sym_shared] = ACTIONS(2166),
    [anon_sym_groupshared] = ACTIONS(2166),
    [anon_sym_uniform] = ACTIONS(2166),
    [anon_sym_row_major] = ACTIONS(2166),
    [anon_sym_column_major] = ACTIONS(2166),
    [anon_sym_globallycoherent] = ACTIONS(2166),
    [anon_sym_centroid] = ACTIONS(2166),
    [anon_sym_noperspective] = ACTIONS(2166),
    [anon_sym_nointerpolation] = ACTIONS(2166),
    [anon_sym_sample] = ACTIONS(2166),
    [anon_sym_linear] = ACTIONS(2166),
    [anon_sym_snorm] = ACTIONS(2166),
    [anon_sym_unorm] = ACTIONS(2166),
    [anon_sym_point] = ACTIONS(2166),
    [anon_sym_line] = ACTIONS(2166),
    [anon_sym_triangleadj] = ACTIONS(2166),
    [anon_sym_lineadj] = ACTIONS(2166),
    [anon_sym_triangle] = ACTIONS(2166),
    [anon_sym_cbuffer] = ACTIONS(2166),
  },
  [513] = {
    [ts_builtin_sym_end] = ACTIONS(2172),
    [sym_identifier] = ACTIONS(2170),
    [aux_sym_preproc_include_token1] = ACTIONS(2170),
    [aux_sym_preproc_def_token1] = ACTIONS(2170),
    [aux_sym_preproc_if_token1] = ACTIONS(2170),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2170),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2170),
    [sym_preproc_directive] = ACTIONS(2170),
    [anon_sym_LPAREN2] = ACTIONS(2172),
    [anon_sym_BANG] = ACTIONS(2172),
    [anon_sym_TILDE] = ACTIONS(2172),
    [anon_sym_DASH] = ACTIONS(2170),
    [anon_sym_PLUS] = ACTIONS(2170),
    [anon_sym_STAR] = ACTIONS(2172),
    [anon_sym_AMP_AMP] = ACTIONS(2172),
    [anon_sym_AMP] = ACTIONS(2170),
    [anon_sym_SEMI] = ACTIONS(2172),
    [anon_sym___extension__] = ACTIONS(2170),
    [anon_sym_typedef] = ACTIONS(2170),
    [anon_sym_in] = ACTIONS(2170),
    [anon_sym_out] = ACTIONS(2170),
    [anon_sym_inout] = ACTIONS(2170),
    [anon_sym_extern] = ACTIONS(2170),
    [anon_sym___attribute__] = ACTIONS(2170),
    [anon_sym_COLON_COLON] = ACTIONS(2172),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2172),
    [anon_sym___declspec] = ACTIONS(2170),
    [anon_sym___based] = ACTIONS(2170),
    [anon_sym___cdecl] = ACTIONS(2170),
    [anon_sym___clrcall] = ACTIONS(2170),
    [anon_sym___stdcall] = ACTIONS(2170),
    [anon_sym___fastcall] = ACTIONS(2170),
    [anon_sym___thiscall] = ACTIONS(2170),
    [anon_sym___vectorcall] = ACTIONS(2170),
    [anon_sym_LBRACE] = ACTIONS(2172),
    [anon_sym_signed] = ACTIONS(2170),
    [anon_sym_unsigned] = ACTIONS(2170),
    [anon_sym_long] = ACTIONS(2170),
    [anon_sym_short] = ACTIONS(2170),
    [anon_sym_LBRACK] = ACTIONS(2170),
    [anon_sym_static] = ACTIONS(2170),
    [anon_sym_register] = ACTIONS(2170),
    [anon_sym_inline] = ACTIONS(2170),
    [anon_sym___inline] = ACTIONS(2170),
    [anon_sym___inline__] = ACTIONS(2170),
    [anon_sym___forceinline] = ACTIONS(2170),
    [anon_sym_thread_local] = ACTIONS(2170),
    [anon_sym___thread] = ACTIONS(2170),
    [anon_sym_const] = ACTIONS(2170),
    [anon_sym_constexpr] = ACTIONS(2170),
    [anon_sym_volatile] = ACTIONS(2170),
    [anon_sym_restrict] = ACTIONS(2170),
    [anon_sym___restrict__] = ACTIONS(2170),
    [anon_sym__Atomic] = ACTIONS(2170),
    [anon_sym__Noreturn] = ACTIONS(2170),
    [anon_sym_noreturn] = ACTIONS(2170),
    [anon_sym_mutable] = ACTIONS(2170),
    [anon_sym_constinit] = ACTIONS(2170),
    [anon_sym_consteval] = ACTIONS(2170),
    [anon_sym_alignas] = ACTIONS(2170),
    [anon_sym__Alignas] = ACTIONS(2170),
    [sym_primitive_type] = ACTIONS(2170),
    [anon_sym_enum] = ACTIONS(2170),
    [anon_sym_class] = ACTIONS(2170),
    [anon_sym_struct] = ACTIONS(2170),
    [anon_sym_union] = ACTIONS(2170),
    [anon_sym_if] = ACTIONS(2170),
    [anon_sym_else] = ACTIONS(2170),
    [anon_sym_switch] = ACTIONS(2170),
    [anon_sym_case] = ACTIONS(2170),
    [anon_sym_default] = ACTIONS(2170),
    [anon_sym_while] = ACTIONS(2170),
    [anon_sym_do] = ACTIONS(2170),
    [anon_sym_for] = ACTIONS(2170),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_break] = ACTIONS(2170),
    [anon_sym_continue] = ACTIONS(2170),
    [anon_sym_goto] = ACTIONS(2170),
    [anon_sym___try] = ACTIONS(2170),
    [anon_sym___leave] = ACTIONS(2170),
    [anon_sym_not] = ACTIONS(2170),
    [anon_sym_compl] = ACTIONS(2170),
    [anon_sym_DASH_DASH] = ACTIONS(2172),
    [anon_sym_PLUS_PLUS] = ACTIONS(2172),
    [anon_sym_sizeof] = ACTIONS(2170),
    [anon_sym___alignof__] = ACTIONS(2170),
    [anon_sym___alignof] = ACTIONS(2170),
    [anon_sym__alignof] = ACTIONS(2170),
    [anon_sym_alignof] = ACTIONS(2170),
    [anon_sym__Alignof] = ACTIONS(2170),
    [anon_sym_offsetof] = ACTIONS(2170),
    [anon_sym__Generic] = ACTIONS(2170),
    [anon_sym_asm] = ACTIONS(2170),
    [anon_sym___asm__] = ACTIONS(2170),
    [sym_number_literal] = ACTIONS(2172),
    [anon_sym_L_SQUOTE] = ACTIONS(2172),
    [anon_sym_u_SQUOTE] = ACTIONS(2172),
    [anon_sym_U_SQUOTE] = ACTIONS(2172),
    [anon_sym_u8_SQUOTE] = ACTIONS(2172),
    [anon_sym_SQUOTE] = ACTIONS(2172),
    [anon_sym_L_DQUOTE] = ACTIONS(2172),
    [anon_sym_u_DQUOTE] = ACTIONS(2172),
    [anon_sym_U_DQUOTE] = ACTIONS(2172),
    [anon_sym_u8_DQUOTE] = ACTIONS(2172),
    [anon_sym_DQUOTE] = ACTIONS(2172),
    [sym_true] = ACTIONS(2170),
    [sym_false] = ACTIONS(2170),
    [anon_sym_NULL] = ACTIONS(2170),
    [anon_sym_nullptr] = ACTIONS(2170),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2170),
    [anon_sym_decltype] = ACTIONS(2170),
    [sym_virtual] = ACTIONS(2170),
    [anon_sym_explicit] = ACTIONS(2170),
    [anon_sym_typename] = ACTIONS(2170),
    [anon_sym_template] = ACTIONS(2170),
    [anon_sym_operator] = ACTIONS(2170),
    [anon_sym_try] = ACTIONS(2170),
    [anon_sym_delete] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2170),
    [anon_sym_namespace] = ACTIONS(2170),
    [anon_sym_using] = ACTIONS(2170),
    [anon_sym_static_assert] = ACTIONS(2170),
    [anon_sym_concept] = ACTIONS(2170),
    [anon_sym_co_return] = ACTIONS(2170),
    [anon_sym_co_yield] = ACTIONS(2170),
    [anon_sym_R_DQUOTE] = ACTIONS(2172),
    [anon_sym_LR_DQUOTE] = ACTIONS(2172),
    [anon_sym_uR_DQUOTE] = ACTIONS(2172),
    [anon_sym_UR_DQUOTE] = ACTIONS(2172),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2172),
    [anon_sym_co_await] = ACTIONS(2170),
    [anon_sym_new] = ACTIONS(2170),
    [anon_sym_requires] = ACTIONS(2170),
    [sym_this] = ACTIONS(2170),
    [anon_sym_discard] = ACTIONS(2170),
    [anon_sym_precise] = ACTIONS(2170),
    [anon_sym_shared] = ACTIONS(2170),
    [anon_sym_groupshared] = ACTIONS(2170),
    [anon_sym_uniform] = ACTIONS(2170),
    [anon_sym_row_major] = ACTIONS(2170),
    [anon_sym_column_major] = ACTIONS(2170),
    [anon_sym_globallycoherent] = ACTIONS(2170),
    [anon_sym_centroid] = ACTIONS(2170),
    [anon_sym_noperspective] = ACTIONS(2170),
    [anon_sym_nointerpolation] = ACTIONS(2170),
    [anon_sym_sample] = ACTIONS(2170),
    [anon_sym_linear] = ACTIONS(2170),
    [anon_sym_snorm] = ACTIONS(2170),
    [anon_sym_unorm] = ACTIONS(2170),
    [anon_sym_point] = ACTIONS(2170),
    [anon_sym_line] = ACTIONS(2170),
    [anon_sym_triangleadj] = ACTIONS(2170),
    [anon_sym_lineadj] = ACTIONS(2170),
    [anon_sym_triangle] = ACTIONS(2170),
    [anon_sym_cbuffer] = ACTIONS(2170),
  },
  [514] = {
    [ts_builtin_sym_end] = ACTIONS(2246),
    [sym_identifier] = ACTIONS(2244),
    [aux_sym_preproc_include_token1] = ACTIONS(2244),
    [aux_sym_preproc_def_token1] = ACTIONS(2244),
    [aux_sym_preproc_if_token1] = ACTIONS(2244),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2244),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2244),
    [sym_preproc_directive] = ACTIONS(2244),
    [anon_sym_LPAREN2] = ACTIONS(2246),
    [anon_sym_BANG] = ACTIONS(2246),
    [anon_sym_TILDE] = ACTIONS(2246),
    [anon_sym_DASH] = ACTIONS(2244),
    [anon_sym_PLUS] = ACTIONS(2244),
    [anon_sym_STAR] = ACTIONS(2246),
    [anon_sym_AMP_AMP] = ACTIONS(2246),
    [anon_sym_AMP] = ACTIONS(2244),
    [anon_sym_SEMI] = ACTIONS(2246),
    [anon_sym___extension__] = ACTIONS(2244),
    [anon_sym_typedef] = ACTIONS(2244),
    [anon_sym_in] = ACTIONS(2244),
    [anon_sym_out] = ACTIONS(2244),
    [anon_sym_inout] = ACTIONS(2244),
    [anon_sym_extern] = ACTIONS(2244),
    [anon_sym___attribute__] = ACTIONS(2244),
    [anon_sym_COLON_COLON] = ACTIONS(2246),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2246),
    [anon_sym___declspec] = ACTIONS(2244),
    [anon_sym___based] = ACTIONS(2244),
    [anon_sym___cdecl] = ACTIONS(2244),
    [anon_sym___clrcall] = ACTIONS(2244),
    [anon_sym___stdcall] = ACTIONS(2244),
    [anon_sym___fastcall] = ACTIONS(2244),
    [anon_sym___thiscall] = ACTIONS(2244),
    [anon_sym___vectorcall] = ACTIONS(2244),
    [anon_sym_LBRACE] = ACTIONS(2246),
    [anon_sym_signed] = ACTIONS(2244),
    [anon_sym_unsigned] = ACTIONS(2244),
    [anon_sym_long] = ACTIONS(2244),
    [anon_sym_short] = ACTIONS(2244),
    [anon_sym_LBRACK] = ACTIONS(2244),
    [anon_sym_static] = ACTIONS(2244),
    [anon_sym_register] = ACTIONS(2244),
    [anon_sym_inline] = ACTIONS(2244),
    [anon_sym___inline] = ACTIONS(2244),
    [anon_sym___inline__] = ACTIONS(2244),
    [anon_sym___forceinline] = ACTIONS(2244),
    [anon_sym_thread_local] = ACTIONS(2244),
    [anon_sym___thread] = ACTIONS(2244),
    [anon_sym_const] = ACTIONS(2244),
    [anon_sym_constexpr] = ACTIONS(2244),
    [anon_sym_volatile] = ACTIONS(2244),
    [anon_sym_restrict] = ACTIONS(2244),
    [anon_sym___restrict__] = ACTIONS(2244),
    [anon_sym__Atomic] = ACTIONS(2244),
    [anon_sym__Noreturn] = ACTIONS(2244),
    [anon_sym_noreturn] = ACTIONS(2244),
    [anon_sym_mutable] = ACTIONS(2244),
    [anon_sym_constinit] = ACTIONS(2244),
    [anon_sym_consteval] = ACTIONS(2244),
    [anon_sym_alignas] = ACTIONS(2244),
    [anon_sym__Alignas] = ACTIONS(2244),
    [sym_primitive_type] = ACTIONS(2244),
    [anon_sym_enum] = ACTIONS(2244),
    [anon_sym_class] = ACTIONS(2244),
    [anon_sym_struct] = ACTIONS(2244),
    [anon_sym_union] = ACTIONS(2244),
    [anon_sym_if] = ACTIONS(2244),
    [anon_sym_else] = ACTIONS(2244),
    [anon_sym_switch] = ACTIONS(2244),
    [anon_sym_case] = ACTIONS(2244),
    [anon_sym_default] = ACTIONS(2244),
    [anon_sym_while] = ACTIONS(2244),
    [anon_sym_do] = ACTIONS(2244),
    [anon_sym_for] = ACTIONS(2244),
    [anon_sym_return] = ACTIONS(2244),
    [anon_sym_break] = ACTIONS(2244),
    [anon_sym_continue] = ACTIONS(2244),
    [anon_sym_goto] = ACTIONS(2244),
    [anon_sym___try] = ACTIONS(2244),
    [anon_sym___leave] = ACTIONS(2244),
    [anon_sym_not] = ACTIONS(2244),
    [anon_sym_compl] = ACTIONS(2244),
    [anon_sym_DASH_DASH] = ACTIONS(2246),
    [anon_sym_PLUS_PLUS] = ACTIONS(2246),
    [anon_sym_sizeof] = ACTIONS(2244),
    [anon_sym___alignof__] = ACTIONS(2244),
    [anon_sym___alignof] = ACTIONS(2244),
    [anon_sym__alignof] = ACTIONS(2244),
    [anon_sym_alignof] = ACTIONS(2244),
    [anon_sym__Alignof] = ACTIONS(2244),
    [anon_sym_offsetof] = ACTIONS(2244),
    [anon_sym__Generic] = ACTIONS(2244),
    [anon_sym_asm] = ACTIONS(2244),
    [anon_sym___asm__] = ACTIONS(2244),
    [sym_number_literal] = ACTIONS(2246),
    [anon_sym_L_SQUOTE] = ACTIONS(2246),
    [anon_sym_u_SQUOTE] = ACTIONS(2246),
    [anon_sym_U_SQUOTE] = ACTIONS(2246),
    [anon_sym_u8_SQUOTE] = ACTIONS(2246),
    [anon_sym_SQUOTE] = ACTIONS(2246),
    [anon_sym_L_DQUOTE] = ACTIONS(2246),
    [anon_sym_u_DQUOTE] = ACTIONS(2246),
    [anon_sym_U_DQUOTE] = ACTIONS(2246),
    [anon_sym_u8_DQUOTE] = ACTIONS(2246),
    [anon_sym_DQUOTE] = ACTIONS(2246),
    [sym_true] = ACTIONS(2244),
    [sym_false] = ACTIONS(2244),
    [anon_sym_NULL] = ACTIONS(2244),
    [anon_sym_nullptr] = ACTIONS(2244),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2244),
    [anon_sym_decltype] = ACTIONS(2244),
    [sym_virtual] = ACTIONS(2244),
    [anon_sym_explicit] = ACTIONS(2244),
    [anon_sym_typename] = ACTIONS(2244),
    [anon_sym_template] = ACTIONS(2244),
    [anon_sym_operator] = ACTIONS(2244),
    [anon_sym_try] = ACTIONS(2244),
    [anon_sym_delete] = ACTIONS(2244),
    [anon_sym_throw] = ACTIONS(2244),
    [anon_sym_namespace] = ACTIONS(2244),
    [anon_sym_using] = ACTIONS(2244),
    [anon_sym_static_assert] = ACTIONS(2244),
    [anon_sym_concept] = ACTIONS(2244),
    [anon_sym_co_return] = ACTIONS(2244),
    [anon_sym_co_yield] = ACTIONS(2244),
    [anon_sym_R_DQUOTE] = ACTIONS(2246),
    [anon_sym_LR_DQUOTE] = ACTIONS(2246),
    [anon_sym_uR_DQUOTE] = ACTIONS(2246),
    [anon_sym_UR_DQUOTE] = ACTIONS(2246),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2246),
    [anon_sym_co_await] = ACTIONS(2244),
    [anon_sym_new] = ACTIONS(2244),
    [anon_sym_requires] = ACTIONS(2244),
    [sym_this] = ACTIONS(2244),
    [anon_sym_discard] = ACTIONS(2244),
    [anon_sym_precise] = ACTIONS(2244),
    [anon_sym_shared] = ACTIONS(2244),
    [anon_sym_groupshared] = ACTIONS(2244),
    [anon_sym_uniform] = ACTIONS(2244),
    [anon_sym_row_major] = ACTIONS(2244),
    [anon_sym_column_major] = ACTIONS(2244),
    [anon_sym_globallycoherent] = ACTIONS(2244),
    [anon_sym_centroid] = ACTIONS(2244),
    [anon_sym_noperspective] = ACTIONS(2244),
    [anon_sym_nointerpolation] = ACTIONS(2244),
    [anon_sym_sample] = ACTIONS(2244),
    [anon_sym_linear] = ACTIONS(2244),
    [anon_sym_snorm] = ACTIONS(2244),
    [anon_sym_unorm] = ACTIONS(2244),
    [anon_sym_point] = ACTIONS(2244),
    [anon_sym_line] = ACTIONS(2244),
    [anon_sym_triangleadj] = ACTIONS(2244),
    [anon_sym_lineadj] = ACTIONS(2244),
    [anon_sym_triangle] = ACTIONS(2244),
    [anon_sym_cbuffer] = ACTIONS(2244),
  },
  [515] = {
    [ts_builtin_sym_end] = ACTIONS(2242),
    [sym_identifier] = ACTIONS(2240),
    [aux_sym_preproc_include_token1] = ACTIONS(2240),
    [aux_sym_preproc_def_token1] = ACTIONS(2240),
    [aux_sym_preproc_if_token1] = ACTIONS(2240),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2240),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2240),
    [sym_preproc_directive] = ACTIONS(2240),
    [anon_sym_LPAREN2] = ACTIONS(2242),
    [anon_sym_BANG] = ACTIONS(2242),
    [anon_sym_TILDE] = ACTIONS(2242),
    [anon_sym_DASH] = ACTIONS(2240),
    [anon_sym_PLUS] = ACTIONS(2240),
    [anon_sym_STAR] = ACTIONS(2242),
    [anon_sym_AMP_AMP] = ACTIONS(2242),
    [anon_sym_AMP] = ACTIONS(2240),
    [anon_sym_SEMI] = ACTIONS(2242),
    [anon_sym___extension__] = ACTIONS(2240),
    [anon_sym_typedef] = ACTIONS(2240),
    [anon_sym_in] = ACTIONS(2240),
    [anon_sym_out] = ACTIONS(2240),
    [anon_sym_inout] = ACTIONS(2240),
    [anon_sym_extern] = ACTIONS(2240),
    [anon_sym___attribute__] = ACTIONS(2240),
    [anon_sym_COLON_COLON] = ACTIONS(2242),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2242),
    [anon_sym___declspec] = ACTIONS(2240),
    [anon_sym___based] = ACTIONS(2240),
    [anon_sym___cdecl] = ACTIONS(2240),
    [anon_sym___clrcall] = ACTIONS(2240),
    [anon_sym___stdcall] = ACTIONS(2240),
    [anon_sym___fastcall] = ACTIONS(2240),
    [anon_sym___thiscall] = ACTIONS(2240),
    [anon_sym___vectorcall] = ACTIONS(2240),
    [anon_sym_LBRACE] = ACTIONS(2242),
    [anon_sym_signed] = ACTIONS(2240),
    [anon_sym_unsigned] = ACTIONS(2240),
    [anon_sym_long] = ACTIONS(2240),
    [anon_sym_short] = ACTIONS(2240),
    [anon_sym_LBRACK] = ACTIONS(2240),
    [anon_sym_static] = ACTIONS(2240),
    [anon_sym_register] = ACTIONS(2240),
    [anon_sym_inline] = ACTIONS(2240),
    [anon_sym___inline] = ACTIONS(2240),
    [anon_sym___inline__] = ACTIONS(2240),
    [anon_sym___forceinline] = ACTIONS(2240),
    [anon_sym_thread_local] = ACTIONS(2240),
    [anon_sym___thread] = ACTIONS(2240),
    [anon_sym_const] = ACTIONS(2240),
    [anon_sym_constexpr] = ACTIONS(2240),
    [anon_sym_volatile] = ACTIONS(2240),
    [anon_sym_restrict] = ACTIONS(2240),
    [anon_sym___restrict__] = ACTIONS(2240),
    [anon_sym__Atomic] = ACTIONS(2240),
    [anon_sym__Noreturn] = ACTIONS(2240),
    [anon_sym_noreturn] = ACTIONS(2240),
    [anon_sym_mutable] = ACTIONS(2240),
    [anon_sym_constinit] = ACTIONS(2240),
    [anon_sym_consteval] = ACTIONS(2240),
    [anon_sym_alignas] = ACTIONS(2240),
    [anon_sym__Alignas] = ACTIONS(2240),
    [sym_primitive_type] = ACTIONS(2240),
    [anon_sym_enum] = ACTIONS(2240),
    [anon_sym_class] = ACTIONS(2240),
    [anon_sym_struct] = ACTIONS(2240),
    [anon_sym_union] = ACTIONS(2240),
    [anon_sym_if] = ACTIONS(2240),
    [anon_sym_else] = ACTIONS(2240),
    [anon_sym_switch] = ACTIONS(2240),
    [anon_sym_case] = ACTIONS(2240),
    [anon_sym_default] = ACTIONS(2240),
    [anon_sym_while] = ACTIONS(2240),
    [anon_sym_do] = ACTIONS(2240),
    [anon_sym_for] = ACTIONS(2240),
    [anon_sym_return] = ACTIONS(2240),
    [anon_sym_break] = ACTIONS(2240),
    [anon_sym_continue] = ACTIONS(2240),
    [anon_sym_goto] = ACTIONS(2240),
    [anon_sym___try] = ACTIONS(2240),
    [anon_sym___leave] = ACTIONS(2240),
    [anon_sym_not] = ACTIONS(2240),
    [anon_sym_compl] = ACTIONS(2240),
    [anon_sym_DASH_DASH] = ACTIONS(2242),
    [anon_sym_PLUS_PLUS] = ACTIONS(2242),
    [anon_sym_sizeof] = ACTIONS(2240),
    [anon_sym___alignof__] = ACTIONS(2240),
    [anon_sym___alignof] = ACTIONS(2240),
    [anon_sym__alignof] = ACTIONS(2240),
    [anon_sym_alignof] = ACTIONS(2240),
    [anon_sym__Alignof] = ACTIONS(2240),
    [anon_sym_offsetof] = ACTIONS(2240),
    [anon_sym__Generic] = ACTIONS(2240),
    [anon_sym_asm] = ACTIONS(2240),
    [anon_sym___asm__] = ACTIONS(2240),
    [sym_number_literal] = ACTIONS(2242),
    [anon_sym_L_SQUOTE] = ACTIONS(2242),
    [anon_sym_u_SQUOTE] = ACTIONS(2242),
    [anon_sym_U_SQUOTE] = ACTIONS(2242),
    [anon_sym_u8_SQUOTE] = ACTIONS(2242),
    [anon_sym_SQUOTE] = ACTIONS(2242),
    [anon_sym_L_DQUOTE] = ACTIONS(2242),
    [anon_sym_u_DQUOTE] = ACTIONS(2242),
    [anon_sym_U_DQUOTE] = ACTIONS(2242),
    [anon_sym_u8_DQUOTE] = ACTIONS(2242),
    [anon_sym_DQUOTE] = ACTIONS(2242),
    [sym_true] = ACTIONS(2240),
    [sym_false] = ACTIONS(2240),
    [anon_sym_NULL] = ACTIONS(2240),
    [anon_sym_nullptr] = ACTIONS(2240),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2240),
    [anon_sym_decltype] = ACTIONS(2240),
    [sym_virtual] = ACTIONS(2240),
    [anon_sym_explicit] = ACTIONS(2240),
    [anon_sym_typename] = ACTIONS(2240),
    [anon_sym_template] = ACTIONS(2240),
    [anon_sym_operator] = ACTIONS(2240),
    [anon_sym_try] = ACTIONS(2240),
    [anon_sym_delete] = ACTIONS(2240),
    [anon_sym_throw] = ACTIONS(2240),
    [anon_sym_namespace] = ACTIONS(2240),
    [anon_sym_using] = ACTIONS(2240),
    [anon_sym_static_assert] = ACTIONS(2240),
    [anon_sym_concept] = ACTIONS(2240),
    [anon_sym_co_return] = ACTIONS(2240),
    [anon_sym_co_yield] = ACTIONS(2240),
    [anon_sym_R_DQUOTE] = ACTIONS(2242),
    [anon_sym_LR_DQUOTE] = ACTIONS(2242),
    [anon_sym_uR_DQUOTE] = ACTIONS(2242),
    [anon_sym_UR_DQUOTE] = ACTIONS(2242),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2242),
    [anon_sym_co_await] = ACTIONS(2240),
    [anon_sym_new] = ACTIONS(2240),
    [anon_sym_requires] = ACTIONS(2240),
    [sym_this] = ACTIONS(2240),
    [anon_sym_discard] = ACTIONS(2240),
    [anon_sym_precise] = ACTIONS(2240),
    [anon_sym_shared] = ACTIONS(2240),
    [anon_sym_groupshared] = ACTIONS(2240),
    [anon_sym_uniform] = ACTIONS(2240),
    [anon_sym_row_major] = ACTIONS(2240),
    [anon_sym_column_major] = ACTIONS(2240),
    [anon_sym_globallycoherent] = ACTIONS(2240),
    [anon_sym_centroid] = ACTIONS(2240),
    [anon_sym_noperspective] = ACTIONS(2240),
    [anon_sym_nointerpolation] = ACTIONS(2240),
    [anon_sym_sample] = ACTIONS(2240),
    [anon_sym_linear] = ACTIONS(2240),
    [anon_sym_snorm] = ACTIONS(2240),
    [anon_sym_unorm] = ACTIONS(2240),
    [anon_sym_point] = ACTIONS(2240),
    [anon_sym_line] = ACTIONS(2240),
    [anon_sym_triangleadj] = ACTIONS(2240),
    [anon_sym_lineadj] = ACTIONS(2240),
    [anon_sym_triangle] = ACTIONS(2240),
    [anon_sym_cbuffer] = ACTIONS(2240),
  },
  [516] = {
    [ts_builtin_sym_end] = ACTIONS(2176),
    [sym_identifier] = ACTIONS(2174),
    [aux_sym_preproc_include_token1] = ACTIONS(2174),
    [aux_sym_preproc_def_token1] = ACTIONS(2174),
    [aux_sym_preproc_if_token1] = ACTIONS(2174),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2174),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2174),
    [sym_preproc_directive] = ACTIONS(2174),
    [anon_sym_LPAREN2] = ACTIONS(2176),
    [anon_sym_BANG] = ACTIONS(2176),
    [anon_sym_TILDE] = ACTIONS(2176),
    [anon_sym_DASH] = ACTIONS(2174),
    [anon_sym_PLUS] = ACTIONS(2174),
    [anon_sym_STAR] = ACTIONS(2176),
    [anon_sym_AMP_AMP] = ACTIONS(2176),
    [anon_sym_AMP] = ACTIONS(2174),
    [anon_sym_SEMI] = ACTIONS(2176),
    [anon_sym___extension__] = ACTIONS(2174),
    [anon_sym_typedef] = ACTIONS(2174),
    [anon_sym_in] = ACTIONS(2174),
    [anon_sym_out] = ACTIONS(2174),
    [anon_sym_inout] = ACTIONS(2174),
    [anon_sym_extern] = ACTIONS(2174),
    [anon_sym___attribute__] = ACTIONS(2174),
    [anon_sym_COLON_COLON] = ACTIONS(2176),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2176),
    [anon_sym___declspec] = ACTIONS(2174),
    [anon_sym___based] = ACTIONS(2174),
    [anon_sym___cdecl] = ACTIONS(2174),
    [anon_sym___clrcall] = ACTIONS(2174),
    [anon_sym___stdcall] = ACTIONS(2174),
    [anon_sym___fastcall] = ACTIONS(2174),
    [anon_sym___thiscall] = ACTIONS(2174),
    [anon_sym___vectorcall] = ACTIONS(2174),
    [anon_sym_LBRACE] = ACTIONS(2176),
    [anon_sym_signed] = ACTIONS(2174),
    [anon_sym_unsigned] = ACTIONS(2174),
    [anon_sym_long] = ACTIONS(2174),
    [anon_sym_short] = ACTIONS(2174),
    [anon_sym_LBRACK] = ACTIONS(2174),
    [anon_sym_static] = ACTIONS(2174),
    [anon_sym_register] = ACTIONS(2174),
    [anon_sym_inline] = ACTIONS(2174),
    [anon_sym___inline] = ACTIONS(2174),
    [anon_sym___inline__] = ACTIONS(2174),
    [anon_sym___forceinline] = ACTIONS(2174),
    [anon_sym_thread_local] = ACTIONS(2174),
    [anon_sym___thread] = ACTIONS(2174),
    [anon_sym_const] = ACTIONS(2174),
    [anon_sym_constexpr] = ACTIONS(2174),
    [anon_sym_volatile] = ACTIONS(2174),
    [anon_sym_restrict] = ACTIONS(2174),
    [anon_sym___restrict__] = ACTIONS(2174),
    [anon_sym__Atomic] = ACTIONS(2174),
    [anon_sym__Noreturn] = ACTIONS(2174),
    [anon_sym_noreturn] = ACTIONS(2174),
    [anon_sym_mutable] = ACTIONS(2174),
    [anon_sym_constinit] = ACTIONS(2174),
    [anon_sym_consteval] = ACTIONS(2174),
    [anon_sym_alignas] = ACTIONS(2174),
    [anon_sym__Alignas] = ACTIONS(2174),
    [sym_primitive_type] = ACTIONS(2174),
    [anon_sym_enum] = ACTIONS(2174),
    [anon_sym_class] = ACTIONS(2174),
    [anon_sym_struct] = ACTIONS(2174),
    [anon_sym_union] = ACTIONS(2174),
    [anon_sym_if] = ACTIONS(2174),
    [anon_sym_else] = ACTIONS(2174),
    [anon_sym_switch] = ACTIONS(2174),
    [anon_sym_case] = ACTIONS(2174),
    [anon_sym_default] = ACTIONS(2174),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_do] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2174),
    [anon_sym_return] = ACTIONS(2174),
    [anon_sym_break] = ACTIONS(2174),
    [anon_sym_continue] = ACTIONS(2174),
    [anon_sym_goto] = ACTIONS(2174),
    [anon_sym___try] = ACTIONS(2174),
    [anon_sym___leave] = ACTIONS(2174),
    [anon_sym_not] = ACTIONS(2174),
    [anon_sym_compl] = ACTIONS(2174),
    [anon_sym_DASH_DASH] = ACTIONS(2176),
    [anon_sym_PLUS_PLUS] = ACTIONS(2176),
    [anon_sym_sizeof] = ACTIONS(2174),
    [anon_sym___alignof__] = ACTIONS(2174),
    [anon_sym___alignof] = ACTIONS(2174),
    [anon_sym__alignof] = ACTIONS(2174),
    [anon_sym_alignof] = ACTIONS(2174),
    [anon_sym__Alignof] = ACTIONS(2174),
    [anon_sym_offsetof] = ACTIONS(2174),
    [anon_sym__Generic] = ACTIONS(2174),
    [anon_sym_asm] = ACTIONS(2174),
    [anon_sym___asm__] = ACTIONS(2174),
    [sym_number_literal] = ACTIONS(2176),
    [anon_sym_L_SQUOTE] = ACTIONS(2176),
    [anon_sym_u_SQUOTE] = ACTIONS(2176),
    [anon_sym_U_SQUOTE] = ACTIONS(2176),
    [anon_sym_u8_SQUOTE] = ACTIONS(2176),
    [anon_sym_SQUOTE] = ACTIONS(2176),
    [anon_sym_L_DQUOTE] = ACTIONS(2176),
    [anon_sym_u_DQUOTE] = ACTIONS(2176),
    [anon_sym_U_DQUOTE] = ACTIONS(2176),
    [anon_sym_u8_DQUOTE] = ACTIONS(2176),
    [anon_sym_DQUOTE] = ACTIONS(2176),
    [sym_true] = ACTIONS(2174),
    [sym_false] = ACTIONS(2174),
    [anon_sym_NULL] = ACTIONS(2174),
    [anon_sym_nullptr] = ACTIONS(2174),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2174),
    [anon_sym_decltype] = ACTIONS(2174),
    [sym_virtual] = ACTIONS(2174),
    [anon_sym_explicit] = ACTIONS(2174),
    [anon_sym_typename] = ACTIONS(2174),
    [anon_sym_template] = ACTIONS(2174),
    [anon_sym_operator] = ACTIONS(2174),
    [anon_sym_try] = ACTIONS(2174),
    [anon_sym_delete] = ACTIONS(2174),
    [anon_sym_throw] = ACTIONS(2174),
    [anon_sym_namespace] = ACTIONS(2174),
    [anon_sym_using] = ACTIONS(2174),
    [anon_sym_static_assert] = ACTIONS(2174),
    [anon_sym_concept] = ACTIONS(2174),
    [anon_sym_co_return] = ACTIONS(2174),
    [anon_sym_co_yield] = ACTIONS(2174),
    [anon_sym_R_DQUOTE] = ACTIONS(2176),
    [anon_sym_LR_DQUOTE] = ACTIONS(2176),
    [anon_sym_uR_DQUOTE] = ACTIONS(2176),
    [anon_sym_UR_DQUOTE] = ACTIONS(2176),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2176),
    [anon_sym_co_await] = ACTIONS(2174),
    [anon_sym_new] = ACTIONS(2174),
    [anon_sym_requires] = ACTIONS(2174),
    [sym_this] = ACTIONS(2174),
    [anon_sym_discard] = ACTIONS(2174),
    [anon_sym_precise] = ACTIONS(2174),
    [anon_sym_shared] = ACTIONS(2174),
    [anon_sym_groupshared] = ACTIONS(2174),
    [anon_sym_uniform] = ACTIONS(2174),
    [anon_sym_row_major] = ACTIONS(2174),
    [anon_sym_column_major] = ACTIONS(2174),
    [anon_sym_globallycoherent] = ACTIONS(2174),
    [anon_sym_centroid] = ACTIONS(2174),
    [anon_sym_noperspective] = ACTIONS(2174),
    [anon_sym_nointerpolation] = ACTIONS(2174),
    [anon_sym_sample] = ACTIONS(2174),
    [anon_sym_linear] = ACTIONS(2174),
    [anon_sym_snorm] = ACTIONS(2174),
    [anon_sym_unorm] = ACTIONS(2174),
    [anon_sym_point] = ACTIONS(2174),
    [anon_sym_line] = ACTIONS(2174),
    [anon_sym_triangleadj] = ACTIONS(2174),
    [anon_sym_lineadj] = ACTIONS(2174),
    [anon_sym_triangle] = ACTIONS(2174),
    [anon_sym_cbuffer] = ACTIONS(2174),
  },
  [517] = {
    [sym_identifier] = ACTIONS(2186),
    [aux_sym_preproc_include_token1] = ACTIONS(2186),
    [aux_sym_preproc_def_token1] = ACTIONS(2186),
    [aux_sym_preproc_if_token1] = ACTIONS(2186),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2186),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2186),
    [sym_preproc_directive] = ACTIONS(2186),
    [anon_sym_LPAREN2] = ACTIONS(2188),
    [anon_sym_BANG] = ACTIONS(2188),
    [anon_sym_TILDE] = ACTIONS(2188),
    [anon_sym_DASH] = ACTIONS(2186),
    [anon_sym_PLUS] = ACTIONS(2186),
    [anon_sym_STAR] = ACTIONS(2188),
    [anon_sym_AMP_AMP] = ACTIONS(2188),
    [anon_sym_AMP] = ACTIONS(2186),
    [anon_sym_SEMI] = ACTIONS(2188),
    [anon_sym___extension__] = ACTIONS(2186),
    [anon_sym_typedef] = ACTIONS(2186),
    [anon_sym_in] = ACTIONS(2186),
    [anon_sym_out] = ACTIONS(2186),
    [anon_sym_inout] = ACTIONS(2186),
    [anon_sym_extern] = ACTIONS(2186),
    [anon_sym___attribute__] = ACTIONS(2186),
    [anon_sym_COLON_COLON] = ACTIONS(2188),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2188),
    [anon_sym___declspec] = ACTIONS(2186),
    [anon_sym___based] = ACTIONS(2186),
    [anon_sym___cdecl] = ACTIONS(2186),
    [anon_sym___clrcall] = ACTIONS(2186),
    [anon_sym___stdcall] = ACTIONS(2186),
    [anon_sym___fastcall] = ACTIONS(2186),
    [anon_sym___thiscall] = ACTIONS(2186),
    [anon_sym___vectorcall] = ACTIONS(2186),
    [anon_sym_LBRACE] = ACTIONS(2188),
    [anon_sym_RBRACE] = ACTIONS(2188),
    [anon_sym_signed] = ACTIONS(2186),
    [anon_sym_unsigned] = ACTIONS(2186),
    [anon_sym_long] = ACTIONS(2186),
    [anon_sym_short] = ACTIONS(2186),
    [anon_sym_LBRACK] = ACTIONS(2186),
    [anon_sym_static] = ACTIONS(2186),
    [anon_sym_register] = ACTIONS(2186),
    [anon_sym_inline] = ACTIONS(2186),
    [anon_sym___inline] = ACTIONS(2186),
    [anon_sym___inline__] = ACTIONS(2186),
    [anon_sym___forceinline] = ACTIONS(2186),
    [anon_sym_thread_local] = ACTIONS(2186),
    [anon_sym___thread] = ACTIONS(2186),
    [anon_sym_const] = ACTIONS(2186),
    [anon_sym_constexpr] = ACTIONS(2186),
    [anon_sym_volatile] = ACTIONS(2186),
    [anon_sym_restrict] = ACTIONS(2186),
    [anon_sym___restrict__] = ACTIONS(2186),
    [anon_sym__Atomic] = ACTIONS(2186),
    [anon_sym__Noreturn] = ACTIONS(2186),
    [anon_sym_noreturn] = ACTIONS(2186),
    [anon_sym_mutable] = ACTIONS(2186),
    [anon_sym_constinit] = ACTIONS(2186),
    [anon_sym_consteval] = ACTIONS(2186),
    [anon_sym_alignas] = ACTIONS(2186),
    [anon_sym__Alignas] = ACTIONS(2186),
    [sym_primitive_type] = ACTIONS(2186),
    [anon_sym_enum] = ACTIONS(2186),
    [anon_sym_class] = ACTIONS(2186),
    [anon_sym_struct] = ACTIONS(2186),
    [anon_sym_union] = ACTIONS(2186),
    [anon_sym_if] = ACTIONS(2186),
    [anon_sym_else] = ACTIONS(2186),
    [anon_sym_switch] = ACTIONS(2186),
    [anon_sym_case] = ACTIONS(2186),
    [anon_sym_default] = ACTIONS(2186),
    [anon_sym_while] = ACTIONS(2186),
    [anon_sym_do] = ACTIONS(2186),
    [anon_sym_for] = ACTIONS(2186),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_break] = ACTIONS(2186),
    [anon_sym_continue] = ACTIONS(2186),
    [anon_sym_goto] = ACTIONS(2186),
    [anon_sym___try] = ACTIONS(2186),
    [anon_sym___leave] = ACTIONS(2186),
    [anon_sym_not] = ACTIONS(2186),
    [anon_sym_compl] = ACTIONS(2186),
    [anon_sym_DASH_DASH] = ACTIONS(2188),
    [anon_sym_PLUS_PLUS] = ACTIONS(2188),
    [anon_sym_sizeof] = ACTIONS(2186),
    [anon_sym___alignof__] = ACTIONS(2186),
    [anon_sym___alignof] = ACTIONS(2186),
    [anon_sym__alignof] = ACTIONS(2186),
    [anon_sym_alignof] = ACTIONS(2186),
    [anon_sym__Alignof] = ACTIONS(2186),
    [anon_sym_offsetof] = ACTIONS(2186),
    [anon_sym__Generic] = ACTIONS(2186),
    [anon_sym_asm] = ACTIONS(2186),
    [anon_sym___asm__] = ACTIONS(2186),
    [sym_number_literal] = ACTIONS(2188),
    [anon_sym_L_SQUOTE] = ACTIONS(2188),
    [anon_sym_u_SQUOTE] = ACTIONS(2188),
    [anon_sym_U_SQUOTE] = ACTIONS(2188),
    [anon_sym_u8_SQUOTE] = ACTIONS(2188),
    [anon_sym_SQUOTE] = ACTIONS(2188),
    [anon_sym_L_DQUOTE] = ACTIONS(2188),
    [anon_sym_u_DQUOTE] = ACTIONS(2188),
    [anon_sym_U_DQUOTE] = ACTIONS(2188),
    [anon_sym_u8_DQUOTE] = ACTIONS(2188),
    [anon_sym_DQUOTE] = ACTIONS(2188),
    [sym_true] = ACTIONS(2186),
    [sym_false] = ACTIONS(2186),
    [anon_sym_NULL] = ACTIONS(2186),
    [anon_sym_nullptr] = ACTIONS(2186),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2186),
    [anon_sym_decltype] = ACTIONS(2186),
    [sym_virtual] = ACTIONS(2186),
    [anon_sym_explicit] = ACTIONS(2186),
    [anon_sym_typename] = ACTIONS(2186),
    [anon_sym_template] = ACTIONS(2186),
    [anon_sym_operator] = ACTIONS(2186),
    [anon_sym_try] = ACTIONS(2186),
    [anon_sym_delete] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2186),
    [anon_sym_namespace] = ACTIONS(2186),
    [anon_sym_using] = ACTIONS(2186),
    [anon_sym_static_assert] = ACTIONS(2186),
    [anon_sym_concept] = ACTIONS(2186),
    [anon_sym_co_return] = ACTIONS(2186),
    [anon_sym_co_yield] = ACTIONS(2186),
    [anon_sym_R_DQUOTE] = ACTIONS(2188),
    [anon_sym_LR_DQUOTE] = ACTIONS(2188),
    [anon_sym_uR_DQUOTE] = ACTIONS(2188),
    [anon_sym_UR_DQUOTE] = ACTIONS(2188),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2188),
    [anon_sym_co_await] = ACTIONS(2186),
    [anon_sym_new] = ACTIONS(2186),
    [anon_sym_requires] = ACTIONS(2186),
    [sym_this] = ACTIONS(2186),
    [anon_sym_discard] = ACTIONS(2186),
    [anon_sym_precise] = ACTIONS(2186),
    [anon_sym_shared] = ACTIONS(2186),
    [anon_sym_groupshared] = ACTIONS(2186),
    [anon_sym_uniform] = ACTIONS(2186),
    [anon_sym_row_major] = ACTIONS(2186),
    [anon_sym_column_major] = ACTIONS(2186),
    [anon_sym_globallycoherent] = ACTIONS(2186),
    [anon_sym_centroid] = ACTIONS(2186),
    [anon_sym_noperspective] = ACTIONS(2186),
    [anon_sym_nointerpolation] = ACTIONS(2186),
    [anon_sym_sample] = ACTIONS(2186),
    [anon_sym_linear] = ACTIONS(2186),
    [anon_sym_snorm] = ACTIONS(2186),
    [anon_sym_unorm] = ACTIONS(2186),
    [anon_sym_point] = ACTIONS(2186),
    [anon_sym_line] = ACTIONS(2186),
    [anon_sym_triangleadj] = ACTIONS(2186),
    [anon_sym_lineadj] = ACTIONS(2186),
    [anon_sym_triangle] = ACTIONS(2186),
    [anon_sym_cbuffer] = ACTIONS(2186),
  },
  [518] = {
    [sym_identifier] = ACTIONS(2190),
    [aux_sym_preproc_include_token1] = ACTIONS(2190),
    [aux_sym_preproc_def_token1] = ACTIONS(2190),
    [aux_sym_preproc_if_token1] = ACTIONS(2190),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2190),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2190),
    [sym_preproc_directive] = ACTIONS(2190),
    [anon_sym_LPAREN2] = ACTIONS(2192),
    [anon_sym_BANG] = ACTIONS(2192),
    [anon_sym_TILDE] = ACTIONS(2192),
    [anon_sym_DASH] = ACTIONS(2190),
    [anon_sym_PLUS] = ACTIONS(2190),
    [anon_sym_STAR] = ACTIONS(2192),
    [anon_sym_AMP_AMP] = ACTIONS(2192),
    [anon_sym_AMP] = ACTIONS(2190),
    [anon_sym_SEMI] = ACTIONS(2192),
    [anon_sym___extension__] = ACTIONS(2190),
    [anon_sym_typedef] = ACTIONS(2190),
    [anon_sym_in] = ACTIONS(2190),
    [anon_sym_out] = ACTIONS(2190),
    [anon_sym_inout] = ACTIONS(2190),
    [anon_sym_extern] = ACTIONS(2190),
    [anon_sym___attribute__] = ACTIONS(2190),
    [anon_sym_COLON_COLON] = ACTIONS(2192),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2192),
    [anon_sym___declspec] = ACTIONS(2190),
    [anon_sym___based] = ACTIONS(2190),
    [anon_sym___cdecl] = ACTIONS(2190),
    [anon_sym___clrcall] = ACTIONS(2190),
    [anon_sym___stdcall] = ACTIONS(2190),
    [anon_sym___fastcall] = ACTIONS(2190),
    [anon_sym___thiscall] = ACTIONS(2190),
    [anon_sym___vectorcall] = ACTIONS(2190),
    [anon_sym_LBRACE] = ACTIONS(2192),
    [anon_sym_RBRACE] = ACTIONS(2192),
    [anon_sym_signed] = ACTIONS(2190),
    [anon_sym_unsigned] = ACTIONS(2190),
    [anon_sym_long] = ACTIONS(2190),
    [anon_sym_short] = ACTIONS(2190),
    [anon_sym_LBRACK] = ACTIONS(2190),
    [anon_sym_static] = ACTIONS(2190),
    [anon_sym_register] = ACTIONS(2190),
    [anon_sym_inline] = ACTIONS(2190),
    [anon_sym___inline] = ACTIONS(2190),
    [anon_sym___inline__] = ACTIONS(2190),
    [anon_sym___forceinline] = ACTIONS(2190),
    [anon_sym_thread_local] = ACTIONS(2190),
    [anon_sym___thread] = ACTIONS(2190),
    [anon_sym_const] = ACTIONS(2190),
    [anon_sym_constexpr] = ACTIONS(2190),
    [anon_sym_volatile] = ACTIONS(2190),
    [anon_sym_restrict] = ACTIONS(2190),
    [anon_sym___restrict__] = ACTIONS(2190),
    [anon_sym__Atomic] = ACTIONS(2190),
    [anon_sym__Noreturn] = ACTIONS(2190),
    [anon_sym_noreturn] = ACTIONS(2190),
    [anon_sym_mutable] = ACTIONS(2190),
    [anon_sym_constinit] = ACTIONS(2190),
    [anon_sym_consteval] = ACTIONS(2190),
    [anon_sym_alignas] = ACTIONS(2190),
    [anon_sym__Alignas] = ACTIONS(2190),
    [sym_primitive_type] = ACTIONS(2190),
    [anon_sym_enum] = ACTIONS(2190),
    [anon_sym_class] = ACTIONS(2190),
    [anon_sym_struct] = ACTIONS(2190),
    [anon_sym_union] = ACTIONS(2190),
    [anon_sym_if] = ACTIONS(2190),
    [anon_sym_else] = ACTIONS(2190),
    [anon_sym_switch] = ACTIONS(2190),
    [anon_sym_case] = ACTIONS(2190),
    [anon_sym_default] = ACTIONS(2190),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_do] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2190),
    [anon_sym_return] = ACTIONS(2190),
    [anon_sym_break] = ACTIONS(2190),
    [anon_sym_continue] = ACTIONS(2190),
    [anon_sym_goto] = ACTIONS(2190),
    [anon_sym___try] = ACTIONS(2190),
    [anon_sym___leave] = ACTIONS(2190),
    [anon_sym_not] = ACTIONS(2190),
    [anon_sym_compl] = ACTIONS(2190),
    [anon_sym_DASH_DASH] = ACTIONS(2192),
    [anon_sym_PLUS_PLUS] = ACTIONS(2192),
    [anon_sym_sizeof] = ACTIONS(2190),
    [anon_sym___alignof__] = ACTIONS(2190),
    [anon_sym___alignof] = ACTIONS(2190),
    [anon_sym__alignof] = ACTIONS(2190),
    [anon_sym_alignof] = ACTIONS(2190),
    [anon_sym__Alignof] = ACTIONS(2190),
    [anon_sym_offsetof] = ACTIONS(2190),
    [anon_sym__Generic] = ACTIONS(2190),
    [anon_sym_asm] = ACTIONS(2190),
    [anon_sym___asm__] = ACTIONS(2190),
    [sym_number_literal] = ACTIONS(2192),
    [anon_sym_L_SQUOTE] = ACTIONS(2192),
    [anon_sym_u_SQUOTE] = ACTIONS(2192),
    [anon_sym_U_SQUOTE] = ACTIONS(2192),
    [anon_sym_u8_SQUOTE] = ACTIONS(2192),
    [anon_sym_SQUOTE] = ACTIONS(2192),
    [anon_sym_L_DQUOTE] = ACTIONS(2192),
    [anon_sym_u_DQUOTE] = ACTIONS(2192),
    [anon_sym_U_DQUOTE] = ACTIONS(2192),
    [anon_sym_u8_DQUOTE] = ACTIONS(2192),
    [anon_sym_DQUOTE] = ACTIONS(2192),
    [sym_true] = ACTIONS(2190),
    [sym_false] = ACTIONS(2190),
    [anon_sym_NULL] = ACTIONS(2190),
    [anon_sym_nullptr] = ACTIONS(2190),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2190),
    [anon_sym_decltype] = ACTIONS(2190),
    [sym_virtual] = ACTIONS(2190),
    [anon_sym_explicit] = ACTIONS(2190),
    [anon_sym_typename] = ACTIONS(2190),
    [anon_sym_template] = ACTIONS(2190),
    [anon_sym_operator] = ACTIONS(2190),
    [anon_sym_try] = ACTIONS(2190),
    [anon_sym_delete] = ACTIONS(2190),
    [anon_sym_throw] = ACTIONS(2190),
    [anon_sym_namespace] = ACTIONS(2190),
    [anon_sym_using] = ACTIONS(2190),
    [anon_sym_static_assert] = ACTIONS(2190),
    [anon_sym_concept] = ACTIONS(2190),
    [anon_sym_co_return] = ACTIONS(2190),
    [anon_sym_co_yield] = ACTIONS(2190),
    [anon_sym_R_DQUOTE] = ACTIONS(2192),
    [anon_sym_LR_DQUOTE] = ACTIONS(2192),
    [anon_sym_uR_DQUOTE] = ACTIONS(2192),
    [anon_sym_UR_DQUOTE] = ACTIONS(2192),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2192),
    [anon_sym_co_await] = ACTIONS(2190),
    [anon_sym_new] = ACTIONS(2190),
    [anon_sym_requires] = ACTIONS(2190),
    [sym_this] = ACTIONS(2190),
    [anon_sym_discard] = ACTIONS(2190),
    [anon_sym_precise] = ACTIONS(2190),
    [anon_sym_shared] = ACTIONS(2190),
    [anon_sym_groupshared] = ACTIONS(2190),
    [anon_sym_uniform] = ACTIONS(2190),
    [anon_sym_row_major] = ACTIONS(2190),
    [anon_sym_column_major] = ACTIONS(2190),
    [anon_sym_globallycoherent] = ACTIONS(2190),
    [anon_sym_centroid] = ACTIONS(2190),
    [anon_sym_noperspective] = ACTIONS(2190),
    [anon_sym_nointerpolation] = ACTIONS(2190),
    [anon_sym_sample] = ACTIONS(2190),
    [anon_sym_linear] = ACTIONS(2190),
    [anon_sym_snorm] = ACTIONS(2190),
    [anon_sym_unorm] = ACTIONS(2190),
    [anon_sym_point] = ACTIONS(2190),
    [anon_sym_line] = ACTIONS(2190),
    [anon_sym_triangleadj] = ACTIONS(2190),
    [anon_sym_lineadj] = ACTIONS(2190),
    [anon_sym_triangle] = ACTIONS(2190),
    [anon_sym_cbuffer] = ACTIONS(2190),
  },
  [519] = {
    [sym_identifier] = ACTIONS(2220),
    [aux_sym_preproc_include_token1] = ACTIONS(2220),
    [aux_sym_preproc_def_token1] = ACTIONS(2220),
    [aux_sym_preproc_if_token1] = ACTIONS(2220),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2220),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2220),
    [sym_preproc_directive] = ACTIONS(2220),
    [anon_sym_LPAREN2] = ACTIONS(2222),
    [anon_sym_BANG] = ACTIONS(2222),
    [anon_sym_TILDE] = ACTIONS(2222),
    [anon_sym_DASH] = ACTIONS(2220),
    [anon_sym_PLUS] = ACTIONS(2220),
    [anon_sym_STAR] = ACTIONS(2222),
    [anon_sym_AMP_AMP] = ACTIONS(2222),
    [anon_sym_AMP] = ACTIONS(2220),
    [anon_sym_SEMI] = ACTIONS(2222),
    [anon_sym___extension__] = ACTIONS(2220),
    [anon_sym_typedef] = ACTIONS(2220),
    [anon_sym_in] = ACTIONS(2220),
    [anon_sym_out] = ACTIONS(2220),
    [anon_sym_inout] = ACTIONS(2220),
    [anon_sym_extern] = ACTIONS(2220),
    [anon_sym___attribute__] = ACTIONS(2220),
    [anon_sym_COLON_COLON] = ACTIONS(2222),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2222),
    [anon_sym___declspec] = ACTIONS(2220),
    [anon_sym___based] = ACTIONS(2220),
    [anon_sym___cdecl] = ACTIONS(2220),
    [anon_sym___clrcall] = ACTIONS(2220),
    [anon_sym___stdcall] = ACTIONS(2220),
    [anon_sym___fastcall] = ACTIONS(2220),
    [anon_sym___thiscall] = ACTIONS(2220),
    [anon_sym___vectorcall] = ACTIONS(2220),
    [anon_sym_LBRACE] = ACTIONS(2222),
    [anon_sym_RBRACE] = ACTIONS(2222),
    [anon_sym_signed] = ACTIONS(2220),
    [anon_sym_unsigned] = ACTIONS(2220),
    [anon_sym_long] = ACTIONS(2220),
    [anon_sym_short] = ACTIONS(2220),
    [anon_sym_LBRACK] = ACTIONS(2220),
    [anon_sym_static] = ACTIONS(2220),
    [anon_sym_register] = ACTIONS(2220),
    [anon_sym_inline] = ACTIONS(2220),
    [anon_sym___inline] = ACTIONS(2220),
    [anon_sym___inline__] = ACTIONS(2220),
    [anon_sym___forceinline] = ACTIONS(2220),
    [anon_sym_thread_local] = ACTIONS(2220),
    [anon_sym___thread] = ACTIONS(2220),
    [anon_sym_const] = ACTIONS(2220),
    [anon_sym_constexpr] = ACTIONS(2220),
    [anon_sym_volatile] = ACTIONS(2220),
    [anon_sym_restrict] = ACTIONS(2220),
    [anon_sym___restrict__] = ACTIONS(2220),
    [anon_sym__Atomic] = ACTIONS(2220),
    [anon_sym__Noreturn] = ACTIONS(2220),
    [anon_sym_noreturn] = ACTIONS(2220),
    [anon_sym_mutable] = ACTIONS(2220),
    [anon_sym_constinit] = ACTIONS(2220),
    [anon_sym_consteval] = ACTIONS(2220),
    [anon_sym_alignas] = ACTIONS(2220),
    [anon_sym__Alignas] = ACTIONS(2220),
    [sym_primitive_type] = ACTIONS(2220),
    [anon_sym_enum] = ACTIONS(2220),
    [anon_sym_class] = ACTIONS(2220),
    [anon_sym_struct] = ACTIONS(2220),
    [anon_sym_union] = ACTIONS(2220),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_else] = ACTIONS(2220),
    [anon_sym_switch] = ACTIONS(2220),
    [anon_sym_case] = ACTIONS(2220),
    [anon_sym_default] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2220),
    [anon_sym_do] = ACTIONS(2220),
    [anon_sym_for] = ACTIONS(2220),
    [anon_sym_return] = ACTIONS(2220),
    [anon_sym_break] = ACTIONS(2220),
    [anon_sym_continue] = ACTIONS(2220),
    [anon_sym_goto] = ACTIONS(2220),
    [anon_sym___try] = ACTIONS(2220),
    [anon_sym___leave] = ACTIONS(2220),
    [anon_sym_not] = ACTIONS(2220),
    [anon_sym_compl] = ACTIONS(2220),
    [anon_sym_DASH_DASH] = ACTIONS(2222),
    [anon_sym_PLUS_PLUS] = ACTIONS(2222),
    [anon_sym_sizeof] = ACTIONS(2220),
    [anon_sym___alignof__] = ACTIONS(2220),
    [anon_sym___alignof] = ACTIONS(2220),
    [anon_sym__alignof] = ACTIONS(2220),
    [anon_sym_alignof] = ACTIONS(2220),
    [anon_sym__Alignof] = ACTIONS(2220),
    [anon_sym_offsetof] = ACTIONS(2220),
    [anon_sym__Generic] = ACTIONS(2220),
    [anon_sym_asm] = ACTIONS(2220),
    [anon_sym___asm__] = ACTIONS(2220),
    [sym_number_literal] = ACTIONS(2222),
    [anon_sym_L_SQUOTE] = ACTIONS(2222),
    [anon_sym_u_SQUOTE] = ACTIONS(2222),
    [anon_sym_U_SQUOTE] = ACTIONS(2222),
    [anon_sym_u8_SQUOTE] = ACTIONS(2222),
    [anon_sym_SQUOTE] = ACTIONS(2222),
    [anon_sym_L_DQUOTE] = ACTIONS(2222),
    [anon_sym_u_DQUOTE] = ACTIONS(2222),
    [anon_sym_U_DQUOTE] = ACTIONS(2222),
    [anon_sym_u8_DQUOTE] = ACTIONS(2222),
    [anon_sym_DQUOTE] = ACTIONS(2222),
    [sym_true] = ACTIONS(2220),
    [sym_false] = ACTIONS(2220),
    [anon_sym_NULL] = ACTIONS(2220),
    [anon_sym_nullptr] = ACTIONS(2220),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2220),
    [anon_sym_decltype] = ACTIONS(2220),
    [sym_virtual] = ACTIONS(2220),
    [anon_sym_explicit] = ACTIONS(2220),
    [anon_sym_typename] = ACTIONS(2220),
    [anon_sym_template] = ACTIONS(2220),
    [anon_sym_operator] = ACTIONS(2220),
    [anon_sym_try] = ACTIONS(2220),
    [anon_sym_delete] = ACTIONS(2220),
    [anon_sym_throw] = ACTIONS(2220),
    [anon_sym_namespace] = ACTIONS(2220),
    [anon_sym_using] = ACTIONS(2220),
    [anon_sym_static_assert] = ACTIONS(2220),
    [anon_sym_concept] = ACTIONS(2220),
    [anon_sym_co_return] = ACTIONS(2220),
    [anon_sym_co_yield] = ACTIONS(2220),
    [anon_sym_R_DQUOTE] = ACTIONS(2222),
    [anon_sym_LR_DQUOTE] = ACTIONS(2222),
    [anon_sym_uR_DQUOTE] = ACTIONS(2222),
    [anon_sym_UR_DQUOTE] = ACTIONS(2222),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2222),
    [anon_sym_co_await] = ACTIONS(2220),
    [anon_sym_new] = ACTIONS(2220),
    [anon_sym_requires] = ACTIONS(2220),
    [sym_this] = ACTIONS(2220),
    [anon_sym_discard] = ACTIONS(2220),
    [anon_sym_precise] = ACTIONS(2220),
    [anon_sym_shared] = ACTIONS(2220),
    [anon_sym_groupshared] = ACTIONS(2220),
    [anon_sym_uniform] = ACTIONS(2220),
    [anon_sym_row_major] = ACTIONS(2220),
    [anon_sym_column_major] = ACTIONS(2220),
    [anon_sym_globallycoherent] = ACTIONS(2220),
    [anon_sym_centroid] = ACTIONS(2220),
    [anon_sym_noperspective] = ACTIONS(2220),
    [anon_sym_nointerpolation] = ACTIONS(2220),
    [anon_sym_sample] = ACTIONS(2220),
    [anon_sym_linear] = ACTIONS(2220),
    [anon_sym_snorm] = ACTIONS(2220),
    [anon_sym_unorm] = ACTIONS(2220),
    [anon_sym_point] = ACTIONS(2220),
    [anon_sym_line] = ACTIONS(2220),
    [anon_sym_triangleadj] = ACTIONS(2220),
    [anon_sym_lineadj] = ACTIONS(2220),
    [anon_sym_triangle] = ACTIONS(2220),
    [anon_sym_cbuffer] = ACTIONS(2220),
  },
  [520] = {
    [sym_identifier] = ACTIONS(2252),
    [aux_sym_preproc_include_token1] = ACTIONS(2252),
    [aux_sym_preproc_def_token1] = ACTIONS(2252),
    [aux_sym_preproc_if_token1] = ACTIONS(2252),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2252),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2252),
    [sym_preproc_directive] = ACTIONS(2252),
    [anon_sym_LPAREN2] = ACTIONS(2254),
    [anon_sym_BANG] = ACTIONS(2254),
    [anon_sym_TILDE] = ACTIONS(2254),
    [anon_sym_DASH] = ACTIONS(2252),
    [anon_sym_PLUS] = ACTIONS(2252),
    [anon_sym_STAR] = ACTIONS(2254),
    [anon_sym_AMP_AMP] = ACTIONS(2254),
    [anon_sym_AMP] = ACTIONS(2252),
    [anon_sym_SEMI] = ACTIONS(2254),
    [anon_sym___extension__] = ACTIONS(2252),
    [anon_sym_typedef] = ACTIONS(2252),
    [anon_sym_in] = ACTIONS(2252),
    [anon_sym_out] = ACTIONS(2252),
    [anon_sym_inout] = ACTIONS(2252),
    [anon_sym_extern] = ACTIONS(2252),
    [anon_sym___attribute__] = ACTIONS(2252),
    [anon_sym_COLON_COLON] = ACTIONS(2254),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2254),
    [anon_sym___declspec] = ACTIONS(2252),
    [anon_sym___based] = ACTIONS(2252),
    [anon_sym___cdecl] = ACTIONS(2252),
    [anon_sym___clrcall] = ACTIONS(2252),
    [anon_sym___stdcall] = ACTIONS(2252),
    [anon_sym___fastcall] = ACTIONS(2252),
    [anon_sym___thiscall] = ACTIONS(2252),
    [anon_sym___vectorcall] = ACTIONS(2252),
    [anon_sym_LBRACE] = ACTIONS(2254),
    [anon_sym_RBRACE] = ACTIONS(2254),
    [anon_sym_signed] = ACTIONS(2252),
    [anon_sym_unsigned] = ACTIONS(2252),
    [anon_sym_long] = ACTIONS(2252),
    [anon_sym_short] = ACTIONS(2252),
    [anon_sym_LBRACK] = ACTIONS(2252),
    [anon_sym_static] = ACTIONS(2252),
    [anon_sym_register] = ACTIONS(2252),
    [anon_sym_inline] = ACTIONS(2252),
    [anon_sym___inline] = ACTIONS(2252),
    [anon_sym___inline__] = ACTIONS(2252),
    [anon_sym___forceinline] = ACTIONS(2252),
    [anon_sym_thread_local] = ACTIONS(2252),
    [anon_sym___thread] = ACTIONS(2252),
    [anon_sym_const] = ACTIONS(2252),
    [anon_sym_constexpr] = ACTIONS(2252),
    [anon_sym_volatile] = ACTIONS(2252),
    [anon_sym_restrict] = ACTIONS(2252),
    [anon_sym___restrict__] = ACTIONS(2252),
    [anon_sym__Atomic] = ACTIONS(2252),
    [anon_sym__Noreturn] = ACTIONS(2252),
    [anon_sym_noreturn] = ACTIONS(2252),
    [anon_sym_mutable] = ACTIONS(2252),
    [anon_sym_constinit] = ACTIONS(2252),
    [anon_sym_consteval] = ACTIONS(2252),
    [anon_sym_alignas] = ACTIONS(2252),
    [anon_sym__Alignas] = ACTIONS(2252),
    [sym_primitive_type] = ACTIONS(2252),
    [anon_sym_enum] = ACTIONS(2252),
    [anon_sym_class] = ACTIONS(2252),
    [anon_sym_struct] = ACTIONS(2252),
    [anon_sym_union] = ACTIONS(2252),
    [anon_sym_if] = ACTIONS(2252),
    [anon_sym_else] = ACTIONS(2252),
    [anon_sym_switch] = ACTIONS(2252),
    [anon_sym_case] = ACTIONS(2252),
    [anon_sym_default] = ACTIONS(2252),
    [anon_sym_while] = ACTIONS(2252),
    [anon_sym_do] = ACTIONS(2252),
    [anon_sym_for] = ACTIONS(2252),
    [anon_sym_return] = ACTIONS(2252),
    [anon_sym_break] = ACTIONS(2252),
    [anon_sym_continue] = ACTIONS(2252),
    [anon_sym_goto] = ACTIONS(2252),
    [anon_sym___try] = ACTIONS(2252),
    [anon_sym___leave] = ACTIONS(2252),
    [anon_sym_not] = ACTIONS(2252),
    [anon_sym_compl] = ACTIONS(2252),
    [anon_sym_DASH_DASH] = ACTIONS(2254),
    [anon_sym_PLUS_PLUS] = ACTIONS(2254),
    [anon_sym_sizeof] = ACTIONS(2252),
    [anon_sym___alignof__] = ACTIONS(2252),
    [anon_sym___alignof] = ACTIONS(2252),
    [anon_sym__alignof] = ACTIONS(2252),
    [anon_sym_alignof] = ACTIONS(2252),
    [anon_sym__Alignof] = ACTIONS(2252),
    [anon_sym_offsetof] = ACTIONS(2252),
    [anon_sym__Generic] = ACTIONS(2252),
    [anon_sym_asm] = ACTIONS(2252),
    [anon_sym___asm__] = ACTIONS(2252),
    [sym_number_literal] = ACTIONS(2254),
    [anon_sym_L_SQUOTE] = ACTIONS(2254),
    [anon_sym_u_SQUOTE] = ACTIONS(2254),
    [anon_sym_U_SQUOTE] = ACTIONS(2254),
    [anon_sym_u8_SQUOTE] = ACTIONS(2254),
    [anon_sym_SQUOTE] = ACTIONS(2254),
    [anon_sym_L_DQUOTE] = ACTIONS(2254),
    [anon_sym_u_DQUOTE] = ACTIONS(2254),
    [anon_sym_U_DQUOTE] = ACTIONS(2254),
    [anon_sym_u8_DQUOTE] = ACTIONS(2254),
    [anon_sym_DQUOTE] = ACTIONS(2254),
    [sym_true] = ACTIONS(2252),
    [sym_false] = ACTIONS(2252),
    [anon_sym_NULL] = ACTIONS(2252),
    [anon_sym_nullptr] = ACTIONS(2252),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2252),
    [anon_sym_decltype] = ACTIONS(2252),
    [sym_virtual] = ACTIONS(2252),
    [anon_sym_explicit] = ACTIONS(2252),
    [anon_sym_typename] = ACTIONS(2252),
    [anon_sym_template] = ACTIONS(2252),
    [anon_sym_operator] = ACTIONS(2252),
    [anon_sym_try] = ACTIONS(2252),
    [anon_sym_delete] = ACTIONS(2252),
    [anon_sym_throw] = ACTIONS(2252),
    [anon_sym_namespace] = ACTIONS(2252),
    [anon_sym_using] = ACTIONS(2252),
    [anon_sym_static_assert] = ACTIONS(2252),
    [anon_sym_concept] = ACTIONS(2252),
    [anon_sym_co_return] = ACTIONS(2252),
    [anon_sym_co_yield] = ACTIONS(2252),
    [anon_sym_R_DQUOTE] = ACTIONS(2254),
    [anon_sym_LR_DQUOTE] = ACTIONS(2254),
    [anon_sym_uR_DQUOTE] = ACTIONS(2254),
    [anon_sym_UR_DQUOTE] = ACTIONS(2254),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2254),
    [anon_sym_co_await] = ACTIONS(2252),
    [anon_sym_new] = ACTIONS(2252),
    [anon_sym_requires] = ACTIONS(2252),
    [sym_this] = ACTIONS(2252),
    [anon_sym_discard] = ACTIONS(2252),
    [anon_sym_precise] = ACTIONS(2252),
    [anon_sym_shared] = ACTIONS(2252),
    [anon_sym_groupshared] = ACTIONS(2252),
    [anon_sym_uniform] = ACTIONS(2252),
    [anon_sym_row_major] = ACTIONS(2252),
    [anon_sym_column_major] = ACTIONS(2252),
    [anon_sym_globallycoherent] = ACTIONS(2252),
    [anon_sym_centroid] = ACTIONS(2252),
    [anon_sym_noperspective] = ACTIONS(2252),
    [anon_sym_nointerpolation] = ACTIONS(2252),
    [anon_sym_sample] = ACTIONS(2252),
    [anon_sym_linear] = ACTIONS(2252),
    [anon_sym_snorm] = ACTIONS(2252),
    [anon_sym_unorm] = ACTIONS(2252),
    [anon_sym_point] = ACTIONS(2252),
    [anon_sym_line] = ACTIONS(2252),
    [anon_sym_triangleadj] = ACTIONS(2252),
    [anon_sym_lineadj] = ACTIONS(2252),
    [anon_sym_triangle] = ACTIONS(2252),
    [anon_sym_cbuffer] = ACTIONS(2252),
  },
  [521] = {
    [ts_builtin_sym_end] = ACTIONS(2238),
    [sym_identifier] = ACTIONS(2236),
    [aux_sym_preproc_include_token1] = ACTIONS(2236),
    [aux_sym_preproc_def_token1] = ACTIONS(2236),
    [aux_sym_preproc_if_token1] = ACTIONS(2236),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2236),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2236),
    [sym_preproc_directive] = ACTIONS(2236),
    [anon_sym_LPAREN2] = ACTIONS(2238),
    [anon_sym_BANG] = ACTIONS(2238),
    [anon_sym_TILDE] = ACTIONS(2238),
    [anon_sym_DASH] = ACTIONS(2236),
    [anon_sym_PLUS] = ACTIONS(2236),
    [anon_sym_STAR] = ACTIONS(2238),
    [anon_sym_AMP_AMP] = ACTIONS(2238),
    [anon_sym_AMP] = ACTIONS(2236),
    [anon_sym_SEMI] = ACTIONS(2238),
    [anon_sym___extension__] = ACTIONS(2236),
    [anon_sym_typedef] = ACTIONS(2236),
    [anon_sym_in] = ACTIONS(2236),
    [anon_sym_out] = ACTIONS(2236),
    [anon_sym_inout] = ACTIONS(2236),
    [anon_sym_extern] = ACTIONS(2236),
    [anon_sym___attribute__] = ACTIONS(2236),
    [anon_sym_COLON_COLON] = ACTIONS(2238),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2238),
    [anon_sym___declspec] = ACTIONS(2236),
    [anon_sym___based] = ACTIONS(2236),
    [anon_sym___cdecl] = ACTIONS(2236),
    [anon_sym___clrcall] = ACTIONS(2236),
    [anon_sym___stdcall] = ACTIONS(2236),
    [anon_sym___fastcall] = ACTIONS(2236),
    [anon_sym___thiscall] = ACTIONS(2236),
    [anon_sym___vectorcall] = ACTIONS(2236),
    [anon_sym_LBRACE] = ACTIONS(2238),
    [anon_sym_signed] = ACTIONS(2236),
    [anon_sym_unsigned] = ACTIONS(2236),
    [anon_sym_long] = ACTIONS(2236),
    [anon_sym_short] = ACTIONS(2236),
    [anon_sym_LBRACK] = ACTIONS(2236),
    [anon_sym_static] = ACTIONS(2236),
    [anon_sym_register] = ACTIONS(2236),
    [anon_sym_inline] = ACTIONS(2236),
    [anon_sym___inline] = ACTIONS(2236),
    [anon_sym___inline__] = ACTIONS(2236),
    [anon_sym___forceinline] = ACTIONS(2236),
    [anon_sym_thread_local] = ACTIONS(2236),
    [anon_sym___thread] = ACTIONS(2236),
    [anon_sym_const] = ACTIONS(2236),
    [anon_sym_constexpr] = ACTIONS(2236),
    [anon_sym_volatile] = ACTIONS(2236),
    [anon_sym_restrict] = ACTIONS(2236),
    [anon_sym___restrict__] = ACTIONS(2236),
    [anon_sym__Atomic] = ACTIONS(2236),
    [anon_sym__Noreturn] = ACTIONS(2236),
    [anon_sym_noreturn] = ACTIONS(2236),
    [anon_sym_mutable] = ACTIONS(2236),
    [anon_sym_constinit] = ACTIONS(2236),
    [anon_sym_consteval] = ACTIONS(2236),
    [anon_sym_alignas] = ACTIONS(2236),
    [anon_sym__Alignas] = ACTIONS(2236),
    [sym_primitive_type] = ACTIONS(2236),
    [anon_sym_enum] = ACTIONS(2236),
    [anon_sym_class] = ACTIONS(2236),
    [anon_sym_struct] = ACTIONS(2236),
    [anon_sym_union] = ACTIONS(2236),
    [anon_sym_if] = ACTIONS(2236),
    [anon_sym_else] = ACTIONS(2236),
    [anon_sym_switch] = ACTIONS(2236),
    [anon_sym_case] = ACTIONS(2236),
    [anon_sym_default] = ACTIONS(2236),
    [anon_sym_while] = ACTIONS(2236),
    [anon_sym_do] = ACTIONS(2236),
    [anon_sym_for] = ACTIONS(2236),
    [anon_sym_return] = ACTIONS(2236),
    [anon_sym_break] = ACTIONS(2236),
    [anon_sym_continue] = ACTIONS(2236),
    [anon_sym_goto] = ACTIONS(2236),
    [anon_sym___try] = ACTIONS(2236),
    [anon_sym___leave] = ACTIONS(2236),
    [anon_sym_not] = ACTIONS(2236),
    [anon_sym_compl] = ACTIONS(2236),
    [anon_sym_DASH_DASH] = ACTIONS(2238),
    [anon_sym_PLUS_PLUS] = ACTIONS(2238),
    [anon_sym_sizeof] = ACTIONS(2236),
    [anon_sym___alignof__] = ACTIONS(2236),
    [anon_sym___alignof] = ACTIONS(2236),
    [anon_sym__alignof] = ACTIONS(2236),
    [anon_sym_alignof] = ACTIONS(2236),
    [anon_sym__Alignof] = ACTIONS(2236),
    [anon_sym_offsetof] = ACTIONS(2236),
    [anon_sym__Generic] = ACTIONS(2236),
    [anon_sym_asm] = ACTIONS(2236),
    [anon_sym___asm__] = ACTIONS(2236),
    [sym_number_literal] = ACTIONS(2238),
    [anon_sym_L_SQUOTE] = ACTIONS(2238),
    [anon_sym_u_SQUOTE] = ACTIONS(2238),
    [anon_sym_U_SQUOTE] = ACTIONS(2238),
    [anon_sym_u8_SQUOTE] = ACTIONS(2238),
    [anon_sym_SQUOTE] = ACTIONS(2238),
    [anon_sym_L_DQUOTE] = ACTIONS(2238),
    [anon_sym_u_DQUOTE] = ACTIONS(2238),
    [anon_sym_U_DQUOTE] = ACTIONS(2238),
    [anon_sym_u8_DQUOTE] = ACTIONS(2238),
    [anon_sym_DQUOTE] = ACTIONS(2238),
    [sym_true] = ACTIONS(2236),
    [sym_false] = ACTIONS(2236),
    [anon_sym_NULL] = ACTIONS(2236),
    [anon_sym_nullptr] = ACTIONS(2236),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2236),
    [anon_sym_decltype] = ACTIONS(2236),
    [sym_virtual] = ACTIONS(2236),
    [anon_sym_explicit] = ACTIONS(2236),
    [anon_sym_typename] = ACTIONS(2236),
    [anon_sym_template] = ACTIONS(2236),
    [anon_sym_operator] = ACTIONS(2236),
    [anon_sym_try] = ACTIONS(2236),
    [anon_sym_delete] = ACTIONS(2236),
    [anon_sym_throw] = ACTIONS(2236),
    [anon_sym_namespace] = ACTIONS(2236),
    [anon_sym_using] = ACTIONS(2236),
    [anon_sym_static_assert] = ACTIONS(2236),
    [anon_sym_concept] = ACTIONS(2236),
    [anon_sym_co_return] = ACTIONS(2236),
    [anon_sym_co_yield] = ACTIONS(2236),
    [anon_sym_R_DQUOTE] = ACTIONS(2238),
    [anon_sym_LR_DQUOTE] = ACTIONS(2238),
    [anon_sym_uR_DQUOTE] = ACTIONS(2238),
    [anon_sym_UR_DQUOTE] = ACTIONS(2238),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2238),
    [anon_sym_co_await] = ACTIONS(2236),
    [anon_sym_new] = ACTIONS(2236),
    [anon_sym_requires] = ACTIONS(2236),
    [sym_this] = ACTIONS(2236),
    [anon_sym_discard] = ACTIONS(2236),
    [anon_sym_precise] = ACTIONS(2236),
    [anon_sym_shared] = ACTIONS(2236),
    [anon_sym_groupshared] = ACTIONS(2236),
    [anon_sym_uniform] = ACTIONS(2236),
    [anon_sym_row_major] = ACTIONS(2236),
    [anon_sym_column_major] = ACTIONS(2236),
    [anon_sym_globallycoherent] = ACTIONS(2236),
    [anon_sym_centroid] = ACTIONS(2236),
    [anon_sym_noperspective] = ACTIONS(2236),
    [anon_sym_nointerpolation] = ACTIONS(2236),
    [anon_sym_sample] = ACTIONS(2236),
    [anon_sym_linear] = ACTIONS(2236),
    [anon_sym_snorm] = ACTIONS(2236),
    [anon_sym_unorm] = ACTIONS(2236),
    [anon_sym_point] = ACTIONS(2236),
    [anon_sym_line] = ACTIONS(2236),
    [anon_sym_triangleadj] = ACTIONS(2236),
    [anon_sym_lineadj] = ACTIONS(2236),
    [anon_sym_triangle] = ACTIONS(2236),
    [anon_sym_cbuffer] = ACTIONS(2236),
  },
  [522] = {
    [sym_identifier] = ACTIONS(2150),
    [aux_sym_preproc_include_token1] = ACTIONS(2150),
    [aux_sym_preproc_def_token1] = ACTIONS(2150),
    [aux_sym_preproc_if_token1] = ACTIONS(2150),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2150),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2150),
    [sym_preproc_directive] = ACTIONS(2150),
    [anon_sym_LPAREN2] = ACTIONS(2152),
    [anon_sym_BANG] = ACTIONS(2152),
    [anon_sym_TILDE] = ACTIONS(2152),
    [anon_sym_DASH] = ACTIONS(2150),
    [anon_sym_PLUS] = ACTIONS(2150),
    [anon_sym_STAR] = ACTIONS(2152),
    [anon_sym_AMP_AMP] = ACTIONS(2152),
    [anon_sym_AMP] = ACTIONS(2150),
    [anon_sym_SEMI] = ACTIONS(2152),
    [anon_sym___extension__] = ACTIONS(2150),
    [anon_sym_typedef] = ACTIONS(2150),
    [anon_sym_in] = ACTIONS(2150),
    [anon_sym_out] = ACTIONS(2150),
    [anon_sym_inout] = ACTIONS(2150),
    [anon_sym_extern] = ACTIONS(2150),
    [anon_sym___attribute__] = ACTIONS(2150),
    [anon_sym_COLON_COLON] = ACTIONS(2152),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2152),
    [anon_sym___declspec] = ACTIONS(2150),
    [anon_sym___based] = ACTIONS(2150),
    [anon_sym___cdecl] = ACTIONS(2150),
    [anon_sym___clrcall] = ACTIONS(2150),
    [anon_sym___stdcall] = ACTIONS(2150),
    [anon_sym___fastcall] = ACTIONS(2150),
    [anon_sym___thiscall] = ACTIONS(2150),
    [anon_sym___vectorcall] = ACTIONS(2150),
    [anon_sym_LBRACE] = ACTIONS(2152),
    [anon_sym_RBRACE] = ACTIONS(2152),
    [anon_sym_signed] = ACTIONS(2150),
    [anon_sym_unsigned] = ACTIONS(2150),
    [anon_sym_long] = ACTIONS(2150),
    [anon_sym_short] = ACTIONS(2150),
    [anon_sym_LBRACK] = ACTIONS(2150),
    [anon_sym_static] = ACTIONS(2150),
    [anon_sym_register] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(2150),
    [anon_sym___inline] = ACTIONS(2150),
    [anon_sym___inline__] = ACTIONS(2150),
    [anon_sym___forceinline] = ACTIONS(2150),
    [anon_sym_thread_local] = ACTIONS(2150),
    [anon_sym___thread] = ACTIONS(2150),
    [anon_sym_const] = ACTIONS(2150),
    [anon_sym_constexpr] = ACTIONS(2150),
    [anon_sym_volatile] = ACTIONS(2150),
    [anon_sym_restrict] = ACTIONS(2150),
    [anon_sym___restrict__] = ACTIONS(2150),
    [anon_sym__Atomic] = ACTIONS(2150),
    [anon_sym__Noreturn] = ACTIONS(2150),
    [anon_sym_noreturn] = ACTIONS(2150),
    [anon_sym_mutable] = ACTIONS(2150),
    [anon_sym_constinit] = ACTIONS(2150),
    [anon_sym_consteval] = ACTIONS(2150),
    [anon_sym_alignas] = ACTIONS(2150),
    [anon_sym__Alignas] = ACTIONS(2150),
    [sym_primitive_type] = ACTIONS(2150),
    [anon_sym_enum] = ACTIONS(2150),
    [anon_sym_class] = ACTIONS(2150),
    [anon_sym_struct] = ACTIONS(2150),
    [anon_sym_union] = ACTIONS(2150),
    [anon_sym_if] = ACTIONS(2150),
    [anon_sym_else] = ACTIONS(2150),
    [anon_sym_switch] = ACTIONS(2150),
    [anon_sym_case] = ACTIONS(2150),
    [anon_sym_default] = ACTIONS(2150),
    [anon_sym_while] = ACTIONS(2150),
    [anon_sym_do] = ACTIONS(2150),
    [anon_sym_for] = ACTIONS(2150),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_break] = ACTIONS(2150),
    [anon_sym_continue] = ACTIONS(2150),
    [anon_sym_goto] = ACTIONS(2150),
    [anon_sym___try] = ACTIONS(2150),
    [anon_sym___leave] = ACTIONS(2150),
    [anon_sym_not] = ACTIONS(2150),
    [anon_sym_compl] = ACTIONS(2150),
    [anon_sym_DASH_DASH] = ACTIONS(2152),
    [anon_sym_PLUS_PLUS] = ACTIONS(2152),
    [anon_sym_sizeof] = ACTIONS(2150),
    [anon_sym___alignof__] = ACTIONS(2150),
    [anon_sym___alignof] = ACTIONS(2150),
    [anon_sym__alignof] = ACTIONS(2150),
    [anon_sym_alignof] = ACTIONS(2150),
    [anon_sym__Alignof] = ACTIONS(2150),
    [anon_sym_offsetof] = ACTIONS(2150),
    [anon_sym__Generic] = ACTIONS(2150),
    [anon_sym_asm] = ACTIONS(2150),
    [anon_sym___asm__] = ACTIONS(2150),
    [sym_number_literal] = ACTIONS(2152),
    [anon_sym_L_SQUOTE] = ACTIONS(2152),
    [anon_sym_u_SQUOTE] = ACTIONS(2152),
    [anon_sym_U_SQUOTE] = ACTIONS(2152),
    [anon_sym_u8_SQUOTE] = ACTIONS(2152),
    [anon_sym_SQUOTE] = ACTIONS(2152),
    [anon_sym_L_DQUOTE] = ACTIONS(2152),
    [anon_sym_u_DQUOTE] = ACTIONS(2152),
    [anon_sym_U_DQUOTE] = ACTIONS(2152),
    [anon_sym_u8_DQUOTE] = ACTIONS(2152),
    [anon_sym_DQUOTE] = ACTIONS(2152),
    [sym_true] = ACTIONS(2150),
    [sym_false] = ACTIONS(2150),
    [anon_sym_NULL] = ACTIONS(2150),
    [anon_sym_nullptr] = ACTIONS(2150),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2150),
    [anon_sym_decltype] = ACTIONS(2150),
    [sym_virtual] = ACTIONS(2150),
    [anon_sym_explicit] = ACTIONS(2150),
    [anon_sym_typename] = ACTIONS(2150),
    [anon_sym_template] = ACTIONS(2150),
    [anon_sym_operator] = ACTIONS(2150),
    [anon_sym_try] = ACTIONS(2150),
    [anon_sym_delete] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2150),
    [anon_sym_namespace] = ACTIONS(2150),
    [anon_sym_using] = ACTIONS(2150),
    [anon_sym_static_assert] = ACTIONS(2150),
    [anon_sym_concept] = ACTIONS(2150),
    [anon_sym_co_return] = ACTIONS(2150),
    [anon_sym_co_yield] = ACTIONS(2150),
    [anon_sym_R_DQUOTE] = ACTIONS(2152),
    [anon_sym_LR_DQUOTE] = ACTIONS(2152),
    [anon_sym_uR_DQUOTE] = ACTIONS(2152),
    [anon_sym_UR_DQUOTE] = ACTIONS(2152),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2152),
    [anon_sym_co_await] = ACTIONS(2150),
    [anon_sym_new] = ACTIONS(2150),
    [anon_sym_requires] = ACTIONS(2150),
    [sym_this] = ACTIONS(2150),
    [anon_sym_discard] = ACTIONS(2150),
    [anon_sym_precise] = ACTIONS(2150),
    [anon_sym_shared] = ACTIONS(2150),
    [anon_sym_groupshared] = ACTIONS(2150),
    [anon_sym_uniform] = ACTIONS(2150),
    [anon_sym_row_major] = ACTIONS(2150),
    [anon_sym_column_major] = ACTIONS(2150),
    [anon_sym_globallycoherent] = ACTIONS(2150),
    [anon_sym_centroid] = ACTIONS(2150),
    [anon_sym_noperspective] = ACTIONS(2150),
    [anon_sym_nointerpolation] = ACTIONS(2150),
    [anon_sym_sample] = ACTIONS(2150),
    [anon_sym_linear] = ACTIONS(2150),
    [anon_sym_snorm] = ACTIONS(2150),
    [anon_sym_unorm] = ACTIONS(2150),
    [anon_sym_point] = ACTIONS(2150),
    [anon_sym_line] = ACTIONS(2150),
    [anon_sym_triangleadj] = ACTIONS(2150),
    [anon_sym_lineadj] = ACTIONS(2150),
    [anon_sym_triangle] = ACTIONS(2150),
    [anon_sym_cbuffer] = ACTIONS(2150),
  },
  [523] = {
    [sym_identifier] = ACTIONS(2162),
    [aux_sym_preproc_include_token1] = ACTIONS(2162),
    [aux_sym_preproc_def_token1] = ACTIONS(2162),
    [aux_sym_preproc_if_token1] = ACTIONS(2162),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2162),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2162),
    [sym_preproc_directive] = ACTIONS(2162),
    [anon_sym_LPAREN2] = ACTIONS(2164),
    [anon_sym_BANG] = ACTIONS(2164),
    [anon_sym_TILDE] = ACTIONS(2164),
    [anon_sym_DASH] = ACTIONS(2162),
    [anon_sym_PLUS] = ACTIONS(2162),
    [anon_sym_STAR] = ACTIONS(2164),
    [anon_sym_AMP_AMP] = ACTIONS(2164),
    [anon_sym_AMP] = ACTIONS(2162),
    [anon_sym_SEMI] = ACTIONS(2164),
    [anon_sym___extension__] = ACTIONS(2162),
    [anon_sym_typedef] = ACTIONS(2162),
    [anon_sym_in] = ACTIONS(2162),
    [anon_sym_out] = ACTIONS(2162),
    [anon_sym_inout] = ACTIONS(2162),
    [anon_sym_extern] = ACTIONS(2162),
    [anon_sym___attribute__] = ACTIONS(2162),
    [anon_sym_COLON_COLON] = ACTIONS(2164),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2164),
    [anon_sym___declspec] = ACTIONS(2162),
    [anon_sym___based] = ACTIONS(2162),
    [anon_sym___cdecl] = ACTIONS(2162),
    [anon_sym___clrcall] = ACTIONS(2162),
    [anon_sym___stdcall] = ACTIONS(2162),
    [anon_sym___fastcall] = ACTIONS(2162),
    [anon_sym___thiscall] = ACTIONS(2162),
    [anon_sym___vectorcall] = ACTIONS(2162),
    [anon_sym_LBRACE] = ACTIONS(2164),
    [anon_sym_RBRACE] = ACTIONS(2164),
    [anon_sym_signed] = ACTIONS(2162),
    [anon_sym_unsigned] = ACTIONS(2162),
    [anon_sym_long] = ACTIONS(2162),
    [anon_sym_short] = ACTIONS(2162),
    [anon_sym_LBRACK] = ACTIONS(2162),
    [anon_sym_static] = ACTIONS(2162),
    [anon_sym_register] = ACTIONS(2162),
    [anon_sym_inline] = ACTIONS(2162),
    [anon_sym___inline] = ACTIONS(2162),
    [anon_sym___inline__] = ACTIONS(2162),
    [anon_sym___forceinline] = ACTIONS(2162),
    [anon_sym_thread_local] = ACTIONS(2162),
    [anon_sym___thread] = ACTIONS(2162),
    [anon_sym_const] = ACTIONS(2162),
    [anon_sym_constexpr] = ACTIONS(2162),
    [anon_sym_volatile] = ACTIONS(2162),
    [anon_sym_restrict] = ACTIONS(2162),
    [anon_sym___restrict__] = ACTIONS(2162),
    [anon_sym__Atomic] = ACTIONS(2162),
    [anon_sym__Noreturn] = ACTIONS(2162),
    [anon_sym_noreturn] = ACTIONS(2162),
    [anon_sym_mutable] = ACTIONS(2162),
    [anon_sym_constinit] = ACTIONS(2162),
    [anon_sym_consteval] = ACTIONS(2162),
    [anon_sym_alignas] = ACTIONS(2162),
    [anon_sym__Alignas] = ACTIONS(2162),
    [sym_primitive_type] = ACTIONS(2162),
    [anon_sym_enum] = ACTIONS(2162),
    [anon_sym_class] = ACTIONS(2162),
    [anon_sym_struct] = ACTIONS(2162),
    [anon_sym_union] = ACTIONS(2162),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_else] = ACTIONS(2162),
    [anon_sym_switch] = ACTIONS(2162),
    [anon_sym_case] = ACTIONS(2162),
    [anon_sym_default] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(2162),
    [anon_sym_do] = ACTIONS(2162),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_return] = ACTIONS(2162),
    [anon_sym_break] = ACTIONS(2162),
    [anon_sym_continue] = ACTIONS(2162),
    [anon_sym_goto] = ACTIONS(2162),
    [anon_sym___try] = ACTIONS(2162),
    [anon_sym___leave] = ACTIONS(2162),
    [anon_sym_not] = ACTIONS(2162),
    [anon_sym_compl] = ACTIONS(2162),
    [anon_sym_DASH_DASH] = ACTIONS(2164),
    [anon_sym_PLUS_PLUS] = ACTIONS(2164),
    [anon_sym_sizeof] = ACTIONS(2162),
    [anon_sym___alignof__] = ACTIONS(2162),
    [anon_sym___alignof] = ACTIONS(2162),
    [anon_sym__alignof] = ACTIONS(2162),
    [anon_sym_alignof] = ACTIONS(2162),
    [anon_sym__Alignof] = ACTIONS(2162),
    [anon_sym_offsetof] = ACTIONS(2162),
    [anon_sym__Generic] = ACTIONS(2162),
    [anon_sym_asm] = ACTIONS(2162),
    [anon_sym___asm__] = ACTIONS(2162),
    [sym_number_literal] = ACTIONS(2164),
    [anon_sym_L_SQUOTE] = ACTIONS(2164),
    [anon_sym_u_SQUOTE] = ACTIONS(2164),
    [anon_sym_U_SQUOTE] = ACTIONS(2164),
    [anon_sym_u8_SQUOTE] = ACTIONS(2164),
    [anon_sym_SQUOTE] = ACTIONS(2164),
    [anon_sym_L_DQUOTE] = ACTIONS(2164),
    [anon_sym_u_DQUOTE] = ACTIONS(2164),
    [anon_sym_U_DQUOTE] = ACTIONS(2164),
    [anon_sym_u8_DQUOTE] = ACTIONS(2164),
    [anon_sym_DQUOTE] = ACTIONS(2164),
    [sym_true] = ACTIONS(2162),
    [sym_false] = ACTIONS(2162),
    [anon_sym_NULL] = ACTIONS(2162),
    [anon_sym_nullptr] = ACTIONS(2162),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2162),
    [anon_sym_decltype] = ACTIONS(2162),
    [sym_virtual] = ACTIONS(2162),
    [anon_sym_explicit] = ACTIONS(2162),
    [anon_sym_typename] = ACTIONS(2162),
    [anon_sym_template] = ACTIONS(2162),
    [anon_sym_operator] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2162),
    [anon_sym_delete] = ACTIONS(2162),
    [anon_sym_throw] = ACTIONS(2162),
    [anon_sym_namespace] = ACTIONS(2162),
    [anon_sym_using] = ACTIONS(2162),
    [anon_sym_static_assert] = ACTIONS(2162),
    [anon_sym_concept] = ACTIONS(2162),
    [anon_sym_co_return] = ACTIONS(2162),
    [anon_sym_co_yield] = ACTIONS(2162),
    [anon_sym_R_DQUOTE] = ACTIONS(2164),
    [anon_sym_LR_DQUOTE] = ACTIONS(2164),
    [anon_sym_uR_DQUOTE] = ACTIONS(2164),
    [anon_sym_UR_DQUOTE] = ACTIONS(2164),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2164),
    [anon_sym_co_await] = ACTIONS(2162),
    [anon_sym_new] = ACTIONS(2162),
    [anon_sym_requires] = ACTIONS(2162),
    [sym_this] = ACTIONS(2162),
    [anon_sym_discard] = ACTIONS(2162),
    [anon_sym_precise] = ACTIONS(2162),
    [anon_sym_shared] = ACTIONS(2162),
    [anon_sym_groupshared] = ACTIONS(2162),
    [anon_sym_uniform] = ACTIONS(2162),
    [anon_sym_row_major] = ACTIONS(2162),
    [anon_sym_column_major] = ACTIONS(2162),
    [anon_sym_globallycoherent] = ACTIONS(2162),
    [anon_sym_centroid] = ACTIONS(2162),
    [anon_sym_noperspective] = ACTIONS(2162),
    [anon_sym_nointerpolation] = ACTIONS(2162),
    [anon_sym_sample] = ACTIONS(2162),
    [anon_sym_linear] = ACTIONS(2162),
    [anon_sym_snorm] = ACTIONS(2162),
    [anon_sym_unorm] = ACTIONS(2162),
    [anon_sym_point] = ACTIONS(2162),
    [anon_sym_line] = ACTIONS(2162),
    [anon_sym_triangleadj] = ACTIONS(2162),
    [anon_sym_lineadj] = ACTIONS(2162),
    [anon_sym_triangle] = ACTIONS(2162),
    [anon_sym_cbuffer] = ACTIONS(2162),
  },
  [524] = {
    [sym_identifier] = ACTIONS(2256),
    [aux_sym_preproc_include_token1] = ACTIONS(2256),
    [aux_sym_preproc_def_token1] = ACTIONS(2256),
    [aux_sym_preproc_if_token1] = ACTIONS(2256),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2256),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2256),
    [sym_preproc_directive] = ACTIONS(2256),
    [anon_sym_LPAREN2] = ACTIONS(2258),
    [anon_sym_BANG] = ACTIONS(2258),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_DASH] = ACTIONS(2256),
    [anon_sym_PLUS] = ACTIONS(2256),
    [anon_sym_STAR] = ACTIONS(2258),
    [anon_sym_AMP_AMP] = ACTIONS(2258),
    [anon_sym_AMP] = ACTIONS(2256),
    [anon_sym_SEMI] = ACTIONS(2258),
    [anon_sym___extension__] = ACTIONS(2256),
    [anon_sym_typedef] = ACTIONS(2256),
    [anon_sym_in] = ACTIONS(2256),
    [anon_sym_out] = ACTIONS(2256),
    [anon_sym_inout] = ACTIONS(2256),
    [anon_sym_extern] = ACTIONS(2256),
    [anon_sym___attribute__] = ACTIONS(2256),
    [anon_sym_COLON_COLON] = ACTIONS(2258),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2258),
    [anon_sym___declspec] = ACTIONS(2256),
    [anon_sym___based] = ACTIONS(2256),
    [anon_sym___cdecl] = ACTIONS(2256),
    [anon_sym___clrcall] = ACTIONS(2256),
    [anon_sym___stdcall] = ACTIONS(2256),
    [anon_sym___fastcall] = ACTIONS(2256),
    [anon_sym___thiscall] = ACTIONS(2256),
    [anon_sym___vectorcall] = ACTIONS(2256),
    [anon_sym_LBRACE] = ACTIONS(2258),
    [anon_sym_RBRACE] = ACTIONS(2258),
    [anon_sym_signed] = ACTIONS(2256),
    [anon_sym_unsigned] = ACTIONS(2256),
    [anon_sym_long] = ACTIONS(2256),
    [anon_sym_short] = ACTIONS(2256),
    [anon_sym_LBRACK] = ACTIONS(2256),
    [anon_sym_static] = ACTIONS(2256),
    [anon_sym_register] = ACTIONS(2256),
    [anon_sym_inline] = ACTIONS(2256),
    [anon_sym___inline] = ACTIONS(2256),
    [anon_sym___inline__] = ACTIONS(2256),
    [anon_sym___forceinline] = ACTIONS(2256),
    [anon_sym_thread_local] = ACTIONS(2256),
    [anon_sym___thread] = ACTIONS(2256),
    [anon_sym_const] = ACTIONS(2256),
    [anon_sym_constexpr] = ACTIONS(2256),
    [anon_sym_volatile] = ACTIONS(2256),
    [anon_sym_restrict] = ACTIONS(2256),
    [anon_sym___restrict__] = ACTIONS(2256),
    [anon_sym__Atomic] = ACTIONS(2256),
    [anon_sym__Noreturn] = ACTIONS(2256),
    [anon_sym_noreturn] = ACTIONS(2256),
    [anon_sym_mutable] = ACTIONS(2256),
    [anon_sym_constinit] = ACTIONS(2256),
    [anon_sym_consteval] = ACTIONS(2256),
    [anon_sym_alignas] = ACTIONS(2256),
    [anon_sym__Alignas] = ACTIONS(2256),
    [sym_primitive_type] = ACTIONS(2256),
    [anon_sym_enum] = ACTIONS(2256),
    [anon_sym_class] = ACTIONS(2256),
    [anon_sym_struct] = ACTIONS(2256),
    [anon_sym_union] = ACTIONS(2256),
    [anon_sym_if] = ACTIONS(2256),
    [anon_sym_else] = ACTIONS(2256),
    [anon_sym_switch] = ACTIONS(2256),
    [anon_sym_case] = ACTIONS(2256),
    [anon_sym_default] = ACTIONS(2256),
    [anon_sym_while] = ACTIONS(2256),
    [anon_sym_do] = ACTIONS(2256),
    [anon_sym_for] = ACTIONS(2256),
    [anon_sym_return] = ACTIONS(2256),
    [anon_sym_break] = ACTIONS(2256),
    [anon_sym_continue] = ACTIONS(2256),
    [anon_sym_goto] = ACTIONS(2256),
    [anon_sym___try] = ACTIONS(2256),
    [anon_sym___leave] = ACTIONS(2256),
    [anon_sym_not] = ACTIONS(2256),
    [anon_sym_compl] = ACTIONS(2256),
    [anon_sym_DASH_DASH] = ACTIONS(2258),
    [anon_sym_PLUS_PLUS] = ACTIONS(2258),
    [anon_sym_sizeof] = ACTIONS(2256),
    [anon_sym___alignof__] = ACTIONS(2256),
    [anon_sym___alignof] = ACTIONS(2256),
    [anon_sym__alignof] = ACTIONS(2256),
    [anon_sym_alignof] = ACTIONS(2256),
    [anon_sym__Alignof] = ACTIONS(2256),
    [anon_sym_offsetof] = ACTIONS(2256),
    [anon_sym__Generic] = ACTIONS(2256),
    [anon_sym_asm] = ACTIONS(2256),
    [anon_sym___asm__] = ACTIONS(2256),
    [sym_number_literal] = ACTIONS(2258),
    [anon_sym_L_SQUOTE] = ACTIONS(2258),
    [anon_sym_u_SQUOTE] = ACTIONS(2258),
    [anon_sym_U_SQUOTE] = ACTIONS(2258),
    [anon_sym_u8_SQUOTE] = ACTIONS(2258),
    [anon_sym_SQUOTE] = ACTIONS(2258),
    [anon_sym_L_DQUOTE] = ACTIONS(2258),
    [anon_sym_u_DQUOTE] = ACTIONS(2258),
    [anon_sym_U_DQUOTE] = ACTIONS(2258),
    [anon_sym_u8_DQUOTE] = ACTIONS(2258),
    [anon_sym_DQUOTE] = ACTIONS(2258),
    [sym_true] = ACTIONS(2256),
    [sym_false] = ACTIONS(2256),
    [anon_sym_NULL] = ACTIONS(2256),
    [anon_sym_nullptr] = ACTIONS(2256),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2256),
    [anon_sym_decltype] = ACTIONS(2256),
    [sym_virtual] = ACTIONS(2256),
    [anon_sym_explicit] = ACTIONS(2256),
    [anon_sym_typename] = ACTIONS(2256),
    [anon_sym_template] = ACTIONS(2256),
    [anon_sym_operator] = ACTIONS(2256),
    [anon_sym_try] = ACTIONS(2256),
    [anon_sym_delete] = ACTIONS(2256),
    [anon_sym_throw] = ACTIONS(2256),
    [anon_sym_namespace] = ACTIONS(2256),
    [anon_sym_using] = ACTIONS(2256),
    [anon_sym_static_assert] = ACTIONS(2256),
    [anon_sym_concept] = ACTIONS(2256),
    [anon_sym_co_return] = ACTIONS(2256),
    [anon_sym_co_yield] = ACTIONS(2256),
    [anon_sym_R_DQUOTE] = ACTIONS(2258),
    [anon_sym_LR_DQUOTE] = ACTIONS(2258),
    [anon_sym_uR_DQUOTE] = ACTIONS(2258),
    [anon_sym_UR_DQUOTE] = ACTIONS(2258),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2258),
    [anon_sym_co_await] = ACTIONS(2256),
    [anon_sym_new] = ACTIONS(2256),
    [anon_sym_requires] = ACTIONS(2256),
    [sym_this] = ACTIONS(2256),
    [anon_sym_discard] = ACTIONS(2256),
    [anon_sym_precise] = ACTIONS(2256),
    [anon_sym_shared] = ACTIONS(2256),
    [anon_sym_groupshared] = ACTIONS(2256),
    [anon_sym_uniform] = ACTIONS(2256),
    [anon_sym_row_major] = ACTIONS(2256),
    [anon_sym_column_major] = ACTIONS(2256),
    [anon_sym_globallycoherent] = ACTIONS(2256),
    [anon_sym_centroid] = ACTIONS(2256),
    [anon_sym_noperspective] = ACTIONS(2256),
    [anon_sym_nointerpolation] = ACTIONS(2256),
    [anon_sym_sample] = ACTIONS(2256),
    [anon_sym_linear] = ACTIONS(2256),
    [anon_sym_snorm] = ACTIONS(2256),
    [anon_sym_unorm] = ACTIONS(2256),
    [anon_sym_point] = ACTIONS(2256),
    [anon_sym_line] = ACTIONS(2256),
    [anon_sym_triangleadj] = ACTIONS(2256),
    [anon_sym_lineadj] = ACTIONS(2256),
    [anon_sym_triangle] = ACTIONS(2256),
    [anon_sym_cbuffer] = ACTIONS(2256),
  },
  [525] = {
    [sym_identifier] = ACTIONS(2178),
    [aux_sym_preproc_include_token1] = ACTIONS(2178),
    [aux_sym_preproc_def_token1] = ACTIONS(2178),
    [aux_sym_preproc_if_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2178),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2178),
    [sym_preproc_directive] = ACTIONS(2178),
    [anon_sym_LPAREN2] = ACTIONS(2180),
    [anon_sym_BANG] = ACTIONS(2180),
    [anon_sym_TILDE] = ACTIONS(2180),
    [anon_sym_DASH] = ACTIONS(2178),
    [anon_sym_PLUS] = ACTIONS(2178),
    [anon_sym_STAR] = ACTIONS(2180),
    [anon_sym_AMP_AMP] = ACTIONS(2180),
    [anon_sym_AMP] = ACTIONS(2178),
    [anon_sym_SEMI] = ACTIONS(2180),
    [anon_sym___extension__] = ACTIONS(2178),
    [anon_sym_typedef] = ACTIONS(2178),
    [anon_sym_in] = ACTIONS(2178),
    [anon_sym_out] = ACTIONS(2178),
    [anon_sym_inout] = ACTIONS(2178),
    [anon_sym_extern] = ACTIONS(2178),
    [anon_sym___attribute__] = ACTIONS(2178),
    [anon_sym_COLON_COLON] = ACTIONS(2180),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2180),
    [anon_sym___declspec] = ACTIONS(2178),
    [anon_sym___based] = ACTIONS(2178),
    [anon_sym___cdecl] = ACTIONS(2178),
    [anon_sym___clrcall] = ACTIONS(2178),
    [anon_sym___stdcall] = ACTIONS(2178),
    [anon_sym___fastcall] = ACTIONS(2178),
    [anon_sym___thiscall] = ACTIONS(2178),
    [anon_sym___vectorcall] = ACTIONS(2178),
    [anon_sym_LBRACE] = ACTIONS(2180),
    [anon_sym_RBRACE] = ACTIONS(2180),
    [anon_sym_signed] = ACTIONS(2178),
    [anon_sym_unsigned] = ACTIONS(2178),
    [anon_sym_long] = ACTIONS(2178),
    [anon_sym_short] = ACTIONS(2178),
    [anon_sym_LBRACK] = ACTIONS(2178),
    [anon_sym_static] = ACTIONS(2178),
    [anon_sym_register] = ACTIONS(2178),
    [anon_sym_inline] = ACTIONS(2178),
    [anon_sym___inline] = ACTIONS(2178),
    [anon_sym___inline__] = ACTIONS(2178),
    [anon_sym___forceinline] = ACTIONS(2178),
    [anon_sym_thread_local] = ACTIONS(2178),
    [anon_sym___thread] = ACTIONS(2178),
    [anon_sym_const] = ACTIONS(2178),
    [anon_sym_constexpr] = ACTIONS(2178),
    [anon_sym_volatile] = ACTIONS(2178),
    [anon_sym_restrict] = ACTIONS(2178),
    [anon_sym___restrict__] = ACTIONS(2178),
    [anon_sym__Atomic] = ACTIONS(2178),
    [anon_sym__Noreturn] = ACTIONS(2178),
    [anon_sym_noreturn] = ACTIONS(2178),
    [anon_sym_mutable] = ACTIONS(2178),
    [anon_sym_constinit] = ACTIONS(2178),
    [anon_sym_consteval] = ACTIONS(2178),
    [anon_sym_alignas] = ACTIONS(2178),
    [anon_sym__Alignas] = ACTIONS(2178),
    [sym_primitive_type] = ACTIONS(2178),
    [anon_sym_enum] = ACTIONS(2178),
    [anon_sym_class] = ACTIONS(2178),
    [anon_sym_struct] = ACTIONS(2178),
    [anon_sym_union] = ACTIONS(2178),
    [anon_sym_if] = ACTIONS(2178),
    [anon_sym_else] = ACTIONS(2178),
    [anon_sym_switch] = ACTIONS(2178),
    [anon_sym_case] = ACTIONS(2178),
    [anon_sym_default] = ACTIONS(2178),
    [anon_sym_while] = ACTIONS(2178),
    [anon_sym_do] = ACTIONS(2178),
    [anon_sym_for] = ACTIONS(2178),
    [anon_sym_return] = ACTIONS(2178),
    [anon_sym_break] = ACTIONS(2178),
    [anon_sym_continue] = ACTIONS(2178),
    [anon_sym_goto] = ACTIONS(2178),
    [anon_sym___try] = ACTIONS(2178),
    [anon_sym___leave] = ACTIONS(2178),
    [anon_sym_not] = ACTIONS(2178),
    [anon_sym_compl] = ACTIONS(2178),
    [anon_sym_DASH_DASH] = ACTIONS(2180),
    [anon_sym_PLUS_PLUS] = ACTIONS(2180),
    [anon_sym_sizeof] = ACTIONS(2178),
    [anon_sym___alignof__] = ACTIONS(2178),
    [anon_sym___alignof] = ACTIONS(2178),
    [anon_sym__alignof] = ACTIONS(2178),
    [anon_sym_alignof] = ACTIONS(2178),
    [anon_sym__Alignof] = ACTIONS(2178),
    [anon_sym_offsetof] = ACTIONS(2178),
    [anon_sym__Generic] = ACTIONS(2178),
    [anon_sym_asm] = ACTIONS(2178),
    [anon_sym___asm__] = ACTIONS(2178),
    [sym_number_literal] = ACTIONS(2180),
    [anon_sym_L_SQUOTE] = ACTIONS(2180),
    [anon_sym_u_SQUOTE] = ACTIONS(2180),
    [anon_sym_U_SQUOTE] = ACTIONS(2180),
    [anon_sym_u8_SQUOTE] = ACTIONS(2180),
    [anon_sym_SQUOTE] = ACTIONS(2180),
    [anon_sym_L_DQUOTE] = ACTIONS(2180),
    [anon_sym_u_DQUOTE] = ACTIONS(2180),
    [anon_sym_U_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8_DQUOTE] = ACTIONS(2180),
    [anon_sym_DQUOTE] = ACTIONS(2180),
    [sym_true] = ACTIONS(2178),
    [sym_false] = ACTIONS(2178),
    [anon_sym_NULL] = ACTIONS(2178),
    [anon_sym_nullptr] = ACTIONS(2178),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2178),
    [anon_sym_decltype] = ACTIONS(2178),
    [sym_virtual] = ACTIONS(2178),
    [anon_sym_explicit] = ACTIONS(2178),
    [anon_sym_typename] = ACTIONS(2178),
    [anon_sym_template] = ACTIONS(2178),
    [anon_sym_operator] = ACTIONS(2178),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_delete] = ACTIONS(2178),
    [anon_sym_throw] = ACTIONS(2178),
    [anon_sym_namespace] = ACTIONS(2178),
    [anon_sym_using] = ACTIONS(2178),
    [anon_sym_static_assert] = ACTIONS(2178),
    [anon_sym_concept] = ACTIONS(2178),
    [anon_sym_co_return] = ACTIONS(2178),
    [anon_sym_co_yield] = ACTIONS(2178),
    [anon_sym_R_DQUOTE] = ACTIONS(2180),
    [anon_sym_LR_DQUOTE] = ACTIONS(2180),
    [anon_sym_uR_DQUOTE] = ACTIONS(2180),
    [anon_sym_UR_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2180),
    [anon_sym_co_await] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2178),
    [anon_sym_requires] = ACTIONS(2178),
    [sym_this] = ACTIONS(2178),
    [anon_sym_discard] = ACTIONS(2178),
    [anon_sym_precise] = ACTIONS(2178),
    [anon_sym_shared] = ACTIONS(2178),
    [anon_sym_groupshared] = ACTIONS(2178),
    [anon_sym_uniform] = ACTIONS(2178),
    [anon_sym_row_major] = ACTIONS(2178),
    [anon_sym_column_major] = ACTIONS(2178),
    [anon_sym_globallycoherent] = ACTIONS(2178),
    [anon_sym_centroid] = ACTIONS(2178),
    [anon_sym_noperspective] = ACTIONS(2178),
    [anon_sym_nointerpolation] = ACTIONS(2178),
    [anon_sym_sample] = ACTIONS(2178),
    [anon_sym_linear] = ACTIONS(2178),
    [anon_sym_snorm] = ACTIONS(2178),
    [anon_sym_unorm] = ACTIONS(2178),
    [anon_sym_point] = ACTIONS(2178),
    [anon_sym_line] = ACTIONS(2178),
    [anon_sym_triangleadj] = ACTIONS(2178),
    [anon_sym_lineadj] = ACTIONS(2178),
    [anon_sym_triangle] = ACTIONS(2178),
    [anon_sym_cbuffer] = ACTIONS(2178),
  },
  [526] = {
    [sym_identifier] = ACTIONS(2142),
    [aux_sym_preproc_include_token1] = ACTIONS(2142),
    [aux_sym_preproc_def_token1] = ACTIONS(2142),
    [aux_sym_preproc_if_token1] = ACTIONS(2142),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2142),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2142),
    [sym_preproc_directive] = ACTIONS(2142),
    [anon_sym_LPAREN2] = ACTIONS(2144),
    [anon_sym_BANG] = ACTIONS(2144),
    [anon_sym_TILDE] = ACTIONS(2144),
    [anon_sym_DASH] = ACTIONS(2142),
    [anon_sym_PLUS] = ACTIONS(2142),
    [anon_sym_STAR] = ACTIONS(2144),
    [anon_sym_AMP_AMP] = ACTIONS(2144),
    [anon_sym_AMP] = ACTIONS(2142),
    [anon_sym_SEMI] = ACTIONS(2144),
    [anon_sym___extension__] = ACTIONS(2142),
    [anon_sym_typedef] = ACTIONS(2142),
    [anon_sym_in] = ACTIONS(2142),
    [anon_sym_out] = ACTIONS(2142),
    [anon_sym_inout] = ACTIONS(2142),
    [anon_sym_extern] = ACTIONS(2142),
    [anon_sym___attribute__] = ACTIONS(2142),
    [anon_sym_COLON_COLON] = ACTIONS(2144),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2144),
    [anon_sym___declspec] = ACTIONS(2142),
    [anon_sym___based] = ACTIONS(2142),
    [anon_sym___cdecl] = ACTIONS(2142),
    [anon_sym___clrcall] = ACTIONS(2142),
    [anon_sym___stdcall] = ACTIONS(2142),
    [anon_sym___fastcall] = ACTIONS(2142),
    [anon_sym___thiscall] = ACTIONS(2142),
    [anon_sym___vectorcall] = ACTIONS(2142),
    [anon_sym_LBRACE] = ACTIONS(2144),
    [anon_sym_RBRACE] = ACTIONS(2144),
    [anon_sym_signed] = ACTIONS(2142),
    [anon_sym_unsigned] = ACTIONS(2142),
    [anon_sym_long] = ACTIONS(2142),
    [anon_sym_short] = ACTIONS(2142),
    [anon_sym_LBRACK] = ACTIONS(2142),
    [anon_sym_static] = ACTIONS(2142),
    [anon_sym_register] = ACTIONS(2142),
    [anon_sym_inline] = ACTIONS(2142),
    [anon_sym___inline] = ACTIONS(2142),
    [anon_sym___inline__] = ACTIONS(2142),
    [anon_sym___forceinline] = ACTIONS(2142),
    [anon_sym_thread_local] = ACTIONS(2142),
    [anon_sym___thread] = ACTIONS(2142),
    [anon_sym_const] = ACTIONS(2142),
    [anon_sym_constexpr] = ACTIONS(2142),
    [anon_sym_volatile] = ACTIONS(2142),
    [anon_sym_restrict] = ACTIONS(2142),
    [anon_sym___restrict__] = ACTIONS(2142),
    [anon_sym__Atomic] = ACTIONS(2142),
    [anon_sym__Noreturn] = ACTIONS(2142),
    [anon_sym_noreturn] = ACTIONS(2142),
    [anon_sym_mutable] = ACTIONS(2142),
    [anon_sym_constinit] = ACTIONS(2142),
    [anon_sym_consteval] = ACTIONS(2142),
    [anon_sym_alignas] = ACTIONS(2142),
    [anon_sym__Alignas] = ACTIONS(2142),
    [sym_primitive_type] = ACTIONS(2142),
    [anon_sym_enum] = ACTIONS(2142),
    [anon_sym_class] = ACTIONS(2142),
    [anon_sym_struct] = ACTIONS(2142),
    [anon_sym_union] = ACTIONS(2142),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_else] = ACTIONS(2142),
    [anon_sym_switch] = ACTIONS(2142),
    [anon_sym_case] = ACTIONS(2142),
    [anon_sym_default] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2142),
    [anon_sym_do] = ACTIONS(2142),
    [anon_sym_for] = ACTIONS(2142),
    [anon_sym_return] = ACTIONS(2142),
    [anon_sym_break] = ACTIONS(2142),
    [anon_sym_continue] = ACTIONS(2142),
    [anon_sym_goto] = ACTIONS(2142),
    [anon_sym___try] = ACTIONS(2142),
    [anon_sym___leave] = ACTIONS(2142),
    [anon_sym_not] = ACTIONS(2142),
    [anon_sym_compl] = ACTIONS(2142),
    [anon_sym_DASH_DASH] = ACTIONS(2144),
    [anon_sym_PLUS_PLUS] = ACTIONS(2144),
    [anon_sym_sizeof] = ACTIONS(2142),
    [anon_sym___alignof__] = ACTIONS(2142),
    [anon_sym___alignof] = ACTIONS(2142),
    [anon_sym__alignof] = ACTIONS(2142),
    [anon_sym_alignof] = ACTIONS(2142),
    [anon_sym__Alignof] = ACTIONS(2142),
    [anon_sym_offsetof] = ACTIONS(2142),
    [anon_sym__Generic] = ACTIONS(2142),
    [anon_sym_asm] = ACTIONS(2142),
    [anon_sym___asm__] = ACTIONS(2142),
    [sym_number_literal] = ACTIONS(2144),
    [anon_sym_L_SQUOTE] = ACTIONS(2144),
    [anon_sym_u_SQUOTE] = ACTIONS(2144),
    [anon_sym_U_SQUOTE] = ACTIONS(2144),
    [anon_sym_u8_SQUOTE] = ACTIONS(2144),
    [anon_sym_SQUOTE] = ACTIONS(2144),
    [anon_sym_L_DQUOTE] = ACTIONS(2144),
    [anon_sym_u_DQUOTE] = ACTIONS(2144),
    [anon_sym_U_DQUOTE] = ACTIONS(2144),
    [anon_sym_u8_DQUOTE] = ACTIONS(2144),
    [anon_sym_DQUOTE] = ACTIONS(2144),
    [sym_true] = ACTIONS(2142),
    [sym_false] = ACTIONS(2142),
    [anon_sym_NULL] = ACTIONS(2142),
    [anon_sym_nullptr] = ACTIONS(2142),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2142),
    [anon_sym_decltype] = ACTIONS(2142),
    [sym_virtual] = ACTIONS(2142),
    [anon_sym_explicit] = ACTIONS(2142),
    [anon_sym_typename] = ACTIONS(2142),
    [anon_sym_template] = ACTIONS(2142),
    [anon_sym_operator] = ACTIONS(2142),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_delete] = ACTIONS(2142),
    [anon_sym_throw] = ACTIONS(2142),
    [anon_sym_namespace] = ACTIONS(2142),
    [anon_sym_using] = ACTIONS(2142),
    [anon_sym_static_assert] = ACTIONS(2142),
    [anon_sym_concept] = ACTIONS(2142),
    [anon_sym_co_return] = ACTIONS(2142),
    [anon_sym_co_yield] = ACTIONS(2142),
    [anon_sym_R_DQUOTE] = ACTIONS(2144),
    [anon_sym_LR_DQUOTE] = ACTIONS(2144),
    [anon_sym_uR_DQUOTE] = ACTIONS(2144),
    [anon_sym_UR_DQUOTE] = ACTIONS(2144),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2144),
    [anon_sym_co_await] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(2142),
    [anon_sym_requires] = ACTIONS(2142),
    [sym_this] = ACTIONS(2142),
    [anon_sym_discard] = ACTIONS(2142),
    [anon_sym_precise] = ACTIONS(2142),
    [anon_sym_shared] = ACTIONS(2142),
    [anon_sym_groupshared] = ACTIONS(2142),
    [anon_sym_uniform] = ACTIONS(2142),
    [anon_sym_row_major] = ACTIONS(2142),
    [anon_sym_column_major] = ACTIONS(2142),
    [anon_sym_globallycoherent] = ACTIONS(2142),
    [anon_sym_centroid] = ACTIONS(2142),
    [anon_sym_noperspective] = ACTIONS(2142),
    [anon_sym_nointerpolation] = ACTIONS(2142),
    [anon_sym_sample] = ACTIONS(2142),
    [anon_sym_linear] = ACTIONS(2142),
    [anon_sym_snorm] = ACTIONS(2142),
    [anon_sym_unorm] = ACTIONS(2142),
    [anon_sym_point] = ACTIONS(2142),
    [anon_sym_line] = ACTIONS(2142),
    [anon_sym_triangleadj] = ACTIONS(2142),
    [anon_sym_lineadj] = ACTIONS(2142),
    [anon_sym_triangle] = ACTIONS(2142),
    [anon_sym_cbuffer] = ACTIONS(2142),
  },
  [527] = {
    [sym_identifier] = ACTIONS(2264),
    [aux_sym_preproc_include_token1] = ACTIONS(2264),
    [aux_sym_preproc_def_token1] = ACTIONS(2264),
    [aux_sym_preproc_if_token1] = ACTIONS(2264),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2264),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2264),
    [sym_preproc_directive] = ACTIONS(2264),
    [anon_sym_LPAREN2] = ACTIONS(2266),
    [anon_sym_BANG] = ACTIONS(2266),
    [anon_sym_TILDE] = ACTIONS(2266),
    [anon_sym_DASH] = ACTIONS(2264),
    [anon_sym_PLUS] = ACTIONS(2264),
    [anon_sym_STAR] = ACTIONS(2266),
    [anon_sym_AMP_AMP] = ACTIONS(2266),
    [anon_sym_AMP] = ACTIONS(2264),
    [anon_sym_SEMI] = ACTIONS(2266),
    [anon_sym___extension__] = ACTIONS(2264),
    [anon_sym_typedef] = ACTIONS(2264),
    [anon_sym_in] = ACTIONS(2264),
    [anon_sym_out] = ACTIONS(2264),
    [anon_sym_inout] = ACTIONS(2264),
    [anon_sym_extern] = ACTIONS(2264),
    [anon_sym___attribute__] = ACTIONS(2264),
    [anon_sym_COLON_COLON] = ACTIONS(2266),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2266),
    [anon_sym___declspec] = ACTIONS(2264),
    [anon_sym___based] = ACTIONS(2264),
    [anon_sym___cdecl] = ACTIONS(2264),
    [anon_sym___clrcall] = ACTIONS(2264),
    [anon_sym___stdcall] = ACTIONS(2264),
    [anon_sym___fastcall] = ACTIONS(2264),
    [anon_sym___thiscall] = ACTIONS(2264),
    [anon_sym___vectorcall] = ACTIONS(2264),
    [anon_sym_LBRACE] = ACTIONS(2266),
    [anon_sym_RBRACE] = ACTIONS(2266),
    [anon_sym_signed] = ACTIONS(2264),
    [anon_sym_unsigned] = ACTIONS(2264),
    [anon_sym_long] = ACTIONS(2264),
    [anon_sym_short] = ACTIONS(2264),
    [anon_sym_LBRACK] = ACTIONS(2264),
    [anon_sym_static] = ACTIONS(2264),
    [anon_sym_register] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(2264),
    [anon_sym___inline] = ACTIONS(2264),
    [anon_sym___inline__] = ACTIONS(2264),
    [anon_sym___forceinline] = ACTIONS(2264),
    [anon_sym_thread_local] = ACTIONS(2264),
    [anon_sym___thread] = ACTIONS(2264),
    [anon_sym_const] = ACTIONS(2264),
    [anon_sym_constexpr] = ACTIONS(2264),
    [anon_sym_volatile] = ACTIONS(2264),
    [anon_sym_restrict] = ACTIONS(2264),
    [anon_sym___restrict__] = ACTIONS(2264),
    [anon_sym__Atomic] = ACTIONS(2264),
    [anon_sym__Noreturn] = ACTIONS(2264),
    [anon_sym_noreturn] = ACTIONS(2264),
    [anon_sym_mutable] = ACTIONS(2264),
    [anon_sym_constinit] = ACTIONS(2264),
    [anon_sym_consteval] = ACTIONS(2264),
    [anon_sym_alignas] = ACTIONS(2264),
    [anon_sym__Alignas] = ACTIONS(2264),
    [sym_primitive_type] = ACTIONS(2264),
    [anon_sym_enum] = ACTIONS(2264),
    [anon_sym_class] = ACTIONS(2264),
    [anon_sym_struct] = ACTIONS(2264),
    [anon_sym_union] = ACTIONS(2264),
    [anon_sym_if] = ACTIONS(2264),
    [anon_sym_else] = ACTIONS(2264),
    [anon_sym_switch] = ACTIONS(2264),
    [anon_sym_case] = ACTIONS(2264),
    [anon_sym_default] = ACTIONS(2264),
    [anon_sym_while] = ACTIONS(2264),
    [anon_sym_do] = ACTIONS(2264),
    [anon_sym_for] = ACTIONS(2264),
    [anon_sym_return] = ACTIONS(2264),
    [anon_sym_break] = ACTIONS(2264),
    [anon_sym_continue] = ACTIONS(2264),
    [anon_sym_goto] = ACTIONS(2264),
    [anon_sym___try] = ACTIONS(2264),
    [anon_sym___leave] = ACTIONS(2264),
    [anon_sym_not] = ACTIONS(2264),
    [anon_sym_compl] = ACTIONS(2264),
    [anon_sym_DASH_DASH] = ACTIONS(2266),
    [anon_sym_PLUS_PLUS] = ACTIONS(2266),
    [anon_sym_sizeof] = ACTIONS(2264),
    [anon_sym___alignof__] = ACTIONS(2264),
    [anon_sym___alignof] = ACTIONS(2264),
    [anon_sym__alignof] = ACTIONS(2264),
    [anon_sym_alignof] = ACTIONS(2264),
    [anon_sym__Alignof] = ACTIONS(2264),
    [anon_sym_offsetof] = ACTIONS(2264),
    [anon_sym__Generic] = ACTIONS(2264),
    [anon_sym_asm] = ACTIONS(2264),
    [anon_sym___asm__] = ACTIONS(2264),
    [sym_number_literal] = ACTIONS(2266),
    [anon_sym_L_SQUOTE] = ACTIONS(2266),
    [anon_sym_u_SQUOTE] = ACTIONS(2266),
    [anon_sym_U_SQUOTE] = ACTIONS(2266),
    [anon_sym_u8_SQUOTE] = ACTIONS(2266),
    [anon_sym_SQUOTE] = ACTIONS(2266),
    [anon_sym_L_DQUOTE] = ACTIONS(2266),
    [anon_sym_u_DQUOTE] = ACTIONS(2266),
    [anon_sym_U_DQUOTE] = ACTIONS(2266),
    [anon_sym_u8_DQUOTE] = ACTIONS(2266),
    [anon_sym_DQUOTE] = ACTIONS(2266),
    [sym_true] = ACTIONS(2264),
    [sym_false] = ACTIONS(2264),
    [anon_sym_NULL] = ACTIONS(2264),
    [anon_sym_nullptr] = ACTIONS(2264),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2264),
    [anon_sym_decltype] = ACTIONS(2264),
    [sym_virtual] = ACTIONS(2264),
    [anon_sym_explicit] = ACTIONS(2264),
    [anon_sym_typename] = ACTIONS(2264),
    [anon_sym_template] = ACTIONS(2264),
    [anon_sym_operator] = ACTIONS(2264),
    [anon_sym_try] = ACTIONS(2264),
    [anon_sym_delete] = ACTIONS(2264),
    [anon_sym_throw] = ACTIONS(2264),
    [anon_sym_namespace] = ACTIONS(2264),
    [anon_sym_using] = ACTIONS(2264),
    [anon_sym_static_assert] = ACTIONS(2264),
    [anon_sym_concept] = ACTIONS(2264),
    [anon_sym_co_return] = ACTIONS(2264),
    [anon_sym_co_yield] = ACTIONS(2264),
    [anon_sym_R_DQUOTE] = ACTIONS(2266),
    [anon_sym_LR_DQUOTE] = ACTIONS(2266),
    [anon_sym_uR_DQUOTE] = ACTIONS(2266),
    [anon_sym_UR_DQUOTE] = ACTIONS(2266),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2266),
    [anon_sym_co_await] = ACTIONS(2264),
    [anon_sym_new] = ACTIONS(2264),
    [anon_sym_requires] = ACTIONS(2264),
    [sym_this] = ACTIONS(2264),
    [anon_sym_discard] = ACTIONS(2264),
    [anon_sym_precise] = ACTIONS(2264),
    [anon_sym_shared] = ACTIONS(2264),
    [anon_sym_groupshared] = ACTIONS(2264),
    [anon_sym_uniform] = ACTIONS(2264),
    [anon_sym_row_major] = ACTIONS(2264),
    [anon_sym_column_major] = ACTIONS(2264),
    [anon_sym_globallycoherent] = ACTIONS(2264),
    [anon_sym_centroid] = ACTIONS(2264),
    [anon_sym_noperspective] = ACTIONS(2264),
    [anon_sym_nointerpolation] = ACTIONS(2264),
    [anon_sym_sample] = ACTIONS(2264),
    [anon_sym_linear] = ACTIONS(2264),
    [anon_sym_snorm] = ACTIONS(2264),
    [anon_sym_unorm] = ACTIONS(2264),
    [anon_sym_point] = ACTIONS(2264),
    [anon_sym_line] = ACTIONS(2264),
    [anon_sym_triangleadj] = ACTIONS(2264),
    [anon_sym_lineadj] = ACTIONS(2264),
    [anon_sym_triangle] = ACTIONS(2264),
    [anon_sym_cbuffer] = ACTIONS(2264),
  },
  [528] = {
    [sym_identifier] = ACTIONS(2182),
    [aux_sym_preproc_include_token1] = ACTIONS(2182),
    [aux_sym_preproc_def_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token2] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2182),
    [sym_preproc_directive] = ACTIONS(2182),
    [anon_sym_LPAREN2] = ACTIONS(2184),
    [anon_sym_BANG] = ACTIONS(2184),
    [anon_sym_TILDE] = ACTIONS(2184),
    [anon_sym_DASH] = ACTIONS(2182),
    [anon_sym_PLUS] = ACTIONS(2182),
    [anon_sym_STAR] = ACTIONS(2184),
    [anon_sym_AMP_AMP] = ACTIONS(2184),
    [anon_sym_AMP] = ACTIONS(2182),
    [anon_sym_SEMI] = ACTIONS(2184),
    [anon_sym___extension__] = ACTIONS(2182),
    [anon_sym_typedef] = ACTIONS(2182),
    [anon_sym_in] = ACTIONS(2182),
    [anon_sym_out] = ACTIONS(2182),
    [anon_sym_inout] = ACTIONS(2182),
    [anon_sym_extern] = ACTIONS(2182),
    [anon_sym___attribute__] = ACTIONS(2182),
    [anon_sym_COLON_COLON] = ACTIONS(2184),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2184),
    [anon_sym___declspec] = ACTIONS(2182),
    [anon_sym___based] = ACTIONS(2182),
    [anon_sym___cdecl] = ACTIONS(2182),
    [anon_sym___clrcall] = ACTIONS(2182),
    [anon_sym___stdcall] = ACTIONS(2182),
    [anon_sym___fastcall] = ACTIONS(2182),
    [anon_sym___thiscall] = ACTIONS(2182),
    [anon_sym___vectorcall] = ACTIONS(2182),
    [anon_sym_LBRACE] = ACTIONS(2184),
    [anon_sym_signed] = ACTIONS(2182),
    [anon_sym_unsigned] = ACTIONS(2182),
    [anon_sym_long] = ACTIONS(2182),
    [anon_sym_short] = ACTIONS(2182),
    [anon_sym_LBRACK] = ACTIONS(2182),
    [anon_sym_static] = ACTIONS(2182),
    [anon_sym_register] = ACTIONS(2182),
    [anon_sym_inline] = ACTIONS(2182),
    [anon_sym___inline] = ACTIONS(2182),
    [anon_sym___inline__] = ACTIONS(2182),
    [anon_sym___forceinline] = ACTIONS(2182),
    [anon_sym_thread_local] = ACTIONS(2182),
    [anon_sym___thread] = ACTIONS(2182),
    [anon_sym_const] = ACTIONS(2182),
    [anon_sym_constexpr] = ACTIONS(2182),
    [anon_sym_volatile] = ACTIONS(2182),
    [anon_sym_restrict] = ACTIONS(2182),
    [anon_sym___restrict__] = ACTIONS(2182),
    [anon_sym__Atomic] = ACTIONS(2182),
    [anon_sym__Noreturn] = ACTIONS(2182),
    [anon_sym_noreturn] = ACTIONS(2182),
    [anon_sym_mutable] = ACTIONS(2182),
    [anon_sym_constinit] = ACTIONS(2182),
    [anon_sym_consteval] = ACTIONS(2182),
    [anon_sym_alignas] = ACTIONS(2182),
    [anon_sym__Alignas] = ACTIONS(2182),
    [sym_primitive_type] = ACTIONS(2182),
    [anon_sym_enum] = ACTIONS(2182),
    [anon_sym_class] = ACTIONS(2182),
    [anon_sym_struct] = ACTIONS(2182),
    [anon_sym_union] = ACTIONS(2182),
    [anon_sym_if] = ACTIONS(2182),
    [anon_sym_else] = ACTIONS(2182),
    [anon_sym_switch] = ACTIONS(2182),
    [anon_sym_case] = ACTIONS(2182),
    [anon_sym_default] = ACTIONS(2182),
    [anon_sym_while] = ACTIONS(2182),
    [anon_sym_do] = ACTIONS(2182),
    [anon_sym_for] = ACTIONS(2182),
    [anon_sym_return] = ACTIONS(2182),
    [anon_sym_break] = ACTIONS(2182),
    [anon_sym_continue] = ACTIONS(2182),
    [anon_sym_goto] = ACTIONS(2182),
    [anon_sym___try] = ACTIONS(2182),
    [anon_sym___leave] = ACTIONS(2182),
    [anon_sym_not] = ACTIONS(2182),
    [anon_sym_compl] = ACTIONS(2182),
    [anon_sym_DASH_DASH] = ACTIONS(2184),
    [anon_sym_PLUS_PLUS] = ACTIONS(2184),
    [anon_sym_sizeof] = ACTIONS(2182),
    [anon_sym___alignof__] = ACTIONS(2182),
    [anon_sym___alignof] = ACTIONS(2182),
    [anon_sym__alignof] = ACTIONS(2182),
    [anon_sym_alignof] = ACTIONS(2182),
    [anon_sym__Alignof] = ACTIONS(2182),
    [anon_sym_offsetof] = ACTIONS(2182),
    [anon_sym__Generic] = ACTIONS(2182),
    [anon_sym_asm] = ACTIONS(2182),
    [anon_sym___asm__] = ACTIONS(2182),
    [sym_number_literal] = ACTIONS(2184),
    [anon_sym_L_SQUOTE] = ACTIONS(2184),
    [anon_sym_u_SQUOTE] = ACTIONS(2184),
    [anon_sym_U_SQUOTE] = ACTIONS(2184),
    [anon_sym_u8_SQUOTE] = ACTIONS(2184),
    [anon_sym_SQUOTE] = ACTIONS(2184),
    [anon_sym_L_DQUOTE] = ACTIONS(2184),
    [anon_sym_u_DQUOTE] = ACTIONS(2184),
    [anon_sym_U_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8_DQUOTE] = ACTIONS(2184),
    [anon_sym_DQUOTE] = ACTIONS(2184),
    [sym_true] = ACTIONS(2182),
    [sym_false] = ACTIONS(2182),
    [anon_sym_NULL] = ACTIONS(2182),
    [anon_sym_nullptr] = ACTIONS(2182),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2182),
    [anon_sym_decltype] = ACTIONS(2182),
    [sym_virtual] = ACTIONS(2182),
    [anon_sym_explicit] = ACTIONS(2182),
    [anon_sym_typename] = ACTIONS(2182),
    [anon_sym_template] = ACTIONS(2182),
    [anon_sym_operator] = ACTIONS(2182),
    [anon_sym_try] = ACTIONS(2182),
    [anon_sym_delete] = ACTIONS(2182),
    [anon_sym_throw] = ACTIONS(2182),
    [anon_sym_namespace] = ACTIONS(2182),
    [anon_sym_using] = ACTIONS(2182),
    [anon_sym_static_assert] = ACTIONS(2182),
    [anon_sym_concept] = ACTIONS(2182),
    [anon_sym_co_return] = ACTIONS(2182),
    [anon_sym_co_yield] = ACTIONS(2182),
    [anon_sym_R_DQUOTE] = ACTIONS(2184),
    [anon_sym_LR_DQUOTE] = ACTIONS(2184),
    [anon_sym_uR_DQUOTE] = ACTIONS(2184),
    [anon_sym_UR_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2184),
    [anon_sym_co_await] = ACTIONS(2182),
    [anon_sym_new] = ACTIONS(2182),
    [anon_sym_requires] = ACTIONS(2182),
    [sym_this] = ACTIONS(2182),
    [anon_sym_discard] = ACTIONS(2182),
    [anon_sym_precise] = ACTIONS(2182),
    [anon_sym_shared] = ACTIONS(2182),
    [anon_sym_groupshared] = ACTIONS(2182),
    [anon_sym_uniform] = ACTIONS(2182),
    [anon_sym_row_major] = ACTIONS(2182),
    [anon_sym_column_major] = ACTIONS(2182),
    [anon_sym_globallycoherent] = ACTIONS(2182),
    [anon_sym_centroid] = ACTIONS(2182),
    [anon_sym_noperspective] = ACTIONS(2182),
    [anon_sym_nointerpolation] = ACTIONS(2182),
    [anon_sym_sample] = ACTIONS(2182),
    [anon_sym_linear] = ACTIONS(2182),
    [anon_sym_snorm] = ACTIONS(2182),
    [anon_sym_unorm] = ACTIONS(2182),
    [anon_sym_point] = ACTIONS(2182),
    [anon_sym_line] = ACTIONS(2182),
    [anon_sym_triangleadj] = ACTIONS(2182),
    [anon_sym_lineadj] = ACTIONS(2182),
    [anon_sym_triangle] = ACTIONS(2182),
    [anon_sym_cbuffer] = ACTIONS(2182),
  },
  [529] = {
    [ts_builtin_sym_end] = ACTIONS(2230),
    [sym_identifier] = ACTIONS(2228),
    [aux_sym_preproc_include_token1] = ACTIONS(2228),
    [aux_sym_preproc_def_token1] = ACTIONS(2228),
    [aux_sym_preproc_if_token1] = ACTIONS(2228),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2228),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2228),
    [sym_preproc_directive] = ACTIONS(2228),
    [anon_sym_LPAREN2] = ACTIONS(2230),
    [anon_sym_BANG] = ACTIONS(2230),
    [anon_sym_TILDE] = ACTIONS(2230),
    [anon_sym_DASH] = ACTIONS(2228),
    [anon_sym_PLUS] = ACTIONS(2228),
    [anon_sym_STAR] = ACTIONS(2230),
    [anon_sym_AMP_AMP] = ACTIONS(2230),
    [anon_sym_AMP] = ACTIONS(2228),
    [anon_sym_SEMI] = ACTIONS(2230),
    [anon_sym___extension__] = ACTIONS(2228),
    [anon_sym_typedef] = ACTIONS(2228),
    [anon_sym_in] = ACTIONS(2228),
    [anon_sym_out] = ACTIONS(2228),
    [anon_sym_inout] = ACTIONS(2228),
    [anon_sym_extern] = ACTIONS(2228),
    [anon_sym___attribute__] = ACTIONS(2228),
    [anon_sym_COLON_COLON] = ACTIONS(2230),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2230),
    [anon_sym___declspec] = ACTIONS(2228),
    [anon_sym___based] = ACTIONS(2228),
    [anon_sym___cdecl] = ACTIONS(2228),
    [anon_sym___clrcall] = ACTIONS(2228),
    [anon_sym___stdcall] = ACTIONS(2228),
    [anon_sym___fastcall] = ACTIONS(2228),
    [anon_sym___thiscall] = ACTIONS(2228),
    [anon_sym___vectorcall] = ACTIONS(2228),
    [anon_sym_LBRACE] = ACTIONS(2230),
    [anon_sym_signed] = ACTIONS(2228),
    [anon_sym_unsigned] = ACTIONS(2228),
    [anon_sym_long] = ACTIONS(2228),
    [anon_sym_short] = ACTIONS(2228),
    [anon_sym_LBRACK] = ACTIONS(2228),
    [anon_sym_static] = ACTIONS(2228),
    [anon_sym_register] = ACTIONS(2228),
    [anon_sym_inline] = ACTIONS(2228),
    [anon_sym___inline] = ACTIONS(2228),
    [anon_sym___inline__] = ACTIONS(2228),
    [anon_sym___forceinline] = ACTIONS(2228),
    [anon_sym_thread_local] = ACTIONS(2228),
    [anon_sym___thread] = ACTIONS(2228),
    [anon_sym_const] = ACTIONS(2228),
    [anon_sym_constexpr] = ACTIONS(2228),
    [anon_sym_volatile] = ACTIONS(2228),
    [anon_sym_restrict] = ACTIONS(2228),
    [anon_sym___restrict__] = ACTIONS(2228),
    [anon_sym__Atomic] = ACTIONS(2228),
    [anon_sym__Noreturn] = ACTIONS(2228),
    [anon_sym_noreturn] = ACTIONS(2228),
    [anon_sym_mutable] = ACTIONS(2228),
    [anon_sym_constinit] = ACTIONS(2228),
    [anon_sym_consteval] = ACTIONS(2228),
    [anon_sym_alignas] = ACTIONS(2228),
    [anon_sym__Alignas] = ACTIONS(2228),
    [sym_primitive_type] = ACTIONS(2228),
    [anon_sym_enum] = ACTIONS(2228),
    [anon_sym_class] = ACTIONS(2228),
    [anon_sym_struct] = ACTIONS(2228),
    [anon_sym_union] = ACTIONS(2228),
    [anon_sym_if] = ACTIONS(2228),
    [anon_sym_else] = ACTIONS(2228),
    [anon_sym_switch] = ACTIONS(2228),
    [anon_sym_case] = ACTIONS(2228),
    [anon_sym_default] = ACTIONS(2228),
    [anon_sym_while] = ACTIONS(2228),
    [anon_sym_do] = ACTIONS(2228),
    [anon_sym_for] = ACTIONS(2228),
    [anon_sym_return] = ACTIONS(2228),
    [anon_sym_break] = ACTIONS(2228),
    [anon_sym_continue] = ACTIONS(2228),
    [anon_sym_goto] = ACTIONS(2228),
    [anon_sym___try] = ACTIONS(2228),
    [anon_sym___leave] = ACTIONS(2228),
    [anon_sym_not] = ACTIONS(2228),
    [anon_sym_compl] = ACTIONS(2228),
    [anon_sym_DASH_DASH] = ACTIONS(2230),
    [anon_sym_PLUS_PLUS] = ACTIONS(2230),
    [anon_sym_sizeof] = ACTIONS(2228),
    [anon_sym___alignof__] = ACTIONS(2228),
    [anon_sym___alignof] = ACTIONS(2228),
    [anon_sym__alignof] = ACTIONS(2228),
    [anon_sym_alignof] = ACTIONS(2228),
    [anon_sym__Alignof] = ACTIONS(2228),
    [anon_sym_offsetof] = ACTIONS(2228),
    [anon_sym__Generic] = ACTIONS(2228),
    [anon_sym_asm] = ACTIONS(2228),
    [anon_sym___asm__] = ACTIONS(2228),
    [sym_number_literal] = ACTIONS(2230),
    [anon_sym_L_SQUOTE] = ACTIONS(2230),
    [anon_sym_u_SQUOTE] = ACTIONS(2230),
    [anon_sym_U_SQUOTE] = ACTIONS(2230),
    [anon_sym_u8_SQUOTE] = ACTIONS(2230),
    [anon_sym_SQUOTE] = ACTIONS(2230),
    [anon_sym_L_DQUOTE] = ACTIONS(2230),
    [anon_sym_u_DQUOTE] = ACTIONS(2230),
    [anon_sym_U_DQUOTE] = ACTIONS(2230),
    [anon_sym_u8_DQUOTE] = ACTIONS(2230),
    [anon_sym_DQUOTE] = ACTIONS(2230),
    [sym_true] = ACTIONS(2228),
    [sym_false] = ACTIONS(2228),
    [anon_sym_NULL] = ACTIONS(2228),
    [anon_sym_nullptr] = ACTIONS(2228),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2228),
    [anon_sym_decltype] = ACTIONS(2228),
    [sym_virtual] = ACTIONS(2228),
    [anon_sym_explicit] = ACTIONS(2228),
    [anon_sym_typename] = ACTIONS(2228),
    [anon_sym_template] = ACTIONS(2228),
    [anon_sym_operator] = ACTIONS(2228),
    [anon_sym_try] = ACTIONS(2228),
    [anon_sym_delete] = ACTIONS(2228),
    [anon_sym_throw] = ACTIONS(2228),
    [anon_sym_namespace] = ACTIONS(2228),
    [anon_sym_using] = ACTIONS(2228),
    [anon_sym_static_assert] = ACTIONS(2228),
    [anon_sym_concept] = ACTIONS(2228),
    [anon_sym_co_return] = ACTIONS(2228),
    [anon_sym_co_yield] = ACTIONS(2228),
    [anon_sym_R_DQUOTE] = ACTIONS(2230),
    [anon_sym_LR_DQUOTE] = ACTIONS(2230),
    [anon_sym_uR_DQUOTE] = ACTIONS(2230),
    [anon_sym_UR_DQUOTE] = ACTIONS(2230),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2230),
    [anon_sym_co_await] = ACTIONS(2228),
    [anon_sym_new] = ACTIONS(2228),
    [anon_sym_requires] = ACTIONS(2228),
    [sym_this] = ACTIONS(2228),
    [anon_sym_discard] = ACTIONS(2228),
    [anon_sym_precise] = ACTIONS(2228),
    [anon_sym_shared] = ACTIONS(2228),
    [anon_sym_groupshared] = ACTIONS(2228),
    [anon_sym_uniform] = ACTIONS(2228),
    [anon_sym_row_major] = ACTIONS(2228),
    [anon_sym_column_major] = ACTIONS(2228),
    [anon_sym_globallycoherent] = ACTIONS(2228),
    [anon_sym_centroid] = ACTIONS(2228),
    [anon_sym_noperspective] = ACTIONS(2228),
    [anon_sym_nointerpolation] = ACTIONS(2228),
    [anon_sym_sample] = ACTIONS(2228),
    [anon_sym_linear] = ACTIONS(2228),
    [anon_sym_snorm] = ACTIONS(2228),
    [anon_sym_unorm] = ACTIONS(2228),
    [anon_sym_point] = ACTIONS(2228),
    [anon_sym_line] = ACTIONS(2228),
    [anon_sym_triangleadj] = ACTIONS(2228),
    [anon_sym_lineadj] = ACTIONS(2228),
    [anon_sym_triangle] = ACTIONS(2228),
    [anon_sym_cbuffer] = ACTIONS(2228),
  },
  [530] = {
    [sym_identifier] = ACTIONS(2182),
    [aux_sym_preproc_include_token1] = ACTIONS(2182),
    [aux_sym_preproc_def_token1] = ACTIONS(2182),
    [aux_sym_preproc_if_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2182),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2182),
    [sym_preproc_directive] = ACTIONS(2182),
    [anon_sym_LPAREN2] = ACTIONS(2184),
    [anon_sym_BANG] = ACTIONS(2184),
    [anon_sym_TILDE] = ACTIONS(2184),
    [anon_sym_DASH] = ACTIONS(2182),
    [anon_sym_PLUS] = ACTIONS(2182),
    [anon_sym_STAR] = ACTIONS(2184),
    [anon_sym_AMP_AMP] = ACTIONS(2184),
    [anon_sym_AMP] = ACTIONS(2182),
    [anon_sym_SEMI] = ACTIONS(2184),
    [anon_sym___extension__] = ACTIONS(2182),
    [anon_sym_typedef] = ACTIONS(2182),
    [anon_sym_in] = ACTIONS(2182),
    [anon_sym_out] = ACTIONS(2182),
    [anon_sym_inout] = ACTIONS(2182),
    [anon_sym_extern] = ACTIONS(2182),
    [anon_sym___attribute__] = ACTIONS(2182),
    [anon_sym_COLON_COLON] = ACTIONS(2184),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2184),
    [anon_sym___declspec] = ACTIONS(2182),
    [anon_sym___based] = ACTIONS(2182),
    [anon_sym___cdecl] = ACTIONS(2182),
    [anon_sym___clrcall] = ACTIONS(2182),
    [anon_sym___stdcall] = ACTIONS(2182),
    [anon_sym___fastcall] = ACTIONS(2182),
    [anon_sym___thiscall] = ACTIONS(2182),
    [anon_sym___vectorcall] = ACTIONS(2182),
    [anon_sym_LBRACE] = ACTIONS(2184),
    [anon_sym_RBRACE] = ACTIONS(2184),
    [anon_sym_signed] = ACTIONS(2182),
    [anon_sym_unsigned] = ACTIONS(2182),
    [anon_sym_long] = ACTIONS(2182),
    [anon_sym_short] = ACTIONS(2182),
    [anon_sym_LBRACK] = ACTIONS(2182),
    [anon_sym_static] = ACTIONS(2182),
    [anon_sym_register] = ACTIONS(2182),
    [anon_sym_inline] = ACTIONS(2182),
    [anon_sym___inline] = ACTIONS(2182),
    [anon_sym___inline__] = ACTIONS(2182),
    [anon_sym___forceinline] = ACTIONS(2182),
    [anon_sym_thread_local] = ACTIONS(2182),
    [anon_sym___thread] = ACTIONS(2182),
    [anon_sym_const] = ACTIONS(2182),
    [anon_sym_constexpr] = ACTIONS(2182),
    [anon_sym_volatile] = ACTIONS(2182),
    [anon_sym_restrict] = ACTIONS(2182),
    [anon_sym___restrict__] = ACTIONS(2182),
    [anon_sym__Atomic] = ACTIONS(2182),
    [anon_sym__Noreturn] = ACTIONS(2182),
    [anon_sym_noreturn] = ACTIONS(2182),
    [anon_sym_mutable] = ACTIONS(2182),
    [anon_sym_constinit] = ACTIONS(2182),
    [anon_sym_consteval] = ACTIONS(2182),
    [anon_sym_alignas] = ACTIONS(2182),
    [anon_sym__Alignas] = ACTIONS(2182),
    [sym_primitive_type] = ACTIONS(2182),
    [anon_sym_enum] = ACTIONS(2182),
    [anon_sym_class] = ACTIONS(2182),
    [anon_sym_struct] = ACTIONS(2182),
    [anon_sym_union] = ACTIONS(2182),
    [anon_sym_if] = ACTIONS(2182),
    [anon_sym_else] = ACTIONS(2182),
    [anon_sym_switch] = ACTIONS(2182),
    [anon_sym_case] = ACTIONS(2182),
    [anon_sym_default] = ACTIONS(2182),
    [anon_sym_while] = ACTIONS(2182),
    [anon_sym_do] = ACTIONS(2182),
    [anon_sym_for] = ACTIONS(2182),
    [anon_sym_return] = ACTIONS(2182),
    [anon_sym_break] = ACTIONS(2182),
    [anon_sym_continue] = ACTIONS(2182),
    [anon_sym_goto] = ACTIONS(2182),
    [anon_sym___try] = ACTIONS(2182),
    [anon_sym___leave] = ACTIONS(2182),
    [anon_sym_not] = ACTIONS(2182),
    [anon_sym_compl] = ACTIONS(2182),
    [anon_sym_DASH_DASH] = ACTIONS(2184),
    [anon_sym_PLUS_PLUS] = ACTIONS(2184),
    [anon_sym_sizeof] = ACTIONS(2182),
    [anon_sym___alignof__] = ACTIONS(2182),
    [anon_sym___alignof] = ACTIONS(2182),
    [anon_sym__alignof] = ACTIONS(2182),
    [anon_sym_alignof] = ACTIONS(2182),
    [anon_sym__Alignof] = ACTIONS(2182),
    [anon_sym_offsetof] = ACTIONS(2182),
    [anon_sym__Generic] = ACTIONS(2182),
    [anon_sym_asm] = ACTIONS(2182),
    [anon_sym___asm__] = ACTIONS(2182),
    [sym_number_literal] = ACTIONS(2184),
    [anon_sym_L_SQUOTE] = ACTIONS(2184),
    [anon_sym_u_SQUOTE] = ACTIONS(2184),
    [anon_sym_U_SQUOTE] = ACTIONS(2184),
    [anon_sym_u8_SQUOTE] = ACTIONS(2184),
    [anon_sym_SQUOTE] = ACTIONS(2184),
    [anon_sym_L_DQUOTE] = ACTIONS(2184),
    [anon_sym_u_DQUOTE] = ACTIONS(2184),
    [anon_sym_U_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8_DQUOTE] = ACTIONS(2184),
    [anon_sym_DQUOTE] = ACTIONS(2184),
    [sym_true] = ACTIONS(2182),
    [sym_false] = ACTIONS(2182),
    [anon_sym_NULL] = ACTIONS(2182),
    [anon_sym_nullptr] = ACTIONS(2182),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2182),
    [anon_sym_decltype] = ACTIONS(2182),
    [sym_virtual] = ACTIONS(2182),
    [anon_sym_explicit] = ACTIONS(2182),
    [anon_sym_typename] = ACTIONS(2182),
    [anon_sym_template] = ACTIONS(2182),
    [anon_sym_operator] = ACTIONS(2182),
    [anon_sym_try] = ACTIONS(2182),
    [anon_sym_delete] = ACTIONS(2182),
    [anon_sym_throw] = ACTIONS(2182),
    [anon_sym_namespace] = ACTIONS(2182),
    [anon_sym_using] = ACTIONS(2182),
    [anon_sym_static_assert] = ACTIONS(2182),
    [anon_sym_concept] = ACTIONS(2182),
    [anon_sym_co_return] = ACTIONS(2182),
    [anon_sym_co_yield] = ACTIONS(2182),
    [anon_sym_R_DQUOTE] = ACTIONS(2184),
    [anon_sym_LR_DQUOTE] = ACTIONS(2184),
    [anon_sym_uR_DQUOTE] = ACTIONS(2184),
    [anon_sym_UR_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2184),
    [anon_sym_co_await] = ACTIONS(2182),
    [anon_sym_new] = ACTIONS(2182),
    [anon_sym_requires] = ACTIONS(2182),
    [sym_this] = ACTIONS(2182),
    [anon_sym_discard] = ACTIONS(2182),
    [anon_sym_precise] = ACTIONS(2182),
    [anon_sym_shared] = ACTIONS(2182),
    [anon_sym_groupshared] = ACTIONS(2182),
    [anon_sym_uniform] = ACTIONS(2182),
    [anon_sym_row_major] = ACTIONS(2182),
    [anon_sym_column_major] = ACTIONS(2182),
    [anon_sym_globallycoherent] = ACTIONS(2182),
    [anon_sym_centroid] = ACTIONS(2182),
    [anon_sym_noperspective] = ACTIONS(2182),
    [anon_sym_nointerpolation] = ACTIONS(2182),
    [anon_sym_sample] = ACTIONS(2182),
    [anon_sym_linear] = ACTIONS(2182),
    [anon_sym_snorm] = ACTIONS(2182),
    [anon_sym_unorm] = ACTIONS(2182),
    [anon_sym_point] = ACTIONS(2182),
    [anon_sym_line] = ACTIONS(2182),
    [anon_sym_triangleadj] = ACTIONS(2182),
    [anon_sym_lineadj] = ACTIONS(2182),
    [anon_sym_triangle] = ACTIONS(2182),
    [anon_sym_cbuffer] = ACTIONS(2182),
  },
  [531] = {
    [sym_identifier] = ACTIONS(2118),
    [aux_sym_preproc_include_token1] = ACTIONS(2118),
    [aux_sym_preproc_def_token1] = ACTIONS(2118),
    [aux_sym_preproc_if_token1] = ACTIONS(2118),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2118),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2118),
    [sym_preproc_directive] = ACTIONS(2118),
    [anon_sym_LPAREN2] = ACTIONS(2120),
    [anon_sym_BANG] = ACTIONS(2120),
    [anon_sym_TILDE] = ACTIONS(2120),
    [anon_sym_DASH] = ACTIONS(2118),
    [anon_sym_PLUS] = ACTIONS(2118),
    [anon_sym_STAR] = ACTIONS(2120),
    [anon_sym_AMP_AMP] = ACTIONS(2120),
    [anon_sym_AMP] = ACTIONS(2118),
    [anon_sym_SEMI] = ACTIONS(2120),
    [anon_sym___extension__] = ACTIONS(2118),
    [anon_sym_typedef] = ACTIONS(2118),
    [anon_sym_in] = ACTIONS(2118),
    [anon_sym_out] = ACTIONS(2118),
    [anon_sym_inout] = ACTIONS(2118),
    [anon_sym_extern] = ACTIONS(2118),
    [anon_sym___attribute__] = ACTIONS(2118),
    [anon_sym_COLON_COLON] = ACTIONS(2120),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2120),
    [anon_sym___declspec] = ACTIONS(2118),
    [anon_sym___based] = ACTIONS(2118),
    [anon_sym___cdecl] = ACTIONS(2118),
    [anon_sym___clrcall] = ACTIONS(2118),
    [anon_sym___stdcall] = ACTIONS(2118),
    [anon_sym___fastcall] = ACTIONS(2118),
    [anon_sym___thiscall] = ACTIONS(2118),
    [anon_sym___vectorcall] = ACTIONS(2118),
    [anon_sym_LBRACE] = ACTIONS(2120),
    [anon_sym_RBRACE] = ACTIONS(2120),
    [anon_sym_signed] = ACTIONS(2118),
    [anon_sym_unsigned] = ACTIONS(2118),
    [anon_sym_long] = ACTIONS(2118),
    [anon_sym_short] = ACTIONS(2118),
    [anon_sym_LBRACK] = ACTIONS(2118),
    [anon_sym_static] = ACTIONS(2118),
    [anon_sym_register] = ACTIONS(2118),
    [anon_sym_inline] = ACTIONS(2118),
    [anon_sym___inline] = ACTIONS(2118),
    [anon_sym___inline__] = ACTIONS(2118),
    [anon_sym___forceinline] = ACTIONS(2118),
    [anon_sym_thread_local] = ACTIONS(2118),
    [anon_sym___thread] = ACTIONS(2118),
    [anon_sym_const] = ACTIONS(2118),
    [anon_sym_constexpr] = ACTIONS(2118),
    [anon_sym_volatile] = ACTIONS(2118),
    [anon_sym_restrict] = ACTIONS(2118),
    [anon_sym___restrict__] = ACTIONS(2118),
    [anon_sym__Atomic] = ACTIONS(2118),
    [anon_sym__Noreturn] = ACTIONS(2118),
    [anon_sym_noreturn] = ACTIONS(2118),
    [anon_sym_mutable] = ACTIONS(2118),
    [anon_sym_constinit] = ACTIONS(2118),
    [anon_sym_consteval] = ACTIONS(2118),
    [anon_sym_alignas] = ACTIONS(2118),
    [anon_sym__Alignas] = ACTIONS(2118),
    [sym_primitive_type] = ACTIONS(2118),
    [anon_sym_enum] = ACTIONS(2118),
    [anon_sym_class] = ACTIONS(2118),
    [anon_sym_struct] = ACTIONS(2118),
    [anon_sym_union] = ACTIONS(2118),
    [anon_sym_if] = ACTIONS(2118),
    [anon_sym_else] = ACTIONS(2118),
    [anon_sym_switch] = ACTIONS(2118),
    [anon_sym_case] = ACTIONS(2118),
    [anon_sym_default] = ACTIONS(2118),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_do] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2118),
    [anon_sym_return] = ACTIONS(2118),
    [anon_sym_break] = ACTIONS(2118),
    [anon_sym_continue] = ACTIONS(2118),
    [anon_sym_goto] = ACTIONS(2118),
    [anon_sym___try] = ACTIONS(2118),
    [anon_sym___leave] = ACTIONS(2118),
    [anon_sym_not] = ACTIONS(2118),
    [anon_sym_compl] = ACTIONS(2118),
    [anon_sym_DASH_DASH] = ACTIONS(2120),
    [anon_sym_PLUS_PLUS] = ACTIONS(2120),
    [anon_sym_sizeof] = ACTIONS(2118),
    [anon_sym___alignof__] = ACTIONS(2118),
    [anon_sym___alignof] = ACTIONS(2118),
    [anon_sym__alignof] = ACTIONS(2118),
    [anon_sym_alignof] = ACTIONS(2118),
    [anon_sym__Alignof] = ACTIONS(2118),
    [anon_sym_offsetof] = ACTIONS(2118),
    [anon_sym__Generic] = ACTIONS(2118),
    [anon_sym_asm] = ACTIONS(2118),
    [anon_sym___asm__] = ACTIONS(2118),
    [sym_number_literal] = ACTIONS(2120),
    [anon_sym_L_SQUOTE] = ACTIONS(2120),
    [anon_sym_u_SQUOTE] = ACTIONS(2120),
    [anon_sym_U_SQUOTE] = ACTIONS(2120),
    [anon_sym_u8_SQUOTE] = ACTIONS(2120),
    [anon_sym_SQUOTE] = ACTIONS(2120),
    [anon_sym_L_DQUOTE] = ACTIONS(2120),
    [anon_sym_u_DQUOTE] = ACTIONS(2120),
    [anon_sym_U_DQUOTE] = ACTIONS(2120),
    [anon_sym_u8_DQUOTE] = ACTIONS(2120),
    [anon_sym_DQUOTE] = ACTIONS(2120),
    [sym_true] = ACTIONS(2118),
    [sym_false] = ACTIONS(2118),
    [anon_sym_NULL] = ACTIONS(2118),
    [anon_sym_nullptr] = ACTIONS(2118),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2118),
    [anon_sym_decltype] = ACTIONS(2118),
    [sym_virtual] = ACTIONS(2118),
    [anon_sym_explicit] = ACTIONS(2118),
    [anon_sym_typename] = ACTIONS(2118),
    [anon_sym_template] = ACTIONS(2118),
    [anon_sym_operator] = ACTIONS(2118),
    [anon_sym_try] = ACTIONS(2118),
    [anon_sym_delete] = ACTIONS(2118),
    [anon_sym_throw] = ACTIONS(2118),
    [anon_sym_namespace] = ACTIONS(2118),
    [anon_sym_using] = ACTIONS(2118),
    [anon_sym_static_assert] = ACTIONS(2118),
    [anon_sym_concept] = ACTIONS(2118),
    [anon_sym_co_return] = ACTIONS(2118),
    [anon_sym_co_yield] = ACTIONS(2118),
    [anon_sym_R_DQUOTE] = ACTIONS(2120),
    [anon_sym_LR_DQUOTE] = ACTIONS(2120),
    [anon_sym_uR_DQUOTE] = ACTIONS(2120),
    [anon_sym_UR_DQUOTE] = ACTIONS(2120),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2120),
    [anon_sym_co_await] = ACTIONS(2118),
    [anon_sym_new] = ACTIONS(2118),
    [anon_sym_requires] = ACTIONS(2118),
    [sym_this] = ACTIONS(2118),
    [anon_sym_discard] = ACTIONS(2118),
    [anon_sym_precise] = ACTIONS(2118),
    [anon_sym_shared] = ACTIONS(2118),
    [anon_sym_groupshared] = ACTIONS(2118),
    [anon_sym_uniform] = ACTIONS(2118),
    [anon_sym_row_major] = ACTIONS(2118),
    [anon_sym_column_major] = ACTIONS(2118),
    [anon_sym_globallycoherent] = ACTIONS(2118),
    [anon_sym_centroid] = ACTIONS(2118),
    [anon_sym_noperspective] = ACTIONS(2118),
    [anon_sym_nointerpolation] = ACTIONS(2118),
    [anon_sym_sample] = ACTIONS(2118),
    [anon_sym_linear] = ACTIONS(2118),
    [anon_sym_snorm] = ACTIONS(2118),
    [anon_sym_unorm] = ACTIONS(2118),
    [anon_sym_point] = ACTIONS(2118),
    [anon_sym_line] = ACTIONS(2118),
    [anon_sym_triangleadj] = ACTIONS(2118),
    [anon_sym_lineadj] = ACTIONS(2118),
    [anon_sym_triangle] = ACTIONS(2118),
    [anon_sym_cbuffer] = ACTIONS(2118),
  },
  [532] = {
    [ts_builtin_sym_end] = ACTIONS(2124),
    [sym_identifier] = ACTIONS(2122),
    [aux_sym_preproc_include_token1] = ACTIONS(2122),
    [aux_sym_preproc_def_token1] = ACTIONS(2122),
    [aux_sym_preproc_if_token1] = ACTIONS(2122),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2122),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2122),
    [sym_preproc_directive] = ACTIONS(2122),
    [anon_sym_LPAREN2] = ACTIONS(2124),
    [anon_sym_BANG] = ACTIONS(2124),
    [anon_sym_TILDE] = ACTIONS(2124),
    [anon_sym_DASH] = ACTIONS(2122),
    [anon_sym_PLUS] = ACTIONS(2122),
    [anon_sym_STAR] = ACTIONS(2124),
    [anon_sym_AMP_AMP] = ACTIONS(2124),
    [anon_sym_AMP] = ACTIONS(2122),
    [anon_sym_SEMI] = ACTIONS(2124),
    [anon_sym___extension__] = ACTIONS(2122),
    [anon_sym_typedef] = ACTIONS(2122),
    [anon_sym_in] = ACTIONS(2122),
    [anon_sym_out] = ACTIONS(2122),
    [anon_sym_inout] = ACTIONS(2122),
    [anon_sym_extern] = ACTIONS(2122),
    [anon_sym___attribute__] = ACTIONS(2122),
    [anon_sym_COLON_COLON] = ACTIONS(2124),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2124),
    [anon_sym___declspec] = ACTIONS(2122),
    [anon_sym___based] = ACTIONS(2122),
    [anon_sym___cdecl] = ACTIONS(2122),
    [anon_sym___clrcall] = ACTIONS(2122),
    [anon_sym___stdcall] = ACTIONS(2122),
    [anon_sym___fastcall] = ACTIONS(2122),
    [anon_sym___thiscall] = ACTIONS(2122),
    [anon_sym___vectorcall] = ACTIONS(2122),
    [anon_sym_LBRACE] = ACTIONS(2124),
    [anon_sym_signed] = ACTIONS(2122),
    [anon_sym_unsigned] = ACTIONS(2122),
    [anon_sym_long] = ACTIONS(2122),
    [anon_sym_short] = ACTIONS(2122),
    [anon_sym_LBRACK] = ACTIONS(2122),
    [anon_sym_static] = ACTIONS(2122),
    [anon_sym_register] = ACTIONS(2122),
    [anon_sym_inline] = ACTIONS(2122),
    [anon_sym___inline] = ACTIONS(2122),
    [anon_sym___inline__] = ACTIONS(2122),
    [anon_sym___forceinline] = ACTIONS(2122),
    [anon_sym_thread_local] = ACTIONS(2122),
    [anon_sym___thread] = ACTIONS(2122),
    [anon_sym_const] = ACTIONS(2122),
    [anon_sym_constexpr] = ACTIONS(2122),
    [anon_sym_volatile] = ACTIONS(2122),
    [anon_sym_restrict] = ACTIONS(2122),
    [anon_sym___restrict__] = ACTIONS(2122),
    [anon_sym__Atomic] = ACTIONS(2122),
    [anon_sym__Noreturn] = ACTIONS(2122),
    [anon_sym_noreturn] = ACTIONS(2122),
    [anon_sym_mutable] = ACTIONS(2122),
    [anon_sym_constinit] = ACTIONS(2122),
    [anon_sym_consteval] = ACTIONS(2122),
    [anon_sym_alignas] = ACTIONS(2122),
    [anon_sym__Alignas] = ACTIONS(2122),
    [sym_primitive_type] = ACTIONS(2122),
    [anon_sym_enum] = ACTIONS(2122),
    [anon_sym_class] = ACTIONS(2122),
    [anon_sym_struct] = ACTIONS(2122),
    [anon_sym_union] = ACTIONS(2122),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_else] = ACTIONS(2122),
    [anon_sym_switch] = ACTIONS(2122),
    [anon_sym_case] = ACTIONS(2122),
    [anon_sym_default] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2122),
    [anon_sym_do] = ACTIONS(2122),
    [anon_sym_for] = ACTIONS(2122),
    [anon_sym_return] = ACTIONS(2122),
    [anon_sym_break] = ACTIONS(2122),
    [anon_sym_continue] = ACTIONS(2122),
    [anon_sym_goto] = ACTIONS(2122),
    [anon_sym___try] = ACTIONS(2122),
    [anon_sym___leave] = ACTIONS(2122),
    [anon_sym_not] = ACTIONS(2122),
    [anon_sym_compl] = ACTIONS(2122),
    [anon_sym_DASH_DASH] = ACTIONS(2124),
    [anon_sym_PLUS_PLUS] = ACTIONS(2124),
    [anon_sym_sizeof] = ACTIONS(2122),
    [anon_sym___alignof__] = ACTIONS(2122),
    [anon_sym___alignof] = ACTIONS(2122),
    [anon_sym__alignof] = ACTIONS(2122),
    [anon_sym_alignof] = ACTIONS(2122),
    [anon_sym__Alignof] = ACTIONS(2122),
    [anon_sym_offsetof] = ACTIONS(2122),
    [anon_sym__Generic] = ACTIONS(2122),
    [anon_sym_asm] = ACTIONS(2122),
    [anon_sym___asm__] = ACTIONS(2122),
    [sym_number_literal] = ACTIONS(2124),
    [anon_sym_L_SQUOTE] = ACTIONS(2124),
    [anon_sym_u_SQUOTE] = ACTIONS(2124),
    [anon_sym_U_SQUOTE] = ACTIONS(2124),
    [anon_sym_u8_SQUOTE] = ACTIONS(2124),
    [anon_sym_SQUOTE] = ACTIONS(2124),
    [anon_sym_L_DQUOTE] = ACTIONS(2124),
    [anon_sym_u_DQUOTE] = ACTIONS(2124),
    [anon_sym_U_DQUOTE] = ACTIONS(2124),
    [anon_sym_u8_DQUOTE] = ACTIONS(2124),
    [anon_sym_DQUOTE] = ACTIONS(2124),
    [sym_true] = ACTIONS(2122),
    [sym_false] = ACTIONS(2122),
    [anon_sym_NULL] = ACTIONS(2122),
    [anon_sym_nullptr] = ACTIONS(2122),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2122),
    [anon_sym_decltype] = ACTIONS(2122),
    [sym_virtual] = ACTIONS(2122),
    [anon_sym_explicit] = ACTIONS(2122),
    [anon_sym_typename] = ACTIONS(2122),
    [anon_sym_template] = ACTIONS(2122),
    [anon_sym_operator] = ACTIONS(2122),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_delete] = ACTIONS(2122),
    [anon_sym_throw] = ACTIONS(2122),
    [anon_sym_namespace] = ACTIONS(2122),
    [anon_sym_using] = ACTIONS(2122),
    [anon_sym_static_assert] = ACTIONS(2122),
    [anon_sym_concept] = ACTIONS(2122),
    [anon_sym_co_return] = ACTIONS(2122),
    [anon_sym_co_yield] = ACTIONS(2122),
    [anon_sym_R_DQUOTE] = ACTIONS(2124),
    [anon_sym_LR_DQUOTE] = ACTIONS(2124),
    [anon_sym_uR_DQUOTE] = ACTIONS(2124),
    [anon_sym_UR_DQUOTE] = ACTIONS(2124),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2124),
    [anon_sym_co_await] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(2122),
    [anon_sym_requires] = ACTIONS(2122),
    [sym_this] = ACTIONS(2122),
    [anon_sym_discard] = ACTIONS(2122),
    [anon_sym_precise] = ACTIONS(2122),
    [anon_sym_shared] = ACTIONS(2122),
    [anon_sym_groupshared] = ACTIONS(2122),
    [anon_sym_uniform] = ACTIONS(2122),
    [anon_sym_row_major] = ACTIONS(2122),
    [anon_sym_column_major] = ACTIONS(2122),
    [anon_sym_globallycoherent] = ACTIONS(2122),
    [anon_sym_centroid] = ACTIONS(2122),
    [anon_sym_noperspective] = ACTIONS(2122),
    [anon_sym_nointerpolation] = ACTIONS(2122),
    [anon_sym_sample] = ACTIONS(2122),
    [anon_sym_linear] = ACTIONS(2122),
    [anon_sym_snorm] = ACTIONS(2122),
    [anon_sym_unorm] = ACTIONS(2122),
    [anon_sym_point] = ACTIONS(2122),
    [anon_sym_line] = ACTIONS(2122),
    [anon_sym_triangleadj] = ACTIONS(2122),
    [anon_sym_lineadj] = ACTIONS(2122),
    [anon_sym_triangle] = ACTIONS(2122),
    [anon_sym_cbuffer] = ACTIONS(2122),
  },
  [533] = {
    [ts_builtin_sym_end] = ACTIONS(2128),
    [sym_identifier] = ACTIONS(2126),
    [aux_sym_preproc_include_token1] = ACTIONS(2126),
    [aux_sym_preproc_def_token1] = ACTIONS(2126),
    [aux_sym_preproc_if_token1] = ACTIONS(2126),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2126),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2126),
    [sym_preproc_directive] = ACTIONS(2126),
    [anon_sym_LPAREN2] = ACTIONS(2128),
    [anon_sym_BANG] = ACTIONS(2128),
    [anon_sym_TILDE] = ACTIONS(2128),
    [anon_sym_DASH] = ACTIONS(2126),
    [anon_sym_PLUS] = ACTIONS(2126),
    [anon_sym_STAR] = ACTIONS(2128),
    [anon_sym_AMP_AMP] = ACTIONS(2128),
    [anon_sym_AMP] = ACTIONS(2126),
    [anon_sym_SEMI] = ACTIONS(2128),
    [anon_sym___extension__] = ACTIONS(2126),
    [anon_sym_typedef] = ACTIONS(2126),
    [anon_sym_in] = ACTIONS(2126),
    [anon_sym_out] = ACTIONS(2126),
    [anon_sym_inout] = ACTIONS(2126),
    [anon_sym_extern] = ACTIONS(2126),
    [anon_sym___attribute__] = ACTIONS(2126),
    [anon_sym_COLON_COLON] = ACTIONS(2128),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2128),
    [anon_sym___declspec] = ACTIONS(2126),
    [anon_sym___based] = ACTIONS(2126),
    [anon_sym___cdecl] = ACTIONS(2126),
    [anon_sym___clrcall] = ACTIONS(2126),
    [anon_sym___stdcall] = ACTIONS(2126),
    [anon_sym___fastcall] = ACTIONS(2126),
    [anon_sym___thiscall] = ACTIONS(2126),
    [anon_sym___vectorcall] = ACTIONS(2126),
    [anon_sym_LBRACE] = ACTIONS(2128),
    [anon_sym_signed] = ACTIONS(2126),
    [anon_sym_unsigned] = ACTIONS(2126),
    [anon_sym_long] = ACTIONS(2126),
    [anon_sym_short] = ACTIONS(2126),
    [anon_sym_LBRACK] = ACTIONS(2126),
    [anon_sym_static] = ACTIONS(2126),
    [anon_sym_register] = ACTIONS(2126),
    [anon_sym_inline] = ACTIONS(2126),
    [anon_sym___inline] = ACTIONS(2126),
    [anon_sym___inline__] = ACTIONS(2126),
    [anon_sym___forceinline] = ACTIONS(2126),
    [anon_sym_thread_local] = ACTIONS(2126),
    [anon_sym___thread] = ACTIONS(2126),
    [anon_sym_const] = ACTIONS(2126),
    [anon_sym_constexpr] = ACTIONS(2126),
    [anon_sym_volatile] = ACTIONS(2126),
    [anon_sym_restrict] = ACTIONS(2126),
    [anon_sym___restrict__] = ACTIONS(2126),
    [anon_sym__Atomic] = ACTIONS(2126),
    [anon_sym__Noreturn] = ACTIONS(2126),
    [anon_sym_noreturn] = ACTIONS(2126),
    [anon_sym_mutable] = ACTIONS(2126),
    [anon_sym_constinit] = ACTIONS(2126),
    [anon_sym_consteval] = ACTIONS(2126),
    [anon_sym_alignas] = ACTIONS(2126),
    [anon_sym__Alignas] = ACTIONS(2126),
    [sym_primitive_type] = ACTIONS(2126),
    [anon_sym_enum] = ACTIONS(2126),
    [anon_sym_class] = ACTIONS(2126),
    [anon_sym_struct] = ACTIONS(2126),
    [anon_sym_union] = ACTIONS(2126),
    [anon_sym_if] = ACTIONS(2126),
    [anon_sym_else] = ACTIONS(2126),
    [anon_sym_switch] = ACTIONS(2126),
    [anon_sym_case] = ACTIONS(2126),
    [anon_sym_default] = ACTIONS(2126),
    [anon_sym_while] = ACTIONS(2126),
    [anon_sym_do] = ACTIONS(2126),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_return] = ACTIONS(2126),
    [anon_sym_break] = ACTIONS(2126),
    [anon_sym_continue] = ACTIONS(2126),
    [anon_sym_goto] = ACTIONS(2126),
    [anon_sym___try] = ACTIONS(2126),
    [anon_sym___leave] = ACTIONS(2126),
    [anon_sym_not] = ACTIONS(2126),
    [anon_sym_compl] = ACTIONS(2126),
    [anon_sym_DASH_DASH] = ACTIONS(2128),
    [anon_sym_PLUS_PLUS] = ACTIONS(2128),
    [anon_sym_sizeof] = ACTIONS(2126),
    [anon_sym___alignof__] = ACTIONS(2126),
    [anon_sym___alignof] = ACTIONS(2126),
    [anon_sym__alignof] = ACTIONS(2126),
    [anon_sym_alignof] = ACTIONS(2126),
    [anon_sym__Alignof] = ACTIONS(2126),
    [anon_sym_offsetof] = ACTIONS(2126),
    [anon_sym__Generic] = ACTIONS(2126),
    [anon_sym_asm] = ACTIONS(2126),
    [anon_sym___asm__] = ACTIONS(2126),
    [sym_number_literal] = ACTIONS(2128),
    [anon_sym_L_SQUOTE] = ACTIONS(2128),
    [anon_sym_u_SQUOTE] = ACTIONS(2128),
    [anon_sym_U_SQUOTE] = ACTIONS(2128),
    [anon_sym_u8_SQUOTE] = ACTIONS(2128),
    [anon_sym_SQUOTE] = ACTIONS(2128),
    [anon_sym_L_DQUOTE] = ACTIONS(2128),
    [anon_sym_u_DQUOTE] = ACTIONS(2128),
    [anon_sym_U_DQUOTE] = ACTIONS(2128),
    [anon_sym_u8_DQUOTE] = ACTIONS(2128),
    [anon_sym_DQUOTE] = ACTIONS(2128),
    [sym_true] = ACTIONS(2126),
    [sym_false] = ACTIONS(2126),
    [anon_sym_NULL] = ACTIONS(2126),
    [anon_sym_nullptr] = ACTIONS(2126),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2126),
    [anon_sym_decltype] = ACTIONS(2126),
    [sym_virtual] = ACTIONS(2126),
    [anon_sym_explicit] = ACTIONS(2126),
    [anon_sym_typename] = ACTIONS(2126),
    [anon_sym_template] = ACTIONS(2126),
    [anon_sym_operator] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2126),
    [anon_sym_delete] = ACTIONS(2126),
    [anon_sym_throw] = ACTIONS(2126),
    [anon_sym_namespace] = ACTIONS(2126),
    [anon_sym_using] = ACTIONS(2126),
    [anon_sym_static_assert] = ACTIONS(2126),
    [anon_sym_concept] = ACTIONS(2126),
    [anon_sym_co_return] = ACTIONS(2126),
    [anon_sym_co_yield] = ACTIONS(2126),
    [anon_sym_R_DQUOTE] = ACTIONS(2128),
    [anon_sym_LR_DQUOTE] = ACTIONS(2128),
    [anon_sym_uR_DQUOTE] = ACTIONS(2128),
    [anon_sym_UR_DQUOTE] = ACTIONS(2128),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2128),
    [anon_sym_co_await] = ACTIONS(2126),
    [anon_sym_new] = ACTIONS(2126),
    [anon_sym_requires] = ACTIONS(2126),
    [sym_this] = ACTIONS(2126),
    [anon_sym_discard] = ACTIONS(2126),
    [anon_sym_precise] = ACTIONS(2126),
    [anon_sym_shared] = ACTIONS(2126),
    [anon_sym_groupshared] = ACTIONS(2126),
    [anon_sym_uniform] = ACTIONS(2126),
    [anon_sym_row_major] = ACTIONS(2126),
    [anon_sym_column_major] = ACTIONS(2126),
    [anon_sym_globallycoherent] = ACTIONS(2126),
    [anon_sym_centroid] = ACTIONS(2126),
    [anon_sym_noperspective] = ACTIONS(2126),
    [anon_sym_nointerpolation] = ACTIONS(2126),
    [anon_sym_sample] = ACTIONS(2126),
    [anon_sym_linear] = ACTIONS(2126),
    [anon_sym_snorm] = ACTIONS(2126),
    [anon_sym_unorm] = ACTIONS(2126),
    [anon_sym_point] = ACTIONS(2126),
    [anon_sym_line] = ACTIONS(2126),
    [anon_sym_triangleadj] = ACTIONS(2126),
    [anon_sym_lineadj] = ACTIONS(2126),
    [anon_sym_triangle] = ACTIONS(2126),
    [anon_sym_cbuffer] = ACTIONS(2126),
  },
  [534] = {
    [ts_builtin_sym_end] = ACTIONS(2200),
    [sym_identifier] = ACTIONS(2198),
    [aux_sym_preproc_include_token1] = ACTIONS(2198),
    [aux_sym_preproc_def_token1] = ACTIONS(2198),
    [aux_sym_preproc_if_token1] = ACTIONS(2198),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2198),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2198),
    [sym_preproc_directive] = ACTIONS(2198),
    [anon_sym_LPAREN2] = ACTIONS(2200),
    [anon_sym_BANG] = ACTIONS(2200),
    [anon_sym_TILDE] = ACTIONS(2200),
    [anon_sym_DASH] = ACTIONS(2198),
    [anon_sym_PLUS] = ACTIONS(2198),
    [anon_sym_STAR] = ACTIONS(2200),
    [anon_sym_AMP_AMP] = ACTIONS(2200),
    [anon_sym_AMP] = ACTIONS(2198),
    [anon_sym_SEMI] = ACTIONS(2200),
    [anon_sym___extension__] = ACTIONS(2198),
    [anon_sym_typedef] = ACTIONS(2198),
    [anon_sym_in] = ACTIONS(2198),
    [anon_sym_out] = ACTIONS(2198),
    [anon_sym_inout] = ACTIONS(2198),
    [anon_sym_extern] = ACTIONS(2198),
    [anon_sym___attribute__] = ACTIONS(2198),
    [anon_sym_COLON_COLON] = ACTIONS(2200),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2200),
    [anon_sym___declspec] = ACTIONS(2198),
    [anon_sym___based] = ACTIONS(2198),
    [anon_sym___cdecl] = ACTIONS(2198),
    [anon_sym___clrcall] = ACTIONS(2198),
    [anon_sym___stdcall] = ACTIONS(2198),
    [anon_sym___fastcall] = ACTIONS(2198),
    [anon_sym___thiscall] = ACTIONS(2198),
    [anon_sym___vectorcall] = ACTIONS(2198),
    [anon_sym_LBRACE] = ACTIONS(2200),
    [anon_sym_signed] = ACTIONS(2198),
    [anon_sym_unsigned] = ACTIONS(2198),
    [anon_sym_long] = ACTIONS(2198),
    [anon_sym_short] = ACTIONS(2198),
    [anon_sym_LBRACK] = ACTIONS(2198),
    [anon_sym_static] = ACTIONS(2198),
    [anon_sym_register] = ACTIONS(2198),
    [anon_sym_inline] = ACTIONS(2198),
    [anon_sym___inline] = ACTIONS(2198),
    [anon_sym___inline__] = ACTIONS(2198),
    [anon_sym___forceinline] = ACTIONS(2198),
    [anon_sym_thread_local] = ACTIONS(2198),
    [anon_sym___thread] = ACTIONS(2198),
    [anon_sym_const] = ACTIONS(2198),
    [anon_sym_constexpr] = ACTIONS(2198),
    [anon_sym_volatile] = ACTIONS(2198),
    [anon_sym_restrict] = ACTIONS(2198),
    [anon_sym___restrict__] = ACTIONS(2198),
    [anon_sym__Atomic] = ACTIONS(2198),
    [anon_sym__Noreturn] = ACTIONS(2198),
    [anon_sym_noreturn] = ACTIONS(2198),
    [anon_sym_mutable] = ACTIONS(2198),
    [anon_sym_constinit] = ACTIONS(2198),
    [anon_sym_consteval] = ACTIONS(2198),
    [anon_sym_alignas] = ACTIONS(2198),
    [anon_sym__Alignas] = ACTIONS(2198),
    [sym_primitive_type] = ACTIONS(2198),
    [anon_sym_enum] = ACTIONS(2198),
    [anon_sym_class] = ACTIONS(2198),
    [anon_sym_struct] = ACTIONS(2198),
    [anon_sym_union] = ACTIONS(2198),
    [anon_sym_if] = ACTIONS(2198),
    [anon_sym_else] = ACTIONS(2198),
    [anon_sym_switch] = ACTIONS(2198),
    [anon_sym_case] = ACTIONS(2198),
    [anon_sym_default] = ACTIONS(2198),
    [anon_sym_while] = ACTIONS(2198),
    [anon_sym_do] = ACTIONS(2198),
    [anon_sym_for] = ACTIONS(2198),
    [anon_sym_return] = ACTIONS(2198),
    [anon_sym_break] = ACTIONS(2198),
    [anon_sym_continue] = ACTIONS(2198),
    [anon_sym_goto] = ACTIONS(2198),
    [anon_sym___try] = ACTIONS(2198),
    [anon_sym___leave] = ACTIONS(2198),
    [anon_sym_not] = ACTIONS(2198),
    [anon_sym_compl] = ACTIONS(2198),
    [anon_sym_DASH_DASH] = ACTIONS(2200),
    [anon_sym_PLUS_PLUS] = ACTIONS(2200),
    [anon_sym_sizeof] = ACTIONS(2198),
    [anon_sym___alignof__] = ACTIONS(2198),
    [anon_sym___alignof] = ACTIONS(2198),
    [anon_sym__alignof] = ACTIONS(2198),
    [anon_sym_alignof] = ACTIONS(2198),
    [anon_sym__Alignof] = ACTIONS(2198),
    [anon_sym_offsetof] = ACTIONS(2198),
    [anon_sym__Generic] = ACTIONS(2198),
    [anon_sym_asm] = ACTIONS(2198),
    [anon_sym___asm__] = ACTIONS(2198),
    [sym_number_literal] = ACTIONS(2200),
    [anon_sym_L_SQUOTE] = ACTIONS(2200),
    [anon_sym_u_SQUOTE] = ACTIONS(2200),
    [anon_sym_U_SQUOTE] = ACTIONS(2200),
    [anon_sym_u8_SQUOTE] = ACTIONS(2200),
    [anon_sym_SQUOTE] = ACTIONS(2200),
    [anon_sym_L_DQUOTE] = ACTIONS(2200),
    [anon_sym_u_DQUOTE] = ACTIONS(2200),
    [anon_sym_U_DQUOTE] = ACTIONS(2200),
    [anon_sym_u8_DQUOTE] = ACTIONS(2200),
    [anon_sym_DQUOTE] = ACTIONS(2200),
    [sym_true] = ACTIONS(2198),
    [sym_false] = ACTIONS(2198),
    [anon_sym_NULL] = ACTIONS(2198),
    [anon_sym_nullptr] = ACTIONS(2198),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2198),
    [anon_sym_decltype] = ACTIONS(2198),
    [sym_virtual] = ACTIONS(2198),
    [anon_sym_explicit] = ACTIONS(2198),
    [anon_sym_typename] = ACTIONS(2198),
    [anon_sym_template] = ACTIONS(2198),
    [anon_sym_operator] = ACTIONS(2198),
    [anon_sym_try] = ACTIONS(2198),
    [anon_sym_delete] = ACTIONS(2198),
    [anon_sym_throw] = ACTIONS(2198),
    [anon_sym_namespace] = ACTIONS(2198),
    [anon_sym_using] = ACTIONS(2198),
    [anon_sym_static_assert] = ACTIONS(2198),
    [anon_sym_concept] = ACTIONS(2198),
    [anon_sym_co_return] = ACTIONS(2198),
    [anon_sym_co_yield] = ACTIONS(2198),
    [anon_sym_R_DQUOTE] = ACTIONS(2200),
    [anon_sym_LR_DQUOTE] = ACTIONS(2200),
    [anon_sym_uR_DQUOTE] = ACTIONS(2200),
    [anon_sym_UR_DQUOTE] = ACTIONS(2200),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2200),
    [anon_sym_co_await] = ACTIONS(2198),
    [anon_sym_new] = ACTIONS(2198),
    [anon_sym_requires] = ACTIONS(2198),
    [sym_this] = ACTIONS(2198),
    [anon_sym_discard] = ACTIONS(2198),
    [anon_sym_precise] = ACTIONS(2198),
    [anon_sym_shared] = ACTIONS(2198),
    [anon_sym_groupshared] = ACTIONS(2198),
    [anon_sym_uniform] = ACTIONS(2198),
    [anon_sym_row_major] = ACTIONS(2198),
    [anon_sym_column_major] = ACTIONS(2198),
    [anon_sym_globallycoherent] = ACTIONS(2198),
    [anon_sym_centroid] = ACTIONS(2198),
    [anon_sym_noperspective] = ACTIONS(2198),
    [anon_sym_nointerpolation] = ACTIONS(2198),
    [anon_sym_sample] = ACTIONS(2198),
    [anon_sym_linear] = ACTIONS(2198),
    [anon_sym_snorm] = ACTIONS(2198),
    [anon_sym_unorm] = ACTIONS(2198),
    [anon_sym_point] = ACTIONS(2198),
    [anon_sym_line] = ACTIONS(2198),
    [anon_sym_triangleadj] = ACTIONS(2198),
    [anon_sym_lineadj] = ACTIONS(2198),
    [anon_sym_triangle] = ACTIONS(2198),
    [anon_sym_cbuffer] = ACTIONS(2198),
  },
  [535] = {
    [ts_builtin_sym_end] = ACTIONS(2226),
    [sym_identifier] = ACTIONS(2224),
    [aux_sym_preproc_include_token1] = ACTIONS(2224),
    [aux_sym_preproc_def_token1] = ACTIONS(2224),
    [aux_sym_preproc_if_token1] = ACTIONS(2224),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2224),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2224),
    [sym_preproc_directive] = ACTIONS(2224),
    [anon_sym_LPAREN2] = ACTIONS(2226),
    [anon_sym_BANG] = ACTIONS(2226),
    [anon_sym_TILDE] = ACTIONS(2226),
    [anon_sym_DASH] = ACTIONS(2224),
    [anon_sym_PLUS] = ACTIONS(2224),
    [anon_sym_STAR] = ACTIONS(2226),
    [anon_sym_AMP_AMP] = ACTIONS(2226),
    [anon_sym_AMP] = ACTIONS(2224),
    [anon_sym_SEMI] = ACTIONS(2226),
    [anon_sym___extension__] = ACTIONS(2224),
    [anon_sym_typedef] = ACTIONS(2224),
    [anon_sym_in] = ACTIONS(2224),
    [anon_sym_out] = ACTIONS(2224),
    [anon_sym_inout] = ACTIONS(2224),
    [anon_sym_extern] = ACTIONS(2224),
    [anon_sym___attribute__] = ACTIONS(2224),
    [anon_sym_COLON_COLON] = ACTIONS(2226),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2226),
    [anon_sym___declspec] = ACTIONS(2224),
    [anon_sym___based] = ACTIONS(2224),
    [anon_sym___cdecl] = ACTIONS(2224),
    [anon_sym___clrcall] = ACTIONS(2224),
    [anon_sym___stdcall] = ACTIONS(2224),
    [anon_sym___fastcall] = ACTIONS(2224),
    [anon_sym___thiscall] = ACTIONS(2224),
    [anon_sym___vectorcall] = ACTIONS(2224),
    [anon_sym_LBRACE] = ACTIONS(2226),
    [anon_sym_signed] = ACTIONS(2224),
    [anon_sym_unsigned] = ACTIONS(2224),
    [anon_sym_long] = ACTIONS(2224),
    [anon_sym_short] = ACTIONS(2224),
    [anon_sym_LBRACK] = ACTIONS(2224),
    [anon_sym_static] = ACTIONS(2224),
    [anon_sym_register] = ACTIONS(2224),
    [anon_sym_inline] = ACTIONS(2224),
    [anon_sym___inline] = ACTIONS(2224),
    [anon_sym___inline__] = ACTIONS(2224),
    [anon_sym___forceinline] = ACTIONS(2224),
    [anon_sym_thread_local] = ACTIONS(2224),
    [anon_sym___thread] = ACTIONS(2224),
    [anon_sym_const] = ACTIONS(2224),
    [anon_sym_constexpr] = ACTIONS(2224),
    [anon_sym_volatile] = ACTIONS(2224),
    [anon_sym_restrict] = ACTIONS(2224),
    [anon_sym___restrict__] = ACTIONS(2224),
    [anon_sym__Atomic] = ACTIONS(2224),
    [anon_sym__Noreturn] = ACTIONS(2224),
    [anon_sym_noreturn] = ACTIONS(2224),
    [anon_sym_mutable] = ACTIONS(2224),
    [anon_sym_constinit] = ACTIONS(2224),
    [anon_sym_consteval] = ACTIONS(2224),
    [anon_sym_alignas] = ACTIONS(2224),
    [anon_sym__Alignas] = ACTIONS(2224),
    [sym_primitive_type] = ACTIONS(2224),
    [anon_sym_enum] = ACTIONS(2224),
    [anon_sym_class] = ACTIONS(2224),
    [anon_sym_struct] = ACTIONS(2224),
    [anon_sym_union] = ACTIONS(2224),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_else] = ACTIONS(2224),
    [anon_sym_switch] = ACTIONS(2224),
    [anon_sym_case] = ACTIONS(2224),
    [anon_sym_default] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(2224),
    [anon_sym_do] = ACTIONS(2224),
    [anon_sym_for] = ACTIONS(2224),
    [anon_sym_return] = ACTIONS(2224),
    [anon_sym_break] = ACTIONS(2224),
    [anon_sym_continue] = ACTIONS(2224),
    [anon_sym_goto] = ACTIONS(2224),
    [anon_sym___try] = ACTIONS(2224),
    [anon_sym___leave] = ACTIONS(2224),
    [anon_sym_not] = ACTIONS(2224),
    [anon_sym_compl] = ACTIONS(2224),
    [anon_sym_DASH_DASH] = ACTIONS(2226),
    [anon_sym_PLUS_PLUS] = ACTIONS(2226),
    [anon_sym_sizeof] = ACTIONS(2224),
    [anon_sym___alignof__] = ACTIONS(2224),
    [anon_sym___alignof] = ACTIONS(2224),
    [anon_sym__alignof] = ACTIONS(2224),
    [anon_sym_alignof] = ACTIONS(2224),
    [anon_sym__Alignof] = ACTIONS(2224),
    [anon_sym_offsetof] = ACTIONS(2224),
    [anon_sym__Generic] = ACTIONS(2224),
    [anon_sym_asm] = ACTIONS(2224),
    [anon_sym___asm__] = ACTIONS(2224),
    [sym_number_literal] = ACTIONS(2226),
    [anon_sym_L_SQUOTE] = ACTIONS(2226),
    [anon_sym_u_SQUOTE] = ACTIONS(2226),
    [anon_sym_U_SQUOTE] = ACTIONS(2226),
    [anon_sym_u8_SQUOTE] = ACTIONS(2226),
    [anon_sym_SQUOTE] = ACTIONS(2226),
    [anon_sym_L_DQUOTE] = ACTIONS(2226),
    [anon_sym_u_DQUOTE] = ACTIONS(2226),
    [anon_sym_U_DQUOTE] = ACTIONS(2226),
    [anon_sym_u8_DQUOTE] = ACTIONS(2226),
    [anon_sym_DQUOTE] = ACTIONS(2226),
    [sym_true] = ACTIONS(2224),
    [sym_false] = ACTIONS(2224),
    [anon_sym_NULL] = ACTIONS(2224),
    [anon_sym_nullptr] = ACTIONS(2224),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2224),
    [anon_sym_decltype] = ACTIONS(2224),
    [sym_virtual] = ACTIONS(2224),
    [anon_sym_explicit] = ACTIONS(2224),
    [anon_sym_typename] = ACTIONS(2224),
    [anon_sym_template] = ACTIONS(2224),
    [anon_sym_operator] = ACTIONS(2224),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_delete] = ACTIONS(2224),
    [anon_sym_throw] = ACTIONS(2224),
    [anon_sym_namespace] = ACTIONS(2224),
    [anon_sym_using] = ACTIONS(2224),
    [anon_sym_static_assert] = ACTIONS(2224),
    [anon_sym_concept] = ACTIONS(2224),
    [anon_sym_co_return] = ACTIONS(2224),
    [anon_sym_co_yield] = ACTIONS(2224),
    [anon_sym_R_DQUOTE] = ACTIONS(2226),
    [anon_sym_LR_DQUOTE] = ACTIONS(2226),
    [anon_sym_uR_DQUOTE] = ACTIONS(2226),
    [anon_sym_UR_DQUOTE] = ACTIONS(2226),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2226),
    [anon_sym_co_await] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(2224),
    [anon_sym_requires] = ACTIONS(2224),
    [sym_this] = ACTIONS(2224),
    [anon_sym_discard] = ACTIONS(2224),
    [anon_sym_precise] = ACTIONS(2224),
    [anon_sym_shared] = ACTIONS(2224),
    [anon_sym_groupshared] = ACTIONS(2224),
    [anon_sym_uniform] = ACTIONS(2224),
    [anon_sym_row_major] = ACTIONS(2224),
    [anon_sym_column_major] = ACTIONS(2224),
    [anon_sym_globallycoherent] = ACTIONS(2224),
    [anon_sym_centroid] = ACTIONS(2224),
    [anon_sym_noperspective] = ACTIONS(2224),
    [anon_sym_nointerpolation] = ACTIONS(2224),
    [anon_sym_sample] = ACTIONS(2224),
    [anon_sym_linear] = ACTIONS(2224),
    [anon_sym_snorm] = ACTIONS(2224),
    [anon_sym_unorm] = ACTIONS(2224),
    [anon_sym_point] = ACTIONS(2224),
    [anon_sym_line] = ACTIONS(2224),
    [anon_sym_triangleadj] = ACTIONS(2224),
    [anon_sym_lineadj] = ACTIONS(2224),
    [anon_sym_triangle] = ACTIONS(2224),
    [anon_sym_cbuffer] = ACTIONS(2224),
  },
  [536] = {
    [sym_expression] = STATE(4448),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7920),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2690),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(2693),
    [anon_sym___extension__] = ACTIONS(2288),
    [anon_sym_in] = ACTIONS(2288),
    [anon_sym_out] = ACTIONS(2288),
    [anon_sym_inout] = ACTIONS(2288),
    [anon_sym_extern] = ACTIONS(2288),
    [anon_sym___attribute__] = ACTIONS(2288),
    [anon_sym_COLON_COLON] = ACTIONS(2695),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2290),
    [anon_sym___declspec] = ACTIONS(2288),
    [anon_sym_signed] = ACTIONS(2288),
    [anon_sym_unsigned] = ACTIONS(2288),
    [anon_sym_long] = ACTIONS(2288),
    [anon_sym_short] = ACTIONS(2288),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(2288),
    [anon_sym_register] = ACTIONS(2288),
    [anon_sym_inline] = ACTIONS(2288),
    [anon_sym___inline] = ACTIONS(2288),
    [anon_sym___inline__] = ACTIONS(2288),
    [anon_sym___forceinline] = ACTIONS(2288),
    [anon_sym_thread_local] = ACTIONS(2288),
    [anon_sym___thread] = ACTIONS(2288),
    [anon_sym_const] = ACTIONS(2288),
    [anon_sym_constexpr] = ACTIONS(2288),
    [anon_sym_volatile] = ACTIONS(2288),
    [anon_sym_restrict] = ACTIONS(2288),
    [anon_sym___restrict__] = ACTIONS(2288),
    [anon_sym__Atomic] = ACTIONS(2288),
    [anon_sym__Noreturn] = ACTIONS(2288),
    [anon_sym_noreturn] = ACTIONS(2288),
    [anon_sym_mutable] = ACTIONS(2288),
    [anon_sym_constinit] = ACTIONS(2288),
    [anon_sym_consteval] = ACTIONS(2288),
    [anon_sym_alignas] = ACTIONS(2288),
    [anon_sym__Alignas] = ACTIONS(2288),
    [sym_primitive_type] = ACTIONS(2698),
    [anon_sym_enum] = ACTIONS(2288),
    [anon_sym_class] = ACTIONS(2288),
    [anon_sym_struct] = ACTIONS(2288),
    [anon_sym_union] = ACTIONS(2288),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2288),
    [anon_sym_decltype] = ACTIONS(2701),
    [sym_virtual] = ACTIONS(2288),
    [anon_sym_typename] = ACTIONS(2288),
    [anon_sym_template] = ACTIONS(2704),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_precise] = ACTIONS(2288),
    [anon_sym_shared] = ACTIONS(2288),
    [anon_sym_groupshared] = ACTIONS(2288),
    [anon_sym_uniform] = ACTIONS(2288),
    [anon_sym_row_major] = ACTIONS(2288),
    [anon_sym_column_major] = ACTIONS(2288),
    [anon_sym_globallycoherent] = ACTIONS(2288),
    [anon_sym_centroid] = ACTIONS(2288),
    [anon_sym_noperspective] = ACTIONS(2288),
    [anon_sym_nointerpolation] = ACTIONS(2288),
    [anon_sym_sample] = ACTIONS(2288),
    [anon_sym_linear] = ACTIONS(2288),
    [anon_sym_snorm] = ACTIONS(2288),
    [anon_sym_unorm] = ACTIONS(2288),
    [anon_sym_point] = ACTIONS(2288),
    [anon_sym_line] = ACTIONS(2288),
    [anon_sym_triangleadj] = ACTIONS(2288),
    [anon_sym_lineadj] = ACTIONS(2288),
    [anon_sym_triangle] = ACTIONS(2288),
  },
  [537] = {
    [ts_builtin_sym_end] = ACTIONS(2156),
    [sym_identifier] = ACTIONS(2154),
    [aux_sym_preproc_include_token1] = ACTIONS(2154),
    [aux_sym_preproc_def_token1] = ACTIONS(2154),
    [aux_sym_preproc_if_token1] = ACTIONS(2154),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2154),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2154),
    [sym_preproc_directive] = ACTIONS(2154),
    [anon_sym_LPAREN2] = ACTIONS(2156),
    [anon_sym_BANG] = ACTIONS(2156),
    [anon_sym_TILDE] = ACTIONS(2156),
    [anon_sym_DASH] = ACTIONS(2154),
    [anon_sym_PLUS] = ACTIONS(2154),
    [anon_sym_STAR] = ACTIONS(2156),
    [anon_sym_AMP_AMP] = ACTIONS(2156),
    [anon_sym_AMP] = ACTIONS(2154),
    [anon_sym_SEMI] = ACTIONS(2156),
    [anon_sym___extension__] = ACTIONS(2154),
    [anon_sym_typedef] = ACTIONS(2154),
    [anon_sym_in] = ACTIONS(2154),
    [anon_sym_out] = ACTIONS(2154),
    [anon_sym_inout] = ACTIONS(2154),
    [anon_sym_extern] = ACTIONS(2154),
    [anon_sym___attribute__] = ACTIONS(2154),
    [anon_sym_COLON_COLON] = ACTIONS(2156),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2156),
    [anon_sym___declspec] = ACTIONS(2154),
    [anon_sym___based] = ACTIONS(2154),
    [anon_sym___cdecl] = ACTIONS(2154),
    [anon_sym___clrcall] = ACTIONS(2154),
    [anon_sym___stdcall] = ACTIONS(2154),
    [anon_sym___fastcall] = ACTIONS(2154),
    [anon_sym___thiscall] = ACTIONS(2154),
    [anon_sym___vectorcall] = ACTIONS(2154),
    [anon_sym_LBRACE] = ACTIONS(2156),
    [anon_sym_signed] = ACTIONS(2154),
    [anon_sym_unsigned] = ACTIONS(2154),
    [anon_sym_long] = ACTIONS(2154),
    [anon_sym_short] = ACTIONS(2154),
    [anon_sym_LBRACK] = ACTIONS(2154),
    [anon_sym_static] = ACTIONS(2154),
    [anon_sym_register] = ACTIONS(2154),
    [anon_sym_inline] = ACTIONS(2154),
    [anon_sym___inline] = ACTIONS(2154),
    [anon_sym___inline__] = ACTIONS(2154),
    [anon_sym___forceinline] = ACTIONS(2154),
    [anon_sym_thread_local] = ACTIONS(2154),
    [anon_sym___thread] = ACTIONS(2154),
    [anon_sym_const] = ACTIONS(2154),
    [anon_sym_constexpr] = ACTIONS(2154),
    [anon_sym_volatile] = ACTIONS(2154),
    [anon_sym_restrict] = ACTIONS(2154),
    [anon_sym___restrict__] = ACTIONS(2154),
    [anon_sym__Atomic] = ACTIONS(2154),
    [anon_sym__Noreturn] = ACTIONS(2154),
    [anon_sym_noreturn] = ACTIONS(2154),
    [anon_sym_mutable] = ACTIONS(2154),
    [anon_sym_constinit] = ACTIONS(2154),
    [anon_sym_consteval] = ACTIONS(2154),
    [anon_sym_alignas] = ACTIONS(2154),
    [anon_sym__Alignas] = ACTIONS(2154),
    [sym_primitive_type] = ACTIONS(2154),
    [anon_sym_enum] = ACTIONS(2154),
    [anon_sym_class] = ACTIONS(2154),
    [anon_sym_struct] = ACTIONS(2154),
    [anon_sym_union] = ACTIONS(2154),
    [anon_sym_if] = ACTIONS(2154),
    [anon_sym_else] = ACTIONS(2154),
    [anon_sym_switch] = ACTIONS(2154),
    [anon_sym_case] = ACTIONS(2154),
    [anon_sym_default] = ACTIONS(2154),
    [anon_sym_while] = ACTIONS(2154),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_for] = ACTIONS(2154),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_break] = ACTIONS(2154),
    [anon_sym_continue] = ACTIONS(2154),
    [anon_sym_goto] = ACTIONS(2154),
    [anon_sym___try] = ACTIONS(2154),
    [anon_sym___leave] = ACTIONS(2154),
    [anon_sym_not] = ACTIONS(2154),
    [anon_sym_compl] = ACTIONS(2154),
    [anon_sym_DASH_DASH] = ACTIONS(2156),
    [anon_sym_PLUS_PLUS] = ACTIONS(2156),
    [anon_sym_sizeof] = ACTIONS(2154),
    [anon_sym___alignof__] = ACTIONS(2154),
    [anon_sym___alignof] = ACTIONS(2154),
    [anon_sym__alignof] = ACTIONS(2154),
    [anon_sym_alignof] = ACTIONS(2154),
    [anon_sym__Alignof] = ACTIONS(2154),
    [anon_sym_offsetof] = ACTIONS(2154),
    [anon_sym__Generic] = ACTIONS(2154),
    [anon_sym_asm] = ACTIONS(2154),
    [anon_sym___asm__] = ACTIONS(2154),
    [sym_number_literal] = ACTIONS(2156),
    [anon_sym_L_SQUOTE] = ACTIONS(2156),
    [anon_sym_u_SQUOTE] = ACTIONS(2156),
    [anon_sym_U_SQUOTE] = ACTIONS(2156),
    [anon_sym_u8_SQUOTE] = ACTIONS(2156),
    [anon_sym_SQUOTE] = ACTIONS(2156),
    [anon_sym_L_DQUOTE] = ACTIONS(2156),
    [anon_sym_u_DQUOTE] = ACTIONS(2156),
    [anon_sym_U_DQUOTE] = ACTIONS(2156),
    [anon_sym_u8_DQUOTE] = ACTIONS(2156),
    [anon_sym_DQUOTE] = ACTIONS(2156),
    [sym_true] = ACTIONS(2154),
    [sym_false] = ACTIONS(2154),
    [anon_sym_NULL] = ACTIONS(2154),
    [anon_sym_nullptr] = ACTIONS(2154),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2154),
    [anon_sym_decltype] = ACTIONS(2154),
    [sym_virtual] = ACTIONS(2154),
    [anon_sym_explicit] = ACTIONS(2154),
    [anon_sym_typename] = ACTIONS(2154),
    [anon_sym_template] = ACTIONS(2154),
    [anon_sym_operator] = ACTIONS(2154),
    [anon_sym_try] = ACTIONS(2154),
    [anon_sym_delete] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2154),
    [anon_sym_namespace] = ACTIONS(2154),
    [anon_sym_using] = ACTIONS(2154),
    [anon_sym_static_assert] = ACTIONS(2154),
    [anon_sym_concept] = ACTIONS(2154),
    [anon_sym_co_return] = ACTIONS(2154),
    [anon_sym_co_yield] = ACTIONS(2154),
    [anon_sym_R_DQUOTE] = ACTIONS(2156),
    [anon_sym_LR_DQUOTE] = ACTIONS(2156),
    [anon_sym_uR_DQUOTE] = ACTIONS(2156),
    [anon_sym_UR_DQUOTE] = ACTIONS(2156),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2156),
    [anon_sym_co_await] = ACTIONS(2154),
    [anon_sym_new] = ACTIONS(2154),
    [anon_sym_requires] = ACTIONS(2154),
    [sym_this] = ACTIONS(2154),
    [anon_sym_discard] = ACTIONS(2154),
    [anon_sym_precise] = ACTIONS(2154),
    [anon_sym_shared] = ACTIONS(2154),
    [anon_sym_groupshared] = ACTIONS(2154),
    [anon_sym_uniform] = ACTIONS(2154),
    [anon_sym_row_major] = ACTIONS(2154),
    [anon_sym_column_major] = ACTIONS(2154),
    [anon_sym_globallycoherent] = ACTIONS(2154),
    [anon_sym_centroid] = ACTIONS(2154),
    [anon_sym_noperspective] = ACTIONS(2154),
    [anon_sym_nointerpolation] = ACTIONS(2154),
    [anon_sym_sample] = ACTIONS(2154),
    [anon_sym_linear] = ACTIONS(2154),
    [anon_sym_snorm] = ACTIONS(2154),
    [anon_sym_unorm] = ACTIONS(2154),
    [anon_sym_point] = ACTIONS(2154),
    [anon_sym_line] = ACTIONS(2154),
    [anon_sym_triangleadj] = ACTIONS(2154),
    [anon_sym_lineadj] = ACTIONS(2154),
    [anon_sym_triangle] = ACTIONS(2154),
    [anon_sym_cbuffer] = ACTIONS(2154),
  },
  [538] = {
    [sym_expression] = STATE(4480),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7941),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2707),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(2710),
    [anon_sym___extension__] = ACTIONS(2712),
    [anon_sym_in] = ACTIONS(2712),
    [anon_sym_out] = ACTIONS(2712),
    [anon_sym_inout] = ACTIONS(2712),
    [anon_sym_extern] = ACTIONS(2712),
    [anon_sym___attribute__] = ACTIONS(2712),
    [anon_sym_COLON_COLON] = ACTIONS(2714),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2717),
    [anon_sym___declspec] = ACTIONS(2712),
    [anon_sym_signed] = ACTIONS(2712),
    [anon_sym_unsigned] = ACTIONS(2712),
    [anon_sym_long] = ACTIONS(2712),
    [anon_sym_short] = ACTIONS(2712),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(2712),
    [anon_sym_register] = ACTIONS(2712),
    [anon_sym_inline] = ACTIONS(2712),
    [anon_sym___inline] = ACTIONS(2712),
    [anon_sym___inline__] = ACTIONS(2712),
    [anon_sym___forceinline] = ACTIONS(2712),
    [anon_sym_thread_local] = ACTIONS(2712),
    [anon_sym___thread] = ACTIONS(2712),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_constexpr] = ACTIONS(2712),
    [anon_sym_volatile] = ACTIONS(2712),
    [anon_sym_restrict] = ACTIONS(2712),
    [anon_sym___restrict__] = ACTIONS(2712),
    [anon_sym__Atomic] = ACTIONS(2712),
    [anon_sym__Noreturn] = ACTIONS(2712),
    [anon_sym_noreturn] = ACTIONS(2712),
    [anon_sym_mutable] = ACTIONS(2712),
    [anon_sym_constinit] = ACTIONS(2712),
    [anon_sym_consteval] = ACTIONS(2712),
    [anon_sym_alignas] = ACTIONS(2712),
    [anon_sym__Alignas] = ACTIONS(2712),
    [sym_primitive_type] = ACTIONS(2719),
    [anon_sym_enum] = ACTIONS(2712),
    [anon_sym_class] = ACTIONS(2712),
    [anon_sym_struct] = ACTIONS(2712),
    [anon_sym_union] = ACTIONS(2712),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2712),
    [anon_sym_decltype] = ACTIONS(2722),
    [sym_virtual] = ACTIONS(2712),
    [anon_sym_typename] = ACTIONS(2712),
    [anon_sym_template] = ACTIONS(2725),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_precise] = ACTIONS(2712),
    [anon_sym_shared] = ACTIONS(2712),
    [anon_sym_groupshared] = ACTIONS(2712),
    [anon_sym_uniform] = ACTIONS(2712),
    [anon_sym_row_major] = ACTIONS(2712),
    [anon_sym_column_major] = ACTIONS(2712),
    [anon_sym_globallycoherent] = ACTIONS(2712),
    [anon_sym_centroid] = ACTIONS(2712),
    [anon_sym_noperspective] = ACTIONS(2712),
    [anon_sym_nointerpolation] = ACTIONS(2712),
    [anon_sym_sample] = ACTIONS(2712),
    [anon_sym_linear] = ACTIONS(2712),
    [anon_sym_snorm] = ACTIONS(2712),
    [anon_sym_unorm] = ACTIONS(2712),
    [anon_sym_point] = ACTIONS(2712),
    [anon_sym_line] = ACTIONS(2712),
    [anon_sym_triangleadj] = ACTIONS(2712),
    [anon_sym_lineadj] = ACTIONS(2712),
    [anon_sym_triangle] = ACTIONS(2712),
  },
  [539] = {
    [ts_builtin_sym_end] = ACTIONS(2160),
    [sym_identifier] = ACTIONS(2158),
    [aux_sym_preproc_include_token1] = ACTIONS(2158),
    [aux_sym_preproc_def_token1] = ACTIONS(2158),
    [aux_sym_preproc_if_token1] = ACTIONS(2158),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2158),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2158),
    [sym_preproc_directive] = ACTIONS(2158),
    [anon_sym_LPAREN2] = ACTIONS(2160),
    [anon_sym_BANG] = ACTIONS(2160),
    [anon_sym_TILDE] = ACTIONS(2160),
    [anon_sym_DASH] = ACTIONS(2158),
    [anon_sym_PLUS] = ACTIONS(2158),
    [anon_sym_STAR] = ACTIONS(2160),
    [anon_sym_AMP_AMP] = ACTIONS(2160),
    [anon_sym_AMP] = ACTIONS(2158),
    [anon_sym_SEMI] = ACTIONS(2160),
    [anon_sym___extension__] = ACTIONS(2158),
    [anon_sym_typedef] = ACTIONS(2158),
    [anon_sym_in] = ACTIONS(2158),
    [anon_sym_out] = ACTIONS(2158),
    [anon_sym_inout] = ACTIONS(2158),
    [anon_sym_extern] = ACTIONS(2158),
    [anon_sym___attribute__] = ACTIONS(2158),
    [anon_sym_COLON_COLON] = ACTIONS(2160),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2160),
    [anon_sym___declspec] = ACTIONS(2158),
    [anon_sym___based] = ACTIONS(2158),
    [anon_sym___cdecl] = ACTIONS(2158),
    [anon_sym___clrcall] = ACTIONS(2158),
    [anon_sym___stdcall] = ACTIONS(2158),
    [anon_sym___fastcall] = ACTIONS(2158),
    [anon_sym___thiscall] = ACTIONS(2158),
    [anon_sym___vectorcall] = ACTIONS(2158),
    [anon_sym_LBRACE] = ACTIONS(2160),
    [anon_sym_signed] = ACTIONS(2158),
    [anon_sym_unsigned] = ACTIONS(2158),
    [anon_sym_long] = ACTIONS(2158),
    [anon_sym_short] = ACTIONS(2158),
    [anon_sym_LBRACK] = ACTIONS(2158),
    [anon_sym_static] = ACTIONS(2158),
    [anon_sym_register] = ACTIONS(2158),
    [anon_sym_inline] = ACTIONS(2158),
    [anon_sym___inline] = ACTIONS(2158),
    [anon_sym___inline__] = ACTIONS(2158),
    [anon_sym___forceinline] = ACTIONS(2158),
    [anon_sym_thread_local] = ACTIONS(2158),
    [anon_sym___thread] = ACTIONS(2158),
    [anon_sym_const] = ACTIONS(2158),
    [anon_sym_constexpr] = ACTIONS(2158),
    [anon_sym_volatile] = ACTIONS(2158),
    [anon_sym_restrict] = ACTIONS(2158),
    [anon_sym___restrict__] = ACTIONS(2158),
    [anon_sym__Atomic] = ACTIONS(2158),
    [anon_sym__Noreturn] = ACTIONS(2158),
    [anon_sym_noreturn] = ACTIONS(2158),
    [anon_sym_mutable] = ACTIONS(2158),
    [anon_sym_constinit] = ACTIONS(2158),
    [anon_sym_consteval] = ACTIONS(2158),
    [anon_sym_alignas] = ACTIONS(2158),
    [anon_sym__Alignas] = ACTIONS(2158),
    [sym_primitive_type] = ACTIONS(2158),
    [anon_sym_enum] = ACTIONS(2158),
    [anon_sym_class] = ACTIONS(2158),
    [anon_sym_struct] = ACTIONS(2158),
    [anon_sym_union] = ACTIONS(2158),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_else] = ACTIONS(2158),
    [anon_sym_switch] = ACTIONS(2158),
    [anon_sym_case] = ACTIONS(2158),
    [anon_sym_default] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2158),
    [anon_sym_do] = ACTIONS(2158),
    [anon_sym_for] = ACTIONS(2158),
    [anon_sym_return] = ACTIONS(2158),
    [anon_sym_break] = ACTIONS(2158),
    [anon_sym_continue] = ACTIONS(2158),
    [anon_sym_goto] = ACTIONS(2158),
    [anon_sym___try] = ACTIONS(2158),
    [anon_sym___leave] = ACTIONS(2158),
    [anon_sym_not] = ACTIONS(2158),
    [anon_sym_compl] = ACTIONS(2158),
    [anon_sym_DASH_DASH] = ACTIONS(2160),
    [anon_sym_PLUS_PLUS] = ACTIONS(2160),
    [anon_sym_sizeof] = ACTIONS(2158),
    [anon_sym___alignof__] = ACTIONS(2158),
    [anon_sym___alignof] = ACTIONS(2158),
    [anon_sym__alignof] = ACTIONS(2158),
    [anon_sym_alignof] = ACTIONS(2158),
    [anon_sym__Alignof] = ACTIONS(2158),
    [anon_sym_offsetof] = ACTIONS(2158),
    [anon_sym__Generic] = ACTIONS(2158),
    [anon_sym_asm] = ACTIONS(2158),
    [anon_sym___asm__] = ACTIONS(2158),
    [sym_number_literal] = ACTIONS(2160),
    [anon_sym_L_SQUOTE] = ACTIONS(2160),
    [anon_sym_u_SQUOTE] = ACTIONS(2160),
    [anon_sym_U_SQUOTE] = ACTIONS(2160),
    [anon_sym_u8_SQUOTE] = ACTIONS(2160),
    [anon_sym_SQUOTE] = ACTIONS(2160),
    [anon_sym_L_DQUOTE] = ACTIONS(2160),
    [anon_sym_u_DQUOTE] = ACTIONS(2160),
    [anon_sym_U_DQUOTE] = ACTIONS(2160),
    [anon_sym_u8_DQUOTE] = ACTIONS(2160),
    [anon_sym_DQUOTE] = ACTIONS(2160),
    [sym_true] = ACTIONS(2158),
    [sym_false] = ACTIONS(2158),
    [anon_sym_NULL] = ACTIONS(2158),
    [anon_sym_nullptr] = ACTIONS(2158),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2158),
    [anon_sym_decltype] = ACTIONS(2158),
    [sym_virtual] = ACTIONS(2158),
    [anon_sym_explicit] = ACTIONS(2158),
    [anon_sym_typename] = ACTIONS(2158),
    [anon_sym_template] = ACTIONS(2158),
    [anon_sym_operator] = ACTIONS(2158),
    [anon_sym_try] = ACTIONS(2158),
    [anon_sym_delete] = ACTIONS(2158),
    [anon_sym_throw] = ACTIONS(2158),
    [anon_sym_namespace] = ACTIONS(2158),
    [anon_sym_using] = ACTIONS(2158),
    [anon_sym_static_assert] = ACTIONS(2158),
    [anon_sym_concept] = ACTIONS(2158),
    [anon_sym_co_return] = ACTIONS(2158),
    [anon_sym_co_yield] = ACTIONS(2158),
    [anon_sym_R_DQUOTE] = ACTIONS(2160),
    [anon_sym_LR_DQUOTE] = ACTIONS(2160),
    [anon_sym_uR_DQUOTE] = ACTIONS(2160),
    [anon_sym_UR_DQUOTE] = ACTIONS(2160),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2160),
    [anon_sym_co_await] = ACTIONS(2158),
    [anon_sym_new] = ACTIONS(2158),
    [anon_sym_requires] = ACTIONS(2158),
    [sym_this] = ACTIONS(2158),
    [anon_sym_discard] = ACTIONS(2158),
    [anon_sym_precise] = ACTIONS(2158),
    [anon_sym_shared] = ACTIONS(2158),
    [anon_sym_groupshared] = ACTIONS(2158),
    [anon_sym_uniform] = ACTIONS(2158),
    [anon_sym_row_major] = ACTIONS(2158),
    [anon_sym_column_major] = ACTIONS(2158),
    [anon_sym_globallycoherent] = ACTIONS(2158),
    [anon_sym_centroid] = ACTIONS(2158),
    [anon_sym_noperspective] = ACTIONS(2158),
    [anon_sym_nointerpolation] = ACTIONS(2158),
    [anon_sym_sample] = ACTIONS(2158),
    [anon_sym_linear] = ACTIONS(2158),
    [anon_sym_snorm] = ACTIONS(2158),
    [anon_sym_unorm] = ACTIONS(2158),
    [anon_sym_point] = ACTIONS(2158),
    [anon_sym_line] = ACTIONS(2158),
    [anon_sym_triangleadj] = ACTIONS(2158),
    [anon_sym_lineadj] = ACTIONS(2158),
    [anon_sym_triangle] = ACTIONS(2158),
    [anon_sym_cbuffer] = ACTIONS(2158),
  },
  [540] = {
    [sym_identifier] = ACTIONS(2204),
    [aux_sym_preproc_include_token1] = ACTIONS(2204),
    [aux_sym_preproc_def_token1] = ACTIONS(2204),
    [aux_sym_preproc_if_token1] = ACTIONS(2204),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2204),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2204),
    [sym_preproc_directive] = ACTIONS(2204),
    [anon_sym_LPAREN2] = ACTIONS(2206),
    [anon_sym_BANG] = ACTIONS(2206),
    [anon_sym_TILDE] = ACTIONS(2206),
    [anon_sym_DASH] = ACTIONS(2204),
    [anon_sym_PLUS] = ACTIONS(2204),
    [anon_sym_STAR] = ACTIONS(2206),
    [anon_sym_AMP_AMP] = ACTIONS(2206),
    [anon_sym_AMP] = ACTIONS(2204),
    [anon_sym_SEMI] = ACTIONS(2206),
    [anon_sym___extension__] = ACTIONS(2204),
    [anon_sym_typedef] = ACTIONS(2204),
    [anon_sym_in] = ACTIONS(2204),
    [anon_sym_out] = ACTIONS(2204),
    [anon_sym_inout] = ACTIONS(2204),
    [anon_sym_extern] = ACTIONS(2204),
    [anon_sym___attribute__] = ACTIONS(2204),
    [anon_sym_COLON_COLON] = ACTIONS(2206),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2206),
    [anon_sym___declspec] = ACTIONS(2204),
    [anon_sym___based] = ACTIONS(2204),
    [anon_sym___cdecl] = ACTIONS(2204),
    [anon_sym___clrcall] = ACTIONS(2204),
    [anon_sym___stdcall] = ACTIONS(2204),
    [anon_sym___fastcall] = ACTIONS(2204),
    [anon_sym___thiscall] = ACTIONS(2204),
    [anon_sym___vectorcall] = ACTIONS(2204),
    [anon_sym_LBRACE] = ACTIONS(2206),
    [anon_sym_RBRACE] = ACTIONS(2206),
    [anon_sym_signed] = ACTIONS(2204),
    [anon_sym_unsigned] = ACTIONS(2204),
    [anon_sym_long] = ACTIONS(2204),
    [anon_sym_short] = ACTIONS(2204),
    [anon_sym_LBRACK] = ACTIONS(2204),
    [anon_sym_static] = ACTIONS(2204),
    [anon_sym_register] = ACTIONS(2204),
    [anon_sym_inline] = ACTIONS(2204),
    [anon_sym___inline] = ACTIONS(2204),
    [anon_sym___inline__] = ACTIONS(2204),
    [anon_sym___forceinline] = ACTIONS(2204),
    [anon_sym_thread_local] = ACTIONS(2204),
    [anon_sym___thread] = ACTIONS(2204),
    [anon_sym_const] = ACTIONS(2204),
    [anon_sym_constexpr] = ACTIONS(2204),
    [anon_sym_volatile] = ACTIONS(2204),
    [anon_sym_restrict] = ACTIONS(2204),
    [anon_sym___restrict__] = ACTIONS(2204),
    [anon_sym__Atomic] = ACTIONS(2204),
    [anon_sym__Noreturn] = ACTIONS(2204),
    [anon_sym_noreturn] = ACTIONS(2204),
    [anon_sym_mutable] = ACTIONS(2204),
    [anon_sym_constinit] = ACTIONS(2204),
    [anon_sym_consteval] = ACTIONS(2204),
    [anon_sym_alignas] = ACTIONS(2204),
    [anon_sym__Alignas] = ACTIONS(2204),
    [sym_primitive_type] = ACTIONS(2204),
    [anon_sym_enum] = ACTIONS(2204),
    [anon_sym_class] = ACTIONS(2204),
    [anon_sym_struct] = ACTIONS(2204),
    [anon_sym_union] = ACTIONS(2204),
    [anon_sym_if] = ACTIONS(2204),
    [anon_sym_else] = ACTIONS(2204),
    [anon_sym_switch] = ACTIONS(2204),
    [anon_sym_case] = ACTIONS(2204),
    [anon_sym_default] = ACTIONS(2204),
    [anon_sym_while] = ACTIONS(2204),
    [anon_sym_do] = ACTIONS(2204),
    [anon_sym_for] = ACTIONS(2204),
    [anon_sym_return] = ACTIONS(2204),
    [anon_sym_break] = ACTIONS(2204),
    [anon_sym_continue] = ACTIONS(2204),
    [anon_sym_goto] = ACTIONS(2204),
    [anon_sym___try] = ACTIONS(2204),
    [anon_sym___leave] = ACTIONS(2204),
    [anon_sym_not] = ACTIONS(2204),
    [anon_sym_compl] = ACTIONS(2204),
    [anon_sym_DASH_DASH] = ACTIONS(2206),
    [anon_sym_PLUS_PLUS] = ACTIONS(2206),
    [anon_sym_sizeof] = ACTIONS(2204),
    [anon_sym___alignof__] = ACTIONS(2204),
    [anon_sym___alignof] = ACTIONS(2204),
    [anon_sym__alignof] = ACTIONS(2204),
    [anon_sym_alignof] = ACTIONS(2204),
    [anon_sym__Alignof] = ACTIONS(2204),
    [anon_sym_offsetof] = ACTIONS(2204),
    [anon_sym__Generic] = ACTIONS(2204),
    [anon_sym_asm] = ACTIONS(2204),
    [anon_sym___asm__] = ACTIONS(2204),
    [sym_number_literal] = ACTIONS(2206),
    [anon_sym_L_SQUOTE] = ACTIONS(2206),
    [anon_sym_u_SQUOTE] = ACTIONS(2206),
    [anon_sym_U_SQUOTE] = ACTIONS(2206),
    [anon_sym_u8_SQUOTE] = ACTIONS(2206),
    [anon_sym_SQUOTE] = ACTIONS(2206),
    [anon_sym_L_DQUOTE] = ACTIONS(2206),
    [anon_sym_u_DQUOTE] = ACTIONS(2206),
    [anon_sym_U_DQUOTE] = ACTIONS(2206),
    [anon_sym_u8_DQUOTE] = ACTIONS(2206),
    [anon_sym_DQUOTE] = ACTIONS(2206),
    [sym_true] = ACTIONS(2204),
    [sym_false] = ACTIONS(2204),
    [anon_sym_NULL] = ACTIONS(2204),
    [anon_sym_nullptr] = ACTIONS(2204),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2204),
    [anon_sym_decltype] = ACTIONS(2204),
    [sym_virtual] = ACTIONS(2204),
    [anon_sym_explicit] = ACTIONS(2204),
    [anon_sym_typename] = ACTIONS(2204),
    [anon_sym_template] = ACTIONS(2204),
    [anon_sym_operator] = ACTIONS(2204),
    [anon_sym_try] = ACTIONS(2204),
    [anon_sym_delete] = ACTIONS(2204),
    [anon_sym_throw] = ACTIONS(2204),
    [anon_sym_namespace] = ACTIONS(2204),
    [anon_sym_using] = ACTIONS(2204),
    [anon_sym_static_assert] = ACTIONS(2204),
    [anon_sym_concept] = ACTIONS(2204),
    [anon_sym_co_return] = ACTIONS(2204),
    [anon_sym_co_yield] = ACTIONS(2204),
    [anon_sym_R_DQUOTE] = ACTIONS(2206),
    [anon_sym_LR_DQUOTE] = ACTIONS(2206),
    [anon_sym_uR_DQUOTE] = ACTIONS(2206),
    [anon_sym_UR_DQUOTE] = ACTIONS(2206),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2206),
    [anon_sym_co_await] = ACTIONS(2204),
    [anon_sym_new] = ACTIONS(2204),
    [anon_sym_requires] = ACTIONS(2204),
    [sym_this] = ACTIONS(2204),
    [anon_sym_discard] = ACTIONS(2204),
    [anon_sym_precise] = ACTIONS(2204),
    [anon_sym_shared] = ACTIONS(2204),
    [anon_sym_groupshared] = ACTIONS(2204),
    [anon_sym_uniform] = ACTIONS(2204),
    [anon_sym_row_major] = ACTIONS(2204),
    [anon_sym_column_major] = ACTIONS(2204),
    [anon_sym_globallycoherent] = ACTIONS(2204),
    [anon_sym_centroid] = ACTIONS(2204),
    [anon_sym_noperspective] = ACTIONS(2204),
    [anon_sym_nointerpolation] = ACTIONS(2204),
    [anon_sym_sample] = ACTIONS(2204),
    [anon_sym_linear] = ACTIONS(2204),
    [anon_sym_snorm] = ACTIONS(2204),
    [anon_sym_unorm] = ACTIONS(2204),
    [anon_sym_point] = ACTIONS(2204),
    [anon_sym_line] = ACTIONS(2204),
    [anon_sym_triangleadj] = ACTIONS(2204),
    [anon_sym_lineadj] = ACTIONS(2204),
    [anon_sym_triangle] = ACTIONS(2204),
    [anon_sym_cbuffer] = ACTIONS(2204),
  },
  [541] = {
    [ts_builtin_sym_end] = ACTIONS(2196),
    [sym_identifier] = ACTIONS(2194),
    [aux_sym_preproc_include_token1] = ACTIONS(2194),
    [aux_sym_preproc_def_token1] = ACTIONS(2194),
    [aux_sym_preproc_if_token1] = ACTIONS(2194),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2194),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2194),
    [sym_preproc_directive] = ACTIONS(2194),
    [anon_sym_LPAREN2] = ACTIONS(2196),
    [anon_sym_BANG] = ACTIONS(2196),
    [anon_sym_TILDE] = ACTIONS(2196),
    [anon_sym_DASH] = ACTIONS(2194),
    [anon_sym_PLUS] = ACTIONS(2194),
    [anon_sym_STAR] = ACTIONS(2196),
    [anon_sym_AMP_AMP] = ACTIONS(2196),
    [anon_sym_AMP] = ACTIONS(2194),
    [anon_sym_SEMI] = ACTIONS(2196),
    [anon_sym___extension__] = ACTIONS(2194),
    [anon_sym_typedef] = ACTIONS(2194),
    [anon_sym_in] = ACTIONS(2194),
    [anon_sym_out] = ACTIONS(2194),
    [anon_sym_inout] = ACTIONS(2194),
    [anon_sym_extern] = ACTIONS(2194),
    [anon_sym___attribute__] = ACTIONS(2194),
    [anon_sym_COLON_COLON] = ACTIONS(2196),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2196),
    [anon_sym___declspec] = ACTIONS(2194),
    [anon_sym___based] = ACTIONS(2194),
    [anon_sym___cdecl] = ACTIONS(2194),
    [anon_sym___clrcall] = ACTIONS(2194),
    [anon_sym___stdcall] = ACTIONS(2194),
    [anon_sym___fastcall] = ACTIONS(2194),
    [anon_sym___thiscall] = ACTIONS(2194),
    [anon_sym___vectorcall] = ACTIONS(2194),
    [anon_sym_LBRACE] = ACTIONS(2196),
    [anon_sym_signed] = ACTIONS(2194),
    [anon_sym_unsigned] = ACTIONS(2194),
    [anon_sym_long] = ACTIONS(2194),
    [anon_sym_short] = ACTIONS(2194),
    [anon_sym_LBRACK] = ACTIONS(2194),
    [anon_sym_static] = ACTIONS(2194),
    [anon_sym_register] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(2194),
    [anon_sym___inline] = ACTIONS(2194),
    [anon_sym___inline__] = ACTIONS(2194),
    [anon_sym___forceinline] = ACTIONS(2194),
    [anon_sym_thread_local] = ACTIONS(2194),
    [anon_sym___thread] = ACTIONS(2194),
    [anon_sym_const] = ACTIONS(2194),
    [anon_sym_constexpr] = ACTIONS(2194),
    [anon_sym_volatile] = ACTIONS(2194),
    [anon_sym_restrict] = ACTIONS(2194),
    [anon_sym___restrict__] = ACTIONS(2194),
    [anon_sym__Atomic] = ACTIONS(2194),
    [anon_sym__Noreturn] = ACTIONS(2194),
    [anon_sym_noreturn] = ACTIONS(2194),
    [anon_sym_mutable] = ACTIONS(2194),
    [anon_sym_constinit] = ACTIONS(2194),
    [anon_sym_consteval] = ACTIONS(2194),
    [anon_sym_alignas] = ACTIONS(2194),
    [anon_sym__Alignas] = ACTIONS(2194),
    [sym_primitive_type] = ACTIONS(2194),
    [anon_sym_enum] = ACTIONS(2194),
    [anon_sym_class] = ACTIONS(2194),
    [anon_sym_struct] = ACTIONS(2194),
    [anon_sym_union] = ACTIONS(2194),
    [anon_sym_if] = ACTIONS(2194),
    [anon_sym_else] = ACTIONS(2194),
    [anon_sym_switch] = ACTIONS(2194),
    [anon_sym_case] = ACTIONS(2194),
    [anon_sym_default] = ACTIONS(2194),
    [anon_sym_while] = ACTIONS(2194),
    [anon_sym_do] = ACTIONS(2194),
    [anon_sym_for] = ACTIONS(2194),
    [anon_sym_return] = ACTIONS(2194),
    [anon_sym_break] = ACTIONS(2194),
    [anon_sym_continue] = ACTIONS(2194),
    [anon_sym_goto] = ACTIONS(2194),
    [anon_sym___try] = ACTIONS(2194),
    [anon_sym___leave] = ACTIONS(2194),
    [anon_sym_not] = ACTIONS(2194),
    [anon_sym_compl] = ACTIONS(2194),
    [anon_sym_DASH_DASH] = ACTIONS(2196),
    [anon_sym_PLUS_PLUS] = ACTIONS(2196),
    [anon_sym_sizeof] = ACTIONS(2194),
    [anon_sym___alignof__] = ACTIONS(2194),
    [anon_sym___alignof] = ACTIONS(2194),
    [anon_sym__alignof] = ACTIONS(2194),
    [anon_sym_alignof] = ACTIONS(2194),
    [anon_sym__Alignof] = ACTIONS(2194),
    [anon_sym_offsetof] = ACTIONS(2194),
    [anon_sym__Generic] = ACTIONS(2194),
    [anon_sym_asm] = ACTIONS(2194),
    [anon_sym___asm__] = ACTIONS(2194),
    [sym_number_literal] = ACTIONS(2196),
    [anon_sym_L_SQUOTE] = ACTIONS(2196),
    [anon_sym_u_SQUOTE] = ACTIONS(2196),
    [anon_sym_U_SQUOTE] = ACTIONS(2196),
    [anon_sym_u8_SQUOTE] = ACTIONS(2196),
    [anon_sym_SQUOTE] = ACTIONS(2196),
    [anon_sym_L_DQUOTE] = ACTIONS(2196),
    [anon_sym_u_DQUOTE] = ACTIONS(2196),
    [anon_sym_U_DQUOTE] = ACTIONS(2196),
    [anon_sym_u8_DQUOTE] = ACTIONS(2196),
    [anon_sym_DQUOTE] = ACTIONS(2196),
    [sym_true] = ACTIONS(2194),
    [sym_false] = ACTIONS(2194),
    [anon_sym_NULL] = ACTIONS(2194),
    [anon_sym_nullptr] = ACTIONS(2194),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2194),
    [anon_sym_decltype] = ACTIONS(2194),
    [sym_virtual] = ACTIONS(2194),
    [anon_sym_explicit] = ACTIONS(2194),
    [anon_sym_typename] = ACTIONS(2194),
    [anon_sym_template] = ACTIONS(2194),
    [anon_sym_operator] = ACTIONS(2194),
    [anon_sym_try] = ACTIONS(2194),
    [anon_sym_delete] = ACTIONS(2194),
    [anon_sym_throw] = ACTIONS(2194),
    [anon_sym_namespace] = ACTIONS(2194),
    [anon_sym_using] = ACTIONS(2194),
    [anon_sym_static_assert] = ACTIONS(2194),
    [anon_sym_concept] = ACTIONS(2194),
    [anon_sym_co_return] = ACTIONS(2194),
    [anon_sym_co_yield] = ACTIONS(2194),
    [anon_sym_R_DQUOTE] = ACTIONS(2196),
    [anon_sym_LR_DQUOTE] = ACTIONS(2196),
    [anon_sym_uR_DQUOTE] = ACTIONS(2196),
    [anon_sym_UR_DQUOTE] = ACTIONS(2196),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2196),
    [anon_sym_co_await] = ACTIONS(2194),
    [anon_sym_new] = ACTIONS(2194),
    [anon_sym_requires] = ACTIONS(2194),
    [sym_this] = ACTIONS(2194),
    [anon_sym_discard] = ACTIONS(2194),
    [anon_sym_precise] = ACTIONS(2194),
    [anon_sym_shared] = ACTIONS(2194),
    [anon_sym_groupshared] = ACTIONS(2194),
    [anon_sym_uniform] = ACTIONS(2194),
    [anon_sym_row_major] = ACTIONS(2194),
    [anon_sym_column_major] = ACTIONS(2194),
    [anon_sym_globallycoherent] = ACTIONS(2194),
    [anon_sym_centroid] = ACTIONS(2194),
    [anon_sym_noperspective] = ACTIONS(2194),
    [anon_sym_nointerpolation] = ACTIONS(2194),
    [anon_sym_sample] = ACTIONS(2194),
    [anon_sym_linear] = ACTIONS(2194),
    [anon_sym_snorm] = ACTIONS(2194),
    [anon_sym_unorm] = ACTIONS(2194),
    [anon_sym_point] = ACTIONS(2194),
    [anon_sym_line] = ACTIONS(2194),
    [anon_sym_triangleadj] = ACTIONS(2194),
    [anon_sym_lineadj] = ACTIONS(2194),
    [anon_sym_triangle] = ACTIONS(2194),
    [anon_sym_cbuffer] = ACTIONS(2194),
  },
  [542] = {
    [sym_identifier] = ACTIONS(2208),
    [aux_sym_preproc_include_token1] = ACTIONS(2208),
    [aux_sym_preproc_def_token1] = ACTIONS(2208),
    [aux_sym_preproc_if_token1] = ACTIONS(2208),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2208),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2208),
    [sym_preproc_directive] = ACTIONS(2208),
    [anon_sym_LPAREN2] = ACTIONS(2210),
    [anon_sym_BANG] = ACTIONS(2210),
    [anon_sym_TILDE] = ACTIONS(2210),
    [anon_sym_DASH] = ACTIONS(2208),
    [anon_sym_PLUS] = ACTIONS(2208),
    [anon_sym_STAR] = ACTIONS(2210),
    [anon_sym_AMP_AMP] = ACTIONS(2210),
    [anon_sym_AMP] = ACTIONS(2208),
    [anon_sym_SEMI] = ACTIONS(2210),
    [anon_sym___extension__] = ACTIONS(2208),
    [anon_sym_typedef] = ACTIONS(2208),
    [anon_sym_in] = ACTIONS(2208),
    [anon_sym_out] = ACTIONS(2208),
    [anon_sym_inout] = ACTIONS(2208),
    [anon_sym_extern] = ACTIONS(2208),
    [anon_sym___attribute__] = ACTIONS(2208),
    [anon_sym_COLON_COLON] = ACTIONS(2210),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2210),
    [anon_sym___declspec] = ACTIONS(2208),
    [anon_sym___based] = ACTIONS(2208),
    [anon_sym___cdecl] = ACTIONS(2208),
    [anon_sym___clrcall] = ACTIONS(2208),
    [anon_sym___stdcall] = ACTIONS(2208),
    [anon_sym___fastcall] = ACTIONS(2208),
    [anon_sym___thiscall] = ACTIONS(2208),
    [anon_sym___vectorcall] = ACTIONS(2208),
    [anon_sym_LBRACE] = ACTIONS(2210),
    [anon_sym_RBRACE] = ACTIONS(2210),
    [anon_sym_signed] = ACTIONS(2208),
    [anon_sym_unsigned] = ACTIONS(2208),
    [anon_sym_long] = ACTIONS(2208),
    [anon_sym_short] = ACTIONS(2208),
    [anon_sym_LBRACK] = ACTIONS(2208),
    [anon_sym_static] = ACTIONS(2208),
    [anon_sym_register] = ACTIONS(2208),
    [anon_sym_inline] = ACTIONS(2208),
    [anon_sym___inline] = ACTIONS(2208),
    [anon_sym___inline__] = ACTIONS(2208),
    [anon_sym___forceinline] = ACTIONS(2208),
    [anon_sym_thread_local] = ACTIONS(2208),
    [anon_sym___thread] = ACTIONS(2208),
    [anon_sym_const] = ACTIONS(2208),
    [anon_sym_constexpr] = ACTIONS(2208),
    [anon_sym_volatile] = ACTIONS(2208),
    [anon_sym_restrict] = ACTIONS(2208),
    [anon_sym___restrict__] = ACTIONS(2208),
    [anon_sym__Atomic] = ACTIONS(2208),
    [anon_sym__Noreturn] = ACTIONS(2208),
    [anon_sym_noreturn] = ACTIONS(2208),
    [anon_sym_mutable] = ACTIONS(2208),
    [anon_sym_constinit] = ACTIONS(2208),
    [anon_sym_consteval] = ACTIONS(2208),
    [anon_sym_alignas] = ACTIONS(2208),
    [anon_sym__Alignas] = ACTIONS(2208),
    [sym_primitive_type] = ACTIONS(2208),
    [anon_sym_enum] = ACTIONS(2208),
    [anon_sym_class] = ACTIONS(2208),
    [anon_sym_struct] = ACTIONS(2208),
    [anon_sym_union] = ACTIONS(2208),
    [anon_sym_if] = ACTIONS(2208),
    [anon_sym_else] = ACTIONS(2208),
    [anon_sym_switch] = ACTIONS(2208),
    [anon_sym_case] = ACTIONS(2208),
    [anon_sym_default] = ACTIONS(2208),
    [anon_sym_while] = ACTIONS(2208),
    [anon_sym_do] = ACTIONS(2208),
    [anon_sym_for] = ACTIONS(2208),
    [anon_sym_return] = ACTIONS(2208),
    [anon_sym_break] = ACTIONS(2208),
    [anon_sym_continue] = ACTIONS(2208),
    [anon_sym_goto] = ACTIONS(2208),
    [anon_sym___try] = ACTIONS(2208),
    [anon_sym___leave] = ACTIONS(2208),
    [anon_sym_not] = ACTIONS(2208),
    [anon_sym_compl] = ACTIONS(2208),
    [anon_sym_DASH_DASH] = ACTIONS(2210),
    [anon_sym_PLUS_PLUS] = ACTIONS(2210),
    [anon_sym_sizeof] = ACTIONS(2208),
    [anon_sym___alignof__] = ACTIONS(2208),
    [anon_sym___alignof] = ACTIONS(2208),
    [anon_sym__alignof] = ACTIONS(2208),
    [anon_sym_alignof] = ACTIONS(2208),
    [anon_sym__Alignof] = ACTIONS(2208),
    [anon_sym_offsetof] = ACTIONS(2208),
    [anon_sym__Generic] = ACTIONS(2208),
    [anon_sym_asm] = ACTIONS(2208),
    [anon_sym___asm__] = ACTIONS(2208),
    [sym_number_literal] = ACTIONS(2210),
    [anon_sym_L_SQUOTE] = ACTIONS(2210),
    [anon_sym_u_SQUOTE] = ACTIONS(2210),
    [anon_sym_U_SQUOTE] = ACTIONS(2210),
    [anon_sym_u8_SQUOTE] = ACTIONS(2210),
    [anon_sym_SQUOTE] = ACTIONS(2210),
    [anon_sym_L_DQUOTE] = ACTIONS(2210),
    [anon_sym_u_DQUOTE] = ACTIONS(2210),
    [anon_sym_U_DQUOTE] = ACTIONS(2210),
    [anon_sym_u8_DQUOTE] = ACTIONS(2210),
    [anon_sym_DQUOTE] = ACTIONS(2210),
    [sym_true] = ACTIONS(2208),
    [sym_false] = ACTIONS(2208),
    [anon_sym_NULL] = ACTIONS(2208),
    [anon_sym_nullptr] = ACTIONS(2208),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2208),
    [anon_sym_decltype] = ACTIONS(2208),
    [sym_virtual] = ACTIONS(2208),
    [anon_sym_explicit] = ACTIONS(2208),
    [anon_sym_typename] = ACTIONS(2208),
    [anon_sym_template] = ACTIONS(2208),
    [anon_sym_operator] = ACTIONS(2208),
    [anon_sym_try] = ACTIONS(2208),
    [anon_sym_delete] = ACTIONS(2208),
    [anon_sym_throw] = ACTIONS(2208),
    [anon_sym_namespace] = ACTIONS(2208),
    [anon_sym_using] = ACTIONS(2208),
    [anon_sym_static_assert] = ACTIONS(2208),
    [anon_sym_concept] = ACTIONS(2208),
    [anon_sym_co_return] = ACTIONS(2208),
    [anon_sym_co_yield] = ACTIONS(2208),
    [anon_sym_R_DQUOTE] = ACTIONS(2210),
    [anon_sym_LR_DQUOTE] = ACTIONS(2210),
    [anon_sym_uR_DQUOTE] = ACTIONS(2210),
    [anon_sym_UR_DQUOTE] = ACTIONS(2210),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2210),
    [anon_sym_co_await] = ACTIONS(2208),
    [anon_sym_new] = ACTIONS(2208),
    [anon_sym_requires] = ACTIONS(2208),
    [sym_this] = ACTIONS(2208),
    [anon_sym_discard] = ACTIONS(2208),
    [anon_sym_precise] = ACTIONS(2208),
    [anon_sym_shared] = ACTIONS(2208),
    [anon_sym_groupshared] = ACTIONS(2208),
    [anon_sym_uniform] = ACTIONS(2208),
    [anon_sym_row_major] = ACTIONS(2208),
    [anon_sym_column_major] = ACTIONS(2208),
    [anon_sym_globallycoherent] = ACTIONS(2208),
    [anon_sym_centroid] = ACTIONS(2208),
    [anon_sym_noperspective] = ACTIONS(2208),
    [anon_sym_nointerpolation] = ACTIONS(2208),
    [anon_sym_sample] = ACTIONS(2208),
    [anon_sym_linear] = ACTIONS(2208),
    [anon_sym_snorm] = ACTIONS(2208),
    [anon_sym_unorm] = ACTIONS(2208),
    [anon_sym_point] = ACTIONS(2208),
    [anon_sym_line] = ACTIONS(2208),
    [anon_sym_triangleadj] = ACTIONS(2208),
    [anon_sym_lineadj] = ACTIONS(2208),
    [anon_sym_triangle] = ACTIONS(2208),
    [anon_sym_cbuffer] = ACTIONS(2208),
  },
  [543] = {
    [sym_identifier] = ACTIONS(2212),
    [aux_sym_preproc_include_token1] = ACTIONS(2212),
    [aux_sym_preproc_def_token1] = ACTIONS(2212),
    [aux_sym_preproc_if_token1] = ACTIONS(2212),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2212),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2212),
    [sym_preproc_directive] = ACTIONS(2212),
    [anon_sym_LPAREN2] = ACTIONS(2214),
    [anon_sym_BANG] = ACTIONS(2214),
    [anon_sym_TILDE] = ACTIONS(2214),
    [anon_sym_DASH] = ACTIONS(2212),
    [anon_sym_PLUS] = ACTIONS(2212),
    [anon_sym_STAR] = ACTIONS(2214),
    [anon_sym_AMP_AMP] = ACTIONS(2214),
    [anon_sym_AMP] = ACTIONS(2212),
    [anon_sym_SEMI] = ACTIONS(2214),
    [anon_sym___extension__] = ACTIONS(2212),
    [anon_sym_typedef] = ACTIONS(2212),
    [anon_sym_in] = ACTIONS(2212),
    [anon_sym_out] = ACTIONS(2212),
    [anon_sym_inout] = ACTIONS(2212),
    [anon_sym_extern] = ACTIONS(2212),
    [anon_sym___attribute__] = ACTIONS(2212),
    [anon_sym_COLON_COLON] = ACTIONS(2214),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2214),
    [anon_sym___declspec] = ACTIONS(2212),
    [anon_sym___based] = ACTIONS(2212),
    [anon_sym___cdecl] = ACTIONS(2212),
    [anon_sym___clrcall] = ACTIONS(2212),
    [anon_sym___stdcall] = ACTIONS(2212),
    [anon_sym___fastcall] = ACTIONS(2212),
    [anon_sym___thiscall] = ACTIONS(2212),
    [anon_sym___vectorcall] = ACTIONS(2212),
    [anon_sym_LBRACE] = ACTIONS(2214),
    [anon_sym_RBRACE] = ACTIONS(2214),
    [anon_sym_signed] = ACTIONS(2212),
    [anon_sym_unsigned] = ACTIONS(2212),
    [anon_sym_long] = ACTIONS(2212),
    [anon_sym_short] = ACTIONS(2212),
    [anon_sym_LBRACK] = ACTIONS(2212),
    [anon_sym_static] = ACTIONS(2212),
    [anon_sym_register] = ACTIONS(2212),
    [anon_sym_inline] = ACTIONS(2212),
    [anon_sym___inline] = ACTIONS(2212),
    [anon_sym___inline__] = ACTIONS(2212),
    [anon_sym___forceinline] = ACTIONS(2212),
    [anon_sym_thread_local] = ACTIONS(2212),
    [anon_sym___thread] = ACTIONS(2212),
    [anon_sym_const] = ACTIONS(2212),
    [anon_sym_constexpr] = ACTIONS(2212),
    [anon_sym_volatile] = ACTIONS(2212),
    [anon_sym_restrict] = ACTIONS(2212),
    [anon_sym___restrict__] = ACTIONS(2212),
    [anon_sym__Atomic] = ACTIONS(2212),
    [anon_sym__Noreturn] = ACTIONS(2212),
    [anon_sym_noreturn] = ACTIONS(2212),
    [anon_sym_mutable] = ACTIONS(2212),
    [anon_sym_constinit] = ACTIONS(2212),
    [anon_sym_consteval] = ACTIONS(2212),
    [anon_sym_alignas] = ACTIONS(2212),
    [anon_sym__Alignas] = ACTIONS(2212),
    [sym_primitive_type] = ACTIONS(2212),
    [anon_sym_enum] = ACTIONS(2212),
    [anon_sym_class] = ACTIONS(2212),
    [anon_sym_struct] = ACTIONS(2212),
    [anon_sym_union] = ACTIONS(2212),
    [anon_sym_if] = ACTIONS(2212),
    [anon_sym_else] = ACTIONS(2212),
    [anon_sym_switch] = ACTIONS(2212),
    [anon_sym_case] = ACTIONS(2212),
    [anon_sym_default] = ACTIONS(2212),
    [anon_sym_while] = ACTIONS(2212),
    [anon_sym_do] = ACTIONS(2212),
    [anon_sym_for] = ACTIONS(2212),
    [anon_sym_return] = ACTIONS(2212),
    [anon_sym_break] = ACTIONS(2212),
    [anon_sym_continue] = ACTIONS(2212),
    [anon_sym_goto] = ACTIONS(2212),
    [anon_sym___try] = ACTIONS(2212),
    [anon_sym___leave] = ACTIONS(2212),
    [anon_sym_not] = ACTIONS(2212),
    [anon_sym_compl] = ACTIONS(2212),
    [anon_sym_DASH_DASH] = ACTIONS(2214),
    [anon_sym_PLUS_PLUS] = ACTIONS(2214),
    [anon_sym_sizeof] = ACTIONS(2212),
    [anon_sym___alignof__] = ACTIONS(2212),
    [anon_sym___alignof] = ACTIONS(2212),
    [anon_sym__alignof] = ACTIONS(2212),
    [anon_sym_alignof] = ACTIONS(2212),
    [anon_sym__Alignof] = ACTIONS(2212),
    [anon_sym_offsetof] = ACTIONS(2212),
    [anon_sym__Generic] = ACTIONS(2212),
    [anon_sym_asm] = ACTIONS(2212),
    [anon_sym___asm__] = ACTIONS(2212),
    [sym_number_literal] = ACTIONS(2214),
    [anon_sym_L_SQUOTE] = ACTIONS(2214),
    [anon_sym_u_SQUOTE] = ACTIONS(2214),
    [anon_sym_U_SQUOTE] = ACTIONS(2214),
    [anon_sym_u8_SQUOTE] = ACTIONS(2214),
    [anon_sym_SQUOTE] = ACTIONS(2214),
    [anon_sym_L_DQUOTE] = ACTIONS(2214),
    [anon_sym_u_DQUOTE] = ACTIONS(2214),
    [anon_sym_U_DQUOTE] = ACTIONS(2214),
    [anon_sym_u8_DQUOTE] = ACTIONS(2214),
    [anon_sym_DQUOTE] = ACTIONS(2214),
    [sym_true] = ACTIONS(2212),
    [sym_false] = ACTIONS(2212),
    [anon_sym_NULL] = ACTIONS(2212),
    [anon_sym_nullptr] = ACTIONS(2212),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2212),
    [anon_sym_decltype] = ACTIONS(2212),
    [sym_virtual] = ACTIONS(2212),
    [anon_sym_explicit] = ACTIONS(2212),
    [anon_sym_typename] = ACTIONS(2212),
    [anon_sym_template] = ACTIONS(2212),
    [anon_sym_operator] = ACTIONS(2212),
    [anon_sym_try] = ACTIONS(2212),
    [anon_sym_delete] = ACTIONS(2212),
    [anon_sym_throw] = ACTIONS(2212),
    [anon_sym_namespace] = ACTIONS(2212),
    [anon_sym_using] = ACTIONS(2212),
    [anon_sym_static_assert] = ACTIONS(2212),
    [anon_sym_concept] = ACTIONS(2212),
    [anon_sym_co_return] = ACTIONS(2212),
    [anon_sym_co_yield] = ACTIONS(2212),
    [anon_sym_R_DQUOTE] = ACTIONS(2214),
    [anon_sym_LR_DQUOTE] = ACTIONS(2214),
    [anon_sym_uR_DQUOTE] = ACTIONS(2214),
    [anon_sym_UR_DQUOTE] = ACTIONS(2214),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2214),
    [anon_sym_co_await] = ACTIONS(2212),
    [anon_sym_new] = ACTIONS(2212),
    [anon_sym_requires] = ACTIONS(2212),
    [sym_this] = ACTIONS(2212),
    [anon_sym_discard] = ACTIONS(2212),
    [anon_sym_precise] = ACTIONS(2212),
    [anon_sym_shared] = ACTIONS(2212),
    [anon_sym_groupshared] = ACTIONS(2212),
    [anon_sym_uniform] = ACTIONS(2212),
    [anon_sym_row_major] = ACTIONS(2212),
    [anon_sym_column_major] = ACTIONS(2212),
    [anon_sym_globallycoherent] = ACTIONS(2212),
    [anon_sym_centroid] = ACTIONS(2212),
    [anon_sym_noperspective] = ACTIONS(2212),
    [anon_sym_nointerpolation] = ACTIONS(2212),
    [anon_sym_sample] = ACTIONS(2212),
    [anon_sym_linear] = ACTIONS(2212),
    [anon_sym_snorm] = ACTIONS(2212),
    [anon_sym_unorm] = ACTIONS(2212),
    [anon_sym_point] = ACTIONS(2212),
    [anon_sym_line] = ACTIONS(2212),
    [anon_sym_triangleadj] = ACTIONS(2212),
    [anon_sym_lineadj] = ACTIONS(2212),
    [anon_sym_triangle] = ACTIONS(2212),
    [anon_sym_cbuffer] = ACTIONS(2212),
  },
  [544] = {
    [sym_identifier] = ACTIONS(1947),
    [aux_sym_preproc_include_token1] = ACTIONS(1947),
    [aux_sym_preproc_def_token1] = ACTIONS(1947),
    [anon_sym_COMMA] = ACTIONS(2202),
    [aux_sym_preproc_if_token1] = ACTIONS(1947),
    [aux_sym_preproc_if_token2] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1947),
    [sym_preproc_directive] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1945),
    [anon_sym_BANG] = ACTIONS(1945),
    [anon_sym_TILDE] = ACTIONS(1945),
    [anon_sym_DASH] = ACTIONS(1947),
    [anon_sym_PLUS] = ACTIONS(1947),
    [anon_sym_STAR] = ACTIONS(1945),
    [anon_sym_AMP_AMP] = ACTIONS(1945),
    [anon_sym_AMP] = ACTIONS(1947),
    [anon_sym_SEMI] = ACTIONS(2202),
    [anon_sym___extension__] = ACTIONS(1947),
    [anon_sym_typedef] = ACTIONS(1947),
    [anon_sym_in] = ACTIONS(1947),
    [anon_sym_out] = ACTIONS(1947),
    [anon_sym_inout] = ACTIONS(1947),
    [anon_sym_extern] = ACTIONS(1947),
    [anon_sym___attribute__] = ACTIONS(1947),
    [anon_sym_COLON_COLON] = ACTIONS(1945),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1945),
    [anon_sym___declspec] = ACTIONS(1947),
    [anon_sym___based] = ACTIONS(1947),
    [anon_sym___cdecl] = ACTIONS(1947),
    [anon_sym___clrcall] = ACTIONS(1947),
    [anon_sym___stdcall] = ACTIONS(1947),
    [anon_sym___fastcall] = ACTIONS(1947),
    [anon_sym___thiscall] = ACTIONS(1947),
    [anon_sym___vectorcall] = ACTIONS(1947),
    [anon_sym_LBRACE] = ACTIONS(1945),
    [anon_sym_signed] = ACTIONS(1947),
    [anon_sym_unsigned] = ACTIONS(1947),
    [anon_sym_long] = ACTIONS(1947),
    [anon_sym_short] = ACTIONS(1947),
    [anon_sym_LBRACK] = ACTIONS(1947),
    [anon_sym_static] = ACTIONS(1947),
    [anon_sym_register] = ACTIONS(1947),
    [anon_sym_inline] = ACTIONS(1947),
    [anon_sym___inline] = ACTIONS(1947),
    [anon_sym___inline__] = ACTIONS(1947),
    [anon_sym___forceinline] = ACTIONS(1947),
    [anon_sym_thread_local] = ACTIONS(1947),
    [anon_sym___thread] = ACTIONS(1947),
    [anon_sym_const] = ACTIONS(1947),
    [anon_sym_constexpr] = ACTIONS(1947),
    [anon_sym_volatile] = ACTIONS(1947),
    [anon_sym_restrict] = ACTIONS(1947),
    [anon_sym___restrict__] = ACTIONS(1947),
    [anon_sym__Atomic] = ACTIONS(1947),
    [anon_sym__Noreturn] = ACTIONS(1947),
    [anon_sym_noreturn] = ACTIONS(1947),
    [anon_sym_mutable] = ACTIONS(1947),
    [anon_sym_constinit] = ACTIONS(1947),
    [anon_sym_consteval] = ACTIONS(1947),
    [anon_sym_alignas] = ACTIONS(1947),
    [anon_sym__Alignas] = ACTIONS(1947),
    [sym_primitive_type] = ACTIONS(1947),
    [anon_sym_enum] = ACTIONS(1947),
    [anon_sym_class] = ACTIONS(1947),
    [anon_sym_struct] = ACTIONS(1947),
    [anon_sym_union] = ACTIONS(1947),
    [anon_sym_if] = ACTIONS(1947),
    [anon_sym_switch] = ACTIONS(1947),
    [anon_sym_case] = ACTIONS(1947),
    [anon_sym_default] = ACTIONS(1947),
    [anon_sym_while] = ACTIONS(1947),
    [anon_sym_do] = ACTIONS(1947),
    [anon_sym_for] = ACTIONS(1947),
    [anon_sym_return] = ACTIONS(1947),
    [anon_sym_break] = ACTIONS(1947),
    [anon_sym_continue] = ACTIONS(1947),
    [anon_sym_goto] = ACTIONS(1947),
    [anon_sym___try] = ACTIONS(1947),
    [anon_sym___leave] = ACTIONS(1947),
    [anon_sym_not] = ACTIONS(1947),
    [anon_sym_compl] = ACTIONS(1947),
    [anon_sym_DASH_DASH] = ACTIONS(1945),
    [anon_sym_PLUS_PLUS] = ACTIONS(1945),
    [anon_sym_sizeof] = ACTIONS(1947),
    [anon_sym___alignof__] = ACTIONS(1947),
    [anon_sym___alignof] = ACTIONS(1947),
    [anon_sym__alignof] = ACTIONS(1947),
    [anon_sym_alignof] = ACTIONS(1947),
    [anon_sym__Alignof] = ACTIONS(1947),
    [anon_sym_offsetof] = ACTIONS(1947),
    [anon_sym__Generic] = ACTIONS(1947),
    [anon_sym_asm] = ACTIONS(1947),
    [anon_sym___asm__] = ACTIONS(1947),
    [sym_number_literal] = ACTIONS(1945),
    [anon_sym_L_SQUOTE] = ACTIONS(1945),
    [anon_sym_u_SQUOTE] = ACTIONS(1945),
    [anon_sym_U_SQUOTE] = ACTIONS(1945),
    [anon_sym_u8_SQUOTE] = ACTIONS(1945),
    [anon_sym_SQUOTE] = ACTIONS(1945),
    [anon_sym_L_DQUOTE] = ACTIONS(1945),
    [anon_sym_u_DQUOTE] = ACTIONS(1945),
    [anon_sym_U_DQUOTE] = ACTIONS(1945),
    [anon_sym_u8_DQUOTE] = ACTIONS(1945),
    [anon_sym_DQUOTE] = ACTIONS(1945),
    [sym_true] = ACTIONS(1947),
    [sym_false] = ACTIONS(1947),
    [anon_sym_NULL] = ACTIONS(1947),
    [anon_sym_nullptr] = ACTIONS(1947),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1947),
    [anon_sym_decltype] = ACTIONS(1947),
    [sym_virtual] = ACTIONS(1947),
    [anon_sym_explicit] = ACTIONS(1947),
    [anon_sym_typename] = ACTIONS(1947),
    [anon_sym_template] = ACTIONS(1947),
    [anon_sym_operator] = ACTIONS(1947),
    [anon_sym_try] = ACTIONS(1947),
    [anon_sym_delete] = ACTIONS(1947),
    [anon_sym_throw] = ACTIONS(1947),
    [anon_sym_namespace] = ACTIONS(1947),
    [anon_sym_using] = ACTIONS(1947),
    [anon_sym_static_assert] = ACTIONS(1947),
    [anon_sym_concept] = ACTIONS(1947),
    [anon_sym_co_return] = ACTIONS(1947),
    [anon_sym_co_yield] = ACTIONS(1947),
    [anon_sym_R_DQUOTE] = ACTIONS(1945),
    [anon_sym_LR_DQUOTE] = ACTIONS(1945),
    [anon_sym_uR_DQUOTE] = ACTIONS(1945),
    [anon_sym_UR_DQUOTE] = ACTIONS(1945),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1945),
    [anon_sym_co_await] = ACTIONS(1947),
    [anon_sym_new] = ACTIONS(1947),
    [anon_sym_requires] = ACTIONS(1947),
    [sym_this] = ACTIONS(1947),
    [anon_sym_discard] = ACTIONS(1947),
    [anon_sym_precise] = ACTIONS(1947),
    [anon_sym_shared] = ACTIONS(1947),
    [anon_sym_groupshared] = ACTIONS(1947),
    [anon_sym_uniform] = ACTIONS(1947),
    [anon_sym_row_major] = ACTIONS(1947),
    [anon_sym_column_major] = ACTIONS(1947),
    [anon_sym_globallycoherent] = ACTIONS(1947),
    [anon_sym_centroid] = ACTIONS(1947),
    [anon_sym_noperspective] = ACTIONS(1947),
    [anon_sym_nointerpolation] = ACTIONS(1947),
    [anon_sym_sample] = ACTIONS(1947),
    [anon_sym_linear] = ACTIONS(1947),
    [anon_sym_snorm] = ACTIONS(1947),
    [anon_sym_unorm] = ACTIONS(1947),
    [anon_sym_point] = ACTIONS(1947),
    [anon_sym_line] = ACTIONS(1947),
    [anon_sym_triangleadj] = ACTIONS(1947),
    [anon_sym_lineadj] = ACTIONS(1947),
    [anon_sym_triangle] = ACTIONS(1947),
    [anon_sym_cbuffer] = ACTIONS(1947),
  },
  [545] = {
    [ts_builtin_sym_end] = ACTIONS(2218),
    [sym_identifier] = ACTIONS(2216),
    [aux_sym_preproc_include_token1] = ACTIONS(2216),
    [aux_sym_preproc_def_token1] = ACTIONS(2216),
    [aux_sym_preproc_if_token1] = ACTIONS(2216),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2216),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2216),
    [sym_preproc_directive] = ACTIONS(2216),
    [anon_sym_LPAREN2] = ACTIONS(2218),
    [anon_sym_BANG] = ACTIONS(2218),
    [anon_sym_TILDE] = ACTIONS(2218),
    [anon_sym_DASH] = ACTIONS(2216),
    [anon_sym_PLUS] = ACTIONS(2216),
    [anon_sym_STAR] = ACTIONS(2218),
    [anon_sym_AMP_AMP] = ACTIONS(2218),
    [anon_sym_AMP] = ACTIONS(2216),
    [anon_sym_SEMI] = ACTIONS(2218),
    [anon_sym___extension__] = ACTIONS(2216),
    [anon_sym_typedef] = ACTIONS(2216),
    [anon_sym_in] = ACTIONS(2216),
    [anon_sym_out] = ACTIONS(2216),
    [anon_sym_inout] = ACTIONS(2216),
    [anon_sym_extern] = ACTIONS(2216),
    [anon_sym___attribute__] = ACTIONS(2216),
    [anon_sym_COLON_COLON] = ACTIONS(2218),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2218),
    [anon_sym___declspec] = ACTIONS(2216),
    [anon_sym___based] = ACTIONS(2216),
    [anon_sym___cdecl] = ACTIONS(2216),
    [anon_sym___clrcall] = ACTIONS(2216),
    [anon_sym___stdcall] = ACTIONS(2216),
    [anon_sym___fastcall] = ACTIONS(2216),
    [anon_sym___thiscall] = ACTIONS(2216),
    [anon_sym___vectorcall] = ACTIONS(2216),
    [anon_sym_LBRACE] = ACTIONS(2218),
    [anon_sym_signed] = ACTIONS(2216),
    [anon_sym_unsigned] = ACTIONS(2216),
    [anon_sym_long] = ACTIONS(2216),
    [anon_sym_short] = ACTIONS(2216),
    [anon_sym_LBRACK] = ACTIONS(2216),
    [anon_sym_static] = ACTIONS(2216),
    [anon_sym_register] = ACTIONS(2216),
    [anon_sym_inline] = ACTIONS(2216),
    [anon_sym___inline] = ACTIONS(2216),
    [anon_sym___inline__] = ACTIONS(2216),
    [anon_sym___forceinline] = ACTIONS(2216),
    [anon_sym_thread_local] = ACTIONS(2216),
    [anon_sym___thread] = ACTIONS(2216),
    [anon_sym_const] = ACTIONS(2216),
    [anon_sym_constexpr] = ACTIONS(2216),
    [anon_sym_volatile] = ACTIONS(2216),
    [anon_sym_restrict] = ACTIONS(2216),
    [anon_sym___restrict__] = ACTIONS(2216),
    [anon_sym__Atomic] = ACTIONS(2216),
    [anon_sym__Noreturn] = ACTIONS(2216),
    [anon_sym_noreturn] = ACTIONS(2216),
    [anon_sym_mutable] = ACTIONS(2216),
    [anon_sym_constinit] = ACTIONS(2216),
    [anon_sym_consteval] = ACTIONS(2216),
    [anon_sym_alignas] = ACTIONS(2216),
    [anon_sym__Alignas] = ACTIONS(2216),
    [sym_primitive_type] = ACTIONS(2216),
    [anon_sym_enum] = ACTIONS(2216),
    [anon_sym_class] = ACTIONS(2216),
    [anon_sym_struct] = ACTIONS(2216),
    [anon_sym_union] = ACTIONS(2216),
    [anon_sym_if] = ACTIONS(2216),
    [anon_sym_else] = ACTIONS(2216),
    [anon_sym_switch] = ACTIONS(2216),
    [anon_sym_case] = ACTIONS(2216),
    [anon_sym_default] = ACTIONS(2216),
    [anon_sym_while] = ACTIONS(2216),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_for] = ACTIONS(2216),
    [anon_sym_return] = ACTIONS(2216),
    [anon_sym_break] = ACTIONS(2216),
    [anon_sym_continue] = ACTIONS(2216),
    [anon_sym_goto] = ACTIONS(2216),
    [anon_sym___try] = ACTIONS(2216),
    [anon_sym___leave] = ACTIONS(2216),
    [anon_sym_not] = ACTIONS(2216),
    [anon_sym_compl] = ACTIONS(2216),
    [anon_sym_DASH_DASH] = ACTIONS(2218),
    [anon_sym_PLUS_PLUS] = ACTIONS(2218),
    [anon_sym_sizeof] = ACTIONS(2216),
    [anon_sym___alignof__] = ACTIONS(2216),
    [anon_sym___alignof] = ACTIONS(2216),
    [anon_sym__alignof] = ACTIONS(2216),
    [anon_sym_alignof] = ACTIONS(2216),
    [anon_sym__Alignof] = ACTIONS(2216),
    [anon_sym_offsetof] = ACTIONS(2216),
    [anon_sym__Generic] = ACTIONS(2216),
    [anon_sym_asm] = ACTIONS(2216),
    [anon_sym___asm__] = ACTIONS(2216),
    [sym_number_literal] = ACTIONS(2218),
    [anon_sym_L_SQUOTE] = ACTIONS(2218),
    [anon_sym_u_SQUOTE] = ACTIONS(2218),
    [anon_sym_U_SQUOTE] = ACTIONS(2218),
    [anon_sym_u8_SQUOTE] = ACTIONS(2218),
    [anon_sym_SQUOTE] = ACTIONS(2218),
    [anon_sym_L_DQUOTE] = ACTIONS(2218),
    [anon_sym_u_DQUOTE] = ACTIONS(2218),
    [anon_sym_U_DQUOTE] = ACTIONS(2218),
    [anon_sym_u8_DQUOTE] = ACTIONS(2218),
    [anon_sym_DQUOTE] = ACTIONS(2218),
    [sym_true] = ACTIONS(2216),
    [sym_false] = ACTIONS(2216),
    [anon_sym_NULL] = ACTIONS(2216),
    [anon_sym_nullptr] = ACTIONS(2216),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2216),
    [anon_sym_decltype] = ACTIONS(2216),
    [sym_virtual] = ACTIONS(2216),
    [anon_sym_explicit] = ACTIONS(2216),
    [anon_sym_typename] = ACTIONS(2216),
    [anon_sym_template] = ACTIONS(2216),
    [anon_sym_operator] = ACTIONS(2216),
    [anon_sym_try] = ACTIONS(2216),
    [anon_sym_delete] = ACTIONS(2216),
    [anon_sym_throw] = ACTIONS(2216),
    [anon_sym_namespace] = ACTIONS(2216),
    [anon_sym_using] = ACTIONS(2216),
    [anon_sym_static_assert] = ACTIONS(2216),
    [anon_sym_concept] = ACTIONS(2216),
    [anon_sym_co_return] = ACTIONS(2216),
    [anon_sym_co_yield] = ACTIONS(2216),
    [anon_sym_R_DQUOTE] = ACTIONS(2218),
    [anon_sym_LR_DQUOTE] = ACTIONS(2218),
    [anon_sym_uR_DQUOTE] = ACTIONS(2218),
    [anon_sym_UR_DQUOTE] = ACTIONS(2218),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2218),
    [anon_sym_co_await] = ACTIONS(2216),
    [anon_sym_new] = ACTIONS(2216),
    [anon_sym_requires] = ACTIONS(2216),
    [sym_this] = ACTIONS(2216),
    [anon_sym_discard] = ACTIONS(2216),
    [anon_sym_precise] = ACTIONS(2216),
    [anon_sym_shared] = ACTIONS(2216),
    [anon_sym_groupshared] = ACTIONS(2216),
    [anon_sym_uniform] = ACTIONS(2216),
    [anon_sym_row_major] = ACTIONS(2216),
    [anon_sym_column_major] = ACTIONS(2216),
    [anon_sym_globallycoherent] = ACTIONS(2216),
    [anon_sym_centroid] = ACTIONS(2216),
    [anon_sym_noperspective] = ACTIONS(2216),
    [anon_sym_nointerpolation] = ACTIONS(2216),
    [anon_sym_sample] = ACTIONS(2216),
    [anon_sym_linear] = ACTIONS(2216),
    [anon_sym_snorm] = ACTIONS(2216),
    [anon_sym_unorm] = ACTIONS(2216),
    [anon_sym_point] = ACTIONS(2216),
    [anon_sym_line] = ACTIONS(2216),
    [anon_sym_triangleadj] = ACTIONS(2216),
    [anon_sym_lineadj] = ACTIONS(2216),
    [anon_sym_triangle] = ACTIONS(2216),
    [anon_sym_cbuffer] = ACTIONS(2216),
  },
  [546] = {
    [sym_identifier] = ACTIONS(2520),
    [aux_sym_preproc_include_token1] = ACTIONS(2520),
    [aux_sym_preproc_def_token1] = ACTIONS(2520),
    [aux_sym_preproc_if_token1] = ACTIONS(2520),
    [aux_sym_preproc_if_token2] = ACTIONS(2520),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2520),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2520),
    [sym_preproc_directive] = ACTIONS(2520),
    [anon_sym_LPAREN2] = ACTIONS(2522),
    [anon_sym_BANG] = ACTIONS(2522),
    [anon_sym_TILDE] = ACTIONS(2522),
    [anon_sym_DASH] = ACTIONS(2520),
    [anon_sym_PLUS] = ACTIONS(2520),
    [anon_sym_STAR] = ACTIONS(2522),
    [anon_sym_AMP_AMP] = ACTIONS(2522),
    [anon_sym_AMP] = ACTIONS(2520),
    [anon_sym_SEMI] = ACTIONS(2522),
    [anon_sym___extension__] = ACTIONS(2520),
    [anon_sym_typedef] = ACTIONS(2520),
    [anon_sym_in] = ACTIONS(2520),
    [anon_sym_out] = ACTIONS(2520),
    [anon_sym_inout] = ACTIONS(2520),
    [anon_sym_extern] = ACTIONS(2520),
    [anon_sym___attribute__] = ACTIONS(2520),
    [anon_sym_COLON_COLON] = ACTIONS(2522),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2522),
    [anon_sym___declspec] = ACTIONS(2520),
    [anon_sym___based] = ACTIONS(2520),
    [anon_sym___cdecl] = ACTIONS(2520),
    [anon_sym___clrcall] = ACTIONS(2520),
    [anon_sym___stdcall] = ACTIONS(2520),
    [anon_sym___fastcall] = ACTIONS(2520),
    [anon_sym___thiscall] = ACTIONS(2520),
    [anon_sym___vectorcall] = ACTIONS(2520),
    [anon_sym_LBRACE] = ACTIONS(2522),
    [anon_sym_signed] = ACTIONS(2520),
    [anon_sym_unsigned] = ACTIONS(2520),
    [anon_sym_long] = ACTIONS(2520),
    [anon_sym_short] = ACTIONS(2520),
    [anon_sym_LBRACK] = ACTIONS(2520),
    [anon_sym_static] = ACTIONS(2520),
    [anon_sym_register] = ACTIONS(2520),
    [anon_sym_inline] = ACTIONS(2520),
    [anon_sym___inline] = ACTIONS(2520),
    [anon_sym___inline__] = ACTIONS(2520),
    [anon_sym___forceinline] = ACTIONS(2520),
    [anon_sym_thread_local] = ACTIONS(2520),
    [anon_sym___thread] = ACTIONS(2520),
    [anon_sym_const] = ACTIONS(2520),
    [anon_sym_constexpr] = ACTIONS(2520),
    [anon_sym_volatile] = ACTIONS(2520),
    [anon_sym_restrict] = ACTIONS(2520),
    [anon_sym___restrict__] = ACTIONS(2520),
    [anon_sym__Atomic] = ACTIONS(2520),
    [anon_sym__Noreturn] = ACTIONS(2520),
    [anon_sym_noreturn] = ACTIONS(2520),
    [anon_sym_mutable] = ACTIONS(2520),
    [anon_sym_constinit] = ACTIONS(2520),
    [anon_sym_consteval] = ACTIONS(2520),
    [anon_sym_alignas] = ACTIONS(2520),
    [anon_sym__Alignas] = ACTIONS(2520),
    [sym_primitive_type] = ACTIONS(2520),
    [anon_sym_enum] = ACTIONS(2520),
    [anon_sym_class] = ACTIONS(2520),
    [anon_sym_struct] = ACTIONS(2520),
    [anon_sym_union] = ACTIONS(2520),
    [anon_sym_if] = ACTIONS(2520),
    [anon_sym_switch] = ACTIONS(2520),
    [anon_sym_case] = ACTIONS(2520),
    [anon_sym_default] = ACTIONS(2520),
    [anon_sym_while] = ACTIONS(2520),
    [anon_sym_do] = ACTIONS(2520),
    [anon_sym_for] = ACTIONS(2520),
    [anon_sym_return] = ACTIONS(2520),
    [anon_sym_break] = ACTIONS(2520),
    [anon_sym_continue] = ACTIONS(2520),
    [anon_sym_goto] = ACTIONS(2520),
    [anon_sym___try] = ACTIONS(2520),
    [anon_sym___leave] = ACTIONS(2520),
    [anon_sym_not] = ACTIONS(2520),
    [anon_sym_compl] = ACTIONS(2520),
    [anon_sym_DASH_DASH] = ACTIONS(2522),
    [anon_sym_PLUS_PLUS] = ACTIONS(2522),
    [anon_sym_sizeof] = ACTIONS(2520),
    [anon_sym___alignof__] = ACTIONS(2520),
    [anon_sym___alignof] = ACTIONS(2520),
    [anon_sym__alignof] = ACTIONS(2520),
    [anon_sym_alignof] = ACTIONS(2520),
    [anon_sym__Alignof] = ACTIONS(2520),
    [anon_sym_offsetof] = ACTIONS(2520),
    [anon_sym__Generic] = ACTIONS(2520),
    [anon_sym_asm] = ACTIONS(2520),
    [anon_sym___asm__] = ACTIONS(2520),
    [sym_number_literal] = ACTIONS(2522),
    [anon_sym_L_SQUOTE] = ACTIONS(2522),
    [anon_sym_u_SQUOTE] = ACTIONS(2522),
    [anon_sym_U_SQUOTE] = ACTIONS(2522),
    [anon_sym_u8_SQUOTE] = ACTIONS(2522),
    [anon_sym_SQUOTE] = ACTIONS(2522),
    [anon_sym_L_DQUOTE] = ACTIONS(2522),
    [anon_sym_u_DQUOTE] = ACTIONS(2522),
    [anon_sym_U_DQUOTE] = ACTIONS(2522),
    [anon_sym_u8_DQUOTE] = ACTIONS(2522),
    [anon_sym_DQUOTE] = ACTIONS(2522),
    [sym_true] = ACTIONS(2520),
    [sym_false] = ACTIONS(2520),
    [anon_sym_NULL] = ACTIONS(2520),
    [anon_sym_nullptr] = ACTIONS(2520),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2520),
    [anon_sym_decltype] = ACTIONS(2520),
    [sym_virtual] = ACTIONS(2520),
    [anon_sym_explicit] = ACTIONS(2520),
    [anon_sym_typename] = ACTIONS(2520),
    [anon_sym_template] = ACTIONS(2520),
    [anon_sym_operator] = ACTIONS(2520),
    [anon_sym_try] = ACTIONS(2520),
    [anon_sym_delete] = ACTIONS(2520),
    [anon_sym_throw] = ACTIONS(2520),
    [anon_sym_namespace] = ACTIONS(2520),
    [anon_sym_using] = ACTIONS(2520),
    [anon_sym_static_assert] = ACTIONS(2520),
    [anon_sym_concept] = ACTIONS(2520),
    [anon_sym_co_return] = ACTIONS(2520),
    [anon_sym_co_yield] = ACTIONS(2520),
    [anon_sym_R_DQUOTE] = ACTIONS(2522),
    [anon_sym_LR_DQUOTE] = ACTIONS(2522),
    [anon_sym_uR_DQUOTE] = ACTIONS(2522),
    [anon_sym_UR_DQUOTE] = ACTIONS(2522),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2522),
    [anon_sym_co_await] = ACTIONS(2520),
    [anon_sym_new] = ACTIONS(2520),
    [anon_sym_requires] = ACTIONS(2520),
    [sym_this] = ACTIONS(2520),
    [anon_sym_discard] = ACTIONS(2520),
    [anon_sym_precise] = ACTIONS(2520),
    [anon_sym_shared] = ACTIONS(2520),
    [anon_sym_groupshared] = ACTIONS(2520),
    [anon_sym_uniform] = ACTIONS(2520),
    [anon_sym_row_major] = ACTIONS(2520),
    [anon_sym_column_major] = ACTIONS(2520),
    [anon_sym_globallycoherent] = ACTIONS(2520),
    [anon_sym_centroid] = ACTIONS(2520),
    [anon_sym_noperspective] = ACTIONS(2520),
    [anon_sym_nointerpolation] = ACTIONS(2520),
    [anon_sym_sample] = ACTIONS(2520),
    [anon_sym_linear] = ACTIONS(2520),
    [anon_sym_snorm] = ACTIONS(2520),
    [anon_sym_unorm] = ACTIONS(2520),
    [anon_sym_point] = ACTIONS(2520),
    [anon_sym_line] = ACTIONS(2520),
    [anon_sym_triangleadj] = ACTIONS(2520),
    [anon_sym_lineadj] = ACTIONS(2520),
    [anon_sym_triangle] = ACTIONS(2520),
    [anon_sym_cbuffer] = ACTIONS(2520),
  },
  [547] = {
    [sym_identifier] = ACTIONS(2412),
    [aux_sym_preproc_include_token1] = ACTIONS(2412),
    [aux_sym_preproc_def_token1] = ACTIONS(2412),
    [aux_sym_preproc_if_token1] = ACTIONS(2412),
    [aux_sym_preproc_if_token2] = ACTIONS(2412),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2412),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2412),
    [sym_preproc_directive] = ACTIONS(2412),
    [anon_sym_LPAREN2] = ACTIONS(2414),
    [anon_sym_BANG] = ACTIONS(2414),
    [anon_sym_TILDE] = ACTIONS(2414),
    [anon_sym_DASH] = ACTIONS(2412),
    [anon_sym_PLUS] = ACTIONS(2412),
    [anon_sym_STAR] = ACTIONS(2414),
    [anon_sym_AMP_AMP] = ACTIONS(2414),
    [anon_sym_AMP] = ACTIONS(2412),
    [anon_sym_SEMI] = ACTIONS(2414),
    [anon_sym___extension__] = ACTIONS(2412),
    [anon_sym_typedef] = ACTIONS(2412),
    [anon_sym_in] = ACTIONS(2412),
    [anon_sym_out] = ACTIONS(2412),
    [anon_sym_inout] = ACTIONS(2412),
    [anon_sym_extern] = ACTIONS(2412),
    [anon_sym___attribute__] = ACTIONS(2412),
    [anon_sym_COLON_COLON] = ACTIONS(2414),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2414),
    [anon_sym___declspec] = ACTIONS(2412),
    [anon_sym___based] = ACTIONS(2412),
    [anon_sym___cdecl] = ACTIONS(2412),
    [anon_sym___clrcall] = ACTIONS(2412),
    [anon_sym___stdcall] = ACTIONS(2412),
    [anon_sym___fastcall] = ACTIONS(2412),
    [anon_sym___thiscall] = ACTIONS(2412),
    [anon_sym___vectorcall] = ACTIONS(2412),
    [anon_sym_LBRACE] = ACTIONS(2414),
    [anon_sym_signed] = ACTIONS(2412),
    [anon_sym_unsigned] = ACTIONS(2412),
    [anon_sym_long] = ACTIONS(2412),
    [anon_sym_short] = ACTIONS(2412),
    [anon_sym_LBRACK] = ACTIONS(2412),
    [anon_sym_static] = ACTIONS(2412),
    [anon_sym_register] = ACTIONS(2412),
    [anon_sym_inline] = ACTIONS(2412),
    [anon_sym___inline] = ACTIONS(2412),
    [anon_sym___inline__] = ACTIONS(2412),
    [anon_sym___forceinline] = ACTIONS(2412),
    [anon_sym_thread_local] = ACTIONS(2412),
    [anon_sym___thread] = ACTIONS(2412),
    [anon_sym_const] = ACTIONS(2412),
    [anon_sym_constexpr] = ACTIONS(2412),
    [anon_sym_volatile] = ACTIONS(2412),
    [anon_sym_restrict] = ACTIONS(2412),
    [anon_sym___restrict__] = ACTIONS(2412),
    [anon_sym__Atomic] = ACTIONS(2412),
    [anon_sym__Noreturn] = ACTIONS(2412),
    [anon_sym_noreturn] = ACTIONS(2412),
    [anon_sym_mutable] = ACTIONS(2412),
    [anon_sym_constinit] = ACTIONS(2412),
    [anon_sym_consteval] = ACTIONS(2412),
    [anon_sym_alignas] = ACTIONS(2412),
    [anon_sym__Alignas] = ACTIONS(2412),
    [sym_primitive_type] = ACTIONS(2412),
    [anon_sym_enum] = ACTIONS(2412),
    [anon_sym_class] = ACTIONS(2412),
    [anon_sym_struct] = ACTIONS(2412),
    [anon_sym_union] = ACTIONS(2412),
    [anon_sym_if] = ACTIONS(2412),
    [anon_sym_switch] = ACTIONS(2412),
    [anon_sym_case] = ACTIONS(2412),
    [anon_sym_default] = ACTIONS(2412),
    [anon_sym_while] = ACTIONS(2412),
    [anon_sym_do] = ACTIONS(2412),
    [anon_sym_for] = ACTIONS(2412),
    [anon_sym_return] = ACTIONS(2412),
    [anon_sym_break] = ACTIONS(2412),
    [anon_sym_continue] = ACTIONS(2412),
    [anon_sym_goto] = ACTIONS(2412),
    [anon_sym___try] = ACTIONS(2412),
    [anon_sym___leave] = ACTIONS(2412),
    [anon_sym_not] = ACTIONS(2412),
    [anon_sym_compl] = ACTIONS(2412),
    [anon_sym_DASH_DASH] = ACTIONS(2414),
    [anon_sym_PLUS_PLUS] = ACTIONS(2414),
    [anon_sym_sizeof] = ACTIONS(2412),
    [anon_sym___alignof__] = ACTIONS(2412),
    [anon_sym___alignof] = ACTIONS(2412),
    [anon_sym__alignof] = ACTIONS(2412),
    [anon_sym_alignof] = ACTIONS(2412),
    [anon_sym__Alignof] = ACTIONS(2412),
    [anon_sym_offsetof] = ACTIONS(2412),
    [anon_sym__Generic] = ACTIONS(2412),
    [anon_sym_asm] = ACTIONS(2412),
    [anon_sym___asm__] = ACTIONS(2412),
    [sym_number_literal] = ACTIONS(2414),
    [anon_sym_L_SQUOTE] = ACTIONS(2414),
    [anon_sym_u_SQUOTE] = ACTIONS(2414),
    [anon_sym_U_SQUOTE] = ACTIONS(2414),
    [anon_sym_u8_SQUOTE] = ACTIONS(2414),
    [anon_sym_SQUOTE] = ACTIONS(2414),
    [anon_sym_L_DQUOTE] = ACTIONS(2414),
    [anon_sym_u_DQUOTE] = ACTIONS(2414),
    [anon_sym_U_DQUOTE] = ACTIONS(2414),
    [anon_sym_u8_DQUOTE] = ACTIONS(2414),
    [anon_sym_DQUOTE] = ACTIONS(2414),
    [sym_true] = ACTIONS(2412),
    [sym_false] = ACTIONS(2412),
    [anon_sym_NULL] = ACTIONS(2412),
    [anon_sym_nullptr] = ACTIONS(2412),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2412),
    [anon_sym_decltype] = ACTIONS(2412),
    [sym_virtual] = ACTIONS(2412),
    [anon_sym_explicit] = ACTIONS(2412),
    [anon_sym_typename] = ACTIONS(2412),
    [anon_sym_template] = ACTIONS(2412),
    [anon_sym_operator] = ACTIONS(2412),
    [anon_sym_try] = ACTIONS(2412),
    [anon_sym_delete] = ACTIONS(2412),
    [anon_sym_throw] = ACTIONS(2412),
    [anon_sym_namespace] = ACTIONS(2412),
    [anon_sym_using] = ACTIONS(2412),
    [anon_sym_static_assert] = ACTIONS(2412),
    [anon_sym_concept] = ACTIONS(2412),
    [anon_sym_co_return] = ACTIONS(2412),
    [anon_sym_co_yield] = ACTIONS(2412),
    [anon_sym_R_DQUOTE] = ACTIONS(2414),
    [anon_sym_LR_DQUOTE] = ACTIONS(2414),
    [anon_sym_uR_DQUOTE] = ACTIONS(2414),
    [anon_sym_UR_DQUOTE] = ACTIONS(2414),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2414),
    [anon_sym_co_await] = ACTIONS(2412),
    [anon_sym_new] = ACTIONS(2412),
    [anon_sym_requires] = ACTIONS(2412),
    [sym_this] = ACTIONS(2412),
    [anon_sym_discard] = ACTIONS(2412),
    [anon_sym_precise] = ACTIONS(2412),
    [anon_sym_shared] = ACTIONS(2412),
    [anon_sym_groupshared] = ACTIONS(2412),
    [anon_sym_uniform] = ACTIONS(2412),
    [anon_sym_row_major] = ACTIONS(2412),
    [anon_sym_column_major] = ACTIONS(2412),
    [anon_sym_globallycoherent] = ACTIONS(2412),
    [anon_sym_centroid] = ACTIONS(2412),
    [anon_sym_noperspective] = ACTIONS(2412),
    [anon_sym_nointerpolation] = ACTIONS(2412),
    [anon_sym_sample] = ACTIONS(2412),
    [anon_sym_linear] = ACTIONS(2412),
    [anon_sym_snorm] = ACTIONS(2412),
    [anon_sym_unorm] = ACTIONS(2412),
    [anon_sym_point] = ACTIONS(2412),
    [anon_sym_line] = ACTIONS(2412),
    [anon_sym_triangleadj] = ACTIONS(2412),
    [anon_sym_lineadj] = ACTIONS(2412),
    [anon_sym_triangle] = ACTIONS(2412),
    [anon_sym_cbuffer] = ACTIONS(2412),
  },
  [548] = {
    [sym_identifier] = ACTIONS(2383),
    [aux_sym_preproc_include_token1] = ACTIONS(2383),
    [aux_sym_preproc_def_token1] = ACTIONS(2383),
    [aux_sym_preproc_if_token1] = ACTIONS(2383),
    [aux_sym_preproc_if_token2] = ACTIONS(2383),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2383),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2383),
    [sym_preproc_directive] = ACTIONS(2383),
    [anon_sym_LPAREN2] = ACTIONS(2386),
    [anon_sym_BANG] = ACTIONS(2386),
    [anon_sym_TILDE] = ACTIONS(2386),
    [anon_sym_DASH] = ACTIONS(2383),
    [anon_sym_PLUS] = ACTIONS(2383),
    [anon_sym_STAR] = ACTIONS(2386),
    [anon_sym_AMP_AMP] = ACTIONS(2386),
    [anon_sym_AMP] = ACTIONS(2383),
    [anon_sym_SEMI] = ACTIONS(2386),
    [anon_sym___extension__] = ACTIONS(2383),
    [anon_sym_typedef] = ACTIONS(2383),
    [anon_sym_in] = ACTIONS(2383),
    [anon_sym_out] = ACTIONS(2383),
    [anon_sym_inout] = ACTIONS(2383),
    [anon_sym_extern] = ACTIONS(2383),
    [anon_sym___attribute__] = ACTIONS(2383),
    [anon_sym_COLON_COLON] = ACTIONS(2386),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2386),
    [anon_sym___declspec] = ACTIONS(2383),
    [anon_sym___based] = ACTIONS(2383),
    [anon_sym___cdecl] = ACTIONS(2383),
    [anon_sym___clrcall] = ACTIONS(2383),
    [anon_sym___stdcall] = ACTIONS(2383),
    [anon_sym___fastcall] = ACTIONS(2383),
    [anon_sym___thiscall] = ACTIONS(2383),
    [anon_sym___vectorcall] = ACTIONS(2383),
    [anon_sym_LBRACE] = ACTIONS(2386),
    [anon_sym_signed] = ACTIONS(2383),
    [anon_sym_unsigned] = ACTIONS(2383),
    [anon_sym_long] = ACTIONS(2383),
    [anon_sym_short] = ACTIONS(2383),
    [anon_sym_LBRACK] = ACTIONS(2383),
    [anon_sym_static] = ACTIONS(2383),
    [anon_sym_register] = ACTIONS(2383),
    [anon_sym_inline] = ACTIONS(2383),
    [anon_sym___inline] = ACTIONS(2383),
    [anon_sym___inline__] = ACTIONS(2383),
    [anon_sym___forceinline] = ACTIONS(2383),
    [anon_sym_thread_local] = ACTIONS(2383),
    [anon_sym___thread] = ACTIONS(2383),
    [anon_sym_const] = ACTIONS(2383),
    [anon_sym_constexpr] = ACTIONS(2383),
    [anon_sym_volatile] = ACTIONS(2383),
    [anon_sym_restrict] = ACTIONS(2383),
    [anon_sym___restrict__] = ACTIONS(2383),
    [anon_sym__Atomic] = ACTIONS(2383),
    [anon_sym__Noreturn] = ACTIONS(2383),
    [anon_sym_noreturn] = ACTIONS(2383),
    [anon_sym_mutable] = ACTIONS(2383),
    [anon_sym_constinit] = ACTIONS(2383),
    [anon_sym_consteval] = ACTIONS(2383),
    [anon_sym_alignas] = ACTIONS(2383),
    [anon_sym__Alignas] = ACTIONS(2383),
    [sym_primitive_type] = ACTIONS(2383),
    [anon_sym_enum] = ACTIONS(2383),
    [anon_sym_class] = ACTIONS(2383),
    [anon_sym_struct] = ACTIONS(2383),
    [anon_sym_union] = ACTIONS(2383),
    [anon_sym_if] = ACTIONS(2383),
    [anon_sym_switch] = ACTIONS(2383),
    [anon_sym_case] = ACTIONS(2383),
    [anon_sym_default] = ACTIONS(2383),
    [anon_sym_while] = ACTIONS(2383),
    [anon_sym_do] = ACTIONS(2383),
    [anon_sym_for] = ACTIONS(2383),
    [anon_sym_return] = ACTIONS(2383),
    [anon_sym_break] = ACTIONS(2383),
    [anon_sym_continue] = ACTIONS(2383),
    [anon_sym_goto] = ACTIONS(2383),
    [anon_sym___try] = ACTIONS(2383),
    [anon_sym___leave] = ACTIONS(2383),
    [anon_sym_not] = ACTIONS(2383),
    [anon_sym_compl] = ACTIONS(2383),
    [anon_sym_DASH_DASH] = ACTIONS(2386),
    [anon_sym_PLUS_PLUS] = ACTIONS(2386),
    [anon_sym_sizeof] = ACTIONS(2383),
    [anon_sym___alignof__] = ACTIONS(2383),
    [anon_sym___alignof] = ACTIONS(2383),
    [anon_sym__alignof] = ACTIONS(2383),
    [anon_sym_alignof] = ACTIONS(2383),
    [anon_sym__Alignof] = ACTIONS(2383),
    [anon_sym_offsetof] = ACTIONS(2383),
    [anon_sym__Generic] = ACTIONS(2383),
    [anon_sym_asm] = ACTIONS(2383),
    [anon_sym___asm__] = ACTIONS(2383),
    [sym_number_literal] = ACTIONS(2386),
    [anon_sym_L_SQUOTE] = ACTIONS(2386),
    [anon_sym_u_SQUOTE] = ACTIONS(2386),
    [anon_sym_U_SQUOTE] = ACTIONS(2386),
    [anon_sym_u8_SQUOTE] = ACTIONS(2386),
    [anon_sym_SQUOTE] = ACTIONS(2386),
    [anon_sym_L_DQUOTE] = ACTIONS(2386),
    [anon_sym_u_DQUOTE] = ACTIONS(2386),
    [anon_sym_U_DQUOTE] = ACTIONS(2386),
    [anon_sym_u8_DQUOTE] = ACTIONS(2386),
    [anon_sym_DQUOTE] = ACTIONS(2386),
    [sym_true] = ACTIONS(2383),
    [sym_false] = ACTIONS(2383),
    [anon_sym_NULL] = ACTIONS(2383),
    [anon_sym_nullptr] = ACTIONS(2383),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2383),
    [anon_sym_decltype] = ACTIONS(2383),
    [sym_virtual] = ACTIONS(2383),
    [anon_sym_explicit] = ACTIONS(2383),
    [anon_sym_typename] = ACTIONS(2383),
    [anon_sym_template] = ACTIONS(2383),
    [anon_sym_operator] = ACTIONS(2383),
    [anon_sym_try] = ACTIONS(2383),
    [anon_sym_delete] = ACTIONS(2383),
    [anon_sym_throw] = ACTIONS(2383),
    [anon_sym_namespace] = ACTIONS(2383),
    [anon_sym_using] = ACTIONS(2383),
    [anon_sym_static_assert] = ACTIONS(2383),
    [anon_sym_concept] = ACTIONS(2383),
    [anon_sym_co_return] = ACTIONS(2383),
    [anon_sym_co_yield] = ACTIONS(2383),
    [anon_sym_R_DQUOTE] = ACTIONS(2386),
    [anon_sym_LR_DQUOTE] = ACTIONS(2386),
    [anon_sym_uR_DQUOTE] = ACTIONS(2386),
    [anon_sym_UR_DQUOTE] = ACTIONS(2386),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2386),
    [anon_sym_co_await] = ACTIONS(2383),
    [anon_sym_new] = ACTIONS(2383),
    [anon_sym_requires] = ACTIONS(2383),
    [sym_this] = ACTIONS(2383),
    [anon_sym_discard] = ACTIONS(2383),
    [anon_sym_precise] = ACTIONS(2383),
    [anon_sym_shared] = ACTIONS(2383),
    [anon_sym_groupshared] = ACTIONS(2383),
    [anon_sym_uniform] = ACTIONS(2383),
    [anon_sym_row_major] = ACTIONS(2383),
    [anon_sym_column_major] = ACTIONS(2383),
    [anon_sym_globallycoherent] = ACTIONS(2383),
    [anon_sym_centroid] = ACTIONS(2383),
    [anon_sym_noperspective] = ACTIONS(2383),
    [anon_sym_nointerpolation] = ACTIONS(2383),
    [anon_sym_sample] = ACTIONS(2383),
    [anon_sym_linear] = ACTIONS(2383),
    [anon_sym_snorm] = ACTIONS(2383),
    [anon_sym_unorm] = ACTIONS(2383),
    [anon_sym_point] = ACTIONS(2383),
    [anon_sym_line] = ACTIONS(2383),
    [anon_sym_triangleadj] = ACTIONS(2383),
    [anon_sym_lineadj] = ACTIONS(2383),
    [anon_sym_triangle] = ACTIONS(2383),
    [anon_sym_cbuffer] = ACTIONS(2383),
  },
  [549] = {
    [sym_identifier] = ACTIONS(2340),
    [aux_sym_preproc_include_token1] = ACTIONS(2340),
    [aux_sym_preproc_def_token1] = ACTIONS(2340),
    [aux_sym_preproc_if_token1] = ACTIONS(2340),
    [aux_sym_preproc_if_token2] = ACTIONS(2340),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2340),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2340),
    [sym_preproc_directive] = ACTIONS(2340),
    [anon_sym_LPAREN2] = ACTIONS(2342),
    [anon_sym_BANG] = ACTIONS(2342),
    [anon_sym_TILDE] = ACTIONS(2342),
    [anon_sym_DASH] = ACTIONS(2340),
    [anon_sym_PLUS] = ACTIONS(2340),
    [anon_sym_STAR] = ACTIONS(2342),
    [anon_sym_AMP_AMP] = ACTIONS(2342),
    [anon_sym_AMP] = ACTIONS(2340),
    [anon_sym_SEMI] = ACTIONS(2342),
    [anon_sym___extension__] = ACTIONS(2340),
    [anon_sym_typedef] = ACTIONS(2340),
    [anon_sym_in] = ACTIONS(2340),
    [anon_sym_out] = ACTIONS(2340),
    [anon_sym_inout] = ACTIONS(2340),
    [anon_sym_extern] = ACTIONS(2340),
    [anon_sym___attribute__] = ACTIONS(2340),
    [anon_sym_COLON_COLON] = ACTIONS(2342),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2342),
    [anon_sym___declspec] = ACTIONS(2340),
    [anon_sym___based] = ACTIONS(2340),
    [anon_sym___cdecl] = ACTIONS(2340),
    [anon_sym___clrcall] = ACTIONS(2340),
    [anon_sym___stdcall] = ACTIONS(2340),
    [anon_sym___fastcall] = ACTIONS(2340),
    [anon_sym___thiscall] = ACTIONS(2340),
    [anon_sym___vectorcall] = ACTIONS(2340),
    [anon_sym_LBRACE] = ACTIONS(2342),
    [anon_sym_signed] = ACTIONS(2340),
    [anon_sym_unsigned] = ACTIONS(2340),
    [anon_sym_long] = ACTIONS(2340),
    [anon_sym_short] = ACTIONS(2340),
    [anon_sym_LBRACK] = ACTIONS(2340),
    [anon_sym_static] = ACTIONS(2340),
    [anon_sym_register] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(2340),
    [anon_sym___inline] = ACTIONS(2340),
    [anon_sym___inline__] = ACTIONS(2340),
    [anon_sym___forceinline] = ACTIONS(2340),
    [anon_sym_thread_local] = ACTIONS(2340),
    [anon_sym___thread] = ACTIONS(2340),
    [anon_sym_const] = ACTIONS(2340),
    [anon_sym_constexpr] = ACTIONS(2340),
    [anon_sym_volatile] = ACTIONS(2340),
    [anon_sym_restrict] = ACTIONS(2340),
    [anon_sym___restrict__] = ACTIONS(2340),
    [anon_sym__Atomic] = ACTIONS(2340),
    [anon_sym__Noreturn] = ACTIONS(2340),
    [anon_sym_noreturn] = ACTIONS(2340),
    [anon_sym_mutable] = ACTIONS(2340),
    [anon_sym_constinit] = ACTIONS(2340),
    [anon_sym_consteval] = ACTIONS(2340),
    [anon_sym_alignas] = ACTIONS(2340),
    [anon_sym__Alignas] = ACTIONS(2340),
    [sym_primitive_type] = ACTIONS(2340),
    [anon_sym_enum] = ACTIONS(2340),
    [anon_sym_class] = ACTIONS(2340),
    [anon_sym_struct] = ACTIONS(2340),
    [anon_sym_union] = ACTIONS(2340),
    [anon_sym_if] = ACTIONS(2340),
    [anon_sym_switch] = ACTIONS(2340),
    [anon_sym_case] = ACTIONS(2340),
    [anon_sym_default] = ACTIONS(2340),
    [anon_sym_while] = ACTIONS(2340),
    [anon_sym_do] = ACTIONS(2340),
    [anon_sym_for] = ACTIONS(2340),
    [anon_sym_return] = ACTIONS(2340),
    [anon_sym_break] = ACTIONS(2340),
    [anon_sym_continue] = ACTIONS(2340),
    [anon_sym_goto] = ACTIONS(2340),
    [anon_sym___try] = ACTIONS(2340),
    [anon_sym___leave] = ACTIONS(2340),
    [anon_sym_not] = ACTIONS(2340),
    [anon_sym_compl] = ACTIONS(2340),
    [anon_sym_DASH_DASH] = ACTIONS(2342),
    [anon_sym_PLUS_PLUS] = ACTIONS(2342),
    [anon_sym_sizeof] = ACTIONS(2340),
    [anon_sym___alignof__] = ACTIONS(2340),
    [anon_sym___alignof] = ACTIONS(2340),
    [anon_sym__alignof] = ACTIONS(2340),
    [anon_sym_alignof] = ACTIONS(2340),
    [anon_sym__Alignof] = ACTIONS(2340),
    [anon_sym_offsetof] = ACTIONS(2340),
    [anon_sym__Generic] = ACTIONS(2340),
    [anon_sym_asm] = ACTIONS(2340),
    [anon_sym___asm__] = ACTIONS(2340),
    [sym_number_literal] = ACTIONS(2342),
    [anon_sym_L_SQUOTE] = ACTIONS(2342),
    [anon_sym_u_SQUOTE] = ACTIONS(2342),
    [anon_sym_U_SQUOTE] = ACTIONS(2342),
    [anon_sym_u8_SQUOTE] = ACTIONS(2342),
    [anon_sym_SQUOTE] = ACTIONS(2342),
    [anon_sym_L_DQUOTE] = ACTIONS(2342),
    [anon_sym_u_DQUOTE] = ACTIONS(2342),
    [anon_sym_U_DQUOTE] = ACTIONS(2342),
    [anon_sym_u8_DQUOTE] = ACTIONS(2342),
    [anon_sym_DQUOTE] = ACTIONS(2342),
    [sym_true] = ACTIONS(2340),
    [sym_false] = ACTIONS(2340),
    [anon_sym_NULL] = ACTIONS(2340),
    [anon_sym_nullptr] = ACTIONS(2340),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2340),
    [anon_sym_decltype] = ACTIONS(2340),
    [sym_virtual] = ACTIONS(2340),
    [anon_sym_explicit] = ACTIONS(2340),
    [anon_sym_typename] = ACTIONS(2340),
    [anon_sym_template] = ACTIONS(2340),
    [anon_sym_operator] = ACTIONS(2340),
    [anon_sym_try] = ACTIONS(2340),
    [anon_sym_delete] = ACTIONS(2340),
    [anon_sym_throw] = ACTIONS(2340),
    [anon_sym_namespace] = ACTIONS(2340),
    [anon_sym_using] = ACTIONS(2340),
    [anon_sym_static_assert] = ACTIONS(2340),
    [anon_sym_concept] = ACTIONS(2340),
    [anon_sym_co_return] = ACTIONS(2340),
    [anon_sym_co_yield] = ACTIONS(2340),
    [anon_sym_R_DQUOTE] = ACTIONS(2342),
    [anon_sym_LR_DQUOTE] = ACTIONS(2342),
    [anon_sym_uR_DQUOTE] = ACTIONS(2342),
    [anon_sym_UR_DQUOTE] = ACTIONS(2342),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2342),
    [anon_sym_co_await] = ACTIONS(2340),
    [anon_sym_new] = ACTIONS(2340),
    [anon_sym_requires] = ACTIONS(2340),
    [sym_this] = ACTIONS(2340),
    [anon_sym_discard] = ACTIONS(2340),
    [anon_sym_precise] = ACTIONS(2340),
    [anon_sym_shared] = ACTIONS(2340),
    [anon_sym_groupshared] = ACTIONS(2340),
    [anon_sym_uniform] = ACTIONS(2340),
    [anon_sym_row_major] = ACTIONS(2340),
    [anon_sym_column_major] = ACTIONS(2340),
    [anon_sym_globallycoherent] = ACTIONS(2340),
    [anon_sym_centroid] = ACTIONS(2340),
    [anon_sym_noperspective] = ACTIONS(2340),
    [anon_sym_nointerpolation] = ACTIONS(2340),
    [anon_sym_sample] = ACTIONS(2340),
    [anon_sym_linear] = ACTIONS(2340),
    [anon_sym_snorm] = ACTIONS(2340),
    [anon_sym_unorm] = ACTIONS(2340),
    [anon_sym_point] = ACTIONS(2340),
    [anon_sym_line] = ACTIONS(2340),
    [anon_sym_triangleadj] = ACTIONS(2340),
    [anon_sym_lineadj] = ACTIONS(2340),
    [anon_sym_triangle] = ACTIONS(2340),
    [anon_sym_cbuffer] = ACTIONS(2340),
  },
  [550] = {
    [sym_identifier] = ACTIONS(2348),
    [aux_sym_preproc_include_token1] = ACTIONS(2348),
    [aux_sym_preproc_def_token1] = ACTIONS(2348),
    [aux_sym_preproc_if_token1] = ACTIONS(2348),
    [aux_sym_preproc_if_token2] = ACTIONS(2348),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2348),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2348),
    [sym_preproc_directive] = ACTIONS(2348),
    [anon_sym_LPAREN2] = ACTIONS(2350),
    [anon_sym_BANG] = ACTIONS(2350),
    [anon_sym_TILDE] = ACTIONS(2350),
    [anon_sym_DASH] = ACTIONS(2348),
    [anon_sym_PLUS] = ACTIONS(2348),
    [anon_sym_STAR] = ACTIONS(2350),
    [anon_sym_AMP_AMP] = ACTIONS(2350),
    [anon_sym_AMP] = ACTIONS(2348),
    [anon_sym_SEMI] = ACTIONS(2350),
    [anon_sym___extension__] = ACTIONS(2348),
    [anon_sym_typedef] = ACTIONS(2348),
    [anon_sym_in] = ACTIONS(2348),
    [anon_sym_out] = ACTIONS(2348),
    [anon_sym_inout] = ACTIONS(2348),
    [anon_sym_extern] = ACTIONS(2348),
    [anon_sym___attribute__] = ACTIONS(2348),
    [anon_sym_COLON_COLON] = ACTIONS(2350),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2350),
    [anon_sym___declspec] = ACTIONS(2348),
    [anon_sym___based] = ACTIONS(2348),
    [anon_sym___cdecl] = ACTIONS(2348),
    [anon_sym___clrcall] = ACTIONS(2348),
    [anon_sym___stdcall] = ACTIONS(2348),
    [anon_sym___fastcall] = ACTIONS(2348),
    [anon_sym___thiscall] = ACTIONS(2348),
    [anon_sym___vectorcall] = ACTIONS(2348),
    [anon_sym_LBRACE] = ACTIONS(2350),
    [anon_sym_signed] = ACTIONS(2348),
    [anon_sym_unsigned] = ACTIONS(2348),
    [anon_sym_long] = ACTIONS(2348),
    [anon_sym_short] = ACTIONS(2348),
    [anon_sym_LBRACK] = ACTIONS(2348),
    [anon_sym_static] = ACTIONS(2348),
    [anon_sym_register] = ACTIONS(2348),
    [anon_sym_inline] = ACTIONS(2348),
    [anon_sym___inline] = ACTIONS(2348),
    [anon_sym___inline__] = ACTIONS(2348),
    [anon_sym___forceinline] = ACTIONS(2348),
    [anon_sym_thread_local] = ACTIONS(2348),
    [anon_sym___thread] = ACTIONS(2348),
    [anon_sym_const] = ACTIONS(2348),
    [anon_sym_constexpr] = ACTIONS(2348),
    [anon_sym_volatile] = ACTIONS(2348),
    [anon_sym_restrict] = ACTIONS(2348),
    [anon_sym___restrict__] = ACTIONS(2348),
    [anon_sym__Atomic] = ACTIONS(2348),
    [anon_sym__Noreturn] = ACTIONS(2348),
    [anon_sym_noreturn] = ACTIONS(2348),
    [anon_sym_mutable] = ACTIONS(2348),
    [anon_sym_constinit] = ACTIONS(2348),
    [anon_sym_consteval] = ACTIONS(2348),
    [anon_sym_alignas] = ACTIONS(2348),
    [anon_sym__Alignas] = ACTIONS(2348),
    [sym_primitive_type] = ACTIONS(2348),
    [anon_sym_enum] = ACTIONS(2348),
    [anon_sym_class] = ACTIONS(2348),
    [anon_sym_struct] = ACTIONS(2348),
    [anon_sym_union] = ACTIONS(2348),
    [anon_sym_if] = ACTIONS(2348),
    [anon_sym_switch] = ACTIONS(2348),
    [anon_sym_case] = ACTIONS(2348),
    [anon_sym_default] = ACTIONS(2348),
    [anon_sym_while] = ACTIONS(2348),
    [anon_sym_do] = ACTIONS(2348),
    [anon_sym_for] = ACTIONS(2348),
    [anon_sym_return] = ACTIONS(2348),
    [anon_sym_break] = ACTIONS(2348),
    [anon_sym_continue] = ACTIONS(2348),
    [anon_sym_goto] = ACTIONS(2348),
    [anon_sym___try] = ACTIONS(2348),
    [anon_sym___leave] = ACTIONS(2348),
    [anon_sym_not] = ACTIONS(2348),
    [anon_sym_compl] = ACTIONS(2348),
    [anon_sym_DASH_DASH] = ACTIONS(2350),
    [anon_sym_PLUS_PLUS] = ACTIONS(2350),
    [anon_sym_sizeof] = ACTIONS(2348),
    [anon_sym___alignof__] = ACTIONS(2348),
    [anon_sym___alignof] = ACTIONS(2348),
    [anon_sym__alignof] = ACTIONS(2348),
    [anon_sym_alignof] = ACTIONS(2348),
    [anon_sym__Alignof] = ACTIONS(2348),
    [anon_sym_offsetof] = ACTIONS(2348),
    [anon_sym__Generic] = ACTIONS(2348),
    [anon_sym_asm] = ACTIONS(2348),
    [anon_sym___asm__] = ACTIONS(2348),
    [sym_number_literal] = ACTIONS(2350),
    [anon_sym_L_SQUOTE] = ACTIONS(2350),
    [anon_sym_u_SQUOTE] = ACTIONS(2350),
    [anon_sym_U_SQUOTE] = ACTIONS(2350),
    [anon_sym_u8_SQUOTE] = ACTIONS(2350),
    [anon_sym_SQUOTE] = ACTIONS(2350),
    [anon_sym_L_DQUOTE] = ACTIONS(2350),
    [anon_sym_u_DQUOTE] = ACTIONS(2350),
    [anon_sym_U_DQUOTE] = ACTIONS(2350),
    [anon_sym_u8_DQUOTE] = ACTIONS(2350),
    [anon_sym_DQUOTE] = ACTIONS(2350),
    [sym_true] = ACTIONS(2348),
    [sym_false] = ACTIONS(2348),
    [anon_sym_NULL] = ACTIONS(2348),
    [anon_sym_nullptr] = ACTIONS(2348),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2348),
    [anon_sym_decltype] = ACTIONS(2348),
    [sym_virtual] = ACTIONS(2348),
    [anon_sym_explicit] = ACTIONS(2348),
    [anon_sym_typename] = ACTIONS(2348),
    [anon_sym_template] = ACTIONS(2348),
    [anon_sym_operator] = ACTIONS(2348),
    [anon_sym_try] = ACTIONS(2348),
    [anon_sym_delete] = ACTIONS(2348),
    [anon_sym_throw] = ACTIONS(2348),
    [anon_sym_namespace] = ACTIONS(2348),
    [anon_sym_using] = ACTIONS(2348),
    [anon_sym_static_assert] = ACTIONS(2348),
    [anon_sym_concept] = ACTIONS(2348),
    [anon_sym_co_return] = ACTIONS(2348),
    [anon_sym_co_yield] = ACTIONS(2348),
    [anon_sym_R_DQUOTE] = ACTIONS(2350),
    [anon_sym_LR_DQUOTE] = ACTIONS(2350),
    [anon_sym_uR_DQUOTE] = ACTIONS(2350),
    [anon_sym_UR_DQUOTE] = ACTIONS(2350),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2350),
    [anon_sym_co_await] = ACTIONS(2348),
    [anon_sym_new] = ACTIONS(2348),
    [anon_sym_requires] = ACTIONS(2348),
    [sym_this] = ACTIONS(2348),
    [anon_sym_discard] = ACTIONS(2348),
    [anon_sym_precise] = ACTIONS(2348),
    [anon_sym_shared] = ACTIONS(2348),
    [anon_sym_groupshared] = ACTIONS(2348),
    [anon_sym_uniform] = ACTIONS(2348),
    [anon_sym_row_major] = ACTIONS(2348),
    [anon_sym_column_major] = ACTIONS(2348),
    [anon_sym_globallycoherent] = ACTIONS(2348),
    [anon_sym_centroid] = ACTIONS(2348),
    [anon_sym_noperspective] = ACTIONS(2348),
    [anon_sym_nointerpolation] = ACTIONS(2348),
    [anon_sym_sample] = ACTIONS(2348),
    [anon_sym_linear] = ACTIONS(2348),
    [anon_sym_snorm] = ACTIONS(2348),
    [anon_sym_unorm] = ACTIONS(2348),
    [anon_sym_point] = ACTIONS(2348),
    [anon_sym_line] = ACTIONS(2348),
    [anon_sym_triangleadj] = ACTIONS(2348),
    [anon_sym_lineadj] = ACTIONS(2348),
    [anon_sym_triangle] = ACTIONS(2348),
    [anon_sym_cbuffer] = ACTIONS(2348),
  },
  [551] = {
    [sym_identifier] = ACTIONS(2364),
    [aux_sym_preproc_include_token1] = ACTIONS(2364),
    [aux_sym_preproc_def_token1] = ACTIONS(2364),
    [aux_sym_preproc_if_token1] = ACTIONS(2364),
    [aux_sym_preproc_if_token2] = ACTIONS(2364),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2364),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2364),
    [sym_preproc_directive] = ACTIONS(2364),
    [anon_sym_LPAREN2] = ACTIONS(2366),
    [anon_sym_BANG] = ACTIONS(2366),
    [anon_sym_TILDE] = ACTIONS(2366),
    [anon_sym_DASH] = ACTIONS(2364),
    [anon_sym_PLUS] = ACTIONS(2364),
    [anon_sym_STAR] = ACTIONS(2366),
    [anon_sym_AMP_AMP] = ACTIONS(2366),
    [anon_sym_AMP] = ACTIONS(2364),
    [anon_sym_SEMI] = ACTIONS(2366),
    [anon_sym___extension__] = ACTIONS(2364),
    [anon_sym_typedef] = ACTIONS(2364),
    [anon_sym_in] = ACTIONS(2364),
    [anon_sym_out] = ACTIONS(2364),
    [anon_sym_inout] = ACTIONS(2364),
    [anon_sym_extern] = ACTIONS(2364),
    [anon_sym___attribute__] = ACTIONS(2364),
    [anon_sym_COLON_COLON] = ACTIONS(2366),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2366),
    [anon_sym___declspec] = ACTIONS(2364),
    [anon_sym___based] = ACTIONS(2364),
    [anon_sym___cdecl] = ACTIONS(2364),
    [anon_sym___clrcall] = ACTIONS(2364),
    [anon_sym___stdcall] = ACTIONS(2364),
    [anon_sym___fastcall] = ACTIONS(2364),
    [anon_sym___thiscall] = ACTIONS(2364),
    [anon_sym___vectorcall] = ACTIONS(2364),
    [anon_sym_LBRACE] = ACTIONS(2366),
    [anon_sym_signed] = ACTIONS(2364),
    [anon_sym_unsigned] = ACTIONS(2364),
    [anon_sym_long] = ACTIONS(2364),
    [anon_sym_short] = ACTIONS(2364),
    [anon_sym_LBRACK] = ACTIONS(2364),
    [anon_sym_static] = ACTIONS(2364),
    [anon_sym_register] = ACTIONS(2364),
    [anon_sym_inline] = ACTIONS(2364),
    [anon_sym___inline] = ACTIONS(2364),
    [anon_sym___inline__] = ACTIONS(2364),
    [anon_sym___forceinline] = ACTIONS(2364),
    [anon_sym_thread_local] = ACTIONS(2364),
    [anon_sym___thread] = ACTIONS(2364),
    [anon_sym_const] = ACTIONS(2364),
    [anon_sym_constexpr] = ACTIONS(2364),
    [anon_sym_volatile] = ACTIONS(2364),
    [anon_sym_restrict] = ACTIONS(2364),
    [anon_sym___restrict__] = ACTIONS(2364),
    [anon_sym__Atomic] = ACTIONS(2364),
    [anon_sym__Noreturn] = ACTIONS(2364),
    [anon_sym_noreturn] = ACTIONS(2364),
    [anon_sym_mutable] = ACTIONS(2364),
    [anon_sym_constinit] = ACTIONS(2364),
    [anon_sym_consteval] = ACTIONS(2364),
    [anon_sym_alignas] = ACTIONS(2364),
    [anon_sym__Alignas] = ACTIONS(2364),
    [sym_primitive_type] = ACTIONS(2364),
    [anon_sym_enum] = ACTIONS(2364),
    [anon_sym_class] = ACTIONS(2364),
    [anon_sym_struct] = ACTIONS(2364),
    [anon_sym_union] = ACTIONS(2364),
    [anon_sym_if] = ACTIONS(2364),
    [anon_sym_switch] = ACTIONS(2364),
    [anon_sym_case] = ACTIONS(2364),
    [anon_sym_default] = ACTIONS(2364),
    [anon_sym_while] = ACTIONS(2364),
    [anon_sym_do] = ACTIONS(2364),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_return] = ACTIONS(2364),
    [anon_sym_break] = ACTIONS(2364),
    [anon_sym_continue] = ACTIONS(2364),
    [anon_sym_goto] = ACTIONS(2364),
    [anon_sym___try] = ACTIONS(2364),
    [anon_sym___leave] = ACTIONS(2364),
    [anon_sym_not] = ACTIONS(2364),
    [anon_sym_compl] = ACTIONS(2364),
    [anon_sym_DASH_DASH] = ACTIONS(2366),
    [anon_sym_PLUS_PLUS] = ACTIONS(2366),
    [anon_sym_sizeof] = ACTIONS(2364),
    [anon_sym___alignof__] = ACTIONS(2364),
    [anon_sym___alignof] = ACTIONS(2364),
    [anon_sym__alignof] = ACTIONS(2364),
    [anon_sym_alignof] = ACTIONS(2364),
    [anon_sym__Alignof] = ACTIONS(2364),
    [anon_sym_offsetof] = ACTIONS(2364),
    [anon_sym__Generic] = ACTIONS(2364),
    [anon_sym_asm] = ACTIONS(2364),
    [anon_sym___asm__] = ACTIONS(2364),
    [sym_number_literal] = ACTIONS(2366),
    [anon_sym_L_SQUOTE] = ACTIONS(2366),
    [anon_sym_u_SQUOTE] = ACTIONS(2366),
    [anon_sym_U_SQUOTE] = ACTIONS(2366),
    [anon_sym_u8_SQUOTE] = ACTIONS(2366),
    [anon_sym_SQUOTE] = ACTIONS(2366),
    [anon_sym_L_DQUOTE] = ACTIONS(2366),
    [anon_sym_u_DQUOTE] = ACTIONS(2366),
    [anon_sym_U_DQUOTE] = ACTIONS(2366),
    [anon_sym_u8_DQUOTE] = ACTIONS(2366),
    [anon_sym_DQUOTE] = ACTIONS(2366),
    [sym_true] = ACTIONS(2364),
    [sym_false] = ACTIONS(2364),
    [anon_sym_NULL] = ACTIONS(2364),
    [anon_sym_nullptr] = ACTIONS(2364),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2364),
    [anon_sym_decltype] = ACTIONS(2364),
    [sym_virtual] = ACTIONS(2364),
    [anon_sym_explicit] = ACTIONS(2364),
    [anon_sym_typename] = ACTIONS(2364),
    [anon_sym_template] = ACTIONS(2364),
    [anon_sym_operator] = ACTIONS(2364),
    [anon_sym_try] = ACTIONS(2364),
    [anon_sym_delete] = ACTIONS(2364),
    [anon_sym_throw] = ACTIONS(2364),
    [anon_sym_namespace] = ACTIONS(2364),
    [anon_sym_using] = ACTIONS(2364),
    [anon_sym_static_assert] = ACTIONS(2364),
    [anon_sym_concept] = ACTIONS(2364),
    [anon_sym_co_return] = ACTIONS(2364),
    [anon_sym_co_yield] = ACTIONS(2364),
    [anon_sym_R_DQUOTE] = ACTIONS(2366),
    [anon_sym_LR_DQUOTE] = ACTIONS(2366),
    [anon_sym_uR_DQUOTE] = ACTIONS(2366),
    [anon_sym_UR_DQUOTE] = ACTIONS(2366),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2366),
    [anon_sym_co_await] = ACTIONS(2364),
    [anon_sym_new] = ACTIONS(2364),
    [anon_sym_requires] = ACTIONS(2364),
    [sym_this] = ACTIONS(2364),
    [anon_sym_discard] = ACTIONS(2364),
    [anon_sym_precise] = ACTIONS(2364),
    [anon_sym_shared] = ACTIONS(2364),
    [anon_sym_groupshared] = ACTIONS(2364),
    [anon_sym_uniform] = ACTIONS(2364),
    [anon_sym_row_major] = ACTIONS(2364),
    [anon_sym_column_major] = ACTIONS(2364),
    [anon_sym_globallycoherent] = ACTIONS(2364),
    [anon_sym_centroid] = ACTIONS(2364),
    [anon_sym_noperspective] = ACTIONS(2364),
    [anon_sym_nointerpolation] = ACTIONS(2364),
    [anon_sym_sample] = ACTIONS(2364),
    [anon_sym_linear] = ACTIONS(2364),
    [anon_sym_snorm] = ACTIONS(2364),
    [anon_sym_unorm] = ACTIONS(2364),
    [anon_sym_point] = ACTIONS(2364),
    [anon_sym_line] = ACTIONS(2364),
    [anon_sym_triangleadj] = ACTIONS(2364),
    [anon_sym_lineadj] = ACTIONS(2364),
    [anon_sym_triangle] = ACTIONS(2364),
    [anon_sym_cbuffer] = ACTIONS(2364),
  },
  [552] = {
    [sym_identifier] = ACTIONS(2404),
    [aux_sym_preproc_include_token1] = ACTIONS(2404),
    [aux_sym_preproc_def_token1] = ACTIONS(2404),
    [aux_sym_preproc_if_token1] = ACTIONS(2404),
    [aux_sym_preproc_if_token2] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2404),
    [sym_preproc_directive] = ACTIONS(2404),
    [anon_sym_LPAREN2] = ACTIONS(2406),
    [anon_sym_BANG] = ACTIONS(2406),
    [anon_sym_TILDE] = ACTIONS(2406),
    [anon_sym_DASH] = ACTIONS(2404),
    [anon_sym_PLUS] = ACTIONS(2404),
    [anon_sym_STAR] = ACTIONS(2406),
    [anon_sym_AMP_AMP] = ACTIONS(2406),
    [anon_sym_AMP] = ACTIONS(2404),
    [anon_sym_SEMI] = ACTIONS(2406),
    [anon_sym___extension__] = ACTIONS(2404),
    [anon_sym_typedef] = ACTIONS(2404),
    [anon_sym_in] = ACTIONS(2404),
    [anon_sym_out] = ACTIONS(2404),
    [anon_sym_inout] = ACTIONS(2404),
    [anon_sym_extern] = ACTIONS(2404),
    [anon_sym___attribute__] = ACTIONS(2404),
    [anon_sym_COLON_COLON] = ACTIONS(2406),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2406),
    [anon_sym___declspec] = ACTIONS(2404),
    [anon_sym___based] = ACTIONS(2404),
    [anon_sym___cdecl] = ACTIONS(2404),
    [anon_sym___clrcall] = ACTIONS(2404),
    [anon_sym___stdcall] = ACTIONS(2404),
    [anon_sym___fastcall] = ACTIONS(2404),
    [anon_sym___thiscall] = ACTIONS(2404),
    [anon_sym___vectorcall] = ACTIONS(2404),
    [anon_sym_LBRACE] = ACTIONS(2406),
    [anon_sym_signed] = ACTIONS(2404),
    [anon_sym_unsigned] = ACTIONS(2404),
    [anon_sym_long] = ACTIONS(2404),
    [anon_sym_short] = ACTIONS(2404),
    [anon_sym_LBRACK] = ACTIONS(2404),
    [anon_sym_static] = ACTIONS(2404),
    [anon_sym_register] = ACTIONS(2404),
    [anon_sym_inline] = ACTIONS(2404),
    [anon_sym___inline] = ACTIONS(2404),
    [anon_sym___inline__] = ACTIONS(2404),
    [anon_sym___forceinline] = ACTIONS(2404),
    [anon_sym_thread_local] = ACTIONS(2404),
    [anon_sym___thread] = ACTIONS(2404),
    [anon_sym_const] = ACTIONS(2404),
    [anon_sym_constexpr] = ACTIONS(2404),
    [anon_sym_volatile] = ACTIONS(2404),
    [anon_sym_restrict] = ACTIONS(2404),
    [anon_sym___restrict__] = ACTIONS(2404),
    [anon_sym__Atomic] = ACTIONS(2404),
    [anon_sym__Noreturn] = ACTIONS(2404),
    [anon_sym_noreturn] = ACTIONS(2404),
    [anon_sym_mutable] = ACTIONS(2404),
    [anon_sym_constinit] = ACTIONS(2404),
    [anon_sym_consteval] = ACTIONS(2404),
    [anon_sym_alignas] = ACTIONS(2404),
    [anon_sym__Alignas] = ACTIONS(2404),
    [sym_primitive_type] = ACTIONS(2404),
    [anon_sym_enum] = ACTIONS(2404),
    [anon_sym_class] = ACTIONS(2404),
    [anon_sym_struct] = ACTIONS(2404),
    [anon_sym_union] = ACTIONS(2404),
    [anon_sym_if] = ACTIONS(2404),
    [anon_sym_switch] = ACTIONS(2404),
    [anon_sym_case] = ACTIONS(2404),
    [anon_sym_default] = ACTIONS(2404),
    [anon_sym_while] = ACTIONS(2404),
    [anon_sym_do] = ACTIONS(2404),
    [anon_sym_for] = ACTIONS(2404),
    [anon_sym_return] = ACTIONS(2404),
    [anon_sym_break] = ACTIONS(2404),
    [anon_sym_continue] = ACTIONS(2404),
    [anon_sym_goto] = ACTIONS(2404),
    [anon_sym___try] = ACTIONS(2404),
    [anon_sym___leave] = ACTIONS(2404),
    [anon_sym_not] = ACTIONS(2404),
    [anon_sym_compl] = ACTIONS(2404),
    [anon_sym_DASH_DASH] = ACTIONS(2406),
    [anon_sym_PLUS_PLUS] = ACTIONS(2406),
    [anon_sym_sizeof] = ACTIONS(2404),
    [anon_sym___alignof__] = ACTIONS(2404),
    [anon_sym___alignof] = ACTIONS(2404),
    [anon_sym__alignof] = ACTIONS(2404),
    [anon_sym_alignof] = ACTIONS(2404),
    [anon_sym__Alignof] = ACTIONS(2404),
    [anon_sym_offsetof] = ACTIONS(2404),
    [anon_sym__Generic] = ACTIONS(2404),
    [anon_sym_asm] = ACTIONS(2404),
    [anon_sym___asm__] = ACTIONS(2404),
    [sym_number_literal] = ACTIONS(2406),
    [anon_sym_L_SQUOTE] = ACTIONS(2406),
    [anon_sym_u_SQUOTE] = ACTIONS(2406),
    [anon_sym_U_SQUOTE] = ACTIONS(2406),
    [anon_sym_u8_SQUOTE] = ACTIONS(2406),
    [anon_sym_SQUOTE] = ACTIONS(2406),
    [anon_sym_L_DQUOTE] = ACTIONS(2406),
    [anon_sym_u_DQUOTE] = ACTIONS(2406),
    [anon_sym_U_DQUOTE] = ACTIONS(2406),
    [anon_sym_u8_DQUOTE] = ACTIONS(2406),
    [anon_sym_DQUOTE] = ACTIONS(2406),
    [sym_true] = ACTIONS(2404),
    [sym_false] = ACTIONS(2404),
    [anon_sym_NULL] = ACTIONS(2404),
    [anon_sym_nullptr] = ACTIONS(2404),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2404),
    [anon_sym_decltype] = ACTIONS(2404),
    [sym_virtual] = ACTIONS(2404),
    [anon_sym_explicit] = ACTIONS(2404),
    [anon_sym_typename] = ACTIONS(2404),
    [anon_sym_template] = ACTIONS(2404),
    [anon_sym_operator] = ACTIONS(2404),
    [anon_sym_try] = ACTIONS(2404),
    [anon_sym_delete] = ACTIONS(2404),
    [anon_sym_throw] = ACTIONS(2404),
    [anon_sym_namespace] = ACTIONS(2404),
    [anon_sym_using] = ACTIONS(2404),
    [anon_sym_static_assert] = ACTIONS(2404),
    [anon_sym_concept] = ACTIONS(2404),
    [anon_sym_co_return] = ACTIONS(2404),
    [anon_sym_co_yield] = ACTIONS(2404),
    [anon_sym_R_DQUOTE] = ACTIONS(2406),
    [anon_sym_LR_DQUOTE] = ACTIONS(2406),
    [anon_sym_uR_DQUOTE] = ACTIONS(2406),
    [anon_sym_UR_DQUOTE] = ACTIONS(2406),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2406),
    [anon_sym_co_await] = ACTIONS(2404),
    [anon_sym_new] = ACTIONS(2404),
    [anon_sym_requires] = ACTIONS(2404),
    [sym_this] = ACTIONS(2404),
    [anon_sym_discard] = ACTIONS(2404),
    [anon_sym_precise] = ACTIONS(2404),
    [anon_sym_shared] = ACTIONS(2404),
    [anon_sym_groupshared] = ACTIONS(2404),
    [anon_sym_uniform] = ACTIONS(2404),
    [anon_sym_row_major] = ACTIONS(2404),
    [anon_sym_column_major] = ACTIONS(2404),
    [anon_sym_globallycoherent] = ACTIONS(2404),
    [anon_sym_centroid] = ACTIONS(2404),
    [anon_sym_noperspective] = ACTIONS(2404),
    [anon_sym_nointerpolation] = ACTIONS(2404),
    [anon_sym_sample] = ACTIONS(2404),
    [anon_sym_linear] = ACTIONS(2404),
    [anon_sym_snorm] = ACTIONS(2404),
    [anon_sym_unorm] = ACTIONS(2404),
    [anon_sym_point] = ACTIONS(2404),
    [anon_sym_line] = ACTIONS(2404),
    [anon_sym_triangleadj] = ACTIONS(2404),
    [anon_sym_lineadj] = ACTIONS(2404),
    [anon_sym_triangle] = ACTIONS(2404),
    [anon_sym_cbuffer] = ACTIONS(2404),
  },
  [553] = {
    [sym_identifier] = ACTIONS(2536),
    [aux_sym_preproc_include_token1] = ACTIONS(2536),
    [aux_sym_preproc_def_token1] = ACTIONS(2536),
    [aux_sym_preproc_if_token1] = ACTIONS(2536),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2536),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2536),
    [sym_preproc_directive] = ACTIONS(2536),
    [anon_sym_LPAREN2] = ACTIONS(2538),
    [anon_sym_BANG] = ACTIONS(2538),
    [anon_sym_TILDE] = ACTIONS(2538),
    [anon_sym_DASH] = ACTIONS(2536),
    [anon_sym_PLUS] = ACTIONS(2536),
    [anon_sym_STAR] = ACTIONS(2538),
    [anon_sym_AMP_AMP] = ACTIONS(2538),
    [anon_sym_AMP] = ACTIONS(2536),
    [anon_sym_SEMI] = ACTIONS(2538),
    [anon_sym___extension__] = ACTIONS(2536),
    [anon_sym_typedef] = ACTIONS(2536),
    [anon_sym_in] = ACTIONS(2536),
    [anon_sym_out] = ACTIONS(2536),
    [anon_sym_inout] = ACTIONS(2536),
    [anon_sym_extern] = ACTIONS(2536),
    [anon_sym___attribute__] = ACTIONS(2536),
    [anon_sym_COLON_COLON] = ACTIONS(2538),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2538),
    [anon_sym___declspec] = ACTIONS(2536),
    [anon_sym___based] = ACTIONS(2536),
    [anon_sym___cdecl] = ACTIONS(2536),
    [anon_sym___clrcall] = ACTIONS(2536),
    [anon_sym___stdcall] = ACTIONS(2536),
    [anon_sym___fastcall] = ACTIONS(2536),
    [anon_sym___thiscall] = ACTIONS(2536),
    [anon_sym___vectorcall] = ACTIONS(2536),
    [anon_sym_LBRACE] = ACTIONS(2538),
    [anon_sym_RBRACE] = ACTIONS(2538),
    [anon_sym_signed] = ACTIONS(2536),
    [anon_sym_unsigned] = ACTIONS(2536),
    [anon_sym_long] = ACTIONS(2536),
    [anon_sym_short] = ACTIONS(2536),
    [anon_sym_LBRACK] = ACTIONS(2536),
    [anon_sym_static] = ACTIONS(2536),
    [anon_sym_register] = ACTIONS(2536),
    [anon_sym_inline] = ACTIONS(2536),
    [anon_sym___inline] = ACTIONS(2536),
    [anon_sym___inline__] = ACTIONS(2536),
    [anon_sym___forceinline] = ACTIONS(2536),
    [anon_sym_thread_local] = ACTIONS(2536),
    [anon_sym___thread] = ACTIONS(2536),
    [anon_sym_const] = ACTIONS(2536),
    [anon_sym_constexpr] = ACTIONS(2536),
    [anon_sym_volatile] = ACTIONS(2536),
    [anon_sym_restrict] = ACTIONS(2536),
    [anon_sym___restrict__] = ACTIONS(2536),
    [anon_sym__Atomic] = ACTIONS(2536),
    [anon_sym__Noreturn] = ACTIONS(2536),
    [anon_sym_noreturn] = ACTIONS(2536),
    [anon_sym_mutable] = ACTIONS(2536),
    [anon_sym_constinit] = ACTIONS(2536),
    [anon_sym_consteval] = ACTIONS(2536),
    [anon_sym_alignas] = ACTIONS(2536),
    [anon_sym__Alignas] = ACTIONS(2536),
    [sym_primitive_type] = ACTIONS(2536),
    [anon_sym_enum] = ACTIONS(2536),
    [anon_sym_class] = ACTIONS(2536),
    [anon_sym_struct] = ACTIONS(2536),
    [anon_sym_union] = ACTIONS(2536),
    [anon_sym_if] = ACTIONS(2536),
    [anon_sym_switch] = ACTIONS(2536),
    [anon_sym_case] = ACTIONS(2536),
    [anon_sym_default] = ACTIONS(2536),
    [anon_sym_while] = ACTIONS(2536),
    [anon_sym_do] = ACTIONS(2536),
    [anon_sym_for] = ACTIONS(2536),
    [anon_sym_return] = ACTIONS(2536),
    [anon_sym_break] = ACTIONS(2536),
    [anon_sym_continue] = ACTIONS(2536),
    [anon_sym_goto] = ACTIONS(2536),
    [anon_sym___try] = ACTIONS(2536),
    [anon_sym___leave] = ACTIONS(2536),
    [anon_sym_not] = ACTIONS(2536),
    [anon_sym_compl] = ACTIONS(2536),
    [anon_sym_DASH_DASH] = ACTIONS(2538),
    [anon_sym_PLUS_PLUS] = ACTIONS(2538),
    [anon_sym_sizeof] = ACTIONS(2536),
    [anon_sym___alignof__] = ACTIONS(2536),
    [anon_sym___alignof] = ACTIONS(2536),
    [anon_sym__alignof] = ACTIONS(2536),
    [anon_sym_alignof] = ACTIONS(2536),
    [anon_sym__Alignof] = ACTIONS(2536),
    [anon_sym_offsetof] = ACTIONS(2536),
    [anon_sym__Generic] = ACTIONS(2536),
    [anon_sym_asm] = ACTIONS(2536),
    [anon_sym___asm__] = ACTIONS(2536),
    [sym_number_literal] = ACTIONS(2538),
    [anon_sym_L_SQUOTE] = ACTIONS(2538),
    [anon_sym_u_SQUOTE] = ACTIONS(2538),
    [anon_sym_U_SQUOTE] = ACTIONS(2538),
    [anon_sym_u8_SQUOTE] = ACTIONS(2538),
    [anon_sym_SQUOTE] = ACTIONS(2538),
    [anon_sym_L_DQUOTE] = ACTIONS(2538),
    [anon_sym_u_DQUOTE] = ACTIONS(2538),
    [anon_sym_U_DQUOTE] = ACTIONS(2538),
    [anon_sym_u8_DQUOTE] = ACTIONS(2538),
    [anon_sym_DQUOTE] = ACTIONS(2538),
    [sym_true] = ACTIONS(2536),
    [sym_false] = ACTIONS(2536),
    [anon_sym_NULL] = ACTIONS(2536),
    [anon_sym_nullptr] = ACTIONS(2536),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2536),
    [anon_sym_decltype] = ACTIONS(2536),
    [sym_virtual] = ACTIONS(2536),
    [anon_sym_explicit] = ACTIONS(2536),
    [anon_sym_typename] = ACTIONS(2536),
    [anon_sym_template] = ACTIONS(2536),
    [anon_sym_operator] = ACTIONS(2536),
    [anon_sym_try] = ACTIONS(2536),
    [anon_sym_delete] = ACTIONS(2536),
    [anon_sym_throw] = ACTIONS(2536),
    [anon_sym_namespace] = ACTIONS(2536),
    [anon_sym_using] = ACTIONS(2536),
    [anon_sym_static_assert] = ACTIONS(2536),
    [anon_sym_concept] = ACTIONS(2536),
    [anon_sym_co_return] = ACTIONS(2536),
    [anon_sym_co_yield] = ACTIONS(2536),
    [anon_sym_R_DQUOTE] = ACTIONS(2538),
    [anon_sym_LR_DQUOTE] = ACTIONS(2538),
    [anon_sym_uR_DQUOTE] = ACTIONS(2538),
    [anon_sym_UR_DQUOTE] = ACTIONS(2538),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2538),
    [anon_sym_co_await] = ACTIONS(2536),
    [anon_sym_new] = ACTIONS(2536),
    [anon_sym_requires] = ACTIONS(2536),
    [sym_this] = ACTIONS(2536),
    [anon_sym_discard] = ACTIONS(2536),
    [anon_sym_precise] = ACTIONS(2536),
    [anon_sym_shared] = ACTIONS(2536),
    [anon_sym_groupshared] = ACTIONS(2536),
    [anon_sym_uniform] = ACTIONS(2536),
    [anon_sym_row_major] = ACTIONS(2536),
    [anon_sym_column_major] = ACTIONS(2536),
    [anon_sym_globallycoherent] = ACTIONS(2536),
    [anon_sym_centroid] = ACTIONS(2536),
    [anon_sym_noperspective] = ACTIONS(2536),
    [anon_sym_nointerpolation] = ACTIONS(2536),
    [anon_sym_sample] = ACTIONS(2536),
    [anon_sym_linear] = ACTIONS(2536),
    [anon_sym_snorm] = ACTIONS(2536),
    [anon_sym_unorm] = ACTIONS(2536),
    [anon_sym_point] = ACTIONS(2536),
    [anon_sym_line] = ACTIONS(2536),
    [anon_sym_triangleadj] = ACTIONS(2536),
    [anon_sym_lineadj] = ACTIONS(2536),
    [anon_sym_triangle] = ACTIONS(2536),
    [anon_sym_cbuffer] = ACTIONS(2536),
  },
  [554] = {
    [sym_identifier] = ACTIONS(2316),
    [aux_sym_preproc_include_token1] = ACTIONS(2316),
    [aux_sym_preproc_def_token1] = ACTIONS(2316),
    [aux_sym_preproc_if_token1] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2316),
    [sym_preproc_directive] = ACTIONS(2316),
    [anon_sym_LPAREN2] = ACTIONS(2318),
    [anon_sym_BANG] = ACTIONS(2318),
    [anon_sym_TILDE] = ACTIONS(2318),
    [anon_sym_DASH] = ACTIONS(2316),
    [anon_sym_PLUS] = ACTIONS(2316),
    [anon_sym_STAR] = ACTIONS(2318),
    [anon_sym_AMP_AMP] = ACTIONS(2318),
    [anon_sym_AMP] = ACTIONS(2316),
    [anon_sym_SEMI] = ACTIONS(2318),
    [anon_sym___extension__] = ACTIONS(2316),
    [anon_sym_typedef] = ACTIONS(2316),
    [anon_sym_in] = ACTIONS(2316),
    [anon_sym_out] = ACTIONS(2316),
    [anon_sym_inout] = ACTIONS(2316),
    [anon_sym_extern] = ACTIONS(2316),
    [anon_sym___attribute__] = ACTIONS(2316),
    [anon_sym_COLON_COLON] = ACTIONS(2318),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2318),
    [anon_sym___declspec] = ACTIONS(2316),
    [anon_sym___based] = ACTIONS(2316),
    [anon_sym___cdecl] = ACTIONS(2316),
    [anon_sym___clrcall] = ACTIONS(2316),
    [anon_sym___stdcall] = ACTIONS(2316),
    [anon_sym___fastcall] = ACTIONS(2316),
    [anon_sym___thiscall] = ACTIONS(2316),
    [anon_sym___vectorcall] = ACTIONS(2316),
    [anon_sym_LBRACE] = ACTIONS(2318),
    [anon_sym_RBRACE] = ACTIONS(2318),
    [anon_sym_signed] = ACTIONS(2316),
    [anon_sym_unsigned] = ACTIONS(2316),
    [anon_sym_long] = ACTIONS(2316),
    [anon_sym_short] = ACTIONS(2316),
    [anon_sym_LBRACK] = ACTIONS(2316),
    [anon_sym_static] = ACTIONS(2316),
    [anon_sym_register] = ACTIONS(2316),
    [anon_sym_inline] = ACTIONS(2316),
    [anon_sym___inline] = ACTIONS(2316),
    [anon_sym___inline__] = ACTIONS(2316),
    [anon_sym___forceinline] = ACTIONS(2316),
    [anon_sym_thread_local] = ACTIONS(2316),
    [anon_sym___thread] = ACTIONS(2316),
    [anon_sym_const] = ACTIONS(2316),
    [anon_sym_constexpr] = ACTIONS(2316),
    [anon_sym_volatile] = ACTIONS(2316),
    [anon_sym_restrict] = ACTIONS(2316),
    [anon_sym___restrict__] = ACTIONS(2316),
    [anon_sym__Atomic] = ACTIONS(2316),
    [anon_sym__Noreturn] = ACTIONS(2316),
    [anon_sym_noreturn] = ACTIONS(2316),
    [anon_sym_mutable] = ACTIONS(2316),
    [anon_sym_constinit] = ACTIONS(2316),
    [anon_sym_consteval] = ACTIONS(2316),
    [anon_sym_alignas] = ACTIONS(2316),
    [anon_sym__Alignas] = ACTIONS(2316),
    [sym_primitive_type] = ACTIONS(2316),
    [anon_sym_enum] = ACTIONS(2316),
    [anon_sym_class] = ACTIONS(2316),
    [anon_sym_struct] = ACTIONS(2316),
    [anon_sym_union] = ACTIONS(2316),
    [anon_sym_if] = ACTIONS(2316),
    [anon_sym_switch] = ACTIONS(2316),
    [anon_sym_case] = ACTIONS(2316),
    [anon_sym_default] = ACTIONS(2316),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2316),
    [anon_sym_return] = ACTIONS(2316),
    [anon_sym_break] = ACTIONS(2316),
    [anon_sym_continue] = ACTIONS(2316),
    [anon_sym_goto] = ACTIONS(2316),
    [anon_sym___try] = ACTIONS(2316),
    [anon_sym___leave] = ACTIONS(2316),
    [anon_sym_not] = ACTIONS(2316),
    [anon_sym_compl] = ACTIONS(2316),
    [anon_sym_DASH_DASH] = ACTIONS(2318),
    [anon_sym_PLUS_PLUS] = ACTIONS(2318),
    [anon_sym_sizeof] = ACTIONS(2316),
    [anon_sym___alignof__] = ACTIONS(2316),
    [anon_sym___alignof] = ACTIONS(2316),
    [anon_sym__alignof] = ACTIONS(2316),
    [anon_sym_alignof] = ACTIONS(2316),
    [anon_sym__Alignof] = ACTIONS(2316),
    [anon_sym_offsetof] = ACTIONS(2316),
    [anon_sym__Generic] = ACTIONS(2316),
    [anon_sym_asm] = ACTIONS(2316),
    [anon_sym___asm__] = ACTIONS(2316),
    [sym_number_literal] = ACTIONS(2318),
    [anon_sym_L_SQUOTE] = ACTIONS(2318),
    [anon_sym_u_SQUOTE] = ACTIONS(2318),
    [anon_sym_U_SQUOTE] = ACTIONS(2318),
    [anon_sym_u8_SQUOTE] = ACTIONS(2318),
    [anon_sym_SQUOTE] = ACTIONS(2318),
    [anon_sym_L_DQUOTE] = ACTIONS(2318),
    [anon_sym_u_DQUOTE] = ACTIONS(2318),
    [anon_sym_U_DQUOTE] = ACTIONS(2318),
    [anon_sym_u8_DQUOTE] = ACTIONS(2318),
    [anon_sym_DQUOTE] = ACTIONS(2318),
    [sym_true] = ACTIONS(2316),
    [sym_false] = ACTIONS(2316),
    [anon_sym_NULL] = ACTIONS(2316),
    [anon_sym_nullptr] = ACTIONS(2316),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2316),
    [anon_sym_decltype] = ACTIONS(2316),
    [sym_virtual] = ACTIONS(2316),
    [anon_sym_explicit] = ACTIONS(2316),
    [anon_sym_typename] = ACTIONS(2316),
    [anon_sym_template] = ACTIONS(2316),
    [anon_sym_operator] = ACTIONS(2316),
    [anon_sym_try] = ACTIONS(2316),
    [anon_sym_delete] = ACTIONS(2316),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_namespace] = ACTIONS(2316),
    [anon_sym_using] = ACTIONS(2316),
    [anon_sym_static_assert] = ACTIONS(2316),
    [anon_sym_concept] = ACTIONS(2316),
    [anon_sym_co_return] = ACTIONS(2316),
    [anon_sym_co_yield] = ACTIONS(2316),
    [anon_sym_R_DQUOTE] = ACTIONS(2318),
    [anon_sym_LR_DQUOTE] = ACTIONS(2318),
    [anon_sym_uR_DQUOTE] = ACTIONS(2318),
    [anon_sym_UR_DQUOTE] = ACTIONS(2318),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2318),
    [anon_sym_co_await] = ACTIONS(2316),
    [anon_sym_new] = ACTIONS(2316),
    [anon_sym_requires] = ACTIONS(2316),
    [sym_this] = ACTIONS(2316),
    [anon_sym_discard] = ACTIONS(2316),
    [anon_sym_precise] = ACTIONS(2316),
    [anon_sym_shared] = ACTIONS(2316),
    [anon_sym_groupshared] = ACTIONS(2316),
    [anon_sym_uniform] = ACTIONS(2316),
    [anon_sym_row_major] = ACTIONS(2316),
    [anon_sym_column_major] = ACTIONS(2316),
    [anon_sym_globallycoherent] = ACTIONS(2316),
    [anon_sym_centroid] = ACTIONS(2316),
    [anon_sym_noperspective] = ACTIONS(2316),
    [anon_sym_nointerpolation] = ACTIONS(2316),
    [anon_sym_sample] = ACTIONS(2316),
    [anon_sym_linear] = ACTIONS(2316),
    [anon_sym_snorm] = ACTIONS(2316),
    [anon_sym_unorm] = ACTIONS(2316),
    [anon_sym_point] = ACTIONS(2316),
    [anon_sym_line] = ACTIONS(2316),
    [anon_sym_triangleadj] = ACTIONS(2316),
    [anon_sym_lineadj] = ACTIONS(2316),
    [anon_sym_triangle] = ACTIONS(2316),
    [anon_sym_cbuffer] = ACTIONS(2316),
  },
  [555] = {
    [sym_identifier] = ACTIONS(2498),
    [aux_sym_preproc_include_token1] = ACTIONS(2498),
    [aux_sym_preproc_def_token1] = ACTIONS(2498),
    [aux_sym_preproc_if_token1] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2498),
    [sym_preproc_directive] = ACTIONS(2498),
    [anon_sym_LPAREN2] = ACTIONS(2500),
    [anon_sym_BANG] = ACTIONS(2500),
    [anon_sym_TILDE] = ACTIONS(2500),
    [anon_sym_DASH] = ACTIONS(2498),
    [anon_sym_PLUS] = ACTIONS(2498),
    [anon_sym_STAR] = ACTIONS(2500),
    [anon_sym_AMP_AMP] = ACTIONS(2500),
    [anon_sym_AMP] = ACTIONS(2498),
    [anon_sym_SEMI] = ACTIONS(2500),
    [anon_sym___extension__] = ACTIONS(2498),
    [anon_sym_typedef] = ACTIONS(2498),
    [anon_sym_in] = ACTIONS(2498),
    [anon_sym_out] = ACTIONS(2498),
    [anon_sym_inout] = ACTIONS(2498),
    [anon_sym_extern] = ACTIONS(2498),
    [anon_sym___attribute__] = ACTIONS(2498),
    [anon_sym_COLON_COLON] = ACTIONS(2500),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2500),
    [anon_sym___declspec] = ACTIONS(2498),
    [anon_sym___based] = ACTIONS(2498),
    [anon_sym___cdecl] = ACTIONS(2498),
    [anon_sym___clrcall] = ACTIONS(2498),
    [anon_sym___stdcall] = ACTIONS(2498),
    [anon_sym___fastcall] = ACTIONS(2498),
    [anon_sym___thiscall] = ACTIONS(2498),
    [anon_sym___vectorcall] = ACTIONS(2498),
    [anon_sym_LBRACE] = ACTIONS(2500),
    [anon_sym_RBRACE] = ACTIONS(2500),
    [anon_sym_signed] = ACTIONS(2498),
    [anon_sym_unsigned] = ACTIONS(2498),
    [anon_sym_long] = ACTIONS(2498),
    [anon_sym_short] = ACTIONS(2498),
    [anon_sym_LBRACK] = ACTIONS(2498),
    [anon_sym_static] = ACTIONS(2498),
    [anon_sym_register] = ACTIONS(2498),
    [anon_sym_inline] = ACTIONS(2498),
    [anon_sym___inline] = ACTIONS(2498),
    [anon_sym___inline__] = ACTIONS(2498),
    [anon_sym___forceinline] = ACTIONS(2498),
    [anon_sym_thread_local] = ACTIONS(2498),
    [anon_sym___thread] = ACTIONS(2498),
    [anon_sym_const] = ACTIONS(2498),
    [anon_sym_constexpr] = ACTIONS(2498),
    [anon_sym_volatile] = ACTIONS(2498),
    [anon_sym_restrict] = ACTIONS(2498),
    [anon_sym___restrict__] = ACTIONS(2498),
    [anon_sym__Atomic] = ACTIONS(2498),
    [anon_sym__Noreturn] = ACTIONS(2498),
    [anon_sym_noreturn] = ACTIONS(2498),
    [anon_sym_mutable] = ACTIONS(2498),
    [anon_sym_constinit] = ACTIONS(2498),
    [anon_sym_consteval] = ACTIONS(2498),
    [anon_sym_alignas] = ACTIONS(2498),
    [anon_sym__Alignas] = ACTIONS(2498),
    [sym_primitive_type] = ACTIONS(2498),
    [anon_sym_enum] = ACTIONS(2498),
    [anon_sym_class] = ACTIONS(2498),
    [anon_sym_struct] = ACTIONS(2498),
    [anon_sym_union] = ACTIONS(2498),
    [anon_sym_if] = ACTIONS(2498),
    [anon_sym_switch] = ACTIONS(2498),
    [anon_sym_case] = ACTIONS(2498),
    [anon_sym_default] = ACTIONS(2498),
    [anon_sym_while] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(2498),
    [anon_sym_for] = ACTIONS(2498),
    [anon_sym_return] = ACTIONS(2498),
    [anon_sym_break] = ACTIONS(2498),
    [anon_sym_continue] = ACTIONS(2498),
    [anon_sym_goto] = ACTIONS(2498),
    [anon_sym___try] = ACTIONS(2498),
    [anon_sym___leave] = ACTIONS(2498),
    [anon_sym_not] = ACTIONS(2498),
    [anon_sym_compl] = ACTIONS(2498),
    [anon_sym_DASH_DASH] = ACTIONS(2500),
    [anon_sym_PLUS_PLUS] = ACTIONS(2500),
    [anon_sym_sizeof] = ACTIONS(2498),
    [anon_sym___alignof__] = ACTIONS(2498),
    [anon_sym___alignof] = ACTIONS(2498),
    [anon_sym__alignof] = ACTIONS(2498),
    [anon_sym_alignof] = ACTIONS(2498),
    [anon_sym__Alignof] = ACTIONS(2498),
    [anon_sym_offsetof] = ACTIONS(2498),
    [anon_sym__Generic] = ACTIONS(2498),
    [anon_sym_asm] = ACTIONS(2498),
    [anon_sym___asm__] = ACTIONS(2498),
    [sym_number_literal] = ACTIONS(2500),
    [anon_sym_L_SQUOTE] = ACTIONS(2500),
    [anon_sym_u_SQUOTE] = ACTIONS(2500),
    [anon_sym_U_SQUOTE] = ACTIONS(2500),
    [anon_sym_u8_SQUOTE] = ACTIONS(2500),
    [anon_sym_SQUOTE] = ACTIONS(2500),
    [anon_sym_L_DQUOTE] = ACTIONS(2500),
    [anon_sym_u_DQUOTE] = ACTIONS(2500),
    [anon_sym_U_DQUOTE] = ACTIONS(2500),
    [anon_sym_u8_DQUOTE] = ACTIONS(2500),
    [anon_sym_DQUOTE] = ACTIONS(2500),
    [sym_true] = ACTIONS(2498),
    [sym_false] = ACTIONS(2498),
    [anon_sym_NULL] = ACTIONS(2498),
    [anon_sym_nullptr] = ACTIONS(2498),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2498),
    [anon_sym_decltype] = ACTIONS(2498),
    [sym_virtual] = ACTIONS(2498),
    [anon_sym_explicit] = ACTIONS(2498),
    [anon_sym_typename] = ACTIONS(2498),
    [anon_sym_template] = ACTIONS(2498),
    [anon_sym_operator] = ACTIONS(2498),
    [anon_sym_try] = ACTIONS(2498),
    [anon_sym_delete] = ACTIONS(2498),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_namespace] = ACTIONS(2498),
    [anon_sym_using] = ACTIONS(2498),
    [anon_sym_static_assert] = ACTIONS(2498),
    [anon_sym_concept] = ACTIONS(2498),
    [anon_sym_co_return] = ACTIONS(2498),
    [anon_sym_co_yield] = ACTIONS(2498),
    [anon_sym_R_DQUOTE] = ACTIONS(2500),
    [anon_sym_LR_DQUOTE] = ACTIONS(2500),
    [anon_sym_uR_DQUOTE] = ACTIONS(2500),
    [anon_sym_UR_DQUOTE] = ACTIONS(2500),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2500),
    [anon_sym_co_await] = ACTIONS(2498),
    [anon_sym_new] = ACTIONS(2498),
    [anon_sym_requires] = ACTIONS(2498),
    [sym_this] = ACTIONS(2498),
    [anon_sym_discard] = ACTIONS(2498),
    [anon_sym_precise] = ACTIONS(2498),
    [anon_sym_shared] = ACTIONS(2498),
    [anon_sym_groupshared] = ACTIONS(2498),
    [anon_sym_uniform] = ACTIONS(2498),
    [anon_sym_row_major] = ACTIONS(2498),
    [anon_sym_column_major] = ACTIONS(2498),
    [anon_sym_globallycoherent] = ACTIONS(2498),
    [anon_sym_centroid] = ACTIONS(2498),
    [anon_sym_noperspective] = ACTIONS(2498),
    [anon_sym_nointerpolation] = ACTIONS(2498),
    [anon_sym_sample] = ACTIONS(2498),
    [anon_sym_linear] = ACTIONS(2498),
    [anon_sym_snorm] = ACTIONS(2498),
    [anon_sym_unorm] = ACTIONS(2498),
    [anon_sym_point] = ACTIONS(2498),
    [anon_sym_line] = ACTIONS(2498),
    [anon_sym_triangleadj] = ACTIONS(2498),
    [anon_sym_lineadj] = ACTIONS(2498),
    [anon_sym_triangle] = ACTIONS(2498),
    [anon_sym_cbuffer] = ACTIONS(2498),
  },
  [556] = {
    [sym_identifier] = ACTIONS(2498),
    [aux_sym_preproc_include_token1] = ACTIONS(2498),
    [aux_sym_preproc_def_token1] = ACTIONS(2498),
    [aux_sym_preproc_if_token1] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2498),
    [sym_preproc_directive] = ACTIONS(2498),
    [anon_sym_LPAREN2] = ACTIONS(2500),
    [anon_sym_BANG] = ACTIONS(2500),
    [anon_sym_TILDE] = ACTIONS(2500),
    [anon_sym_DASH] = ACTIONS(2498),
    [anon_sym_PLUS] = ACTIONS(2498),
    [anon_sym_STAR] = ACTIONS(2500),
    [anon_sym_AMP_AMP] = ACTIONS(2500),
    [anon_sym_AMP] = ACTIONS(2498),
    [anon_sym_SEMI] = ACTIONS(2500),
    [anon_sym___extension__] = ACTIONS(2498),
    [anon_sym_typedef] = ACTIONS(2498),
    [anon_sym_in] = ACTIONS(2498),
    [anon_sym_out] = ACTIONS(2498),
    [anon_sym_inout] = ACTIONS(2498),
    [anon_sym_extern] = ACTIONS(2498),
    [anon_sym___attribute__] = ACTIONS(2498),
    [anon_sym_COLON_COLON] = ACTIONS(2500),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2500),
    [anon_sym___declspec] = ACTIONS(2498),
    [anon_sym___based] = ACTIONS(2498),
    [anon_sym___cdecl] = ACTIONS(2498),
    [anon_sym___clrcall] = ACTIONS(2498),
    [anon_sym___stdcall] = ACTIONS(2498),
    [anon_sym___fastcall] = ACTIONS(2498),
    [anon_sym___thiscall] = ACTIONS(2498),
    [anon_sym___vectorcall] = ACTIONS(2498),
    [anon_sym_LBRACE] = ACTIONS(2500),
    [anon_sym_RBRACE] = ACTIONS(2500),
    [anon_sym_signed] = ACTIONS(2498),
    [anon_sym_unsigned] = ACTIONS(2498),
    [anon_sym_long] = ACTIONS(2498),
    [anon_sym_short] = ACTIONS(2498),
    [anon_sym_LBRACK] = ACTIONS(2498),
    [anon_sym_static] = ACTIONS(2498),
    [anon_sym_register] = ACTIONS(2498),
    [anon_sym_inline] = ACTIONS(2498),
    [anon_sym___inline] = ACTIONS(2498),
    [anon_sym___inline__] = ACTIONS(2498),
    [anon_sym___forceinline] = ACTIONS(2498),
    [anon_sym_thread_local] = ACTIONS(2498),
    [anon_sym___thread] = ACTIONS(2498),
    [anon_sym_const] = ACTIONS(2498),
    [anon_sym_constexpr] = ACTIONS(2498),
    [anon_sym_volatile] = ACTIONS(2498),
    [anon_sym_restrict] = ACTIONS(2498),
    [anon_sym___restrict__] = ACTIONS(2498),
    [anon_sym__Atomic] = ACTIONS(2498),
    [anon_sym__Noreturn] = ACTIONS(2498),
    [anon_sym_noreturn] = ACTIONS(2498),
    [anon_sym_mutable] = ACTIONS(2498),
    [anon_sym_constinit] = ACTIONS(2498),
    [anon_sym_consteval] = ACTIONS(2498),
    [anon_sym_alignas] = ACTIONS(2498),
    [anon_sym__Alignas] = ACTIONS(2498),
    [sym_primitive_type] = ACTIONS(2498),
    [anon_sym_enum] = ACTIONS(2498),
    [anon_sym_class] = ACTIONS(2498),
    [anon_sym_struct] = ACTIONS(2498),
    [anon_sym_union] = ACTIONS(2498),
    [anon_sym_if] = ACTIONS(2498),
    [anon_sym_switch] = ACTIONS(2498),
    [anon_sym_case] = ACTIONS(2498),
    [anon_sym_default] = ACTIONS(2498),
    [anon_sym_while] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(2498),
    [anon_sym_for] = ACTIONS(2498),
    [anon_sym_return] = ACTIONS(2498),
    [anon_sym_break] = ACTIONS(2498),
    [anon_sym_continue] = ACTIONS(2498),
    [anon_sym_goto] = ACTIONS(2498),
    [anon_sym___try] = ACTIONS(2498),
    [anon_sym___leave] = ACTIONS(2498),
    [anon_sym_not] = ACTIONS(2498),
    [anon_sym_compl] = ACTIONS(2498),
    [anon_sym_DASH_DASH] = ACTIONS(2500),
    [anon_sym_PLUS_PLUS] = ACTIONS(2500),
    [anon_sym_sizeof] = ACTIONS(2498),
    [anon_sym___alignof__] = ACTIONS(2498),
    [anon_sym___alignof] = ACTIONS(2498),
    [anon_sym__alignof] = ACTIONS(2498),
    [anon_sym_alignof] = ACTIONS(2498),
    [anon_sym__Alignof] = ACTIONS(2498),
    [anon_sym_offsetof] = ACTIONS(2498),
    [anon_sym__Generic] = ACTIONS(2498),
    [anon_sym_asm] = ACTIONS(2498),
    [anon_sym___asm__] = ACTIONS(2498),
    [sym_number_literal] = ACTIONS(2500),
    [anon_sym_L_SQUOTE] = ACTIONS(2500),
    [anon_sym_u_SQUOTE] = ACTIONS(2500),
    [anon_sym_U_SQUOTE] = ACTIONS(2500),
    [anon_sym_u8_SQUOTE] = ACTIONS(2500),
    [anon_sym_SQUOTE] = ACTIONS(2500),
    [anon_sym_L_DQUOTE] = ACTIONS(2500),
    [anon_sym_u_DQUOTE] = ACTIONS(2500),
    [anon_sym_U_DQUOTE] = ACTIONS(2500),
    [anon_sym_u8_DQUOTE] = ACTIONS(2500),
    [anon_sym_DQUOTE] = ACTIONS(2500),
    [sym_true] = ACTIONS(2498),
    [sym_false] = ACTIONS(2498),
    [anon_sym_NULL] = ACTIONS(2498),
    [anon_sym_nullptr] = ACTIONS(2498),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2498),
    [anon_sym_decltype] = ACTIONS(2498),
    [sym_virtual] = ACTIONS(2498),
    [anon_sym_explicit] = ACTIONS(2498),
    [anon_sym_typename] = ACTIONS(2498),
    [anon_sym_template] = ACTIONS(2498),
    [anon_sym_operator] = ACTIONS(2498),
    [anon_sym_try] = ACTIONS(2498),
    [anon_sym_delete] = ACTIONS(2498),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_namespace] = ACTIONS(2498),
    [anon_sym_using] = ACTIONS(2498),
    [anon_sym_static_assert] = ACTIONS(2498),
    [anon_sym_concept] = ACTIONS(2498),
    [anon_sym_co_return] = ACTIONS(2498),
    [anon_sym_co_yield] = ACTIONS(2498),
    [anon_sym_R_DQUOTE] = ACTIONS(2500),
    [anon_sym_LR_DQUOTE] = ACTIONS(2500),
    [anon_sym_uR_DQUOTE] = ACTIONS(2500),
    [anon_sym_UR_DQUOTE] = ACTIONS(2500),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2500),
    [anon_sym_co_await] = ACTIONS(2498),
    [anon_sym_new] = ACTIONS(2498),
    [anon_sym_requires] = ACTIONS(2498),
    [sym_this] = ACTIONS(2498),
    [anon_sym_discard] = ACTIONS(2498),
    [anon_sym_precise] = ACTIONS(2498),
    [anon_sym_shared] = ACTIONS(2498),
    [anon_sym_groupshared] = ACTIONS(2498),
    [anon_sym_uniform] = ACTIONS(2498),
    [anon_sym_row_major] = ACTIONS(2498),
    [anon_sym_column_major] = ACTIONS(2498),
    [anon_sym_globallycoherent] = ACTIONS(2498),
    [anon_sym_centroid] = ACTIONS(2498),
    [anon_sym_noperspective] = ACTIONS(2498),
    [anon_sym_nointerpolation] = ACTIONS(2498),
    [anon_sym_sample] = ACTIONS(2498),
    [anon_sym_linear] = ACTIONS(2498),
    [anon_sym_snorm] = ACTIONS(2498),
    [anon_sym_unorm] = ACTIONS(2498),
    [anon_sym_point] = ACTIONS(2498),
    [anon_sym_line] = ACTIONS(2498),
    [anon_sym_triangleadj] = ACTIONS(2498),
    [anon_sym_lineadj] = ACTIONS(2498),
    [anon_sym_triangle] = ACTIONS(2498),
    [anon_sym_cbuffer] = ACTIONS(2498),
  },
  [557] = {
    [sym_identifier] = ACTIONS(2404),
    [aux_sym_preproc_include_token1] = ACTIONS(2404),
    [aux_sym_preproc_def_token1] = ACTIONS(2404),
    [aux_sym_preproc_if_token1] = ACTIONS(2404),
    [aux_sym_preproc_if_token2] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2404),
    [sym_preproc_directive] = ACTIONS(2404),
    [anon_sym_LPAREN2] = ACTIONS(2406),
    [anon_sym_BANG] = ACTIONS(2406),
    [anon_sym_TILDE] = ACTIONS(2406),
    [anon_sym_DASH] = ACTIONS(2404),
    [anon_sym_PLUS] = ACTIONS(2404),
    [anon_sym_STAR] = ACTIONS(2406),
    [anon_sym_AMP_AMP] = ACTIONS(2406),
    [anon_sym_AMP] = ACTIONS(2404),
    [anon_sym_SEMI] = ACTIONS(2406),
    [anon_sym___extension__] = ACTIONS(2404),
    [anon_sym_typedef] = ACTIONS(2404),
    [anon_sym_in] = ACTIONS(2404),
    [anon_sym_out] = ACTIONS(2404),
    [anon_sym_inout] = ACTIONS(2404),
    [anon_sym_extern] = ACTIONS(2404),
    [anon_sym___attribute__] = ACTIONS(2404),
    [anon_sym_COLON_COLON] = ACTIONS(2406),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2406),
    [anon_sym___declspec] = ACTIONS(2404),
    [anon_sym___based] = ACTIONS(2404),
    [anon_sym___cdecl] = ACTIONS(2404),
    [anon_sym___clrcall] = ACTIONS(2404),
    [anon_sym___stdcall] = ACTIONS(2404),
    [anon_sym___fastcall] = ACTIONS(2404),
    [anon_sym___thiscall] = ACTIONS(2404),
    [anon_sym___vectorcall] = ACTIONS(2404),
    [anon_sym_LBRACE] = ACTIONS(2406),
    [anon_sym_signed] = ACTIONS(2404),
    [anon_sym_unsigned] = ACTIONS(2404),
    [anon_sym_long] = ACTIONS(2404),
    [anon_sym_short] = ACTIONS(2404),
    [anon_sym_LBRACK] = ACTIONS(2404),
    [anon_sym_static] = ACTIONS(2404),
    [anon_sym_register] = ACTIONS(2404),
    [anon_sym_inline] = ACTIONS(2404),
    [anon_sym___inline] = ACTIONS(2404),
    [anon_sym___inline__] = ACTIONS(2404),
    [anon_sym___forceinline] = ACTIONS(2404),
    [anon_sym_thread_local] = ACTIONS(2404),
    [anon_sym___thread] = ACTIONS(2404),
    [anon_sym_const] = ACTIONS(2404),
    [anon_sym_constexpr] = ACTIONS(2404),
    [anon_sym_volatile] = ACTIONS(2404),
    [anon_sym_restrict] = ACTIONS(2404),
    [anon_sym___restrict__] = ACTIONS(2404),
    [anon_sym__Atomic] = ACTIONS(2404),
    [anon_sym__Noreturn] = ACTIONS(2404),
    [anon_sym_noreturn] = ACTIONS(2404),
    [anon_sym_mutable] = ACTIONS(2404),
    [anon_sym_constinit] = ACTIONS(2404),
    [anon_sym_consteval] = ACTIONS(2404),
    [anon_sym_alignas] = ACTIONS(2404),
    [anon_sym__Alignas] = ACTIONS(2404),
    [sym_primitive_type] = ACTIONS(2404),
    [anon_sym_enum] = ACTIONS(2404),
    [anon_sym_class] = ACTIONS(2404),
    [anon_sym_struct] = ACTIONS(2404),
    [anon_sym_union] = ACTIONS(2404),
    [anon_sym_if] = ACTIONS(2404),
    [anon_sym_switch] = ACTIONS(2404),
    [anon_sym_case] = ACTIONS(2404),
    [anon_sym_default] = ACTIONS(2404),
    [anon_sym_while] = ACTIONS(2404),
    [anon_sym_do] = ACTIONS(2404),
    [anon_sym_for] = ACTIONS(2404),
    [anon_sym_return] = ACTIONS(2404),
    [anon_sym_break] = ACTIONS(2404),
    [anon_sym_continue] = ACTIONS(2404),
    [anon_sym_goto] = ACTIONS(2404),
    [anon_sym___try] = ACTIONS(2404),
    [anon_sym___leave] = ACTIONS(2404),
    [anon_sym_not] = ACTIONS(2404),
    [anon_sym_compl] = ACTIONS(2404),
    [anon_sym_DASH_DASH] = ACTIONS(2406),
    [anon_sym_PLUS_PLUS] = ACTIONS(2406),
    [anon_sym_sizeof] = ACTIONS(2404),
    [anon_sym___alignof__] = ACTIONS(2404),
    [anon_sym___alignof] = ACTIONS(2404),
    [anon_sym__alignof] = ACTIONS(2404),
    [anon_sym_alignof] = ACTIONS(2404),
    [anon_sym__Alignof] = ACTIONS(2404),
    [anon_sym_offsetof] = ACTIONS(2404),
    [anon_sym__Generic] = ACTIONS(2404),
    [anon_sym_asm] = ACTIONS(2404),
    [anon_sym___asm__] = ACTIONS(2404),
    [sym_number_literal] = ACTIONS(2406),
    [anon_sym_L_SQUOTE] = ACTIONS(2406),
    [anon_sym_u_SQUOTE] = ACTIONS(2406),
    [anon_sym_U_SQUOTE] = ACTIONS(2406),
    [anon_sym_u8_SQUOTE] = ACTIONS(2406),
    [anon_sym_SQUOTE] = ACTIONS(2406),
    [anon_sym_L_DQUOTE] = ACTIONS(2406),
    [anon_sym_u_DQUOTE] = ACTIONS(2406),
    [anon_sym_U_DQUOTE] = ACTIONS(2406),
    [anon_sym_u8_DQUOTE] = ACTIONS(2406),
    [anon_sym_DQUOTE] = ACTIONS(2406),
    [sym_true] = ACTIONS(2404),
    [sym_false] = ACTIONS(2404),
    [anon_sym_NULL] = ACTIONS(2404),
    [anon_sym_nullptr] = ACTIONS(2404),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2404),
    [anon_sym_decltype] = ACTIONS(2404),
    [sym_virtual] = ACTIONS(2404),
    [anon_sym_explicit] = ACTIONS(2404),
    [anon_sym_typename] = ACTIONS(2404),
    [anon_sym_template] = ACTIONS(2404),
    [anon_sym_operator] = ACTIONS(2404),
    [anon_sym_try] = ACTIONS(2404),
    [anon_sym_delete] = ACTIONS(2404),
    [anon_sym_throw] = ACTIONS(2404),
    [anon_sym_namespace] = ACTIONS(2404),
    [anon_sym_using] = ACTIONS(2404),
    [anon_sym_static_assert] = ACTIONS(2404),
    [anon_sym_concept] = ACTIONS(2404),
    [anon_sym_co_return] = ACTIONS(2404),
    [anon_sym_co_yield] = ACTIONS(2404),
    [anon_sym_R_DQUOTE] = ACTIONS(2406),
    [anon_sym_LR_DQUOTE] = ACTIONS(2406),
    [anon_sym_uR_DQUOTE] = ACTIONS(2406),
    [anon_sym_UR_DQUOTE] = ACTIONS(2406),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2406),
    [anon_sym_co_await] = ACTIONS(2404),
    [anon_sym_new] = ACTIONS(2404),
    [anon_sym_requires] = ACTIONS(2404),
    [sym_this] = ACTIONS(2404),
    [anon_sym_discard] = ACTIONS(2404),
    [anon_sym_precise] = ACTIONS(2404),
    [anon_sym_shared] = ACTIONS(2404),
    [anon_sym_groupshared] = ACTIONS(2404),
    [anon_sym_uniform] = ACTIONS(2404),
    [anon_sym_row_major] = ACTIONS(2404),
    [anon_sym_column_major] = ACTIONS(2404),
    [anon_sym_globallycoherent] = ACTIONS(2404),
    [anon_sym_centroid] = ACTIONS(2404),
    [anon_sym_noperspective] = ACTIONS(2404),
    [anon_sym_nointerpolation] = ACTIONS(2404),
    [anon_sym_sample] = ACTIONS(2404),
    [anon_sym_linear] = ACTIONS(2404),
    [anon_sym_snorm] = ACTIONS(2404),
    [anon_sym_unorm] = ACTIONS(2404),
    [anon_sym_point] = ACTIONS(2404),
    [anon_sym_line] = ACTIONS(2404),
    [anon_sym_triangleadj] = ACTIONS(2404),
    [anon_sym_lineadj] = ACTIONS(2404),
    [anon_sym_triangle] = ACTIONS(2404),
    [anon_sym_cbuffer] = ACTIONS(2404),
  },
  [558] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_include_token1] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token2] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_BANG] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_DASH] = ACTIONS(2324),
    [anon_sym_PLUS] = ACTIONS(2324),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym_SEMI] = ACTIONS(2326),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym___cdecl] = ACTIONS(2324),
    [anon_sym___clrcall] = ACTIONS(2324),
    [anon_sym___stdcall] = ACTIONS(2324),
    [anon_sym___fastcall] = ACTIONS(2324),
    [anon_sym___thiscall] = ACTIONS(2324),
    [anon_sym___vectorcall] = ACTIONS(2324),
    [anon_sym_LBRACE] = ACTIONS(2326),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [anon_sym_if] = ACTIONS(2324),
    [anon_sym_switch] = ACTIONS(2324),
    [anon_sym_case] = ACTIONS(2324),
    [anon_sym_default] = ACTIONS(2324),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_do] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2324),
    [anon_sym_return] = ACTIONS(2324),
    [anon_sym_break] = ACTIONS(2324),
    [anon_sym_continue] = ACTIONS(2324),
    [anon_sym_goto] = ACTIONS(2324),
    [anon_sym___try] = ACTIONS(2324),
    [anon_sym___leave] = ACTIONS(2324),
    [anon_sym_not] = ACTIONS(2324),
    [anon_sym_compl] = ACTIONS(2324),
    [anon_sym_DASH_DASH] = ACTIONS(2326),
    [anon_sym_PLUS_PLUS] = ACTIONS(2326),
    [anon_sym_sizeof] = ACTIONS(2324),
    [anon_sym___alignof__] = ACTIONS(2324),
    [anon_sym___alignof] = ACTIONS(2324),
    [anon_sym__alignof] = ACTIONS(2324),
    [anon_sym_alignof] = ACTIONS(2324),
    [anon_sym__Alignof] = ACTIONS(2324),
    [anon_sym_offsetof] = ACTIONS(2324),
    [anon_sym__Generic] = ACTIONS(2324),
    [anon_sym_asm] = ACTIONS(2324),
    [anon_sym___asm__] = ACTIONS(2324),
    [sym_number_literal] = ACTIONS(2326),
    [anon_sym_L_SQUOTE] = ACTIONS(2326),
    [anon_sym_u_SQUOTE] = ACTIONS(2326),
    [anon_sym_U_SQUOTE] = ACTIONS(2326),
    [anon_sym_u8_SQUOTE] = ACTIONS(2326),
    [anon_sym_SQUOTE] = ACTIONS(2326),
    [anon_sym_L_DQUOTE] = ACTIONS(2326),
    [anon_sym_u_DQUOTE] = ACTIONS(2326),
    [anon_sym_U_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8_DQUOTE] = ACTIONS(2326),
    [anon_sym_DQUOTE] = ACTIONS(2326),
    [sym_true] = ACTIONS(2324),
    [sym_false] = ACTIONS(2324),
    [anon_sym_NULL] = ACTIONS(2324),
    [anon_sym_nullptr] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_try] = ACTIONS(2324),
    [anon_sym_delete] = ACTIONS(2324),
    [anon_sym_throw] = ACTIONS(2324),
    [anon_sym_namespace] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_concept] = ACTIONS(2324),
    [anon_sym_co_return] = ACTIONS(2324),
    [anon_sym_co_yield] = ACTIONS(2324),
    [anon_sym_R_DQUOTE] = ACTIONS(2326),
    [anon_sym_LR_DQUOTE] = ACTIONS(2326),
    [anon_sym_uR_DQUOTE] = ACTIONS(2326),
    [anon_sym_UR_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2326),
    [anon_sym_co_await] = ACTIONS(2324),
    [anon_sym_new] = ACTIONS(2324),
    [anon_sym_requires] = ACTIONS(2324),
    [sym_this] = ACTIONS(2324),
    [anon_sym_discard] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
    [anon_sym_cbuffer] = ACTIONS(2324),
  },
  [559] = {
    [sym_identifier] = ACTIONS(2502),
    [aux_sym_preproc_include_token1] = ACTIONS(2502),
    [aux_sym_preproc_def_token1] = ACTIONS(2502),
    [aux_sym_preproc_if_token1] = ACTIONS(2502),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2502),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2502),
    [sym_preproc_directive] = ACTIONS(2502),
    [anon_sym_LPAREN2] = ACTIONS(2504),
    [anon_sym_BANG] = ACTIONS(2504),
    [anon_sym_TILDE] = ACTIONS(2504),
    [anon_sym_DASH] = ACTIONS(2502),
    [anon_sym_PLUS] = ACTIONS(2502),
    [anon_sym_STAR] = ACTIONS(2504),
    [anon_sym_AMP_AMP] = ACTIONS(2504),
    [anon_sym_AMP] = ACTIONS(2502),
    [anon_sym_SEMI] = ACTIONS(2504),
    [anon_sym___extension__] = ACTIONS(2502),
    [anon_sym_typedef] = ACTIONS(2502),
    [anon_sym_in] = ACTIONS(2502),
    [anon_sym_out] = ACTIONS(2502),
    [anon_sym_inout] = ACTIONS(2502),
    [anon_sym_extern] = ACTIONS(2502),
    [anon_sym___attribute__] = ACTIONS(2502),
    [anon_sym_COLON_COLON] = ACTIONS(2504),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2504),
    [anon_sym___declspec] = ACTIONS(2502),
    [anon_sym___based] = ACTIONS(2502),
    [anon_sym___cdecl] = ACTIONS(2502),
    [anon_sym___clrcall] = ACTIONS(2502),
    [anon_sym___stdcall] = ACTIONS(2502),
    [anon_sym___fastcall] = ACTIONS(2502),
    [anon_sym___thiscall] = ACTIONS(2502),
    [anon_sym___vectorcall] = ACTIONS(2502),
    [anon_sym_LBRACE] = ACTIONS(2504),
    [anon_sym_RBRACE] = ACTIONS(2504),
    [anon_sym_signed] = ACTIONS(2502),
    [anon_sym_unsigned] = ACTIONS(2502),
    [anon_sym_long] = ACTIONS(2502),
    [anon_sym_short] = ACTIONS(2502),
    [anon_sym_LBRACK] = ACTIONS(2502),
    [anon_sym_static] = ACTIONS(2502),
    [anon_sym_register] = ACTIONS(2502),
    [anon_sym_inline] = ACTIONS(2502),
    [anon_sym___inline] = ACTIONS(2502),
    [anon_sym___inline__] = ACTIONS(2502),
    [anon_sym___forceinline] = ACTIONS(2502),
    [anon_sym_thread_local] = ACTIONS(2502),
    [anon_sym___thread] = ACTIONS(2502),
    [anon_sym_const] = ACTIONS(2502),
    [anon_sym_constexpr] = ACTIONS(2502),
    [anon_sym_volatile] = ACTIONS(2502),
    [anon_sym_restrict] = ACTIONS(2502),
    [anon_sym___restrict__] = ACTIONS(2502),
    [anon_sym__Atomic] = ACTIONS(2502),
    [anon_sym__Noreturn] = ACTIONS(2502),
    [anon_sym_noreturn] = ACTIONS(2502),
    [anon_sym_mutable] = ACTIONS(2502),
    [anon_sym_constinit] = ACTIONS(2502),
    [anon_sym_consteval] = ACTIONS(2502),
    [anon_sym_alignas] = ACTIONS(2502),
    [anon_sym__Alignas] = ACTIONS(2502),
    [sym_primitive_type] = ACTIONS(2502),
    [anon_sym_enum] = ACTIONS(2502),
    [anon_sym_class] = ACTIONS(2502),
    [anon_sym_struct] = ACTIONS(2502),
    [anon_sym_union] = ACTIONS(2502),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_switch] = ACTIONS(2502),
    [anon_sym_case] = ACTIONS(2502),
    [anon_sym_default] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_do] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2502),
    [anon_sym_return] = ACTIONS(2502),
    [anon_sym_break] = ACTIONS(2502),
    [anon_sym_continue] = ACTIONS(2502),
    [anon_sym_goto] = ACTIONS(2502),
    [anon_sym___try] = ACTIONS(2502),
    [anon_sym___leave] = ACTIONS(2502),
    [anon_sym_not] = ACTIONS(2502),
    [anon_sym_compl] = ACTIONS(2502),
    [anon_sym_DASH_DASH] = ACTIONS(2504),
    [anon_sym_PLUS_PLUS] = ACTIONS(2504),
    [anon_sym_sizeof] = ACTIONS(2502),
    [anon_sym___alignof__] = ACTIONS(2502),
    [anon_sym___alignof] = ACTIONS(2502),
    [anon_sym__alignof] = ACTIONS(2502),
    [anon_sym_alignof] = ACTIONS(2502),
    [anon_sym__Alignof] = ACTIONS(2502),
    [anon_sym_offsetof] = ACTIONS(2502),
    [anon_sym__Generic] = ACTIONS(2502),
    [anon_sym_asm] = ACTIONS(2502),
    [anon_sym___asm__] = ACTIONS(2502),
    [sym_number_literal] = ACTIONS(2504),
    [anon_sym_L_SQUOTE] = ACTIONS(2504),
    [anon_sym_u_SQUOTE] = ACTIONS(2504),
    [anon_sym_U_SQUOTE] = ACTIONS(2504),
    [anon_sym_u8_SQUOTE] = ACTIONS(2504),
    [anon_sym_SQUOTE] = ACTIONS(2504),
    [anon_sym_L_DQUOTE] = ACTIONS(2504),
    [anon_sym_u_DQUOTE] = ACTIONS(2504),
    [anon_sym_U_DQUOTE] = ACTIONS(2504),
    [anon_sym_u8_DQUOTE] = ACTIONS(2504),
    [anon_sym_DQUOTE] = ACTIONS(2504),
    [sym_true] = ACTIONS(2502),
    [sym_false] = ACTIONS(2502),
    [anon_sym_NULL] = ACTIONS(2502),
    [anon_sym_nullptr] = ACTIONS(2502),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2502),
    [anon_sym_decltype] = ACTIONS(2502),
    [sym_virtual] = ACTIONS(2502),
    [anon_sym_explicit] = ACTIONS(2502),
    [anon_sym_typename] = ACTIONS(2502),
    [anon_sym_template] = ACTIONS(2502),
    [anon_sym_operator] = ACTIONS(2502),
    [anon_sym_try] = ACTIONS(2502),
    [anon_sym_delete] = ACTIONS(2502),
    [anon_sym_throw] = ACTIONS(2502),
    [anon_sym_namespace] = ACTIONS(2502),
    [anon_sym_using] = ACTIONS(2502),
    [anon_sym_static_assert] = ACTIONS(2502),
    [anon_sym_concept] = ACTIONS(2502),
    [anon_sym_co_return] = ACTIONS(2502),
    [anon_sym_co_yield] = ACTIONS(2502),
    [anon_sym_R_DQUOTE] = ACTIONS(2504),
    [anon_sym_LR_DQUOTE] = ACTIONS(2504),
    [anon_sym_uR_DQUOTE] = ACTIONS(2504),
    [anon_sym_UR_DQUOTE] = ACTIONS(2504),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2504),
    [anon_sym_co_await] = ACTIONS(2502),
    [anon_sym_new] = ACTIONS(2502),
    [anon_sym_requires] = ACTIONS(2502),
    [sym_this] = ACTIONS(2502),
    [anon_sym_discard] = ACTIONS(2502),
    [anon_sym_precise] = ACTIONS(2502),
    [anon_sym_shared] = ACTIONS(2502),
    [anon_sym_groupshared] = ACTIONS(2502),
    [anon_sym_uniform] = ACTIONS(2502),
    [anon_sym_row_major] = ACTIONS(2502),
    [anon_sym_column_major] = ACTIONS(2502),
    [anon_sym_globallycoherent] = ACTIONS(2502),
    [anon_sym_centroid] = ACTIONS(2502),
    [anon_sym_noperspective] = ACTIONS(2502),
    [anon_sym_nointerpolation] = ACTIONS(2502),
    [anon_sym_sample] = ACTIONS(2502),
    [anon_sym_linear] = ACTIONS(2502),
    [anon_sym_snorm] = ACTIONS(2502),
    [anon_sym_unorm] = ACTIONS(2502),
    [anon_sym_point] = ACTIONS(2502),
    [anon_sym_line] = ACTIONS(2502),
    [anon_sym_triangleadj] = ACTIONS(2502),
    [anon_sym_lineadj] = ACTIONS(2502),
    [anon_sym_triangle] = ACTIONS(2502),
    [anon_sym_cbuffer] = ACTIONS(2502),
  },
  [560] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_include_token1] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token2] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_BANG] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_DASH] = ACTIONS(2324),
    [anon_sym_PLUS] = ACTIONS(2324),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym_SEMI] = ACTIONS(2326),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym___cdecl] = ACTIONS(2324),
    [anon_sym___clrcall] = ACTIONS(2324),
    [anon_sym___stdcall] = ACTIONS(2324),
    [anon_sym___fastcall] = ACTIONS(2324),
    [anon_sym___thiscall] = ACTIONS(2324),
    [anon_sym___vectorcall] = ACTIONS(2324),
    [anon_sym_LBRACE] = ACTIONS(2326),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [anon_sym_if] = ACTIONS(2324),
    [anon_sym_switch] = ACTIONS(2324),
    [anon_sym_case] = ACTIONS(2324),
    [anon_sym_default] = ACTIONS(2324),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_do] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2324),
    [anon_sym_return] = ACTIONS(2324),
    [anon_sym_break] = ACTIONS(2324),
    [anon_sym_continue] = ACTIONS(2324),
    [anon_sym_goto] = ACTIONS(2324),
    [anon_sym___try] = ACTIONS(2324),
    [anon_sym___leave] = ACTIONS(2324),
    [anon_sym_not] = ACTIONS(2324),
    [anon_sym_compl] = ACTIONS(2324),
    [anon_sym_DASH_DASH] = ACTIONS(2326),
    [anon_sym_PLUS_PLUS] = ACTIONS(2326),
    [anon_sym_sizeof] = ACTIONS(2324),
    [anon_sym___alignof__] = ACTIONS(2324),
    [anon_sym___alignof] = ACTIONS(2324),
    [anon_sym__alignof] = ACTIONS(2324),
    [anon_sym_alignof] = ACTIONS(2324),
    [anon_sym__Alignof] = ACTIONS(2324),
    [anon_sym_offsetof] = ACTIONS(2324),
    [anon_sym__Generic] = ACTIONS(2324),
    [anon_sym_asm] = ACTIONS(2324),
    [anon_sym___asm__] = ACTIONS(2324),
    [sym_number_literal] = ACTIONS(2326),
    [anon_sym_L_SQUOTE] = ACTIONS(2326),
    [anon_sym_u_SQUOTE] = ACTIONS(2326),
    [anon_sym_U_SQUOTE] = ACTIONS(2326),
    [anon_sym_u8_SQUOTE] = ACTIONS(2326),
    [anon_sym_SQUOTE] = ACTIONS(2326),
    [anon_sym_L_DQUOTE] = ACTIONS(2326),
    [anon_sym_u_DQUOTE] = ACTIONS(2326),
    [anon_sym_U_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8_DQUOTE] = ACTIONS(2326),
    [anon_sym_DQUOTE] = ACTIONS(2326),
    [sym_true] = ACTIONS(2324),
    [sym_false] = ACTIONS(2324),
    [anon_sym_NULL] = ACTIONS(2324),
    [anon_sym_nullptr] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_try] = ACTIONS(2324),
    [anon_sym_delete] = ACTIONS(2324),
    [anon_sym_throw] = ACTIONS(2324),
    [anon_sym_namespace] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_concept] = ACTIONS(2324),
    [anon_sym_co_return] = ACTIONS(2324),
    [anon_sym_co_yield] = ACTIONS(2324),
    [anon_sym_R_DQUOTE] = ACTIONS(2326),
    [anon_sym_LR_DQUOTE] = ACTIONS(2326),
    [anon_sym_uR_DQUOTE] = ACTIONS(2326),
    [anon_sym_UR_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2326),
    [anon_sym_co_await] = ACTIONS(2324),
    [anon_sym_new] = ACTIONS(2324),
    [anon_sym_requires] = ACTIONS(2324),
    [sym_this] = ACTIONS(2324),
    [anon_sym_discard] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
    [anon_sym_cbuffer] = ACTIONS(2324),
  },
  [561] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_include_token1] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token2] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_BANG] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_DASH] = ACTIONS(2324),
    [anon_sym_PLUS] = ACTIONS(2324),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym_SEMI] = ACTIONS(2326),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym___cdecl] = ACTIONS(2324),
    [anon_sym___clrcall] = ACTIONS(2324),
    [anon_sym___stdcall] = ACTIONS(2324),
    [anon_sym___fastcall] = ACTIONS(2324),
    [anon_sym___thiscall] = ACTIONS(2324),
    [anon_sym___vectorcall] = ACTIONS(2324),
    [anon_sym_LBRACE] = ACTIONS(2326),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [anon_sym_if] = ACTIONS(2324),
    [anon_sym_switch] = ACTIONS(2324),
    [anon_sym_case] = ACTIONS(2324),
    [anon_sym_default] = ACTIONS(2324),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_do] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2324),
    [anon_sym_return] = ACTIONS(2324),
    [anon_sym_break] = ACTIONS(2324),
    [anon_sym_continue] = ACTIONS(2324),
    [anon_sym_goto] = ACTIONS(2324),
    [anon_sym___try] = ACTIONS(2324),
    [anon_sym___leave] = ACTIONS(2324),
    [anon_sym_not] = ACTIONS(2324),
    [anon_sym_compl] = ACTIONS(2324),
    [anon_sym_DASH_DASH] = ACTIONS(2326),
    [anon_sym_PLUS_PLUS] = ACTIONS(2326),
    [anon_sym_sizeof] = ACTIONS(2324),
    [anon_sym___alignof__] = ACTIONS(2324),
    [anon_sym___alignof] = ACTIONS(2324),
    [anon_sym__alignof] = ACTIONS(2324),
    [anon_sym_alignof] = ACTIONS(2324),
    [anon_sym__Alignof] = ACTIONS(2324),
    [anon_sym_offsetof] = ACTIONS(2324),
    [anon_sym__Generic] = ACTIONS(2324),
    [anon_sym_asm] = ACTIONS(2324),
    [anon_sym___asm__] = ACTIONS(2324),
    [sym_number_literal] = ACTIONS(2326),
    [anon_sym_L_SQUOTE] = ACTIONS(2326),
    [anon_sym_u_SQUOTE] = ACTIONS(2326),
    [anon_sym_U_SQUOTE] = ACTIONS(2326),
    [anon_sym_u8_SQUOTE] = ACTIONS(2326),
    [anon_sym_SQUOTE] = ACTIONS(2326),
    [anon_sym_L_DQUOTE] = ACTIONS(2326),
    [anon_sym_u_DQUOTE] = ACTIONS(2326),
    [anon_sym_U_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8_DQUOTE] = ACTIONS(2326),
    [anon_sym_DQUOTE] = ACTIONS(2326),
    [sym_true] = ACTIONS(2324),
    [sym_false] = ACTIONS(2324),
    [anon_sym_NULL] = ACTIONS(2324),
    [anon_sym_nullptr] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_try] = ACTIONS(2324),
    [anon_sym_delete] = ACTIONS(2324),
    [anon_sym_throw] = ACTIONS(2324),
    [anon_sym_namespace] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_concept] = ACTIONS(2324),
    [anon_sym_co_return] = ACTIONS(2324),
    [anon_sym_co_yield] = ACTIONS(2324),
    [anon_sym_R_DQUOTE] = ACTIONS(2326),
    [anon_sym_LR_DQUOTE] = ACTIONS(2326),
    [anon_sym_uR_DQUOTE] = ACTIONS(2326),
    [anon_sym_UR_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2326),
    [anon_sym_co_await] = ACTIONS(2324),
    [anon_sym_new] = ACTIONS(2324),
    [anon_sym_requires] = ACTIONS(2324),
    [sym_this] = ACTIONS(2324),
    [anon_sym_discard] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
    [anon_sym_cbuffer] = ACTIONS(2324),
  },
  [562] = {
    [sym_identifier] = ACTIONS(2393),
    [aux_sym_preproc_include_token1] = ACTIONS(2393),
    [aux_sym_preproc_def_token1] = ACTIONS(2393),
    [aux_sym_preproc_if_token1] = ACTIONS(2393),
    [aux_sym_preproc_if_token2] = ACTIONS(2393),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2393),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2393),
    [sym_preproc_directive] = ACTIONS(2393),
    [anon_sym_LPAREN2] = ACTIONS(2395),
    [anon_sym_BANG] = ACTIONS(2395),
    [anon_sym_TILDE] = ACTIONS(2395),
    [anon_sym_DASH] = ACTIONS(2393),
    [anon_sym_PLUS] = ACTIONS(2393),
    [anon_sym_STAR] = ACTIONS(2395),
    [anon_sym_AMP_AMP] = ACTIONS(2395),
    [anon_sym_AMP] = ACTIONS(2393),
    [anon_sym_SEMI] = ACTIONS(2395),
    [anon_sym___extension__] = ACTIONS(2393),
    [anon_sym_typedef] = ACTIONS(2393),
    [anon_sym_in] = ACTIONS(2393),
    [anon_sym_out] = ACTIONS(2393),
    [anon_sym_inout] = ACTIONS(2393),
    [anon_sym_extern] = ACTIONS(2393),
    [anon_sym___attribute__] = ACTIONS(2393),
    [anon_sym_COLON_COLON] = ACTIONS(2395),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2395),
    [anon_sym___declspec] = ACTIONS(2393),
    [anon_sym___based] = ACTIONS(2393),
    [anon_sym___cdecl] = ACTIONS(2393),
    [anon_sym___clrcall] = ACTIONS(2393),
    [anon_sym___stdcall] = ACTIONS(2393),
    [anon_sym___fastcall] = ACTIONS(2393),
    [anon_sym___thiscall] = ACTIONS(2393),
    [anon_sym___vectorcall] = ACTIONS(2393),
    [anon_sym_LBRACE] = ACTIONS(2395),
    [anon_sym_signed] = ACTIONS(2393),
    [anon_sym_unsigned] = ACTIONS(2393),
    [anon_sym_long] = ACTIONS(2393),
    [anon_sym_short] = ACTIONS(2393),
    [anon_sym_LBRACK] = ACTIONS(2393),
    [anon_sym_static] = ACTIONS(2393),
    [anon_sym_register] = ACTIONS(2393),
    [anon_sym_inline] = ACTIONS(2393),
    [anon_sym___inline] = ACTIONS(2393),
    [anon_sym___inline__] = ACTIONS(2393),
    [anon_sym___forceinline] = ACTIONS(2393),
    [anon_sym_thread_local] = ACTIONS(2393),
    [anon_sym___thread] = ACTIONS(2393),
    [anon_sym_const] = ACTIONS(2393),
    [anon_sym_constexpr] = ACTIONS(2393),
    [anon_sym_volatile] = ACTIONS(2393),
    [anon_sym_restrict] = ACTIONS(2393),
    [anon_sym___restrict__] = ACTIONS(2393),
    [anon_sym__Atomic] = ACTIONS(2393),
    [anon_sym__Noreturn] = ACTIONS(2393),
    [anon_sym_noreturn] = ACTIONS(2393),
    [anon_sym_mutable] = ACTIONS(2393),
    [anon_sym_constinit] = ACTIONS(2393),
    [anon_sym_consteval] = ACTIONS(2393),
    [anon_sym_alignas] = ACTIONS(2393),
    [anon_sym__Alignas] = ACTIONS(2393),
    [sym_primitive_type] = ACTIONS(2393),
    [anon_sym_enum] = ACTIONS(2393),
    [anon_sym_class] = ACTIONS(2393),
    [anon_sym_struct] = ACTIONS(2393),
    [anon_sym_union] = ACTIONS(2393),
    [anon_sym_if] = ACTIONS(2393),
    [anon_sym_switch] = ACTIONS(2393),
    [anon_sym_case] = ACTIONS(2393),
    [anon_sym_default] = ACTIONS(2393),
    [anon_sym_while] = ACTIONS(2393),
    [anon_sym_do] = ACTIONS(2393),
    [anon_sym_for] = ACTIONS(2393),
    [anon_sym_return] = ACTIONS(2393),
    [anon_sym_break] = ACTIONS(2393),
    [anon_sym_continue] = ACTIONS(2393),
    [anon_sym_goto] = ACTIONS(2393),
    [anon_sym___try] = ACTIONS(2393),
    [anon_sym___leave] = ACTIONS(2393),
    [anon_sym_not] = ACTIONS(2393),
    [anon_sym_compl] = ACTIONS(2393),
    [anon_sym_DASH_DASH] = ACTIONS(2395),
    [anon_sym_PLUS_PLUS] = ACTIONS(2395),
    [anon_sym_sizeof] = ACTIONS(2393),
    [anon_sym___alignof__] = ACTIONS(2393),
    [anon_sym___alignof] = ACTIONS(2393),
    [anon_sym__alignof] = ACTIONS(2393),
    [anon_sym_alignof] = ACTIONS(2393),
    [anon_sym__Alignof] = ACTIONS(2393),
    [anon_sym_offsetof] = ACTIONS(2393),
    [anon_sym__Generic] = ACTIONS(2393),
    [anon_sym_asm] = ACTIONS(2393),
    [anon_sym___asm__] = ACTIONS(2393),
    [sym_number_literal] = ACTIONS(2395),
    [anon_sym_L_SQUOTE] = ACTIONS(2395),
    [anon_sym_u_SQUOTE] = ACTIONS(2395),
    [anon_sym_U_SQUOTE] = ACTIONS(2395),
    [anon_sym_u8_SQUOTE] = ACTIONS(2395),
    [anon_sym_SQUOTE] = ACTIONS(2395),
    [anon_sym_L_DQUOTE] = ACTIONS(2395),
    [anon_sym_u_DQUOTE] = ACTIONS(2395),
    [anon_sym_U_DQUOTE] = ACTIONS(2395),
    [anon_sym_u8_DQUOTE] = ACTIONS(2395),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_true] = ACTIONS(2393),
    [sym_false] = ACTIONS(2393),
    [anon_sym_NULL] = ACTIONS(2393),
    [anon_sym_nullptr] = ACTIONS(2393),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2393),
    [anon_sym_decltype] = ACTIONS(2393),
    [sym_virtual] = ACTIONS(2393),
    [anon_sym_explicit] = ACTIONS(2393),
    [anon_sym_typename] = ACTIONS(2393),
    [anon_sym_template] = ACTIONS(2393),
    [anon_sym_operator] = ACTIONS(2393),
    [anon_sym_try] = ACTIONS(2393),
    [anon_sym_delete] = ACTIONS(2393),
    [anon_sym_throw] = ACTIONS(2393),
    [anon_sym_namespace] = ACTIONS(2393),
    [anon_sym_using] = ACTIONS(2393),
    [anon_sym_static_assert] = ACTIONS(2393),
    [anon_sym_concept] = ACTIONS(2393),
    [anon_sym_co_return] = ACTIONS(2393),
    [anon_sym_co_yield] = ACTIONS(2393),
    [anon_sym_R_DQUOTE] = ACTIONS(2395),
    [anon_sym_LR_DQUOTE] = ACTIONS(2395),
    [anon_sym_uR_DQUOTE] = ACTIONS(2395),
    [anon_sym_UR_DQUOTE] = ACTIONS(2395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2395),
    [anon_sym_co_await] = ACTIONS(2393),
    [anon_sym_new] = ACTIONS(2393),
    [anon_sym_requires] = ACTIONS(2393),
    [sym_this] = ACTIONS(2393),
    [anon_sym_discard] = ACTIONS(2393),
    [anon_sym_precise] = ACTIONS(2393),
    [anon_sym_shared] = ACTIONS(2393),
    [anon_sym_groupshared] = ACTIONS(2393),
    [anon_sym_uniform] = ACTIONS(2393),
    [anon_sym_row_major] = ACTIONS(2393),
    [anon_sym_column_major] = ACTIONS(2393),
    [anon_sym_globallycoherent] = ACTIONS(2393),
    [anon_sym_centroid] = ACTIONS(2393),
    [anon_sym_noperspective] = ACTIONS(2393),
    [anon_sym_nointerpolation] = ACTIONS(2393),
    [anon_sym_sample] = ACTIONS(2393),
    [anon_sym_linear] = ACTIONS(2393),
    [anon_sym_snorm] = ACTIONS(2393),
    [anon_sym_unorm] = ACTIONS(2393),
    [anon_sym_point] = ACTIONS(2393),
    [anon_sym_line] = ACTIONS(2393),
    [anon_sym_triangleadj] = ACTIONS(2393),
    [anon_sym_lineadj] = ACTIONS(2393),
    [anon_sym_triangle] = ACTIONS(2393),
    [anon_sym_cbuffer] = ACTIONS(2393),
  },
  [563] = {
    [sym_identifier] = ACTIONS(2364),
    [aux_sym_preproc_include_token1] = ACTIONS(2364),
    [aux_sym_preproc_def_token1] = ACTIONS(2364),
    [aux_sym_preproc_if_token1] = ACTIONS(2364),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2364),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2364),
    [sym_preproc_directive] = ACTIONS(2364),
    [anon_sym_LPAREN2] = ACTIONS(2366),
    [anon_sym_BANG] = ACTIONS(2366),
    [anon_sym_TILDE] = ACTIONS(2366),
    [anon_sym_DASH] = ACTIONS(2364),
    [anon_sym_PLUS] = ACTIONS(2364),
    [anon_sym_STAR] = ACTIONS(2366),
    [anon_sym_AMP_AMP] = ACTIONS(2366),
    [anon_sym_AMP] = ACTIONS(2364),
    [anon_sym_SEMI] = ACTIONS(2366),
    [anon_sym___extension__] = ACTIONS(2364),
    [anon_sym_typedef] = ACTIONS(2364),
    [anon_sym_in] = ACTIONS(2364),
    [anon_sym_out] = ACTIONS(2364),
    [anon_sym_inout] = ACTIONS(2364),
    [anon_sym_extern] = ACTIONS(2364),
    [anon_sym___attribute__] = ACTIONS(2364),
    [anon_sym_COLON_COLON] = ACTIONS(2366),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2366),
    [anon_sym___declspec] = ACTIONS(2364),
    [anon_sym___based] = ACTIONS(2364),
    [anon_sym___cdecl] = ACTIONS(2364),
    [anon_sym___clrcall] = ACTIONS(2364),
    [anon_sym___stdcall] = ACTIONS(2364),
    [anon_sym___fastcall] = ACTIONS(2364),
    [anon_sym___thiscall] = ACTIONS(2364),
    [anon_sym___vectorcall] = ACTIONS(2364),
    [anon_sym_LBRACE] = ACTIONS(2366),
    [anon_sym_RBRACE] = ACTIONS(2366),
    [anon_sym_signed] = ACTIONS(2364),
    [anon_sym_unsigned] = ACTIONS(2364),
    [anon_sym_long] = ACTIONS(2364),
    [anon_sym_short] = ACTIONS(2364),
    [anon_sym_LBRACK] = ACTIONS(2364),
    [anon_sym_static] = ACTIONS(2364),
    [anon_sym_register] = ACTIONS(2364),
    [anon_sym_inline] = ACTIONS(2364),
    [anon_sym___inline] = ACTIONS(2364),
    [anon_sym___inline__] = ACTIONS(2364),
    [anon_sym___forceinline] = ACTIONS(2364),
    [anon_sym_thread_local] = ACTIONS(2364),
    [anon_sym___thread] = ACTIONS(2364),
    [anon_sym_const] = ACTIONS(2364),
    [anon_sym_constexpr] = ACTIONS(2364),
    [anon_sym_volatile] = ACTIONS(2364),
    [anon_sym_restrict] = ACTIONS(2364),
    [anon_sym___restrict__] = ACTIONS(2364),
    [anon_sym__Atomic] = ACTIONS(2364),
    [anon_sym__Noreturn] = ACTIONS(2364),
    [anon_sym_noreturn] = ACTIONS(2364),
    [anon_sym_mutable] = ACTIONS(2364),
    [anon_sym_constinit] = ACTIONS(2364),
    [anon_sym_consteval] = ACTIONS(2364),
    [anon_sym_alignas] = ACTIONS(2364),
    [anon_sym__Alignas] = ACTIONS(2364),
    [sym_primitive_type] = ACTIONS(2364),
    [anon_sym_enum] = ACTIONS(2364),
    [anon_sym_class] = ACTIONS(2364),
    [anon_sym_struct] = ACTIONS(2364),
    [anon_sym_union] = ACTIONS(2364),
    [anon_sym_if] = ACTIONS(2364),
    [anon_sym_switch] = ACTIONS(2364),
    [anon_sym_case] = ACTIONS(2364),
    [anon_sym_default] = ACTIONS(2364),
    [anon_sym_while] = ACTIONS(2364),
    [anon_sym_do] = ACTIONS(2364),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_return] = ACTIONS(2364),
    [anon_sym_break] = ACTIONS(2364),
    [anon_sym_continue] = ACTIONS(2364),
    [anon_sym_goto] = ACTIONS(2364),
    [anon_sym___try] = ACTIONS(2364),
    [anon_sym___leave] = ACTIONS(2364),
    [anon_sym_not] = ACTIONS(2364),
    [anon_sym_compl] = ACTIONS(2364),
    [anon_sym_DASH_DASH] = ACTIONS(2366),
    [anon_sym_PLUS_PLUS] = ACTIONS(2366),
    [anon_sym_sizeof] = ACTIONS(2364),
    [anon_sym___alignof__] = ACTIONS(2364),
    [anon_sym___alignof] = ACTIONS(2364),
    [anon_sym__alignof] = ACTIONS(2364),
    [anon_sym_alignof] = ACTIONS(2364),
    [anon_sym__Alignof] = ACTIONS(2364),
    [anon_sym_offsetof] = ACTIONS(2364),
    [anon_sym__Generic] = ACTIONS(2364),
    [anon_sym_asm] = ACTIONS(2364),
    [anon_sym___asm__] = ACTIONS(2364),
    [sym_number_literal] = ACTIONS(2366),
    [anon_sym_L_SQUOTE] = ACTIONS(2366),
    [anon_sym_u_SQUOTE] = ACTIONS(2366),
    [anon_sym_U_SQUOTE] = ACTIONS(2366),
    [anon_sym_u8_SQUOTE] = ACTIONS(2366),
    [anon_sym_SQUOTE] = ACTIONS(2366),
    [anon_sym_L_DQUOTE] = ACTIONS(2366),
    [anon_sym_u_DQUOTE] = ACTIONS(2366),
    [anon_sym_U_DQUOTE] = ACTIONS(2366),
    [anon_sym_u8_DQUOTE] = ACTIONS(2366),
    [anon_sym_DQUOTE] = ACTIONS(2366),
    [sym_true] = ACTIONS(2364),
    [sym_false] = ACTIONS(2364),
    [anon_sym_NULL] = ACTIONS(2364),
    [anon_sym_nullptr] = ACTIONS(2364),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2364),
    [anon_sym_decltype] = ACTIONS(2364),
    [sym_virtual] = ACTIONS(2364),
    [anon_sym_explicit] = ACTIONS(2364),
    [anon_sym_typename] = ACTIONS(2364),
    [anon_sym_template] = ACTIONS(2364),
    [anon_sym_operator] = ACTIONS(2364),
    [anon_sym_try] = ACTIONS(2364),
    [anon_sym_delete] = ACTIONS(2364),
    [anon_sym_throw] = ACTIONS(2364),
    [anon_sym_namespace] = ACTIONS(2364),
    [anon_sym_using] = ACTIONS(2364),
    [anon_sym_static_assert] = ACTIONS(2364),
    [anon_sym_concept] = ACTIONS(2364),
    [anon_sym_co_return] = ACTIONS(2364),
    [anon_sym_co_yield] = ACTIONS(2364),
    [anon_sym_R_DQUOTE] = ACTIONS(2366),
    [anon_sym_LR_DQUOTE] = ACTIONS(2366),
    [anon_sym_uR_DQUOTE] = ACTIONS(2366),
    [anon_sym_UR_DQUOTE] = ACTIONS(2366),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2366),
    [anon_sym_co_await] = ACTIONS(2364),
    [anon_sym_new] = ACTIONS(2364),
    [anon_sym_requires] = ACTIONS(2364),
    [sym_this] = ACTIONS(2364),
    [anon_sym_discard] = ACTIONS(2364),
    [anon_sym_precise] = ACTIONS(2364),
    [anon_sym_shared] = ACTIONS(2364),
    [anon_sym_groupshared] = ACTIONS(2364),
    [anon_sym_uniform] = ACTIONS(2364),
    [anon_sym_row_major] = ACTIONS(2364),
    [anon_sym_column_major] = ACTIONS(2364),
    [anon_sym_globallycoherent] = ACTIONS(2364),
    [anon_sym_centroid] = ACTIONS(2364),
    [anon_sym_noperspective] = ACTIONS(2364),
    [anon_sym_nointerpolation] = ACTIONS(2364),
    [anon_sym_sample] = ACTIONS(2364),
    [anon_sym_linear] = ACTIONS(2364),
    [anon_sym_snorm] = ACTIONS(2364),
    [anon_sym_unorm] = ACTIONS(2364),
    [anon_sym_point] = ACTIONS(2364),
    [anon_sym_line] = ACTIONS(2364),
    [anon_sym_triangleadj] = ACTIONS(2364),
    [anon_sym_lineadj] = ACTIONS(2364),
    [anon_sym_triangle] = ACTIONS(2364),
    [anon_sym_cbuffer] = ACTIONS(2364),
  },
  [564] = {
    [sym_identifier] = ACTIONS(2328),
    [aux_sym_preproc_include_token1] = ACTIONS(2328),
    [aux_sym_preproc_def_token1] = ACTIONS(2328),
    [aux_sym_preproc_if_token1] = ACTIONS(2328),
    [aux_sym_preproc_if_token2] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2328),
    [sym_preproc_directive] = ACTIONS(2328),
    [anon_sym_LPAREN2] = ACTIONS(2330),
    [anon_sym_BANG] = ACTIONS(2330),
    [anon_sym_TILDE] = ACTIONS(2330),
    [anon_sym_DASH] = ACTIONS(2328),
    [anon_sym_PLUS] = ACTIONS(2328),
    [anon_sym_STAR] = ACTIONS(2330),
    [anon_sym_AMP_AMP] = ACTIONS(2330),
    [anon_sym_AMP] = ACTIONS(2328),
    [anon_sym_SEMI] = ACTIONS(2330),
    [anon_sym___extension__] = ACTIONS(2328),
    [anon_sym_typedef] = ACTIONS(2328),
    [anon_sym_in] = ACTIONS(2328),
    [anon_sym_out] = ACTIONS(2328),
    [anon_sym_inout] = ACTIONS(2328),
    [anon_sym_extern] = ACTIONS(2328),
    [anon_sym___attribute__] = ACTIONS(2328),
    [anon_sym_COLON_COLON] = ACTIONS(2330),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2330),
    [anon_sym___declspec] = ACTIONS(2328),
    [anon_sym___based] = ACTIONS(2328),
    [anon_sym___cdecl] = ACTIONS(2328),
    [anon_sym___clrcall] = ACTIONS(2328),
    [anon_sym___stdcall] = ACTIONS(2328),
    [anon_sym___fastcall] = ACTIONS(2328),
    [anon_sym___thiscall] = ACTIONS(2328),
    [anon_sym___vectorcall] = ACTIONS(2328),
    [anon_sym_LBRACE] = ACTIONS(2330),
    [anon_sym_signed] = ACTIONS(2328),
    [anon_sym_unsigned] = ACTIONS(2328),
    [anon_sym_long] = ACTIONS(2328),
    [anon_sym_short] = ACTIONS(2328),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_static] = ACTIONS(2328),
    [anon_sym_register] = ACTIONS(2328),
    [anon_sym_inline] = ACTIONS(2328),
    [anon_sym___inline] = ACTIONS(2328),
    [anon_sym___inline__] = ACTIONS(2328),
    [anon_sym___forceinline] = ACTIONS(2328),
    [anon_sym_thread_local] = ACTIONS(2328),
    [anon_sym___thread] = ACTIONS(2328),
    [anon_sym_const] = ACTIONS(2328),
    [anon_sym_constexpr] = ACTIONS(2328),
    [anon_sym_volatile] = ACTIONS(2328),
    [anon_sym_restrict] = ACTIONS(2328),
    [anon_sym___restrict__] = ACTIONS(2328),
    [anon_sym__Atomic] = ACTIONS(2328),
    [anon_sym__Noreturn] = ACTIONS(2328),
    [anon_sym_noreturn] = ACTIONS(2328),
    [anon_sym_mutable] = ACTIONS(2328),
    [anon_sym_constinit] = ACTIONS(2328),
    [anon_sym_consteval] = ACTIONS(2328),
    [anon_sym_alignas] = ACTIONS(2328),
    [anon_sym__Alignas] = ACTIONS(2328),
    [sym_primitive_type] = ACTIONS(2328),
    [anon_sym_enum] = ACTIONS(2328),
    [anon_sym_class] = ACTIONS(2328),
    [anon_sym_struct] = ACTIONS(2328),
    [anon_sym_union] = ACTIONS(2328),
    [anon_sym_if] = ACTIONS(2328),
    [anon_sym_switch] = ACTIONS(2328),
    [anon_sym_case] = ACTIONS(2328),
    [anon_sym_default] = ACTIONS(2328),
    [anon_sym_while] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(2328),
    [anon_sym_for] = ACTIONS(2328),
    [anon_sym_return] = ACTIONS(2328),
    [anon_sym_break] = ACTIONS(2328),
    [anon_sym_continue] = ACTIONS(2328),
    [anon_sym_goto] = ACTIONS(2328),
    [anon_sym___try] = ACTIONS(2328),
    [anon_sym___leave] = ACTIONS(2328),
    [anon_sym_not] = ACTIONS(2328),
    [anon_sym_compl] = ACTIONS(2328),
    [anon_sym_DASH_DASH] = ACTIONS(2330),
    [anon_sym_PLUS_PLUS] = ACTIONS(2330),
    [anon_sym_sizeof] = ACTIONS(2328),
    [anon_sym___alignof__] = ACTIONS(2328),
    [anon_sym___alignof] = ACTIONS(2328),
    [anon_sym__alignof] = ACTIONS(2328),
    [anon_sym_alignof] = ACTIONS(2328),
    [anon_sym__Alignof] = ACTIONS(2328),
    [anon_sym_offsetof] = ACTIONS(2328),
    [anon_sym__Generic] = ACTIONS(2328),
    [anon_sym_asm] = ACTIONS(2328),
    [anon_sym___asm__] = ACTIONS(2328),
    [sym_number_literal] = ACTIONS(2330),
    [anon_sym_L_SQUOTE] = ACTIONS(2330),
    [anon_sym_u_SQUOTE] = ACTIONS(2330),
    [anon_sym_U_SQUOTE] = ACTIONS(2330),
    [anon_sym_u8_SQUOTE] = ACTIONS(2330),
    [anon_sym_SQUOTE] = ACTIONS(2330),
    [anon_sym_L_DQUOTE] = ACTIONS(2330),
    [anon_sym_u_DQUOTE] = ACTIONS(2330),
    [anon_sym_U_DQUOTE] = ACTIONS(2330),
    [anon_sym_u8_DQUOTE] = ACTIONS(2330),
    [anon_sym_DQUOTE] = ACTIONS(2330),
    [sym_true] = ACTIONS(2328),
    [sym_false] = ACTIONS(2328),
    [anon_sym_NULL] = ACTIONS(2328),
    [anon_sym_nullptr] = ACTIONS(2328),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2328),
    [anon_sym_decltype] = ACTIONS(2328),
    [sym_virtual] = ACTIONS(2328),
    [anon_sym_explicit] = ACTIONS(2328),
    [anon_sym_typename] = ACTIONS(2328),
    [anon_sym_template] = ACTIONS(2328),
    [anon_sym_operator] = ACTIONS(2328),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_delete] = ACTIONS(2328),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_namespace] = ACTIONS(2328),
    [anon_sym_using] = ACTIONS(2328),
    [anon_sym_static_assert] = ACTIONS(2328),
    [anon_sym_concept] = ACTIONS(2328),
    [anon_sym_co_return] = ACTIONS(2328),
    [anon_sym_co_yield] = ACTIONS(2328),
    [anon_sym_R_DQUOTE] = ACTIONS(2330),
    [anon_sym_LR_DQUOTE] = ACTIONS(2330),
    [anon_sym_uR_DQUOTE] = ACTIONS(2330),
    [anon_sym_UR_DQUOTE] = ACTIONS(2330),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2330),
    [anon_sym_co_await] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(2328),
    [anon_sym_requires] = ACTIONS(2328),
    [sym_this] = ACTIONS(2328),
    [anon_sym_discard] = ACTIONS(2328),
    [anon_sym_precise] = ACTIONS(2328),
    [anon_sym_shared] = ACTIONS(2328),
    [anon_sym_groupshared] = ACTIONS(2328),
    [anon_sym_uniform] = ACTIONS(2328),
    [anon_sym_row_major] = ACTIONS(2328),
    [anon_sym_column_major] = ACTIONS(2328),
    [anon_sym_globallycoherent] = ACTIONS(2328),
    [anon_sym_centroid] = ACTIONS(2328),
    [anon_sym_noperspective] = ACTIONS(2328),
    [anon_sym_nointerpolation] = ACTIONS(2328),
    [anon_sym_sample] = ACTIONS(2328),
    [anon_sym_linear] = ACTIONS(2328),
    [anon_sym_snorm] = ACTIONS(2328),
    [anon_sym_unorm] = ACTIONS(2328),
    [anon_sym_point] = ACTIONS(2328),
    [anon_sym_line] = ACTIONS(2328),
    [anon_sym_triangleadj] = ACTIONS(2328),
    [anon_sym_lineadj] = ACTIONS(2328),
    [anon_sym_triangle] = ACTIONS(2328),
    [anon_sym_cbuffer] = ACTIONS(2328),
  },
  [565] = {
    [sym_identifier] = ACTIONS(2540),
    [aux_sym_preproc_include_token1] = ACTIONS(2540),
    [aux_sym_preproc_def_token1] = ACTIONS(2540),
    [aux_sym_preproc_if_token1] = ACTIONS(2540),
    [aux_sym_preproc_if_token2] = ACTIONS(2540),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2540),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2540),
    [sym_preproc_directive] = ACTIONS(2540),
    [anon_sym_LPAREN2] = ACTIONS(2542),
    [anon_sym_BANG] = ACTIONS(2542),
    [anon_sym_TILDE] = ACTIONS(2542),
    [anon_sym_DASH] = ACTIONS(2540),
    [anon_sym_PLUS] = ACTIONS(2540),
    [anon_sym_STAR] = ACTIONS(2542),
    [anon_sym_AMP_AMP] = ACTIONS(2542),
    [anon_sym_AMP] = ACTIONS(2540),
    [anon_sym_SEMI] = ACTIONS(2542),
    [anon_sym___extension__] = ACTIONS(2540),
    [anon_sym_typedef] = ACTIONS(2540),
    [anon_sym_in] = ACTIONS(2540),
    [anon_sym_out] = ACTIONS(2540),
    [anon_sym_inout] = ACTIONS(2540),
    [anon_sym_extern] = ACTIONS(2540),
    [anon_sym___attribute__] = ACTIONS(2540),
    [anon_sym_COLON_COLON] = ACTIONS(2542),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2542),
    [anon_sym___declspec] = ACTIONS(2540),
    [anon_sym___based] = ACTIONS(2540),
    [anon_sym___cdecl] = ACTIONS(2540),
    [anon_sym___clrcall] = ACTIONS(2540),
    [anon_sym___stdcall] = ACTIONS(2540),
    [anon_sym___fastcall] = ACTIONS(2540),
    [anon_sym___thiscall] = ACTIONS(2540),
    [anon_sym___vectorcall] = ACTIONS(2540),
    [anon_sym_LBRACE] = ACTIONS(2542),
    [anon_sym_signed] = ACTIONS(2540),
    [anon_sym_unsigned] = ACTIONS(2540),
    [anon_sym_long] = ACTIONS(2540),
    [anon_sym_short] = ACTIONS(2540),
    [anon_sym_LBRACK] = ACTIONS(2540),
    [anon_sym_static] = ACTIONS(2540),
    [anon_sym_register] = ACTIONS(2540),
    [anon_sym_inline] = ACTIONS(2540),
    [anon_sym___inline] = ACTIONS(2540),
    [anon_sym___inline__] = ACTIONS(2540),
    [anon_sym___forceinline] = ACTIONS(2540),
    [anon_sym_thread_local] = ACTIONS(2540),
    [anon_sym___thread] = ACTIONS(2540),
    [anon_sym_const] = ACTIONS(2540),
    [anon_sym_constexpr] = ACTIONS(2540),
    [anon_sym_volatile] = ACTIONS(2540),
    [anon_sym_restrict] = ACTIONS(2540),
    [anon_sym___restrict__] = ACTIONS(2540),
    [anon_sym__Atomic] = ACTIONS(2540),
    [anon_sym__Noreturn] = ACTIONS(2540),
    [anon_sym_noreturn] = ACTIONS(2540),
    [anon_sym_mutable] = ACTIONS(2540),
    [anon_sym_constinit] = ACTIONS(2540),
    [anon_sym_consteval] = ACTIONS(2540),
    [anon_sym_alignas] = ACTIONS(2540),
    [anon_sym__Alignas] = ACTIONS(2540),
    [sym_primitive_type] = ACTIONS(2540),
    [anon_sym_enum] = ACTIONS(2540),
    [anon_sym_class] = ACTIONS(2540),
    [anon_sym_struct] = ACTIONS(2540),
    [anon_sym_union] = ACTIONS(2540),
    [anon_sym_if] = ACTIONS(2540),
    [anon_sym_switch] = ACTIONS(2540),
    [anon_sym_case] = ACTIONS(2540),
    [anon_sym_default] = ACTIONS(2540),
    [anon_sym_while] = ACTIONS(2540),
    [anon_sym_do] = ACTIONS(2540),
    [anon_sym_for] = ACTIONS(2540),
    [anon_sym_return] = ACTIONS(2540),
    [anon_sym_break] = ACTIONS(2540),
    [anon_sym_continue] = ACTIONS(2540),
    [anon_sym_goto] = ACTIONS(2540),
    [anon_sym___try] = ACTIONS(2540),
    [anon_sym___leave] = ACTIONS(2540),
    [anon_sym_not] = ACTIONS(2540),
    [anon_sym_compl] = ACTIONS(2540),
    [anon_sym_DASH_DASH] = ACTIONS(2542),
    [anon_sym_PLUS_PLUS] = ACTIONS(2542),
    [anon_sym_sizeof] = ACTIONS(2540),
    [anon_sym___alignof__] = ACTIONS(2540),
    [anon_sym___alignof] = ACTIONS(2540),
    [anon_sym__alignof] = ACTIONS(2540),
    [anon_sym_alignof] = ACTIONS(2540),
    [anon_sym__Alignof] = ACTIONS(2540),
    [anon_sym_offsetof] = ACTIONS(2540),
    [anon_sym__Generic] = ACTIONS(2540),
    [anon_sym_asm] = ACTIONS(2540),
    [anon_sym___asm__] = ACTIONS(2540),
    [sym_number_literal] = ACTIONS(2542),
    [anon_sym_L_SQUOTE] = ACTIONS(2542),
    [anon_sym_u_SQUOTE] = ACTIONS(2542),
    [anon_sym_U_SQUOTE] = ACTIONS(2542),
    [anon_sym_u8_SQUOTE] = ACTIONS(2542),
    [anon_sym_SQUOTE] = ACTIONS(2542),
    [anon_sym_L_DQUOTE] = ACTIONS(2542),
    [anon_sym_u_DQUOTE] = ACTIONS(2542),
    [anon_sym_U_DQUOTE] = ACTIONS(2542),
    [anon_sym_u8_DQUOTE] = ACTIONS(2542),
    [anon_sym_DQUOTE] = ACTIONS(2542),
    [sym_true] = ACTIONS(2540),
    [sym_false] = ACTIONS(2540),
    [anon_sym_NULL] = ACTIONS(2540),
    [anon_sym_nullptr] = ACTIONS(2540),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2540),
    [anon_sym_decltype] = ACTIONS(2540),
    [sym_virtual] = ACTIONS(2540),
    [anon_sym_explicit] = ACTIONS(2540),
    [anon_sym_typename] = ACTIONS(2540),
    [anon_sym_template] = ACTIONS(2540),
    [anon_sym_operator] = ACTIONS(2540),
    [anon_sym_try] = ACTIONS(2540),
    [anon_sym_delete] = ACTIONS(2540),
    [anon_sym_throw] = ACTIONS(2540),
    [anon_sym_namespace] = ACTIONS(2540),
    [anon_sym_using] = ACTIONS(2540),
    [anon_sym_static_assert] = ACTIONS(2540),
    [anon_sym_concept] = ACTIONS(2540),
    [anon_sym_co_return] = ACTIONS(2540),
    [anon_sym_co_yield] = ACTIONS(2540),
    [anon_sym_R_DQUOTE] = ACTIONS(2542),
    [anon_sym_LR_DQUOTE] = ACTIONS(2542),
    [anon_sym_uR_DQUOTE] = ACTIONS(2542),
    [anon_sym_UR_DQUOTE] = ACTIONS(2542),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2542),
    [anon_sym_co_await] = ACTIONS(2540),
    [anon_sym_new] = ACTIONS(2540),
    [anon_sym_requires] = ACTIONS(2540),
    [sym_this] = ACTIONS(2540),
    [anon_sym_discard] = ACTIONS(2540),
    [anon_sym_precise] = ACTIONS(2540),
    [anon_sym_shared] = ACTIONS(2540),
    [anon_sym_groupshared] = ACTIONS(2540),
    [anon_sym_uniform] = ACTIONS(2540),
    [anon_sym_row_major] = ACTIONS(2540),
    [anon_sym_column_major] = ACTIONS(2540),
    [anon_sym_globallycoherent] = ACTIONS(2540),
    [anon_sym_centroid] = ACTIONS(2540),
    [anon_sym_noperspective] = ACTIONS(2540),
    [anon_sym_nointerpolation] = ACTIONS(2540),
    [anon_sym_sample] = ACTIONS(2540),
    [anon_sym_linear] = ACTIONS(2540),
    [anon_sym_snorm] = ACTIONS(2540),
    [anon_sym_unorm] = ACTIONS(2540),
    [anon_sym_point] = ACTIONS(2540),
    [anon_sym_line] = ACTIONS(2540),
    [anon_sym_triangleadj] = ACTIONS(2540),
    [anon_sym_lineadj] = ACTIONS(2540),
    [anon_sym_triangle] = ACTIONS(2540),
    [anon_sym_cbuffer] = ACTIONS(2540),
  },
  [566] = {
    [sym_identifier] = ACTIONS(2356),
    [aux_sym_preproc_include_token1] = ACTIONS(2356),
    [aux_sym_preproc_def_token1] = ACTIONS(2356),
    [aux_sym_preproc_if_token1] = ACTIONS(2356),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2356),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2356),
    [sym_preproc_directive] = ACTIONS(2356),
    [anon_sym_LPAREN2] = ACTIONS(2358),
    [anon_sym_BANG] = ACTIONS(2358),
    [anon_sym_TILDE] = ACTIONS(2358),
    [anon_sym_DASH] = ACTIONS(2356),
    [anon_sym_PLUS] = ACTIONS(2356),
    [anon_sym_STAR] = ACTIONS(2358),
    [anon_sym_AMP_AMP] = ACTIONS(2358),
    [anon_sym_AMP] = ACTIONS(2356),
    [anon_sym_SEMI] = ACTIONS(2358),
    [anon_sym___extension__] = ACTIONS(2356),
    [anon_sym_typedef] = ACTIONS(2356),
    [anon_sym_in] = ACTIONS(2356),
    [anon_sym_out] = ACTIONS(2356),
    [anon_sym_inout] = ACTIONS(2356),
    [anon_sym_extern] = ACTIONS(2356),
    [anon_sym___attribute__] = ACTIONS(2356),
    [anon_sym_COLON_COLON] = ACTIONS(2358),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2358),
    [anon_sym___declspec] = ACTIONS(2356),
    [anon_sym___based] = ACTIONS(2356),
    [anon_sym___cdecl] = ACTIONS(2356),
    [anon_sym___clrcall] = ACTIONS(2356),
    [anon_sym___stdcall] = ACTIONS(2356),
    [anon_sym___fastcall] = ACTIONS(2356),
    [anon_sym___thiscall] = ACTIONS(2356),
    [anon_sym___vectorcall] = ACTIONS(2356),
    [anon_sym_LBRACE] = ACTIONS(2358),
    [anon_sym_RBRACE] = ACTIONS(2358),
    [anon_sym_signed] = ACTIONS(2356),
    [anon_sym_unsigned] = ACTIONS(2356),
    [anon_sym_long] = ACTIONS(2356),
    [anon_sym_short] = ACTIONS(2356),
    [anon_sym_LBRACK] = ACTIONS(2356),
    [anon_sym_static] = ACTIONS(2356),
    [anon_sym_register] = ACTIONS(2356),
    [anon_sym_inline] = ACTIONS(2356),
    [anon_sym___inline] = ACTIONS(2356),
    [anon_sym___inline__] = ACTIONS(2356),
    [anon_sym___forceinline] = ACTIONS(2356),
    [anon_sym_thread_local] = ACTIONS(2356),
    [anon_sym___thread] = ACTIONS(2356),
    [anon_sym_const] = ACTIONS(2356),
    [anon_sym_constexpr] = ACTIONS(2356),
    [anon_sym_volatile] = ACTIONS(2356),
    [anon_sym_restrict] = ACTIONS(2356),
    [anon_sym___restrict__] = ACTIONS(2356),
    [anon_sym__Atomic] = ACTIONS(2356),
    [anon_sym__Noreturn] = ACTIONS(2356),
    [anon_sym_noreturn] = ACTIONS(2356),
    [anon_sym_mutable] = ACTIONS(2356),
    [anon_sym_constinit] = ACTIONS(2356),
    [anon_sym_consteval] = ACTIONS(2356),
    [anon_sym_alignas] = ACTIONS(2356),
    [anon_sym__Alignas] = ACTIONS(2356),
    [sym_primitive_type] = ACTIONS(2356),
    [anon_sym_enum] = ACTIONS(2356),
    [anon_sym_class] = ACTIONS(2356),
    [anon_sym_struct] = ACTIONS(2356),
    [anon_sym_union] = ACTIONS(2356),
    [anon_sym_if] = ACTIONS(2356),
    [anon_sym_switch] = ACTIONS(2356),
    [anon_sym_case] = ACTIONS(2356),
    [anon_sym_default] = ACTIONS(2356),
    [anon_sym_while] = ACTIONS(2356),
    [anon_sym_do] = ACTIONS(2356),
    [anon_sym_for] = ACTIONS(2356),
    [anon_sym_return] = ACTIONS(2356),
    [anon_sym_break] = ACTIONS(2356),
    [anon_sym_continue] = ACTIONS(2356),
    [anon_sym_goto] = ACTIONS(2356),
    [anon_sym___try] = ACTIONS(2356),
    [anon_sym___leave] = ACTIONS(2356),
    [anon_sym_not] = ACTIONS(2356),
    [anon_sym_compl] = ACTIONS(2356),
    [anon_sym_DASH_DASH] = ACTIONS(2358),
    [anon_sym_PLUS_PLUS] = ACTIONS(2358),
    [anon_sym_sizeof] = ACTIONS(2356),
    [anon_sym___alignof__] = ACTIONS(2356),
    [anon_sym___alignof] = ACTIONS(2356),
    [anon_sym__alignof] = ACTIONS(2356),
    [anon_sym_alignof] = ACTIONS(2356),
    [anon_sym__Alignof] = ACTIONS(2356),
    [anon_sym_offsetof] = ACTIONS(2356),
    [anon_sym__Generic] = ACTIONS(2356),
    [anon_sym_asm] = ACTIONS(2356),
    [anon_sym___asm__] = ACTIONS(2356),
    [sym_number_literal] = ACTIONS(2358),
    [anon_sym_L_SQUOTE] = ACTIONS(2358),
    [anon_sym_u_SQUOTE] = ACTIONS(2358),
    [anon_sym_U_SQUOTE] = ACTIONS(2358),
    [anon_sym_u8_SQUOTE] = ACTIONS(2358),
    [anon_sym_SQUOTE] = ACTIONS(2358),
    [anon_sym_L_DQUOTE] = ACTIONS(2358),
    [anon_sym_u_DQUOTE] = ACTIONS(2358),
    [anon_sym_U_DQUOTE] = ACTIONS(2358),
    [anon_sym_u8_DQUOTE] = ACTIONS(2358),
    [anon_sym_DQUOTE] = ACTIONS(2358),
    [sym_true] = ACTIONS(2356),
    [sym_false] = ACTIONS(2356),
    [anon_sym_NULL] = ACTIONS(2356),
    [anon_sym_nullptr] = ACTIONS(2356),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2356),
    [anon_sym_decltype] = ACTIONS(2356),
    [sym_virtual] = ACTIONS(2356),
    [anon_sym_explicit] = ACTIONS(2356),
    [anon_sym_typename] = ACTIONS(2356),
    [anon_sym_template] = ACTIONS(2356),
    [anon_sym_operator] = ACTIONS(2356),
    [anon_sym_try] = ACTIONS(2356),
    [anon_sym_delete] = ACTIONS(2356),
    [anon_sym_throw] = ACTIONS(2356),
    [anon_sym_namespace] = ACTIONS(2356),
    [anon_sym_using] = ACTIONS(2356),
    [anon_sym_static_assert] = ACTIONS(2356),
    [anon_sym_concept] = ACTIONS(2356),
    [anon_sym_co_return] = ACTIONS(2356),
    [anon_sym_co_yield] = ACTIONS(2356),
    [anon_sym_R_DQUOTE] = ACTIONS(2358),
    [anon_sym_LR_DQUOTE] = ACTIONS(2358),
    [anon_sym_uR_DQUOTE] = ACTIONS(2358),
    [anon_sym_UR_DQUOTE] = ACTIONS(2358),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2358),
    [anon_sym_co_await] = ACTIONS(2356),
    [anon_sym_new] = ACTIONS(2356),
    [anon_sym_requires] = ACTIONS(2356),
    [sym_this] = ACTIONS(2356),
    [anon_sym_discard] = ACTIONS(2356),
    [anon_sym_precise] = ACTIONS(2356),
    [anon_sym_shared] = ACTIONS(2356),
    [anon_sym_groupshared] = ACTIONS(2356),
    [anon_sym_uniform] = ACTIONS(2356),
    [anon_sym_row_major] = ACTIONS(2356),
    [anon_sym_column_major] = ACTIONS(2356),
    [anon_sym_globallycoherent] = ACTIONS(2356),
    [anon_sym_centroid] = ACTIONS(2356),
    [anon_sym_noperspective] = ACTIONS(2356),
    [anon_sym_nointerpolation] = ACTIONS(2356),
    [anon_sym_sample] = ACTIONS(2356),
    [anon_sym_linear] = ACTIONS(2356),
    [anon_sym_snorm] = ACTIONS(2356),
    [anon_sym_unorm] = ACTIONS(2356),
    [anon_sym_point] = ACTIONS(2356),
    [anon_sym_line] = ACTIONS(2356),
    [anon_sym_triangleadj] = ACTIONS(2356),
    [anon_sym_lineadj] = ACTIONS(2356),
    [anon_sym_triangle] = ACTIONS(2356),
    [anon_sym_cbuffer] = ACTIONS(2356),
  },
  [567] = {
    [sym_identifier] = ACTIONS(2549),
    [aux_sym_preproc_include_token1] = ACTIONS(2549),
    [aux_sym_preproc_def_token1] = ACTIONS(2549),
    [aux_sym_preproc_if_token1] = ACTIONS(2549),
    [aux_sym_preproc_if_token2] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2549),
    [sym_preproc_directive] = ACTIONS(2549),
    [anon_sym_LPAREN2] = ACTIONS(2551),
    [anon_sym_BANG] = ACTIONS(2551),
    [anon_sym_TILDE] = ACTIONS(2551),
    [anon_sym_DASH] = ACTIONS(2549),
    [anon_sym_PLUS] = ACTIONS(2549),
    [anon_sym_STAR] = ACTIONS(2551),
    [anon_sym_AMP_AMP] = ACTIONS(2551),
    [anon_sym_AMP] = ACTIONS(2549),
    [anon_sym_SEMI] = ACTIONS(2551),
    [anon_sym___extension__] = ACTIONS(2549),
    [anon_sym_typedef] = ACTIONS(2549),
    [anon_sym_in] = ACTIONS(2549),
    [anon_sym_out] = ACTIONS(2549),
    [anon_sym_inout] = ACTIONS(2549),
    [anon_sym_extern] = ACTIONS(2549),
    [anon_sym___attribute__] = ACTIONS(2549),
    [anon_sym_COLON_COLON] = ACTIONS(2551),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2551),
    [anon_sym___declspec] = ACTIONS(2549),
    [anon_sym___based] = ACTIONS(2549),
    [anon_sym___cdecl] = ACTIONS(2549),
    [anon_sym___clrcall] = ACTIONS(2549),
    [anon_sym___stdcall] = ACTIONS(2549),
    [anon_sym___fastcall] = ACTIONS(2549),
    [anon_sym___thiscall] = ACTIONS(2549),
    [anon_sym___vectorcall] = ACTIONS(2549),
    [anon_sym_LBRACE] = ACTIONS(2551),
    [anon_sym_signed] = ACTIONS(2549),
    [anon_sym_unsigned] = ACTIONS(2549),
    [anon_sym_long] = ACTIONS(2549),
    [anon_sym_short] = ACTIONS(2549),
    [anon_sym_LBRACK] = ACTIONS(2549),
    [anon_sym_static] = ACTIONS(2549),
    [anon_sym_register] = ACTIONS(2549),
    [anon_sym_inline] = ACTIONS(2549),
    [anon_sym___inline] = ACTIONS(2549),
    [anon_sym___inline__] = ACTIONS(2549),
    [anon_sym___forceinline] = ACTIONS(2549),
    [anon_sym_thread_local] = ACTIONS(2549),
    [anon_sym___thread] = ACTIONS(2549),
    [anon_sym_const] = ACTIONS(2549),
    [anon_sym_constexpr] = ACTIONS(2549),
    [anon_sym_volatile] = ACTIONS(2549),
    [anon_sym_restrict] = ACTIONS(2549),
    [anon_sym___restrict__] = ACTIONS(2549),
    [anon_sym__Atomic] = ACTIONS(2549),
    [anon_sym__Noreturn] = ACTIONS(2549),
    [anon_sym_noreturn] = ACTIONS(2549),
    [anon_sym_mutable] = ACTIONS(2549),
    [anon_sym_constinit] = ACTIONS(2549),
    [anon_sym_consteval] = ACTIONS(2549),
    [anon_sym_alignas] = ACTIONS(2549),
    [anon_sym__Alignas] = ACTIONS(2549),
    [sym_primitive_type] = ACTIONS(2549),
    [anon_sym_enum] = ACTIONS(2549),
    [anon_sym_class] = ACTIONS(2549),
    [anon_sym_struct] = ACTIONS(2549),
    [anon_sym_union] = ACTIONS(2549),
    [anon_sym_if] = ACTIONS(2549),
    [anon_sym_switch] = ACTIONS(2549),
    [anon_sym_case] = ACTIONS(2549),
    [anon_sym_default] = ACTIONS(2549),
    [anon_sym_while] = ACTIONS(2549),
    [anon_sym_do] = ACTIONS(2549),
    [anon_sym_for] = ACTIONS(2549),
    [anon_sym_return] = ACTIONS(2549),
    [anon_sym_break] = ACTIONS(2549),
    [anon_sym_continue] = ACTIONS(2549),
    [anon_sym_goto] = ACTIONS(2549),
    [anon_sym___try] = ACTIONS(2549),
    [anon_sym___leave] = ACTIONS(2549),
    [anon_sym_not] = ACTIONS(2549),
    [anon_sym_compl] = ACTIONS(2549),
    [anon_sym_DASH_DASH] = ACTIONS(2551),
    [anon_sym_PLUS_PLUS] = ACTIONS(2551),
    [anon_sym_sizeof] = ACTIONS(2549),
    [anon_sym___alignof__] = ACTIONS(2549),
    [anon_sym___alignof] = ACTIONS(2549),
    [anon_sym__alignof] = ACTIONS(2549),
    [anon_sym_alignof] = ACTIONS(2549),
    [anon_sym__Alignof] = ACTIONS(2549),
    [anon_sym_offsetof] = ACTIONS(2549),
    [anon_sym__Generic] = ACTIONS(2549),
    [anon_sym_asm] = ACTIONS(2549),
    [anon_sym___asm__] = ACTIONS(2549),
    [sym_number_literal] = ACTIONS(2551),
    [anon_sym_L_SQUOTE] = ACTIONS(2551),
    [anon_sym_u_SQUOTE] = ACTIONS(2551),
    [anon_sym_U_SQUOTE] = ACTIONS(2551),
    [anon_sym_u8_SQUOTE] = ACTIONS(2551),
    [anon_sym_SQUOTE] = ACTIONS(2551),
    [anon_sym_L_DQUOTE] = ACTIONS(2551),
    [anon_sym_u_DQUOTE] = ACTIONS(2551),
    [anon_sym_U_DQUOTE] = ACTIONS(2551),
    [anon_sym_u8_DQUOTE] = ACTIONS(2551),
    [anon_sym_DQUOTE] = ACTIONS(2551),
    [sym_true] = ACTIONS(2549),
    [sym_false] = ACTIONS(2549),
    [anon_sym_NULL] = ACTIONS(2549),
    [anon_sym_nullptr] = ACTIONS(2549),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2549),
    [anon_sym_decltype] = ACTIONS(2549),
    [sym_virtual] = ACTIONS(2549),
    [anon_sym_explicit] = ACTIONS(2549),
    [anon_sym_typename] = ACTIONS(2549),
    [anon_sym_template] = ACTIONS(2549),
    [anon_sym_operator] = ACTIONS(2549),
    [anon_sym_try] = ACTIONS(2549),
    [anon_sym_delete] = ACTIONS(2549),
    [anon_sym_throw] = ACTIONS(2549),
    [anon_sym_namespace] = ACTIONS(2549),
    [anon_sym_using] = ACTIONS(2549),
    [anon_sym_static_assert] = ACTIONS(2549),
    [anon_sym_concept] = ACTIONS(2549),
    [anon_sym_co_return] = ACTIONS(2549),
    [anon_sym_co_yield] = ACTIONS(2549),
    [anon_sym_R_DQUOTE] = ACTIONS(2551),
    [anon_sym_LR_DQUOTE] = ACTIONS(2551),
    [anon_sym_uR_DQUOTE] = ACTIONS(2551),
    [anon_sym_UR_DQUOTE] = ACTIONS(2551),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2551),
    [anon_sym_co_await] = ACTIONS(2549),
    [anon_sym_new] = ACTIONS(2549),
    [anon_sym_requires] = ACTIONS(2549),
    [sym_this] = ACTIONS(2549),
    [anon_sym_discard] = ACTIONS(2549),
    [anon_sym_precise] = ACTIONS(2549),
    [anon_sym_shared] = ACTIONS(2549),
    [anon_sym_groupshared] = ACTIONS(2549),
    [anon_sym_uniform] = ACTIONS(2549),
    [anon_sym_row_major] = ACTIONS(2549),
    [anon_sym_column_major] = ACTIONS(2549),
    [anon_sym_globallycoherent] = ACTIONS(2549),
    [anon_sym_centroid] = ACTIONS(2549),
    [anon_sym_noperspective] = ACTIONS(2549),
    [anon_sym_nointerpolation] = ACTIONS(2549),
    [anon_sym_sample] = ACTIONS(2549),
    [anon_sym_linear] = ACTIONS(2549),
    [anon_sym_snorm] = ACTIONS(2549),
    [anon_sym_unorm] = ACTIONS(2549),
    [anon_sym_point] = ACTIONS(2549),
    [anon_sym_line] = ACTIONS(2549),
    [anon_sym_triangleadj] = ACTIONS(2549),
    [anon_sym_lineadj] = ACTIONS(2549),
    [anon_sym_triangle] = ACTIONS(2549),
    [anon_sym_cbuffer] = ACTIONS(2549),
  },
  [568] = {
    [sym_identifier] = ACTIONS(2404),
    [aux_sym_preproc_include_token1] = ACTIONS(2404),
    [aux_sym_preproc_def_token1] = ACTIONS(2404),
    [aux_sym_preproc_if_token1] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2404),
    [sym_preproc_directive] = ACTIONS(2404),
    [anon_sym_LPAREN2] = ACTIONS(2406),
    [anon_sym_BANG] = ACTIONS(2406),
    [anon_sym_TILDE] = ACTIONS(2406),
    [anon_sym_DASH] = ACTIONS(2404),
    [anon_sym_PLUS] = ACTIONS(2404),
    [anon_sym_STAR] = ACTIONS(2406),
    [anon_sym_AMP_AMP] = ACTIONS(2406),
    [anon_sym_AMP] = ACTIONS(2404),
    [anon_sym_SEMI] = ACTIONS(2406),
    [anon_sym___extension__] = ACTIONS(2404),
    [anon_sym_typedef] = ACTIONS(2404),
    [anon_sym_in] = ACTIONS(2404),
    [anon_sym_out] = ACTIONS(2404),
    [anon_sym_inout] = ACTIONS(2404),
    [anon_sym_extern] = ACTIONS(2404),
    [anon_sym___attribute__] = ACTIONS(2404),
    [anon_sym_COLON_COLON] = ACTIONS(2406),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2406),
    [anon_sym___declspec] = ACTIONS(2404),
    [anon_sym___based] = ACTIONS(2404),
    [anon_sym___cdecl] = ACTIONS(2404),
    [anon_sym___clrcall] = ACTIONS(2404),
    [anon_sym___stdcall] = ACTIONS(2404),
    [anon_sym___fastcall] = ACTIONS(2404),
    [anon_sym___thiscall] = ACTIONS(2404),
    [anon_sym___vectorcall] = ACTIONS(2404),
    [anon_sym_LBRACE] = ACTIONS(2406),
    [anon_sym_RBRACE] = ACTIONS(2406),
    [anon_sym_signed] = ACTIONS(2404),
    [anon_sym_unsigned] = ACTIONS(2404),
    [anon_sym_long] = ACTIONS(2404),
    [anon_sym_short] = ACTIONS(2404),
    [anon_sym_LBRACK] = ACTIONS(2404),
    [anon_sym_static] = ACTIONS(2404),
    [anon_sym_register] = ACTIONS(2404),
    [anon_sym_inline] = ACTIONS(2404),
    [anon_sym___inline] = ACTIONS(2404),
    [anon_sym___inline__] = ACTIONS(2404),
    [anon_sym___forceinline] = ACTIONS(2404),
    [anon_sym_thread_local] = ACTIONS(2404),
    [anon_sym___thread] = ACTIONS(2404),
    [anon_sym_const] = ACTIONS(2404),
    [anon_sym_constexpr] = ACTIONS(2404),
    [anon_sym_volatile] = ACTIONS(2404),
    [anon_sym_restrict] = ACTIONS(2404),
    [anon_sym___restrict__] = ACTIONS(2404),
    [anon_sym__Atomic] = ACTIONS(2404),
    [anon_sym__Noreturn] = ACTIONS(2404),
    [anon_sym_noreturn] = ACTIONS(2404),
    [anon_sym_mutable] = ACTIONS(2404),
    [anon_sym_constinit] = ACTIONS(2404),
    [anon_sym_consteval] = ACTIONS(2404),
    [anon_sym_alignas] = ACTIONS(2404),
    [anon_sym__Alignas] = ACTIONS(2404),
    [sym_primitive_type] = ACTIONS(2404),
    [anon_sym_enum] = ACTIONS(2404),
    [anon_sym_class] = ACTIONS(2404),
    [anon_sym_struct] = ACTIONS(2404),
    [anon_sym_union] = ACTIONS(2404),
    [anon_sym_if] = ACTIONS(2404),
    [anon_sym_switch] = ACTIONS(2404),
    [anon_sym_case] = ACTIONS(2404),
    [anon_sym_default] = ACTIONS(2404),
    [anon_sym_while] = ACTIONS(2404),
    [anon_sym_do] = ACTIONS(2404),
    [anon_sym_for] = ACTIONS(2404),
    [anon_sym_return] = ACTIONS(2404),
    [anon_sym_break] = ACTIONS(2404),
    [anon_sym_continue] = ACTIONS(2404),
    [anon_sym_goto] = ACTIONS(2404),
    [anon_sym___try] = ACTIONS(2404),
    [anon_sym___leave] = ACTIONS(2404),
    [anon_sym_not] = ACTIONS(2404),
    [anon_sym_compl] = ACTIONS(2404),
    [anon_sym_DASH_DASH] = ACTIONS(2406),
    [anon_sym_PLUS_PLUS] = ACTIONS(2406),
    [anon_sym_sizeof] = ACTIONS(2404),
    [anon_sym___alignof__] = ACTIONS(2404),
    [anon_sym___alignof] = ACTIONS(2404),
    [anon_sym__alignof] = ACTIONS(2404),
    [anon_sym_alignof] = ACTIONS(2404),
    [anon_sym__Alignof] = ACTIONS(2404),
    [anon_sym_offsetof] = ACTIONS(2404),
    [anon_sym__Generic] = ACTIONS(2404),
    [anon_sym_asm] = ACTIONS(2404),
    [anon_sym___asm__] = ACTIONS(2404),
    [sym_number_literal] = ACTIONS(2406),
    [anon_sym_L_SQUOTE] = ACTIONS(2406),
    [anon_sym_u_SQUOTE] = ACTIONS(2406),
    [anon_sym_U_SQUOTE] = ACTIONS(2406),
    [anon_sym_u8_SQUOTE] = ACTIONS(2406),
    [anon_sym_SQUOTE] = ACTIONS(2406),
    [anon_sym_L_DQUOTE] = ACTIONS(2406),
    [anon_sym_u_DQUOTE] = ACTIONS(2406),
    [anon_sym_U_DQUOTE] = ACTIONS(2406),
    [anon_sym_u8_DQUOTE] = ACTIONS(2406),
    [anon_sym_DQUOTE] = ACTIONS(2406),
    [sym_true] = ACTIONS(2404),
    [sym_false] = ACTIONS(2404),
    [anon_sym_NULL] = ACTIONS(2404),
    [anon_sym_nullptr] = ACTIONS(2404),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2404),
    [anon_sym_decltype] = ACTIONS(2404),
    [sym_virtual] = ACTIONS(2404),
    [anon_sym_explicit] = ACTIONS(2404),
    [anon_sym_typename] = ACTIONS(2404),
    [anon_sym_template] = ACTIONS(2404),
    [anon_sym_operator] = ACTIONS(2404),
    [anon_sym_try] = ACTIONS(2404),
    [anon_sym_delete] = ACTIONS(2404),
    [anon_sym_throw] = ACTIONS(2404),
    [anon_sym_namespace] = ACTIONS(2404),
    [anon_sym_using] = ACTIONS(2404),
    [anon_sym_static_assert] = ACTIONS(2404),
    [anon_sym_concept] = ACTIONS(2404),
    [anon_sym_co_return] = ACTIONS(2404),
    [anon_sym_co_yield] = ACTIONS(2404),
    [anon_sym_R_DQUOTE] = ACTIONS(2406),
    [anon_sym_LR_DQUOTE] = ACTIONS(2406),
    [anon_sym_uR_DQUOTE] = ACTIONS(2406),
    [anon_sym_UR_DQUOTE] = ACTIONS(2406),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2406),
    [anon_sym_co_await] = ACTIONS(2404),
    [anon_sym_new] = ACTIONS(2404),
    [anon_sym_requires] = ACTIONS(2404),
    [sym_this] = ACTIONS(2404),
    [anon_sym_discard] = ACTIONS(2404),
    [anon_sym_precise] = ACTIONS(2404),
    [anon_sym_shared] = ACTIONS(2404),
    [anon_sym_groupshared] = ACTIONS(2404),
    [anon_sym_uniform] = ACTIONS(2404),
    [anon_sym_row_major] = ACTIONS(2404),
    [anon_sym_column_major] = ACTIONS(2404),
    [anon_sym_globallycoherent] = ACTIONS(2404),
    [anon_sym_centroid] = ACTIONS(2404),
    [anon_sym_noperspective] = ACTIONS(2404),
    [anon_sym_nointerpolation] = ACTIONS(2404),
    [anon_sym_sample] = ACTIONS(2404),
    [anon_sym_linear] = ACTIONS(2404),
    [anon_sym_snorm] = ACTIONS(2404),
    [anon_sym_unorm] = ACTIONS(2404),
    [anon_sym_point] = ACTIONS(2404),
    [anon_sym_line] = ACTIONS(2404),
    [anon_sym_triangleadj] = ACTIONS(2404),
    [anon_sym_lineadj] = ACTIONS(2404),
    [anon_sym_triangle] = ACTIONS(2404),
    [anon_sym_cbuffer] = ACTIONS(2404),
  },
  [569] = {
    [sym_identifier] = ACTIONS(2404),
    [aux_sym_preproc_include_token1] = ACTIONS(2404),
    [aux_sym_preproc_def_token1] = ACTIONS(2404),
    [aux_sym_preproc_if_token1] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2404),
    [sym_preproc_directive] = ACTIONS(2404),
    [anon_sym_LPAREN2] = ACTIONS(2406),
    [anon_sym_BANG] = ACTIONS(2406),
    [anon_sym_TILDE] = ACTIONS(2406),
    [anon_sym_DASH] = ACTIONS(2404),
    [anon_sym_PLUS] = ACTIONS(2404),
    [anon_sym_STAR] = ACTIONS(2406),
    [anon_sym_AMP_AMP] = ACTIONS(2406),
    [anon_sym_AMP] = ACTIONS(2404),
    [anon_sym_SEMI] = ACTIONS(2406),
    [anon_sym___extension__] = ACTIONS(2404),
    [anon_sym_typedef] = ACTIONS(2404),
    [anon_sym_in] = ACTIONS(2404),
    [anon_sym_out] = ACTIONS(2404),
    [anon_sym_inout] = ACTIONS(2404),
    [anon_sym_extern] = ACTIONS(2404),
    [anon_sym___attribute__] = ACTIONS(2404),
    [anon_sym_COLON_COLON] = ACTIONS(2406),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2406),
    [anon_sym___declspec] = ACTIONS(2404),
    [anon_sym___based] = ACTIONS(2404),
    [anon_sym___cdecl] = ACTIONS(2404),
    [anon_sym___clrcall] = ACTIONS(2404),
    [anon_sym___stdcall] = ACTIONS(2404),
    [anon_sym___fastcall] = ACTIONS(2404),
    [anon_sym___thiscall] = ACTIONS(2404),
    [anon_sym___vectorcall] = ACTIONS(2404),
    [anon_sym_LBRACE] = ACTIONS(2406),
    [anon_sym_RBRACE] = ACTIONS(2406),
    [anon_sym_signed] = ACTIONS(2404),
    [anon_sym_unsigned] = ACTIONS(2404),
    [anon_sym_long] = ACTIONS(2404),
    [anon_sym_short] = ACTIONS(2404),
    [anon_sym_LBRACK] = ACTIONS(2404),
    [anon_sym_static] = ACTIONS(2404),
    [anon_sym_register] = ACTIONS(2404),
    [anon_sym_inline] = ACTIONS(2404),
    [anon_sym___inline] = ACTIONS(2404),
    [anon_sym___inline__] = ACTIONS(2404),
    [anon_sym___forceinline] = ACTIONS(2404),
    [anon_sym_thread_local] = ACTIONS(2404),
    [anon_sym___thread] = ACTIONS(2404),
    [anon_sym_const] = ACTIONS(2404),
    [anon_sym_constexpr] = ACTIONS(2404),
    [anon_sym_volatile] = ACTIONS(2404),
    [anon_sym_restrict] = ACTIONS(2404),
    [anon_sym___restrict__] = ACTIONS(2404),
    [anon_sym__Atomic] = ACTIONS(2404),
    [anon_sym__Noreturn] = ACTIONS(2404),
    [anon_sym_noreturn] = ACTIONS(2404),
    [anon_sym_mutable] = ACTIONS(2404),
    [anon_sym_constinit] = ACTIONS(2404),
    [anon_sym_consteval] = ACTIONS(2404),
    [anon_sym_alignas] = ACTIONS(2404),
    [anon_sym__Alignas] = ACTIONS(2404),
    [sym_primitive_type] = ACTIONS(2404),
    [anon_sym_enum] = ACTIONS(2404),
    [anon_sym_class] = ACTIONS(2404),
    [anon_sym_struct] = ACTIONS(2404),
    [anon_sym_union] = ACTIONS(2404),
    [anon_sym_if] = ACTIONS(2404),
    [anon_sym_switch] = ACTIONS(2404),
    [anon_sym_case] = ACTIONS(2404),
    [anon_sym_default] = ACTIONS(2404),
    [anon_sym_while] = ACTIONS(2404),
    [anon_sym_do] = ACTIONS(2404),
    [anon_sym_for] = ACTIONS(2404),
    [anon_sym_return] = ACTIONS(2404),
    [anon_sym_break] = ACTIONS(2404),
    [anon_sym_continue] = ACTIONS(2404),
    [anon_sym_goto] = ACTIONS(2404),
    [anon_sym___try] = ACTIONS(2404),
    [anon_sym___leave] = ACTIONS(2404),
    [anon_sym_not] = ACTIONS(2404),
    [anon_sym_compl] = ACTIONS(2404),
    [anon_sym_DASH_DASH] = ACTIONS(2406),
    [anon_sym_PLUS_PLUS] = ACTIONS(2406),
    [anon_sym_sizeof] = ACTIONS(2404),
    [anon_sym___alignof__] = ACTIONS(2404),
    [anon_sym___alignof] = ACTIONS(2404),
    [anon_sym__alignof] = ACTIONS(2404),
    [anon_sym_alignof] = ACTIONS(2404),
    [anon_sym__Alignof] = ACTIONS(2404),
    [anon_sym_offsetof] = ACTIONS(2404),
    [anon_sym__Generic] = ACTIONS(2404),
    [anon_sym_asm] = ACTIONS(2404),
    [anon_sym___asm__] = ACTIONS(2404),
    [sym_number_literal] = ACTIONS(2406),
    [anon_sym_L_SQUOTE] = ACTIONS(2406),
    [anon_sym_u_SQUOTE] = ACTIONS(2406),
    [anon_sym_U_SQUOTE] = ACTIONS(2406),
    [anon_sym_u8_SQUOTE] = ACTIONS(2406),
    [anon_sym_SQUOTE] = ACTIONS(2406),
    [anon_sym_L_DQUOTE] = ACTIONS(2406),
    [anon_sym_u_DQUOTE] = ACTIONS(2406),
    [anon_sym_U_DQUOTE] = ACTIONS(2406),
    [anon_sym_u8_DQUOTE] = ACTIONS(2406),
    [anon_sym_DQUOTE] = ACTIONS(2406),
    [sym_true] = ACTIONS(2404),
    [sym_false] = ACTIONS(2404),
    [anon_sym_NULL] = ACTIONS(2404),
    [anon_sym_nullptr] = ACTIONS(2404),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2404),
    [anon_sym_decltype] = ACTIONS(2404),
    [sym_virtual] = ACTIONS(2404),
    [anon_sym_explicit] = ACTIONS(2404),
    [anon_sym_typename] = ACTIONS(2404),
    [anon_sym_template] = ACTIONS(2404),
    [anon_sym_operator] = ACTIONS(2404),
    [anon_sym_try] = ACTIONS(2404),
    [anon_sym_delete] = ACTIONS(2404),
    [anon_sym_throw] = ACTIONS(2404),
    [anon_sym_namespace] = ACTIONS(2404),
    [anon_sym_using] = ACTIONS(2404),
    [anon_sym_static_assert] = ACTIONS(2404),
    [anon_sym_concept] = ACTIONS(2404),
    [anon_sym_co_return] = ACTIONS(2404),
    [anon_sym_co_yield] = ACTIONS(2404),
    [anon_sym_R_DQUOTE] = ACTIONS(2406),
    [anon_sym_LR_DQUOTE] = ACTIONS(2406),
    [anon_sym_uR_DQUOTE] = ACTIONS(2406),
    [anon_sym_UR_DQUOTE] = ACTIONS(2406),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2406),
    [anon_sym_co_await] = ACTIONS(2404),
    [anon_sym_new] = ACTIONS(2404),
    [anon_sym_requires] = ACTIONS(2404),
    [sym_this] = ACTIONS(2404),
    [anon_sym_discard] = ACTIONS(2404),
    [anon_sym_precise] = ACTIONS(2404),
    [anon_sym_shared] = ACTIONS(2404),
    [anon_sym_groupshared] = ACTIONS(2404),
    [anon_sym_uniform] = ACTIONS(2404),
    [anon_sym_row_major] = ACTIONS(2404),
    [anon_sym_column_major] = ACTIONS(2404),
    [anon_sym_globallycoherent] = ACTIONS(2404),
    [anon_sym_centroid] = ACTIONS(2404),
    [anon_sym_noperspective] = ACTIONS(2404),
    [anon_sym_nointerpolation] = ACTIONS(2404),
    [anon_sym_sample] = ACTIONS(2404),
    [anon_sym_linear] = ACTIONS(2404),
    [anon_sym_snorm] = ACTIONS(2404),
    [anon_sym_unorm] = ACTIONS(2404),
    [anon_sym_point] = ACTIONS(2404),
    [anon_sym_line] = ACTIONS(2404),
    [anon_sym_triangleadj] = ACTIONS(2404),
    [anon_sym_lineadj] = ACTIONS(2404),
    [anon_sym_triangle] = ACTIONS(2404),
    [anon_sym_cbuffer] = ACTIONS(2404),
  },
  [570] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_include_token1] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_BANG] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_DASH] = ACTIONS(2324),
    [anon_sym_PLUS] = ACTIONS(2324),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym_SEMI] = ACTIONS(2326),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym___cdecl] = ACTIONS(2324),
    [anon_sym___clrcall] = ACTIONS(2324),
    [anon_sym___stdcall] = ACTIONS(2324),
    [anon_sym___fastcall] = ACTIONS(2324),
    [anon_sym___thiscall] = ACTIONS(2324),
    [anon_sym___vectorcall] = ACTIONS(2324),
    [anon_sym_LBRACE] = ACTIONS(2326),
    [anon_sym_RBRACE] = ACTIONS(2326),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [anon_sym_if] = ACTIONS(2324),
    [anon_sym_switch] = ACTIONS(2324),
    [anon_sym_case] = ACTIONS(2324),
    [anon_sym_default] = ACTIONS(2324),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_do] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2324),
    [anon_sym_return] = ACTIONS(2324),
    [anon_sym_break] = ACTIONS(2324),
    [anon_sym_continue] = ACTIONS(2324),
    [anon_sym_goto] = ACTIONS(2324),
    [anon_sym___try] = ACTIONS(2324),
    [anon_sym___leave] = ACTIONS(2324),
    [anon_sym_not] = ACTIONS(2324),
    [anon_sym_compl] = ACTIONS(2324),
    [anon_sym_DASH_DASH] = ACTIONS(2326),
    [anon_sym_PLUS_PLUS] = ACTIONS(2326),
    [anon_sym_sizeof] = ACTIONS(2324),
    [anon_sym___alignof__] = ACTIONS(2324),
    [anon_sym___alignof] = ACTIONS(2324),
    [anon_sym__alignof] = ACTIONS(2324),
    [anon_sym_alignof] = ACTIONS(2324),
    [anon_sym__Alignof] = ACTIONS(2324),
    [anon_sym_offsetof] = ACTIONS(2324),
    [anon_sym__Generic] = ACTIONS(2324),
    [anon_sym_asm] = ACTIONS(2324),
    [anon_sym___asm__] = ACTIONS(2324),
    [sym_number_literal] = ACTIONS(2326),
    [anon_sym_L_SQUOTE] = ACTIONS(2326),
    [anon_sym_u_SQUOTE] = ACTIONS(2326),
    [anon_sym_U_SQUOTE] = ACTIONS(2326),
    [anon_sym_u8_SQUOTE] = ACTIONS(2326),
    [anon_sym_SQUOTE] = ACTIONS(2326),
    [anon_sym_L_DQUOTE] = ACTIONS(2326),
    [anon_sym_u_DQUOTE] = ACTIONS(2326),
    [anon_sym_U_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8_DQUOTE] = ACTIONS(2326),
    [anon_sym_DQUOTE] = ACTIONS(2326),
    [sym_true] = ACTIONS(2324),
    [sym_false] = ACTIONS(2324),
    [anon_sym_NULL] = ACTIONS(2324),
    [anon_sym_nullptr] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_try] = ACTIONS(2324),
    [anon_sym_delete] = ACTIONS(2324),
    [anon_sym_throw] = ACTIONS(2324),
    [anon_sym_namespace] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_concept] = ACTIONS(2324),
    [anon_sym_co_return] = ACTIONS(2324),
    [anon_sym_co_yield] = ACTIONS(2324),
    [anon_sym_R_DQUOTE] = ACTIONS(2326),
    [anon_sym_LR_DQUOTE] = ACTIONS(2326),
    [anon_sym_uR_DQUOTE] = ACTIONS(2326),
    [anon_sym_UR_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2326),
    [anon_sym_co_await] = ACTIONS(2324),
    [anon_sym_new] = ACTIONS(2324),
    [anon_sym_requires] = ACTIONS(2324),
    [sym_this] = ACTIONS(2324),
    [anon_sym_discard] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
    [anon_sym_cbuffer] = ACTIONS(2324),
  },
  [571] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_include_token1] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token2] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_BANG] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_DASH] = ACTIONS(2324),
    [anon_sym_PLUS] = ACTIONS(2324),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym_SEMI] = ACTIONS(2326),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym___cdecl] = ACTIONS(2324),
    [anon_sym___clrcall] = ACTIONS(2324),
    [anon_sym___stdcall] = ACTIONS(2324),
    [anon_sym___fastcall] = ACTIONS(2324),
    [anon_sym___thiscall] = ACTIONS(2324),
    [anon_sym___vectorcall] = ACTIONS(2324),
    [anon_sym_LBRACE] = ACTIONS(2326),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [anon_sym_if] = ACTIONS(2324),
    [anon_sym_switch] = ACTIONS(2324),
    [anon_sym_case] = ACTIONS(2324),
    [anon_sym_default] = ACTIONS(2324),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_do] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2324),
    [anon_sym_return] = ACTIONS(2324),
    [anon_sym_break] = ACTIONS(2324),
    [anon_sym_continue] = ACTIONS(2324),
    [anon_sym_goto] = ACTIONS(2324),
    [anon_sym___try] = ACTIONS(2324),
    [anon_sym___leave] = ACTIONS(2324),
    [anon_sym_not] = ACTIONS(2324),
    [anon_sym_compl] = ACTIONS(2324),
    [anon_sym_DASH_DASH] = ACTIONS(2326),
    [anon_sym_PLUS_PLUS] = ACTIONS(2326),
    [anon_sym_sizeof] = ACTIONS(2324),
    [anon_sym___alignof__] = ACTIONS(2324),
    [anon_sym___alignof] = ACTIONS(2324),
    [anon_sym__alignof] = ACTIONS(2324),
    [anon_sym_alignof] = ACTIONS(2324),
    [anon_sym__Alignof] = ACTIONS(2324),
    [anon_sym_offsetof] = ACTIONS(2324),
    [anon_sym__Generic] = ACTIONS(2324),
    [anon_sym_asm] = ACTIONS(2324),
    [anon_sym___asm__] = ACTIONS(2324),
    [sym_number_literal] = ACTIONS(2326),
    [anon_sym_L_SQUOTE] = ACTIONS(2326),
    [anon_sym_u_SQUOTE] = ACTIONS(2326),
    [anon_sym_U_SQUOTE] = ACTIONS(2326),
    [anon_sym_u8_SQUOTE] = ACTIONS(2326),
    [anon_sym_SQUOTE] = ACTIONS(2326),
    [anon_sym_L_DQUOTE] = ACTIONS(2326),
    [anon_sym_u_DQUOTE] = ACTIONS(2326),
    [anon_sym_U_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8_DQUOTE] = ACTIONS(2326),
    [anon_sym_DQUOTE] = ACTIONS(2326),
    [sym_true] = ACTIONS(2324),
    [sym_false] = ACTIONS(2324),
    [anon_sym_NULL] = ACTIONS(2324),
    [anon_sym_nullptr] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_try] = ACTIONS(2324),
    [anon_sym_delete] = ACTIONS(2324),
    [anon_sym_throw] = ACTIONS(2324),
    [anon_sym_namespace] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_concept] = ACTIONS(2324),
    [anon_sym_co_return] = ACTIONS(2324),
    [anon_sym_co_yield] = ACTIONS(2324),
    [anon_sym_R_DQUOTE] = ACTIONS(2326),
    [anon_sym_LR_DQUOTE] = ACTIONS(2326),
    [anon_sym_uR_DQUOTE] = ACTIONS(2326),
    [anon_sym_UR_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2326),
    [anon_sym_co_await] = ACTIONS(2324),
    [anon_sym_new] = ACTIONS(2324),
    [anon_sym_requires] = ACTIONS(2324),
    [sym_this] = ACTIONS(2324),
    [anon_sym_discard] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
    [anon_sym_cbuffer] = ACTIONS(2324),
  },
  [572] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_include_token1] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_BANG] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_DASH] = ACTIONS(2324),
    [anon_sym_PLUS] = ACTIONS(2324),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym_SEMI] = ACTIONS(2326),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym___cdecl] = ACTIONS(2324),
    [anon_sym___clrcall] = ACTIONS(2324),
    [anon_sym___stdcall] = ACTIONS(2324),
    [anon_sym___fastcall] = ACTIONS(2324),
    [anon_sym___thiscall] = ACTIONS(2324),
    [anon_sym___vectorcall] = ACTIONS(2324),
    [anon_sym_LBRACE] = ACTIONS(2326),
    [anon_sym_RBRACE] = ACTIONS(2326),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [anon_sym_if] = ACTIONS(2324),
    [anon_sym_switch] = ACTIONS(2324),
    [anon_sym_case] = ACTIONS(2324),
    [anon_sym_default] = ACTIONS(2324),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_do] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2324),
    [anon_sym_return] = ACTIONS(2324),
    [anon_sym_break] = ACTIONS(2324),
    [anon_sym_continue] = ACTIONS(2324),
    [anon_sym_goto] = ACTIONS(2324),
    [anon_sym___try] = ACTIONS(2324),
    [anon_sym___leave] = ACTIONS(2324),
    [anon_sym_not] = ACTIONS(2324),
    [anon_sym_compl] = ACTIONS(2324),
    [anon_sym_DASH_DASH] = ACTIONS(2326),
    [anon_sym_PLUS_PLUS] = ACTIONS(2326),
    [anon_sym_sizeof] = ACTIONS(2324),
    [anon_sym___alignof__] = ACTIONS(2324),
    [anon_sym___alignof] = ACTIONS(2324),
    [anon_sym__alignof] = ACTIONS(2324),
    [anon_sym_alignof] = ACTIONS(2324),
    [anon_sym__Alignof] = ACTIONS(2324),
    [anon_sym_offsetof] = ACTIONS(2324),
    [anon_sym__Generic] = ACTIONS(2324),
    [anon_sym_asm] = ACTIONS(2324),
    [anon_sym___asm__] = ACTIONS(2324),
    [sym_number_literal] = ACTIONS(2326),
    [anon_sym_L_SQUOTE] = ACTIONS(2326),
    [anon_sym_u_SQUOTE] = ACTIONS(2326),
    [anon_sym_U_SQUOTE] = ACTIONS(2326),
    [anon_sym_u8_SQUOTE] = ACTIONS(2326),
    [anon_sym_SQUOTE] = ACTIONS(2326),
    [anon_sym_L_DQUOTE] = ACTIONS(2326),
    [anon_sym_u_DQUOTE] = ACTIONS(2326),
    [anon_sym_U_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8_DQUOTE] = ACTIONS(2326),
    [anon_sym_DQUOTE] = ACTIONS(2326),
    [sym_true] = ACTIONS(2324),
    [sym_false] = ACTIONS(2324),
    [anon_sym_NULL] = ACTIONS(2324),
    [anon_sym_nullptr] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_try] = ACTIONS(2324),
    [anon_sym_delete] = ACTIONS(2324),
    [anon_sym_throw] = ACTIONS(2324),
    [anon_sym_namespace] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_concept] = ACTIONS(2324),
    [anon_sym_co_return] = ACTIONS(2324),
    [anon_sym_co_yield] = ACTIONS(2324),
    [anon_sym_R_DQUOTE] = ACTIONS(2326),
    [anon_sym_LR_DQUOTE] = ACTIONS(2326),
    [anon_sym_uR_DQUOTE] = ACTIONS(2326),
    [anon_sym_UR_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2326),
    [anon_sym_co_await] = ACTIONS(2324),
    [anon_sym_new] = ACTIONS(2324),
    [anon_sym_requires] = ACTIONS(2324),
    [sym_this] = ACTIONS(2324),
    [anon_sym_discard] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
    [anon_sym_cbuffer] = ACTIONS(2324),
  },
  [573] = {
    [sym_identifier] = ACTIONS(2320),
    [aux_sym_preproc_include_token1] = ACTIONS(2320),
    [aux_sym_preproc_def_token1] = ACTIONS(2320),
    [aux_sym_preproc_if_token1] = ACTIONS(2320),
    [aux_sym_preproc_if_token2] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2320),
    [sym_preproc_directive] = ACTIONS(2320),
    [anon_sym_LPAREN2] = ACTIONS(2322),
    [anon_sym_BANG] = ACTIONS(2322),
    [anon_sym_TILDE] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2322),
    [anon_sym_AMP_AMP] = ACTIONS(2322),
    [anon_sym_AMP] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym___extension__] = ACTIONS(2320),
    [anon_sym_typedef] = ACTIONS(2320),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_out] = ACTIONS(2320),
    [anon_sym_inout] = ACTIONS(2320),
    [anon_sym_extern] = ACTIONS(2320),
    [anon_sym___attribute__] = ACTIONS(2320),
    [anon_sym_COLON_COLON] = ACTIONS(2322),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2322),
    [anon_sym___declspec] = ACTIONS(2320),
    [anon_sym___based] = ACTIONS(2320),
    [anon_sym___cdecl] = ACTIONS(2320),
    [anon_sym___clrcall] = ACTIONS(2320),
    [anon_sym___stdcall] = ACTIONS(2320),
    [anon_sym___fastcall] = ACTIONS(2320),
    [anon_sym___thiscall] = ACTIONS(2320),
    [anon_sym___vectorcall] = ACTIONS(2320),
    [anon_sym_LBRACE] = ACTIONS(2322),
    [anon_sym_signed] = ACTIONS(2320),
    [anon_sym_unsigned] = ACTIONS(2320),
    [anon_sym_long] = ACTIONS(2320),
    [anon_sym_short] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2320),
    [anon_sym_static] = ACTIONS(2320),
    [anon_sym_register] = ACTIONS(2320),
    [anon_sym_inline] = ACTIONS(2320),
    [anon_sym___inline] = ACTIONS(2320),
    [anon_sym___inline__] = ACTIONS(2320),
    [anon_sym___forceinline] = ACTIONS(2320),
    [anon_sym_thread_local] = ACTIONS(2320),
    [anon_sym___thread] = ACTIONS(2320),
    [anon_sym_const] = ACTIONS(2320),
    [anon_sym_constexpr] = ACTIONS(2320),
    [anon_sym_volatile] = ACTIONS(2320),
    [anon_sym_restrict] = ACTIONS(2320),
    [anon_sym___restrict__] = ACTIONS(2320),
    [anon_sym__Atomic] = ACTIONS(2320),
    [anon_sym__Noreturn] = ACTIONS(2320),
    [anon_sym_noreturn] = ACTIONS(2320),
    [anon_sym_mutable] = ACTIONS(2320),
    [anon_sym_constinit] = ACTIONS(2320),
    [anon_sym_consteval] = ACTIONS(2320),
    [anon_sym_alignas] = ACTIONS(2320),
    [anon_sym__Alignas] = ACTIONS(2320),
    [sym_primitive_type] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_class] = ACTIONS(2320),
    [anon_sym_struct] = ACTIONS(2320),
    [anon_sym_union] = ACTIONS(2320),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_switch] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_default] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_do] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_return] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_goto] = ACTIONS(2320),
    [anon_sym___try] = ACTIONS(2320),
    [anon_sym___leave] = ACTIONS(2320),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_compl] = ACTIONS(2320),
    [anon_sym_DASH_DASH] = ACTIONS(2322),
    [anon_sym_PLUS_PLUS] = ACTIONS(2322),
    [anon_sym_sizeof] = ACTIONS(2320),
    [anon_sym___alignof__] = ACTIONS(2320),
    [anon_sym___alignof] = ACTIONS(2320),
    [anon_sym__alignof] = ACTIONS(2320),
    [anon_sym_alignof] = ACTIONS(2320),
    [anon_sym__Alignof] = ACTIONS(2320),
    [anon_sym_offsetof] = ACTIONS(2320),
    [anon_sym__Generic] = ACTIONS(2320),
    [anon_sym_asm] = ACTIONS(2320),
    [anon_sym___asm__] = ACTIONS(2320),
    [sym_number_literal] = ACTIONS(2322),
    [anon_sym_L_SQUOTE] = ACTIONS(2322),
    [anon_sym_u_SQUOTE] = ACTIONS(2322),
    [anon_sym_U_SQUOTE] = ACTIONS(2322),
    [anon_sym_u8_SQUOTE] = ACTIONS(2322),
    [anon_sym_SQUOTE] = ACTIONS(2322),
    [anon_sym_L_DQUOTE] = ACTIONS(2322),
    [anon_sym_u_DQUOTE] = ACTIONS(2322),
    [anon_sym_U_DQUOTE] = ACTIONS(2322),
    [anon_sym_u8_DQUOTE] = ACTIONS(2322),
    [anon_sym_DQUOTE] = ACTIONS(2322),
    [sym_true] = ACTIONS(2320),
    [sym_false] = ACTIONS(2320),
    [anon_sym_NULL] = ACTIONS(2320),
    [anon_sym_nullptr] = ACTIONS(2320),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2320),
    [anon_sym_decltype] = ACTIONS(2320),
    [sym_virtual] = ACTIONS(2320),
    [anon_sym_explicit] = ACTIONS(2320),
    [anon_sym_typename] = ACTIONS(2320),
    [anon_sym_template] = ACTIONS(2320),
    [anon_sym_operator] = ACTIONS(2320),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_delete] = ACTIONS(2320),
    [anon_sym_throw] = ACTIONS(2320),
    [anon_sym_namespace] = ACTIONS(2320),
    [anon_sym_using] = ACTIONS(2320),
    [anon_sym_static_assert] = ACTIONS(2320),
    [anon_sym_concept] = ACTIONS(2320),
    [anon_sym_co_return] = ACTIONS(2320),
    [anon_sym_co_yield] = ACTIONS(2320),
    [anon_sym_R_DQUOTE] = ACTIONS(2322),
    [anon_sym_LR_DQUOTE] = ACTIONS(2322),
    [anon_sym_uR_DQUOTE] = ACTIONS(2322),
    [anon_sym_UR_DQUOTE] = ACTIONS(2322),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2322),
    [anon_sym_co_await] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(2320),
    [anon_sym_requires] = ACTIONS(2320),
    [sym_this] = ACTIONS(2320),
    [anon_sym_discard] = ACTIONS(2320),
    [anon_sym_precise] = ACTIONS(2320),
    [anon_sym_shared] = ACTIONS(2320),
    [anon_sym_groupshared] = ACTIONS(2320),
    [anon_sym_uniform] = ACTIONS(2320),
    [anon_sym_row_major] = ACTIONS(2320),
    [anon_sym_column_major] = ACTIONS(2320),
    [anon_sym_globallycoherent] = ACTIONS(2320),
    [anon_sym_centroid] = ACTIONS(2320),
    [anon_sym_noperspective] = ACTIONS(2320),
    [anon_sym_nointerpolation] = ACTIONS(2320),
    [anon_sym_sample] = ACTIONS(2320),
    [anon_sym_linear] = ACTIONS(2320),
    [anon_sym_snorm] = ACTIONS(2320),
    [anon_sym_unorm] = ACTIONS(2320),
    [anon_sym_point] = ACTIONS(2320),
    [anon_sym_line] = ACTIONS(2320),
    [anon_sym_triangleadj] = ACTIONS(2320),
    [anon_sym_lineadj] = ACTIONS(2320),
    [anon_sym_triangle] = ACTIONS(2320),
    [anon_sym_cbuffer] = ACTIONS(2320),
  },
  [574] = {
    [sym_identifier] = ACTIONS(2304),
    [aux_sym_preproc_include_token1] = ACTIONS(2304),
    [aux_sym_preproc_def_token1] = ACTIONS(2304),
    [aux_sym_preproc_if_token1] = ACTIONS(2304),
    [aux_sym_preproc_if_token2] = ACTIONS(2304),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2304),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2304),
    [sym_preproc_directive] = ACTIONS(2304),
    [anon_sym_LPAREN2] = ACTIONS(2306),
    [anon_sym_BANG] = ACTIONS(2306),
    [anon_sym_TILDE] = ACTIONS(2306),
    [anon_sym_DASH] = ACTIONS(2304),
    [anon_sym_PLUS] = ACTIONS(2304),
    [anon_sym_STAR] = ACTIONS(2306),
    [anon_sym_AMP_AMP] = ACTIONS(2306),
    [anon_sym_AMP] = ACTIONS(2304),
    [anon_sym_SEMI] = ACTIONS(2306),
    [anon_sym___extension__] = ACTIONS(2304),
    [anon_sym_typedef] = ACTIONS(2304),
    [anon_sym_in] = ACTIONS(2304),
    [anon_sym_out] = ACTIONS(2304),
    [anon_sym_inout] = ACTIONS(2304),
    [anon_sym_extern] = ACTIONS(2304),
    [anon_sym___attribute__] = ACTIONS(2304),
    [anon_sym_COLON_COLON] = ACTIONS(2306),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2306),
    [anon_sym___declspec] = ACTIONS(2304),
    [anon_sym___based] = ACTIONS(2304),
    [anon_sym___cdecl] = ACTIONS(2304),
    [anon_sym___clrcall] = ACTIONS(2304),
    [anon_sym___stdcall] = ACTIONS(2304),
    [anon_sym___fastcall] = ACTIONS(2304),
    [anon_sym___thiscall] = ACTIONS(2304),
    [anon_sym___vectorcall] = ACTIONS(2304),
    [anon_sym_LBRACE] = ACTIONS(2306),
    [anon_sym_signed] = ACTIONS(2304),
    [anon_sym_unsigned] = ACTIONS(2304),
    [anon_sym_long] = ACTIONS(2304),
    [anon_sym_short] = ACTIONS(2304),
    [anon_sym_LBRACK] = ACTIONS(2304),
    [anon_sym_static] = ACTIONS(2304),
    [anon_sym_register] = ACTIONS(2304),
    [anon_sym_inline] = ACTIONS(2304),
    [anon_sym___inline] = ACTIONS(2304),
    [anon_sym___inline__] = ACTIONS(2304),
    [anon_sym___forceinline] = ACTIONS(2304),
    [anon_sym_thread_local] = ACTIONS(2304),
    [anon_sym___thread] = ACTIONS(2304),
    [anon_sym_const] = ACTIONS(2304),
    [anon_sym_constexpr] = ACTIONS(2304),
    [anon_sym_volatile] = ACTIONS(2304),
    [anon_sym_restrict] = ACTIONS(2304),
    [anon_sym___restrict__] = ACTIONS(2304),
    [anon_sym__Atomic] = ACTIONS(2304),
    [anon_sym__Noreturn] = ACTIONS(2304),
    [anon_sym_noreturn] = ACTIONS(2304),
    [anon_sym_mutable] = ACTIONS(2304),
    [anon_sym_constinit] = ACTIONS(2304),
    [anon_sym_consteval] = ACTIONS(2304),
    [anon_sym_alignas] = ACTIONS(2304),
    [anon_sym__Alignas] = ACTIONS(2304),
    [sym_primitive_type] = ACTIONS(2304),
    [anon_sym_enum] = ACTIONS(2304),
    [anon_sym_class] = ACTIONS(2304),
    [anon_sym_struct] = ACTIONS(2304),
    [anon_sym_union] = ACTIONS(2304),
    [anon_sym_if] = ACTIONS(2304),
    [anon_sym_switch] = ACTIONS(2304),
    [anon_sym_case] = ACTIONS(2304),
    [anon_sym_default] = ACTIONS(2304),
    [anon_sym_while] = ACTIONS(2304),
    [anon_sym_do] = ACTIONS(2304),
    [anon_sym_for] = ACTIONS(2304),
    [anon_sym_return] = ACTIONS(2304),
    [anon_sym_break] = ACTIONS(2304),
    [anon_sym_continue] = ACTIONS(2304),
    [anon_sym_goto] = ACTIONS(2304),
    [anon_sym___try] = ACTIONS(2304),
    [anon_sym___leave] = ACTIONS(2304),
    [anon_sym_not] = ACTIONS(2304),
    [anon_sym_compl] = ACTIONS(2304),
    [anon_sym_DASH_DASH] = ACTIONS(2306),
    [anon_sym_PLUS_PLUS] = ACTIONS(2306),
    [anon_sym_sizeof] = ACTIONS(2304),
    [anon_sym___alignof__] = ACTIONS(2304),
    [anon_sym___alignof] = ACTIONS(2304),
    [anon_sym__alignof] = ACTIONS(2304),
    [anon_sym_alignof] = ACTIONS(2304),
    [anon_sym__Alignof] = ACTIONS(2304),
    [anon_sym_offsetof] = ACTIONS(2304),
    [anon_sym__Generic] = ACTIONS(2304),
    [anon_sym_asm] = ACTIONS(2304),
    [anon_sym___asm__] = ACTIONS(2304),
    [sym_number_literal] = ACTIONS(2306),
    [anon_sym_L_SQUOTE] = ACTIONS(2306),
    [anon_sym_u_SQUOTE] = ACTIONS(2306),
    [anon_sym_U_SQUOTE] = ACTIONS(2306),
    [anon_sym_u8_SQUOTE] = ACTIONS(2306),
    [anon_sym_SQUOTE] = ACTIONS(2306),
    [anon_sym_L_DQUOTE] = ACTIONS(2306),
    [anon_sym_u_DQUOTE] = ACTIONS(2306),
    [anon_sym_U_DQUOTE] = ACTIONS(2306),
    [anon_sym_u8_DQUOTE] = ACTIONS(2306),
    [anon_sym_DQUOTE] = ACTIONS(2306),
    [sym_true] = ACTIONS(2304),
    [sym_false] = ACTIONS(2304),
    [anon_sym_NULL] = ACTIONS(2304),
    [anon_sym_nullptr] = ACTIONS(2304),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2304),
    [anon_sym_decltype] = ACTIONS(2304),
    [sym_virtual] = ACTIONS(2304),
    [anon_sym_explicit] = ACTIONS(2304),
    [anon_sym_typename] = ACTIONS(2304),
    [anon_sym_template] = ACTIONS(2304),
    [anon_sym_operator] = ACTIONS(2304),
    [anon_sym_try] = ACTIONS(2304),
    [anon_sym_delete] = ACTIONS(2304),
    [anon_sym_throw] = ACTIONS(2304),
    [anon_sym_namespace] = ACTIONS(2304),
    [anon_sym_using] = ACTIONS(2304),
    [anon_sym_static_assert] = ACTIONS(2304),
    [anon_sym_concept] = ACTIONS(2304),
    [anon_sym_co_return] = ACTIONS(2304),
    [anon_sym_co_yield] = ACTIONS(2304),
    [anon_sym_R_DQUOTE] = ACTIONS(2306),
    [anon_sym_LR_DQUOTE] = ACTIONS(2306),
    [anon_sym_uR_DQUOTE] = ACTIONS(2306),
    [anon_sym_UR_DQUOTE] = ACTIONS(2306),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2306),
    [anon_sym_co_await] = ACTIONS(2304),
    [anon_sym_new] = ACTIONS(2304),
    [anon_sym_requires] = ACTIONS(2304),
    [sym_this] = ACTIONS(2304),
    [anon_sym_discard] = ACTIONS(2304),
    [anon_sym_precise] = ACTIONS(2304),
    [anon_sym_shared] = ACTIONS(2304),
    [anon_sym_groupshared] = ACTIONS(2304),
    [anon_sym_uniform] = ACTIONS(2304),
    [anon_sym_row_major] = ACTIONS(2304),
    [anon_sym_column_major] = ACTIONS(2304),
    [anon_sym_globallycoherent] = ACTIONS(2304),
    [anon_sym_centroid] = ACTIONS(2304),
    [anon_sym_noperspective] = ACTIONS(2304),
    [anon_sym_nointerpolation] = ACTIONS(2304),
    [anon_sym_sample] = ACTIONS(2304),
    [anon_sym_linear] = ACTIONS(2304),
    [anon_sym_snorm] = ACTIONS(2304),
    [anon_sym_unorm] = ACTIONS(2304),
    [anon_sym_point] = ACTIONS(2304),
    [anon_sym_line] = ACTIONS(2304),
    [anon_sym_triangleadj] = ACTIONS(2304),
    [anon_sym_lineadj] = ACTIONS(2304),
    [anon_sym_triangle] = ACTIONS(2304),
    [anon_sym_cbuffer] = ACTIONS(2304),
  },
  [575] = {
    [sym_identifier] = ACTIONS(2300),
    [aux_sym_preproc_include_token1] = ACTIONS(2300),
    [aux_sym_preproc_def_token1] = ACTIONS(2300),
    [aux_sym_preproc_if_token1] = ACTIONS(2300),
    [aux_sym_preproc_if_token2] = ACTIONS(2300),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2300),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2300),
    [sym_preproc_directive] = ACTIONS(2300),
    [anon_sym_LPAREN2] = ACTIONS(2302),
    [anon_sym_BANG] = ACTIONS(2302),
    [anon_sym_TILDE] = ACTIONS(2302),
    [anon_sym_DASH] = ACTIONS(2300),
    [anon_sym_PLUS] = ACTIONS(2300),
    [anon_sym_STAR] = ACTIONS(2302),
    [anon_sym_AMP_AMP] = ACTIONS(2302),
    [anon_sym_AMP] = ACTIONS(2300),
    [anon_sym_SEMI] = ACTIONS(2302),
    [anon_sym___extension__] = ACTIONS(2300),
    [anon_sym_typedef] = ACTIONS(2300),
    [anon_sym_in] = ACTIONS(2300),
    [anon_sym_out] = ACTIONS(2300),
    [anon_sym_inout] = ACTIONS(2300),
    [anon_sym_extern] = ACTIONS(2300),
    [anon_sym___attribute__] = ACTIONS(2300),
    [anon_sym_COLON_COLON] = ACTIONS(2302),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2302),
    [anon_sym___declspec] = ACTIONS(2300),
    [anon_sym___based] = ACTIONS(2300),
    [anon_sym___cdecl] = ACTIONS(2300),
    [anon_sym___clrcall] = ACTIONS(2300),
    [anon_sym___stdcall] = ACTIONS(2300),
    [anon_sym___fastcall] = ACTIONS(2300),
    [anon_sym___thiscall] = ACTIONS(2300),
    [anon_sym___vectorcall] = ACTIONS(2300),
    [anon_sym_LBRACE] = ACTIONS(2302),
    [anon_sym_signed] = ACTIONS(2300),
    [anon_sym_unsigned] = ACTIONS(2300),
    [anon_sym_long] = ACTIONS(2300),
    [anon_sym_short] = ACTIONS(2300),
    [anon_sym_LBRACK] = ACTIONS(2300),
    [anon_sym_static] = ACTIONS(2300),
    [anon_sym_register] = ACTIONS(2300),
    [anon_sym_inline] = ACTIONS(2300),
    [anon_sym___inline] = ACTIONS(2300),
    [anon_sym___inline__] = ACTIONS(2300),
    [anon_sym___forceinline] = ACTIONS(2300),
    [anon_sym_thread_local] = ACTIONS(2300),
    [anon_sym___thread] = ACTIONS(2300),
    [anon_sym_const] = ACTIONS(2300),
    [anon_sym_constexpr] = ACTIONS(2300),
    [anon_sym_volatile] = ACTIONS(2300),
    [anon_sym_restrict] = ACTIONS(2300),
    [anon_sym___restrict__] = ACTIONS(2300),
    [anon_sym__Atomic] = ACTIONS(2300),
    [anon_sym__Noreturn] = ACTIONS(2300),
    [anon_sym_noreturn] = ACTIONS(2300),
    [anon_sym_mutable] = ACTIONS(2300),
    [anon_sym_constinit] = ACTIONS(2300),
    [anon_sym_consteval] = ACTIONS(2300),
    [anon_sym_alignas] = ACTIONS(2300),
    [anon_sym__Alignas] = ACTIONS(2300),
    [sym_primitive_type] = ACTIONS(2300),
    [anon_sym_enum] = ACTIONS(2300),
    [anon_sym_class] = ACTIONS(2300),
    [anon_sym_struct] = ACTIONS(2300),
    [anon_sym_union] = ACTIONS(2300),
    [anon_sym_if] = ACTIONS(2300),
    [anon_sym_switch] = ACTIONS(2300),
    [anon_sym_case] = ACTIONS(2300),
    [anon_sym_default] = ACTIONS(2300),
    [anon_sym_while] = ACTIONS(2300),
    [anon_sym_do] = ACTIONS(2300),
    [anon_sym_for] = ACTIONS(2300),
    [anon_sym_return] = ACTIONS(2300),
    [anon_sym_break] = ACTIONS(2300),
    [anon_sym_continue] = ACTIONS(2300),
    [anon_sym_goto] = ACTIONS(2300),
    [anon_sym___try] = ACTIONS(2300),
    [anon_sym___leave] = ACTIONS(2300),
    [anon_sym_not] = ACTIONS(2300),
    [anon_sym_compl] = ACTIONS(2300),
    [anon_sym_DASH_DASH] = ACTIONS(2302),
    [anon_sym_PLUS_PLUS] = ACTIONS(2302),
    [anon_sym_sizeof] = ACTIONS(2300),
    [anon_sym___alignof__] = ACTIONS(2300),
    [anon_sym___alignof] = ACTIONS(2300),
    [anon_sym__alignof] = ACTIONS(2300),
    [anon_sym_alignof] = ACTIONS(2300),
    [anon_sym__Alignof] = ACTIONS(2300),
    [anon_sym_offsetof] = ACTIONS(2300),
    [anon_sym__Generic] = ACTIONS(2300),
    [anon_sym_asm] = ACTIONS(2300),
    [anon_sym___asm__] = ACTIONS(2300),
    [sym_number_literal] = ACTIONS(2302),
    [anon_sym_L_SQUOTE] = ACTIONS(2302),
    [anon_sym_u_SQUOTE] = ACTIONS(2302),
    [anon_sym_U_SQUOTE] = ACTIONS(2302),
    [anon_sym_u8_SQUOTE] = ACTIONS(2302),
    [anon_sym_SQUOTE] = ACTIONS(2302),
    [anon_sym_L_DQUOTE] = ACTIONS(2302),
    [anon_sym_u_DQUOTE] = ACTIONS(2302),
    [anon_sym_U_DQUOTE] = ACTIONS(2302),
    [anon_sym_u8_DQUOTE] = ACTIONS(2302),
    [anon_sym_DQUOTE] = ACTIONS(2302),
    [sym_true] = ACTIONS(2300),
    [sym_false] = ACTIONS(2300),
    [anon_sym_NULL] = ACTIONS(2300),
    [anon_sym_nullptr] = ACTIONS(2300),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2300),
    [anon_sym_decltype] = ACTIONS(2300),
    [sym_virtual] = ACTIONS(2300),
    [anon_sym_explicit] = ACTIONS(2300),
    [anon_sym_typename] = ACTIONS(2300),
    [anon_sym_template] = ACTIONS(2300),
    [anon_sym_operator] = ACTIONS(2300),
    [anon_sym_try] = ACTIONS(2300),
    [anon_sym_delete] = ACTIONS(2300),
    [anon_sym_throw] = ACTIONS(2300),
    [anon_sym_namespace] = ACTIONS(2300),
    [anon_sym_using] = ACTIONS(2300),
    [anon_sym_static_assert] = ACTIONS(2300),
    [anon_sym_concept] = ACTIONS(2300),
    [anon_sym_co_return] = ACTIONS(2300),
    [anon_sym_co_yield] = ACTIONS(2300),
    [anon_sym_R_DQUOTE] = ACTIONS(2302),
    [anon_sym_LR_DQUOTE] = ACTIONS(2302),
    [anon_sym_uR_DQUOTE] = ACTIONS(2302),
    [anon_sym_UR_DQUOTE] = ACTIONS(2302),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2302),
    [anon_sym_co_await] = ACTIONS(2300),
    [anon_sym_new] = ACTIONS(2300),
    [anon_sym_requires] = ACTIONS(2300),
    [sym_this] = ACTIONS(2300),
    [anon_sym_discard] = ACTIONS(2300),
    [anon_sym_precise] = ACTIONS(2300),
    [anon_sym_shared] = ACTIONS(2300),
    [anon_sym_groupshared] = ACTIONS(2300),
    [anon_sym_uniform] = ACTIONS(2300),
    [anon_sym_row_major] = ACTIONS(2300),
    [anon_sym_column_major] = ACTIONS(2300),
    [anon_sym_globallycoherent] = ACTIONS(2300),
    [anon_sym_centroid] = ACTIONS(2300),
    [anon_sym_noperspective] = ACTIONS(2300),
    [anon_sym_nointerpolation] = ACTIONS(2300),
    [anon_sym_sample] = ACTIONS(2300),
    [anon_sym_linear] = ACTIONS(2300),
    [anon_sym_snorm] = ACTIONS(2300),
    [anon_sym_unorm] = ACTIONS(2300),
    [anon_sym_point] = ACTIONS(2300),
    [anon_sym_line] = ACTIONS(2300),
    [anon_sym_triangleadj] = ACTIONS(2300),
    [anon_sym_lineadj] = ACTIONS(2300),
    [anon_sym_triangle] = ACTIONS(2300),
    [anon_sym_cbuffer] = ACTIONS(2300),
  },
  [576] = {
    [sym_identifier] = ACTIONS(2524),
    [aux_sym_preproc_include_token1] = ACTIONS(2524),
    [aux_sym_preproc_def_token1] = ACTIONS(2524),
    [aux_sym_preproc_if_token1] = ACTIONS(2524),
    [aux_sym_preproc_if_token2] = ACTIONS(2524),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2524),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2524),
    [sym_preproc_directive] = ACTIONS(2524),
    [anon_sym_LPAREN2] = ACTIONS(2526),
    [anon_sym_BANG] = ACTIONS(2526),
    [anon_sym_TILDE] = ACTIONS(2526),
    [anon_sym_DASH] = ACTIONS(2524),
    [anon_sym_PLUS] = ACTIONS(2524),
    [anon_sym_STAR] = ACTIONS(2526),
    [anon_sym_AMP_AMP] = ACTIONS(2526),
    [anon_sym_AMP] = ACTIONS(2524),
    [anon_sym_SEMI] = ACTIONS(2526),
    [anon_sym___extension__] = ACTIONS(2524),
    [anon_sym_typedef] = ACTIONS(2524),
    [anon_sym_in] = ACTIONS(2524),
    [anon_sym_out] = ACTIONS(2524),
    [anon_sym_inout] = ACTIONS(2524),
    [anon_sym_extern] = ACTIONS(2524),
    [anon_sym___attribute__] = ACTIONS(2524),
    [anon_sym_COLON_COLON] = ACTIONS(2526),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2526),
    [anon_sym___declspec] = ACTIONS(2524),
    [anon_sym___based] = ACTIONS(2524),
    [anon_sym___cdecl] = ACTIONS(2524),
    [anon_sym___clrcall] = ACTIONS(2524),
    [anon_sym___stdcall] = ACTIONS(2524),
    [anon_sym___fastcall] = ACTIONS(2524),
    [anon_sym___thiscall] = ACTIONS(2524),
    [anon_sym___vectorcall] = ACTIONS(2524),
    [anon_sym_LBRACE] = ACTIONS(2526),
    [anon_sym_signed] = ACTIONS(2524),
    [anon_sym_unsigned] = ACTIONS(2524),
    [anon_sym_long] = ACTIONS(2524),
    [anon_sym_short] = ACTIONS(2524),
    [anon_sym_LBRACK] = ACTIONS(2524),
    [anon_sym_static] = ACTIONS(2524),
    [anon_sym_register] = ACTIONS(2524),
    [anon_sym_inline] = ACTIONS(2524),
    [anon_sym___inline] = ACTIONS(2524),
    [anon_sym___inline__] = ACTIONS(2524),
    [anon_sym___forceinline] = ACTIONS(2524),
    [anon_sym_thread_local] = ACTIONS(2524),
    [anon_sym___thread] = ACTIONS(2524),
    [anon_sym_const] = ACTIONS(2524),
    [anon_sym_constexpr] = ACTIONS(2524),
    [anon_sym_volatile] = ACTIONS(2524),
    [anon_sym_restrict] = ACTIONS(2524),
    [anon_sym___restrict__] = ACTIONS(2524),
    [anon_sym__Atomic] = ACTIONS(2524),
    [anon_sym__Noreturn] = ACTIONS(2524),
    [anon_sym_noreturn] = ACTIONS(2524),
    [anon_sym_mutable] = ACTIONS(2524),
    [anon_sym_constinit] = ACTIONS(2524),
    [anon_sym_consteval] = ACTIONS(2524),
    [anon_sym_alignas] = ACTIONS(2524),
    [anon_sym__Alignas] = ACTIONS(2524),
    [sym_primitive_type] = ACTIONS(2524),
    [anon_sym_enum] = ACTIONS(2524),
    [anon_sym_class] = ACTIONS(2524),
    [anon_sym_struct] = ACTIONS(2524),
    [anon_sym_union] = ACTIONS(2524),
    [anon_sym_if] = ACTIONS(2524),
    [anon_sym_switch] = ACTIONS(2524),
    [anon_sym_case] = ACTIONS(2524),
    [anon_sym_default] = ACTIONS(2524),
    [anon_sym_while] = ACTIONS(2524),
    [anon_sym_do] = ACTIONS(2524),
    [anon_sym_for] = ACTIONS(2524),
    [anon_sym_return] = ACTIONS(2524),
    [anon_sym_break] = ACTIONS(2524),
    [anon_sym_continue] = ACTIONS(2524),
    [anon_sym_goto] = ACTIONS(2524),
    [anon_sym___try] = ACTIONS(2524),
    [anon_sym___leave] = ACTIONS(2524),
    [anon_sym_not] = ACTIONS(2524),
    [anon_sym_compl] = ACTIONS(2524),
    [anon_sym_DASH_DASH] = ACTIONS(2526),
    [anon_sym_PLUS_PLUS] = ACTIONS(2526),
    [anon_sym_sizeof] = ACTIONS(2524),
    [anon_sym___alignof__] = ACTIONS(2524),
    [anon_sym___alignof] = ACTIONS(2524),
    [anon_sym__alignof] = ACTIONS(2524),
    [anon_sym_alignof] = ACTIONS(2524),
    [anon_sym__Alignof] = ACTIONS(2524),
    [anon_sym_offsetof] = ACTIONS(2524),
    [anon_sym__Generic] = ACTIONS(2524),
    [anon_sym_asm] = ACTIONS(2524),
    [anon_sym___asm__] = ACTIONS(2524),
    [sym_number_literal] = ACTIONS(2526),
    [anon_sym_L_SQUOTE] = ACTIONS(2526),
    [anon_sym_u_SQUOTE] = ACTIONS(2526),
    [anon_sym_U_SQUOTE] = ACTIONS(2526),
    [anon_sym_u8_SQUOTE] = ACTIONS(2526),
    [anon_sym_SQUOTE] = ACTIONS(2526),
    [anon_sym_L_DQUOTE] = ACTIONS(2526),
    [anon_sym_u_DQUOTE] = ACTIONS(2526),
    [anon_sym_U_DQUOTE] = ACTIONS(2526),
    [anon_sym_u8_DQUOTE] = ACTIONS(2526),
    [anon_sym_DQUOTE] = ACTIONS(2526),
    [sym_true] = ACTIONS(2524),
    [sym_false] = ACTIONS(2524),
    [anon_sym_NULL] = ACTIONS(2524),
    [anon_sym_nullptr] = ACTIONS(2524),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2524),
    [anon_sym_decltype] = ACTIONS(2524),
    [sym_virtual] = ACTIONS(2524),
    [anon_sym_explicit] = ACTIONS(2524),
    [anon_sym_typename] = ACTIONS(2524),
    [anon_sym_template] = ACTIONS(2524),
    [anon_sym_operator] = ACTIONS(2524),
    [anon_sym_try] = ACTIONS(2524),
    [anon_sym_delete] = ACTIONS(2524),
    [anon_sym_throw] = ACTIONS(2524),
    [anon_sym_namespace] = ACTIONS(2524),
    [anon_sym_using] = ACTIONS(2524),
    [anon_sym_static_assert] = ACTIONS(2524),
    [anon_sym_concept] = ACTIONS(2524),
    [anon_sym_co_return] = ACTIONS(2524),
    [anon_sym_co_yield] = ACTIONS(2524),
    [anon_sym_R_DQUOTE] = ACTIONS(2526),
    [anon_sym_LR_DQUOTE] = ACTIONS(2526),
    [anon_sym_uR_DQUOTE] = ACTIONS(2526),
    [anon_sym_UR_DQUOTE] = ACTIONS(2526),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2526),
    [anon_sym_co_await] = ACTIONS(2524),
    [anon_sym_new] = ACTIONS(2524),
    [anon_sym_requires] = ACTIONS(2524),
    [sym_this] = ACTIONS(2524),
    [anon_sym_discard] = ACTIONS(2524),
    [anon_sym_precise] = ACTIONS(2524),
    [anon_sym_shared] = ACTIONS(2524),
    [anon_sym_groupshared] = ACTIONS(2524),
    [anon_sym_uniform] = ACTIONS(2524),
    [anon_sym_row_major] = ACTIONS(2524),
    [anon_sym_column_major] = ACTIONS(2524),
    [anon_sym_globallycoherent] = ACTIONS(2524),
    [anon_sym_centroid] = ACTIONS(2524),
    [anon_sym_noperspective] = ACTIONS(2524),
    [anon_sym_nointerpolation] = ACTIONS(2524),
    [anon_sym_sample] = ACTIONS(2524),
    [anon_sym_linear] = ACTIONS(2524),
    [anon_sym_snorm] = ACTIONS(2524),
    [anon_sym_unorm] = ACTIONS(2524),
    [anon_sym_point] = ACTIONS(2524),
    [anon_sym_line] = ACTIONS(2524),
    [anon_sym_triangleadj] = ACTIONS(2524),
    [anon_sym_lineadj] = ACTIONS(2524),
    [anon_sym_triangle] = ACTIONS(2524),
    [anon_sym_cbuffer] = ACTIONS(2524),
  },
  [577] = {
    [sym_identifier] = ACTIONS(2528),
    [aux_sym_preproc_include_token1] = ACTIONS(2528),
    [aux_sym_preproc_def_token1] = ACTIONS(2528),
    [aux_sym_preproc_if_token1] = ACTIONS(2528),
    [aux_sym_preproc_if_token2] = ACTIONS(2528),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2528),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2528),
    [sym_preproc_directive] = ACTIONS(2528),
    [anon_sym_LPAREN2] = ACTIONS(2530),
    [anon_sym_BANG] = ACTIONS(2530),
    [anon_sym_TILDE] = ACTIONS(2530),
    [anon_sym_DASH] = ACTIONS(2528),
    [anon_sym_PLUS] = ACTIONS(2528),
    [anon_sym_STAR] = ACTIONS(2530),
    [anon_sym_AMP_AMP] = ACTIONS(2530),
    [anon_sym_AMP] = ACTIONS(2528),
    [anon_sym_SEMI] = ACTIONS(2530),
    [anon_sym___extension__] = ACTIONS(2528),
    [anon_sym_typedef] = ACTIONS(2528),
    [anon_sym_in] = ACTIONS(2528),
    [anon_sym_out] = ACTIONS(2528),
    [anon_sym_inout] = ACTIONS(2528),
    [anon_sym_extern] = ACTIONS(2528),
    [anon_sym___attribute__] = ACTIONS(2528),
    [anon_sym_COLON_COLON] = ACTIONS(2530),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2530),
    [anon_sym___declspec] = ACTIONS(2528),
    [anon_sym___based] = ACTIONS(2528),
    [anon_sym___cdecl] = ACTIONS(2528),
    [anon_sym___clrcall] = ACTIONS(2528),
    [anon_sym___stdcall] = ACTIONS(2528),
    [anon_sym___fastcall] = ACTIONS(2528),
    [anon_sym___thiscall] = ACTIONS(2528),
    [anon_sym___vectorcall] = ACTIONS(2528),
    [anon_sym_LBRACE] = ACTIONS(2530),
    [anon_sym_signed] = ACTIONS(2528),
    [anon_sym_unsigned] = ACTIONS(2528),
    [anon_sym_long] = ACTIONS(2528),
    [anon_sym_short] = ACTIONS(2528),
    [anon_sym_LBRACK] = ACTIONS(2528),
    [anon_sym_static] = ACTIONS(2528),
    [anon_sym_register] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(2528),
    [anon_sym___inline] = ACTIONS(2528),
    [anon_sym___inline__] = ACTIONS(2528),
    [anon_sym___forceinline] = ACTIONS(2528),
    [anon_sym_thread_local] = ACTIONS(2528),
    [anon_sym___thread] = ACTIONS(2528),
    [anon_sym_const] = ACTIONS(2528),
    [anon_sym_constexpr] = ACTIONS(2528),
    [anon_sym_volatile] = ACTIONS(2528),
    [anon_sym_restrict] = ACTIONS(2528),
    [anon_sym___restrict__] = ACTIONS(2528),
    [anon_sym__Atomic] = ACTIONS(2528),
    [anon_sym__Noreturn] = ACTIONS(2528),
    [anon_sym_noreturn] = ACTIONS(2528),
    [anon_sym_mutable] = ACTIONS(2528),
    [anon_sym_constinit] = ACTIONS(2528),
    [anon_sym_consteval] = ACTIONS(2528),
    [anon_sym_alignas] = ACTIONS(2528),
    [anon_sym__Alignas] = ACTIONS(2528),
    [sym_primitive_type] = ACTIONS(2528),
    [anon_sym_enum] = ACTIONS(2528),
    [anon_sym_class] = ACTIONS(2528),
    [anon_sym_struct] = ACTIONS(2528),
    [anon_sym_union] = ACTIONS(2528),
    [anon_sym_if] = ACTIONS(2528),
    [anon_sym_switch] = ACTIONS(2528),
    [anon_sym_case] = ACTIONS(2528),
    [anon_sym_default] = ACTIONS(2528),
    [anon_sym_while] = ACTIONS(2528),
    [anon_sym_do] = ACTIONS(2528),
    [anon_sym_for] = ACTIONS(2528),
    [anon_sym_return] = ACTIONS(2528),
    [anon_sym_break] = ACTIONS(2528),
    [anon_sym_continue] = ACTIONS(2528),
    [anon_sym_goto] = ACTIONS(2528),
    [anon_sym___try] = ACTIONS(2528),
    [anon_sym___leave] = ACTIONS(2528),
    [anon_sym_not] = ACTIONS(2528),
    [anon_sym_compl] = ACTIONS(2528),
    [anon_sym_DASH_DASH] = ACTIONS(2530),
    [anon_sym_PLUS_PLUS] = ACTIONS(2530),
    [anon_sym_sizeof] = ACTIONS(2528),
    [anon_sym___alignof__] = ACTIONS(2528),
    [anon_sym___alignof] = ACTIONS(2528),
    [anon_sym__alignof] = ACTIONS(2528),
    [anon_sym_alignof] = ACTIONS(2528),
    [anon_sym__Alignof] = ACTIONS(2528),
    [anon_sym_offsetof] = ACTIONS(2528),
    [anon_sym__Generic] = ACTIONS(2528),
    [anon_sym_asm] = ACTIONS(2528),
    [anon_sym___asm__] = ACTIONS(2528),
    [sym_number_literal] = ACTIONS(2530),
    [anon_sym_L_SQUOTE] = ACTIONS(2530),
    [anon_sym_u_SQUOTE] = ACTIONS(2530),
    [anon_sym_U_SQUOTE] = ACTIONS(2530),
    [anon_sym_u8_SQUOTE] = ACTIONS(2530),
    [anon_sym_SQUOTE] = ACTIONS(2530),
    [anon_sym_L_DQUOTE] = ACTIONS(2530),
    [anon_sym_u_DQUOTE] = ACTIONS(2530),
    [anon_sym_U_DQUOTE] = ACTIONS(2530),
    [anon_sym_u8_DQUOTE] = ACTIONS(2530),
    [anon_sym_DQUOTE] = ACTIONS(2530),
    [sym_true] = ACTIONS(2528),
    [sym_false] = ACTIONS(2528),
    [anon_sym_NULL] = ACTIONS(2528),
    [anon_sym_nullptr] = ACTIONS(2528),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2528),
    [anon_sym_decltype] = ACTIONS(2528),
    [sym_virtual] = ACTIONS(2528),
    [anon_sym_explicit] = ACTIONS(2528),
    [anon_sym_typename] = ACTIONS(2528),
    [anon_sym_template] = ACTIONS(2528),
    [anon_sym_operator] = ACTIONS(2528),
    [anon_sym_try] = ACTIONS(2528),
    [anon_sym_delete] = ACTIONS(2528),
    [anon_sym_throw] = ACTIONS(2528),
    [anon_sym_namespace] = ACTIONS(2528),
    [anon_sym_using] = ACTIONS(2528),
    [anon_sym_static_assert] = ACTIONS(2528),
    [anon_sym_concept] = ACTIONS(2528),
    [anon_sym_co_return] = ACTIONS(2528),
    [anon_sym_co_yield] = ACTIONS(2528),
    [anon_sym_R_DQUOTE] = ACTIONS(2530),
    [anon_sym_LR_DQUOTE] = ACTIONS(2530),
    [anon_sym_uR_DQUOTE] = ACTIONS(2530),
    [anon_sym_UR_DQUOTE] = ACTIONS(2530),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2530),
    [anon_sym_co_await] = ACTIONS(2528),
    [anon_sym_new] = ACTIONS(2528),
    [anon_sym_requires] = ACTIONS(2528),
    [sym_this] = ACTIONS(2528),
    [anon_sym_discard] = ACTIONS(2528),
    [anon_sym_precise] = ACTIONS(2528),
    [anon_sym_shared] = ACTIONS(2528),
    [anon_sym_groupshared] = ACTIONS(2528),
    [anon_sym_uniform] = ACTIONS(2528),
    [anon_sym_row_major] = ACTIONS(2528),
    [anon_sym_column_major] = ACTIONS(2528),
    [anon_sym_globallycoherent] = ACTIONS(2528),
    [anon_sym_centroid] = ACTIONS(2528),
    [anon_sym_noperspective] = ACTIONS(2528),
    [anon_sym_nointerpolation] = ACTIONS(2528),
    [anon_sym_sample] = ACTIONS(2528),
    [anon_sym_linear] = ACTIONS(2528),
    [anon_sym_snorm] = ACTIONS(2528),
    [anon_sym_unorm] = ACTIONS(2528),
    [anon_sym_point] = ACTIONS(2528),
    [anon_sym_line] = ACTIONS(2528),
    [anon_sym_triangleadj] = ACTIONS(2528),
    [anon_sym_lineadj] = ACTIONS(2528),
    [anon_sym_triangle] = ACTIONS(2528),
    [anon_sym_cbuffer] = ACTIONS(2528),
  },
  [578] = {
    [sym_identifier] = ACTIONS(2506),
    [aux_sym_preproc_include_token1] = ACTIONS(2506),
    [aux_sym_preproc_def_token1] = ACTIONS(2506),
    [aux_sym_preproc_if_token1] = ACTIONS(2506),
    [aux_sym_preproc_if_token2] = ACTIONS(2506),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2506),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2506),
    [sym_preproc_directive] = ACTIONS(2506),
    [anon_sym_LPAREN2] = ACTIONS(2508),
    [anon_sym_BANG] = ACTIONS(2508),
    [anon_sym_TILDE] = ACTIONS(2508),
    [anon_sym_DASH] = ACTIONS(2506),
    [anon_sym_PLUS] = ACTIONS(2506),
    [anon_sym_STAR] = ACTIONS(2508),
    [anon_sym_AMP_AMP] = ACTIONS(2508),
    [anon_sym_AMP] = ACTIONS(2506),
    [anon_sym_SEMI] = ACTIONS(2508),
    [anon_sym___extension__] = ACTIONS(2506),
    [anon_sym_typedef] = ACTIONS(2506),
    [anon_sym_in] = ACTIONS(2506),
    [anon_sym_out] = ACTIONS(2506),
    [anon_sym_inout] = ACTIONS(2506),
    [anon_sym_extern] = ACTIONS(2506),
    [anon_sym___attribute__] = ACTIONS(2506),
    [anon_sym_COLON_COLON] = ACTIONS(2508),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2508),
    [anon_sym___declspec] = ACTIONS(2506),
    [anon_sym___based] = ACTIONS(2506),
    [anon_sym___cdecl] = ACTIONS(2506),
    [anon_sym___clrcall] = ACTIONS(2506),
    [anon_sym___stdcall] = ACTIONS(2506),
    [anon_sym___fastcall] = ACTIONS(2506),
    [anon_sym___thiscall] = ACTIONS(2506),
    [anon_sym___vectorcall] = ACTIONS(2506),
    [anon_sym_LBRACE] = ACTIONS(2508),
    [anon_sym_signed] = ACTIONS(2506),
    [anon_sym_unsigned] = ACTIONS(2506),
    [anon_sym_long] = ACTIONS(2506),
    [anon_sym_short] = ACTIONS(2506),
    [anon_sym_LBRACK] = ACTIONS(2506),
    [anon_sym_static] = ACTIONS(2506),
    [anon_sym_register] = ACTIONS(2506),
    [anon_sym_inline] = ACTIONS(2506),
    [anon_sym___inline] = ACTIONS(2506),
    [anon_sym___inline__] = ACTIONS(2506),
    [anon_sym___forceinline] = ACTIONS(2506),
    [anon_sym_thread_local] = ACTIONS(2506),
    [anon_sym___thread] = ACTIONS(2506),
    [anon_sym_const] = ACTIONS(2506),
    [anon_sym_constexpr] = ACTIONS(2506),
    [anon_sym_volatile] = ACTIONS(2506),
    [anon_sym_restrict] = ACTIONS(2506),
    [anon_sym___restrict__] = ACTIONS(2506),
    [anon_sym__Atomic] = ACTIONS(2506),
    [anon_sym__Noreturn] = ACTIONS(2506),
    [anon_sym_noreturn] = ACTIONS(2506),
    [anon_sym_mutable] = ACTIONS(2506),
    [anon_sym_constinit] = ACTIONS(2506),
    [anon_sym_consteval] = ACTIONS(2506),
    [anon_sym_alignas] = ACTIONS(2506),
    [anon_sym__Alignas] = ACTIONS(2506),
    [sym_primitive_type] = ACTIONS(2506),
    [anon_sym_enum] = ACTIONS(2506),
    [anon_sym_class] = ACTIONS(2506),
    [anon_sym_struct] = ACTIONS(2506),
    [anon_sym_union] = ACTIONS(2506),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_switch] = ACTIONS(2506),
    [anon_sym_case] = ACTIONS(2506),
    [anon_sym_default] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(2506),
    [anon_sym_do] = ACTIONS(2506),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_return] = ACTIONS(2506),
    [anon_sym_break] = ACTIONS(2506),
    [anon_sym_continue] = ACTIONS(2506),
    [anon_sym_goto] = ACTIONS(2506),
    [anon_sym___try] = ACTIONS(2506),
    [anon_sym___leave] = ACTIONS(2506),
    [anon_sym_not] = ACTIONS(2506),
    [anon_sym_compl] = ACTIONS(2506),
    [anon_sym_DASH_DASH] = ACTIONS(2508),
    [anon_sym_PLUS_PLUS] = ACTIONS(2508),
    [anon_sym_sizeof] = ACTIONS(2506),
    [anon_sym___alignof__] = ACTIONS(2506),
    [anon_sym___alignof] = ACTIONS(2506),
    [anon_sym__alignof] = ACTIONS(2506),
    [anon_sym_alignof] = ACTIONS(2506),
    [anon_sym__Alignof] = ACTIONS(2506),
    [anon_sym_offsetof] = ACTIONS(2506),
    [anon_sym__Generic] = ACTIONS(2506),
    [anon_sym_asm] = ACTIONS(2506),
    [anon_sym___asm__] = ACTIONS(2506),
    [sym_number_literal] = ACTIONS(2508),
    [anon_sym_L_SQUOTE] = ACTIONS(2508),
    [anon_sym_u_SQUOTE] = ACTIONS(2508),
    [anon_sym_U_SQUOTE] = ACTIONS(2508),
    [anon_sym_u8_SQUOTE] = ACTIONS(2508),
    [anon_sym_SQUOTE] = ACTIONS(2508),
    [anon_sym_L_DQUOTE] = ACTIONS(2508),
    [anon_sym_u_DQUOTE] = ACTIONS(2508),
    [anon_sym_U_DQUOTE] = ACTIONS(2508),
    [anon_sym_u8_DQUOTE] = ACTIONS(2508),
    [anon_sym_DQUOTE] = ACTIONS(2508),
    [sym_true] = ACTIONS(2506),
    [sym_false] = ACTIONS(2506),
    [anon_sym_NULL] = ACTIONS(2506),
    [anon_sym_nullptr] = ACTIONS(2506),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2506),
    [anon_sym_decltype] = ACTIONS(2506),
    [sym_virtual] = ACTIONS(2506),
    [anon_sym_explicit] = ACTIONS(2506),
    [anon_sym_typename] = ACTIONS(2506),
    [anon_sym_template] = ACTIONS(2506),
    [anon_sym_operator] = ACTIONS(2506),
    [anon_sym_try] = ACTIONS(2506),
    [anon_sym_delete] = ACTIONS(2506),
    [anon_sym_throw] = ACTIONS(2506),
    [anon_sym_namespace] = ACTIONS(2506),
    [anon_sym_using] = ACTIONS(2506),
    [anon_sym_static_assert] = ACTIONS(2506),
    [anon_sym_concept] = ACTIONS(2506),
    [anon_sym_co_return] = ACTIONS(2506),
    [anon_sym_co_yield] = ACTIONS(2506),
    [anon_sym_R_DQUOTE] = ACTIONS(2508),
    [anon_sym_LR_DQUOTE] = ACTIONS(2508),
    [anon_sym_uR_DQUOTE] = ACTIONS(2508),
    [anon_sym_UR_DQUOTE] = ACTIONS(2508),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2508),
    [anon_sym_co_await] = ACTIONS(2506),
    [anon_sym_new] = ACTIONS(2506),
    [anon_sym_requires] = ACTIONS(2506),
    [sym_this] = ACTIONS(2506),
    [anon_sym_discard] = ACTIONS(2506),
    [anon_sym_precise] = ACTIONS(2506),
    [anon_sym_shared] = ACTIONS(2506),
    [anon_sym_groupshared] = ACTIONS(2506),
    [anon_sym_uniform] = ACTIONS(2506),
    [anon_sym_row_major] = ACTIONS(2506),
    [anon_sym_column_major] = ACTIONS(2506),
    [anon_sym_globallycoherent] = ACTIONS(2506),
    [anon_sym_centroid] = ACTIONS(2506),
    [anon_sym_noperspective] = ACTIONS(2506),
    [anon_sym_nointerpolation] = ACTIONS(2506),
    [anon_sym_sample] = ACTIONS(2506),
    [anon_sym_linear] = ACTIONS(2506),
    [anon_sym_snorm] = ACTIONS(2506),
    [anon_sym_unorm] = ACTIONS(2506),
    [anon_sym_point] = ACTIONS(2506),
    [anon_sym_line] = ACTIONS(2506),
    [anon_sym_triangleadj] = ACTIONS(2506),
    [anon_sym_lineadj] = ACTIONS(2506),
    [anon_sym_triangle] = ACTIONS(2506),
    [anon_sym_cbuffer] = ACTIONS(2506),
  },
  [579] = {
    [sym_identifier] = ACTIONS(2436),
    [aux_sym_preproc_include_token1] = ACTIONS(2436),
    [aux_sym_preproc_def_token1] = ACTIONS(2436),
    [aux_sym_preproc_if_token1] = ACTIONS(2436),
    [aux_sym_preproc_if_token2] = ACTIONS(2436),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2436),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2436),
    [sym_preproc_directive] = ACTIONS(2436),
    [anon_sym_LPAREN2] = ACTIONS(2438),
    [anon_sym_BANG] = ACTIONS(2438),
    [anon_sym_TILDE] = ACTIONS(2438),
    [anon_sym_DASH] = ACTIONS(2436),
    [anon_sym_PLUS] = ACTIONS(2436),
    [anon_sym_STAR] = ACTIONS(2438),
    [anon_sym_AMP_AMP] = ACTIONS(2438),
    [anon_sym_AMP] = ACTIONS(2436),
    [anon_sym_SEMI] = ACTIONS(2438),
    [anon_sym___extension__] = ACTIONS(2436),
    [anon_sym_typedef] = ACTIONS(2436),
    [anon_sym_in] = ACTIONS(2436),
    [anon_sym_out] = ACTIONS(2436),
    [anon_sym_inout] = ACTIONS(2436),
    [anon_sym_extern] = ACTIONS(2436),
    [anon_sym___attribute__] = ACTIONS(2436),
    [anon_sym_COLON_COLON] = ACTIONS(2438),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2438),
    [anon_sym___declspec] = ACTIONS(2436),
    [anon_sym___based] = ACTIONS(2436),
    [anon_sym___cdecl] = ACTIONS(2436),
    [anon_sym___clrcall] = ACTIONS(2436),
    [anon_sym___stdcall] = ACTIONS(2436),
    [anon_sym___fastcall] = ACTIONS(2436),
    [anon_sym___thiscall] = ACTIONS(2436),
    [anon_sym___vectorcall] = ACTIONS(2436),
    [anon_sym_LBRACE] = ACTIONS(2438),
    [anon_sym_signed] = ACTIONS(2436),
    [anon_sym_unsigned] = ACTIONS(2436),
    [anon_sym_long] = ACTIONS(2436),
    [anon_sym_short] = ACTIONS(2436),
    [anon_sym_LBRACK] = ACTIONS(2436),
    [anon_sym_static] = ACTIONS(2436),
    [anon_sym_register] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2436),
    [anon_sym___inline] = ACTIONS(2436),
    [anon_sym___inline__] = ACTIONS(2436),
    [anon_sym___forceinline] = ACTIONS(2436),
    [anon_sym_thread_local] = ACTIONS(2436),
    [anon_sym___thread] = ACTIONS(2436),
    [anon_sym_const] = ACTIONS(2436),
    [anon_sym_constexpr] = ACTIONS(2436),
    [anon_sym_volatile] = ACTIONS(2436),
    [anon_sym_restrict] = ACTIONS(2436),
    [anon_sym___restrict__] = ACTIONS(2436),
    [anon_sym__Atomic] = ACTIONS(2436),
    [anon_sym__Noreturn] = ACTIONS(2436),
    [anon_sym_noreturn] = ACTIONS(2436),
    [anon_sym_mutable] = ACTIONS(2436),
    [anon_sym_constinit] = ACTIONS(2436),
    [anon_sym_consteval] = ACTIONS(2436),
    [anon_sym_alignas] = ACTIONS(2436),
    [anon_sym__Alignas] = ACTIONS(2436),
    [sym_primitive_type] = ACTIONS(2436),
    [anon_sym_enum] = ACTIONS(2436),
    [anon_sym_class] = ACTIONS(2436),
    [anon_sym_struct] = ACTIONS(2436),
    [anon_sym_union] = ACTIONS(2436),
    [anon_sym_if] = ACTIONS(2436),
    [anon_sym_switch] = ACTIONS(2436),
    [anon_sym_case] = ACTIONS(2436),
    [anon_sym_default] = ACTIONS(2436),
    [anon_sym_while] = ACTIONS(2436),
    [anon_sym_do] = ACTIONS(2436),
    [anon_sym_for] = ACTIONS(2436),
    [anon_sym_return] = ACTIONS(2436),
    [anon_sym_break] = ACTIONS(2436),
    [anon_sym_continue] = ACTIONS(2436),
    [anon_sym_goto] = ACTIONS(2436),
    [anon_sym___try] = ACTIONS(2436),
    [anon_sym___leave] = ACTIONS(2436),
    [anon_sym_not] = ACTIONS(2436),
    [anon_sym_compl] = ACTIONS(2436),
    [anon_sym_DASH_DASH] = ACTIONS(2438),
    [anon_sym_PLUS_PLUS] = ACTIONS(2438),
    [anon_sym_sizeof] = ACTIONS(2436),
    [anon_sym___alignof__] = ACTIONS(2436),
    [anon_sym___alignof] = ACTIONS(2436),
    [anon_sym__alignof] = ACTIONS(2436),
    [anon_sym_alignof] = ACTIONS(2436),
    [anon_sym__Alignof] = ACTIONS(2436),
    [anon_sym_offsetof] = ACTIONS(2436),
    [anon_sym__Generic] = ACTIONS(2436),
    [anon_sym_asm] = ACTIONS(2436),
    [anon_sym___asm__] = ACTIONS(2436),
    [sym_number_literal] = ACTIONS(2438),
    [anon_sym_L_SQUOTE] = ACTIONS(2438),
    [anon_sym_u_SQUOTE] = ACTIONS(2438),
    [anon_sym_U_SQUOTE] = ACTIONS(2438),
    [anon_sym_u8_SQUOTE] = ACTIONS(2438),
    [anon_sym_SQUOTE] = ACTIONS(2438),
    [anon_sym_L_DQUOTE] = ACTIONS(2438),
    [anon_sym_u_DQUOTE] = ACTIONS(2438),
    [anon_sym_U_DQUOTE] = ACTIONS(2438),
    [anon_sym_u8_DQUOTE] = ACTIONS(2438),
    [anon_sym_DQUOTE] = ACTIONS(2438),
    [sym_true] = ACTIONS(2436),
    [sym_false] = ACTIONS(2436),
    [anon_sym_NULL] = ACTIONS(2436),
    [anon_sym_nullptr] = ACTIONS(2436),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2436),
    [anon_sym_decltype] = ACTIONS(2436),
    [sym_virtual] = ACTIONS(2436),
    [anon_sym_explicit] = ACTIONS(2436),
    [anon_sym_typename] = ACTIONS(2436),
    [anon_sym_template] = ACTIONS(2436),
    [anon_sym_operator] = ACTIONS(2436),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_delete] = ACTIONS(2436),
    [anon_sym_throw] = ACTIONS(2436),
    [anon_sym_namespace] = ACTIONS(2436),
    [anon_sym_using] = ACTIONS(2436),
    [anon_sym_static_assert] = ACTIONS(2436),
    [anon_sym_concept] = ACTIONS(2436),
    [anon_sym_co_return] = ACTIONS(2436),
    [anon_sym_co_yield] = ACTIONS(2436),
    [anon_sym_R_DQUOTE] = ACTIONS(2438),
    [anon_sym_LR_DQUOTE] = ACTIONS(2438),
    [anon_sym_uR_DQUOTE] = ACTIONS(2438),
    [anon_sym_UR_DQUOTE] = ACTIONS(2438),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2438),
    [anon_sym_co_await] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(2436),
    [anon_sym_requires] = ACTIONS(2436),
    [sym_this] = ACTIONS(2436),
    [anon_sym_discard] = ACTIONS(2436),
    [anon_sym_precise] = ACTIONS(2436),
    [anon_sym_shared] = ACTIONS(2436),
    [anon_sym_groupshared] = ACTIONS(2436),
    [anon_sym_uniform] = ACTIONS(2436),
    [anon_sym_row_major] = ACTIONS(2436),
    [anon_sym_column_major] = ACTIONS(2436),
    [anon_sym_globallycoherent] = ACTIONS(2436),
    [anon_sym_centroid] = ACTIONS(2436),
    [anon_sym_noperspective] = ACTIONS(2436),
    [anon_sym_nointerpolation] = ACTIONS(2436),
    [anon_sym_sample] = ACTIONS(2436),
    [anon_sym_linear] = ACTIONS(2436),
    [anon_sym_snorm] = ACTIONS(2436),
    [anon_sym_unorm] = ACTIONS(2436),
    [anon_sym_point] = ACTIONS(2436),
    [anon_sym_line] = ACTIONS(2436),
    [anon_sym_triangleadj] = ACTIONS(2436),
    [anon_sym_lineadj] = ACTIONS(2436),
    [anon_sym_triangle] = ACTIONS(2436),
    [anon_sym_cbuffer] = ACTIONS(2436),
  },
  [580] = {
    [sym_identifier] = ACTIONS(2408),
    [aux_sym_preproc_include_token1] = ACTIONS(2408),
    [aux_sym_preproc_def_token1] = ACTIONS(2408),
    [aux_sym_preproc_if_token1] = ACTIONS(2408),
    [aux_sym_preproc_if_token2] = ACTIONS(2408),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2408),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2408),
    [sym_preproc_directive] = ACTIONS(2408),
    [anon_sym_LPAREN2] = ACTIONS(2410),
    [anon_sym_BANG] = ACTIONS(2410),
    [anon_sym_TILDE] = ACTIONS(2410),
    [anon_sym_DASH] = ACTIONS(2408),
    [anon_sym_PLUS] = ACTIONS(2408),
    [anon_sym_STAR] = ACTIONS(2410),
    [anon_sym_AMP_AMP] = ACTIONS(2410),
    [anon_sym_AMP] = ACTIONS(2408),
    [anon_sym_SEMI] = ACTIONS(2410),
    [anon_sym___extension__] = ACTIONS(2408),
    [anon_sym_typedef] = ACTIONS(2408),
    [anon_sym_in] = ACTIONS(2408),
    [anon_sym_out] = ACTIONS(2408),
    [anon_sym_inout] = ACTIONS(2408),
    [anon_sym_extern] = ACTIONS(2408),
    [anon_sym___attribute__] = ACTIONS(2408),
    [anon_sym_COLON_COLON] = ACTIONS(2410),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2410),
    [anon_sym___declspec] = ACTIONS(2408),
    [anon_sym___based] = ACTIONS(2408),
    [anon_sym___cdecl] = ACTIONS(2408),
    [anon_sym___clrcall] = ACTIONS(2408),
    [anon_sym___stdcall] = ACTIONS(2408),
    [anon_sym___fastcall] = ACTIONS(2408),
    [anon_sym___thiscall] = ACTIONS(2408),
    [anon_sym___vectorcall] = ACTIONS(2408),
    [anon_sym_LBRACE] = ACTIONS(2410),
    [anon_sym_signed] = ACTIONS(2408),
    [anon_sym_unsigned] = ACTIONS(2408),
    [anon_sym_long] = ACTIONS(2408),
    [anon_sym_short] = ACTIONS(2408),
    [anon_sym_LBRACK] = ACTIONS(2408),
    [anon_sym_static] = ACTIONS(2408),
    [anon_sym_register] = ACTIONS(2408),
    [anon_sym_inline] = ACTIONS(2408),
    [anon_sym___inline] = ACTIONS(2408),
    [anon_sym___inline__] = ACTIONS(2408),
    [anon_sym___forceinline] = ACTIONS(2408),
    [anon_sym_thread_local] = ACTIONS(2408),
    [anon_sym___thread] = ACTIONS(2408),
    [anon_sym_const] = ACTIONS(2408),
    [anon_sym_constexpr] = ACTIONS(2408),
    [anon_sym_volatile] = ACTIONS(2408),
    [anon_sym_restrict] = ACTIONS(2408),
    [anon_sym___restrict__] = ACTIONS(2408),
    [anon_sym__Atomic] = ACTIONS(2408),
    [anon_sym__Noreturn] = ACTIONS(2408),
    [anon_sym_noreturn] = ACTIONS(2408),
    [anon_sym_mutable] = ACTIONS(2408),
    [anon_sym_constinit] = ACTIONS(2408),
    [anon_sym_consteval] = ACTIONS(2408),
    [anon_sym_alignas] = ACTIONS(2408),
    [anon_sym__Alignas] = ACTIONS(2408),
    [sym_primitive_type] = ACTIONS(2408),
    [anon_sym_enum] = ACTIONS(2408),
    [anon_sym_class] = ACTIONS(2408),
    [anon_sym_struct] = ACTIONS(2408),
    [anon_sym_union] = ACTIONS(2408),
    [anon_sym_if] = ACTIONS(2408),
    [anon_sym_switch] = ACTIONS(2408),
    [anon_sym_case] = ACTIONS(2408),
    [anon_sym_default] = ACTIONS(2408),
    [anon_sym_while] = ACTIONS(2408),
    [anon_sym_do] = ACTIONS(2408),
    [anon_sym_for] = ACTIONS(2408),
    [anon_sym_return] = ACTIONS(2408),
    [anon_sym_break] = ACTIONS(2408),
    [anon_sym_continue] = ACTIONS(2408),
    [anon_sym_goto] = ACTIONS(2408),
    [anon_sym___try] = ACTIONS(2408),
    [anon_sym___leave] = ACTIONS(2408),
    [anon_sym_not] = ACTIONS(2408),
    [anon_sym_compl] = ACTIONS(2408),
    [anon_sym_DASH_DASH] = ACTIONS(2410),
    [anon_sym_PLUS_PLUS] = ACTIONS(2410),
    [anon_sym_sizeof] = ACTIONS(2408),
    [anon_sym___alignof__] = ACTIONS(2408),
    [anon_sym___alignof] = ACTIONS(2408),
    [anon_sym__alignof] = ACTIONS(2408),
    [anon_sym_alignof] = ACTIONS(2408),
    [anon_sym__Alignof] = ACTIONS(2408),
    [anon_sym_offsetof] = ACTIONS(2408),
    [anon_sym__Generic] = ACTIONS(2408),
    [anon_sym_asm] = ACTIONS(2408),
    [anon_sym___asm__] = ACTIONS(2408),
    [sym_number_literal] = ACTIONS(2410),
    [anon_sym_L_SQUOTE] = ACTIONS(2410),
    [anon_sym_u_SQUOTE] = ACTIONS(2410),
    [anon_sym_U_SQUOTE] = ACTIONS(2410),
    [anon_sym_u8_SQUOTE] = ACTIONS(2410),
    [anon_sym_SQUOTE] = ACTIONS(2410),
    [anon_sym_L_DQUOTE] = ACTIONS(2410),
    [anon_sym_u_DQUOTE] = ACTIONS(2410),
    [anon_sym_U_DQUOTE] = ACTIONS(2410),
    [anon_sym_u8_DQUOTE] = ACTIONS(2410),
    [anon_sym_DQUOTE] = ACTIONS(2410),
    [sym_true] = ACTIONS(2408),
    [sym_false] = ACTIONS(2408),
    [anon_sym_NULL] = ACTIONS(2408),
    [anon_sym_nullptr] = ACTIONS(2408),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2408),
    [anon_sym_decltype] = ACTIONS(2408),
    [sym_virtual] = ACTIONS(2408),
    [anon_sym_explicit] = ACTIONS(2408),
    [anon_sym_typename] = ACTIONS(2408),
    [anon_sym_template] = ACTIONS(2408),
    [anon_sym_operator] = ACTIONS(2408),
    [anon_sym_try] = ACTIONS(2408),
    [anon_sym_delete] = ACTIONS(2408),
    [anon_sym_throw] = ACTIONS(2408),
    [anon_sym_namespace] = ACTIONS(2408),
    [anon_sym_using] = ACTIONS(2408),
    [anon_sym_static_assert] = ACTIONS(2408),
    [anon_sym_concept] = ACTIONS(2408),
    [anon_sym_co_return] = ACTIONS(2408),
    [anon_sym_co_yield] = ACTIONS(2408),
    [anon_sym_R_DQUOTE] = ACTIONS(2410),
    [anon_sym_LR_DQUOTE] = ACTIONS(2410),
    [anon_sym_uR_DQUOTE] = ACTIONS(2410),
    [anon_sym_UR_DQUOTE] = ACTIONS(2410),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2410),
    [anon_sym_co_await] = ACTIONS(2408),
    [anon_sym_new] = ACTIONS(2408),
    [anon_sym_requires] = ACTIONS(2408),
    [sym_this] = ACTIONS(2408),
    [anon_sym_discard] = ACTIONS(2408),
    [anon_sym_precise] = ACTIONS(2408),
    [anon_sym_shared] = ACTIONS(2408),
    [anon_sym_groupshared] = ACTIONS(2408),
    [anon_sym_uniform] = ACTIONS(2408),
    [anon_sym_row_major] = ACTIONS(2408),
    [anon_sym_column_major] = ACTIONS(2408),
    [anon_sym_globallycoherent] = ACTIONS(2408),
    [anon_sym_centroid] = ACTIONS(2408),
    [anon_sym_noperspective] = ACTIONS(2408),
    [anon_sym_nointerpolation] = ACTIONS(2408),
    [anon_sym_sample] = ACTIONS(2408),
    [anon_sym_linear] = ACTIONS(2408),
    [anon_sym_snorm] = ACTIONS(2408),
    [anon_sym_unorm] = ACTIONS(2408),
    [anon_sym_point] = ACTIONS(2408),
    [anon_sym_line] = ACTIONS(2408),
    [anon_sym_triangleadj] = ACTIONS(2408),
    [anon_sym_lineadj] = ACTIONS(2408),
    [anon_sym_triangle] = ACTIONS(2408),
    [anon_sym_cbuffer] = ACTIONS(2408),
  },
  [581] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_include_token1] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token2] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_BANG] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_DASH] = ACTIONS(2332),
    [anon_sym_PLUS] = ACTIONS(2332),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym_SEMI] = ACTIONS(2334),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym___cdecl] = ACTIONS(2332),
    [anon_sym___clrcall] = ACTIONS(2332),
    [anon_sym___stdcall] = ACTIONS(2332),
    [anon_sym___fastcall] = ACTIONS(2332),
    [anon_sym___thiscall] = ACTIONS(2332),
    [anon_sym___vectorcall] = ACTIONS(2332),
    [anon_sym_LBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_switch] = ACTIONS(2332),
    [anon_sym_case] = ACTIONS(2332),
    [anon_sym_default] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2332),
    [anon_sym_do] = ACTIONS(2332),
    [anon_sym_for] = ACTIONS(2332),
    [anon_sym_return] = ACTIONS(2332),
    [anon_sym_break] = ACTIONS(2332),
    [anon_sym_continue] = ACTIONS(2332),
    [anon_sym_goto] = ACTIONS(2332),
    [anon_sym___try] = ACTIONS(2332),
    [anon_sym___leave] = ACTIONS(2332),
    [anon_sym_not] = ACTIONS(2332),
    [anon_sym_compl] = ACTIONS(2332),
    [anon_sym_DASH_DASH] = ACTIONS(2334),
    [anon_sym_PLUS_PLUS] = ACTIONS(2334),
    [anon_sym_sizeof] = ACTIONS(2332),
    [anon_sym___alignof__] = ACTIONS(2332),
    [anon_sym___alignof] = ACTIONS(2332),
    [anon_sym__alignof] = ACTIONS(2332),
    [anon_sym_alignof] = ACTIONS(2332),
    [anon_sym__Alignof] = ACTIONS(2332),
    [anon_sym_offsetof] = ACTIONS(2332),
    [anon_sym__Generic] = ACTIONS(2332),
    [anon_sym_asm] = ACTIONS(2332),
    [anon_sym___asm__] = ACTIONS(2332),
    [sym_number_literal] = ACTIONS(2334),
    [anon_sym_L_SQUOTE] = ACTIONS(2334),
    [anon_sym_u_SQUOTE] = ACTIONS(2334),
    [anon_sym_U_SQUOTE] = ACTIONS(2334),
    [anon_sym_u8_SQUOTE] = ACTIONS(2334),
    [anon_sym_SQUOTE] = ACTIONS(2334),
    [anon_sym_L_DQUOTE] = ACTIONS(2334),
    [anon_sym_u_DQUOTE] = ACTIONS(2334),
    [anon_sym_U_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8_DQUOTE] = ACTIONS(2334),
    [anon_sym_DQUOTE] = ACTIONS(2334),
    [sym_true] = ACTIONS(2332),
    [sym_false] = ACTIONS(2332),
    [anon_sym_NULL] = ACTIONS(2332),
    [anon_sym_nullptr] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_try] = ACTIONS(2332),
    [anon_sym_delete] = ACTIONS(2332),
    [anon_sym_throw] = ACTIONS(2332),
    [anon_sym_namespace] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_concept] = ACTIONS(2332),
    [anon_sym_co_return] = ACTIONS(2332),
    [anon_sym_co_yield] = ACTIONS(2332),
    [anon_sym_R_DQUOTE] = ACTIONS(2334),
    [anon_sym_LR_DQUOTE] = ACTIONS(2334),
    [anon_sym_uR_DQUOTE] = ACTIONS(2334),
    [anon_sym_UR_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2334),
    [anon_sym_co_await] = ACTIONS(2332),
    [anon_sym_new] = ACTIONS(2332),
    [anon_sym_requires] = ACTIONS(2332),
    [sym_this] = ACTIONS(2332),
    [anon_sym_discard] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
    [anon_sym_cbuffer] = ACTIONS(2332),
  },
  [582] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_include_token1] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token2] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_BANG] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_DASH] = ACTIONS(2332),
    [anon_sym_PLUS] = ACTIONS(2332),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym_SEMI] = ACTIONS(2334),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym___cdecl] = ACTIONS(2332),
    [anon_sym___clrcall] = ACTIONS(2332),
    [anon_sym___stdcall] = ACTIONS(2332),
    [anon_sym___fastcall] = ACTIONS(2332),
    [anon_sym___thiscall] = ACTIONS(2332),
    [anon_sym___vectorcall] = ACTIONS(2332),
    [anon_sym_LBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_switch] = ACTIONS(2332),
    [anon_sym_case] = ACTIONS(2332),
    [anon_sym_default] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2332),
    [anon_sym_do] = ACTIONS(2332),
    [anon_sym_for] = ACTIONS(2332),
    [anon_sym_return] = ACTIONS(2332),
    [anon_sym_break] = ACTIONS(2332),
    [anon_sym_continue] = ACTIONS(2332),
    [anon_sym_goto] = ACTIONS(2332),
    [anon_sym___try] = ACTIONS(2332),
    [anon_sym___leave] = ACTIONS(2332),
    [anon_sym_not] = ACTIONS(2332),
    [anon_sym_compl] = ACTIONS(2332),
    [anon_sym_DASH_DASH] = ACTIONS(2334),
    [anon_sym_PLUS_PLUS] = ACTIONS(2334),
    [anon_sym_sizeof] = ACTIONS(2332),
    [anon_sym___alignof__] = ACTIONS(2332),
    [anon_sym___alignof] = ACTIONS(2332),
    [anon_sym__alignof] = ACTIONS(2332),
    [anon_sym_alignof] = ACTIONS(2332),
    [anon_sym__Alignof] = ACTIONS(2332),
    [anon_sym_offsetof] = ACTIONS(2332),
    [anon_sym__Generic] = ACTIONS(2332),
    [anon_sym_asm] = ACTIONS(2332),
    [anon_sym___asm__] = ACTIONS(2332),
    [sym_number_literal] = ACTIONS(2334),
    [anon_sym_L_SQUOTE] = ACTIONS(2334),
    [anon_sym_u_SQUOTE] = ACTIONS(2334),
    [anon_sym_U_SQUOTE] = ACTIONS(2334),
    [anon_sym_u8_SQUOTE] = ACTIONS(2334),
    [anon_sym_SQUOTE] = ACTIONS(2334),
    [anon_sym_L_DQUOTE] = ACTIONS(2334),
    [anon_sym_u_DQUOTE] = ACTIONS(2334),
    [anon_sym_U_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8_DQUOTE] = ACTIONS(2334),
    [anon_sym_DQUOTE] = ACTIONS(2334),
    [sym_true] = ACTIONS(2332),
    [sym_false] = ACTIONS(2332),
    [anon_sym_NULL] = ACTIONS(2332),
    [anon_sym_nullptr] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_try] = ACTIONS(2332),
    [anon_sym_delete] = ACTIONS(2332),
    [anon_sym_throw] = ACTIONS(2332),
    [anon_sym_namespace] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_concept] = ACTIONS(2332),
    [anon_sym_co_return] = ACTIONS(2332),
    [anon_sym_co_yield] = ACTIONS(2332),
    [anon_sym_R_DQUOTE] = ACTIONS(2334),
    [anon_sym_LR_DQUOTE] = ACTIONS(2334),
    [anon_sym_uR_DQUOTE] = ACTIONS(2334),
    [anon_sym_UR_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2334),
    [anon_sym_co_await] = ACTIONS(2332),
    [anon_sym_new] = ACTIONS(2332),
    [anon_sym_requires] = ACTIONS(2332),
    [sym_this] = ACTIONS(2332),
    [anon_sym_discard] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
    [anon_sym_cbuffer] = ACTIONS(2332),
  },
  [583] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_include_token1] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_BANG] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_DASH] = ACTIONS(2324),
    [anon_sym_PLUS] = ACTIONS(2324),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym_SEMI] = ACTIONS(2326),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym___cdecl] = ACTIONS(2324),
    [anon_sym___clrcall] = ACTIONS(2324),
    [anon_sym___stdcall] = ACTIONS(2324),
    [anon_sym___fastcall] = ACTIONS(2324),
    [anon_sym___thiscall] = ACTIONS(2324),
    [anon_sym___vectorcall] = ACTIONS(2324),
    [anon_sym_LBRACE] = ACTIONS(2326),
    [anon_sym_RBRACE] = ACTIONS(2326),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [anon_sym_if] = ACTIONS(2324),
    [anon_sym_switch] = ACTIONS(2324),
    [anon_sym_case] = ACTIONS(2324),
    [anon_sym_default] = ACTIONS(2324),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_do] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2324),
    [anon_sym_return] = ACTIONS(2324),
    [anon_sym_break] = ACTIONS(2324),
    [anon_sym_continue] = ACTIONS(2324),
    [anon_sym_goto] = ACTIONS(2324),
    [anon_sym___try] = ACTIONS(2324),
    [anon_sym___leave] = ACTIONS(2324),
    [anon_sym_not] = ACTIONS(2324),
    [anon_sym_compl] = ACTIONS(2324),
    [anon_sym_DASH_DASH] = ACTIONS(2326),
    [anon_sym_PLUS_PLUS] = ACTIONS(2326),
    [anon_sym_sizeof] = ACTIONS(2324),
    [anon_sym___alignof__] = ACTIONS(2324),
    [anon_sym___alignof] = ACTIONS(2324),
    [anon_sym__alignof] = ACTIONS(2324),
    [anon_sym_alignof] = ACTIONS(2324),
    [anon_sym__Alignof] = ACTIONS(2324),
    [anon_sym_offsetof] = ACTIONS(2324),
    [anon_sym__Generic] = ACTIONS(2324),
    [anon_sym_asm] = ACTIONS(2324),
    [anon_sym___asm__] = ACTIONS(2324),
    [sym_number_literal] = ACTIONS(2326),
    [anon_sym_L_SQUOTE] = ACTIONS(2326),
    [anon_sym_u_SQUOTE] = ACTIONS(2326),
    [anon_sym_U_SQUOTE] = ACTIONS(2326),
    [anon_sym_u8_SQUOTE] = ACTIONS(2326),
    [anon_sym_SQUOTE] = ACTIONS(2326),
    [anon_sym_L_DQUOTE] = ACTIONS(2326),
    [anon_sym_u_DQUOTE] = ACTIONS(2326),
    [anon_sym_U_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8_DQUOTE] = ACTIONS(2326),
    [anon_sym_DQUOTE] = ACTIONS(2326),
    [sym_true] = ACTIONS(2324),
    [sym_false] = ACTIONS(2324),
    [anon_sym_NULL] = ACTIONS(2324),
    [anon_sym_nullptr] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_try] = ACTIONS(2324),
    [anon_sym_delete] = ACTIONS(2324),
    [anon_sym_throw] = ACTIONS(2324),
    [anon_sym_namespace] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_concept] = ACTIONS(2324),
    [anon_sym_co_return] = ACTIONS(2324),
    [anon_sym_co_yield] = ACTIONS(2324),
    [anon_sym_R_DQUOTE] = ACTIONS(2326),
    [anon_sym_LR_DQUOTE] = ACTIONS(2326),
    [anon_sym_uR_DQUOTE] = ACTIONS(2326),
    [anon_sym_UR_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2326),
    [anon_sym_co_await] = ACTIONS(2324),
    [anon_sym_new] = ACTIONS(2324),
    [anon_sym_requires] = ACTIONS(2324),
    [sym_this] = ACTIONS(2324),
    [anon_sym_discard] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
    [anon_sym_cbuffer] = ACTIONS(2324),
  },
  [584] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_include_token1] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_BANG] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_DASH] = ACTIONS(2324),
    [anon_sym_PLUS] = ACTIONS(2324),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym_SEMI] = ACTIONS(2326),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym___cdecl] = ACTIONS(2324),
    [anon_sym___clrcall] = ACTIONS(2324),
    [anon_sym___stdcall] = ACTIONS(2324),
    [anon_sym___fastcall] = ACTIONS(2324),
    [anon_sym___thiscall] = ACTIONS(2324),
    [anon_sym___vectorcall] = ACTIONS(2324),
    [anon_sym_LBRACE] = ACTIONS(2326),
    [anon_sym_RBRACE] = ACTIONS(2326),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [anon_sym_if] = ACTIONS(2324),
    [anon_sym_switch] = ACTIONS(2324),
    [anon_sym_case] = ACTIONS(2324),
    [anon_sym_default] = ACTIONS(2324),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_do] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2324),
    [anon_sym_return] = ACTIONS(2324),
    [anon_sym_break] = ACTIONS(2324),
    [anon_sym_continue] = ACTIONS(2324),
    [anon_sym_goto] = ACTIONS(2324),
    [anon_sym___try] = ACTIONS(2324),
    [anon_sym___leave] = ACTIONS(2324),
    [anon_sym_not] = ACTIONS(2324),
    [anon_sym_compl] = ACTIONS(2324),
    [anon_sym_DASH_DASH] = ACTIONS(2326),
    [anon_sym_PLUS_PLUS] = ACTIONS(2326),
    [anon_sym_sizeof] = ACTIONS(2324),
    [anon_sym___alignof__] = ACTIONS(2324),
    [anon_sym___alignof] = ACTIONS(2324),
    [anon_sym__alignof] = ACTIONS(2324),
    [anon_sym_alignof] = ACTIONS(2324),
    [anon_sym__Alignof] = ACTIONS(2324),
    [anon_sym_offsetof] = ACTIONS(2324),
    [anon_sym__Generic] = ACTIONS(2324),
    [anon_sym_asm] = ACTIONS(2324),
    [anon_sym___asm__] = ACTIONS(2324),
    [sym_number_literal] = ACTIONS(2326),
    [anon_sym_L_SQUOTE] = ACTIONS(2326),
    [anon_sym_u_SQUOTE] = ACTIONS(2326),
    [anon_sym_U_SQUOTE] = ACTIONS(2326),
    [anon_sym_u8_SQUOTE] = ACTIONS(2326),
    [anon_sym_SQUOTE] = ACTIONS(2326),
    [anon_sym_L_DQUOTE] = ACTIONS(2326),
    [anon_sym_u_DQUOTE] = ACTIONS(2326),
    [anon_sym_U_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8_DQUOTE] = ACTIONS(2326),
    [anon_sym_DQUOTE] = ACTIONS(2326),
    [sym_true] = ACTIONS(2324),
    [sym_false] = ACTIONS(2324),
    [anon_sym_NULL] = ACTIONS(2324),
    [anon_sym_nullptr] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_try] = ACTIONS(2324),
    [anon_sym_delete] = ACTIONS(2324),
    [anon_sym_throw] = ACTIONS(2324),
    [anon_sym_namespace] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_concept] = ACTIONS(2324),
    [anon_sym_co_return] = ACTIONS(2324),
    [anon_sym_co_yield] = ACTIONS(2324),
    [anon_sym_R_DQUOTE] = ACTIONS(2326),
    [anon_sym_LR_DQUOTE] = ACTIONS(2326),
    [anon_sym_uR_DQUOTE] = ACTIONS(2326),
    [anon_sym_UR_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2326),
    [anon_sym_co_await] = ACTIONS(2324),
    [anon_sym_new] = ACTIONS(2324),
    [anon_sym_requires] = ACTIONS(2324),
    [sym_this] = ACTIONS(2324),
    [anon_sym_discard] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
    [anon_sym_cbuffer] = ACTIONS(2324),
  },
  [585] = {
    [sym_identifier] = ACTIONS(2320),
    [aux_sym_preproc_include_token1] = ACTIONS(2320),
    [aux_sym_preproc_def_token1] = ACTIONS(2320),
    [aux_sym_preproc_if_token1] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2320),
    [sym_preproc_directive] = ACTIONS(2320),
    [anon_sym_LPAREN2] = ACTIONS(2322),
    [anon_sym_BANG] = ACTIONS(2322),
    [anon_sym_TILDE] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2322),
    [anon_sym_AMP_AMP] = ACTIONS(2322),
    [anon_sym_AMP] = ACTIONS(2320),
    [anon_sym_SEMI] = ACTIONS(2322),
    [anon_sym___extension__] = ACTIONS(2320),
    [anon_sym_typedef] = ACTIONS(2320),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_out] = ACTIONS(2320),
    [anon_sym_inout] = ACTIONS(2320),
    [anon_sym_extern] = ACTIONS(2320),
    [anon_sym___attribute__] = ACTIONS(2320),
    [anon_sym_COLON_COLON] = ACTIONS(2322),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2322),
    [anon_sym___declspec] = ACTIONS(2320),
    [anon_sym___based] = ACTIONS(2320),
    [anon_sym___cdecl] = ACTIONS(2320),
    [anon_sym___clrcall] = ACTIONS(2320),
    [anon_sym___stdcall] = ACTIONS(2320),
    [anon_sym___fastcall] = ACTIONS(2320),
    [anon_sym___thiscall] = ACTIONS(2320),
    [anon_sym___vectorcall] = ACTIONS(2320),
    [anon_sym_LBRACE] = ACTIONS(2322),
    [anon_sym_RBRACE] = ACTIONS(2322),
    [anon_sym_signed] = ACTIONS(2320),
    [anon_sym_unsigned] = ACTIONS(2320),
    [anon_sym_long] = ACTIONS(2320),
    [anon_sym_short] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2320),
    [anon_sym_static] = ACTIONS(2320),
    [anon_sym_register] = ACTIONS(2320),
    [anon_sym_inline] = ACTIONS(2320),
    [anon_sym___inline] = ACTIONS(2320),
    [anon_sym___inline__] = ACTIONS(2320),
    [anon_sym___forceinline] = ACTIONS(2320),
    [anon_sym_thread_local] = ACTIONS(2320),
    [anon_sym___thread] = ACTIONS(2320),
    [anon_sym_const] = ACTIONS(2320),
    [anon_sym_constexpr] = ACTIONS(2320),
    [anon_sym_volatile] = ACTIONS(2320),
    [anon_sym_restrict] = ACTIONS(2320),
    [anon_sym___restrict__] = ACTIONS(2320),
    [anon_sym__Atomic] = ACTIONS(2320),
    [anon_sym__Noreturn] = ACTIONS(2320),
    [anon_sym_noreturn] = ACTIONS(2320),
    [anon_sym_mutable] = ACTIONS(2320),
    [anon_sym_constinit] = ACTIONS(2320),
    [anon_sym_consteval] = ACTIONS(2320),
    [anon_sym_alignas] = ACTIONS(2320),
    [anon_sym__Alignas] = ACTIONS(2320),
    [sym_primitive_type] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_class] = ACTIONS(2320),
    [anon_sym_struct] = ACTIONS(2320),
    [anon_sym_union] = ACTIONS(2320),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_switch] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_default] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_do] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_return] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_goto] = ACTIONS(2320),
    [anon_sym___try] = ACTIONS(2320),
    [anon_sym___leave] = ACTIONS(2320),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_compl] = ACTIONS(2320),
    [anon_sym_DASH_DASH] = ACTIONS(2322),
    [anon_sym_PLUS_PLUS] = ACTIONS(2322),
    [anon_sym_sizeof] = ACTIONS(2320),
    [anon_sym___alignof__] = ACTIONS(2320),
    [anon_sym___alignof] = ACTIONS(2320),
    [anon_sym__alignof] = ACTIONS(2320),
    [anon_sym_alignof] = ACTIONS(2320),
    [anon_sym__Alignof] = ACTIONS(2320),
    [anon_sym_offsetof] = ACTIONS(2320),
    [anon_sym__Generic] = ACTIONS(2320),
    [anon_sym_asm] = ACTIONS(2320),
    [anon_sym___asm__] = ACTIONS(2320),
    [sym_number_literal] = ACTIONS(2322),
    [anon_sym_L_SQUOTE] = ACTIONS(2322),
    [anon_sym_u_SQUOTE] = ACTIONS(2322),
    [anon_sym_U_SQUOTE] = ACTIONS(2322),
    [anon_sym_u8_SQUOTE] = ACTIONS(2322),
    [anon_sym_SQUOTE] = ACTIONS(2322),
    [anon_sym_L_DQUOTE] = ACTIONS(2322),
    [anon_sym_u_DQUOTE] = ACTIONS(2322),
    [anon_sym_U_DQUOTE] = ACTIONS(2322),
    [anon_sym_u8_DQUOTE] = ACTIONS(2322),
    [anon_sym_DQUOTE] = ACTIONS(2322),
    [sym_true] = ACTIONS(2320),
    [sym_false] = ACTIONS(2320),
    [anon_sym_NULL] = ACTIONS(2320),
    [anon_sym_nullptr] = ACTIONS(2320),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2320),
    [anon_sym_decltype] = ACTIONS(2320),
    [sym_virtual] = ACTIONS(2320),
    [anon_sym_explicit] = ACTIONS(2320),
    [anon_sym_typename] = ACTIONS(2320),
    [anon_sym_template] = ACTIONS(2320),
    [anon_sym_operator] = ACTIONS(2320),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_delete] = ACTIONS(2320),
    [anon_sym_throw] = ACTIONS(2320),
    [anon_sym_namespace] = ACTIONS(2320),
    [anon_sym_using] = ACTIONS(2320),
    [anon_sym_static_assert] = ACTIONS(2320),
    [anon_sym_concept] = ACTIONS(2320),
    [anon_sym_co_return] = ACTIONS(2320),
    [anon_sym_co_yield] = ACTIONS(2320),
    [anon_sym_R_DQUOTE] = ACTIONS(2322),
    [anon_sym_LR_DQUOTE] = ACTIONS(2322),
    [anon_sym_uR_DQUOTE] = ACTIONS(2322),
    [anon_sym_UR_DQUOTE] = ACTIONS(2322),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2322),
    [anon_sym_co_await] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(2320),
    [anon_sym_requires] = ACTIONS(2320),
    [sym_this] = ACTIONS(2320),
    [anon_sym_discard] = ACTIONS(2320),
    [anon_sym_precise] = ACTIONS(2320),
    [anon_sym_shared] = ACTIONS(2320),
    [anon_sym_groupshared] = ACTIONS(2320),
    [anon_sym_uniform] = ACTIONS(2320),
    [anon_sym_row_major] = ACTIONS(2320),
    [anon_sym_column_major] = ACTIONS(2320),
    [anon_sym_globallycoherent] = ACTIONS(2320),
    [anon_sym_centroid] = ACTIONS(2320),
    [anon_sym_noperspective] = ACTIONS(2320),
    [anon_sym_nointerpolation] = ACTIONS(2320),
    [anon_sym_sample] = ACTIONS(2320),
    [anon_sym_linear] = ACTIONS(2320),
    [anon_sym_snorm] = ACTIONS(2320),
    [anon_sym_unorm] = ACTIONS(2320),
    [anon_sym_point] = ACTIONS(2320),
    [anon_sym_line] = ACTIONS(2320),
    [anon_sym_triangleadj] = ACTIONS(2320),
    [anon_sym_lineadj] = ACTIONS(2320),
    [anon_sym_triangle] = ACTIONS(2320),
    [anon_sym_cbuffer] = ACTIONS(2320),
  },
  [586] = {
    [sym_identifier] = ACTIONS(2312),
    [aux_sym_preproc_include_token1] = ACTIONS(2312),
    [aux_sym_preproc_def_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2312),
    [sym_preproc_directive] = ACTIONS(2312),
    [anon_sym_LPAREN2] = ACTIONS(2314),
    [anon_sym_BANG] = ACTIONS(2314),
    [anon_sym_TILDE] = ACTIONS(2314),
    [anon_sym_DASH] = ACTIONS(2312),
    [anon_sym_PLUS] = ACTIONS(2312),
    [anon_sym_STAR] = ACTIONS(2314),
    [anon_sym_AMP_AMP] = ACTIONS(2314),
    [anon_sym_AMP] = ACTIONS(2312),
    [anon_sym_SEMI] = ACTIONS(2314),
    [anon_sym___extension__] = ACTIONS(2312),
    [anon_sym_typedef] = ACTIONS(2312),
    [anon_sym_in] = ACTIONS(2312),
    [anon_sym_out] = ACTIONS(2312),
    [anon_sym_inout] = ACTIONS(2312),
    [anon_sym_extern] = ACTIONS(2312),
    [anon_sym___attribute__] = ACTIONS(2312),
    [anon_sym_COLON_COLON] = ACTIONS(2314),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2314),
    [anon_sym___declspec] = ACTIONS(2312),
    [anon_sym___based] = ACTIONS(2312),
    [anon_sym___cdecl] = ACTIONS(2312),
    [anon_sym___clrcall] = ACTIONS(2312),
    [anon_sym___stdcall] = ACTIONS(2312),
    [anon_sym___fastcall] = ACTIONS(2312),
    [anon_sym___thiscall] = ACTIONS(2312),
    [anon_sym___vectorcall] = ACTIONS(2312),
    [anon_sym_LBRACE] = ACTIONS(2314),
    [anon_sym_RBRACE] = ACTIONS(2314),
    [anon_sym_signed] = ACTIONS(2312),
    [anon_sym_unsigned] = ACTIONS(2312),
    [anon_sym_long] = ACTIONS(2312),
    [anon_sym_short] = ACTIONS(2312),
    [anon_sym_LBRACK] = ACTIONS(2312),
    [anon_sym_static] = ACTIONS(2312),
    [anon_sym_register] = ACTIONS(2312),
    [anon_sym_inline] = ACTIONS(2312),
    [anon_sym___inline] = ACTIONS(2312),
    [anon_sym___inline__] = ACTIONS(2312),
    [anon_sym___forceinline] = ACTIONS(2312),
    [anon_sym_thread_local] = ACTIONS(2312),
    [anon_sym___thread] = ACTIONS(2312),
    [anon_sym_const] = ACTIONS(2312),
    [anon_sym_constexpr] = ACTIONS(2312),
    [anon_sym_volatile] = ACTIONS(2312),
    [anon_sym_restrict] = ACTIONS(2312),
    [anon_sym___restrict__] = ACTIONS(2312),
    [anon_sym__Atomic] = ACTIONS(2312),
    [anon_sym__Noreturn] = ACTIONS(2312),
    [anon_sym_noreturn] = ACTIONS(2312),
    [anon_sym_mutable] = ACTIONS(2312),
    [anon_sym_constinit] = ACTIONS(2312),
    [anon_sym_consteval] = ACTIONS(2312),
    [anon_sym_alignas] = ACTIONS(2312),
    [anon_sym__Alignas] = ACTIONS(2312),
    [sym_primitive_type] = ACTIONS(2312),
    [anon_sym_enum] = ACTIONS(2312),
    [anon_sym_class] = ACTIONS(2312),
    [anon_sym_struct] = ACTIONS(2312),
    [anon_sym_union] = ACTIONS(2312),
    [anon_sym_if] = ACTIONS(2312),
    [anon_sym_switch] = ACTIONS(2312),
    [anon_sym_case] = ACTIONS(2312),
    [anon_sym_default] = ACTIONS(2312),
    [anon_sym_while] = ACTIONS(2312),
    [anon_sym_do] = ACTIONS(2312),
    [anon_sym_for] = ACTIONS(2312),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_break] = ACTIONS(2312),
    [anon_sym_continue] = ACTIONS(2312),
    [anon_sym_goto] = ACTIONS(2312),
    [anon_sym___try] = ACTIONS(2312),
    [anon_sym___leave] = ACTIONS(2312),
    [anon_sym_not] = ACTIONS(2312),
    [anon_sym_compl] = ACTIONS(2312),
    [anon_sym_DASH_DASH] = ACTIONS(2314),
    [anon_sym_PLUS_PLUS] = ACTIONS(2314),
    [anon_sym_sizeof] = ACTIONS(2312),
    [anon_sym___alignof__] = ACTIONS(2312),
    [anon_sym___alignof] = ACTIONS(2312),
    [anon_sym__alignof] = ACTIONS(2312),
    [anon_sym_alignof] = ACTIONS(2312),
    [anon_sym__Alignof] = ACTIONS(2312),
    [anon_sym_offsetof] = ACTIONS(2312),
    [anon_sym__Generic] = ACTIONS(2312),
    [anon_sym_asm] = ACTIONS(2312),
    [anon_sym___asm__] = ACTIONS(2312),
    [sym_number_literal] = ACTIONS(2314),
    [anon_sym_L_SQUOTE] = ACTIONS(2314),
    [anon_sym_u_SQUOTE] = ACTIONS(2314),
    [anon_sym_U_SQUOTE] = ACTIONS(2314),
    [anon_sym_u8_SQUOTE] = ACTIONS(2314),
    [anon_sym_SQUOTE] = ACTIONS(2314),
    [anon_sym_L_DQUOTE] = ACTIONS(2314),
    [anon_sym_u_DQUOTE] = ACTIONS(2314),
    [anon_sym_U_DQUOTE] = ACTIONS(2314),
    [anon_sym_u8_DQUOTE] = ACTIONS(2314),
    [anon_sym_DQUOTE] = ACTIONS(2314),
    [sym_true] = ACTIONS(2312),
    [sym_false] = ACTIONS(2312),
    [anon_sym_NULL] = ACTIONS(2312),
    [anon_sym_nullptr] = ACTIONS(2312),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2312),
    [anon_sym_decltype] = ACTIONS(2312),
    [sym_virtual] = ACTIONS(2312),
    [anon_sym_explicit] = ACTIONS(2312),
    [anon_sym_typename] = ACTIONS(2312),
    [anon_sym_template] = ACTIONS(2312),
    [anon_sym_operator] = ACTIONS(2312),
    [anon_sym_try] = ACTIONS(2312),
    [anon_sym_delete] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2312),
    [anon_sym_namespace] = ACTIONS(2312),
    [anon_sym_using] = ACTIONS(2312),
    [anon_sym_static_assert] = ACTIONS(2312),
    [anon_sym_concept] = ACTIONS(2312),
    [anon_sym_co_return] = ACTIONS(2312),
    [anon_sym_co_yield] = ACTIONS(2312),
    [anon_sym_R_DQUOTE] = ACTIONS(2314),
    [anon_sym_LR_DQUOTE] = ACTIONS(2314),
    [anon_sym_uR_DQUOTE] = ACTIONS(2314),
    [anon_sym_UR_DQUOTE] = ACTIONS(2314),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2314),
    [anon_sym_co_await] = ACTIONS(2312),
    [anon_sym_new] = ACTIONS(2312),
    [anon_sym_requires] = ACTIONS(2312),
    [sym_this] = ACTIONS(2312),
    [anon_sym_discard] = ACTIONS(2312),
    [anon_sym_precise] = ACTIONS(2312),
    [anon_sym_shared] = ACTIONS(2312),
    [anon_sym_groupshared] = ACTIONS(2312),
    [anon_sym_uniform] = ACTIONS(2312),
    [anon_sym_row_major] = ACTIONS(2312),
    [anon_sym_column_major] = ACTIONS(2312),
    [anon_sym_globallycoherent] = ACTIONS(2312),
    [anon_sym_centroid] = ACTIONS(2312),
    [anon_sym_noperspective] = ACTIONS(2312),
    [anon_sym_nointerpolation] = ACTIONS(2312),
    [anon_sym_sample] = ACTIONS(2312),
    [anon_sym_linear] = ACTIONS(2312),
    [anon_sym_snorm] = ACTIONS(2312),
    [anon_sym_unorm] = ACTIONS(2312),
    [anon_sym_point] = ACTIONS(2312),
    [anon_sym_line] = ACTIONS(2312),
    [anon_sym_triangleadj] = ACTIONS(2312),
    [anon_sym_lineadj] = ACTIONS(2312),
    [anon_sym_triangle] = ACTIONS(2312),
    [anon_sym_cbuffer] = ACTIONS(2312),
  },
  [587] = {
    [sym_identifier] = ACTIONS(2308),
    [aux_sym_preproc_include_token1] = ACTIONS(2308),
    [aux_sym_preproc_def_token1] = ACTIONS(2308),
    [aux_sym_preproc_if_token1] = ACTIONS(2308),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2308),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2308),
    [sym_preproc_directive] = ACTIONS(2308),
    [anon_sym_LPAREN2] = ACTIONS(2310),
    [anon_sym_BANG] = ACTIONS(2310),
    [anon_sym_TILDE] = ACTIONS(2310),
    [anon_sym_DASH] = ACTIONS(2308),
    [anon_sym_PLUS] = ACTIONS(2308),
    [anon_sym_STAR] = ACTIONS(2310),
    [anon_sym_AMP_AMP] = ACTIONS(2310),
    [anon_sym_AMP] = ACTIONS(2308),
    [anon_sym_SEMI] = ACTIONS(2310),
    [anon_sym___extension__] = ACTIONS(2308),
    [anon_sym_typedef] = ACTIONS(2308),
    [anon_sym_in] = ACTIONS(2308),
    [anon_sym_out] = ACTIONS(2308),
    [anon_sym_inout] = ACTIONS(2308),
    [anon_sym_extern] = ACTIONS(2308),
    [anon_sym___attribute__] = ACTIONS(2308),
    [anon_sym_COLON_COLON] = ACTIONS(2310),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2310),
    [anon_sym___declspec] = ACTIONS(2308),
    [anon_sym___based] = ACTIONS(2308),
    [anon_sym___cdecl] = ACTIONS(2308),
    [anon_sym___clrcall] = ACTIONS(2308),
    [anon_sym___stdcall] = ACTIONS(2308),
    [anon_sym___fastcall] = ACTIONS(2308),
    [anon_sym___thiscall] = ACTIONS(2308),
    [anon_sym___vectorcall] = ACTIONS(2308),
    [anon_sym_LBRACE] = ACTIONS(2310),
    [anon_sym_RBRACE] = ACTIONS(2310),
    [anon_sym_signed] = ACTIONS(2308),
    [anon_sym_unsigned] = ACTIONS(2308),
    [anon_sym_long] = ACTIONS(2308),
    [anon_sym_short] = ACTIONS(2308),
    [anon_sym_LBRACK] = ACTIONS(2308),
    [anon_sym_static] = ACTIONS(2308),
    [anon_sym_register] = ACTIONS(2308),
    [anon_sym_inline] = ACTIONS(2308),
    [anon_sym___inline] = ACTIONS(2308),
    [anon_sym___inline__] = ACTIONS(2308),
    [anon_sym___forceinline] = ACTIONS(2308),
    [anon_sym_thread_local] = ACTIONS(2308),
    [anon_sym___thread] = ACTIONS(2308),
    [anon_sym_const] = ACTIONS(2308),
    [anon_sym_constexpr] = ACTIONS(2308),
    [anon_sym_volatile] = ACTIONS(2308),
    [anon_sym_restrict] = ACTIONS(2308),
    [anon_sym___restrict__] = ACTIONS(2308),
    [anon_sym__Atomic] = ACTIONS(2308),
    [anon_sym__Noreturn] = ACTIONS(2308),
    [anon_sym_noreturn] = ACTIONS(2308),
    [anon_sym_mutable] = ACTIONS(2308),
    [anon_sym_constinit] = ACTIONS(2308),
    [anon_sym_consteval] = ACTIONS(2308),
    [anon_sym_alignas] = ACTIONS(2308),
    [anon_sym__Alignas] = ACTIONS(2308),
    [sym_primitive_type] = ACTIONS(2308),
    [anon_sym_enum] = ACTIONS(2308),
    [anon_sym_class] = ACTIONS(2308),
    [anon_sym_struct] = ACTIONS(2308),
    [anon_sym_union] = ACTIONS(2308),
    [anon_sym_if] = ACTIONS(2308),
    [anon_sym_switch] = ACTIONS(2308),
    [anon_sym_case] = ACTIONS(2308),
    [anon_sym_default] = ACTIONS(2308),
    [anon_sym_while] = ACTIONS(2308),
    [anon_sym_do] = ACTIONS(2308),
    [anon_sym_for] = ACTIONS(2308),
    [anon_sym_return] = ACTIONS(2308),
    [anon_sym_break] = ACTIONS(2308),
    [anon_sym_continue] = ACTIONS(2308),
    [anon_sym_goto] = ACTIONS(2308),
    [anon_sym___try] = ACTIONS(2308),
    [anon_sym___leave] = ACTIONS(2308),
    [anon_sym_not] = ACTIONS(2308),
    [anon_sym_compl] = ACTIONS(2308),
    [anon_sym_DASH_DASH] = ACTIONS(2310),
    [anon_sym_PLUS_PLUS] = ACTIONS(2310),
    [anon_sym_sizeof] = ACTIONS(2308),
    [anon_sym___alignof__] = ACTIONS(2308),
    [anon_sym___alignof] = ACTIONS(2308),
    [anon_sym__alignof] = ACTIONS(2308),
    [anon_sym_alignof] = ACTIONS(2308),
    [anon_sym__Alignof] = ACTIONS(2308),
    [anon_sym_offsetof] = ACTIONS(2308),
    [anon_sym__Generic] = ACTIONS(2308),
    [anon_sym_asm] = ACTIONS(2308),
    [anon_sym___asm__] = ACTIONS(2308),
    [sym_number_literal] = ACTIONS(2310),
    [anon_sym_L_SQUOTE] = ACTIONS(2310),
    [anon_sym_u_SQUOTE] = ACTIONS(2310),
    [anon_sym_U_SQUOTE] = ACTIONS(2310),
    [anon_sym_u8_SQUOTE] = ACTIONS(2310),
    [anon_sym_SQUOTE] = ACTIONS(2310),
    [anon_sym_L_DQUOTE] = ACTIONS(2310),
    [anon_sym_u_DQUOTE] = ACTIONS(2310),
    [anon_sym_U_DQUOTE] = ACTIONS(2310),
    [anon_sym_u8_DQUOTE] = ACTIONS(2310),
    [anon_sym_DQUOTE] = ACTIONS(2310),
    [sym_true] = ACTIONS(2308),
    [sym_false] = ACTIONS(2308),
    [anon_sym_NULL] = ACTIONS(2308),
    [anon_sym_nullptr] = ACTIONS(2308),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2308),
    [anon_sym_decltype] = ACTIONS(2308),
    [sym_virtual] = ACTIONS(2308),
    [anon_sym_explicit] = ACTIONS(2308),
    [anon_sym_typename] = ACTIONS(2308),
    [anon_sym_template] = ACTIONS(2308),
    [anon_sym_operator] = ACTIONS(2308),
    [anon_sym_try] = ACTIONS(2308),
    [anon_sym_delete] = ACTIONS(2308),
    [anon_sym_throw] = ACTIONS(2308),
    [anon_sym_namespace] = ACTIONS(2308),
    [anon_sym_using] = ACTIONS(2308),
    [anon_sym_static_assert] = ACTIONS(2308),
    [anon_sym_concept] = ACTIONS(2308),
    [anon_sym_co_return] = ACTIONS(2308),
    [anon_sym_co_yield] = ACTIONS(2308),
    [anon_sym_R_DQUOTE] = ACTIONS(2310),
    [anon_sym_LR_DQUOTE] = ACTIONS(2310),
    [anon_sym_uR_DQUOTE] = ACTIONS(2310),
    [anon_sym_UR_DQUOTE] = ACTIONS(2310),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2310),
    [anon_sym_co_await] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(2308),
    [anon_sym_requires] = ACTIONS(2308),
    [sym_this] = ACTIONS(2308),
    [anon_sym_discard] = ACTIONS(2308),
    [anon_sym_precise] = ACTIONS(2308),
    [anon_sym_shared] = ACTIONS(2308),
    [anon_sym_groupshared] = ACTIONS(2308),
    [anon_sym_uniform] = ACTIONS(2308),
    [anon_sym_row_major] = ACTIONS(2308),
    [anon_sym_column_major] = ACTIONS(2308),
    [anon_sym_globallycoherent] = ACTIONS(2308),
    [anon_sym_centroid] = ACTIONS(2308),
    [anon_sym_noperspective] = ACTIONS(2308),
    [anon_sym_nointerpolation] = ACTIONS(2308),
    [anon_sym_sample] = ACTIONS(2308),
    [anon_sym_linear] = ACTIONS(2308),
    [anon_sym_snorm] = ACTIONS(2308),
    [anon_sym_unorm] = ACTIONS(2308),
    [anon_sym_point] = ACTIONS(2308),
    [anon_sym_line] = ACTIONS(2308),
    [anon_sym_triangleadj] = ACTIONS(2308),
    [anon_sym_lineadj] = ACTIONS(2308),
    [anon_sym_triangle] = ACTIONS(2308),
    [anon_sym_cbuffer] = ACTIONS(2308),
  },
  [588] = {
    [sym_identifier] = ACTIONS(2304),
    [aux_sym_preproc_include_token1] = ACTIONS(2304),
    [aux_sym_preproc_def_token1] = ACTIONS(2304),
    [aux_sym_preproc_if_token1] = ACTIONS(2304),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2304),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2304),
    [sym_preproc_directive] = ACTIONS(2304),
    [anon_sym_LPAREN2] = ACTIONS(2306),
    [anon_sym_BANG] = ACTIONS(2306),
    [anon_sym_TILDE] = ACTIONS(2306),
    [anon_sym_DASH] = ACTIONS(2304),
    [anon_sym_PLUS] = ACTIONS(2304),
    [anon_sym_STAR] = ACTIONS(2306),
    [anon_sym_AMP_AMP] = ACTIONS(2306),
    [anon_sym_AMP] = ACTIONS(2304),
    [anon_sym_SEMI] = ACTIONS(2306),
    [anon_sym___extension__] = ACTIONS(2304),
    [anon_sym_typedef] = ACTIONS(2304),
    [anon_sym_in] = ACTIONS(2304),
    [anon_sym_out] = ACTIONS(2304),
    [anon_sym_inout] = ACTIONS(2304),
    [anon_sym_extern] = ACTIONS(2304),
    [anon_sym___attribute__] = ACTIONS(2304),
    [anon_sym_COLON_COLON] = ACTIONS(2306),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2306),
    [anon_sym___declspec] = ACTIONS(2304),
    [anon_sym___based] = ACTIONS(2304),
    [anon_sym___cdecl] = ACTIONS(2304),
    [anon_sym___clrcall] = ACTIONS(2304),
    [anon_sym___stdcall] = ACTIONS(2304),
    [anon_sym___fastcall] = ACTIONS(2304),
    [anon_sym___thiscall] = ACTIONS(2304),
    [anon_sym___vectorcall] = ACTIONS(2304),
    [anon_sym_LBRACE] = ACTIONS(2306),
    [anon_sym_RBRACE] = ACTIONS(2306),
    [anon_sym_signed] = ACTIONS(2304),
    [anon_sym_unsigned] = ACTIONS(2304),
    [anon_sym_long] = ACTIONS(2304),
    [anon_sym_short] = ACTIONS(2304),
    [anon_sym_LBRACK] = ACTIONS(2304),
    [anon_sym_static] = ACTIONS(2304),
    [anon_sym_register] = ACTIONS(2304),
    [anon_sym_inline] = ACTIONS(2304),
    [anon_sym___inline] = ACTIONS(2304),
    [anon_sym___inline__] = ACTIONS(2304),
    [anon_sym___forceinline] = ACTIONS(2304),
    [anon_sym_thread_local] = ACTIONS(2304),
    [anon_sym___thread] = ACTIONS(2304),
    [anon_sym_const] = ACTIONS(2304),
    [anon_sym_constexpr] = ACTIONS(2304),
    [anon_sym_volatile] = ACTIONS(2304),
    [anon_sym_restrict] = ACTIONS(2304),
    [anon_sym___restrict__] = ACTIONS(2304),
    [anon_sym__Atomic] = ACTIONS(2304),
    [anon_sym__Noreturn] = ACTIONS(2304),
    [anon_sym_noreturn] = ACTIONS(2304),
    [anon_sym_mutable] = ACTIONS(2304),
    [anon_sym_constinit] = ACTIONS(2304),
    [anon_sym_consteval] = ACTIONS(2304),
    [anon_sym_alignas] = ACTIONS(2304),
    [anon_sym__Alignas] = ACTIONS(2304),
    [sym_primitive_type] = ACTIONS(2304),
    [anon_sym_enum] = ACTIONS(2304),
    [anon_sym_class] = ACTIONS(2304),
    [anon_sym_struct] = ACTIONS(2304),
    [anon_sym_union] = ACTIONS(2304),
    [anon_sym_if] = ACTIONS(2304),
    [anon_sym_switch] = ACTIONS(2304),
    [anon_sym_case] = ACTIONS(2304),
    [anon_sym_default] = ACTIONS(2304),
    [anon_sym_while] = ACTIONS(2304),
    [anon_sym_do] = ACTIONS(2304),
    [anon_sym_for] = ACTIONS(2304),
    [anon_sym_return] = ACTIONS(2304),
    [anon_sym_break] = ACTIONS(2304),
    [anon_sym_continue] = ACTIONS(2304),
    [anon_sym_goto] = ACTIONS(2304),
    [anon_sym___try] = ACTIONS(2304),
    [anon_sym___leave] = ACTIONS(2304),
    [anon_sym_not] = ACTIONS(2304),
    [anon_sym_compl] = ACTIONS(2304),
    [anon_sym_DASH_DASH] = ACTIONS(2306),
    [anon_sym_PLUS_PLUS] = ACTIONS(2306),
    [anon_sym_sizeof] = ACTIONS(2304),
    [anon_sym___alignof__] = ACTIONS(2304),
    [anon_sym___alignof] = ACTIONS(2304),
    [anon_sym__alignof] = ACTIONS(2304),
    [anon_sym_alignof] = ACTIONS(2304),
    [anon_sym__Alignof] = ACTIONS(2304),
    [anon_sym_offsetof] = ACTIONS(2304),
    [anon_sym__Generic] = ACTIONS(2304),
    [anon_sym_asm] = ACTIONS(2304),
    [anon_sym___asm__] = ACTIONS(2304),
    [sym_number_literal] = ACTIONS(2306),
    [anon_sym_L_SQUOTE] = ACTIONS(2306),
    [anon_sym_u_SQUOTE] = ACTIONS(2306),
    [anon_sym_U_SQUOTE] = ACTIONS(2306),
    [anon_sym_u8_SQUOTE] = ACTIONS(2306),
    [anon_sym_SQUOTE] = ACTIONS(2306),
    [anon_sym_L_DQUOTE] = ACTIONS(2306),
    [anon_sym_u_DQUOTE] = ACTIONS(2306),
    [anon_sym_U_DQUOTE] = ACTIONS(2306),
    [anon_sym_u8_DQUOTE] = ACTIONS(2306),
    [anon_sym_DQUOTE] = ACTIONS(2306),
    [sym_true] = ACTIONS(2304),
    [sym_false] = ACTIONS(2304),
    [anon_sym_NULL] = ACTIONS(2304),
    [anon_sym_nullptr] = ACTIONS(2304),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2304),
    [anon_sym_decltype] = ACTIONS(2304),
    [sym_virtual] = ACTIONS(2304),
    [anon_sym_explicit] = ACTIONS(2304),
    [anon_sym_typename] = ACTIONS(2304),
    [anon_sym_template] = ACTIONS(2304),
    [anon_sym_operator] = ACTIONS(2304),
    [anon_sym_try] = ACTIONS(2304),
    [anon_sym_delete] = ACTIONS(2304),
    [anon_sym_throw] = ACTIONS(2304),
    [anon_sym_namespace] = ACTIONS(2304),
    [anon_sym_using] = ACTIONS(2304),
    [anon_sym_static_assert] = ACTIONS(2304),
    [anon_sym_concept] = ACTIONS(2304),
    [anon_sym_co_return] = ACTIONS(2304),
    [anon_sym_co_yield] = ACTIONS(2304),
    [anon_sym_R_DQUOTE] = ACTIONS(2306),
    [anon_sym_LR_DQUOTE] = ACTIONS(2306),
    [anon_sym_uR_DQUOTE] = ACTIONS(2306),
    [anon_sym_UR_DQUOTE] = ACTIONS(2306),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2306),
    [anon_sym_co_await] = ACTIONS(2304),
    [anon_sym_new] = ACTIONS(2304),
    [anon_sym_requires] = ACTIONS(2304),
    [sym_this] = ACTIONS(2304),
    [anon_sym_discard] = ACTIONS(2304),
    [anon_sym_precise] = ACTIONS(2304),
    [anon_sym_shared] = ACTIONS(2304),
    [anon_sym_groupshared] = ACTIONS(2304),
    [anon_sym_uniform] = ACTIONS(2304),
    [anon_sym_row_major] = ACTIONS(2304),
    [anon_sym_column_major] = ACTIONS(2304),
    [anon_sym_globallycoherent] = ACTIONS(2304),
    [anon_sym_centroid] = ACTIONS(2304),
    [anon_sym_noperspective] = ACTIONS(2304),
    [anon_sym_nointerpolation] = ACTIONS(2304),
    [anon_sym_sample] = ACTIONS(2304),
    [anon_sym_linear] = ACTIONS(2304),
    [anon_sym_snorm] = ACTIONS(2304),
    [anon_sym_unorm] = ACTIONS(2304),
    [anon_sym_point] = ACTIONS(2304),
    [anon_sym_line] = ACTIONS(2304),
    [anon_sym_triangleadj] = ACTIONS(2304),
    [anon_sym_lineadj] = ACTIONS(2304),
    [anon_sym_triangle] = ACTIONS(2304),
    [anon_sym_cbuffer] = ACTIONS(2304),
  },
  [589] = {
    [sym_identifier] = ACTIONS(2300),
    [aux_sym_preproc_include_token1] = ACTIONS(2300),
    [aux_sym_preproc_def_token1] = ACTIONS(2300),
    [aux_sym_preproc_if_token1] = ACTIONS(2300),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2300),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2300),
    [sym_preproc_directive] = ACTIONS(2300),
    [anon_sym_LPAREN2] = ACTIONS(2302),
    [anon_sym_BANG] = ACTIONS(2302),
    [anon_sym_TILDE] = ACTIONS(2302),
    [anon_sym_DASH] = ACTIONS(2300),
    [anon_sym_PLUS] = ACTIONS(2300),
    [anon_sym_STAR] = ACTIONS(2302),
    [anon_sym_AMP_AMP] = ACTIONS(2302),
    [anon_sym_AMP] = ACTIONS(2300),
    [anon_sym_SEMI] = ACTIONS(2302),
    [anon_sym___extension__] = ACTIONS(2300),
    [anon_sym_typedef] = ACTIONS(2300),
    [anon_sym_in] = ACTIONS(2300),
    [anon_sym_out] = ACTIONS(2300),
    [anon_sym_inout] = ACTIONS(2300),
    [anon_sym_extern] = ACTIONS(2300),
    [anon_sym___attribute__] = ACTIONS(2300),
    [anon_sym_COLON_COLON] = ACTIONS(2302),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2302),
    [anon_sym___declspec] = ACTIONS(2300),
    [anon_sym___based] = ACTIONS(2300),
    [anon_sym___cdecl] = ACTIONS(2300),
    [anon_sym___clrcall] = ACTIONS(2300),
    [anon_sym___stdcall] = ACTIONS(2300),
    [anon_sym___fastcall] = ACTIONS(2300),
    [anon_sym___thiscall] = ACTIONS(2300),
    [anon_sym___vectorcall] = ACTIONS(2300),
    [anon_sym_LBRACE] = ACTIONS(2302),
    [anon_sym_RBRACE] = ACTIONS(2302),
    [anon_sym_signed] = ACTIONS(2300),
    [anon_sym_unsigned] = ACTIONS(2300),
    [anon_sym_long] = ACTIONS(2300),
    [anon_sym_short] = ACTIONS(2300),
    [anon_sym_LBRACK] = ACTIONS(2300),
    [anon_sym_static] = ACTIONS(2300),
    [anon_sym_register] = ACTIONS(2300),
    [anon_sym_inline] = ACTIONS(2300),
    [anon_sym___inline] = ACTIONS(2300),
    [anon_sym___inline__] = ACTIONS(2300),
    [anon_sym___forceinline] = ACTIONS(2300),
    [anon_sym_thread_local] = ACTIONS(2300),
    [anon_sym___thread] = ACTIONS(2300),
    [anon_sym_const] = ACTIONS(2300),
    [anon_sym_constexpr] = ACTIONS(2300),
    [anon_sym_volatile] = ACTIONS(2300),
    [anon_sym_restrict] = ACTIONS(2300),
    [anon_sym___restrict__] = ACTIONS(2300),
    [anon_sym__Atomic] = ACTIONS(2300),
    [anon_sym__Noreturn] = ACTIONS(2300),
    [anon_sym_noreturn] = ACTIONS(2300),
    [anon_sym_mutable] = ACTIONS(2300),
    [anon_sym_constinit] = ACTIONS(2300),
    [anon_sym_consteval] = ACTIONS(2300),
    [anon_sym_alignas] = ACTIONS(2300),
    [anon_sym__Alignas] = ACTIONS(2300),
    [sym_primitive_type] = ACTIONS(2300),
    [anon_sym_enum] = ACTIONS(2300),
    [anon_sym_class] = ACTIONS(2300),
    [anon_sym_struct] = ACTIONS(2300),
    [anon_sym_union] = ACTIONS(2300),
    [anon_sym_if] = ACTIONS(2300),
    [anon_sym_switch] = ACTIONS(2300),
    [anon_sym_case] = ACTIONS(2300),
    [anon_sym_default] = ACTIONS(2300),
    [anon_sym_while] = ACTIONS(2300),
    [anon_sym_do] = ACTIONS(2300),
    [anon_sym_for] = ACTIONS(2300),
    [anon_sym_return] = ACTIONS(2300),
    [anon_sym_break] = ACTIONS(2300),
    [anon_sym_continue] = ACTIONS(2300),
    [anon_sym_goto] = ACTIONS(2300),
    [anon_sym___try] = ACTIONS(2300),
    [anon_sym___leave] = ACTIONS(2300),
    [anon_sym_not] = ACTIONS(2300),
    [anon_sym_compl] = ACTIONS(2300),
    [anon_sym_DASH_DASH] = ACTIONS(2302),
    [anon_sym_PLUS_PLUS] = ACTIONS(2302),
    [anon_sym_sizeof] = ACTIONS(2300),
    [anon_sym___alignof__] = ACTIONS(2300),
    [anon_sym___alignof] = ACTIONS(2300),
    [anon_sym__alignof] = ACTIONS(2300),
    [anon_sym_alignof] = ACTIONS(2300),
    [anon_sym__Alignof] = ACTIONS(2300),
    [anon_sym_offsetof] = ACTIONS(2300),
    [anon_sym__Generic] = ACTIONS(2300),
    [anon_sym_asm] = ACTIONS(2300),
    [anon_sym___asm__] = ACTIONS(2300),
    [sym_number_literal] = ACTIONS(2302),
    [anon_sym_L_SQUOTE] = ACTIONS(2302),
    [anon_sym_u_SQUOTE] = ACTIONS(2302),
    [anon_sym_U_SQUOTE] = ACTIONS(2302),
    [anon_sym_u8_SQUOTE] = ACTIONS(2302),
    [anon_sym_SQUOTE] = ACTIONS(2302),
    [anon_sym_L_DQUOTE] = ACTIONS(2302),
    [anon_sym_u_DQUOTE] = ACTIONS(2302),
    [anon_sym_U_DQUOTE] = ACTIONS(2302),
    [anon_sym_u8_DQUOTE] = ACTIONS(2302),
    [anon_sym_DQUOTE] = ACTIONS(2302),
    [sym_true] = ACTIONS(2300),
    [sym_false] = ACTIONS(2300),
    [anon_sym_NULL] = ACTIONS(2300),
    [anon_sym_nullptr] = ACTIONS(2300),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2300),
    [anon_sym_decltype] = ACTIONS(2300),
    [sym_virtual] = ACTIONS(2300),
    [anon_sym_explicit] = ACTIONS(2300),
    [anon_sym_typename] = ACTIONS(2300),
    [anon_sym_template] = ACTIONS(2300),
    [anon_sym_operator] = ACTIONS(2300),
    [anon_sym_try] = ACTIONS(2300),
    [anon_sym_delete] = ACTIONS(2300),
    [anon_sym_throw] = ACTIONS(2300),
    [anon_sym_namespace] = ACTIONS(2300),
    [anon_sym_using] = ACTIONS(2300),
    [anon_sym_static_assert] = ACTIONS(2300),
    [anon_sym_concept] = ACTIONS(2300),
    [anon_sym_co_return] = ACTIONS(2300),
    [anon_sym_co_yield] = ACTIONS(2300),
    [anon_sym_R_DQUOTE] = ACTIONS(2302),
    [anon_sym_LR_DQUOTE] = ACTIONS(2302),
    [anon_sym_uR_DQUOTE] = ACTIONS(2302),
    [anon_sym_UR_DQUOTE] = ACTIONS(2302),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2302),
    [anon_sym_co_await] = ACTIONS(2300),
    [anon_sym_new] = ACTIONS(2300),
    [anon_sym_requires] = ACTIONS(2300),
    [sym_this] = ACTIONS(2300),
    [anon_sym_discard] = ACTIONS(2300),
    [anon_sym_precise] = ACTIONS(2300),
    [anon_sym_shared] = ACTIONS(2300),
    [anon_sym_groupshared] = ACTIONS(2300),
    [anon_sym_uniform] = ACTIONS(2300),
    [anon_sym_row_major] = ACTIONS(2300),
    [anon_sym_column_major] = ACTIONS(2300),
    [anon_sym_globallycoherent] = ACTIONS(2300),
    [anon_sym_centroid] = ACTIONS(2300),
    [anon_sym_noperspective] = ACTIONS(2300),
    [anon_sym_nointerpolation] = ACTIONS(2300),
    [anon_sym_sample] = ACTIONS(2300),
    [anon_sym_linear] = ACTIONS(2300),
    [anon_sym_snorm] = ACTIONS(2300),
    [anon_sym_unorm] = ACTIONS(2300),
    [anon_sym_point] = ACTIONS(2300),
    [anon_sym_line] = ACTIONS(2300),
    [anon_sym_triangleadj] = ACTIONS(2300),
    [anon_sym_lineadj] = ACTIONS(2300),
    [anon_sym_triangle] = ACTIONS(2300),
    [anon_sym_cbuffer] = ACTIONS(2300),
  },
  [590] = {
    [sym_identifier] = ACTIONS(2458),
    [aux_sym_preproc_include_token1] = ACTIONS(2458),
    [aux_sym_preproc_def_token1] = ACTIONS(2458),
    [aux_sym_preproc_if_token1] = ACTIONS(2458),
    [aux_sym_preproc_if_token2] = ACTIONS(2458),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2458),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2458),
    [sym_preproc_directive] = ACTIONS(2458),
    [anon_sym_LPAREN2] = ACTIONS(2460),
    [anon_sym_BANG] = ACTIONS(2460),
    [anon_sym_TILDE] = ACTIONS(2460),
    [anon_sym_DASH] = ACTIONS(2458),
    [anon_sym_PLUS] = ACTIONS(2458),
    [anon_sym_STAR] = ACTIONS(2460),
    [anon_sym_AMP_AMP] = ACTIONS(2460),
    [anon_sym_AMP] = ACTIONS(2458),
    [anon_sym_SEMI] = ACTIONS(2460),
    [anon_sym___extension__] = ACTIONS(2458),
    [anon_sym_typedef] = ACTIONS(2458),
    [anon_sym_in] = ACTIONS(2458),
    [anon_sym_out] = ACTIONS(2458),
    [anon_sym_inout] = ACTIONS(2458),
    [anon_sym_extern] = ACTIONS(2458),
    [anon_sym___attribute__] = ACTIONS(2458),
    [anon_sym_COLON_COLON] = ACTIONS(2460),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2460),
    [anon_sym___declspec] = ACTIONS(2458),
    [anon_sym___based] = ACTIONS(2458),
    [anon_sym___cdecl] = ACTIONS(2458),
    [anon_sym___clrcall] = ACTIONS(2458),
    [anon_sym___stdcall] = ACTIONS(2458),
    [anon_sym___fastcall] = ACTIONS(2458),
    [anon_sym___thiscall] = ACTIONS(2458),
    [anon_sym___vectorcall] = ACTIONS(2458),
    [anon_sym_LBRACE] = ACTIONS(2460),
    [anon_sym_signed] = ACTIONS(2458),
    [anon_sym_unsigned] = ACTIONS(2458),
    [anon_sym_long] = ACTIONS(2458),
    [anon_sym_short] = ACTIONS(2458),
    [anon_sym_LBRACK] = ACTIONS(2458),
    [anon_sym_static] = ACTIONS(2458),
    [anon_sym_register] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(2458),
    [anon_sym___inline] = ACTIONS(2458),
    [anon_sym___inline__] = ACTIONS(2458),
    [anon_sym___forceinline] = ACTIONS(2458),
    [anon_sym_thread_local] = ACTIONS(2458),
    [anon_sym___thread] = ACTIONS(2458),
    [anon_sym_const] = ACTIONS(2458),
    [anon_sym_constexpr] = ACTIONS(2458),
    [anon_sym_volatile] = ACTIONS(2458),
    [anon_sym_restrict] = ACTIONS(2458),
    [anon_sym___restrict__] = ACTIONS(2458),
    [anon_sym__Atomic] = ACTIONS(2458),
    [anon_sym__Noreturn] = ACTIONS(2458),
    [anon_sym_noreturn] = ACTIONS(2458),
    [anon_sym_mutable] = ACTIONS(2458),
    [anon_sym_constinit] = ACTIONS(2458),
    [anon_sym_consteval] = ACTIONS(2458),
    [anon_sym_alignas] = ACTIONS(2458),
    [anon_sym__Alignas] = ACTIONS(2458),
    [sym_primitive_type] = ACTIONS(2458),
    [anon_sym_enum] = ACTIONS(2458),
    [anon_sym_class] = ACTIONS(2458),
    [anon_sym_struct] = ACTIONS(2458),
    [anon_sym_union] = ACTIONS(2458),
    [anon_sym_if] = ACTIONS(2458),
    [anon_sym_switch] = ACTIONS(2458),
    [anon_sym_case] = ACTIONS(2458),
    [anon_sym_default] = ACTIONS(2458),
    [anon_sym_while] = ACTIONS(2458),
    [anon_sym_do] = ACTIONS(2458),
    [anon_sym_for] = ACTIONS(2458),
    [anon_sym_return] = ACTIONS(2458),
    [anon_sym_break] = ACTIONS(2458),
    [anon_sym_continue] = ACTIONS(2458),
    [anon_sym_goto] = ACTIONS(2458),
    [anon_sym___try] = ACTIONS(2458),
    [anon_sym___leave] = ACTIONS(2458),
    [anon_sym_not] = ACTIONS(2458),
    [anon_sym_compl] = ACTIONS(2458),
    [anon_sym_DASH_DASH] = ACTIONS(2460),
    [anon_sym_PLUS_PLUS] = ACTIONS(2460),
    [anon_sym_sizeof] = ACTIONS(2458),
    [anon_sym___alignof__] = ACTIONS(2458),
    [anon_sym___alignof] = ACTIONS(2458),
    [anon_sym__alignof] = ACTIONS(2458),
    [anon_sym_alignof] = ACTIONS(2458),
    [anon_sym__Alignof] = ACTIONS(2458),
    [anon_sym_offsetof] = ACTIONS(2458),
    [anon_sym__Generic] = ACTIONS(2458),
    [anon_sym_asm] = ACTIONS(2458),
    [anon_sym___asm__] = ACTIONS(2458),
    [sym_number_literal] = ACTIONS(2460),
    [anon_sym_L_SQUOTE] = ACTIONS(2460),
    [anon_sym_u_SQUOTE] = ACTIONS(2460),
    [anon_sym_U_SQUOTE] = ACTIONS(2460),
    [anon_sym_u8_SQUOTE] = ACTIONS(2460),
    [anon_sym_SQUOTE] = ACTIONS(2460),
    [anon_sym_L_DQUOTE] = ACTIONS(2460),
    [anon_sym_u_DQUOTE] = ACTIONS(2460),
    [anon_sym_U_DQUOTE] = ACTIONS(2460),
    [anon_sym_u8_DQUOTE] = ACTIONS(2460),
    [anon_sym_DQUOTE] = ACTIONS(2460),
    [sym_true] = ACTIONS(2458),
    [sym_false] = ACTIONS(2458),
    [anon_sym_NULL] = ACTIONS(2458),
    [anon_sym_nullptr] = ACTIONS(2458),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2458),
    [anon_sym_decltype] = ACTIONS(2458),
    [sym_virtual] = ACTIONS(2458),
    [anon_sym_explicit] = ACTIONS(2458),
    [anon_sym_typename] = ACTIONS(2458),
    [anon_sym_template] = ACTIONS(2458),
    [anon_sym_operator] = ACTIONS(2458),
    [anon_sym_try] = ACTIONS(2458),
    [anon_sym_delete] = ACTIONS(2458),
    [anon_sym_throw] = ACTIONS(2458),
    [anon_sym_namespace] = ACTIONS(2458),
    [anon_sym_using] = ACTIONS(2458),
    [anon_sym_static_assert] = ACTIONS(2458),
    [anon_sym_concept] = ACTIONS(2458),
    [anon_sym_co_return] = ACTIONS(2458),
    [anon_sym_co_yield] = ACTIONS(2458),
    [anon_sym_R_DQUOTE] = ACTIONS(2460),
    [anon_sym_LR_DQUOTE] = ACTIONS(2460),
    [anon_sym_uR_DQUOTE] = ACTIONS(2460),
    [anon_sym_UR_DQUOTE] = ACTIONS(2460),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2460),
    [anon_sym_co_await] = ACTIONS(2458),
    [anon_sym_new] = ACTIONS(2458),
    [anon_sym_requires] = ACTIONS(2458),
    [sym_this] = ACTIONS(2458),
    [anon_sym_discard] = ACTIONS(2458),
    [anon_sym_precise] = ACTIONS(2458),
    [anon_sym_shared] = ACTIONS(2458),
    [anon_sym_groupshared] = ACTIONS(2458),
    [anon_sym_uniform] = ACTIONS(2458),
    [anon_sym_row_major] = ACTIONS(2458),
    [anon_sym_column_major] = ACTIONS(2458),
    [anon_sym_globallycoherent] = ACTIONS(2458),
    [anon_sym_centroid] = ACTIONS(2458),
    [anon_sym_noperspective] = ACTIONS(2458),
    [anon_sym_nointerpolation] = ACTIONS(2458),
    [anon_sym_sample] = ACTIONS(2458),
    [anon_sym_linear] = ACTIONS(2458),
    [anon_sym_snorm] = ACTIONS(2458),
    [anon_sym_unorm] = ACTIONS(2458),
    [anon_sym_point] = ACTIONS(2458),
    [anon_sym_line] = ACTIONS(2458),
    [anon_sym_triangleadj] = ACTIONS(2458),
    [anon_sym_lineadj] = ACTIONS(2458),
    [anon_sym_triangle] = ACTIONS(2458),
    [anon_sym_cbuffer] = ACTIONS(2458),
  },
  [591] = {
    [sym_identifier] = ACTIONS(2498),
    [aux_sym_preproc_include_token1] = ACTIONS(2498),
    [aux_sym_preproc_def_token1] = ACTIONS(2498),
    [aux_sym_preproc_if_token1] = ACTIONS(2498),
    [aux_sym_preproc_if_token2] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2498),
    [sym_preproc_directive] = ACTIONS(2498),
    [anon_sym_LPAREN2] = ACTIONS(2500),
    [anon_sym_BANG] = ACTIONS(2500),
    [anon_sym_TILDE] = ACTIONS(2500),
    [anon_sym_DASH] = ACTIONS(2498),
    [anon_sym_PLUS] = ACTIONS(2498),
    [anon_sym_STAR] = ACTIONS(2500),
    [anon_sym_AMP_AMP] = ACTIONS(2500),
    [anon_sym_AMP] = ACTIONS(2498),
    [anon_sym_SEMI] = ACTIONS(2500),
    [anon_sym___extension__] = ACTIONS(2498),
    [anon_sym_typedef] = ACTIONS(2498),
    [anon_sym_in] = ACTIONS(2498),
    [anon_sym_out] = ACTIONS(2498),
    [anon_sym_inout] = ACTIONS(2498),
    [anon_sym_extern] = ACTIONS(2498),
    [anon_sym___attribute__] = ACTIONS(2498),
    [anon_sym_COLON_COLON] = ACTIONS(2500),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2500),
    [anon_sym___declspec] = ACTIONS(2498),
    [anon_sym___based] = ACTIONS(2498),
    [anon_sym___cdecl] = ACTIONS(2498),
    [anon_sym___clrcall] = ACTIONS(2498),
    [anon_sym___stdcall] = ACTIONS(2498),
    [anon_sym___fastcall] = ACTIONS(2498),
    [anon_sym___thiscall] = ACTIONS(2498),
    [anon_sym___vectorcall] = ACTIONS(2498),
    [anon_sym_LBRACE] = ACTIONS(2500),
    [anon_sym_signed] = ACTIONS(2498),
    [anon_sym_unsigned] = ACTIONS(2498),
    [anon_sym_long] = ACTIONS(2498),
    [anon_sym_short] = ACTIONS(2498),
    [anon_sym_LBRACK] = ACTIONS(2498),
    [anon_sym_static] = ACTIONS(2498),
    [anon_sym_register] = ACTIONS(2498),
    [anon_sym_inline] = ACTIONS(2498),
    [anon_sym___inline] = ACTIONS(2498),
    [anon_sym___inline__] = ACTIONS(2498),
    [anon_sym___forceinline] = ACTIONS(2498),
    [anon_sym_thread_local] = ACTIONS(2498),
    [anon_sym___thread] = ACTIONS(2498),
    [anon_sym_const] = ACTIONS(2498),
    [anon_sym_constexpr] = ACTIONS(2498),
    [anon_sym_volatile] = ACTIONS(2498),
    [anon_sym_restrict] = ACTIONS(2498),
    [anon_sym___restrict__] = ACTIONS(2498),
    [anon_sym__Atomic] = ACTIONS(2498),
    [anon_sym__Noreturn] = ACTIONS(2498),
    [anon_sym_noreturn] = ACTIONS(2498),
    [anon_sym_mutable] = ACTIONS(2498),
    [anon_sym_constinit] = ACTIONS(2498),
    [anon_sym_consteval] = ACTIONS(2498),
    [anon_sym_alignas] = ACTIONS(2498),
    [anon_sym__Alignas] = ACTIONS(2498),
    [sym_primitive_type] = ACTIONS(2498),
    [anon_sym_enum] = ACTIONS(2498),
    [anon_sym_class] = ACTIONS(2498),
    [anon_sym_struct] = ACTIONS(2498),
    [anon_sym_union] = ACTIONS(2498),
    [anon_sym_if] = ACTIONS(2498),
    [anon_sym_switch] = ACTIONS(2498),
    [anon_sym_case] = ACTIONS(2498),
    [anon_sym_default] = ACTIONS(2498),
    [anon_sym_while] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(2498),
    [anon_sym_for] = ACTIONS(2498),
    [anon_sym_return] = ACTIONS(2498),
    [anon_sym_break] = ACTIONS(2498),
    [anon_sym_continue] = ACTIONS(2498),
    [anon_sym_goto] = ACTIONS(2498),
    [anon_sym___try] = ACTIONS(2498),
    [anon_sym___leave] = ACTIONS(2498),
    [anon_sym_not] = ACTIONS(2498),
    [anon_sym_compl] = ACTIONS(2498),
    [anon_sym_DASH_DASH] = ACTIONS(2500),
    [anon_sym_PLUS_PLUS] = ACTIONS(2500),
    [anon_sym_sizeof] = ACTIONS(2498),
    [anon_sym___alignof__] = ACTIONS(2498),
    [anon_sym___alignof] = ACTIONS(2498),
    [anon_sym__alignof] = ACTIONS(2498),
    [anon_sym_alignof] = ACTIONS(2498),
    [anon_sym__Alignof] = ACTIONS(2498),
    [anon_sym_offsetof] = ACTIONS(2498),
    [anon_sym__Generic] = ACTIONS(2498),
    [anon_sym_asm] = ACTIONS(2498),
    [anon_sym___asm__] = ACTIONS(2498),
    [sym_number_literal] = ACTIONS(2500),
    [anon_sym_L_SQUOTE] = ACTIONS(2500),
    [anon_sym_u_SQUOTE] = ACTIONS(2500),
    [anon_sym_U_SQUOTE] = ACTIONS(2500),
    [anon_sym_u8_SQUOTE] = ACTIONS(2500),
    [anon_sym_SQUOTE] = ACTIONS(2500),
    [anon_sym_L_DQUOTE] = ACTIONS(2500),
    [anon_sym_u_DQUOTE] = ACTIONS(2500),
    [anon_sym_U_DQUOTE] = ACTIONS(2500),
    [anon_sym_u8_DQUOTE] = ACTIONS(2500),
    [anon_sym_DQUOTE] = ACTIONS(2500),
    [sym_true] = ACTIONS(2498),
    [sym_false] = ACTIONS(2498),
    [anon_sym_NULL] = ACTIONS(2498),
    [anon_sym_nullptr] = ACTIONS(2498),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2498),
    [anon_sym_decltype] = ACTIONS(2498),
    [sym_virtual] = ACTIONS(2498),
    [anon_sym_explicit] = ACTIONS(2498),
    [anon_sym_typename] = ACTIONS(2498),
    [anon_sym_template] = ACTIONS(2498),
    [anon_sym_operator] = ACTIONS(2498),
    [anon_sym_try] = ACTIONS(2498),
    [anon_sym_delete] = ACTIONS(2498),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_namespace] = ACTIONS(2498),
    [anon_sym_using] = ACTIONS(2498),
    [anon_sym_static_assert] = ACTIONS(2498),
    [anon_sym_concept] = ACTIONS(2498),
    [anon_sym_co_return] = ACTIONS(2498),
    [anon_sym_co_yield] = ACTIONS(2498),
    [anon_sym_R_DQUOTE] = ACTIONS(2500),
    [anon_sym_LR_DQUOTE] = ACTIONS(2500),
    [anon_sym_uR_DQUOTE] = ACTIONS(2500),
    [anon_sym_UR_DQUOTE] = ACTIONS(2500),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2500),
    [anon_sym_co_await] = ACTIONS(2498),
    [anon_sym_new] = ACTIONS(2498),
    [anon_sym_requires] = ACTIONS(2498),
    [sym_this] = ACTIONS(2498),
    [anon_sym_discard] = ACTIONS(2498),
    [anon_sym_precise] = ACTIONS(2498),
    [anon_sym_shared] = ACTIONS(2498),
    [anon_sym_groupshared] = ACTIONS(2498),
    [anon_sym_uniform] = ACTIONS(2498),
    [anon_sym_row_major] = ACTIONS(2498),
    [anon_sym_column_major] = ACTIONS(2498),
    [anon_sym_globallycoherent] = ACTIONS(2498),
    [anon_sym_centroid] = ACTIONS(2498),
    [anon_sym_noperspective] = ACTIONS(2498),
    [anon_sym_nointerpolation] = ACTIONS(2498),
    [anon_sym_sample] = ACTIONS(2498),
    [anon_sym_linear] = ACTIONS(2498),
    [anon_sym_snorm] = ACTIONS(2498),
    [anon_sym_unorm] = ACTIONS(2498),
    [anon_sym_point] = ACTIONS(2498),
    [anon_sym_line] = ACTIONS(2498),
    [anon_sym_triangleadj] = ACTIONS(2498),
    [anon_sym_lineadj] = ACTIONS(2498),
    [anon_sym_triangle] = ACTIONS(2498),
    [anon_sym_cbuffer] = ACTIONS(2498),
  },
  [592] = {
    [sym_identifier] = ACTIONS(2498),
    [aux_sym_preproc_include_token1] = ACTIONS(2498),
    [aux_sym_preproc_def_token1] = ACTIONS(2498),
    [aux_sym_preproc_if_token1] = ACTIONS(2498),
    [aux_sym_preproc_if_token2] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2498),
    [sym_preproc_directive] = ACTIONS(2498),
    [anon_sym_LPAREN2] = ACTIONS(2500),
    [anon_sym_BANG] = ACTIONS(2500),
    [anon_sym_TILDE] = ACTIONS(2500),
    [anon_sym_DASH] = ACTIONS(2498),
    [anon_sym_PLUS] = ACTIONS(2498),
    [anon_sym_STAR] = ACTIONS(2500),
    [anon_sym_AMP_AMP] = ACTIONS(2500),
    [anon_sym_AMP] = ACTIONS(2498),
    [anon_sym_SEMI] = ACTIONS(2500),
    [anon_sym___extension__] = ACTIONS(2498),
    [anon_sym_typedef] = ACTIONS(2498),
    [anon_sym_in] = ACTIONS(2498),
    [anon_sym_out] = ACTIONS(2498),
    [anon_sym_inout] = ACTIONS(2498),
    [anon_sym_extern] = ACTIONS(2498),
    [anon_sym___attribute__] = ACTIONS(2498),
    [anon_sym_COLON_COLON] = ACTIONS(2500),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2500),
    [anon_sym___declspec] = ACTIONS(2498),
    [anon_sym___based] = ACTIONS(2498),
    [anon_sym___cdecl] = ACTIONS(2498),
    [anon_sym___clrcall] = ACTIONS(2498),
    [anon_sym___stdcall] = ACTIONS(2498),
    [anon_sym___fastcall] = ACTIONS(2498),
    [anon_sym___thiscall] = ACTIONS(2498),
    [anon_sym___vectorcall] = ACTIONS(2498),
    [anon_sym_LBRACE] = ACTIONS(2500),
    [anon_sym_signed] = ACTIONS(2498),
    [anon_sym_unsigned] = ACTIONS(2498),
    [anon_sym_long] = ACTIONS(2498),
    [anon_sym_short] = ACTIONS(2498),
    [anon_sym_LBRACK] = ACTIONS(2498),
    [anon_sym_static] = ACTIONS(2498),
    [anon_sym_register] = ACTIONS(2498),
    [anon_sym_inline] = ACTIONS(2498),
    [anon_sym___inline] = ACTIONS(2498),
    [anon_sym___inline__] = ACTIONS(2498),
    [anon_sym___forceinline] = ACTIONS(2498),
    [anon_sym_thread_local] = ACTIONS(2498),
    [anon_sym___thread] = ACTIONS(2498),
    [anon_sym_const] = ACTIONS(2498),
    [anon_sym_constexpr] = ACTIONS(2498),
    [anon_sym_volatile] = ACTIONS(2498),
    [anon_sym_restrict] = ACTIONS(2498),
    [anon_sym___restrict__] = ACTIONS(2498),
    [anon_sym__Atomic] = ACTIONS(2498),
    [anon_sym__Noreturn] = ACTIONS(2498),
    [anon_sym_noreturn] = ACTIONS(2498),
    [anon_sym_mutable] = ACTIONS(2498),
    [anon_sym_constinit] = ACTIONS(2498),
    [anon_sym_consteval] = ACTIONS(2498),
    [anon_sym_alignas] = ACTIONS(2498),
    [anon_sym__Alignas] = ACTIONS(2498),
    [sym_primitive_type] = ACTIONS(2498),
    [anon_sym_enum] = ACTIONS(2498),
    [anon_sym_class] = ACTIONS(2498),
    [anon_sym_struct] = ACTIONS(2498),
    [anon_sym_union] = ACTIONS(2498),
    [anon_sym_if] = ACTIONS(2498),
    [anon_sym_switch] = ACTIONS(2498),
    [anon_sym_case] = ACTIONS(2498),
    [anon_sym_default] = ACTIONS(2498),
    [anon_sym_while] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(2498),
    [anon_sym_for] = ACTIONS(2498),
    [anon_sym_return] = ACTIONS(2498),
    [anon_sym_break] = ACTIONS(2498),
    [anon_sym_continue] = ACTIONS(2498),
    [anon_sym_goto] = ACTIONS(2498),
    [anon_sym___try] = ACTIONS(2498),
    [anon_sym___leave] = ACTIONS(2498),
    [anon_sym_not] = ACTIONS(2498),
    [anon_sym_compl] = ACTIONS(2498),
    [anon_sym_DASH_DASH] = ACTIONS(2500),
    [anon_sym_PLUS_PLUS] = ACTIONS(2500),
    [anon_sym_sizeof] = ACTIONS(2498),
    [anon_sym___alignof__] = ACTIONS(2498),
    [anon_sym___alignof] = ACTIONS(2498),
    [anon_sym__alignof] = ACTIONS(2498),
    [anon_sym_alignof] = ACTIONS(2498),
    [anon_sym__Alignof] = ACTIONS(2498),
    [anon_sym_offsetof] = ACTIONS(2498),
    [anon_sym__Generic] = ACTIONS(2498),
    [anon_sym_asm] = ACTIONS(2498),
    [anon_sym___asm__] = ACTIONS(2498),
    [sym_number_literal] = ACTIONS(2500),
    [anon_sym_L_SQUOTE] = ACTIONS(2500),
    [anon_sym_u_SQUOTE] = ACTIONS(2500),
    [anon_sym_U_SQUOTE] = ACTIONS(2500),
    [anon_sym_u8_SQUOTE] = ACTIONS(2500),
    [anon_sym_SQUOTE] = ACTIONS(2500),
    [anon_sym_L_DQUOTE] = ACTIONS(2500),
    [anon_sym_u_DQUOTE] = ACTIONS(2500),
    [anon_sym_U_DQUOTE] = ACTIONS(2500),
    [anon_sym_u8_DQUOTE] = ACTIONS(2500),
    [anon_sym_DQUOTE] = ACTIONS(2500),
    [sym_true] = ACTIONS(2498),
    [sym_false] = ACTIONS(2498),
    [anon_sym_NULL] = ACTIONS(2498),
    [anon_sym_nullptr] = ACTIONS(2498),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2498),
    [anon_sym_decltype] = ACTIONS(2498),
    [sym_virtual] = ACTIONS(2498),
    [anon_sym_explicit] = ACTIONS(2498),
    [anon_sym_typename] = ACTIONS(2498),
    [anon_sym_template] = ACTIONS(2498),
    [anon_sym_operator] = ACTIONS(2498),
    [anon_sym_try] = ACTIONS(2498),
    [anon_sym_delete] = ACTIONS(2498),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_namespace] = ACTIONS(2498),
    [anon_sym_using] = ACTIONS(2498),
    [anon_sym_static_assert] = ACTIONS(2498),
    [anon_sym_concept] = ACTIONS(2498),
    [anon_sym_co_return] = ACTIONS(2498),
    [anon_sym_co_yield] = ACTIONS(2498),
    [anon_sym_R_DQUOTE] = ACTIONS(2500),
    [anon_sym_LR_DQUOTE] = ACTIONS(2500),
    [anon_sym_uR_DQUOTE] = ACTIONS(2500),
    [anon_sym_UR_DQUOTE] = ACTIONS(2500),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2500),
    [anon_sym_co_await] = ACTIONS(2498),
    [anon_sym_new] = ACTIONS(2498),
    [anon_sym_requires] = ACTIONS(2498),
    [sym_this] = ACTIONS(2498),
    [anon_sym_discard] = ACTIONS(2498),
    [anon_sym_precise] = ACTIONS(2498),
    [anon_sym_shared] = ACTIONS(2498),
    [anon_sym_groupshared] = ACTIONS(2498),
    [anon_sym_uniform] = ACTIONS(2498),
    [anon_sym_row_major] = ACTIONS(2498),
    [anon_sym_column_major] = ACTIONS(2498),
    [anon_sym_globallycoherent] = ACTIONS(2498),
    [anon_sym_centroid] = ACTIONS(2498),
    [anon_sym_noperspective] = ACTIONS(2498),
    [anon_sym_nointerpolation] = ACTIONS(2498),
    [anon_sym_sample] = ACTIONS(2498),
    [anon_sym_linear] = ACTIONS(2498),
    [anon_sym_snorm] = ACTIONS(2498),
    [anon_sym_unorm] = ACTIONS(2498),
    [anon_sym_point] = ACTIONS(2498),
    [anon_sym_line] = ACTIONS(2498),
    [anon_sym_triangleadj] = ACTIONS(2498),
    [anon_sym_lineadj] = ACTIONS(2498),
    [anon_sym_triangle] = ACTIONS(2498),
    [anon_sym_cbuffer] = ACTIONS(2498),
  },
  [593] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_include_token1] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token2] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_BANG] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_DASH] = ACTIONS(2332),
    [anon_sym_PLUS] = ACTIONS(2332),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym_SEMI] = ACTIONS(2334),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym___cdecl] = ACTIONS(2332),
    [anon_sym___clrcall] = ACTIONS(2332),
    [anon_sym___stdcall] = ACTIONS(2332),
    [anon_sym___fastcall] = ACTIONS(2332),
    [anon_sym___thiscall] = ACTIONS(2332),
    [anon_sym___vectorcall] = ACTIONS(2332),
    [anon_sym_LBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_switch] = ACTIONS(2332),
    [anon_sym_case] = ACTIONS(2332),
    [anon_sym_default] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2332),
    [anon_sym_do] = ACTIONS(2332),
    [anon_sym_for] = ACTIONS(2332),
    [anon_sym_return] = ACTIONS(2332),
    [anon_sym_break] = ACTIONS(2332),
    [anon_sym_continue] = ACTIONS(2332),
    [anon_sym_goto] = ACTIONS(2332),
    [anon_sym___try] = ACTIONS(2332),
    [anon_sym___leave] = ACTIONS(2332),
    [anon_sym_not] = ACTIONS(2332),
    [anon_sym_compl] = ACTIONS(2332),
    [anon_sym_DASH_DASH] = ACTIONS(2334),
    [anon_sym_PLUS_PLUS] = ACTIONS(2334),
    [anon_sym_sizeof] = ACTIONS(2332),
    [anon_sym___alignof__] = ACTIONS(2332),
    [anon_sym___alignof] = ACTIONS(2332),
    [anon_sym__alignof] = ACTIONS(2332),
    [anon_sym_alignof] = ACTIONS(2332),
    [anon_sym__Alignof] = ACTIONS(2332),
    [anon_sym_offsetof] = ACTIONS(2332),
    [anon_sym__Generic] = ACTIONS(2332),
    [anon_sym_asm] = ACTIONS(2332),
    [anon_sym___asm__] = ACTIONS(2332),
    [sym_number_literal] = ACTIONS(2334),
    [anon_sym_L_SQUOTE] = ACTIONS(2334),
    [anon_sym_u_SQUOTE] = ACTIONS(2334),
    [anon_sym_U_SQUOTE] = ACTIONS(2334),
    [anon_sym_u8_SQUOTE] = ACTIONS(2334),
    [anon_sym_SQUOTE] = ACTIONS(2334),
    [anon_sym_L_DQUOTE] = ACTIONS(2334),
    [anon_sym_u_DQUOTE] = ACTIONS(2334),
    [anon_sym_U_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8_DQUOTE] = ACTIONS(2334),
    [anon_sym_DQUOTE] = ACTIONS(2334),
    [sym_true] = ACTIONS(2332),
    [sym_false] = ACTIONS(2332),
    [anon_sym_NULL] = ACTIONS(2332),
    [anon_sym_nullptr] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_try] = ACTIONS(2332),
    [anon_sym_delete] = ACTIONS(2332),
    [anon_sym_throw] = ACTIONS(2332),
    [anon_sym_namespace] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_concept] = ACTIONS(2332),
    [anon_sym_co_return] = ACTIONS(2332),
    [anon_sym_co_yield] = ACTIONS(2332),
    [anon_sym_R_DQUOTE] = ACTIONS(2334),
    [anon_sym_LR_DQUOTE] = ACTIONS(2334),
    [anon_sym_uR_DQUOTE] = ACTIONS(2334),
    [anon_sym_UR_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2334),
    [anon_sym_co_await] = ACTIONS(2332),
    [anon_sym_new] = ACTIONS(2332),
    [anon_sym_requires] = ACTIONS(2332),
    [sym_this] = ACTIONS(2332),
    [anon_sym_discard] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
    [anon_sym_cbuffer] = ACTIONS(2332),
  },
  [594] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_include_token1] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token2] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_BANG] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_DASH] = ACTIONS(2332),
    [anon_sym_PLUS] = ACTIONS(2332),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym_SEMI] = ACTIONS(2334),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym___cdecl] = ACTIONS(2332),
    [anon_sym___clrcall] = ACTIONS(2332),
    [anon_sym___stdcall] = ACTIONS(2332),
    [anon_sym___fastcall] = ACTIONS(2332),
    [anon_sym___thiscall] = ACTIONS(2332),
    [anon_sym___vectorcall] = ACTIONS(2332),
    [anon_sym_LBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_switch] = ACTIONS(2332),
    [anon_sym_case] = ACTIONS(2332),
    [anon_sym_default] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2332),
    [anon_sym_do] = ACTIONS(2332),
    [anon_sym_for] = ACTIONS(2332),
    [anon_sym_return] = ACTIONS(2332),
    [anon_sym_break] = ACTIONS(2332),
    [anon_sym_continue] = ACTIONS(2332),
    [anon_sym_goto] = ACTIONS(2332),
    [anon_sym___try] = ACTIONS(2332),
    [anon_sym___leave] = ACTIONS(2332),
    [anon_sym_not] = ACTIONS(2332),
    [anon_sym_compl] = ACTIONS(2332),
    [anon_sym_DASH_DASH] = ACTIONS(2334),
    [anon_sym_PLUS_PLUS] = ACTIONS(2334),
    [anon_sym_sizeof] = ACTIONS(2332),
    [anon_sym___alignof__] = ACTIONS(2332),
    [anon_sym___alignof] = ACTIONS(2332),
    [anon_sym__alignof] = ACTIONS(2332),
    [anon_sym_alignof] = ACTIONS(2332),
    [anon_sym__Alignof] = ACTIONS(2332),
    [anon_sym_offsetof] = ACTIONS(2332),
    [anon_sym__Generic] = ACTIONS(2332),
    [anon_sym_asm] = ACTIONS(2332),
    [anon_sym___asm__] = ACTIONS(2332),
    [sym_number_literal] = ACTIONS(2334),
    [anon_sym_L_SQUOTE] = ACTIONS(2334),
    [anon_sym_u_SQUOTE] = ACTIONS(2334),
    [anon_sym_U_SQUOTE] = ACTIONS(2334),
    [anon_sym_u8_SQUOTE] = ACTIONS(2334),
    [anon_sym_SQUOTE] = ACTIONS(2334),
    [anon_sym_L_DQUOTE] = ACTIONS(2334),
    [anon_sym_u_DQUOTE] = ACTIONS(2334),
    [anon_sym_U_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8_DQUOTE] = ACTIONS(2334),
    [anon_sym_DQUOTE] = ACTIONS(2334),
    [sym_true] = ACTIONS(2332),
    [sym_false] = ACTIONS(2332),
    [anon_sym_NULL] = ACTIONS(2332),
    [anon_sym_nullptr] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_try] = ACTIONS(2332),
    [anon_sym_delete] = ACTIONS(2332),
    [anon_sym_throw] = ACTIONS(2332),
    [anon_sym_namespace] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_concept] = ACTIONS(2332),
    [anon_sym_co_return] = ACTIONS(2332),
    [anon_sym_co_yield] = ACTIONS(2332),
    [anon_sym_R_DQUOTE] = ACTIONS(2334),
    [anon_sym_LR_DQUOTE] = ACTIONS(2334),
    [anon_sym_uR_DQUOTE] = ACTIONS(2334),
    [anon_sym_UR_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2334),
    [anon_sym_co_await] = ACTIONS(2332),
    [anon_sym_new] = ACTIONS(2332),
    [anon_sym_requires] = ACTIONS(2332),
    [sym_this] = ACTIONS(2332),
    [anon_sym_discard] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
    [anon_sym_cbuffer] = ACTIONS(2332),
  },
  [595] = {
    [sym_identifier] = ACTIONS(2502),
    [aux_sym_preproc_include_token1] = ACTIONS(2502),
    [aux_sym_preproc_def_token1] = ACTIONS(2502),
    [aux_sym_preproc_if_token1] = ACTIONS(2502),
    [aux_sym_preproc_if_token2] = ACTIONS(2502),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2502),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2502),
    [sym_preproc_directive] = ACTIONS(2502),
    [anon_sym_LPAREN2] = ACTIONS(2504),
    [anon_sym_BANG] = ACTIONS(2504),
    [anon_sym_TILDE] = ACTIONS(2504),
    [anon_sym_DASH] = ACTIONS(2502),
    [anon_sym_PLUS] = ACTIONS(2502),
    [anon_sym_STAR] = ACTIONS(2504),
    [anon_sym_AMP_AMP] = ACTIONS(2504),
    [anon_sym_AMP] = ACTIONS(2502),
    [anon_sym_SEMI] = ACTIONS(2504),
    [anon_sym___extension__] = ACTIONS(2502),
    [anon_sym_typedef] = ACTIONS(2502),
    [anon_sym_in] = ACTIONS(2502),
    [anon_sym_out] = ACTIONS(2502),
    [anon_sym_inout] = ACTIONS(2502),
    [anon_sym_extern] = ACTIONS(2502),
    [anon_sym___attribute__] = ACTIONS(2502),
    [anon_sym_COLON_COLON] = ACTIONS(2504),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2504),
    [anon_sym___declspec] = ACTIONS(2502),
    [anon_sym___based] = ACTIONS(2502),
    [anon_sym___cdecl] = ACTIONS(2502),
    [anon_sym___clrcall] = ACTIONS(2502),
    [anon_sym___stdcall] = ACTIONS(2502),
    [anon_sym___fastcall] = ACTIONS(2502),
    [anon_sym___thiscall] = ACTIONS(2502),
    [anon_sym___vectorcall] = ACTIONS(2502),
    [anon_sym_LBRACE] = ACTIONS(2504),
    [anon_sym_signed] = ACTIONS(2502),
    [anon_sym_unsigned] = ACTIONS(2502),
    [anon_sym_long] = ACTIONS(2502),
    [anon_sym_short] = ACTIONS(2502),
    [anon_sym_LBRACK] = ACTIONS(2502),
    [anon_sym_static] = ACTIONS(2502),
    [anon_sym_register] = ACTIONS(2502),
    [anon_sym_inline] = ACTIONS(2502),
    [anon_sym___inline] = ACTIONS(2502),
    [anon_sym___inline__] = ACTIONS(2502),
    [anon_sym___forceinline] = ACTIONS(2502),
    [anon_sym_thread_local] = ACTIONS(2502),
    [anon_sym___thread] = ACTIONS(2502),
    [anon_sym_const] = ACTIONS(2502),
    [anon_sym_constexpr] = ACTIONS(2502),
    [anon_sym_volatile] = ACTIONS(2502),
    [anon_sym_restrict] = ACTIONS(2502),
    [anon_sym___restrict__] = ACTIONS(2502),
    [anon_sym__Atomic] = ACTIONS(2502),
    [anon_sym__Noreturn] = ACTIONS(2502),
    [anon_sym_noreturn] = ACTIONS(2502),
    [anon_sym_mutable] = ACTIONS(2502),
    [anon_sym_constinit] = ACTIONS(2502),
    [anon_sym_consteval] = ACTIONS(2502),
    [anon_sym_alignas] = ACTIONS(2502),
    [anon_sym__Alignas] = ACTIONS(2502),
    [sym_primitive_type] = ACTIONS(2502),
    [anon_sym_enum] = ACTIONS(2502),
    [anon_sym_class] = ACTIONS(2502),
    [anon_sym_struct] = ACTIONS(2502),
    [anon_sym_union] = ACTIONS(2502),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_switch] = ACTIONS(2502),
    [anon_sym_case] = ACTIONS(2502),
    [anon_sym_default] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_do] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2502),
    [anon_sym_return] = ACTIONS(2502),
    [anon_sym_break] = ACTIONS(2502),
    [anon_sym_continue] = ACTIONS(2502),
    [anon_sym_goto] = ACTIONS(2502),
    [anon_sym___try] = ACTIONS(2502),
    [anon_sym___leave] = ACTIONS(2502),
    [anon_sym_not] = ACTIONS(2502),
    [anon_sym_compl] = ACTIONS(2502),
    [anon_sym_DASH_DASH] = ACTIONS(2504),
    [anon_sym_PLUS_PLUS] = ACTIONS(2504),
    [anon_sym_sizeof] = ACTIONS(2502),
    [anon_sym___alignof__] = ACTIONS(2502),
    [anon_sym___alignof] = ACTIONS(2502),
    [anon_sym__alignof] = ACTIONS(2502),
    [anon_sym_alignof] = ACTIONS(2502),
    [anon_sym__Alignof] = ACTIONS(2502),
    [anon_sym_offsetof] = ACTIONS(2502),
    [anon_sym__Generic] = ACTIONS(2502),
    [anon_sym_asm] = ACTIONS(2502),
    [anon_sym___asm__] = ACTIONS(2502),
    [sym_number_literal] = ACTIONS(2504),
    [anon_sym_L_SQUOTE] = ACTIONS(2504),
    [anon_sym_u_SQUOTE] = ACTIONS(2504),
    [anon_sym_U_SQUOTE] = ACTIONS(2504),
    [anon_sym_u8_SQUOTE] = ACTIONS(2504),
    [anon_sym_SQUOTE] = ACTIONS(2504),
    [anon_sym_L_DQUOTE] = ACTIONS(2504),
    [anon_sym_u_DQUOTE] = ACTIONS(2504),
    [anon_sym_U_DQUOTE] = ACTIONS(2504),
    [anon_sym_u8_DQUOTE] = ACTIONS(2504),
    [anon_sym_DQUOTE] = ACTIONS(2504),
    [sym_true] = ACTIONS(2502),
    [sym_false] = ACTIONS(2502),
    [anon_sym_NULL] = ACTIONS(2502),
    [anon_sym_nullptr] = ACTIONS(2502),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2502),
    [anon_sym_decltype] = ACTIONS(2502),
    [sym_virtual] = ACTIONS(2502),
    [anon_sym_explicit] = ACTIONS(2502),
    [anon_sym_typename] = ACTIONS(2502),
    [anon_sym_template] = ACTIONS(2502),
    [anon_sym_operator] = ACTIONS(2502),
    [anon_sym_try] = ACTIONS(2502),
    [anon_sym_delete] = ACTIONS(2502),
    [anon_sym_throw] = ACTIONS(2502),
    [anon_sym_namespace] = ACTIONS(2502),
    [anon_sym_using] = ACTIONS(2502),
    [anon_sym_static_assert] = ACTIONS(2502),
    [anon_sym_concept] = ACTIONS(2502),
    [anon_sym_co_return] = ACTIONS(2502),
    [anon_sym_co_yield] = ACTIONS(2502),
    [anon_sym_R_DQUOTE] = ACTIONS(2504),
    [anon_sym_LR_DQUOTE] = ACTIONS(2504),
    [anon_sym_uR_DQUOTE] = ACTIONS(2504),
    [anon_sym_UR_DQUOTE] = ACTIONS(2504),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2504),
    [anon_sym_co_await] = ACTIONS(2502),
    [anon_sym_new] = ACTIONS(2502),
    [anon_sym_requires] = ACTIONS(2502),
    [sym_this] = ACTIONS(2502),
    [anon_sym_discard] = ACTIONS(2502),
    [anon_sym_precise] = ACTIONS(2502),
    [anon_sym_shared] = ACTIONS(2502),
    [anon_sym_groupshared] = ACTIONS(2502),
    [anon_sym_uniform] = ACTIONS(2502),
    [anon_sym_row_major] = ACTIONS(2502),
    [anon_sym_column_major] = ACTIONS(2502),
    [anon_sym_globallycoherent] = ACTIONS(2502),
    [anon_sym_centroid] = ACTIONS(2502),
    [anon_sym_noperspective] = ACTIONS(2502),
    [anon_sym_nointerpolation] = ACTIONS(2502),
    [anon_sym_sample] = ACTIONS(2502),
    [anon_sym_linear] = ACTIONS(2502),
    [anon_sym_snorm] = ACTIONS(2502),
    [anon_sym_unorm] = ACTIONS(2502),
    [anon_sym_point] = ACTIONS(2502),
    [anon_sym_line] = ACTIONS(2502),
    [anon_sym_triangleadj] = ACTIONS(2502),
    [anon_sym_lineadj] = ACTIONS(2502),
    [anon_sym_triangle] = ACTIONS(2502),
    [anon_sym_cbuffer] = ACTIONS(2502),
  },
  [596] = {
    [sym_identifier] = ACTIONS(2336),
    [aux_sym_preproc_include_token1] = ACTIONS(2336),
    [aux_sym_preproc_def_token1] = ACTIONS(2336),
    [aux_sym_preproc_if_token1] = ACTIONS(2336),
    [aux_sym_preproc_if_token2] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2336),
    [sym_preproc_directive] = ACTIONS(2336),
    [anon_sym_LPAREN2] = ACTIONS(2338),
    [anon_sym_BANG] = ACTIONS(2338),
    [anon_sym_TILDE] = ACTIONS(2338),
    [anon_sym_DASH] = ACTIONS(2336),
    [anon_sym_PLUS] = ACTIONS(2336),
    [anon_sym_STAR] = ACTIONS(2338),
    [anon_sym_AMP_AMP] = ACTIONS(2338),
    [anon_sym_AMP] = ACTIONS(2336),
    [anon_sym_SEMI] = ACTIONS(2338),
    [anon_sym___extension__] = ACTIONS(2336),
    [anon_sym_typedef] = ACTIONS(2336),
    [anon_sym_in] = ACTIONS(2336),
    [anon_sym_out] = ACTIONS(2336),
    [anon_sym_inout] = ACTIONS(2336),
    [anon_sym_extern] = ACTIONS(2336),
    [anon_sym___attribute__] = ACTIONS(2336),
    [anon_sym_COLON_COLON] = ACTIONS(2338),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2338),
    [anon_sym___declspec] = ACTIONS(2336),
    [anon_sym___based] = ACTIONS(2336),
    [anon_sym___cdecl] = ACTIONS(2336),
    [anon_sym___clrcall] = ACTIONS(2336),
    [anon_sym___stdcall] = ACTIONS(2336),
    [anon_sym___fastcall] = ACTIONS(2336),
    [anon_sym___thiscall] = ACTIONS(2336),
    [anon_sym___vectorcall] = ACTIONS(2336),
    [anon_sym_LBRACE] = ACTIONS(2338),
    [anon_sym_signed] = ACTIONS(2336),
    [anon_sym_unsigned] = ACTIONS(2336),
    [anon_sym_long] = ACTIONS(2336),
    [anon_sym_short] = ACTIONS(2336),
    [anon_sym_LBRACK] = ACTIONS(2336),
    [anon_sym_static] = ACTIONS(2336),
    [anon_sym_register] = ACTIONS(2336),
    [anon_sym_inline] = ACTIONS(2336),
    [anon_sym___inline] = ACTIONS(2336),
    [anon_sym___inline__] = ACTIONS(2336),
    [anon_sym___forceinline] = ACTIONS(2336),
    [anon_sym_thread_local] = ACTIONS(2336),
    [anon_sym___thread] = ACTIONS(2336),
    [anon_sym_const] = ACTIONS(2336),
    [anon_sym_constexpr] = ACTIONS(2336),
    [anon_sym_volatile] = ACTIONS(2336),
    [anon_sym_restrict] = ACTIONS(2336),
    [anon_sym___restrict__] = ACTIONS(2336),
    [anon_sym__Atomic] = ACTIONS(2336),
    [anon_sym__Noreturn] = ACTIONS(2336),
    [anon_sym_noreturn] = ACTIONS(2336),
    [anon_sym_mutable] = ACTIONS(2336),
    [anon_sym_constinit] = ACTIONS(2336),
    [anon_sym_consteval] = ACTIONS(2336),
    [anon_sym_alignas] = ACTIONS(2336),
    [anon_sym__Alignas] = ACTIONS(2336),
    [sym_primitive_type] = ACTIONS(2336),
    [anon_sym_enum] = ACTIONS(2336),
    [anon_sym_class] = ACTIONS(2336),
    [anon_sym_struct] = ACTIONS(2336),
    [anon_sym_union] = ACTIONS(2336),
    [anon_sym_if] = ACTIONS(2336),
    [anon_sym_switch] = ACTIONS(2336),
    [anon_sym_case] = ACTIONS(2336),
    [anon_sym_default] = ACTIONS(2336),
    [anon_sym_while] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(2336),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_return] = ACTIONS(2336),
    [anon_sym_break] = ACTIONS(2336),
    [anon_sym_continue] = ACTIONS(2336),
    [anon_sym_goto] = ACTIONS(2336),
    [anon_sym___try] = ACTIONS(2336),
    [anon_sym___leave] = ACTIONS(2336),
    [anon_sym_not] = ACTIONS(2336),
    [anon_sym_compl] = ACTIONS(2336),
    [anon_sym_DASH_DASH] = ACTIONS(2338),
    [anon_sym_PLUS_PLUS] = ACTIONS(2338),
    [anon_sym_sizeof] = ACTIONS(2336),
    [anon_sym___alignof__] = ACTIONS(2336),
    [anon_sym___alignof] = ACTIONS(2336),
    [anon_sym__alignof] = ACTIONS(2336),
    [anon_sym_alignof] = ACTIONS(2336),
    [anon_sym__Alignof] = ACTIONS(2336),
    [anon_sym_offsetof] = ACTIONS(2336),
    [anon_sym__Generic] = ACTIONS(2336),
    [anon_sym_asm] = ACTIONS(2336),
    [anon_sym___asm__] = ACTIONS(2336),
    [sym_number_literal] = ACTIONS(2338),
    [anon_sym_L_SQUOTE] = ACTIONS(2338),
    [anon_sym_u_SQUOTE] = ACTIONS(2338),
    [anon_sym_U_SQUOTE] = ACTIONS(2338),
    [anon_sym_u8_SQUOTE] = ACTIONS(2338),
    [anon_sym_SQUOTE] = ACTIONS(2338),
    [anon_sym_L_DQUOTE] = ACTIONS(2338),
    [anon_sym_u_DQUOTE] = ACTIONS(2338),
    [anon_sym_U_DQUOTE] = ACTIONS(2338),
    [anon_sym_u8_DQUOTE] = ACTIONS(2338),
    [anon_sym_DQUOTE] = ACTIONS(2338),
    [sym_true] = ACTIONS(2336),
    [sym_false] = ACTIONS(2336),
    [anon_sym_NULL] = ACTIONS(2336),
    [anon_sym_nullptr] = ACTIONS(2336),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2336),
    [anon_sym_decltype] = ACTIONS(2336),
    [sym_virtual] = ACTIONS(2336),
    [anon_sym_explicit] = ACTIONS(2336),
    [anon_sym_typename] = ACTIONS(2336),
    [anon_sym_template] = ACTIONS(2336),
    [anon_sym_operator] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2336),
    [anon_sym_delete] = ACTIONS(2336),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_namespace] = ACTIONS(2336),
    [anon_sym_using] = ACTIONS(2336),
    [anon_sym_static_assert] = ACTIONS(2336),
    [anon_sym_concept] = ACTIONS(2336),
    [anon_sym_co_return] = ACTIONS(2336),
    [anon_sym_co_yield] = ACTIONS(2336),
    [anon_sym_R_DQUOTE] = ACTIONS(2338),
    [anon_sym_LR_DQUOTE] = ACTIONS(2338),
    [anon_sym_uR_DQUOTE] = ACTIONS(2338),
    [anon_sym_UR_DQUOTE] = ACTIONS(2338),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2338),
    [anon_sym_co_await] = ACTIONS(2336),
    [anon_sym_new] = ACTIONS(2336),
    [anon_sym_requires] = ACTIONS(2336),
    [sym_this] = ACTIONS(2336),
    [anon_sym_discard] = ACTIONS(2336),
    [anon_sym_precise] = ACTIONS(2336),
    [anon_sym_shared] = ACTIONS(2336),
    [anon_sym_groupshared] = ACTIONS(2336),
    [anon_sym_uniform] = ACTIONS(2336),
    [anon_sym_row_major] = ACTIONS(2336),
    [anon_sym_column_major] = ACTIONS(2336),
    [anon_sym_globallycoherent] = ACTIONS(2336),
    [anon_sym_centroid] = ACTIONS(2336),
    [anon_sym_noperspective] = ACTIONS(2336),
    [anon_sym_nointerpolation] = ACTIONS(2336),
    [anon_sym_sample] = ACTIONS(2336),
    [anon_sym_linear] = ACTIONS(2336),
    [anon_sym_snorm] = ACTIONS(2336),
    [anon_sym_unorm] = ACTIONS(2336),
    [anon_sym_point] = ACTIONS(2336),
    [anon_sym_line] = ACTIONS(2336),
    [anon_sym_triangleadj] = ACTIONS(2336),
    [anon_sym_lineadj] = ACTIONS(2336),
    [anon_sym_triangle] = ACTIONS(2336),
    [anon_sym_cbuffer] = ACTIONS(2336),
  },
  [597] = {
    [sym_identifier] = ACTIONS(2336),
    [aux_sym_preproc_include_token1] = ACTIONS(2336),
    [aux_sym_preproc_def_token1] = ACTIONS(2336),
    [aux_sym_preproc_if_token1] = ACTIONS(2336),
    [aux_sym_preproc_if_token2] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2336),
    [sym_preproc_directive] = ACTIONS(2336),
    [anon_sym_LPAREN2] = ACTIONS(2338),
    [anon_sym_BANG] = ACTIONS(2338),
    [anon_sym_TILDE] = ACTIONS(2338),
    [anon_sym_DASH] = ACTIONS(2336),
    [anon_sym_PLUS] = ACTIONS(2336),
    [anon_sym_STAR] = ACTIONS(2338),
    [anon_sym_AMP_AMP] = ACTIONS(2338),
    [anon_sym_AMP] = ACTIONS(2336),
    [anon_sym_SEMI] = ACTIONS(2338),
    [anon_sym___extension__] = ACTIONS(2336),
    [anon_sym_typedef] = ACTIONS(2336),
    [anon_sym_in] = ACTIONS(2336),
    [anon_sym_out] = ACTIONS(2336),
    [anon_sym_inout] = ACTIONS(2336),
    [anon_sym_extern] = ACTIONS(2336),
    [anon_sym___attribute__] = ACTIONS(2336),
    [anon_sym_COLON_COLON] = ACTIONS(2338),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2338),
    [anon_sym___declspec] = ACTIONS(2336),
    [anon_sym___based] = ACTIONS(2336),
    [anon_sym___cdecl] = ACTIONS(2336),
    [anon_sym___clrcall] = ACTIONS(2336),
    [anon_sym___stdcall] = ACTIONS(2336),
    [anon_sym___fastcall] = ACTIONS(2336),
    [anon_sym___thiscall] = ACTIONS(2336),
    [anon_sym___vectorcall] = ACTIONS(2336),
    [anon_sym_LBRACE] = ACTIONS(2338),
    [anon_sym_signed] = ACTIONS(2336),
    [anon_sym_unsigned] = ACTIONS(2336),
    [anon_sym_long] = ACTIONS(2336),
    [anon_sym_short] = ACTIONS(2336),
    [anon_sym_LBRACK] = ACTIONS(2336),
    [anon_sym_static] = ACTIONS(2336),
    [anon_sym_register] = ACTIONS(2336),
    [anon_sym_inline] = ACTIONS(2336),
    [anon_sym___inline] = ACTIONS(2336),
    [anon_sym___inline__] = ACTIONS(2336),
    [anon_sym___forceinline] = ACTIONS(2336),
    [anon_sym_thread_local] = ACTIONS(2336),
    [anon_sym___thread] = ACTIONS(2336),
    [anon_sym_const] = ACTIONS(2336),
    [anon_sym_constexpr] = ACTIONS(2336),
    [anon_sym_volatile] = ACTIONS(2336),
    [anon_sym_restrict] = ACTIONS(2336),
    [anon_sym___restrict__] = ACTIONS(2336),
    [anon_sym__Atomic] = ACTIONS(2336),
    [anon_sym__Noreturn] = ACTIONS(2336),
    [anon_sym_noreturn] = ACTIONS(2336),
    [anon_sym_mutable] = ACTIONS(2336),
    [anon_sym_constinit] = ACTIONS(2336),
    [anon_sym_consteval] = ACTIONS(2336),
    [anon_sym_alignas] = ACTIONS(2336),
    [anon_sym__Alignas] = ACTIONS(2336),
    [sym_primitive_type] = ACTIONS(2336),
    [anon_sym_enum] = ACTIONS(2336),
    [anon_sym_class] = ACTIONS(2336),
    [anon_sym_struct] = ACTIONS(2336),
    [anon_sym_union] = ACTIONS(2336),
    [anon_sym_if] = ACTIONS(2336),
    [anon_sym_switch] = ACTIONS(2336),
    [anon_sym_case] = ACTIONS(2336),
    [anon_sym_default] = ACTIONS(2336),
    [anon_sym_while] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(2336),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_return] = ACTIONS(2336),
    [anon_sym_break] = ACTIONS(2336),
    [anon_sym_continue] = ACTIONS(2336),
    [anon_sym_goto] = ACTIONS(2336),
    [anon_sym___try] = ACTIONS(2336),
    [anon_sym___leave] = ACTIONS(2336),
    [anon_sym_not] = ACTIONS(2336),
    [anon_sym_compl] = ACTIONS(2336),
    [anon_sym_DASH_DASH] = ACTIONS(2338),
    [anon_sym_PLUS_PLUS] = ACTIONS(2338),
    [anon_sym_sizeof] = ACTIONS(2336),
    [anon_sym___alignof__] = ACTIONS(2336),
    [anon_sym___alignof] = ACTIONS(2336),
    [anon_sym__alignof] = ACTIONS(2336),
    [anon_sym_alignof] = ACTIONS(2336),
    [anon_sym__Alignof] = ACTIONS(2336),
    [anon_sym_offsetof] = ACTIONS(2336),
    [anon_sym__Generic] = ACTIONS(2336),
    [anon_sym_asm] = ACTIONS(2336),
    [anon_sym___asm__] = ACTIONS(2336),
    [sym_number_literal] = ACTIONS(2338),
    [anon_sym_L_SQUOTE] = ACTIONS(2338),
    [anon_sym_u_SQUOTE] = ACTIONS(2338),
    [anon_sym_U_SQUOTE] = ACTIONS(2338),
    [anon_sym_u8_SQUOTE] = ACTIONS(2338),
    [anon_sym_SQUOTE] = ACTIONS(2338),
    [anon_sym_L_DQUOTE] = ACTIONS(2338),
    [anon_sym_u_DQUOTE] = ACTIONS(2338),
    [anon_sym_U_DQUOTE] = ACTIONS(2338),
    [anon_sym_u8_DQUOTE] = ACTIONS(2338),
    [anon_sym_DQUOTE] = ACTIONS(2338),
    [sym_true] = ACTIONS(2336),
    [sym_false] = ACTIONS(2336),
    [anon_sym_NULL] = ACTIONS(2336),
    [anon_sym_nullptr] = ACTIONS(2336),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2336),
    [anon_sym_decltype] = ACTIONS(2336),
    [sym_virtual] = ACTIONS(2336),
    [anon_sym_explicit] = ACTIONS(2336),
    [anon_sym_typename] = ACTIONS(2336),
    [anon_sym_template] = ACTIONS(2336),
    [anon_sym_operator] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2336),
    [anon_sym_delete] = ACTIONS(2336),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_namespace] = ACTIONS(2336),
    [anon_sym_using] = ACTIONS(2336),
    [anon_sym_static_assert] = ACTIONS(2336),
    [anon_sym_concept] = ACTIONS(2336),
    [anon_sym_co_return] = ACTIONS(2336),
    [anon_sym_co_yield] = ACTIONS(2336),
    [anon_sym_R_DQUOTE] = ACTIONS(2338),
    [anon_sym_LR_DQUOTE] = ACTIONS(2338),
    [anon_sym_uR_DQUOTE] = ACTIONS(2338),
    [anon_sym_UR_DQUOTE] = ACTIONS(2338),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2338),
    [anon_sym_co_await] = ACTIONS(2336),
    [anon_sym_new] = ACTIONS(2336),
    [anon_sym_requires] = ACTIONS(2336),
    [sym_this] = ACTIONS(2336),
    [anon_sym_discard] = ACTIONS(2336),
    [anon_sym_precise] = ACTIONS(2336),
    [anon_sym_shared] = ACTIONS(2336),
    [anon_sym_groupshared] = ACTIONS(2336),
    [anon_sym_uniform] = ACTIONS(2336),
    [anon_sym_row_major] = ACTIONS(2336),
    [anon_sym_column_major] = ACTIONS(2336),
    [anon_sym_globallycoherent] = ACTIONS(2336),
    [anon_sym_centroid] = ACTIONS(2336),
    [anon_sym_noperspective] = ACTIONS(2336),
    [anon_sym_nointerpolation] = ACTIONS(2336),
    [anon_sym_sample] = ACTIONS(2336),
    [anon_sym_linear] = ACTIONS(2336),
    [anon_sym_snorm] = ACTIONS(2336),
    [anon_sym_unorm] = ACTIONS(2336),
    [anon_sym_point] = ACTIONS(2336),
    [anon_sym_line] = ACTIONS(2336),
    [anon_sym_triangleadj] = ACTIONS(2336),
    [anon_sym_lineadj] = ACTIONS(2336),
    [anon_sym_triangle] = ACTIONS(2336),
    [anon_sym_cbuffer] = ACTIONS(2336),
  },
  [598] = {
    [sym_identifier] = ACTIONS(2344),
    [aux_sym_preproc_include_token1] = ACTIONS(2344),
    [aux_sym_preproc_def_token1] = ACTIONS(2344),
    [aux_sym_preproc_if_token1] = ACTIONS(2344),
    [aux_sym_preproc_if_token2] = ACTIONS(2344),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2344),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2344),
    [sym_preproc_directive] = ACTIONS(2344),
    [anon_sym_LPAREN2] = ACTIONS(2346),
    [anon_sym_BANG] = ACTIONS(2346),
    [anon_sym_TILDE] = ACTIONS(2346),
    [anon_sym_DASH] = ACTIONS(2344),
    [anon_sym_PLUS] = ACTIONS(2344),
    [anon_sym_STAR] = ACTIONS(2346),
    [anon_sym_AMP_AMP] = ACTIONS(2346),
    [anon_sym_AMP] = ACTIONS(2344),
    [anon_sym_SEMI] = ACTIONS(2346),
    [anon_sym___extension__] = ACTIONS(2344),
    [anon_sym_typedef] = ACTIONS(2344),
    [anon_sym_in] = ACTIONS(2344),
    [anon_sym_out] = ACTIONS(2344),
    [anon_sym_inout] = ACTIONS(2344),
    [anon_sym_extern] = ACTIONS(2344),
    [anon_sym___attribute__] = ACTIONS(2344),
    [anon_sym_COLON_COLON] = ACTIONS(2346),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2346),
    [anon_sym___declspec] = ACTIONS(2344),
    [anon_sym___based] = ACTIONS(2344),
    [anon_sym___cdecl] = ACTIONS(2344),
    [anon_sym___clrcall] = ACTIONS(2344),
    [anon_sym___stdcall] = ACTIONS(2344),
    [anon_sym___fastcall] = ACTIONS(2344),
    [anon_sym___thiscall] = ACTIONS(2344),
    [anon_sym___vectorcall] = ACTIONS(2344),
    [anon_sym_LBRACE] = ACTIONS(2346),
    [anon_sym_signed] = ACTIONS(2344),
    [anon_sym_unsigned] = ACTIONS(2344),
    [anon_sym_long] = ACTIONS(2344),
    [anon_sym_short] = ACTIONS(2344),
    [anon_sym_LBRACK] = ACTIONS(2344),
    [anon_sym_static] = ACTIONS(2344),
    [anon_sym_register] = ACTIONS(2344),
    [anon_sym_inline] = ACTIONS(2344),
    [anon_sym___inline] = ACTIONS(2344),
    [anon_sym___inline__] = ACTIONS(2344),
    [anon_sym___forceinline] = ACTIONS(2344),
    [anon_sym_thread_local] = ACTIONS(2344),
    [anon_sym___thread] = ACTIONS(2344),
    [anon_sym_const] = ACTIONS(2344),
    [anon_sym_constexpr] = ACTIONS(2344),
    [anon_sym_volatile] = ACTIONS(2344),
    [anon_sym_restrict] = ACTIONS(2344),
    [anon_sym___restrict__] = ACTIONS(2344),
    [anon_sym__Atomic] = ACTIONS(2344),
    [anon_sym__Noreturn] = ACTIONS(2344),
    [anon_sym_noreturn] = ACTIONS(2344),
    [anon_sym_mutable] = ACTIONS(2344),
    [anon_sym_constinit] = ACTIONS(2344),
    [anon_sym_consteval] = ACTIONS(2344),
    [anon_sym_alignas] = ACTIONS(2344),
    [anon_sym__Alignas] = ACTIONS(2344),
    [sym_primitive_type] = ACTIONS(2344),
    [anon_sym_enum] = ACTIONS(2344),
    [anon_sym_class] = ACTIONS(2344),
    [anon_sym_struct] = ACTIONS(2344),
    [anon_sym_union] = ACTIONS(2344),
    [anon_sym_if] = ACTIONS(2344),
    [anon_sym_switch] = ACTIONS(2344),
    [anon_sym_case] = ACTIONS(2344),
    [anon_sym_default] = ACTIONS(2344),
    [anon_sym_while] = ACTIONS(2344),
    [anon_sym_do] = ACTIONS(2344),
    [anon_sym_for] = ACTIONS(2344),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_break] = ACTIONS(2344),
    [anon_sym_continue] = ACTIONS(2344),
    [anon_sym_goto] = ACTIONS(2344),
    [anon_sym___try] = ACTIONS(2344),
    [anon_sym___leave] = ACTIONS(2344),
    [anon_sym_not] = ACTIONS(2344),
    [anon_sym_compl] = ACTIONS(2344),
    [anon_sym_DASH_DASH] = ACTIONS(2346),
    [anon_sym_PLUS_PLUS] = ACTIONS(2346),
    [anon_sym_sizeof] = ACTIONS(2344),
    [anon_sym___alignof__] = ACTIONS(2344),
    [anon_sym___alignof] = ACTIONS(2344),
    [anon_sym__alignof] = ACTIONS(2344),
    [anon_sym_alignof] = ACTIONS(2344),
    [anon_sym__Alignof] = ACTIONS(2344),
    [anon_sym_offsetof] = ACTIONS(2344),
    [anon_sym__Generic] = ACTIONS(2344),
    [anon_sym_asm] = ACTIONS(2344),
    [anon_sym___asm__] = ACTIONS(2344),
    [sym_number_literal] = ACTIONS(2346),
    [anon_sym_L_SQUOTE] = ACTIONS(2346),
    [anon_sym_u_SQUOTE] = ACTIONS(2346),
    [anon_sym_U_SQUOTE] = ACTIONS(2346),
    [anon_sym_u8_SQUOTE] = ACTIONS(2346),
    [anon_sym_SQUOTE] = ACTIONS(2346),
    [anon_sym_L_DQUOTE] = ACTIONS(2346),
    [anon_sym_u_DQUOTE] = ACTIONS(2346),
    [anon_sym_U_DQUOTE] = ACTIONS(2346),
    [anon_sym_u8_DQUOTE] = ACTIONS(2346),
    [anon_sym_DQUOTE] = ACTIONS(2346),
    [sym_true] = ACTIONS(2344),
    [sym_false] = ACTIONS(2344),
    [anon_sym_NULL] = ACTIONS(2344),
    [anon_sym_nullptr] = ACTIONS(2344),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2344),
    [anon_sym_decltype] = ACTIONS(2344),
    [sym_virtual] = ACTIONS(2344),
    [anon_sym_explicit] = ACTIONS(2344),
    [anon_sym_typename] = ACTIONS(2344),
    [anon_sym_template] = ACTIONS(2344),
    [anon_sym_operator] = ACTIONS(2344),
    [anon_sym_try] = ACTIONS(2344),
    [anon_sym_delete] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2344),
    [anon_sym_namespace] = ACTIONS(2344),
    [anon_sym_using] = ACTIONS(2344),
    [anon_sym_static_assert] = ACTIONS(2344),
    [anon_sym_concept] = ACTIONS(2344),
    [anon_sym_co_return] = ACTIONS(2344),
    [anon_sym_co_yield] = ACTIONS(2344),
    [anon_sym_R_DQUOTE] = ACTIONS(2346),
    [anon_sym_LR_DQUOTE] = ACTIONS(2346),
    [anon_sym_uR_DQUOTE] = ACTIONS(2346),
    [anon_sym_UR_DQUOTE] = ACTIONS(2346),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2346),
    [anon_sym_co_await] = ACTIONS(2344),
    [anon_sym_new] = ACTIONS(2344),
    [anon_sym_requires] = ACTIONS(2344),
    [sym_this] = ACTIONS(2344),
    [anon_sym_discard] = ACTIONS(2344),
    [anon_sym_precise] = ACTIONS(2344),
    [anon_sym_shared] = ACTIONS(2344),
    [anon_sym_groupshared] = ACTIONS(2344),
    [anon_sym_uniform] = ACTIONS(2344),
    [anon_sym_row_major] = ACTIONS(2344),
    [anon_sym_column_major] = ACTIONS(2344),
    [anon_sym_globallycoherent] = ACTIONS(2344),
    [anon_sym_centroid] = ACTIONS(2344),
    [anon_sym_noperspective] = ACTIONS(2344),
    [anon_sym_nointerpolation] = ACTIONS(2344),
    [anon_sym_sample] = ACTIONS(2344),
    [anon_sym_linear] = ACTIONS(2344),
    [anon_sym_snorm] = ACTIONS(2344),
    [anon_sym_unorm] = ACTIONS(2344),
    [anon_sym_point] = ACTIONS(2344),
    [anon_sym_line] = ACTIONS(2344),
    [anon_sym_triangleadj] = ACTIONS(2344),
    [anon_sym_lineadj] = ACTIONS(2344),
    [anon_sym_triangle] = ACTIONS(2344),
    [anon_sym_cbuffer] = ACTIONS(2344),
  },
  [599] = {
    [sym_identifier] = ACTIONS(2383),
    [aux_sym_preproc_include_token1] = ACTIONS(2383),
    [aux_sym_preproc_def_token1] = ACTIONS(2383),
    [aux_sym_preproc_if_token1] = ACTIONS(2383),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2383),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2383),
    [sym_preproc_directive] = ACTIONS(2383),
    [anon_sym_LPAREN2] = ACTIONS(2386),
    [anon_sym_BANG] = ACTIONS(2386),
    [anon_sym_TILDE] = ACTIONS(2386),
    [anon_sym_DASH] = ACTIONS(2383),
    [anon_sym_PLUS] = ACTIONS(2383),
    [anon_sym_STAR] = ACTIONS(2386),
    [anon_sym_AMP_AMP] = ACTIONS(2386),
    [anon_sym_AMP] = ACTIONS(2383),
    [anon_sym_SEMI] = ACTIONS(2386),
    [anon_sym___extension__] = ACTIONS(2383),
    [anon_sym_typedef] = ACTIONS(2383),
    [anon_sym_in] = ACTIONS(2383),
    [anon_sym_out] = ACTIONS(2383),
    [anon_sym_inout] = ACTIONS(2383),
    [anon_sym_extern] = ACTIONS(2383),
    [anon_sym___attribute__] = ACTIONS(2383),
    [anon_sym_COLON_COLON] = ACTIONS(2386),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2386),
    [anon_sym___declspec] = ACTIONS(2383),
    [anon_sym___based] = ACTIONS(2383),
    [anon_sym___cdecl] = ACTIONS(2383),
    [anon_sym___clrcall] = ACTIONS(2383),
    [anon_sym___stdcall] = ACTIONS(2383),
    [anon_sym___fastcall] = ACTIONS(2383),
    [anon_sym___thiscall] = ACTIONS(2383),
    [anon_sym___vectorcall] = ACTIONS(2383),
    [anon_sym_LBRACE] = ACTIONS(2386),
    [anon_sym_RBRACE] = ACTIONS(2386),
    [anon_sym_signed] = ACTIONS(2383),
    [anon_sym_unsigned] = ACTIONS(2383),
    [anon_sym_long] = ACTIONS(2383),
    [anon_sym_short] = ACTIONS(2383),
    [anon_sym_LBRACK] = ACTIONS(2383),
    [anon_sym_static] = ACTIONS(2383),
    [anon_sym_register] = ACTIONS(2383),
    [anon_sym_inline] = ACTIONS(2383),
    [anon_sym___inline] = ACTIONS(2383),
    [anon_sym___inline__] = ACTIONS(2383),
    [anon_sym___forceinline] = ACTIONS(2383),
    [anon_sym_thread_local] = ACTIONS(2383),
    [anon_sym___thread] = ACTIONS(2383),
    [anon_sym_const] = ACTIONS(2383),
    [anon_sym_constexpr] = ACTIONS(2383),
    [anon_sym_volatile] = ACTIONS(2383),
    [anon_sym_restrict] = ACTIONS(2383),
    [anon_sym___restrict__] = ACTIONS(2383),
    [anon_sym__Atomic] = ACTIONS(2383),
    [anon_sym__Noreturn] = ACTIONS(2383),
    [anon_sym_noreturn] = ACTIONS(2383),
    [anon_sym_mutable] = ACTIONS(2383),
    [anon_sym_constinit] = ACTIONS(2383),
    [anon_sym_consteval] = ACTIONS(2383),
    [anon_sym_alignas] = ACTIONS(2383),
    [anon_sym__Alignas] = ACTIONS(2383),
    [sym_primitive_type] = ACTIONS(2383),
    [anon_sym_enum] = ACTIONS(2383),
    [anon_sym_class] = ACTIONS(2383),
    [anon_sym_struct] = ACTIONS(2383),
    [anon_sym_union] = ACTIONS(2383),
    [anon_sym_if] = ACTIONS(2383),
    [anon_sym_switch] = ACTIONS(2383),
    [anon_sym_case] = ACTIONS(2383),
    [anon_sym_default] = ACTIONS(2383),
    [anon_sym_while] = ACTIONS(2383),
    [anon_sym_do] = ACTIONS(2383),
    [anon_sym_for] = ACTIONS(2383),
    [anon_sym_return] = ACTIONS(2383),
    [anon_sym_break] = ACTIONS(2383),
    [anon_sym_continue] = ACTIONS(2383),
    [anon_sym_goto] = ACTIONS(2383),
    [anon_sym___try] = ACTIONS(2383),
    [anon_sym___leave] = ACTIONS(2383),
    [anon_sym_not] = ACTIONS(2383),
    [anon_sym_compl] = ACTIONS(2383),
    [anon_sym_DASH_DASH] = ACTIONS(2386),
    [anon_sym_PLUS_PLUS] = ACTIONS(2386),
    [anon_sym_sizeof] = ACTIONS(2383),
    [anon_sym___alignof__] = ACTIONS(2383),
    [anon_sym___alignof] = ACTIONS(2383),
    [anon_sym__alignof] = ACTIONS(2383),
    [anon_sym_alignof] = ACTIONS(2383),
    [anon_sym__Alignof] = ACTIONS(2383),
    [anon_sym_offsetof] = ACTIONS(2383),
    [anon_sym__Generic] = ACTIONS(2383),
    [anon_sym_asm] = ACTIONS(2383),
    [anon_sym___asm__] = ACTIONS(2383),
    [sym_number_literal] = ACTIONS(2386),
    [anon_sym_L_SQUOTE] = ACTIONS(2386),
    [anon_sym_u_SQUOTE] = ACTIONS(2386),
    [anon_sym_U_SQUOTE] = ACTIONS(2386),
    [anon_sym_u8_SQUOTE] = ACTIONS(2386),
    [anon_sym_SQUOTE] = ACTIONS(2386),
    [anon_sym_L_DQUOTE] = ACTIONS(2386),
    [anon_sym_u_DQUOTE] = ACTIONS(2386),
    [anon_sym_U_DQUOTE] = ACTIONS(2386),
    [anon_sym_u8_DQUOTE] = ACTIONS(2386),
    [anon_sym_DQUOTE] = ACTIONS(2386),
    [sym_true] = ACTIONS(2383),
    [sym_false] = ACTIONS(2383),
    [anon_sym_NULL] = ACTIONS(2383),
    [anon_sym_nullptr] = ACTIONS(2383),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2383),
    [anon_sym_decltype] = ACTIONS(2383),
    [sym_virtual] = ACTIONS(2383),
    [anon_sym_explicit] = ACTIONS(2383),
    [anon_sym_typename] = ACTIONS(2383),
    [anon_sym_template] = ACTIONS(2383),
    [anon_sym_operator] = ACTIONS(2383),
    [anon_sym_try] = ACTIONS(2383),
    [anon_sym_delete] = ACTIONS(2383),
    [anon_sym_throw] = ACTIONS(2383),
    [anon_sym_namespace] = ACTIONS(2383),
    [anon_sym_using] = ACTIONS(2383),
    [anon_sym_static_assert] = ACTIONS(2383),
    [anon_sym_concept] = ACTIONS(2383),
    [anon_sym_co_return] = ACTIONS(2383),
    [anon_sym_co_yield] = ACTIONS(2383),
    [anon_sym_R_DQUOTE] = ACTIONS(2386),
    [anon_sym_LR_DQUOTE] = ACTIONS(2386),
    [anon_sym_uR_DQUOTE] = ACTIONS(2386),
    [anon_sym_UR_DQUOTE] = ACTIONS(2386),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2386),
    [anon_sym_co_await] = ACTIONS(2383),
    [anon_sym_new] = ACTIONS(2383),
    [anon_sym_requires] = ACTIONS(2383),
    [sym_this] = ACTIONS(2383),
    [anon_sym_discard] = ACTIONS(2383),
    [anon_sym_precise] = ACTIONS(2383),
    [anon_sym_shared] = ACTIONS(2383),
    [anon_sym_groupshared] = ACTIONS(2383),
    [anon_sym_uniform] = ACTIONS(2383),
    [anon_sym_row_major] = ACTIONS(2383),
    [anon_sym_column_major] = ACTIONS(2383),
    [anon_sym_globallycoherent] = ACTIONS(2383),
    [anon_sym_centroid] = ACTIONS(2383),
    [anon_sym_noperspective] = ACTIONS(2383),
    [anon_sym_nointerpolation] = ACTIONS(2383),
    [anon_sym_sample] = ACTIONS(2383),
    [anon_sym_linear] = ACTIONS(2383),
    [anon_sym_snorm] = ACTIONS(2383),
    [anon_sym_unorm] = ACTIONS(2383),
    [anon_sym_point] = ACTIONS(2383),
    [anon_sym_line] = ACTIONS(2383),
    [anon_sym_triangleadj] = ACTIONS(2383),
    [anon_sym_lineadj] = ACTIONS(2383),
    [anon_sym_triangle] = ACTIONS(2383),
    [anon_sym_cbuffer] = ACTIONS(2383),
  },
  [600] = {
    [sym_identifier] = ACTIONS(2352),
    [aux_sym_preproc_include_token1] = ACTIONS(2352),
    [aux_sym_preproc_def_token1] = ACTIONS(2352),
    [aux_sym_preproc_if_token1] = ACTIONS(2352),
    [aux_sym_preproc_if_token2] = ACTIONS(2352),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2352),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2352),
    [sym_preproc_directive] = ACTIONS(2352),
    [anon_sym_LPAREN2] = ACTIONS(2354),
    [anon_sym_BANG] = ACTIONS(2354),
    [anon_sym_TILDE] = ACTIONS(2354),
    [anon_sym_DASH] = ACTIONS(2352),
    [anon_sym_PLUS] = ACTIONS(2352),
    [anon_sym_STAR] = ACTIONS(2354),
    [anon_sym_AMP_AMP] = ACTIONS(2354),
    [anon_sym_AMP] = ACTIONS(2352),
    [anon_sym_SEMI] = ACTIONS(2354),
    [anon_sym___extension__] = ACTIONS(2352),
    [anon_sym_typedef] = ACTIONS(2352),
    [anon_sym_in] = ACTIONS(2352),
    [anon_sym_out] = ACTIONS(2352),
    [anon_sym_inout] = ACTIONS(2352),
    [anon_sym_extern] = ACTIONS(2352),
    [anon_sym___attribute__] = ACTIONS(2352),
    [anon_sym_COLON_COLON] = ACTIONS(2354),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2354),
    [anon_sym___declspec] = ACTIONS(2352),
    [anon_sym___based] = ACTIONS(2352),
    [anon_sym___cdecl] = ACTIONS(2352),
    [anon_sym___clrcall] = ACTIONS(2352),
    [anon_sym___stdcall] = ACTIONS(2352),
    [anon_sym___fastcall] = ACTIONS(2352),
    [anon_sym___thiscall] = ACTIONS(2352),
    [anon_sym___vectorcall] = ACTIONS(2352),
    [anon_sym_LBRACE] = ACTIONS(2354),
    [anon_sym_signed] = ACTIONS(2352),
    [anon_sym_unsigned] = ACTIONS(2352),
    [anon_sym_long] = ACTIONS(2352),
    [anon_sym_short] = ACTIONS(2352),
    [anon_sym_LBRACK] = ACTIONS(2352),
    [anon_sym_static] = ACTIONS(2352),
    [anon_sym_register] = ACTIONS(2352),
    [anon_sym_inline] = ACTIONS(2352),
    [anon_sym___inline] = ACTIONS(2352),
    [anon_sym___inline__] = ACTIONS(2352),
    [anon_sym___forceinline] = ACTIONS(2352),
    [anon_sym_thread_local] = ACTIONS(2352),
    [anon_sym___thread] = ACTIONS(2352),
    [anon_sym_const] = ACTIONS(2352),
    [anon_sym_constexpr] = ACTIONS(2352),
    [anon_sym_volatile] = ACTIONS(2352),
    [anon_sym_restrict] = ACTIONS(2352),
    [anon_sym___restrict__] = ACTIONS(2352),
    [anon_sym__Atomic] = ACTIONS(2352),
    [anon_sym__Noreturn] = ACTIONS(2352),
    [anon_sym_noreturn] = ACTIONS(2352),
    [anon_sym_mutable] = ACTIONS(2352),
    [anon_sym_constinit] = ACTIONS(2352),
    [anon_sym_consteval] = ACTIONS(2352),
    [anon_sym_alignas] = ACTIONS(2352),
    [anon_sym__Alignas] = ACTIONS(2352),
    [sym_primitive_type] = ACTIONS(2352),
    [anon_sym_enum] = ACTIONS(2352),
    [anon_sym_class] = ACTIONS(2352),
    [anon_sym_struct] = ACTIONS(2352),
    [anon_sym_union] = ACTIONS(2352),
    [anon_sym_if] = ACTIONS(2352),
    [anon_sym_switch] = ACTIONS(2352),
    [anon_sym_case] = ACTIONS(2352),
    [anon_sym_default] = ACTIONS(2352),
    [anon_sym_while] = ACTIONS(2352),
    [anon_sym_do] = ACTIONS(2352),
    [anon_sym_for] = ACTIONS(2352),
    [anon_sym_return] = ACTIONS(2352),
    [anon_sym_break] = ACTIONS(2352),
    [anon_sym_continue] = ACTIONS(2352),
    [anon_sym_goto] = ACTIONS(2352),
    [anon_sym___try] = ACTIONS(2352),
    [anon_sym___leave] = ACTIONS(2352),
    [anon_sym_not] = ACTIONS(2352),
    [anon_sym_compl] = ACTIONS(2352),
    [anon_sym_DASH_DASH] = ACTIONS(2354),
    [anon_sym_PLUS_PLUS] = ACTIONS(2354),
    [anon_sym_sizeof] = ACTIONS(2352),
    [anon_sym___alignof__] = ACTIONS(2352),
    [anon_sym___alignof] = ACTIONS(2352),
    [anon_sym__alignof] = ACTIONS(2352),
    [anon_sym_alignof] = ACTIONS(2352),
    [anon_sym__Alignof] = ACTIONS(2352),
    [anon_sym_offsetof] = ACTIONS(2352),
    [anon_sym__Generic] = ACTIONS(2352),
    [anon_sym_asm] = ACTIONS(2352),
    [anon_sym___asm__] = ACTIONS(2352),
    [sym_number_literal] = ACTIONS(2354),
    [anon_sym_L_SQUOTE] = ACTIONS(2354),
    [anon_sym_u_SQUOTE] = ACTIONS(2354),
    [anon_sym_U_SQUOTE] = ACTIONS(2354),
    [anon_sym_u8_SQUOTE] = ACTIONS(2354),
    [anon_sym_SQUOTE] = ACTIONS(2354),
    [anon_sym_L_DQUOTE] = ACTIONS(2354),
    [anon_sym_u_DQUOTE] = ACTIONS(2354),
    [anon_sym_U_DQUOTE] = ACTIONS(2354),
    [anon_sym_u8_DQUOTE] = ACTIONS(2354),
    [anon_sym_DQUOTE] = ACTIONS(2354),
    [sym_true] = ACTIONS(2352),
    [sym_false] = ACTIONS(2352),
    [anon_sym_NULL] = ACTIONS(2352),
    [anon_sym_nullptr] = ACTIONS(2352),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2352),
    [anon_sym_decltype] = ACTIONS(2352),
    [sym_virtual] = ACTIONS(2352),
    [anon_sym_explicit] = ACTIONS(2352),
    [anon_sym_typename] = ACTIONS(2352),
    [anon_sym_template] = ACTIONS(2352),
    [anon_sym_operator] = ACTIONS(2352),
    [anon_sym_try] = ACTIONS(2352),
    [anon_sym_delete] = ACTIONS(2352),
    [anon_sym_throw] = ACTIONS(2352),
    [anon_sym_namespace] = ACTIONS(2352),
    [anon_sym_using] = ACTIONS(2352),
    [anon_sym_static_assert] = ACTIONS(2352),
    [anon_sym_concept] = ACTIONS(2352),
    [anon_sym_co_return] = ACTIONS(2352),
    [anon_sym_co_yield] = ACTIONS(2352),
    [anon_sym_R_DQUOTE] = ACTIONS(2354),
    [anon_sym_LR_DQUOTE] = ACTIONS(2354),
    [anon_sym_uR_DQUOTE] = ACTIONS(2354),
    [anon_sym_UR_DQUOTE] = ACTIONS(2354),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2354),
    [anon_sym_co_await] = ACTIONS(2352),
    [anon_sym_new] = ACTIONS(2352),
    [anon_sym_requires] = ACTIONS(2352),
    [sym_this] = ACTIONS(2352),
    [anon_sym_discard] = ACTIONS(2352),
    [anon_sym_precise] = ACTIONS(2352),
    [anon_sym_shared] = ACTIONS(2352),
    [anon_sym_groupshared] = ACTIONS(2352),
    [anon_sym_uniform] = ACTIONS(2352),
    [anon_sym_row_major] = ACTIONS(2352),
    [anon_sym_column_major] = ACTIONS(2352),
    [anon_sym_globallycoherent] = ACTIONS(2352),
    [anon_sym_centroid] = ACTIONS(2352),
    [anon_sym_noperspective] = ACTIONS(2352),
    [anon_sym_nointerpolation] = ACTIONS(2352),
    [anon_sym_sample] = ACTIONS(2352),
    [anon_sym_linear] = ACTIONS(2352),
    [anon_sym_snorm] = ACTIONS(2352),
    [anon_sym_unorm] = ACTIONS(2352),
    [anon_sym_point] = ACTIONS(2352),
    [anon_sym_line] = ACTIONS(2352),
    [anon_sym_triangleadj] = ACTIONS(2352),
    [anon_sym_lineadj] = ACTIONS(2352),
    [anon_sym_triangle] = ACTIONS(2352),
    [anon_sym_cbuffer] = ACTIONS(2352),
  },
  [601] = {
    [sym_identifier] = ACTIONS(2524),
    [aux_sym_preproc_include_token1] = ACTIONS(2524),
    [aux_sym_preproc_def_token1] = ACTIONS(2524),
    [aux_sym_preproc_if_token1] = ACTIONS(2524),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2524),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2524),
    [sym_preproc_directive] = ACTIONS(2524),
    [anon_sym_LPAREN2] = ACTIONS(2526),
    [anon_sym_BANG] = ACTIONS(2526),
    [anon_sym_TILDE] = ACTIONS(2526),
    [anon_sym_DASH] = ACTIONS(2524),
    [anon_sym_PLUS] = ACTIONS(2524),
    [anon_sym_STAR] = ACTIONS(2526),
    [anon_sym_AMP_AMP] = ACTIONS(2526),
    [anon_sym_AMP] = ACTIONS(2524),
    [anon_sym_SEMI] = ACTIONS(2526),
    [anon_sym___extension__] = ACTIONS(2524),
    [anon_sym_typedef] = ACTIONS(2524),
    [anon_sym_in] = ACTIONS(2524),
    [anon_sym_out] = ACTIONS(2524),
    [anon_sym_inout] = ACTIONS(2524),
    [anon_sym_extern] = ACTIONS(2524),
    [anon_sym___attribute__] = ACTIONS(2524),
    [anon_sym_COLON_COLON] = ACTIONS(2526),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2526),
    [anon_sym___declspec] = ACTIONS(2524),
    [anon_sym___based] = ACTIONS(2524),
    [anon_sym___cdecl] = ACTIONS(2524),
    [anon_sym___clrcall] = ACTIONS(2524),
    [anon_sym___stdcall] = ACTIONS(2524),
    [anon_sym___fastcall] = ACTIONS(2524),
    [anon_sym___thiscall] = ACTIONS(2524),
    [anon_sym___vectorcall] = ACTIONS(2524),
    [anon_sym_LBRACE] = ACTIONS(2526),
    [anon_sym_RBRACE] = ACTIONS(2526),
    [anon_sym_signed] = ACTIONS(2524),
    [anon_sym_unsigned] = ACTIONS(2524),
    [anon_sym_long] = ACTIONS(2524),
    [anon_sym_short] = ACTIONS(2524),
    [anon_sym_LBRACK] = ACTIONS(2524),
    [anon_sym_static] = ACTIONS(2524),
    [anon_sym_register] = ACTIONS(2524),
    [anon_sym_inline] = ACTIONS(2524),
    [anon_sym___inline] = ACTIONS(2524),
    [anon_sym___inline__] = ACTIONS(2524),
    [anon_sym___forceinline] = ACTIONS(2524),
    [anon_sym_thread_local] = ACTIONS(2524),
    [anon_sym___thread] = ACTIONS(2524),
    [anon_sym_const] = ACTIONS(2524),
    [anon_sym_constexpr] = ACTIONS(2524),
    [anon_sym_volatile] = ACTIONS(2524),
    [anon_sym_restrict] = ACTIONS(2524),
    [anon_sym___restrict__] = ACTIONS(2524),
    [anon_sym__Atomic] = ACTIONS(2524),
    [anon_sym__Noreturn] = ACTIONS(2524),
    [anon_sym_noreturn] = ACTIONS(2524),
    [anon_sym_mutable] = ACTIONS(2524),
    [anon_sym_constinit] = ACTIONS(2524),
    [anon_sym_consteval] = ACTIONS(2524),
    [anon_sym_alignas] = ACTIONS(2524),
    [anon_sym__Alignas] = ACTIONS(2524),
    [sym_primitive_type] = ACTIONS(2524),
    [anon_sym_enum] = ACTIONS(2524),
    [anon_sym_class] = ACTIONS(2524),
    [anon_sym_struct] = ACTIONS(2524),
    [anon_sym_union] = ACTIONS(2524),
    [anon_sym_if] = ACTIONS(2524),
    [anon_sym_switch] = ACTIONS(2524),
    [anon_sym_case] = ACTIONS(2524),
    [anon_sym_default] = ACTIONS(2524),
    [anon_sym_while] = ACTIONS(2524),
    [anon_sym_do] = ACTIONS(2524),
    [anon_sym_for] = ACTIONS(2524),
    [anon_sym_return] = ACTIONS(2524),
    [anon_sym_break] = ACTIONS(2524),
    [anon_sym_continue] = ACTIONS(2524),
    [anon_sym_goto] = ACTIONS(2524),
    [anon_sym___try] = ACTIONS(2524),
    [anon_sym___leave] = ACTIONS(2524),
    [anon_sym_not] = ACTIONS(2524),
    [anon_sym_compl] = ACTIONS(2524),
    [anon_sym_DASH_DASH] = ACTIONS(2526),
    [anon_sym_PLUS_PLUS] = ACTIONS(2526),
    [anon_sym_sizeof] = ACTIONS(2524),
    [anon_sym___alignof__] = ACTIONS(2524),
    [anon_sym___alignof] = ACTIONS(2524),
    [anon_sym__alignof] = ACTIONS(2524),
    [anon_sym_alignof] = ACTIONS(2524),
    [anon_sym__Alignof] = ACTIONS(2524),
    [anon_sym_offsetof] = ACTIONS(2524),
    [anon_sym__Generic] = ACTIONS(2524),
    [anon_sym_asm] = ACTIONS(2524),
    [anon_sym___asm__] = ACTIONS(2524),
    [sym_number_literal] = ACTIONS(2526),
    [anon_sym_L_SQUOTE] = ACTIONS(2526),
    [anon_sym_u_SQUOTE] = ACTIONS(2526),
    [anon_sym_U_SQUOTE] = ACTIONS(2526),
    [anon_sym_u8_SQUOTE] = ACTIONS(2526),
    [anon_sym_SQUOTE] = ACTIONS(2526),
    [anon_sym_L_DQUOTE] = ACTIONS(2526),
    [anon_sym_u_DQUOTE] = ACTIONS(2526),
    [anon_sym_U_DQUOTE] = ACTIONS(2526),
    [anon_sym_u8_DQUOTE] = ACTIONS(2526),
    [anon_sym_DQUOTE] = ACTIONS(2526),
    [sym_true] = ACTIONS(2524),
    [sym_false] = ACTIONS(2524),
    [anon_sym_NULL] = ACTIONS(2524),
    [anon_sym_nullptr] = ACTIONS(2524),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2524),
    [anon_sym_decltype] = ACTIONS(2524),
    [sym_virtual] = ACTIONS(2524),
    [anon_sym_explicit] = ACTIONS(2524),
    [anon_sym_typename] = ACTIONS(2524),
    [anon_sym_template] = ACTIONS(2524),
    [anon_sym_operator] = ACTIONS(2524),
    [anon_sym_try] = ACTIONS(2524),
    [anon_sym_delete] = ACTIONS(2524),
    [anon_sym_throw] = ACTIONS(2524),
    [anon_sym_namespace] = ACTIONS(2524),
    [anon_sym_using] = ACTIONS(2524),
    [anon_sym_static_assert] = ACTIONS(2524),
    [anon_sym_concept] = ACTIONS(2524),
    [anon_sym_co_return] = ACTIONS(2524),
    [anon_sym_co_yield] = ACTIONS(2524),
    [anon_sym_R_DQUOTE] = ACTIONS(2526),
    [anon_sym_LR_DQUOTE] = ACTIONS(2526),
    [anon_sym_uR_DQUOTE] = ACTIONS(2526),
    [anon_sym_UR_DQUOTE] = ACTIONS(2526),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2526),
    [anon_sym_co_await] = ACTIONS(2524),
    [anon_sym_new] = ACTIONS(2524),
    [anon_sym_requires] = ACTIONS(2524),
    [sym_this] = ACTIONS(2524),
    [anon_sym_discard] = ACTIONS(2524),
    [anon_sym_precise] = ACTIONS(2524),
    [anon_sym_shared] = ACTIONS(2524),
    [anon_sym_groupshared] = ACTIONS(2524),
    [anon_sym_uniform] = ACTIONS(2524),
    [anon_sym_row_major] = ACTIONS(2524),
    [anon_sym_column_major] = ACTIONS(2524),
    [anon_sym_globallycoherent] = ACTIONS(2524),
    [anon_sym_centroid] = ACTIONS(2524),
    [anon_sym_noperspective] = ACTIONS(2524),
    [anon_sym_nointerpolation] = ACTIONS(2524),
    [anon_sym_sample] = ACTIONS(2524),
    [anon_sym_linear] = ACTIONS(2524),
    [anon_sym_snorm] = ACTIONS(2524),
    [anon_sym_unorm] = ACTIONS(2524),
    [anon_sym_point] = ACTIONS(2524),
    [anon_sym_line] = ACTIONS(2524),
    [anon_sym_triangleadj] = ACTIONS(2524),
    [anon_sym_lineadj] = ACTIONS(2524),
    [anon_sym_triangle] = ACTIONS(2524),
    [anon_sym_cbuffer] = ACTIONS(2524),
  },
  [602] = {
    [sym_identifier] = ACTIONS(2528),
    [aux_sym_preproc_include_token1] = ACTIONS(2528),
    [aux_sym_preproc_def_token1] = ACTIONS(2528),
    [aux_sym_preproc_if_token1] = ACTIONS(2528),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2528),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2528),
    [sym_preproc_directive] = ACTIONS(2528),
    [anon_sym_LPAREN2] = ACTIONS(2530),
    [anon_sym_BANG] = ACTIONS(2530),
    [anon_sym_TILDE] = ACTIONS(2530),
    [anon_sym_DASH] = ACTIONS(2528),
    [anon_sym_PLUS] = ACTIONS(2528),
    [anon_sym_STAR] = ACTIONS(2530),
    [anon_sym_AMP_AMP] = ACTIONS(2530),
    [anon_sym_AMP] = ACTIONS(2528),
    [anon_sym_SEMI] = ACTIONS(2530),
    [anon_sym___extension__] = ACTIONS(2528),
    [anon_sym_typedef] = ACTIONS(2528),
    [anon_sym_in] = ACTIONS(2528),
    [anon_sym_out] = ACTIONS(2528),
    [anon_sym_inout] = ACTIONS(2528),
    [anon_sym_extern] = ACTIONS(2528),
    [anon_sym___attribute__] = ACTIONS(2528),
    [anon_sym_COLON_COLON] = ACTIONS(2530),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2530),
    [anon_sym___declspec] = ACTIONS(2528),
    [anon_sym___based] = ACTIONS(2528),
    [anon_sym___cdecl] = ACTIONS(2528),
    [anon_sym___clrcall] = ACTIONS(2528),
    [anon_sym___stdcall] = ACTIONS(2528),
    [anon_sym___fastcall] = ACTIONS(2528),
    [anon_sym___thiscall] = ACTIONS(2528),
    [anon_sym___vectorcall] = ACTIONS(2528),
    [anon_sym_LBRACE] = ACTIONS(2530),
    [anon_sym_RBRACE] = ACTIONS(2530),
    [anon_sym_signed] = ACTIONS(2528),
    [anon_sym_unsigned] = ACTIONS(2528),
    [anon_sym_long] = ACTIONS(2528),
    [anon_sym_short] = ACTIONS(2528),
    [anon_sym_LBRACK] = ACTIONS(2528),
    [anon_sym_static] = ACTIONS(2528),
    [anon_sym_register] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(2528),
    [anon_sym___inline] = ACTIONS(2528),
    [anon_sym___inline__] = ACTIONS(2528),
    [anon_sym___forceinline] = ACTIONS(2528),
    [anon_sym_thread_local] = ACTIONS(2528),
    [anon_sym___thread] = ACTIONS(2528),
    [anon_sym_const] = ACTIONS(2528),
    [anon_sym_constexpr] = ACTIONS(2528),
    [anon_sym_volatile] = ACTIONS(2528),
    [anon_sym_restrict] = ACTIONS(2528),
    [anon_sym___restrict__] = ACTIONS(2528),
    [anon_sym__Atomic] = ACTIONS(2528),
    [anon_sym__Noreturn] = ACTIONS(2528),
    [anon_sym_noreturn] = ACTIONS(2528),
    [anon_sym_mutable] = ACTIONS(2528),
    [anon_sym_constinit] = ACTIONS(2528),
    [anon_sym_consteval] = ACTIONS(2528),
    [anon_sym_alignas] = ACTIONS(2528),
    [anon_sym__Alignas] = ACTIONS(2528),
    [sym_primitive_type] = ACTIONS(2528),
    [anon_sym_enum] = ACTIONS(2528),
    [anon_sym_class] = ACTIONS(2528),
    [anon_sym_struct] = ACTIONS(2528),
    [anon_sym_union] = ACTIONS(2528),
    [anon_sym_if] = ACTIONS(2528),
    [anon_sym_switch] = ACTIONS(2528),
    [anon_sym_case] = ACTIONS(2528),
    [anon_sym_default] = ACTIONS(2528),
    [anon_sym_while] = ACTIONS(2528),
    [anon_sym_do] = ACTIONS(2528),
    [anon_sym_for] = ACTIONS(2528),
    [anon_sym_return] = ACTIONS(2528),
    [anon_sym_break] = ACTIONS(2528),
    [anon_sym_continue] = ACTIONS(2528),
    [anon_sym_goto] = ACTIONS(2528),
    [anon_sym___try] = ACTIONS(2528),
    [anon_sym___leave] = ACTIONS(2528),
    [anon_sym_not] = ACTIONS(2528),
    [anon_sym_compl] = ACTIONS(2528),
    [anon_sym_DASH_DASH] = ACTIONS(2530),
    [anon_sym_PLUS_PLUS] = ACTIONS(2530),
    [anon_sym_sizeof] = ACTIONS(2528),
    [anon_sym___alignof__] = ACTIONS(2528),
    [anon_sym___alignof] = ACTIONS(2528),
    [anon_sym__alignof] = ACTIONS(2528),
    [anon_sym_alignof] = ACTIONS(2528),
    [anon_sym__Alignof] = ACTIONS(2528),
    [anon_sym_offsetof] = ACTIONS(2528),
    [anon_sym__Generic] = ACTIONS(2528),
    [anon_sym_asm] = ACTIONS(2528),
    [anon_sym___asm__] = ACTIONS(2528),
    [sym_number_literal] = ACTIONS(2530),
    [anon_sym_L_SQUOTE] = ACTIONS(2530),
    [anon_sym_u_SQUOTE] = ACTIONS(2530),
    [anon_sym_U_SQUOTE] = ACTIONS(2530),
    [anon_sym_u8_SQUOTE] = ACTIONS(2530),
    [anon_sym_SQUOTE] = ACTIONS(2530),
    [anon_sym_L_DQUOTE] = ACTIONS(2530),
    [anon_sym_u_DQUOTE] = ACTIONS(2530),
    [anon_sym_U_DQUOTE] = ACTIONS(2530),
    [anon_sym_u8_DQUOTE] = ACTIONS(2530),
    [anon_sym_DQUOTE] = ACTIONS(2530),
    [sym_true] = ACTIONS(2528),
    [sym_false] = ACTIONS(2528),
    [anon_sym_NULL] = ACTIONS(2528),
    [anon_sym_nullptr] = ACTIONS(2528),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2528),
    [anon_sym_decltype] = ACTIONS(2528),
    [sym_virtual] = ACTIONS(2528),
    [anon_sym_explicit] = ACTIONS(2528),
    [anon_sym_typename] = ACTIONS(2528),
    [anon_sym_template] = ACTIONS(2528),
    [anon_sym_operator] = ACTIONS(2528),
    [anon_sym_try] = ACTIONS(2528),
    [anon_sym_delete] = ACTIONS(2528),
    [anon_sym_throw] = ACTIONS(2528),
    [anon_sym_namespace] = ACTIONS(2528),
    [anon_sym_using] = ACTIONS(2528),
    [anon_sym_static_assert] = ACTIONS(2528),
    [anon_sym_concept] = ACTIONS(2528),
    [anon_sym_co_return] = ACTIONS(2528),
    [anon_sym_co_yield] = ACTIONS(2528),
    [anon_sym_R_DQUOTE] = ACTIONS(2530),
    [anon_sym_LR_DQUOTE] = ACTIONS(2530),
    [anon_sym_uR_DQUOTE] = ACTIONS(2530),
    [anon_sym_UR_DQUOTE] = ACTIONS(2530),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2530),
    [anon_sym_co_await] = ACTIONS(2528),
    [anon_sym_new] = ACTIONS(2528),
    [anon_sym_requires] = ACTIONS(2528),
    [sym_this] = ACTIONS(2528),
    [anon_sym_discard] = ACTIONS(2528),
    [anon_sym_precise] = ACTIONS(2528),
    [anon_sym_shared] = ACTIONS(2528),
    [anon_sym_groupshared] = ACTIONS(2528),
    [anon_sym_uniform] = ACTIONS(2528),
    [anon_sym_row_major] = ACTIONS(2528),
    [anon_sym_column_major] = ACTIONS(2528),
    [anon_sym_globallycoherent] = ACTIONS(2528),
    [anon_sym_centroid] = ACTIONS(2528),
    [anon_sym_noperspective] = ACTIONS(2528),
    [anon_sym_nointerpolation] = ACTIONS(2528),
    [anon_sym_sample] = ACTIONS(2528),
    [anon_sym_linear] = ACTIONS(2528),
    [anon_sym_snorm] = ACTIONS(2528),
    [anon_sym_unorm] = ACTIONS(2528),
    [anon_sym_point] = ACTIONS(2528),
    [anon_sym_line] = ACTIONS(2528),
    [anon_sym_triangleadj] = ACTIONS(2528),
    [anon_sym_lineadj] = ACTIONS(2528),
    [anon_sym_triangle] = ACTIONS(2528),
    [anon_sym_cbuffer] = ACTIONS(2528),
  },
  [603] = {
    [sym_identifier] = ACTIONS(2506),
    [aux_sym_preproc_include_token1] = ACTIONS(2506),
    [aux_sym_preproc_def_token1] = ACTIONS(2506),
    [aux_sym_preproc_if_token1] = ACTIONS(2506),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2506),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2506),
    [sym_preproc_directive] = ACTIONS(2506),
    [anon_sym_LPAREN2] = ACTIONS(2508),
    [anon_sym_BANG] = ACTIONS(2508),
    [anon_sym_TILDE] = ACTIONS(2508),
    [anon_sym_DASH] = ACTIONS(2506),
    [anon_sym_PLUS] = ACTIONS(2506),
    [anon_sym_STAR] = ACTIONS(2508),
    [anon_sym_AMP_AMP] = ACTIONS(2508),
    [anon_sym_AMP] = ACTIONS(2506),
    [anon_sym_SEMI] = ACTIONS(2508),
    [anon_sym___extension__] = ACTIONS(2506),
    [anon_sym_typedef] = ACTIONS(2506),
    [anon_sym_in] = ACTIONS(2506),
    [anon_sym_out] = ACTIONS(2506),
    [anon_sym_inout] = ACTIONS(2506),
    [anon_sym_extern] = ACTIONS(2506),
    [anon_sym___attribute__] = ACTIONS(2506),
    [anon_sym_COLON_COLON] = ACTIONS(2508),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2508),
    [anon_sym___declspec] = ACTIONS(2506),
    [anon_sym___based] = ACTIONS(2506),
    [anon_sym___cdecl] = ACTIONS(2506),
    [anon_sym___clrcall] = ACTIONS(2506),
    [anon_sym___stdcall] = ACTIONS(2506),
    [anon_sym___fastcall] = ACTIONS(2506),
    [anon_sym___thiscall] = ACTIONS(2506),
    [anon_sym___vectorcall] = ACTIONS(2506),
    [anon_sym_LBRACE] = ACTIONS(2508),
    [anon_sym_RBRACE] = ACTIONS(2508),
    [anon_sym_signed] = ACTIONS(2506),
    [anon_sym_unsigned] = ACTIONS(2506),
    [anon_sym_long] = ACTIONS(2506),
    [anon_sym_short] = ACTIONS(2506),
    [anon_sym_LBRACK] = ACTIONS(2506),
    [anon_sym_static] = ACTIONS(2506),
    [anon_sym_register] = ACTIONS(2506),
    [anon_sym_inline] = ACTIONS(2506),
    [anon_sym___inline] = ACTIONS(2506),
    [anon_sym___inline__] = ACTIONS(2506),
    [anon_sym___forceinline] = ACTIONS(2506),
    [anon_sym_thread_local] = ACTIONS(2506),
    [anon_sym___thread] = ACTIONS(2506),
    [anon_sym_const] = ACTIONS(2506),
    [anon_sym_constexpr] = ACTIONS(2506),
    [anon_sym_volatile] = ACTIONS(2506),
    [anon_sym_restrict] = ACTIONS(2506),
    [anon_sym___restrict__] = ACTIONS(2506),
    [anon_sym__Atomic] = ACTIONS(2506),
    [anon_sym__Noreturn] = ACTIONS(2506),
    [anon_sym_noreturn] = ACTIONS(2506),
    [anon_sym_mutable] = ACTIONS(2506),
    [anon_sym_constinit] = ACTIONS(2506),
    [anon_sym_consteval] = ACTIONS(2506),
    [anon_sym_alignas] = ACTIONS(2506),
    [anon_sym__Alignas] = ACTIONS(2506),
    [sym_primitive_type] = ACTIONS(2506),
    [anon_sym_enum] = ACTIONS(2506),
    [anon_sym_class] = ACTIONS(2506),
    [anon_sym_struct] = ACTIONS(2506),
    [anon_sym_union] = ACTIONS(2506),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_switch] = ACTIONS(2506),
    [anon_sym_case] = ACTIONS(2506),
    [anon_sym_default] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(2506),
    [anon_sym_do] = ACTIONS(2506),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_return] = ACTIONS(2506),
    [anon_sym_break] = ACTIONS(2506),
    [anon_sym_continue] = ACTIONS(2506),
    [anon_sym_goto] = ACTIONS(2506),
    [anon_sym___try] = ACTIONS(2506),
    [anon_sym___leave] = ACTIONS(2506),
    [anon_sym_not] = ACTIONS(2506),
    [anon_sym_compl] = ACTIONS(2506),
    [anon_sym_DASH_DASH] = ACTIONS(2508),
    [anon_sym_PLUS_PLUS] = ACTIONS(2508),
    [anon_sym_sizeof] = ACTIONS(2506),
    [anon_sym___alignof__] = ACTIONS(2506),
    [anon_sym___alignof] = ACTIONS(2506),
    [anon_sym__alignof] = ACTIONS(2506),
    [anon_sym_alignof] = ACTIONS(2506),
    [anon_sym__Alignof] = ACTIONS(2506),
    [anon_sym_offsetof] = ACTIONS(2506),
    [anon_sym__Generic] = ACTIONS(2506),
    [anon_sym_asm] = ACTIONS(2506),
    [anon_sym___asm__] = ACTIONS(2506),
    [sym_number_literal] = ACTIONS(2508),
    [anon_sym_L_SQUOTE] = ACTIONS(2508),
    [anon_sym_u_SQUOTE] = ACTIONS(2508),
    [anon_sym_U_SQUOTE] = ACTIONS(2508),
    [anon_sym_u8_SQUOTE] = ACTIONS(2508),
    [anon_sym_SQUOTE] = ACTIONS(2508),
    [anon_sym_L_DQUOTE] = ACTIONS(2508),
    [anon_sym_u_DQUOTE] = ACTIONS(2508),
    [anon_sym_U_DQUOTE] = ACTIONS(2508),
    [anon_sym_u8_DQUOTE] = ACTIONS(2508),
    [anon_sym_DQUOTE] = ACTIONS(2508),
    [sym_true] = ACTIONS(2506),
    [sym_false] = ACTIONS(2506),
    [anon_sym_NULL] = ACTIONS(2506),
    [anon_sym_nullptr] = ACTIONS(2506),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2506),
    [anon_sym_decltype] = ACTIONS(2506),
    [sym_virtual] = ACTIONS(2506),
    [anon_sym_explicit] = ACTIONS(2506),
    [anon_sym_typename] = ACTIONS(2506),
    [anon_sym_template] = ACTIONS(2506),
    [anon_sym_operator] = ACTIONS(2506),
    [anon_sym_try] = ACTIONS(2506),
    [anon_sym_delete] = ACTIONS(2506),
    [anon_sym_throw] = ACTIONS(2506),
    [anon_sym_namespace] = ACTIONS(2506),
    [anon_sym_using] = ACTIONS(2506),
    [anon_sym_static_assert] = ACTIONS(2506),
    [anon_sym_concept] = ACTIONS(2506),
    [anon_sym_co_return] = ACTIONS(2506),
    [anon_sym_co_yield] = ACTIONS(2506),
    [anon_sym_R_DQUOTE] = ACTIONS(2508),
    [anon_sym_LR_DQUOTE] = ACTIONS(2508),
    [anon_sym_uR_DQUOTE] = ACTIONS(2508),
    [anon_sym_UR_DQUOTE] = ACTIONS(2508),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2508),
    [anon_sym_co_await] = ACTIONS(2506),
    [anon_sym_new] = ACTIONS(2506),
    [anon_sym_requires] = ACTIONS(2506),
    [sym_this] = ACTIONS(2506),
    [anon_sym_discard] = ACTIONS(2506),
    [anon_sym_precise] = ACTIONS(2506),
    [anon_sym_shared] = ACTIONS(2506),
    [anon_sym_groupshared] = ACTIONS(2506),
    [anon_sym_uniform] = ACTIONS(2506),
    [anon_sym_row_major] = ACTIONS(2506),
    [anon_sym_column_major] = ACTIONS(2506),
    [anon_sym_globallycoherent] = ACTIONS(2506),
    [anon_sym_centroid] = ACTIONS(2506),
    [anon_sym_noperspective] = ACTIONS(2506),
    [anon_sym_nointerpolation] = ACTIONS(2506),
    [anon_sym_sample] = ACTIONS(2506),
    [anon_sym_linear] = ACTIONS(2506),
    [anon_sym_snorm] = ACTIONS(2506),
    [anon_sym_unorm] = ACTIONS(2506),
    [anon_sym_point] = ACTIONS(2506),
    [anon_sym_line] = ACTIONS(2506),
    [anon_sym_triangleadj] = ACTIONS(2506),
    [anon_sym_lineadj] = ACTIONS(2506),
    [anon_sym_triangle] = ACTIONS(2506),
    [anon_sym_cbuffer] = ACTIONS(2506),
  },
  [604] = {
    [sym_identifier] = ACTIONS(2436),
    [aux_sym_preproc_include_token1] = ACTIONS(2436),
    [aux_sym_preproc_def_token1] = ACTIONS(2436),
    [aux_sym_preproc_if_token1] = ACTIONS(2436),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2436),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2436),
    [sym_preproc_directive] = ACTIONS(2436),
    [anon_sym_LPAREN2] = ACTIONS(2438),
    [anon_sym_BANG] = ACTIONS(2438),
    [anon_sym_TILDE] = ACTIONS(2438),
    [anon_sym_DASH] = ACTIONS(2436),
    [anon_sym_PLUS] = ACTIONS(2436),
    [anon_sym_STAR] = ACTIONS(2438),
    [anon_sym_AMP_AMP] = ACTIONS(2438),
    [anon_sym_AMP] = ACTIONS(2436),
    [anon_sym_SEMI] = ACTIONS(2438),
    [anon_sym___extension__] = ACTIONS(2436),
    [anon_sym_typedef] = ACTIONS(2436),
    [anon_sym_in] = ACTIONS(2436),
    [anon_sym_out] = ACTIONS(2436),
    [anon_sym_inout] = ACTIONS(2436),
    [anon_sym_extern] = ACTIONS(2436),
    [anon_sym___attribute__] = ACTIONS(2436),
    [anon_sym_COLON_COLON] = ACTIONS(2438),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2438),
    [anon_sym___declspec] = ACTIONS(2436),
    [anon_sym___based] = ACTIONS(2436),
    [anon_sym___cdecl] = ACTIONS(2436),
    [anon_sym___clrcall] = ACTIONS(2436),
    [anon_sym___stdcall] = ACTIONS(2436),
    [anon_sym___fastcall] = ACTIONS(2436),
    [anon_sym___thiscall] = ACTIONS(2436),
    [anon_sym___vectorcall] = ACTIONS(2436),
    [anon_sym_LBRACE] = ACTIONS(2438),
    [anon_sym_RBRACE] = ACTIONS(2438),
    [anon_sym_signed] = ACTIONS(2436),
    [anon_sym_unsigned] = ACTIONS(2436),
    [anon_sym_long] = ACTIONS(2436),
    [anon_sym_short] = ACTIONS(2436),
    [anon_sym_LBRACK] = ACTIONS(2436),
    [anon_sym_static] = ACTIONS(2436),
    [anon_sym_register] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2436),
    [anon_sym___inline] = ACTIONS(2436),
    [anon_sym___inline__] = ACTIONS(2436),
    [anon_sym___forceinline] = ACTIONS(2436),
    [anon_sym_thread_local] = ACTIONS(2436),
    [anon_sym___thread] = ACTIONS(2436),
    [anon_sym_const] = ACTIONS(2436),
    [anon_sym_constexpr] = ACTIONS(2436),
    [anon_sym_volatile] = ACTIONS(2436),
    [anon_sym_restrict] = ACTIONS(2436),
    [anon_sym___restrict__] = ACTIONS(2436),
    [anon_sym__Atomic] = ACTIONS(2436),
    [anon_sym__Noreturn] = ACTIONS(2436),
    [anon_sym_noreturn] = ACTIONS(2436),
    [anon_sym_mutable] = ACTIONS(2436),
    [anon_sym_constinit] = ACTIONS(2436),
    [anon_sym_consteval] = ACTIONS(2436),
    [anon_sym_alignas] = ACTIONS(2436),
    [anon_sym__Alignas] = ACTIONS(2436),
    [sym_primitive_type] = ACTIONS(2436),
    [anon_sym_enum] = ACTIONS(2436),
    [anon_sym_class] = ACTIONS(2436),
    [anon_sym_struct] = ACTIONS(2436),
    [anon_sym_union] = ACTIONS(2436),
    [anon_sym_if] = ACTIONS(2436),
    [anon_sym_switch] = ACTIONS(2436),
    [anon_sym_case] = ACTIONS(2436),
    [anon_sym_default] = ACTIONS(2436),
    [anon_sym_while] = ACTIONS(2436),
    [anon_sym_do] = ACTIONS(2436),
    [anon_sym_for] = ACTIONS(2436),
    [anon_sym_return] = ACTIONS(2436),
    [anon_sym_break] = ACTIONS(2436),
    [anon_sym_continue] = ACTIONS(2436),
    [anon_sym_goto] = ACTIONS(2436),
    [anon_sym___try] = ACTIONS(2436),
    [anon_sym___leave] = ACTIONS(2436),
    [anon_sym_not] = ACTIONS(2436),
    [anon_sym_compl] = ACTIONS(2436),
    [anon_sym_DASH_DASH] = ACTIONS(2438),
    [anon_sym_PLUS_PLUS] = ACTIONS(2438),
    [anon_sym_sizeof] = ACTIONS(2436),
    [anon_sym___alignof__] = ACTIONS(2436),
    [anon_sym___alignof] = ACTIONS(2436),
    [anon_sym__alignof] = ACTIONS(2436),
    [anon_sym_alignof] = ACTIONS(2436),
    [anon_sym__Alignof] = ACTIONS(2436),
    [anon_sym_offsetof] = ACTIONS(2436),
    [anon_sym__Generic] = ACTIONS(2436),
    [anon_sym_asm] = ACTIONS(2436),
    [anon_sym___asm__] = ACTIONS(2436),
    [sym_number_literal] = ACTIONS(2438),
    [anon_sym_L_SQUOTE] = ACTIONS(2438),
    [anon_sym_u_SQUOTE] = ACTIONS(2438),
    [anon_sym_U_SQUOTE] = ACTIONS(2438),
    [anon_sym_u8_SQUOTE] = ACTIONS(2438),
    [anon_sym_SQUOTE] = ACTIONS(2438),
    [anon_sym_L_DQUOTE] = ACTIONS(2438),
    [anon_sym_u_DQUOTE] = ACTIONS(2438),
    [anon_sym_U_DQUOTE] = ACTIONS(2438),
    [anon_sym_u8_DQUOTE] = ACTIONS(2438),
    [anon_sym_DQUOTE] = ACTIONS(2438),
    [sym_true] = ACTIONS(2436),
    [sym_false] = ACTIONS(2436),
    [anon_sym_NULL] = ACTIONS(2436),
    [anon_sym_nullptr] = ACTIONS(2436),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2436),
    [anon_sym_decltype] = ACTIONS(2436),
    [sym_virtual] = ACTIONS(2436),
    [anon_sym_explicit] = ACTIONS(2436),
    [anon_sym_typename] = ACTIONS(2436),
    [anon_sym_template] = ACTIONS(2436),
    [anon_sym_operator] = ACTIONS(2436),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_delete] = ACTIONS(2436),
    [anon_sym_throw] = ACTIONS(2436),
    [anon_sym_namespace] = ACTIONS(2436),
    [anon_sym_using] = ACTIONS(2436),
    [anon_sym_static_assert] = ACTIONS(2436),
    [anon_sym_concept] = ACTIONS(2436),
    [anon_sym_co_return] = ACTIONS(2436),
    [anon_sym_co_yield] = ACTIONS(2436),
    [anon_sym_R_DQUOTE] = ACTIONS(2438),
    [anon_sym_LR_DQUOTE] = ACTIONS(2438),
    [anon_sym_uR_DQUOTE] = ACTIONS(2438),
    [anon_sym_UR_DQUOTE] = ACTIONS(2438),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2438),
    [anon_sym_co_await] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(2436),
    [anon_sym_requires] = ACTIONS(2436),
    [sym_this] = ACTIONS(2436),
    [anon_sym_discard] = ACTIONS(2436),
    [anon_sym_precise] = ACTIONS(2436),
    [anon_sym_shared] = ACTIONS(2436),
    [anon_sym_groupshared] = ACTIONS(2436),
    [anon_sym_uniform] = ACTIONS(2436),
    [anon_sym_row_major] = ACTIONS(2436),
    [anon_sym_column_major] = ACTIONS(2436),
    [anon_sym_globallycoherent] = ACTIONS(2436),
    [anon_sym_centroid] = ACTIONS(2436),
    [anon_sym_noperspective] = ACTIONS(2436),
    [anon_sym_nointerpolation] = ACTIONS(2436),
    [anon_sym_sample] = ACTIONS(2436),
    [anon_sym_linear] = ACTIONS(2436),
    [anon_sym_snorm] = ACTIONS(2436),
    [anon_sym_unorm] = ACTIONS(2436),
    [anon_sym_point] = ACTIONS(2436),
    [anon_sym_line] = ACTIONS(2436),
    [anon_sym_triangleadj] = ACTIONS(2436),
    [anon_sym_lineadj] = ACTIONS(2436),
    [anon_sym_triangle] = ACTIONS(2436),
    [anon_sym_cbuffer] = ACTIONS(2436),
  },
  [605] = {
    [sym_identifier] = ACTIONS(2408),
    [aux_sym_preproc_include_token1] = ACTIONS(2408),
    [aux_sym_preproc_def_token1] = ACTIONS(2408),
    [aux_sym_preproc_if_token1] = ACTIONS(2408),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2408),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2408),
    [sym_preproc_directive] = ACTIONS(2408),
    [anon_sym_LPAREN2] = ACTIONS(2410),
    [anon_sym_BANG] = ACTIONS(2410),
    [anon_sym_TILDE] = ACTIONS(2410),
    [anon_sym_DASH] = ACTIONS(2408),
    [anon_sym_PLUS] = ACTIONS(2408),
    [anon_sym_STAR] = ACTIONS(2410),
    [anon_sym_AMP_AMP] = ACTIONS(2410),
    [anon_sym_AMP] = ACTIONS(2408),
    [anon_sym_SEMI] = ACTIONS(2410),
    [anon_sym___extension__] = ACTIONS(2408),
    [anon_sym_typedef] = ACTIONS(2408),
    [anon_sym_in] = ACTIONS(2408),
    [anon_sym_out] = ACTIONS(2408),
    [anon_sym_inout] = ACTIONS(2408),
    [anon_sym_extern] = ACTIONS(2408),
    [anon_sym___attribute__] = ACTIONS(2408),
    [anon_sym_COLON_COLON] = ACTIONS(2410),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2410),
    [anon_sym___declspec] = ACTIONS(2408),
    [anon_sym___based] = ACTIONS(2408),
    [anon_sym___cdecl] = ACTIONS(2408),
    [anon_sym___clrcall] = ACTIONS(2408),
    [anon_sym___stdcall] = ACTIONS(2408),
    [anon_sym___fastcall] = ACTIONS(2408),
    [anon_sym___thiscall] = ACTIONS(2408),
    [anon_sym___vectorcall] = ACTIONS(2408),
    [anon_sym_LBRACE] = ACTIONS(2410),
    [anon_sym_RBRACE] = ACTIONS(2410),
    [anon_sym_signed] = ACTIONS(2408),
    [anon_sym_unsigned] = ACTIONS(2408),
    [anon_sym_long] = ACTIONS(2408),
    [anon_sym_short] = ACTIONS(2408),
    [anon_sym_LBRACK] = ACTIONS(2408),
    [anon_sym_static] = ACTIONS(2408),
    [anon_sym_register] = ACTIONS(2408),
    [anon_sym_inline] = ACTIONS(2408),
    [anon_sym___inline] = ACTIONS(2408),
    [anon_sym___inline__] = ACTIONS(2408),
    [anon_sym___forceinline] = ACTIONS(2408),
    [anon_sym_thread_local] = ACTIONS(2408),
    [anon_sym___thread] = ACTIONS(2408),
    [anon_sym_const] = ACTIONS(2408),
    [anon_sym_constexpr] = ACTIONS(2408),
    [anon_sym_volatile] = ACTIONS(2408),
    [anon_sym_restrict] = ACTIONS(2408),
    [anon_sym___restrict__] = ACTIONS(2408),
    [anon_sym__Atomic] = ACTIONS(2408),
    [anon_sym__Noreturn] = ACTIONS(2408),
    [anon_sym_noreturn] = ACTIONS(2408),
    [anon_sym_mutable] = ACTIONS(2408),
    [anon_sym_constinit] = ACTIONS(2408),
    [anon_sym_consteval] = ACTIONS(2408),
    [anon_sym_alignas] = ACTIONS(2408),
    [anon_sym__Alignas] = ACTIONS(2408),
    [sym_primitive_type] = ACTIONS(2408),
    [anon_sym_enum] = ACTIONS(2408),
    [anon_sym_class] = ACTIONS(2408),
    [anon_sym_struct] = ACTIONS(2408),
    [anon_sym_union] = ACTIONS(2408),
    [anon_sym_if] = ACTIONS(2408),
    [anon_sym_switch] = ACTIONS(2408),
    [anon_sym_case] = ACTIONS(2408),
    [anon_sym_default] = ACTIONS(2408),
    [anon_sym_while] = ACTIONS(2408),
    [anon_sym_do] = ACTIONS(2408),
    [anon_sym_for] = ACTIONS(2408),
    [anon_sym_return] = ACTIONS(2408),
    [anon_sym_break] = ACTIONS(2408),
    [anon_sym_continue] = ACTIONS(2408),
    [anon_sym_goto] = ACTIONS(2408),
    [anon_sym___try] = ACTIONS(2408),
    [anon_sym___leave] = ACTIONS(2408),
    [anon_sym_not] = ACTIONS(2408),
    [anon_sym_compl] = ACTIONS(2408),
    [anon_sym_DASH_DASH] = ACTIONS(2410),
    [anon_sym_PLUS_PLUS] = ACTIONS(2410),
    [anon_sym_sizeof] = ACTIONS(2408),
    [anon_sym___alignof__] = ACTIONS(2408),
    [anon_sym___alignof] = ACTIONS(2408),
    [anon_sym__alignof] = ACTIONS(2408),
    [anon_sym_alignof] = ACTIONS(2408),
    [anon_sym__Alignof] = ACTIONS(2408),
    [anon_sym_offsetof] = ACTIONS(2408),
    [anon_sym__Generic] = ACTIONS(2408),
    [anon_sym_asm] = ACTIONS(2408),
    [anon_sym___asm__] = ACTIONS(2408),
    [sym_number_literal] = ACTIONS(2410),
    [anon_sym_L_SQUOTE] = ACTIONS(2410),
    [anon_sym_u_SQUOTE] = ACTIONS(2410),
    [anon_sym_U_SQUOTE] = ACTIONS(2410),
    [anon_sym_u8_SQUOTE] = ACTIONS(2410),
    [anon_sym_SQUOTE] = ACTIONS(2410),
    [anon_sym_L_DQUOTE] = ACTIONS(2410),
    [anon_sym_u_DQUOTE] = ACTIONS(2410),
    [anon_sym_U_DQUOTE] = ACTIONS(2410),
    [anon_sym_u8_DQUOTE] = ACTIONS(2410),
    [anon_sym_DQUOTE] = ACTIONS(2410),
    [sym_true] = ACTIONS(2408),
    [sym_false] = ACTIONS(2408),
    [anon_sym_NULL] = ACTIONS(2408),
    [anon_sym_nullptr] = ACTIONS(2408),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2408),
    [anon_sym_decltype] = ACTIONS(2408),
    [sym_virtual] = ACTIONS(2408),
    [anon_sym_explicit] = ACTIONS(2408),
    [anon_sym_typename] = ACTIONS(2408),
    [anon_sym_template] = ACTIONS(2408),
    [anon_sym_operator] = ACTIONS(2408),
    [anon_sym_try] = ACTIONS(2408),
    [anon_sym_delete] = ACTIONS(2408),
    [anon_sym_throw] = ACTIONS(2408),
    [anon_sym_namespace] = ACTIONS(2408),
    [anon_sym_using] = ACTIONS(2408),
    [anon_sym_static_assert] = ACTIONS(2408),
    [anon_sym_concept] = ACTIONS(2408),
    [anon_sym_co_return] = ACTIONS(2408),
    [anon_sym_co_yield] = ACTIONS(2408),
    [anon_sym_R_DQUOTE] = ACTIONS(2410),
    [anon_sym_LR_DQUOTE] = ACTIONS(2410),
    [anon_sym_uR_DQUOTE] = ACTIONS(2410),
    [anon_sym_UR_DQUOTE] = ACTIONS(2410),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2410),
    [anon_sym_co_await] = ACTIONS(2408),
    [anon_sym_new] = ACTIONS(2408),
    [anon_sym_requires] = ACTIONS(2408),
    [sym_this] = ACTIONS(2408),
    [anon_sym_discard] = ACTIONS(2408),
    [anon_sym_precise] = ACTIONS(2408),
    [anon_sym_shared] = ACTIONS(2408),
    [anon_sym_groupshared] = ACTIONS(2408),
    [anon_sym_uniform] = ACTIONS(2408),
    [anon_sym_row_major] = ACTIONS(2408),
    [anon_sym_column_major] = ACTIONS(2408),
    [anon_sym_globallycoherent] = ACTIONS(2408),
    [anon_sym_centroid] = ACTIONS(2408),
    [anon_sym_noperspective] = ACTIONS(2408),
    [anon_sym_nointerpolation] = ACTIONS(2408),
    [anon_sym_sample] = ACTIONS(2408),
    [anon_sym_linear] = ACTIONS(2408),
    [anon_sym_snorm] = ACTIONS(2408),
    [anon_sym_unorm] = ACTIONS(2408),
    [anon_sym_point] = ACTIONS(2408),
    [anon_sym_line] = ACTIONS(2408),
    [anon_sym_triangleadj] = ACTIONS(2408),
    [anon_sym_lineadj] = ACTIONS(2408),
    [anon_sym_triangle] = ACTIONS(2408),
    [anon_sym_cbuffer] = ACTIONS(2408),
  },
  [606] = {
    [sym_identifier] = ACTIONS(2389),
    [aux_sym_preproc_include_token1] = ACTIONS(2389),
    [aux_sym_preproc_def_token1] = ACTIONS(2389),
    [aux_sym_preproc_if_token1] = ACTIONS(2389),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2389),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2389),
    [sym_preproc_directive] = ACTIONS(2389),
    [anon_sym_LPAREN2] = ACTIONS(2391),
    [anon_sym_BANG] = ACTIONS(2391),
    [anon_sym_TILDE] = ACTIONS(2391),
    [anon_sym_DASH] = ACTIONS(2389),
    [anon_sym_PLUS] = ACTIONS(2389),
    [anon_sym_STAR] = ACTIONS(2391),
    [anon_sym_AMP_AMP] = ACTIONS(2391),
    [anon_sym_AMP] = ACTIONS(2389),
    [anon_sym_SEMI] = ACTIONS(2391),
    [anon_sym___extension__] = ACTIONS(2389),
    [anon_sym_typedef] = ACTIONS(2389),
    [anon_sym_in] = ACTIONS(2389),
    [anon_sym_out] = ACTIONS(2389),
    [anon_sym_inout] = ACTIONS(2389),
    [anon_sym_extern] = ACTIONS(2389),
    [anon_sym___attribute__] = ACTIONS(2389),
    [anon_sym_COLON_COLON] = ACTIONS(2391),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2391),
    [anon_sym___declspec] = ACTIONS(2389),
    [anon_sym___based] = ACTIONS(2389),
    [anon_sym___cdecl] = ACTIONS(2389),
    [anon_sym___clrcall] = ACTIONS(2389),
    [anon_sym___stdcall] = ACTIONS(2389),
    [anon_sym___fastcall] = ACTIONS(2389),
    [anon_sym___thiscall] = ACTIONS(2389),
    [anon_sym___vectorcall] = ACTIONS(2389),
    [anon_sym_LBRACE] = ACTIONS(2391),
    [anon_sym_RBRACE] = ACTIONS(2391),
    [anon_sym_signed] = ACTIONS(2389),
    [anon_sym_unsigned] = ACTIONS(2389),
    [anon_sym_long] = ACTIONS(2389),
    [anon_sym_short] = ACTIONS(2389),
    [anon_sym_LBRACK] = ACTIONS(2389),
    [anon_sym_static] = ACTIONS(2389),
    [anon_sym_register] = ACTIONS(2389),
    [anon_sym_inline] = ACTIONS(2389),
    [anon_sym___inline] = ACTIONS(2389),
    [anon_sym___inline__] = ACTIONS(2389),
    [anon_sym___forceinline] = ACTIONS(2389),
    [anon_sym_thread_local] = ACTIONS(2389),
    [anon_sym___thread] = ACTIONS(2389),
    [anon_sym_const] = ACTIONS(2389),
    [anon_sym_constexpr] = ACTIONS(2389),
    [anon_sym_volatile] = ACTIONS(2389),
    [anon_sym_restrict] = ACTIONS(2389),
    [anon_sym___restrict__] = ACTIONS(2389),
    [anon_sym__Atomic] = ACTIONS(2389),
    [anon_sym__Noreturn] = ACTIONS(2389),
    [anon_sym_noreturn] = ACTIONS(2389),
    [anon_sym_mutable] = ACTIONS(2389),
    [anon_sym_constinit] = ACTIONS(2389),
    [anon_sym_consteval] = ACTIONS(2389),
    [anon_sym_alignas] = ACTIONS(2389),
    [anon_sym__Alignas] = ACTIONS(2389),
    [sym_primitive_type] = ACTIONS(2389),
    [anon_sym_enum] = ACTIONS(2389),
    [anon_sym_class] = ACTIONS(2389),
    [anon_sym_struct] = ACTIONS(2389),
    [anon_sym_union] = ACTIONS(2389),
    [anon_sym_if] = ACTIONS(2389),
    [anon_sym_switch] = ACTIONS(2389),
    [anon_sym_case] = ACTIONS(2389),
    [anon_sym_default] = ACTIONS(2389),
    [anon_sym_while] = ACTIONS(2389),
    [anon_sym_do] = ACTIONS(2389),
    [anon_sym_for] = ACTIONS(2389),
    [anon_sym_return] = ACTIONS(2389),
    [anon_sym_break] = ACTIONS(2389),
    [anon_sym_continue] = ACTIONS(2389),
    [anon_sym_goto] = ACTIONS(2389),
    [anon_sym___try] = ACTIONS(2389),
    [anon_sym___leave] = ACTIONS(2389),
    [anon_sym_not] = ACTIONS(2389),
    [anon_sym_compl] = ACTIONS(2389),
    [anon_sym_DASH_DASH] = ACTIONS(2391),
    [anon_sym_PLUS_PLUS] = ACTIONS(2391),
    [anon_sym_sizeof] = ACTIONS(2389),
    [anon_sym___alignof__] = ACTIONS(2389),
    [anon_sym___alignof] = ACTIONS(2389),
    [anon_sym__alignof] = ACTIONS(2389),
    [anon_sym_alignof] = ACTIONS(2389),
    [anon_sym__Alignof] = ACTIONS(2389),
    [anon_sym_offsetof] = ACTIONS(2389),
    [anon_sym__Generic] = ACTIONS(2389),
    [anon_sym_asm] = ACTIONS(2389),
    [anon_sym___asm__] = ACTIONS(2389),
    [sym_number_literal] = ACTIONS(2391),
    [anon_sym_L_SQUOTE] = ACTIONS(2391),
    [anon_sym_u_SQUOTE] = ACTIONS(2391),
    [anon_sym_U_SQUOTE] = ACTIONS(2391),
    [anon_sym_u8_SQUOTE] = ACTIONS(2391),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_L_DQUOTE] = ACTIONS(2391),
    [anon_sym_u_DQUOTE] = ACTIONS(2391),
    [anon_sym_U_DQUOTE] = ACTIONS(2391),
    [anon_sym_u8_DQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2391),
    [sym_true] = ACTIONS(2389),
    [sym_false] = ACTIONS(2389),
    [anon_sym_NULL] = ACTIONS(2389),
    [anon_sym_nullptr] = ACTIONS(2389),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2389),
    [anon_sym_decltype] = ACTIONS(2389),
    [sym_virtual] = ACTIONS(2389),
    [anon_sym_explicit] = ACTIONS(2389),
    [anon_sym_typename] = ACTIONS(2389),
    [anon_sym_template] = ACTIONS(2389),
    [anon_sym_operator] = ACTIONS(2389),
    [anon_sym_try] = ACTIONS(2389),
    [anon_sym_delete] = ACTIONS(2389),
    [anon_sym_throw] = ACTIONS(2389),
    [anon_sym_namespace] = ACTIONS(2389),
    [anon_sym_using] = ACTIONS(2389),
    [anon_sym_static_assert] = ACTIONS(2389),
    [anon_sym_concept] = ACTIONS(2389),
    [anon_sym_co_return] = ACTIONS(2389),
    [anon_sym_co_yield] = ACTIONS(2389),
    [anon_sym_R_DQUOTE] = ACTIONS(2391),
    [anon_sym_LR_DQUOTE] = ACTIONS(2391),
    [anon_sym_uR_DQUOTE] = ACTIONS(2391),
    [anon_sym_UR_DQUOTE] = ACTIONS(2391),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2391),
    [anon_sym_co_await] = ACTIONS(2389),
    [anon_sym_new] = ACTIONS(2389),
    [anon_sym_requires] = ACTIONS(2389),
    [sym_this] = ACTIONS(2389),
    [anon_sym_discard] = ACTIONS(2389),
    [anon_sym_precise] = ACTIONS(2389),
    [anon_sym_shared] = ACTIONS(2389),
    [anon_sym_groupshared] = ACTIONS(2389),
    [anon_sym_uniform] = ACTIONS(2389),
    [anon_sym_row_major] = ACTIONS(2389),
    [anon_sym_column_major] = ACTIONS(2389),
    [anon_sym_globallycoherent] = ACTIONS(2389),
    [anon_sym_centroid] = ACTIONS(2389),
    [anon_sym_noperspective] = ACTIONS(2389),
    [anon_sym_nointerpolation] = ACTIONS(2389),
    [anon_sym_sample] = ACTIONS(2389),
    [anon_sym_linear] = ACTIONS(2389),
    [anon_sym_snorm] = ACTIONS(2389),
    [anon_sym_unorm] = ACTIONS(2389),
    [anon_sym_point] = ACTIONS(2389),
    [anon_sym_line] = ACTIONS(2389),
    [anon_sym_triangleadj] = ACTIONS(2389),
    [anon_sym_lineadj] = ACTIONS(2389),
    [anon_sym_triangle] = ACTIONS(2389),
    [anon_sym_cbuffer] = ACTIONS(2389),
  },
  [607] = {
    [sym_identifier] = ACTIONS(2360),
    [aux_sym_preproc_include_token1] = ACTIONS(2360),
    [aux_sym_preproc_def_token1] = ACTIONS(2360),
    [aux_sym_preproc_if_token1] = ACTIONS(2360),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2360),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2360),
    [sym_preproc_directive] = ACTIONS(2360),
    [anon_sym_LPAREN2] = ACTIONS(2362),
    [anon_sym_BANG] = ACTIONS(2362),
    [anon_sym_TILDE] = ACTIONS(2362),
    [anon_sym_DASH] = ACTIONS(2360),
    [anon_sym_PLUS] = ACTIONS(2360),
    [anon_sym_STAR] = ACTIONS(2362),
    [anon_sym_AMP_AMP] = ACTIONS(2362),
    [anon_sym_AMP] = ACTIONS(2360),
    [anon_sym_SEMI] = ACTIONS(2362),
    [anon_sym___extension__] = ACTIONS(2360),
    [anon_sym_typedef] = ACTIONS(2360),
    [anon_sym_in] = ACTIONS(2360),
    [anon_sym_out] = ACTIONS(2360),
    [anon_sym_inout] = ACTIONS(2360),
    [anon_sym_extern] = ACTIONS(2360),
    [anon_sym___attribute__] = ACTIONS(2360),
    [anon_sym_COLON_COLON] = ACTIONS(2362),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2362),
    [anon_sym___declspec] = ACTIONS(2360),
    [anon_sym___based] = ACTIONS(2360),
    [anon_sym___cdecl] = ACTIONS(2360),
    [anon_sym___clrcall] = ACTIONS(2360),
    [anon_sym___stdcall] = ACTIONS(2360),
    [anon_sym___fastcall] = ACTIONS(2360),
    [anon_sym___thiscall] = ACTIONS(2360),
    [anon_sym___vectorcall] = ACTIONS(2360),
    [anon_sym_LBRACE] = ACTIONS(2362),
    [anon_sym_RBRACE] = ACTIONS(2362),
    [anon_sym_signed] = ACTIONS(2360),
    [anon_sym_unsigned] = ACTIONS(2360),
    [anon_sym_long] = ACTIONS(2360),
    [anon_sym_short] = ACTIONS(2360),
    [anon_sym_LBRACK] = ACTIONS(2360),
    [anon_sym_static] = ACTIONS(2360),
    [anon_sym_register] = ACTIONS(2360),
    [anon_sym_inline] = ACTIONS(2360),
    [anon_sym___inline] = ACTIONS(2360),
    [anon_sym___inline__] = ACTIONS(2360),
    [anon_sym___forceinline] = ACTIONS(2360),
    [anon_sym_thread_local] = ACTIONS(2360),
    [anon_sym___thread] = ACTIONS(2360),
    [anon_sym_const] = ACTIONS(2360),
    [anon_sym_constexpr] = ACTIONS(2360),
    [anon_sym_volatile] = ACTIONS(2360),
    [anon_sym_restrict] = ACTIONS(2360),
    [anon_sym___restrict__] = ACTIONS(2360),
    [anon_sym__Atomic] = ACTIONS(2360),
    [anon_sym__Noreturn] = ACTIONS(2360),
    [anon_sym_noreturn] = ACTIONS(2360),
    [anon_sym_mutable] = ACTIONS(2360),
    [anon_sym_constinit] = ACTIONS(2360),
    [anon_sym_consteval] = ACTIONS(2360),
    [anon_sym_alignas] = ACTIONS(2360),
    [anon_sym__Alignas] = ACTIONS(2360),
    [sym_primitive_type] = ACTIONS(2360),
    [anon_sym_enum] = ACTIONS(2360),
    [anon_sym_class] = ACTIONS(2360),
    [anon_sym_struct] = ACTIONS(2360),
    [anon_sym_union] = ACTIONS(2360),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_switch] = ACTIONS(2360),
    [anon_sym_case] = ACTIONS(2360),
    [anon_sym_default] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2360),
    [anon_sym_do] = ACTIONS(2360),
    [anon_sym_for] = ACTIONS(2360),
    [anon_sym_return] = ACTIONS(2360),
    [anon_sym_break] = ACTIONS(2360),
    [anon_sym_continue] = ACTIONS(2360),
    [anon_sym_goto] = ACTIONS(2360),
    [anon_sym___try] = ACTIONS(2360),
    [anon_sym___leave] = ACTIONS(2360),
    [anon_sym_not] = ACTIONS(2360),
    [anon_sym_compl] = ACTIONS(2360),
    [anon_sym_DASH_DASH] = ACTIONS(2362),
    [anon_sym_PLUS_PLUS] = ACTIONS(2362),
    [anon_sym_sizeof] = ACTIONS(2360),
    [anon_sym___alignof__] = ACTIONS(2360),
    [anon_sym___alignof] = ACTIONS(2360),
    [anon_sym__alignof] = ACTIONS(2360),
    [anon_sym_alignof] = ACTIONS(2360),
    [anon_sym__Alignof] = ACTIONS(2360),
    [anon_sym_offsetof] = ACTIONS(2360),
    [anon_sym__Generic] = ACTIONS(2360),
    [anon_sym_asm] = ACTIONS(2360),
    [anon_sym___asm__] = ACTIONS(2360),
    [sym_number_literal] = ACTIONS(2362),
    [anon_sym_L_SQUOTE] = ACTIONS(2362),
    [anon_sym_u_SQUOTE] = ACTIONS(2362),
    [anon_sym_U_SQUOTE] = ACTIONS(2362),
    [anon_sym_u8_SQUOTE] = ACTIONS(2362),
    [anon_sym_SQUOTE] = ACTIONS(2362),
    [anon_sym_L_DQUOTE] = ACTIONS(2362),
    [anon_sym_u_DQUOTE] = ACTIONS(2362),
    [anon_sym_U_DQUOTE] = ACTIONS(2362),
    [anon_sym_u8_DQUOTE] = ACTIONS(2362),
    [anon_sym_DQUOTE] = ACTIONS(2362),
    [sym_true] = ACTIONS(2360),
    [sym_false] = ACTIONS(2360),
    [anon_sym_NULL] = ACTIONS(2360),
    [anon_sym_nullptr] = ACTIONS(2360),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2360),
    [anon_sym_decltype] = ACTIONS(2360),
    [sym_virtual] = ACTIONS(2360),
    [anon_sym_explicit] = ACTIONS(2360),
    [anon_sym_typename] = ACTIONS(2360),
    [anon_sym_template] = ACTIONS(2360),
    [anon_sym_operator] = ACTIONS(2360),
    [anon_sym_try] = ACTIONS(2360),
    [anon_sym_delete] = ACTIONS(2360),
    [anon_sym_throw] = ACTIONS(2360),
    [anon_sym_namespace] = ACTIONS(2360),
    [anon_sym_using] = ACTIONS(2360),
    [anon_sym_static_assert] = ACTIONS(2360),
    [anon_sym_concept] = ACTIONS(2360),
    [anon_sym_co_return] = ACTIONS(2360),
    [anon_sym_co_yield] = ACTIONS(2360),
    [anon_sym_R_DQUOTE] = ACTIONS(2362),
    [anon_sym_LR_DQUOTE] = ACTIONS(2362),
    [anon_sym_uR_DQUOTE] = ACTIONS(2362),
    [anon_sym_UR_DQUOTE] = ACTIONS(2362),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2362),
    [anon_sym_co_await] = ACTIONS(2360),
    [anon_sym_new] = ACTIONS(2360),
    [anon_sym_requires] = ACTIONS(2360),
    [sym_this] = ACTIONS(2360),
    [anon_sym_discard] = ACTIONS(2360),
    [anon_sym_precise] = ACTIONS(2360),
    [anon_sym_shared] = ACTIONS(2360),
    [anon_sym_groupshared] = ACTIONS(2360),
    [anon_sym_uniform] = ACTIONS(2360),
    [anon_sym_row_major] = ACTIONS(2360),
    [anon_sym_column_major] = ACTIONS(2360),
    [anon_sym_globallycoherent] = ACTIONS(2360),
    [anon_sym_centroid] = ACTIONS(2360),
    [anon_sym_noperspective] = ACTIONS(2360),
    [anon_sym_nointerpolation] = ACTIONS(2360),
    [anon_sym_sample] = ACTIONS(2360),
    [anon_sym_linear] = ACTIONS(2360),
    [anon_sym_snorm] = ACTIONS(2360),
    [anon_sym_unorm] = ACTIONS(2360),
    [anon_sym_point] = ACTIONS(2360),
    [anon_sym_line] = ACTIONS(2360),
    [anon_sym_triangleadj] = ACTIONS(2360),
    [anon_sym_lineadj] = ACTIONS(2360),
    [anon_sym_triangle] = ACTIONS(2360),
    [anon_sym_cbuffer] = ACTIONS(2360),
  },
  [608] = {
    [sym_identifier] = ACTIONS(2400),
    [aux_sym_preproc_include_token1] = ACTIONS(2400),
    [aux_sym_preproc_def_token1] = ACTIONS(2400),
    [aux_sym_preproc_if_token1] = ACTIONS(2400),
    [aux_sym_preproc_if_token2] = ACTIONS(2400),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2400),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2400),
    [sym_preproc_directive] = ACTIONS(2400),
    [anon_sym_LPAREN2] = ACTIONS(2402),
    [anon_sym_BANG] = ACTIONS(2402),
    [anon_sym_TILDE] = ACTIONS(2402),
    [anon_sym_DASH] = ACTIONS(2400),
    [anon_sym_PLUS] = ACTIONS(2400),
    [anon_sym_STAR] = ACTIONS(2402),
    [anon_sym_AMP_AMP] = ACTIONS(2402),
    [anon_sym_AMP] = ACTIONS(2400),
    [anon_sym_SEMI] = ACTIONS(2402),
    [anon_sym___extension__] = ACTIONS(2400),
    [anon_sym_typedef] = ACTIONS(2400),
    [anon_sym_in] = ACTIONS(2400),
    [anon_sym_out] = ACTIONS(2400),
    [anon_sym_inout] = ACTIONS(2400),
    [anon_sym_extern] = ACTIONS(2400),
    [anon_sym___attribute__] = ACTIONS(2400),
    [anon_sym_COLON_COLON] = ACTIONS(2402),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2402),
    [anon_sym___declspec] = ACTIONS(2400),
    [anon_sym___based] = ACTIONS(2400),
    [anon_sym___cdecl] = ACTIONS(2400),
    [anon_sym___clrcall] = ACTIONS(2400),
    [anon_sym___stdcall] = ACTIONS(2400),
    [anon_sym___fastcall] = ACTIONS(2400),
    [anon_sym___thiscall] = ACTIONS(2400),
    [anon_sym___vectorcall] = ACTIONS(2400),
    [anon_sym_LBRACE] = ACTIONS(2402),
    [anon_sym_signed] = ACTIONS(2400),
    [anon_sym_unsigned] = ACTIONS(2400),
    [anon_sym_long] = ACTIONS(2400),
    [anon_sym_short] = ACTIONS(2400),
    [anon_sym_LBRACK] = ACTIONS(2400),
    [anon_sym_static] = ACTIONS(2400),
    [anon_sym_register] = ACTIONS(2400),
    [anon_sym_inline] = ACTIONS(2400),
    [anon_sym___inline] = ACTIONS(2400),
    [anon_sym___inline__] = ACTIONS(2400),
    [anon_sym___forceinline] = ACTIONS(2400),
    [anon_sym_thread_local] = ACTIONS(2400),
    [anon_sym___thread] = ACTIONS(2400),
    [anon_sym_const] = ACTIONS(2400),
    [anon_sym_constexpr] = ACTIONS(2400),
    [anon_sym_volatile] = ACTIONS(2400),
    [anon_sym_restrict] = ACTIONS(2400),
    [anon_sym___restrict__] = ACTIONS(2400),
    [anon_sym__Atomic] = ACTIONS(2400),
    [anon_sym__Noreturn] = ACTIONS(2400),
    [anon_sym_noreturn] = ACTIONS(2400),
    [anon_sym_mutable] = ACTIONS(2400),
    [anon_sym_constinit] = ACTIONS(2400),
    [anon_sym_consteval] = ACTIONS(2400),
    [anon_sym_alignas] = ACTIONS(2400),
    [anon_sym__Alignas] = ACTIONS(2400),
    [sym_primitive_type] = ACTIONS(2400),
    [anon_sym_enum] = ACTIONS(2400),
    [anon_sym_class] = ACTIONS(2400),
    [anon_sym_struct] = ACTIONS(2400),
    [anon_sym_union] = ACTIONS(2400),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_switch] = ACTIONS(2400),
    [anon_sym_case] = ACTIONS(2400),
    [anon_sym_default] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(2400),
    [anon_sym_do] = ACTIONS(2400),
    [anon_sym_for] = ACTIONS(2400),
    [anon_sym_return] = ACTIONS(2400),
    [anon_sym_break] = ACTIONS(2400),
    [anon_sym_continue] = ACTIONS(2400),
    [anon_sym_goto] = ACTIONS(2400),
    [anon_sym___try] = ACTIONS(2400),
    [anon_sym___leave] = ACTIONS(2400),
    [anon_sym_not] = ACTIONS(2400),
    [anon_sym_compl] = ACTIONS(2400),
    [anon_sym_DASH_DASH] = ACTIONS(2402),
    [anon_sym_PLUS_PLUS] = ACTIONS(2402),
    [anon_sym_sizeof] = ACTIONS(2400),
    [anon_sym___alignof__] = ACTIONS(2400),
    [anon_sym___alignof] = ACTIONS(2400),
    [anon_sym__alignof] = ACTIONS(2400),
    [anon_sym_alignof] = ACTIONS(2400),
    [anon_sym__Alignof] = ACTIONS(2400),
    [anon_sym_offsetof] = ACTIONS(2400),
    [anon_sym__Generic] = ACTIONS(2400),
    [anon_sym_asm] = ACTIONS(2400),
    [anon_sym___asm__] = ACTIONS(2400),
    [sym_number_literal] = ACTIONS(2402),
    [anon_sym_L_SQUOTE] = ACTIONS(2402),
    [anon_sym_u_SQUOTE] = ACTIONS(2402),
    [anon_sym_U_SQUOTE] = ACTIONS(2402),
    [anon_sym_u8_SQUOTE] = ACTIONS(2402),
    [anon_sym_SQUOTE] = ACTIONS(2402),
    [anon_sym_L_DQUOTE] = ACTIONS(2402),
    [anon_sym_u_DQUOTE] = ACTIONS(2402),
    [anon_sym_U_DQUOTE] = ACTIONS(2402),
    [anon_sym_u8_DQUOTE] = ACTIONS(2402),
    [anon_sym_DQUOTE] = ACTIONS(2402),
    [sym_true] = ACTIONS(2400),
    [sym_false] = ACTIONS(2400),
    [anon_sym_NULL] = ACTIONS(2400),
    [anon_sym_nullptr] = ACTIONS(2400),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2400),
    [anon_sym_decltype] = ACTIONS(2400),
    [sym_virtual] = ACTIONS(2400),
    [anon_sym_explicit] = ACTIONS(2400),
    [anon_sym_typename] = ACTIONS(2400),
    [anon_sym_template] = ACTIONS(2400),
    [anon_sym_operator] = ACTIONS(2400),
    [anon_sym_try] = ACTIONS(2400),
    [anon_sym_delete] = ACTIONS(2400),
    [anon_sym_throw] = ACTIONS(2400),
    [anon_sym_namespace] = ACTIONS(2400),
    [anon_sym_using] = ACTIONS(2400),
    [anon_sym_static_assert] = ACTIONS(2400),
    [anon_sym_concept] = ACTIONS(2400),
    [anon_sym_co_return] = ACTIONS(2400),
    [anon_sym_co_yield] = ACTIONS(2400),
    [anon_sym_R_DQUOTE] = ACTIONS(2402),
    [anon_sym_LR_DQUOTE] = ACTIONS(2402),
    [anon_sym_uR_DQUOTE] = ACTIONS(2402),
    [anon_sym_UR_DQUOTE] = ACTIONS(2402),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2402),
    [anon_sym_co_await] = ACTIONS(2400),
    [anon_sym_new] = ACTIONS(2400),
    [anon_sym_requires] = ACTIONS(2400),
    [sym_this] = ACTIONS(2400),
    [anon_sym_discard] = ACTIONS(2400),
    [anon_sym_precise] = ACTIONS(2400),
    [anon_sym_shared] = ACTIONS(2400),
    [anon_sym_groupshared] = ACTIONS(2400),
    [anon_sym_uniform] = ACTIONS(2400),
    [anon_sym_row_major] = ACTIONS(2400),
    [anon_sym_column_major] = ACTIONS(2400),
    [anon_sym_globallycoherent] = ACTIONS(2400),
    [anon_sym_centroid] = ACTIONS(2400),
    [anon_sym_noperspective] = ACTIONS(2400),
    [anon_sym_nointerpolation] = ACTIONS(2400),
    [anon_sym_sample] = ACTIONS(2400),
    [anon_sym_linear] = ACTIONS(2400),
    [anon_sym_snorm] = ACTIONS(2400),
    [anon_sym_unorm] = ACTIONS(2400),
    [anon_sym_point] = ACTIONS(2400),
    [anon_sym_line] = ACTIONS(2400),
    [anon_sym_triangleadj] = ACTIONS(2400),
    [anon_sym_lineadj] = ACTIONS(2400),
    [anon_sym_triangle] = ACTIONS(2400),
    [anon_sym_cbuffer] = ACTIONS(2400),
  },
  [609] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_include_token1] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_BANG] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_DASH] = ACTIONS(2332),
    [anon_sym_PLUS] = ACTIONS(2332),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym_SEMI] = ACTIONS(2334),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym___cdecl] = ACTIONS(2332),
    [anon_sym___clrcall] = ACTIONS(2332),
    [anon_sym___stdcall] = ACTIONS(2332),
    [anon_sym___fastcall] = ACTIONS(2332),
    [anon_sym___thiscall] = ACTIONS(2332),
    [anon_sym___vectorcall] = ACTIONS(2332),
    [anon_sym_LBRACE] = ACTIONS(2334),
    [anon_sym_RBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_switch] = ACTIONS(2332),
    [anon_sym_case] = ACTIONS(2332),
    [anon_sym_default] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2332),
    [anon_sym_do] = ACTIONS(2332),
    [anon_sym_for] = ACTIONS(2332),
    [anon_sym_return] = ACTIONS(2332),
    [anon_sym_break] = ACTIONS(2332),
    [anon_sym_continue] = ACTIONS(2332),
    [anon_sym_goto] = ACTIONS(2332),
    [anon_sym___try] = ACTIONS(2332),
    [anon_sym___leave] = ACTIONS(2332),
    [anon_sym_not] = ACTIONS(2332),
    [anon_sym_compl] = ACTIONS(2332),
    [anon_sym_DASH_DASH] = ACTIONS(2334),
    [anon_sym_PLUS_PLUS] = ACTIONS(2334),
    [anon_sym_sizeof] = ACTIONS(2332),
    [anon_sym___alignof__] = ACTIONS(2332),
    [anon_sym___alignof] = ACTIONS(2332),
    [anon_sym__alignof] = ACTIONS(2332),
    [anon_sym_alignof] = ACTIONS(2332),
    [anon_sym__Alignof] = ACTIONS(2332),
    [anon_sym_offsetof] = ACTIONS(2332),
    [anon_sym__Generic] = ACTIONS(2332),
    [anon_sym_asm] = ACTIONS(2332),
    [anon_sym___asm__] = ACTIONS(2332),
    [sym_number_literal] = ACTIONS(2334),
    [anon_sym_L_SQUOTE] = ACTIONS(2334),
    [anon_sym_u_SQUOTE] = ACTIONS(2334),
    [anon_sym_U_SQUOTE] = ACTIONS(2334),
    [anon_sym_u8_SQUOTE] = ACTIONS(2334),
    [anon_sym_SQUOTE] = ACTIONS(2334),
    [anon_sym_L_DQUOTE] = ACTIONS(2334),
    [anon_sym_u_DQUOTE] = ACTIONS(2334),
    [anon_sym_U_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8_DQUOTE] = ACTIONS(2334),
    [anon_sym_DQUOTE] = ACTIONS(2334),
    [sym_true] = ACTIONS(2332),
    [sym_false] = ACTIONS(2332),
    [anon_sym_NULL] = ACTIONS(2332),
    [anon_sym_nullptr] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_try] = ACTIONS(2332),
    [anon_sym_delete] = ACTIONS(2332),
    [anon_sym_throw] = ACTIONS(2332),
    [anon_sym_namespace] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_concept] = ACTIONS(2332),
    [anon_sym_co_return] = ACTIONS(2332),
    [anon_sym_co_yield] = ACTIONS(2332),
    [anon_sym_R_DQUOTE] = ACTIONS(2334),
    [anon_sym_LR_DQUOTE] = ACTIONS(2334),
    [anon_sym_uR_DQUOTE] = ACTIONS(2334),
    [anon_sym_UR_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2334),
    [anon_sym_co_await] = ACTIONS(2332),
    [anon_sym_new] = ACTIONS(2332),
    [anon_sym_requires] = ACTIONS(2332),
    [sym_this] = ACTIONS(2332),
    [anon_sym_discard] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
    [anon_sym_cbuffer] = ACTIONS(2332),
  },
  [610] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_include_token1] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_BANG] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_DASH] = ACTIONS(2332),
    [anon_sym_PLUS] = ACTIONS(2332),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym_SEMI] = ACTIONS(2334),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym___cdecl] = ACTIONS(2332),
    [anon_sym___clrcall] = ACTIONS(2332),
    [anon_sym___stdcall] = ACTIONS(2332),
    [anon_sym___fastcall] = ACTIONS(2332),
    [anon_sym___thiscall] = ACTIONS(2332),
    [anon_sym___vectorcall] = ACTIONS(2332),
    [anon_sym_LBRACE] = ACTIONS(2334),
    [anon_sym_RBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_switch] = ACTIONS(2332),
    [anon_sym_case] = ACTIONS(2332),
    [anon_sym_default] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2332),
    [anon_sym_do] = ACTIONS(2332),
    [anon_sym_for] = ACTIONS(2332),
    [anon_sym_return] = ACTIONS(2332),
    [anon_sym_break] = ACTIONS(2332),
    [anon_sym_continue] = ACTIONS(2332),
    [anon_sym_goto] = ACTIONS(2332),
    [anon_sym___try] = ACTIONS(2332),
    [anon_sym___leave] = ACTIONS(2332),
    [anon_sym_not] = ACTIONS(2332),
    [anon_sym_compl] = ACTIONS(2332),
    [anon_sym_DASH_DASH] = ACTIONS(2334),
    [anon_sym_PLUS_PLUS] = ACTIONS(2334),
    [anon_sym_sizeof] = ACTIONS(2332),
    [anon_sym___alignof__] = ACTIONS(2332),
    [anon_sym___alignof] = ACTIONS(2332),
    [anon_sym__alignof] = ACTIONS(2332),
    [anon_sym_alignof] = ACTIONS(2332),
    [anon_sym__Alignof] = ACTIONS(2332),
    [anon_sym_offsetof] = ACTIONS(2332),
    [anon_sym__Generic] = ACTIONS(2332),
    [anon_sym_asm] = ACTIONS(2332),
    [anon_sym___asm__] = ACTIONS(2332),
    [sym_number_literal] = ACTIONS(2334),
    [anon_sym_L_SQUOTE] = ACTIONS(2334),
    [anon_sym_u_SQUOTE] = ACTIONS(2334),
    [anon_sym_U_SQUOTE] = ACTIONS(2334),
    [anon_sym_u8_SQUOTE] = ACTIONS(2334),
    [anon_sym_SQUOTE] = ACTIONS(2334),
    [anon_sym_L_DQUOTE] = ACTIONS(2334),
    [anon_sym_u_DQUOTE] = ACTIONS(2334),
    [anon_sym_U_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8_DQUOTE] = ACTIONS(2334),
    [anon_sym_DQUOTE] = ACTIONS(2334),
    [sym_true] = ACTIONS(2332),
    [sym_false] = ACTIONS(2332),
    [anon_sym_NULL] = ACTIONS(2332),
    [anon_sym_nullptr] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_try] = ACTIONS(2332),
    [anon_sym_delete] = ACTIONS(2332),
    [anon_sym_throw] = ACTIONS(2332),
    [anon_sym_namespace] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_concept] = ACTIONS(2332),
    [anon_sym_co_return] = ACTIONS(2332),
    [anon_sym_co_yield] = ACTIONS(2332),
    [anon_sym_R_DQUOTE] = ACTIONS(2334),
    [anon_sym_LR_DQUOTE] = ACTIONS(2334),
    [anon_sym_uR_DQUOTE] = ACTIONS(2334),
    [anon_sym_UR_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2334),
    [anon_sym_co_await] = ACTIONS(2332),
    [anon_sym_new] = ACTIONS(2332),
    [anon_sym_requires] = ACTIONS(2332),
    [sym_this] = ACTIONS(2332),
    [anon_sym_discard] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
    [anon_sym_cbuffer] = ACTIONS(2332),
  },
  [611] = {
    [sym_identifier] = ACTIONS(2360),
    [aux_sym_preproc_include_token1] = ACTIONS(2360),
    [aux_sym_preproc_def_token1] = ACTIONS(2360),
    [aux_sym_preproc_if_token1] = ACTIONS(2360),
    [aux_sym_preproc_if_token2] = ACTIONS(2360),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2360),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2360),
    [sym_preproc_directive] = ACTIONS(2360),
    [anon_sym_LPAREN2] = ACTIONS(2362),
    [anon_sym_BANG] = ACTIONS(2362),
    [anon_sym_TILDE] = ACTIONS(2362),
    [anon_sym_DASH] = ACTIONS(2360),
    [anon_sym_PLUS] = ACTIONS(2360),
    [anon_sym_STAR] = ACTIONS(2362),
    [anon_sym_AMP_AMP] = ACTIONS(2362),
    [anon_sym_AMP] = ACTIONS(2360),
    [anon_sym_SEMI] = ACTIONS(2362),
    [anon_sym___extension__] = ACTIONS(2360),
    [anon_sym_typedef] = ACTIONS(2360),
    [anon_sym_in] = ACTIONS(2360),
    [anon_sym_out] = ACTIONS(2360),
    [anon_sym_inout] = ACTIONS(2360),
    [anon_sym_extern] = ACTIONS(2360),
    [anon_sym___attribute__] = ACTIONS(2360),
    [anon_sym_COLON_COLON] = ACTIONS(2362),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2362),
    [anon_sym___declspec] = ACTIONS(2360),
    [anon_sym___based] = ACTIONS(2360),
    [anon_sym___cdecl] = ACTIONS(2360),
    [anon_sym___clrcall] = ACTIONS(2360),
    [anon_sym___stdcall] = ACTIONS(2360),
    [anon_sym___fastcall] = ACTIONS(2360),
    [anon_sym___thiscall] = ACTIONS(2360),
    [anon_sym___vectorcall] = ACTIONS(2360),
    [anon_sym_LBRACE] = ACTIONS(2362),
    [anon_sym_signed] = ACTIONS(2360),
    [anon_sym_unsigned] = ACTIONS(2360),
    [anon_sym_long] = ACTIONS(2360),
    [anon_sym_short] = ACTIONS(2360),
    [anon_sym_LBRACK] = ACTIONS(2360),
    [anon_sym_static] = ACTIONS(2360),
    [anon_sym_register] = ACTIONS(2360),
    [anon_sym_inline] = ACTIONS(2360),
    [anon_sym___inline] = ACTIONS(2360),
    [anon_sym___inline__] = ACTIONS(2360),
    [anon_sym___forceinline] = ACTIONS(2360),
    [anon_sym_thread_local] = ACTIONS(2360),
    [anon_sym___thread] = ACTIONS(2360),
    [anon_sym_const] = ACTIONS(2360),
    [anon_sym_constexpr] = ACTIONS(2360),
    [anon_sym_volatile] = ACTIONS(2360),
    [anon_sym_restrict] = ACTIONS(2360),
    [anon_sym___restrict__] = ACTIONS(2360),
    [anon_sym__Atomic] = ACTIONS(2360),
    [anon_sym__Noreturn] = ACTIONS(2360),
    [anon_sym_noreturn] = ACTIONS(2360),
    [anon_sym_mutable] = ACTIONS(2360),
    [anon_sym_constinit] = ACTIONS(2360),
    [anon_sym_consteval] = ACTIONS(2360),
    [anon_sym_alignas] = ACTIONS(2360),
    [anon_sym__Alignas] = ACTIONS(2360),
    [sym_primitive_type] = ACTIONS(2360),
    [anon_sym_enum] = ACTIONS(2360),
    [anon_sym_class] = ACTIONS(2360),
    [anon_sym_struct] = ACTIONS(2360),
    [anon_sym_union] = ACTIONS(2360),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_switch] = ACTIONS(2360),
    [anon_sym_case] = ACTIONS(2360),
    [anon_sym_default] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2360),
    [anon_sym_do] = ACTIONS(2360),
    [anon_sym_for] = ACTIONS(2360),
    [anon_sym_return] = ACTIONS(2360),
    [anon_sym_break] = ACTIONS(2360),
    [anon_sym_continue] = ACTIONS(2360),
    [anon_sym_goto] = ACTIONS(2360),
    [anon_sym___try] = ACTIONS(2360),
    [anon_sym___leave] = ACTIONS(2360),
    [anon_sym_not] = ACTIONS(2360),
    [anon_sym_compl] = ACTIONS(2360),
    [anon_sym_DASH_DASH] = ACTIONS(2362),
    [anon_sym_PLUS_PLUS] = ACTIONS(2362),
    [anon_sym_sizeof] = ACTIONS(2360),
    [anon_sym___alignof__] = ACTIONS(2360),
    [anon_sym___alignof] = ACTIONS(2360),
    [anon_sym__alignof] = ACTIONS(2360),
    [anon_sym_alignof] = ACTIONS(2360),
    [anon_sym__Alignof] = ACTIONS(2360),
    [anon_sym_offsetof] = ACTIONS(2360),
    [anon_sym__Generic] = ACTIONS(2360),
    [anon_sym_asm] = ACTIONS(2360),
    [anon_sym___asm__] = ACTIONS(2360),
    [sym_number_literal] = ACTIONS(2362),
    [anon_sym_L_SQUOTE] = ACTIONS(2362),
    [anon_sym_u_SQUOTE] = ACTIONS(2362),
    [anon_sym_U_SQUOTE] = ACTIONS(2362),
    [anon_sym_u8_SQUOTE] = ACTIONS(2362),
    [anon_sym_SQUOTE] = ACTIONS(2362),
    [anon_sym_L_DQUOTE] = ACTIONS(2362),
    [anon_sym_u_DQUOTE] = ACTIONS(2362),
    [anon_sym_U_DQUOTE] = ACTIONS(2362),
    [anon_sym_u8_DQUOTE] = ACTIONS(2362),
    [anon_sym_DQUOTE] = ACTIONS(2362),
    [sym_true] = ACTIONS(2360),
    [sym_false] = ACTIONS(2360),
    [anon_sym_NULL] = ACTIONS(2360),
    [anon_sym_nullptr] = ACTIONS(2360),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2360),
    [anon_sym_decltype] = ACTIONS(2360),
    [sym_virtual] = ACTIONS(2360),
    [anon_sym_explicit] = ACTIONS(2360),
    [anon_sym_typename] = ACTIONS(2360),
    [anon_sym_template] = ACTIONS(2360),
    [anon_sym_operator] = ACTIONS(2360),
    [anon_sym_try] = ACTIONS(2360),
    [anon_sym_delete] = ACTIONS(2360),
    [anon_sym_throw] = ACTIONS(2360),
    [anon_sym_namespace] = ACTIONS(2360),
    [anon_sym_using] = ACTIONS(2360),
    [anon_sym_static_assert] = ACTIONS(2360),
    [anon_sym_concept] = ACTIONS(2360),
    [anon_sym_co_return] = ACTIONS(2360),
    [anon_sym_co_yield] = ACTIONS(2360),
    [anon_sym_R_DQUOTE] = ACTIONS(2362),
    [anon_sym_LR_DQUOTE] = ACTIONS(2362),
    [anon_sym_uR_DQUOTE] = ACTIONS(2362),
    [anon_sym_UR_DQUOTE] = ACTIONS(2362),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2362),
    [anon_sym_co_await] = ACTIONS(2360),
    [anon_sym_new] = ACTIONS(2360),
    [anon_sym_requires] = ACTIONS(2360),
    [sym_this] = ACTIONS(2360),
    [anon_sym_discard] = ACTIONS(2360),
    [anon_sym_precise] = ACTIONS(2360),
    [anon_sym_shared] = ACTIONS(2360),
    [anon_sym_groupshared] = ACTIONS(2360),
    [anon_sym_uniform] = ACTIONS(2360),
    [anon_sym_row_major] = ACTIONS(2360),
    [anon_sym_column_major] = ACTIONS(2360),
    [anon_sym_globallycoherent] = ACTIONS(2360),
    [anon_sym_centroid] = ACTIONS(2360),
    [anon_sym_noperspective] = ACTIONS(2360),
    [anon_sym_nointerpolation] = ACTIONS(2360),
    [anon_sym_sample] = ACTIONS(2360),
    [anon_sym_linear] = ACTIONS(2360),
    [anon_sym_snorm] = ACTIONS(2360),
    [anon_sym_unorm] = ACTIONS(2360),
    [anon_sym_point] = ACTIONS(2360),
    [anon_sym_line] = ACTIONS(2360),
    [anon_sym_triangleadj] = ACTIONS(2360),
    [anon_sym_lineadj] = ACTIONS(2360),
    [anon_sym_triangle] = ACTIONS(2360),
    [anon_sym_cbuffer] = ACTIONS(2360),
  },
  [612] = {
    [sym_identifier] = ACTIONS(2389),
    [aux_sym_preproc_include_token1] = ACTIONS(2389),
    [aux_sym_preproc_def_token1] = ACTIONS(2389),
    [aux_sym_preproc_if_token1] = ACTIONS(2389),
    [aux_sym_preproc_if_token2] = ACTIONS(2389),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2389),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2389),
    [sym_preproc_directive] = ACTIONS(2389),
    [anon_sym_LPAREN2] = ACTIONS(2391),
    [anon_sym_BANG] = ACTIONS(2391),
    [anon_sym_TILDE] = ACTIONS(2391),
    [anon_sym_DASH] = ACTIONS(2389),
    [anon_sym_PLUS] = ACTIONS(2389),
    [anon_sym_STAR] = ACTIONS(2391),
    [anon_sym_AMP_AMP] = ACTIONS(2391),
    [anon_sym_AMP] = ACTIONS(2389),
    [anon_sym_SEMI] = ACTIONS(2391),
    [anon_sym___extension__] = ACTIONS(2389),
    [anon_sym_typedef] = ACTIONS(2389),
    [anon_sym_in] = ACTIONS(2389),
    [anon_sym_out] = ACTIONS(2389),
    [anon_sym_inout] = ACTIONS(2389),
    [anon_sym_extern] = ACTIONS(2389),
    [anon_sym___attribute__] = ACTIONS(2389),
    [anon_sym_COLON_COLON] = ACTIONS(2391),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2391),
    [anon_sym___declspec] = ACTIONS(2389),
    [anon_sym___based] = ACTIONS(2389),
    [anon_sym___cdecl] = ACTIONS(2389),
    [anon_sym___clrcall] = ACTIONS(2389),
    [anon_sym___stdcall] = ACTIONS(2389),
    [anon_sym___fastcall] = ACTIONS(2389),
    [anon_sym___thiscall] = ACTIONS(2389),
    [anon_sym___vectorcall] = ACTIONS(2389),
    [anon_sym_LBRACE] = ACTIONS(2391),
    [anon_sym_signed] = ACTIONS(2389),
    [anon_sym_unsigned] = ACTIONS(2389),
    [anon_sym_long] = ACTIONS(2389),
    [anon_sym_short] = ACTIONS(2389),
    [anon_sym_LBRACK] = ACTIONS(2389),
    [anon_sym_static] = ACTIONS(2389),
    [anon_sym_register] = ACTIONS(2389),
    [anon_sym_inline] = ACTIONS(2389),
    [anon_sym___inline] = ACTIONS(2389),
    [anon_sym___inline__] = ACTIONS(2389),
    [anon_sym___forceinline] = ACTIONS(2389),
    [anon_sym_thread_local] = ACTIONS(2389),
    [anon_sym___thread] = ACTIONS(2389),
    [anon_sym_const] = ACTIONS(2389),
    [anon_sym_constexpr] = ACTIONS(2389),
    [anon_sym_volatile] = ACTIONS(2389),
    [anon_sym_restrict] = ACTIONS(2389),
    [anon_sym___restrict__] = ACTIONS(2389),
    [anon_sym__Atomic] = ACTIONS(2389),
    [anon_sym__Noreturn] = ACTIONS(2389),
    [anon_sym_noreturn] = ACTIONS(2389),
    [anon_sym_mutable] = ACTIONS(2389),
    [anon_sym_constinit] = ACTIONS(2389),
    [anon_sym_consteval] = ACTIONS(2389),
    [anon_sym_alignas] = ACTIONS(2389),
    [anon_sym__Alignas] = ACTIONS(2389),
    [sym_primitive_type] = ACTIONS(2389),
    [anon_sym_enum] = ACTIONS(2389),
    [anon_sym_class] = ACTIONS(2389),
    [anon_sym_struct] = ACTIONS(2389),
    [anon_sym_union] = ACTIONS(2389),
    [anon_sym_if] = ACTIONS(2389),
    [anon_sym_switch] = ACTIONS(2389),
    [anon_sym_case] = ACTIONS(2389),
    [anon_sym_default] = ACTIONS(2389),
    [anon_sym_while] = ACTIONS(2389),
    [anon_sym_do] = ACTIONS(2389),
    [anon_sym_for] = ACTIONS(2389),
    [anon_sym_return] = ACTIONS(2389),
    [anon_sym_break] = ACTIONS(2389),
    [anon_sym_continue] = ACTIONS(2389),
    [anon_sym_goto] = ACTIONS(2389),
    [anon_sym___try] = ACTIONS(2389),
    [anon_sym___leave] = ACTIONS(2389),
    [anon_sym_not] = ACTIONS(2389),
    [anon_sym_compl] = ACTIONS(2389),
    [anon_sym_DASH_DASH] = ACTIONS(2391),
    [anon_sym_PLUS_PLUS] = ACTIONS(2391),
    [anon_sym_sizeof] = ACTIONS(2389),
    [anon_sym___alignof__] = ACTIONS(2389),
    [anon_sym___alignof] = ACTIONS(2389),
    [anon_sym__alignof] = ACTIONS(2389),
    [anon_sym_alignof] = ACTIONS(2389),
    [anon_sym__Alignof] = ACTIONS(2389),
    [anon_sym_offsetof] = ACTIONS(2389),
    [anon_sym__Generic] = ACTIONS(2389),
    [anon_sym_asm] = ACTIONS(2389),
    [anon_sym___asm__] = ACTIONS(2389),
    [sym_number_literal] = ACTIONS(2391),
    [anon_sym_L_SQUOTE] = ACTIONS(2391),
    [anon_sym_u_SQUOTE] = ACTIONS(2391),
    [anon_sym_U_SQUOTE] = ACTIONS(2391),
    [anon_sym_u8_SQUOTE] = ACTIONS(2391),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_L_DQUOTE] = ACTIONS(2391),
    [anon_sym_u_DQUOTE] = ACTIONS(2391),
    [anon_sym_U_DQUOTE] = ACTIONS(2391),
    [anon_sym_u8_DQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2391),
    [sym_true] = ACTIONS(2389),
    [sym_false] = ACTIONS(2389),
    [anon_sym_NULL] = ACTIONS(2389),
    [anon_sym_nullptr] = ACTIONS(2389),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2389),
    [anon_sym_decltype] = ACTIONS(2389),
    [sym_virtual] = ACTIONS(2389),
    [anon_sym_explicit] = ACTIONS(2389),
    [anon_sym_typename] = ACTIONS(2389),
    [anon_sym_template] = ACTIONS(2389),
    [anon_sym_operator] = ACTIONS(2389),
    [anon_sym_try] = ACTIONS(2389),
    [anon_sym_delete] = ACTIONS(2389),
    [anon_sym_throw] = ACTIONS(2389),
    [anon_sym_namespace] = ACTIONS(2389),
    [anon_sym_using] = ACTIONS(2389),
    [anon_sym_static_assert] = ACTIONS(2389),
    [anon_sym_concept] = ACTIONS(2389),
    [anon_sym_co_return] = ACTIONS(2389),
    [anon_sym_co_yield] = ACTIONS(2389),
    [anon_sym_R_DQUOTE] = ACTIONS(2391),
    [anon_sym_LR_DQUOTE] = ACTIONS(2391),
    [anon_sym_uR_DQUOTE] = ACTIONS(2391),
    [anon_sym_UR_DQUOTE] = ACTIONS(2391),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2391),
    [anon_sym_co_await] = ACTIONS(2389),
    [anon_sym_new] = ACTIONS(2389),
    [anon_sym_requires] = ACTIONS(2389),
    [sym_this] = ACTIONS(2389),
    [anon_sym_discard] = ACTIONS(2389),
    [anon_sym_precise] = ACTIONS(2389),
    [anon_sym_shared] = ACTIONS(2389),
    [anon_sym_groupshared] = ACTIONS(2389),
    [anon_sym_uniform] = ACTIONS(2389),
    [anon_sym_row_major] = ACTIONS(2389),
    [anon_sym_column_major] = ACTIONS(2389),
    [anon_sym_globallycoherent] = ACTIONS(2389),
    [anon_sym_centroid] = ACTIONS(2389),
    [anon_sym_noperspective] = ACTIONS(2389),
    [anon_sym_nointerpolation] = ACTIONS(2389),
    [anon_sym_sample] = ACTIONS(2389),
    [anon_sym_linear] = ACTIONS(2389),
    [anon_sym_snorm] = ACTIONS(2389),
    [anon_sym_unorm] = ACTIONS(2389),
    [anon_sym_point] = ACTIONS(2389),
    [anon_sym_line] = ACTIONS(2389),
    [anon_sym_triangleadj] = ACTIONS(2389),
    [anon_sym_lineadj] = ACTIONS(2389),
    [anon_sym_triangle] = ACTIONS(2389),
    [anon_sym_cbuffer] = ACTIONS(2389),
  },
  [613] = {
    [sym_identifier] = ACTIONS(2516),
    [aux_sym_preproc_include_token1] = ACTIONS(2516),
    [aux_sym_preproc_def_token1] = ACTIONS(2516),
    [aux_sym_preproc_if_token1] = ACTIONS(2516),
    [aux_sym_preproc_if_token2] = ACTIONS(2516),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2516),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2516),
    [sym_preproc_directive] = ACTIONS(2516),
    [anon_sym_LPAREN2] = ACTIONS(2518),
    [anon_sym_BANG] = ACTIONS(2518),
    [anon_sym_TILDE] = ACTIONS(2518),
    [anon_sym_DASH] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(2516),
    [anon_sym_STAR] = ACTIONS(2518),
    [anon_sym_AMP_AMP] = ACTIONS(2518),
    [anon_sym_AMP] = ACTIONS(2516),
    [anon_sym_SEMI] = ACTIONS(2518),
    [anon_sym___extension__] = ACTIONS(2516),
    [anon_sym_typedef] = ACTIONS(2516),
    [anon_sym_in] = ACTIONS(2516),
    [anon_sym_out] = ACTIONS(2516),
    [anon_sym_inout] = ACTIONS(2516),
    [anon_sym_extern] = ACTIONS(2516),
    [anon_sym___attribute__] = ACTIONS(2516),
    [anon_sym_COLON_COLON] = ACTIONS(2518),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2518),
    [anon_sym___declspec] = ACTIONS(2516),
    [anon_sym___based] = ACTIONS(2516),
    [anon_sym___cdecl] = ACTIONS(2516),
    [anon_sym___clrcall] = ACTIONS(2516),
    [anon_sym___stdcall] = ACTIONS(2516),
    [anon_sym___fastcall] = ACTIONS(2516),
    [anon_sym___thiscall] = ACTIONS(2516),
    [anon_sym___vectorcall] = ACTIONS(2516),
    [anon_sym_LBRACE] = ACTIONS(2518),
    [anon_sym_signed] = ACTIONS(2516),
    [anon_sym_unsigned] = ACTIONS(2516),
    [anon_sym_long] = ACTIONS(2516),
    [anon_sym_short] = ACTIONS(2516),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_static] = ACTIONS(2516),
    [anon_sym_register] = ACTIONS(2516),
    [anon_sym_inline] = ACTIONS(2516),
    [anon_sym___inline] = ACTIONS(2516),
    [anon_sym___inline__] = ACTIONS(2516),
    [anon_sym___forceinline] = ACTIONS(2516),
    [anon_sym_thread_local] = ACTIONS(2516),
    [anon_sym___thread] = ACTIONS(2516),
    [anon_sym_const] = ACTIONS(2516),
    [anon_sym_constexpr] = ACTIONS(2516),
    [anon_sym_volatile] = ACTIONS(2516),
    [anon_sym_restrict] = ACTIONS(2516),
    [anon_sym___restrict__] = ACTIONS(2516),
    [anon_sym__Atomic] = ACTIONS(2516),
    [anon_sym__Noreturn] = ACTIONS(2516),
    [anon_sym_noreturn] = ACTIONS(2516),
    [anon_sym_mutable] = ACTIONS(2516),
    [anon_sym_constinit] = ACTIONS(2516),
    [anon_sym_consteval] = ACTIONS(2516),
    [anon_sym_alignas] = ACTIONS(2516),
    [anon_sym__Alignas] = ACTIONS(2516),
    [sym_primitive_type] = ACTIONS(2516),
    [anon_sym_enum] = ACTIONS(2516),
    [anon_sym_class] = ACTIONS(2516),
    [anon_sym_struct] = ACTIONS(2516),
    [anon_sym_union] = ACTIONS(2516),
    [anon_sym_if] = ACTIONS(2516),
    [anon_sym_switch] = ACTIONS(2516),
    [anon_sym_case] = ACTIONS(2516),
    [anon_sym_default] = ACTIONS(2516),
    [anon_sym_while] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(2516),
    [anon_sym_for] = ACTIONS(2516),
    [anon_sym_return] = ACTIONS(2516),
    [anon_sym_break] = ACTIONS(2516),
    [anon_sym_continue] = ACTIONS(2516),
    [anon_sym_goto] = ACTIONS(2516),
    [anon_sym___try] = ACTIONS(2516),
    [anon_sym___leave] = ACTIONS(2516),
    [anon_sym_not] = ACTIONS(2516),
    [anon_sym_compl] = ACTIONS(2516),
    [anon_sym_DASH_DASH] = ACTIONS(2518),
    [anon_sym_PLUS_PLUS] = ACTIONS(2518),
    [anon_sym_sizeof] = ACTIONS(2516),
    [anon_sym___alignof__] = ACTIONS(2516),
    [anon_sym___alignof] = ACTIONS(2516),
    [anon_sym__alignof] = ACTIONS(2516),
    [anon_sym_alignof] = ACTIONS(2516),
    [anon_sym__Alignof] = ACTIONS(2516),
    [anon_sym_offsetof] = ACTIONS(2516),
    [anon_sym__Generic] = ACTIONS(2516),
    [anon_sym_asm] = ACTIONS(2516),
    [anon_sym___asm__] = ACTIONS(2516),
    [sym_number_literal] = ACTIONS(2518),
    [anon_sym_L_SQUOTE] = ACTIONS(2518),
    [anon_sym_u_SQUOTE] = ACTIONS(2518),
    [anon_sym_U_SQUOTE] = ACTIONS(2518),
    [anon_sym_u8_SQUOTE] = ACTIONS(2518),
    [anon_sym_SQUOTE] = ACTIONS(2518),
    [anon_sym_L_DQUOTE] = ACTIONS(2518),
    [anon_sym_u_DQUOTE] = ACTIONS(2518),
    [anon_sym_U_DQUOTE] = ACTIONS(2518),
    [anon_sym_u8_DQUOTE] = ACTIONS(2518),
    [anon_sym_DQUOTE] = ACTIONS(2518),
    [sym_true] = ACTIONS(2516),
    [sym_false] = ACTIONS(2516),
    [anon_sym_NULL] = ACTIONS(2516),
    [anon_sym_nullptr] = ACTIONS(2516),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2516),
    [anon_sym_decltype] = ACTIONS(2516),
    [sym_virtual] = ACTIONS(2516),
    [anon_sym_explicit] = ACTIONS(2516),
    [anon_sym_typename] = ACTIONS(2516),
    [anon_sym_template] = ACTIONS(2516),
    [anon_sym_operator] = ACTIONS(2516),
    [anon_sym_try] = ACTIONS(2516),
    [anon_sym_delete] = ACTIONS(2516),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_namespace] = ACTIONS(2516),
    [anon_sym_using] = ACTIONS(2516),
    [anon_sym_static_assert] = ACTIONS(2516),
    [anon_sym_concept] = ACTIONS(2516),
    [anon_sym_co_return] = ACTIONS(2516),
    [anon_sym_co_yield] = ACTIONS(2516),
    [anon_sym_R_DQUOTE] = ACTIONS(2518),
    [anon_sym_LR_DQUOTE] = ACTIONS(2518),
    [anon_sym_uR_DQUOTE] = ACTIONS(2518),
    [anon_sym_UR_DQUOTE] = ACTIONS(2518),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2518),
    [anon_sym_co_await] = ACTIONS(2516),
    [anon_sym_new] = ACTIONS(2516),
    [anon_sym_requires] = ACTIONS(2516),
    [sym_this] = ACTIONS(2516),
    [anon_sym_discard] = ACTIONS(2516),
    [anon_sym_precise] = ACTIONS(2516),
    [anon_sym_shared] = ACTIONS(2516),
    [anon_sym_groupshared] = ACTIONS(2516),
    [anon_sym_uniform] = ACTIONS(2516),
    [anon_sym_row_major] = ACTIONS(2516),
    [anon_sym_column_major] = ACTIONS(2516),
    [anon_sym_globallycoherent] = ACTIONS(2516),
    [anon_sym_centroid] = ACTIONS(2516),
    [anon_sym_noperspective] = ACTIONS(2516),
    [anon_sym_nointerpolation] = ACTIONS(2516),
    [anon_sym_sample] = ACTIONS(2516),
    [anon_sym_linear] = ACTIONS(2516),
    [anon_sym_snorm] = ACTIONS(2516),
    [anon_sym_unorm] = ACTIONS(2516),
    [anon_sym_point] = ACTIONS(2516),
    [anon_sym_line] = ACTIONS(2516),
    [anon_sym_triangleadj] = ACTIONS(2516),
    [anon_sym_lineadj] = ACTIONS(2516),
    [anon_sym_triangle] = ACTIONS(2516),
    [anon_sym_cbuffer] = ACTIONS(2516),
  },
  [614] = {
    [sym_identifier] = ACTIONS(2510),
    [aux_sym_preproc_include_token1] = ACTIONS(2510),
    [aux_sym_preproc_def_token1] = ACTIONS(2510),
    [aux_sym_preproc_if_token1] = ACTIONS(2510),
    [aux_sym_preproc_if_token2] = ACTIONS(2510),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2510),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2510),
    [sym_preproc_directive] = ACTIONS(2510),
    [anon_sym_LPAREN2] = ACTIONS(2512),
    [anon_sym_BANG] = ACTIONS(2512),
    [anon_sym_TILDE] = ACTIONS(2512),
    [anon_sym_DASH] = ACTIONS(2510),
    [anon_sym_PLUS] = ACTIONS(2510),
    [anon_sym_STAR] = ACTIONS(2512),
    [anon_sym_AMP_AMP] = ACTIONS(2512),
    [anon_sym_AMP] = ACTIONS(2510),
    [anon_sym_SEMI] = ACTIONS(2512),
    [anon_sym___extension__] = ACTIONS(2510),
    [anon_sym_typedef] = ACTIONS(2510),
    [anon_sym_in] = ACTIONS(2510),
    [anon_sym_out] = ACTIONS(2510),
    [anon_sym_inout] = ACTIONS(2510),
    [anon_sym_extern] = ACTIONS(2510),
    [anon_sym___attribute__] = ACTIONS(2510),
    [anon_sym_COLON_COLON] = ACTIONS(2512),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2512),
    [anon_sym___declspec] = ACTIONS(2510),
    [anon_sym___based] = ACTIONS(2510),
    [anon_sym___cdecl] = ACTIONS(2510),
    [anon_sym___clrcall] = ACTIONS(2510),
    [anon_sym___stdcall] = ACTIONS(2510),
    [anon_sym___fastcall] = ACTIONS(2510),
    [anon_sym___thiscall] = ACTIONS(2510),
    [anon_sym___vectorcall] = ACTIONS(2510),
    [anon_sym_LBRACE] = ACTIONS(2512),
    [anon_sym_signed] = ACTIONS(2510),
    [anon_sym_unsigned] = ACTIONS(2510),
    [anon_sym_long] = ACTIONS(2510),
    [anon_sym_short] = ACTIONS(2510),
    [anon_sym_LBRACK] = ACTIONS(2510),
    [anon_sym_static] = ACTIONS(2510),
    [anon_sym_register] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(2510),
    [anon_sym___inline] = ACTIONS(2510),
    [anon_sym___inline__] = ACTIONS(2510),
    [anon_sym___forceinline] = ACTIONS(2510),
    [anon_sym_thread_local] = ACTIONS(2510),
    [anon_sym___thread] = ACTIONS(2510),
    [anon_sym_const] = ACTIONS(2510),
    [anon_sym_constexpr] = ACTIONS(2510),
    [anon_sym_volatile] = ACTIONS(2510),
    [anon_sym_restrict] = ACTIONS(2510),
    [anon_sym___restrict__] = ACTIONS(2510),
    [anon_sym__Atomic] = ACTIONS(2510),
    [anon_sym__Noreturn] = ACTIONS(2510),
    [anon_sym_noreturn] = ACTIONS(2510),
    [anon_sym_mutable] = ACTIONS(2510),
    [anon_sym_constinit] = ACTIONS(2510),
    [anon_sym_consteval] = ACTIONS(2510),
    [anon_sym_alignas] = ACTIONS(2510),
    [anon_sym__Alignas] = ACTIONS(2510),
    [sym_primitive_type] = ACTIONS(2510),
    [anon_sym_enum] = ACTIONS(2510),
    [anon_sym_class] = ACTIONS(2510),
    [anon_sym_struct] = ACTIONS(2510),
    [anon_sym_union] = ACTIONS(2510),
    [anon_sym_if] = ACTIONS(2510),
    [anon_sym_switch] = ACTIONS(2510),
    [anon_sym_case] = ACTIONS(2510),
    [anon_sym_default] = ACTIONS(2510),
    [anon_sym_while] = ACTIONS(2510),
    [anon_sym_do] = ACTIONS(2510),
    [anon_sym_for] = ACTIONS(2510),
    [anon_sym_return] = ACTIONS(2510),
    [anon_sym_break] = ACTIONS(2510),
    [anon_sym_continue] = ACTIONS(2510),
    [anon_sym_goto] = ACTIONS(2510),
    [anon_sym___try] = ACTIONS(2510),
    [anon_sym___leave] = ACTIONS(2510),
    [anon_sym_not] = ACTIONS(2510),
    [anon_sym_compl] = ACTIONS(2510),
    [anon_sym_DASH_DASH] = ACTIONS(2512),
    [anon_sym_PLUS_PLUS] = ACTIONS(2512),
    [anon_sym_sizeof] = ACTIONS(2510),
    [anon_sym___alignof__] = ACTIONS(2510),
    [anon_sym___alignof] = ACTIONS(2510),
    [anon_sym__alignof] = ACTIONS(2510),
    [anon_sym_alignof] = ACTIONS(2510),
    [anon_sym__Alignof] = ACTIONS(2510),
    [anon_sym_offsetof] = ACTIONS(2510),
    [anon_sym__Generic] = ACTIONS(2510),
    [anon_sym_asm] = ACTIONS(2510),
    [anon_sym___asm__] = ACTIONS(2510),
    [sym_number_literal] = ACTIONS(2512),
    [anon_sym_L_SQUOTE] = ACTIONS(2512),
    [anon_sym_u_SQUOTE] = ACTIONS(2512),
    [anon_sym_U_SQUOTE] = ACTIONS(2512),
    [anon_sym_u8_SQUOTE] = ACTIONS(2512),
    [anon_sym_SQUOTE] = ACTIONS(2512),
    [anon_sym_L_DQUOTE] = ACTIONS(2512),
    [anon_sym_u_DQUOTE] = ACTIONS(2512),
    [anon_sym_U_DQUOTE] = ACTIONS(2512),
    [anon_sym_u8_DQUOTE] = ACTIONS(2512),
    [anon_sym_DQUOTE] = ACTIONS(2512),
    [sym_true] = ACTIONS(2510),
    [sym_false] = ACTIONS(2510),
    [anon_sym_NULL] = ACTIONS(2510),
    [anon_sym_nullptr] = ACTIONS(2510),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2510),
    [anon_sym_decltype] = ACTIONS(2510),
    [sym_virtual] = ACTIONS(2510),
    [anon_sym_explicit] = ACTIONS(2510),
    [anon_sym_typename] = ACTIONS(2510),
    [anon_sym_template] = ACTIONS(2510),
    [anon_sym_operator] = ACTIONS(2510),
    [anon_sym_try] = ACTIONS(2510),
    [anon_sym_delete] = ACTIONS(2510),
    [anon_sym_throw] = ACTIONS(2510),
    [anon_sym_namespace] = ACTIONS(2510),
    [anon_sym_using] = ACTIONS(2510),
    [anon_sym_static_assert] = ACTIONS(2510),
    [anon_sym_concept] = ACTIONS(2510),
    [anon_sym_co_return] = ACTIONS(2510),
    [anon_sym_co_yield] = ACTIONS(2510),
    [anon_sym_R_DQUOTE] = ACTIONS(2512),
    [anon_sym_LR_DQUOTE] = ACTIONS(2512),
    [anon_sym_uR_DQUOTE] = ACTIONS(2512),
    [anon_sym_UR_DQUOTE] = ACTIONS(2512),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2512),
    [anon_sym_co_await] = ACTIONS(2510),
    [anon_sym_new] = ACTIONS(2510),
    [anon_sym_requires] = ACTIONS(2510),
    [sym_this] = ACTIONS(2510),
    [anon_sym_discard] = ACTIONS(2510),
    [anon_sym_precise] = ACTIONS(2510),
    [anon_sym_shared] = ACTIONS(2510),
    [anon_sym_groupshared] = ACTIONS(2510),
    [anon_sym_uniform] = ACTIONS(2510),
    [anon_sym_row_major] = ACTIONS(2510),
    [anon_sym_column_major] = ACTIONS(2510),
    [anon_sym_globallycoherent] = ACTIONS(2510),
    [anon_sym_centroid] = ACTIONS(2510),
    [anon_sym_noperspective] = ACTIONS(2510),
    [anon_sym_nointerpolation] = ACTIONS(2510),
    [anon_sym_sample] = ACTIONS(2510),
    [anon_sym_linear] = ACTIONS(2510),
    [anon_sym_snorm] = ACTIONS(2510),
    [anon_sym_unorm] = ACTIONS(2510),
    [anon_sym_point] = ACTIONS(2510),
    [anon_sym_line] = ACTIONS(2510),
    [anon_sym_triangleadj] = ACTIONS(2510),
    [anon_sym_lineadj] = ACTIONS(2510),
    [anon_sym_triangle] = ACTIONS(2510),
    [anon_sym_cbuffer] = ACTIONS(2510),
  },
  [615] = {
    [sym_identifier] = ACTIONS(2371),
    [aux_sym_preproc_include_token1] = ACTIONS(2371),
    [aux_sym_preproc_def_token1] = ACTIONS(2371),
    [aux_sym_preproc_if_token1] = ACTIONS(2371),
    [aux_sym_preproc_if_token2] = ACTIONS(2371),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2371),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2371),
    [sym_preproc_directive] = ACTIONS(2371),
    [anon_sym_LPAREN2] = ACTIONS(2373),
    [anon_sym_BANG] = ACTIONS(2373),
    [anon_sym_TILDE] = ACTIONS(2373),
    [anon_sym_DASH] = ACTIONS(2371),
    [anon_sym_PLUS] = ACTIONS(2371),
    [anon_sym_STAR] = ACTIONS(2373),
    [anon_sym_AMP_AMP] = ACTIONS(2373),
    [anon_sym_AMP] = ACTIONS(2371),
    [anon_sym_SEMI] = ACTIONS(2373),
    [anon_sym___extension__] = ACTIONS(2371),
    [anon_sym_typedef] = ACTIONS(2371),
    [anon_sym_in] = ACTIONS(2371),
    [anon_sym_out] = ACTIONS(2371),
    [anon_sym_inout] = ACTIONS(2371),
    [anon_sym_extern] = ACTIONS(2371),
    [anon_sym___attribute__] = ACTIONS(2371),
    [anon_sym_COLON_COLON] = ACTIONS(2373),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2373),
    [anon_sym___declspec] = ACTIONS(2371),
    [anon_sym___based] = ACTIONS(2371),
    [anon_sym___cdecl] = ACTIONS(2371),
    [anon_sym___clrcall] = ACTIONS(2371),
    [anon_sym___stdcall] = ACTIONS(2371),
    [anon_sym___fastcall] = ACTIONS(2371),
    [anon_sym___thiscall] = ACTIONS(2371),
    [anon_sym___vectorcall] = ACTIONS(2371),
    [anon_sym_LBRACE] = ACTIONS(2373),
    [anon_sym_signed] = ACTIONS(2371),
    [anon_sym_unsigned] = ACTIONS(2371),
    [anon_sym_long] = ACTIONS(2371),
    [anon_sym_short] = ACTIONS(2371),
    [anon_sym_LBRACK] = ACTIONS(2371),
    [anon_sym_static] = ACTIONS(2371),
    [anon_sym_register] = ACTIONS(2371),
    [anon_sym_inline] = ACTIONS(2371),
    [anon_sym___inline] = ACTIONS(2371),
    [anon_sym___inline__] = ACTIONS(2371),
    [anon_sym___forceinline] = ACTIONS(2371),
    [anon_sym_thread_local] = ACTIONS(2371),
    [anon_sym___thread] = ACTIONS(2371),
    [anon_sym_const] = ACTIONS(2371),
    [anon_sym_constexpr] = ACTIONS(2371),
    [anon_sym_volatile] = ACTIONS(2371),
    [anon_sym_restrict] = ACTIONS(2371),
    [anon_sym___restrict__] = ACTIONS(2371),
    [anon_sym__Atomic] = ACTIONS(2371),
    [anon_sym__Noreturn] = ACTIONS(2371),
    [anon_sym_noreturn] = ACTIONS(2371),
    [anon_sym_mutable] = ACTIONS(2371),
    [anon_sym_constinit] = ACTIONS(2371),
    [anon_sym_consteval] = ACTIONS(2371),
    [anon_sym_alignas] = ACTIONS(2371),
    [anon_sym__Alignas] = ACTIONS(2371),
    [sym_primitive_type] = ACTIONS(2371),
    [anon_sym_enum] = ACTIONS(2371),
    [anon_sym_class] = ACTIONS(2371),
    [anon_sym_struct] = ACTIONS(2371),
    [anon_sym_union] = ACTIONS(2371),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_switch] = ACTIONS(2371),
    [anon_sym_case] = ACTIONS(2371),
    [anon_sym_default] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(2371),
    [anon_sym_do] = ACTIONS(2371),
    [anon_sym_for] = ACTIONS(2371),
    [anon_sym_return] = ACTIONS(2371),
    [anon_sym_break] = ACTIONS(2371),
    [anon_sym_continue] = ACTIONS(2371),
    [anon_sym_goto] = ACTIONS(2371),
    [anon_sym___try] = ACTIONS(2371),
    [anon_sym___leave] = ACTIONS(2371),
    [anon_sym_not] = ACTIONS(2371),
    [anon_sym_compl] = ACTIONS(2371),
    [anon_sym_DASH_DASH] = ACTIONS(2373),
    [anon_sym_PLUS_PLUS] = ACTIONS(2373),
    [anon_sym_sizeof] = ACTIONS(2371),
    [anon_sym___alignof__] = ACTIONS(2371),
    [anon_sym___alignof] = ACTIONS(2371),
    [anon_sym__alignof] = ACTIONS(2371),
    [anon_sym_alignof] = ACTIONS(2371),
    [anon_sym__Alignof] = ACTIONS(2371),
    [anon_sym_offsetof] = ACTIONS(2371),
    [anon_sym__Generic] = ACTIONS(2371),
    [anon_sym_asm] = ACTIONS(2371),
    [anon_sym___asm__] = ACTIONS(2371),
    [sym_number_literal] = ACTIONS(2373),
    [anon_sym_L_SQUOTE] = ACTIONS(2373),
    [anon_sym_u_SQUOTE] = ACTIONS(2373),
    [anon_sym_U_SQUOTE] = ACTIONS(2373),
    [anon_sym_u8_SQUOTE] = ACTIONS(2373),
    [anon_sym_SQUOTE] = ACTIONS(2373),
    [anon_sym_L_DQUOTE] = ACTIONS(2373),
    [anon_sym_u_DQUOTE] = ACTIONS(2373),
    [anon_sym_U_DQUOTE] = ACTIONS(2373),
    [anon_sym_u8_DQUOTE] = ACTIONS(2373),
    [anon_sym_DQUOTE] = ACTIONS(2373),
    [sym_true] = ACTIONS(2371),
    [sym_false] = ACTIONS(2371),
    [anon_sym_NULL] = ACTIONS(2371),
    [anon_sym_nullptr] = ACTIONS(2371),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2371),
    [anon_sym_decltype] = ACTIONS(2371),
    [sym_virtual] = ACTIONS(2371),
    [anon_sym_explicit] = ACTIONS(2371),
    [anon_sym_typename] = ACTIONS(2371),
    [anon_sym_template] = ACTIONS(2371),
    [anon_sym_operator] = ACTIONS(2371),
    [anon_sym_try] = ACTIONS(2371),
    [anon_sym_delete] = ACTIONS(2371),
    [anon_sym_throw] = ACTIONS(2371),
    [anon_sym_namespace] = ACTIONS(2371),
    [anon_sym_using] = ACTIONS(2371),
    [anon_sym_static_assert] = ACTIONS(2371),
    [anon_sym_concept] = ACTIONS(2371),
    [anon_sym_co_return] = ACTIONS(2371),
    [anon_sym_co_yield] = ACTIONS(2371),
    [anon_sym_R_DQUOTE] = ACTIONS(2373),
    [anon_sym_LR_DQUOTE] = ACTIONS(2373),
    [anon_sym_uR_DQUOTE] = ACTIONS(2373),
    [anon_sym_UR_DQUOTE] = ACTIONS(2373),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2373),
    [anon_sym_co_await] = ACTIONS(2371),
    [anon_sym_new] = ACTIONS(2371),
    [anon_sym_requires] = ACTIONS(2371),
    [sym_this] = ACTIONS(2371),
    [anon_sym_discard] = ACTIONS(2371),
    [anon_sym_precise] = ACTIONS(2371),
    [anon_sym_shared] = ACTIONS(2371),
    [anon_sym_groupshared] = ACTIONS(2371),
    [anon_sym_uniform] = ACTIONS(2371),
    [anon_sym_row_major] = ACTIONS(2371),
    [anon_sym_column_major] = ACTIONS(2371),
    [anon_sym_globallycoherent] = ACTIONS(2371),
    [anon_sym_centroid] = ACTIONS(2371),
    [anon_sym_noperspective] = ACTIONS(2371),
    [anon_sym_nointerpolation] = ACTIONS(2371),
    [anon_sym_sample] = ACTIONS(2371),
    [anon_sym_linear] = ACTIONS(2371),
    [anon_sym_snorm] = ACTIONS(2371),
    [anon_sym_unorm] = ACTIONS(2371),
    [anon_sym_point] = ACTIONS(2371),
    [anon_sym_line] = ACTIONS(2371),
    [anon_sym_triangleadj] = ACTIONS(2371),
    [anon_sym_lineadj] = ACTIONS(2371),
    [anon_sym_triangle] = ACTIONS(2371),
    [anon_sym_cbuffer] = ACTIONS(2371),
  },
  [616] = {
    [sym_identifier] = ACTIONS(2375),
    [aux_sym_preproc_include_token1] = ACTIONS(2375),
    [aux_sym_preproc_def_token1] = ACTIONS(2375),
    [aux_sym_preproc_if_token1] = ACTIONS(2375),
    [aux_sym_preproc_if_token2] = ACTIONS(2375),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2375),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2375),
    [sym_preproc_directive] = ACTIONS(2375),
    [anon_sym_LPAREN2] = ACTIONS(2377),
    [anon_sym_BANG] = ACTIONS(2377),
    [anon_sym_TILDE] = ACTIONS(2377),
    [anon_sym_DASH] = ACTIONS(2375),
    [anon_sym_PLUS] = ACTIONS(2375),
    [anon_sym_STAR] = ACTIONS(2377),
    [anon_sym_AMP_AMP] = ACTIONS(2377),
    [anon_sym_AMP] = ACTIONS(2375),
    [anon_sym_SEMI] = ACTIONS(2377),
    [anon_sym___extension__] = ACTIONS(2375),
    [anon_sym_typedef] = ACTIONS(2375),
    [anon_sym_in] = ACTIONS(2375),
    [anon_sym_out] = ACTIONS(2375),
    [anon_sym_inout] = ACTIONS(2375),
    [anon_sym_extern] = ACTIONS(2375),
    [anon_sym___attribute__] = ACTIONS(2375),
    [anon_sym_COLON_COLON] = ACTIONS(2377),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2377),
    [anon_sym___declspec] = ACTIONS(2375),
    [anon_sym___based] = ACTIONS(2375),
    [anon_sym___cdecl] = ACTIONS(2375),
    [anon_sym___clrcall] = ACTIONS(2375),
    [anon_sym___stdcall] = ACTIONS(2375),
    [anon_sym___fastcall] = ACTIONS(2375),
    [anon_sym___thiscall] = ACTIONS(2375),
    [anon_sym___vectorcall] = ACTIONS(2375),
    [anon_sym_LBRACE] = ACTIONS(2377),
    [anon_sym_signed] = ACTIONS(2375),
    [anon_sym_unsigned] = ACTIONS(2375),
    [anon_sym_long] = ACTIONS(2375),
    [anon_sym_short] = ACTIONS(2375),
    [anon_sym_LBRACK] = ACTIONS(2375),
    [anon_sym_static] = ACTIONS(2375),
    [anon_sym_register] = ACTIONS(2375),
    [anon_sym_inline] = ACTIONS(2375),
    [anon_sym___inline] = ACTIONS(2375),
    [anon_sym___inline__] = ACTIONS(2375),
    [anon_sym___forceinline] = ACTIONS(2375),
    [anon_sym_thread_local] = ACTIONS(2375),
    [anon_sym___thread] = ACTIONS(2375),
    [anon_sym_const] = ACTIONS(2375),
    [anon_sym_constexpr] = ACTIONS(2375),
    [anon_sym_volatile] = ACTIONS(2375),
    [anon_sym_restrict] = ACTIONS(2375),
    [anon_sym___restrict__] = ACTIONS(2375),
    [anon_sym__Atomic] = ACTIONS(2375),
    [anon_sym__Noreturn] = ACTIONS(2375),
    [anon_sym_noreturn] = ACTIONS(2375),
    [anon_sym_mutable] = ACTIONS(2375),
    [anon_sym_constinit] = ACTIONS(2375),
    [anon_sym_consteval] = ACTIONS(2375),
    [anon_sym_alignas] = ACTIONS(2375),
    [anon_sym__Alignas] = ACTIONS(2375),
    [sym_primitive_type] = ACTIONS(2375),
    [anon_sym_enum] = ACTIONS(2375),
    [anon_sym_class] = ACTIONS(2375),
    [anon_sym_struct] = ACTIONS(2375),
    [anon_sym_union] = ACTIONS(2375),
    [anon_sym_if] = ACTIONS(2375),
    [anon_sym_switch] = ACTIONS(2375),
    [anon_sym_case] = ACTIONS(2375),
    [anon_sym_default] = ACTIONS(2375),
    [anon_sym_while] = ACTIONS(2375),
    [anon_sym_do] = ACTIONS(2375),
    [anon_sym_for] = ACTIONS(2375),
    [anon_sym_return] = ACTIONS(2375),
    [anon_sym_break] = ACTIONS(2375),
    [anon_sym_continue] = ACTIONS(2375),
    [anon_sym_goto] = ACTIONS(2375),
    [anon_sym___try] = ACTIONS(2375),
    [anon_sym___leave] = ACTIONS(2375),
    [anon_sym_not] = ACTIONS(2375),
    [anon_sym_compl] = ACTIONS(2375),
    [anon_sym_DASH_DASH] = ACTIONS(2377),
    [anon_sym_PLUS_PLUS] = ACTIONS(2377),
    [anon_sym_sizeof] = ACTIONS(2375),
    [anon_sym___alignof__] = ACTIONS(2375),
    [anon_sym___alignof] = ACTIONS(2375),
    [anon_sym__alignof] = ACTIONS(2375),
    [anon_sym_alignof] = ACTIONS(2375),
    [anon_sym__Alignof] = ACTIONS(2375),
    [anon_sym_offsetof] = ACTIONS(2375),
    [anon_sym__Generic] = ACTIONS(2375),
    [anon_sym_asm] = ACTIONS(2375),
    [anon_sym___asm__] = ACTIONS(2375),
    [sym_number_literal] = ACTIONS(2377),
    [anon_sym_L_SQUOTE] = ACTIONS(2377),
    [anon_sym_u_SQUOTE] = ACTIONS(2377),
    [anon_sym_U_SQUOTE] = ACTIONS(2377),
    [anon_sym_u8_SQUOTE] = ACTIONS(2377),
    [anon_sym_SQUOTE] = ACTIONS(2377),
    [anon_sym_L_DQUOTE] = ACTIONS(2377),
    [anon_sym_u_DQUOTE] = ACTIONS(2377),
    [anon_sym_U_DQUOTE] = ACTIONS(2377),
    [anon_sym_u8_DQUOTE] = ACTIONS(2377),
    [anon_sym_DQUOTE] = ACTIONS(2377),
    [sym_true] = ACTIONS(2375),
    [sym_false] = ACTIONS(2375),
    [anon_sym_NULL] = ACTIONS(2375),
    [anon_sym_nullptr] = ACTIONS(2375),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2375),
    [anon_sym_decltype] = ACTIONS(2375),
    [sym_virtual] = ACTIONS(2375),
    [anon_sym_explicit] = ACTIONS(2375),
    [anon_sym_typename] = ACTIONS(2375),
    [anon_sym_template] = ACTIONS(2375),
    [anon_sym_operator] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_delete] = ACTIONS(2375),
    [anon_sym_throw] = ACTIONS(2375),
    [anon_sym_namespace] = ACTIONS(2375),
    [anon_sym_using] = ACTIONS(2375),
    [anon_sym_static_assert] = ACTIONS(2375),
    [anon_sym_concept] = ACTIONS(2375),
    [anon_sym_co_return] = ACTIONS(2375),
    [anon_sym_co_yield] = ACTIONS(2375),
    [anon_sym_R_DQUOTE] = ACTIONS(2377),
    [anon_sym_LR_DQUOTE] = ACTIONS(2377),
    [anon_sym_uR_DQUOTE] = ACTIONS(2377),
    [anon_sym_UR_DQUOTE] = ACTIONS(2377),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2377),
    [anon_sym_co_await] = ACTIONS(2375),
    [anon_sym_new] = ACTIONS(2375),
    [anon_sym_requires] = ACTIONS(2375),
    [sym_this] = ACTIONS(2375),
    [anon_sym_discard] = ACTIONS(2375),
    [anon_sym_precise] = ACTIONS(2375),
    [anon_sym_shared] = ACTIONS(2375),
    [anon_sym_groupshared] = ACTIONS(2375),
    [anon_sym_uniform] = ACTIONS(2375),
    [anon_sym_row_major] = ACTIONS(2375),
    [anon_sym_column_major] = ACTIONS(2375),
    [anon_sym_globallycoherent] = ACTIONS(2375),
    [anon_sym_centroid] = ACTIONS(2375),
    [anon_sym_noperspective] = ACTIONS(2375),
    [anon_sym_nointerpolation] = ACTIONS(2375),
    [anon_sym_sample] = ACTIONS(2375),
    [anon_sym_linear] = ACTIONS(2375),
    [anon_sym_snorm] = ACTIONS(2375),
    [anon_sym_unorm] = ACTIONS(2375),
    [anon_sym_point] = ACTIONS(2375),
    [anon_sym_line] = ACTIONS(2375),
    [anon_sym_triangleadj] = ACTIONS(2375),
    [anon_sym_lineadj] = ACTIONS(2375),
    [anon_sym_triangle] = ACTIONS(2375),
    [anon_sym_cbuffer] = ACTIONS(2375),
  },
  [617] = {
    [sym_identifier] = ACTIONS(2379),
    [aux_sym_preproc_include_token1] = ACTIONS(2379),
    [aux_sym_preproc_def_token1] = ACTIONS(2379),
    [aux_sym_preproc_if_token1] = ACTIONS(2379),
    [aux_sym_preproc_if_token2] = ACTIONS(2379),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2379),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2379),
    [sym_preproc_directive] = ACTIONS(2379),
    [anon_sym_LPAREN2] = ACTIONS(2381),
    [anon_sym_BANG] = ACTIONS(2381),
    [anon_sym_TILDE] = ACTIONS(2381),
    [anon_sym_DASH] = ACTIONS(2379),
    [anon_sym_PLUS] = ACTIONS(2379),
    [anon_sym_STAR] = ACTIONS(2381),
    [anon_sym_AMP_AMP] = ACTIONS(2381),
    [anon_sym_AMP] = ACTIONS(2379),
    [anon_sym_SEMI] = ACTIONS(2381),
    [anon_sym___extension__] = ACTIONS(2379),
    [anon_sym_typedef] = ACTIONS(2379),
    [anon_sym_in] = ACTIONS(2379),
    [anon_sym_out] = ACTIONS(2379),
    [anon_sym_inout] = ACTIONS(2379),
    [anon_sym_extern] = ACTIONS(2379),
    [anon_sym___attribute__] = ACTIONS(2379),
    [anon_sym_COLON_COLON] = ACTIONS(2381),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2381),
    [anon_sym___declspec] = ACTIONS(2379),
    [anon_sym___based] = ACTIONS(2379),
    [anon_sym___cdecl] = ACTIONS(2379),
    [anon_sym___clrcall] = ACTIONS(2379),
    [anon_sym___stdcall] = ACTIONS(2379),
    [anon_sym___fastcall] = ACTIONS(2379),
    [anon_sym___thiscall] = ACTIONS(2379),
    [anon_sym___vectorcall] = ACTIONS(2379),
    [anon_sym_LBRACE] = ACTIONS(2381),
    [anon_sym_signed] = ACTIONS(2379),
    [anon_sym_unsigned] = ACTIONS(2379),
    [anon_sym_long] = ACTIONS(2379),
    [anon_sym_short] = ACTIONS(2379),
    [anon_sym_LBRACK] = ACTIONS(2379),
    [anon_sym_static] = ACTIONS(2379),
    [anon_sym_register] = ACTIONS(2379),
    [anon_sym_inline] = ACTIONS(2379),
    [anon_sym___inline] = ACTIONS(2379),
    [anon_sym___inline__] = ACTIONS(2379),
    [anon_sym___forceinline] = ACTIONS(2379),
    [anon_sym_thread_local] = ACTIONS(2379),
    [anon_sym___thread] = ACTIONS(2379),
    [anon_sym_const] = ACTIONS(2379),
    [anon_sym_constexpr] = ACTIONS(2379),
    [anon_sym_volatile] = ACTIONS(2379),
    [anon_sym_restrict] = ACTIONS(2379),
    [anon_sym___restrict__] = ACTIONS(2379),
    [anon_sym__Atomic] = ACTIONS(2379),
    [anon_sym__Noreturn] = ACTIONS(2379),
    [anon_sym_noreturn] = ACTIONS(2379),
    [anon_sym_mutable] = ACTIONS(2379),
    [anon_sym_constinit] = ACTIONS(2379),
    [anon_sym_consteval] = ACTIONS(2379),
    [anon_sym_alignas] = ACTIONS(2379),
    [anon_sym__Alignas] = ACTIONS(2379),
    [sym_primitive_type] = ACTIONS(2379),
    [anon_sym_enum] = ACTIONS(2379),
    [anon_sym_class] = ACTIONS(2379),
    [anon_sym_struct] = ACTIONS(2379),
    [anon_sym_union] = ACTIONS(2379),
    [anon_sym_if] = ACTIONS(2379),
    [anon_sym_switch] = ACTIONS(2379),
    [anon_sym_case] = ACTIONS(2379),
    [anon_sym_default] = ACTIONS(2379),
    [anon_sym_while] = ACTIONS(2379),
    [anon_sym_do] = ACTIONS(2379),
    [anon_sym_for] = ACTIONS(2379),
    [anon_sym_return] = ACTIONS(2379),
    [anon_sym_break] = ACTIONS(2379),
    [anon_sym_continue] = ACTIONS(2379),
    [anon_sym_goto] = ACTIONS(2379),
    [anon_sym___try] = ACTIONS(2379),
    [anon_sym___leave] = ACTIONS(2379),
    [anon_sym_not] = ACTIONS(2379),
    [anon_sym_compl] = ACTIONS(2379),
    [anon_sym_DASH_DASH] = ACTIONS(2381),
    [anon_sym_PLUS_PLUS] = ACTIONS(2381),
    [anon_sym_sizeof] = ACTIONS(2379),
    [anon_sym___alignof__] = ACTIONS(2379),
    [anon_sym___alignof] = ACTIONS(2379),
    [anon_sym__alignof] = ACTIONS(2379),
    [anon_sym_alignof] = ACTIONS(2379),
    [anon_sym__Alignof] = ACTIONS(2379),
    [anon_sym_offsetof] = ACTIONS(2379),
    [anon_sym__Generic] = ACTIONS(2379),
    [anon_sym_asm] = ACTIONS(2379),
    [anon_sym___asm__] = ACTIONS(2379),
    [sym_number_literal] = ACTIONS(2381),
    [anon_sym_L_SQUOTE] = ACTIONS(2381),
    [anon_sym_u_SQUOTE] = ACTIONS(2381),
    [anon_sym_U_SQUOTE] = ACTIONS(2381),
    [anon_sym_u8_SQUOTE] = ACTIONS(2381),
    [anon_sym_SQUOTE] = ACTIONS(2381),
    [anon_sym_L_DQUOTE] = ACTIONS(2381),
    [anon_sym_u_DQUOTE] = ACTIONS(2381),
    [anon_sym_U_DQUOTE] = ACTIONS(2381),
    [anon_sym_u8_DQUOTE] = ACTIONS(2381),
    [anon_sym_DQUOTE] = ACTIONS(2381),
    [sym_true] = ACTIONS(2379),
    [sym_false] = ACTIONS(2379),
    [anon_sym_NULL] = ACTIONS(2379),
    [anon_sym_nullptr] = ACTIONS(2379),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2379),
    [anon_sym_decltype] = ACTIONS(2379),
    [sym_virtual] = ACTIONS(2379),
    [anon_sym_explicit] = ACTIONS(2379),
    [anon_sym_typename] = ACTIONS(2379),
    [anon_sym_template] = ACTIONS(2379),
    [anon_sym_operator] = ACTIONS(2379),
    [anon_sym_try] = ACTIONS(2379),
    [anon_sym_delete] = ACTIONS(2379),
    [anon_sym_throw] = ACTIONS(2379),
    [anon_sym_namespace] = ACTIONS(2379),
    [anon_sym_using] = ACTIONS(2379),
    [anon_sym_static_assert] = ACTIONS(2379),
    [anon_sym_concept] = ACTIONS(2379),
    [anon_sym_co_return] = ACTIONS(2379),
    [anon_sym_co_yield] = ACTIONS(2379),
    [anon_sym_R_DQUOTE] = ACTIONS(2381),
    [anon_sym_LR_DQUOTE] = ACTIONS(2381),
    [anon_sym_uR_DQUOTE] = ACTIONS(2381),
    [anon_sym_UR_DQUOTE] = ACTIONS(2381),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2381),
    [anon_sym_co_await] = ACTIONS(2379),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_requires] = ACTIONS(2379),
    [sym_this] = ACTIONS(2379),
    [anon_sym_discard] = ACTIONS(2379),
    [anon_sym_precise] = ACTIONS(2379),
    [anon_sym_shared] = ACTIONS(2379),
    [anon_sym_groupshared] = ACTIONS(2379),
    [anon_sym_uniform] = ACTIONS(2379),
    [anon_sym_row_major] = ACTIONS(2379),
    [anon_sym_column_major] = ACTIONS(2379),
    [anon_sym_globallycoherent] = ACTIONS(2379),
    [anon_sym_centroid] = ACTIONS(2379),
    [anon_sym_noperspective] = ACTIONS(2379),
    [anon_sym_nointerpolation] = ACTIONS(2379),
    [anon_sym_sample] = ACTIONS(2379),
    [anon_sym_linear] = ACTIONS(2379),
    [anon_sym_snorm] = ACTIONS(2379),
    [anon_sym_unorm] = ACTIONS(2379),
    [anon_sym_point] = ACTIONS(2379),
    [anon_sym_line] = ACTIONS(2379),
    [anon_sym_triangleadj] = ACTIONS(2379),
    [anon_sym_lineadj] = ACTIONS(2379),
    [anon_sym_triangle] = ACTIONS(2379),
    [anon_sym_cbuffer] = ACTIONS(2379),
  },
  [618] = {
    [sym_identifier] = ACTIONS(2553),
    [aux_sym_preproc_include_token1] = ACTIONS(2553),
    [aux_sym_preproc_def_token1] = ACTIONS(2553),
    [aux_sym_preproc_if_token1] = ACTIONS(2553),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2553),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2553),
    [sym_preproc_directive] = ACTIONS(2553),
    [anon_sym_LPAREN2] = ACTIONS(2555),
    [anon_sym_BANG] = ACTIONS(2555),
    [anon_sym_TILDE] = ACTIONS(2555),
    [anon_sym_DASH] = ACTIONS(2553),
    [anon_sym_PLUS] = ACTIONS(2553),
    [anon_sym_STAR] = ACTIONS(2555),
    [anon_sym_AMP_AMP] = ACTIONS(2555),
    [anon_sym_AMP] = ACTIONS(2553),
    [anon_sym_SEMI] = ACTIONS(2555),
    [anon_sym___extension__] = ACTIONS(2553),
    [anon_sym_typedef] = ACTIONS(2553),
    [anon_sym_in] = ACTIONS(2553),
    [anon_sym_out] = ACTIONS(2553),
    [anon_sym_inout] = ACTIONS(2553),
    [anon_sym_extern] = ACTIONS(2553),
    [anon_sym___attribute__] = ACTIONS(2553),
    [anon_sym_COLON_COLON] = ACTIONS(2555),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2555),
    [anon_sym___declspec] = ACTIONS(2553),
    [anon_sym___based] = ACTIONS(2553),
    [anon_sym___cdecl] = ACTIONS(2553),
    [anon_sym___clrcall] = ACTIONS(2553),
    [anon_sym___stdcall] = ACTIONS(2553),
    [anon_sym___fastcall] = ACTIONS(2553),
    [anon_sym___thiscall] = ACTIONS(2553),
    [anon_sym___vectorcall] = ACTIONS(2553),
    [anon_sym_LBRACE] = ACTIONS(2555),
    [anon_sym_RBRACE] = ACTIONS(2555),
    [anon_sym_signed] = ACTIONS(2553),
    [anon_sym_unsigned] = ACTIONS(2553),
    [anon_sym_long] = ACTIONS(2553),
    [anon_sym_short] = ACTIONS(2553),
    [anon_sym_LBRACK] = ACTIONS(2553),
    [anon_sym_static] = ACTIONS(2553),
    [anon_sym_register] = ACTIONS(2553),
    [anon_sym_inline] = ACTIONS(2553),
    [anon_sym___inline] = ACTIONS(2553),
    [anon_sym___inline__] = ACTIONS(2553),
    [anon_sym___forceinline] = ACTIONS(2553),
    [anon_sym_thread_local] = ACTIONS(2553),
    [anon_sym___thread] = ACTIONS(2553),
    [anon_sym_const] = ACTIONS(2553),
    [anon_sym_constexpr] = ACTIONS(2553),
    [anon_sym_volatile] = ACTIONS(2553),
    [anon_sym_restrict] = ACTIONS(2553),
    [anon_sym___restrict__] = ACTIONS(2553),
    [anon_sym__Atomic] = ACTIONS(2553),
    [anon_sym__Noreturn] = ACTIONS(2553),
    [anon_sym_noreturn] = ACTIONS(2553),
    [anon_sym_mutable] = ACTIONS(2553),
    [anon_sym_constinit] = ACTIONS(2553),
    [anon_sym_consteval] = ACTIONS(2553),
    [anon_sym_alignas] = ACTIONS(2553),
    [anon_sym__Alignas] = ACTIONS(2553),
    [sym_primitive_type] = ACTIONS(2553),
    [anon_sym_enum] = ACTIONS(2553),
    [anon_sym_class] = ACTIONS(2553),
    [anon_sym_struct] = ACTIONS(2553),
    [anon_sym_union] = ACTIONS(2553),
    [anon_sym_if] = ACTIONS(2553),
    [anon_sym_switch] = ACTIONS(2553),
    [anon_sym_case] = ACTIONS(2553),
    [anon_sym_default] = ACTIONS(2553),
    [anon_sym_while] = ACTIONS(2553),
    [anon_sym_do] = ACTIONS(2553),
    [anon_sym_for] = ACTIONS(2553),
    [anon_sym_return] = ACTIONS(2553),
    [anon_sym_break] = ACTIONS(2553),
    [anon_sym_continue] = ACTIONS(2553),
    [anon_sym_goto] = ACTIONS(2553),
    [anon_sym___try] = ACTIONS(2553),
    [anon_sym___leave] = ACTIONS(2553),
    [anon_sym_not] = ACTIONS(2553),
    [anon_sym_compl] = ACTIONS(2553),
    [anon_sym_DASH_DASH] = ACTIONS(2555),
    [anon_sym_PLUS_PLUS] = ACTIONS(2555),
    [anon_sym_sizeof] = ACTIONS(2553),
    [anon_sym___alignof__] = ACTIONS(2553),
    [anon_sym___alignof] = ACTIONS(2553),
    [anon_sym__alignof] = ACTIONS(2553),
    [anon_sym_alignof] = ACTIONS(2553),
    [anon_sym__Alignof] = ACTIONS(2553),
    [anon_sym_offsetof] = ACTIONS(2553),
    [anon_sym__Generic] = ACTIONS(2553),
    [anon_sym_asm] = ACTIONS(2553),
    [anon_sym___asm__] = ACTIONS(2553),
    [sym_number_literal] = ACTIONS(2555),
    [anon_sym_L_SQUOTE] = ACTIONS(2555),
    [anon_sym_u_SQUOTE] = ACTIONS(2555),
    [anon_sym_U_SQUOTE] = ACTIONS(2555),
    [anon_sym_u8_SQUOTE] = ACTIONS(2555),
    [anon_sym_SQUOTE] = ACTIONS(2555),
    [anon_sym_L_DQUOTE] = ACTIONS(2555),
    [anon_sym_u_DQUOTE] = ACTIONS(2555),
    [anon_sym_U_DQUOTE] = ACTIONS(2555),
    [anon_sym_u8_DQUOTE] = ACTIONS(2555),
    [anon_sym_DQUOTE] = ACTIONS(2555),
    [sym_true] = ACTIONS(2553),
    [sym_false] = ACTIONS(2553),
    [anon_sym_NULL] = ACTIONS(2553),
    [anon_sym_nullptr] = ACTIONS(2553),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2553),
    [anon_sym_decltype] = ACTIONS(2553),
    [sym_virtual] = ACTIONS(2553),
    [anon_sym_explicit] = ACTIONS(2553),
    [anon_sym_typename] = ACTIONS(2553),
    [anon_sym_template] = ACTIONS(2553),
    [anon_sym_operator] = ACTIONS(2553),
    [anon_sym_try] = ACTIONS(2553),
    [anon_sym_delete] = ACTIONS(2553),
    [anon_sym_throw] = ACTIONS(2553),
    [anon_sym_namespace] = ACTIONS(2553),
    [anon_sym_using] = ACTIONS(2553),
    [anon_sym_static_assert] = ACTIONS(2553),
    [anon_sym_concept] = ACTIONS(2553),
    [anon_sym_co_return] = ACTIONS(2553),
    [anon_sym_co_yield] = ACTIONS(2553),
    [anon_sym_R_DQUOTE] = ACTIONS(2555),
    [anon_sym_LR_DQUOTE] = ACTIONS(2555),
    [anon_sym_uR_DQUOTE] = ACTIONS(2555),
    [anon_sym_UR_DQUOTE] = ACTIONS(2555),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2555),
    [anon_sym_co_await] = ACTIONS(2553),
    [anon_sym_new] = ACTIONS(2553),
    [anon_sym_requires] = ACTIONS(2553),
    [sym_this] = ACTIONS(2553),
    [anon_sym_discard] = ACTIONS(2553),
    [anon_sym_precise] = ACTIONS(2553),
    [anon_sym_shared] = ACTIONS(2553),
    [anon_sym_groupshared] = ACTIONS(2553),
    [anon_sym_uniform] = ACTIONS(2553),
    [anon_sym_row_major] = ACTIONS(2553),
    [anon_sym_column_major] = ACTIONS(2553),
    [anon_sym_globallycoherent] = ACTIONS(2553),
    [anon_sym_centroid] = ACTIONS(2553),
    [anon_sym_noperspective] = ACTIONS(2553),
    [anon_sym_nointerpolation] = ACTIONS(2553),
    [anon_sym_sample] = ACTIONS(2553),
    [anon_sym_linear] = ACTIONS(2553),
    [anon_sym_snorm] = ACTIONS(2553),
    [anon_sym_unorm] = ACTIONS(2553),
    [anon_sym_point] = ACTIONS(2553),
    [anon_sym_line] = ACTIONS(2553),
    [anon_sym_triangleadj] = ACTIONS(2553),
    [anon_sym_lineadj] = ACTIONS(2553),
    [anon_sym_triangle] = ACTIONS(2553),
    [anon_sym_cbuffer] = ACTIONS(2553),
  },
  [619] = {
    [sym_identifier] = ACTIONS(2573),
    [aux_sym_preproc_include_token1] = ACTIONS(2573),
    [aux_sym_preproc_def_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2573),
    [sym_preproc_directive] = ACTIONS(2573),
    [anon_sym_LPAREN2] = ACTIONS(2575),
    [anon_sym_BANG] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(2575),
    [anon_sym_DASH] = ACTIONS(2573),
    [anon_sym_PLUS] = ACTIONS(2573),
    [anon_sym_STAR] = ACTIONS(2575),
    [anon_sym_AMP_AMP] = ACTIONS(2575),
    [anon_sym_AMP] = ACTIONS(2573),
    [anon_sym_SEMI] = ACTIONS(2575),
    [anon_sym___extension__] = ACTIONS(2573),
    [anon_sym_typedef] = ACTIONS(2573),
    [anon_sym_in] = ACTIONS(2573),
    [anon_sym_out] = ACTIONS(2573),
    [anon_sym_inout] = ACTIONS(2573),
    [anon_sym_extern] = ACTIONS(2573),
    [anon_sym___attribute__] = ACTIONS(2573),
    [anon_sym_COLON_COLON] = ACTIONS(2575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2575),
    [anon_sym___declspec] = ACTIONS(2573),
    [anon_sym___based] = ACTIONS(2573),
    [anon_sym___cdecl] = ACTIONS(2573),
    [anon_sym___clrcall] = ACTIONS(2573),
    [anon_sym___stdcall] = ACTIONS(2573),
    [anon_sym___fastcall] = ACTIONS(2573),
    [anon_sym___thiscall] = ACTIONS(2573),
    [anon_sym___vectorcall] = ACTIONS(2573),
    [anon_sym_LBRACE] = ACTIONS(2575),
    [anon_sym_RBRACE] = ACTIONS(2575),
    [anon_sym_signed] = ACTIONS(2573),
    [anon_sym_unsigned] = ACTIONS(2573),
    [anon_sym_long] = ACTIONS(2573),
    [anon_sym_short] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2573),
    [anon_sym_static] = ACTIONS(2573),
    [anon_sym_register] = ACTIONS(2573),
    [anon_sym_inline] = ACTIONS(2573),
    [anon_sym___inline] = ACTIONS(2573),
    [anon_sym___inline__] = ACTIONS(2573),
    [anon_sym___forceinline] = ACTIONS(2573),
    [anon_sym_thread_local] = ACTIONS(2573),
    [anon_sym___thread] = ACTIONS(2573),
    [anon_sym_const] = ACTIONS(2573),
    [anon_sym_constexpr] = ACTIONS(2573),
    [anon_sym_volatile] = ACTIONS(2573),
    [anon_sym_restrict] = ACTIONS(2573),
    [anon_sym___restrict__] = ACTIONS(2573),
    [anon_sym__Atomic] = ACTIONS(2573),
    [anon_sym__Noreturn] = ACTIONS(2573),
    [anon_sym_noreturn] = ACTIONS(2573),
    [anon_sym_mutable] = ACTIONS(2573),
    [anon_sym_constinit] = ACTIONS(2573),
    [anon_sym_consteval] = ACTIONS(2573),
    [anon_sym_alignas] = ACTIONS(2573),
    [anon_sym__Alignas] = ACTIONS(2573),
    [sym_primitive_type] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_class] = ACTIONS(2573),
    [anon_sym_struct] = ACTIONS(2573),
    [anon_sym_union] = ACTIONS(2573),
    [anon_sym_if] = ACTIONS(2573),
    [anon_sym_switch] = ACTIONS(2573),
    [anon_sym_case] = ACTIONS(2573),
    [anon_sym_default] = ACTIONS(2573),
    [anon_sym_while] = ACTIONS(2573),
    [anon_sym_do] = ACTIONS(2573),
    [anon_sym_for] = ACTIONS(2573),
    [anon_sym_return] = ACTIONS(2573),
    [anon_sym_break] = ACTIONS(2573),
    [anon_sym_continue] = ACTIONS(2573),
    [anon_sym_goto] = ACTIONS(2573),
    [anon_sym___try] = ACTIONS(2573),
    [anon_sym___leave] = ACTIONS(2573),
    [anon_sym_not] = ACTIONS(2573),
    [anon_sym_compl] = ACTIONS(2573),
    [anon_sym_DASH_DASH] = ACTIONS(2575),
    [anon_sym_PLUS_PLUS] = ACTIONS(2575),
    [anon_sym_sizeof] = ACTIONS(2573),
    [anon_sym___alignof__] = ACTIONS(2573),
    [anon_sym___alignof] = ACTIONS(2573),
    [anon_sym__alignof] = ACTIONS(2573),
    [anon_sym_alignof] = ACTIONS(2573),
    [anon_sym__Alignof] = ACTIONS(2573),
    [anon_sym_offsetof] = ACTIONS(2573),
    [anon_sym__Generic] = ACTIONS(2573),
    [anon_sym_asm] = ACTIONS(2573),
    [anon_sym___asm__] = ACTIONS(2573),
    [sym_number_literal] = ACTIONS(2575),
    [anon_sym_L_SQUOTE] = ACTIONS(2575),
    [anon_sym_u_SQUOTE] = ACTIONS(2575),
    [anon_sym_U_SQUOTE] = ACTIONS(2575),
    [anon_sym_u8_SQUOTE] = ACTIONS(2575),
    [anon_sym_SQUOTE] = ACTIONS(2575),
    [anon_sym_L_DQUOTE] = ACTIONS(2575),
    [anon_sym_u_DQUOTE] = ACTIONS(2575),
    [anon_sym_U_DQUOTE] = ACTIONS(2575),
    [anon_sym_u8_DQUOTE] = ACTIONS(2575),
    [anon_sym_DQUOTE] = ACTIONS(2575),
    [sym_true] = ACTIONS(2573),
    [sym_false] = ACTIONS(2573),
    [anon_sym_NULL] = ACTIONS(2573),
    [anon_sym_nullptr] = ACTIONS(2573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2573),
    [anon_sym_decltype] = ACTIONS(2573),
    [sym_virtual] = ACTIONS(2573),
    [anon_sym_explicit] = ACTIONS(2573),
    [anon_sym_typename] = ACTIONS(2573),
    [anon_sym_template] = ACTIONS(2573),
    [anon_sym_operator] = ACTIONS(2573),
    [anon_sym_try] = ACTIONS(2573),
    [anon_sym_delete] = ACTIONS(2573),
    [anon_sym_throw] = ACTIONS(2573),
    [anon_sym_namespace] = ACTIONS(2573),
    [anon_sym_using] = ACTIONS(2573),
    [anon_sym_static_assert] = ACTIONS(2573),
    [anon_sym_concept] = ACTIONS(2573),
    [anon_sym_co_return] = ACTIONS(2573),
    [anon_sym_co_yield] = ACTIONS(2573),
    [anon_sym_R_DQUOTE] = ACTIONS(2575),
    [anon_sym_LR_DQUOTE] = ACTIONS(2575),
    [anon_sym_uR_DQUOTE] = ACTIONS(2575),
    [anon_sym_UR_DQUOTE] = ACTIONS(2575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2575),
    [anon_sym_co_await] = ACTIONS(2573),
    [anon_sym_new] = ACTIONS(2573),
    [anon_sym_requires] = ACTIONS(2573),
    [sym_this] = ACTIONS(2573),
    [anon_sym_discard] = ACTIONS(2573),
    [anon_sym_precise] = ACTIONS(2573),
    [anon_sym_shared] = ACTIONS(2573),
    [anon_sym_groupshared] = ACTIONS(2573),
    [anon_sym_uniform] = ACTIONS(2573),
    [anon_sym_row_major] = ACTIONS(2573),
    [anon_sym_column_major] = ACTIONS(2573),
    [anon_sym_globallycoherent] = ACTIONS(2573),
    [anon_sym_centroid] = ACTIONS(2573),
    [anon_sym_noperspective] = ACTIONS(2573),
    [anon_sym_nointerpolation] = ACTIONS(2573),
    [anon_sym_sample] = ACTIONS(2573),
    [anon_sym_linear] = ACTIONS(2573),
    [anon_sym_snorm] = ACTIONS(2573),
    [anon_sym_unorm] = ACTIONS(2573),
    [anon_sym_point] = ACTIONS(2573),
    [anon_sym_line] = ACTIONS(2573),
    [anon_sym_triangleadj] = ACTIONS(2573),
    [anon_sym_lineadj] = ACTIONS(2573),
    [anon_sym_triangle] = ACTIONS(2573),
    [anon_sym_cbuffer] = ACTIONS(2573),
  },
  [620] = {
    [sym_identifier] = ACTIONS(2466),
    [aux_sym_preproc_include_token1] = ACTIONS(2466),
    [aux_sym_preproc_def_token1] = ACTIONS(2466),
    [aux_sym_preproc_if_token1] = ACTIONS(2466),
    [aux_sym_preproc_if_token2] = ACTIONS(2466),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2466),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2466),
    [sym_preproc_directive] = ACTIONS(2466),
    [anon_sym_LPAREN2] = ACTIONS(2468),
    [anon_sym_BANG] = ACTIONS(2468),
    [anon_sym_TILDE] = ACTIONS(2468),
    [anon_sym_DASH] = ACTIONS(2466),
    [anon_sym_PLUS] = ACTIONS(2466),
    [anon_sym_STAR] = ACTIONS(2468),
    [anon_sym_AMP_AMP] = ACTIONS(2468),
    [anon_sym_AMP] = ACTIONS(2466),
    [anon_sym_SEMI] = ACTIONS(2468),
    [anon_sym___extension__] = ACTIONS(2466),
    [anon_sym_typedef] = ACTIONS(2466),
    [anon_sym_in] = ACTIONS(2466),
    [anon_sym_out] = ACTIONS(2466),
    [anon_sym_inout] = ACTIONS(2466),
    [anon_sym_extern] = ACTIONS(2466),
    [anon_sym___attribute__] = ACTIONS(2466),
    [anon_sym_COLON_COLON] = ACTIONS(2468),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2468),
    [anon_sym___declspec] = ACTIONS(2466),
    [anon_sym___based] = ACTIONS(2466),
    [anon_sym___cdecl] = ACTIONS(2466),
    [anon_sym___clrcall] = ACTIONS(2466),
    [anon_sym___stdcall] = ACTIONS(2466),
    [anon_sym___fastcall] = ACTIONS(2466),
    [anon_sym___thiscall] = ACTIONS(2466),
    [anon_sym___vectorcall] = ACTIONS(2466),
    [anon_sym_LBRACE] = ACTIONS(2468),
    [anon_sym_signed] = ACTIONS(2466),
    [anon_sym_unsigned] = ACTIONS(2466),
    [anon_sym_long] = ACTIONS(2466),
    [anon_sym_short] = ACTIONS(2466),
    [anon_sym_LBRACK] = ACTIONS(2466),
    [anon_sym_static] = ACTIONS(2466),
    [anon_sym_register] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2466),
    [anon_sym___inline] = ACTIONS(2466),
    [anon_sym___inline__] = ACTIONS(2466),
    [anon_sym___forceinline] = ACTIONS(2466),
    [anon_sym_thread_local] = ACTIONS(2466),
    [anon_sym___thread] = ACTIONS(2466),
    [anon_sym_const] = ACTIONS(2466),
    [anon_sym_constexpr] = ACTIONS(2466),
    [anon_sym_volatile] = ACTIONS(2466),
    [anon_sym_restrict] = ACTIONS(2466),
    [anon_sym___restrict__] = ACTIONS(2466),
    [anon_sym__Atomic] = ACTIONS(2466),
    [anon_sym__Noreturn] = ACTIONS(2466),
    [anon_sym_noreturn] = ACTIONS(2466),
    [anon_sym_mutable] = ACTIONS(2466),
    [anon_sym_constinit] = ACTIONS(2466),
    [anon_sym_consteval] = ACTIONS(2466),
    [anon_sym_alignas] = ACTIONS(2466),
    [anon_sym__Alignas] = ACTIONS(2466),
    [sym_primitive_type] = ACTIONS(2466),
    [anon_sym_enum] = ACTIONS(2466),
    [anon_sym_class] = ACTIONS(2466),
    [anon_sym_struct] = ACTIONS(2466),
    [anon_sym_union] = ACTIONS(2466),
    [anon_sym_if] = ACTIONS(2466),
    [anon_sym_switch] = ACTIONS(2466),
    [anon_sym_case] = ACTIONS(2466),
    [anon_sym_default] = ACTIONS(2466),
    [anon_sym_while] = ACTIONS(2466),
    [anon_sym_do] = ACTIONS(2466),
    [anon_sym_for] = ACTIONS(2466),
    [anon_sym_return] = ACTIONS(2466),
    [anon_sym_break] = ACTIONS(2466),
    [anon_sym_continue] = ACTIONS(2466),
    [anon_sym_goto] = ACTIONS(2466),
    [anon_sym___try] = ACTIONS(2466),
    [anon_sym___leave] = ACTIONS(2466),
    [anon_sym_not] = ACTIONS(2466),
    [anon_sym_compl] = ACTIONS(2466),
    [anon_sym_DASH_DASH] = ACTIONS(2468),
    [anon_sym_PLUS_PLUS] = ACTIONS(2468),
    [anon_sym_sizeof] = ACTIONS(2466),
    [anon_sym___alignof__] = ACTIONS(2466),
    [anon_sym___alignof] = ACTIONS(2466),
    [anon_sym__alignof] = ACTIONS(2466),
    [anon_sym_alignof] = ACTIONS(2466),
    [anon_sym__Alignof] = ACTIONS(2466),
    [anon_sym_offsetof] = ACTIONS(2466),
    [anon_sym__Generic] = ACTIONS(2466),
    [anon_sym_asm] = ACTIONS(2466),
    [anon_sym___asm__] = ACTIONS(2466),
    [sym_number_literal] = ACTIONS(2468),
    [anon_sym_L_SQUOTE] = ACTIONS(2468),
    [anon_sym_u_SQUOTE] = ACTIONS(2468),
    [anon_sym_U_SQUOTE] = ACTIONS(2468),
    [anon_sym_u8_SQUOTE] = ACTIONS(2468),
    [anon_sym_SQUOTE] = ACTIONS(2468),
    [anon_sym_L_DQUOTE] = ACTIONS(2468),
    [anon_sym_u_DQUOTE] = ACTIONS(2468),
    [anon_sym_U_DQUOTE] = ACTIONS(2468),
    [anon_sym_u8_DQUOTE] = ACTIONS(2468),
    [anon_sym_DQUOTE] = ACTIONS(2468),
    [sym_true] = ACTIONS(2466),
    [sym_false] = ACTIONS(2466),
    [anon_sym_NULL] = ACTIONS(2466),
    [anon_sym_nullptr] = ACTIONS(2466),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2466),
    [anon_sym_decltype] = ACTIONS(2466),
    [sym_virtual] = ACTIONS(2466),
    [anon_sym_explicit] = ACTIONS(2466),
    [anon_sym_typename] = ACTIONS(2466),
    [anon_sym_template] = ACTIONS(2466),
    [anon_sym_operator] = ACTIONS(2466),
    [anon_sym_try] = ACTIONS(2466),
    [anon_sym_delete] = ACTIONS(2466),
    [anon_sym_throw] = ACTIONS(2466),
    [anon_sym_namespace] = ACTIONS(2466),
    [anon_sym_using] = ACTIONS(2466),
    [anon_sym_static_assert] = ACTIONS(2466),
    [anon_sym_concept] = ACTIONS(2466),
    [anon_sym_co_return] = ACTIONS(2466),
    [anon_sym_co_yield] = ACTIONS(2466),
    [anon_sym_R_DQUOTE] = ACTIONS(2468),
    [anon_sym_LR_DQUOTE] = ACTIONS(2468),
    [anon_sym_uR_DQUOTE] = ACTIONS(2468),
    [anon_sym_UR_DQUOTE] = ACTIONS(2468),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2468),
    [anon_sym_co_await] = ACTIONS(2466),
    [anon_sym_new] = ACTIONS(2466),
    [anon_sym_requires] = ACTIONS(2466),
    [sym_this] = ACTIONS(2466),
    [anon_sym_discard] = ACTIONS(2466),
    [anon_sym_precise] = ACTIONS(2466),
    [anon_sym_shared] = ACTIONS(2466),
    [anon_sym_groupshared] = ACTIONS(2466),
    [anon_sym_uniform] = ACTIONS(2466),
    [anon_sym_row_major] = ACTIONS(2466),
    [anon_sym_column_major] = ACTIONS(2466),
    [anon_sym_globallycoherent] = ACTIONS(2466),
    [anon_sym_centroid] = ACTIONS(2466),
    [anon_sym_noperspective] = ACTIONS(2466),
    [anon_sym_nointerpolation] = ACTIONS(2466),
    [anon_sym_sample] = ACTIONS(2466),
    [anon_sym_linear] = ACTIONS(2466),
    [anon_sym_snorm] = ACTIONS(2466),
    [anon_sym_unorm] = ACTIONS(2466),
    [anon_sym_point] = ACTIONS(2466),
    [anon_sym_line] = ACTIONS(2466),
    [anon_sym_triangleadj] = ACTIONS(2466),
    [anon_sym_lineadj] = ACTIONS(2466),
    [anon_sym_triangle] = ACTIONS(2466),
    [anon_sym_cbuffer] = ACTIONS(2466),
  },
  [621] = {
    [sym_identifier] = ACTIONS(2490),
    [aux_sym_preproc_include_token1] = ACTIONS(2490),
    [aux_sym_preproc_def_token1] = ACTIONS(2490),
    [aux_sym_preproc_if_token1] = ACTIONS(2490),
    [aux_sym_preproc_if_token2] = ACTIONS(2490),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2490),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2490),
    [sym_preproc_directive] = ACTIONS(2490),
    [anon_sym_LPAREN2] = ACTIONS(2492),
    [anon_sym_BANG] = ACTIONS(2492),
    [anon_sym_TILDE] = ACTIONS(2492),
    [anon_sym_DASH] = ACTIONS(2490),
    [anon_sym_PLUS] = ACTIONS(2490),
    [anon_sym_STAR] = ACTIONS(2492),
    [anon_sym_AMP_AMP] = ACTIONS(2492),
    [anon_sym_AMP] = ACTIONS(2490),
    [anon_sym_SEMI] = ACTIONS(2492),
    [anon_sym___extension__] = ACTIONS(2490),
    [anon_sym_typedef] = ACTIONS(2490),
    [anon_sym_in] = ACTIONS(2490),
    [anon_sym_out] = ACTIONS(2490),
    [anon_sym_inout] = ACTIONS(2490),
    [anon_sym_extern] = ACTIONS(2490),
    [anon_sym___attribute__] = ACTIONS(2490),
    [anon_sym_COLON_COLON] = ACTIONS(2492),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2492),
    [anon_sym___declspec] = ACTIONS(2490),
    [anon_sym___based] = ACTIONS(2490),
    [anon_sym___cdecl] = ACTIONS(2490),
    [anon_sym___clrcall] = ACTIONS(2490),
    [anon_sym___stdcall] = ACTIONS(2490),
    [anon_sym___fastcall] = ACTIONS(2490),
    [anon_sym___thiscall] = ACTIONS(2490),
    [anon_sym___vectorcall] = ACTIONS(2490),
    [anon_sym_LBRACE] = ACTIONS(2492),
    [anon_sym_signed] = ACTIONS(2490),
    [anon_sym_unsigned] = ACTIONS(2490),
    [anon_sym_long] = ACTIONS(2490),
    [anon_sym_short] = ACTIONS(2490),
    [anon_sym_LBRACK] = ACTIONS(2490),
    [anon_sym_static] = ACTIONS(2490),
    [anon_sym_register] = ACTIONS(2490),
    [anon_sym_inline] = ACTIONS(2490),
    [anon_sym___inline] = ACTIONS(2490),
    [anon_sym___inline__] = ACTIONS(2490),
    [anon_sym___forceinline] = ACTIONS(2490),
    [anon_sym_thread_local] = ACTIONS(2490),
    [anon_sym___thread] = ACTIONS(2490),
    [anon_sym_const] = ACTIONS(2490),
    [anon_sym_constexpr] = ACTIONS(2490),
    [anon_sym_volatile] = ACTIONS(2490),
    [anon_sym_restrict] = ACTIONS(2490),
    [anon_sym___restrict__] = ACTIONS(2490),
    [anon_sym__Atomic] = ACTIONS(2490),
    [anon_sym__Noreturn] = ACTIONS(2490),
    [anon_sym_noreturn] = ACTIONS(2490),
    [anon_sym_mutable] = ACTIONS(2490),
    [anon_sym_constinit] = ACTIONS(2490),
    [anon_sym_consteval] = ACTIONS(2490),
    [anon_sym_alignas] = ACTIONS(2490),
    [anon_sym__Alignas] = ACTIONS(2490),
    [sym_primitive_type] = ACTIONS(2490),
    [anon_sym_enum] = ACTIONS(2490),
    [anon_sym_class] = ACTIONS(2490),
    [anon_sym_struct] = ACTIONS(2490),
    [anon_sym_union] = ACTIONS(2490),
    [anon_sym_if] = ACTIONS(2490),
    [anon_sym_switch] = ACTIONS(2490),
    [anon_sym_case] = ACTIONS(2490),
    [anon_sym_default] = ACTIONS(2490),
    [anon_sym_while] = ACTIONS(2490),
    [anon_sym_do] = ACTIONS(2490),
    [anon_sym_for] = ACTIONS(2490),
    [anon_sym_return] = ACTIONS(2490),
    [anon_sym_break] = ACTIONS(2490),
    [anon_sym_continue] = ACTIONS(2490),
    [anon_sym_goto] = ACTIONS(2490),
    [anon_sym___try] = ACTIONS(2490),
    [anon_sym___leave] = ACTIONS(2490),
    [anon_sym_not] = ACTIONS(2490),
    [anon_sym_compl] = ACTIONS(2490),
    [anon_sym_DASH_DASH] = ACTIONS(2492),
    [anon_sym_PLUS_PLUS] = ACTIONS(2492),
    [anon_sym_sizeof] = ACTIONS(2490),
    [anon_sym___alignof__] = ACTIONS(2490),
    [anon_sym___alignof] = ACTIONS(2490),
    [anon_sym__alignof] = ACTIONS(2490),
    [anon_sym_alignof] = ACTIONS(2490),
    [anon_sym__Alignof] = ACTIONS(2490),
    [anon_sym_offsetof] = ACTIONS(2490),
    [anon_sym__Generic] = ACTIONS(2490),
    [anon_sym_asm] = ACTIONS(2490),
    [anon_sym___asm__] = ACTIONS(2490),
    [sym_number_literal] = ACTIONS(2492),
    [anon_sym_L_SQUOTE] = ACTIONS(2492),
    [anon_sym_u_SQUOTE] = ACTIONS(2492),
    [anon_sym_U_SQUOTE] = ACTIONS(2492),
    [anon_sym_u8_SQUOTE] = ACTIONS(2492),
    [anon_sym_SQUOTE] = ACTIONS(2492),
    [anon_sym_L_DQUOTE] = ACTIONS(2492),
    [anon_sym_u_DQUOTE] = ACTIONS(2492),
    [anon_sym_U_DQUOTE] = ACTIONS(2492),
    [anon_sym_u8_DQUOTE] = ACTIONS(2492),
    [anon_sym_DQUOTE] = ACTIONS(2492),
    [sym_true] = ACTIONS(2490),
    [sym_false] = ACTIONS(2490),
    [anon_sym_NULL] = ACTIONS(2490),
    [anon_sym_nullptr] = ACTIONS(2490),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2490),
    [anon_sym_decltype] = ACTIONS(2490),
    [sym_virtual] = ACTIONS(2490),
    [anon_sym_explicit] = ACTIONS(2490),
    [anon_sym_typename] = ACTIONS(2490),
    [anon_sym_template] = ACTIONS(2490),
    [anon_sym_operator] = ACTIONS(2490),
    [anon_sym_try] = ACTIONS(2490),
    [anon_sym_delete] = ACTIONS(2490),
    [anon_sym_throw] = ACTIONS(2490),
    [anon_sym_namespace] = ACTIONS(2490),
    [anon_sym_using] = ACTIONS(2490),
    [anon_sym_static_assert] = ACTIONS(2490),
    [anon_sym_concept] = ACTIONS(2490),
    [anon_sym_co_return] = ACTIONS(2490),
    [anon_sym_co_yield] = ACTIONS(2490),
    [anon_sym_R_DQUOTE] = ACTIONS(2492),
    [anon_sym_LR_DQUOTE] = ACTIONS(2492),
    [anon_sym_uR_DQUOTE] = ACTIONS(2492),
    [anon_sym_UR_DQUOTE] = ACTIONS(2492),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2492),
    [anon_sym_co_await] = ACTIONS(2490),
    [anon_sym_new] = ACTIONS(2490),
    [anon_sym_requires] = ACTIONS(2490),
    [sym_this] = ACTIONS(2490),
    [anon_sym_discard] = ACTIONS(2490),
    [anon_sym_precise] = ACTIONS(2490),
    [anon_sym_shared] = ACTIONS(2490),
    [anon_sym_groupshared] = ACTIONS(2490),
    [anon_sym_uniform] = ACTIONS(2490),
    [anon_sym_row_major] = ACTIONS(2490),
    [anon_sym_column_major] = ACTIONS(2490),
    [anon_sym_globallycoherent] = ACTIONS(2490),
    [anon_sym_centroid] = ACTIONS(2490),
    [anon_sym_noperspective] = ACTIONS(2490),
    [anon_sym_nointerpolation] = ACTIONS(2490),
    [anon_sym_sample] = ACTIONS(2490),
    [anon_sym_linear] = ACTIONS(2490),
    [anon_sym_snorm] = ACTIONS(2490),
    [anon_sym_unorm] = ACTIONS(2490),
    [anon_sym_point] = ACTIONS(2490),
    [anon_sym_line] = ACTIONS(2490),
    [anon_sym_triangleadj] = ACTIONS(2490),
    [anon_sym_lineadj] = ACTIONS(2490),
    [anon_sym_triangle] = ACTIONS(2490),
    [anon_sym_cbuffer] = ACTIONS(2490),
  },
  [622] = {
    [sym_identifier] = ACTIONS(2458),
    [aux_sym_preproc_include_token1] = ACTIONS(2458),
    [aux_sym_preproc_def_token1] = ACTIONS(2458),
    [aux_sym_preproc_if_token1] = ACTIONS(2458),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2458),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2458),
    [sym_preproc_directive] = ACTIONS(2458),
    [anon_sym_LPAREN2] = ACTIONS(2460),
    [anon_sym_BANG] = ACTIONS(2460),
    [anon_sym_TILDE] = ACTIONS(2460),
    [anon_sym_DASH] = ACTIONS(2458),
    [anon_sym_PLUS] = ACTIONS(2458),
    [anon_sym_STAR] = ACTIONS(2460),
    [anon_sym_AMP_AMP] = ACTIONS(2460),
    [anon_sym_AMP] = ACTIONS(2458),
    [anon_sym_SEMI] = ACTIONS(2460),
    [anon_sym___extension__] = ACTIONS(2458),
    [anon_sym_typedef] = ACTIONS(2458),
    [anon_sym_in] = ACTIONS(2458),
    [anon_sym_out] = ACTIONS(2458),
    [anon_sym_inout] = ACTIONS(2458),
    [anon_sym_extern] = ACTIONS(2458),
    [anon_sym___attribute__] = ACTIONS(2458),
    [anon_sym_COLON_COLON] = ACTIONS(2460),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2460),
    [anon_sym___declspec] = ACTIONS(2458),
    [anon_sym___based] = ACTIONS(2458),
    [anon_sym___cdecl] = ACTIONS(2458),
    [anon_sym___clrcall] = ACTIONS(2458),
    [anon_sym___stdcall] = ACTIONS(2458),
    [anon_sym___fastcall] = ACTIONS(2458),
    [anon_sym___thiscall] = ACTIONS(2458),
    [anon_sym___vectorcall] = ACTIONS(2458),
    [anon_sym_LBRACE] = ACTIONS(2460),
    [anon_sym_RBRACE] = ACTIONS(2460),
    [anon_sym_signed] = ACTIONS(2458),
    [anon_sym_unsigned] = ACTIONS(2458),
    [anon_sym_long] = ACTIONS(2458),
    [anon_sym_short] = ACTIONS(2458),
    [anon_sym_LBRACK] = ACTIONS(2458),
    [anon_sym_static] = ACTIONS(2458),
    [anon_sym_register] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(2458),
    [anon_sym___inline] = ACTIONS(2458),
    [anon_sym___inline__] = ACTIONS(2458),
    [anon_sym___forceinline] = ACTIONS(2458),
    [anon_sym_thread_local] = ACTIONS(2458),
    [anon_sym___thread] = ACTIONS(2458),
    [anon_sym_const] = ACTIONS(2458),
    [anon_sym_constexpr] = ACTIONS(2458),
    [anon_sym_volatile] = ACTIONS(2458),
    [anon_sym_restrict] = ACTIONS(2458),
    [anon_sym___restrict__] = ACTIONS(2458),
    [anon_sym__Atomic] = ACTIONS(2458),
    [anon_sym__Noreturn] = ACTIONS(2458),
    [anon_sym_noreturn] = ACTIONS(2458),
    [anon_sym_mutable] = ACTIONS(2458),
    [anon_sym_constinit] = ACTIONS(2458),
    [anon_sym_consteval] = ACTIONS(2458),
    [anon_sym_alignas] = ACTIONS(2458),
    [anon_sym__Alignas] = ACTIONS(2458),
    [sym_primitive_type] = ACTIONS(2458),
    [anon_sym_enum] = ACTIONS(2458),
    [anon_sym_class] = ACTIONS(2458),
    [anon_sym_struct] = ACTIONS(2458),
    [anon_sym_union] = ACTIONS(2458),
    [anon_sym_if] = ACTIONS(2458),
    [anon_sym_switch] = ACTIONS(2458),
    [anon_sym_case] = ACTIONS(2458),
    [anon_sym_default] = ACTIONS(2458),
    [anon_sym_while] = ACTIONS(2458),
    [anon_sym_do] = ACTIONS(2458),
    [anon_sym_for] = ACTIONS(2458),
    [anon_sym_return] = ACTIONS(2458),
    [anon_sym_break] = ACTIONS(2458),
    [anon_sym_continue] = ACTIONS(2458),
    [anon_sym_goto] = ACTIONS(2458),
    [anon_sym___try] = ACTIONS(2458),
    [anon_sym___leave] = ACTIONS(2458),
    [anon_sym_not] = ACTIONS(2458),
    [anon_sym_compl] = ACTIONS(2458),
    [anon_sym_DASH_DASH] = ACTIONS(2460),
    [anon_sym_PLUS_PLUS] = ACTIONS(2460),
    [anon_sym_sizeof] = ACTIONS(2458),
    [anon_sym___alignof__] = ACTIONS(2458),
    [anon_sym___alignof] = ACTIONS(2458),
    [anon_sym__alignof] = ACTIONS(2458),
    [anon_sym_alignof] = ACTIONS(2458),
    [anon_sym__Alignof] = ACTIONS(2458),
    [anon_sym_offsetof] = ACTIONS(2458),
    [anon_sym__Generic] = ACTIONS(2458),
    [anon_sym_asm] = ACTIONS(2458),
    [anon_sym___asm__] = ACTIONS(2458),
    [sym_number_literal] = ACTIONS(2460),
    [anon_sym_L_SQUOTE] = ACTIONS(2460),
    [anon_sym_u_SQUOTE] = ACTIONS(2460),
    [anon_sym_U_SQUOTE] = ACTIONS(2460),
    [anon_sym_u8_SQUOTE] = ACTIONS(2460),
    [anon_sym_SQUOTE] = ACTIONS(2460),
    [anon_sym_L_DQUOTE] = ACTIONS(2460),
    [anon_sym_u_DQUOTE] = ACTIONS(2460),
    [anon_sym_U_DQUOTE] = ACTIONS(2460),
    [anon_sym_u8_DQUOTE] = ACTIONS(2460),
    [anon_sym_DQUOTE] = ACTIONS(2460),
    [sym_true] = ACTIONS(2458),
    [sym_false] = ACTIONS(2458),
    [anon_sym_NULL] = ACTIONS(2458),
    [anon_sym_nullptr] = ACTIONS(2458),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2458),
    [anon_sym_decltype] = ACTIONS(2458),
    [sym_virtual] = ACTIONS(2458),
    [anon_sym_explicit] = ACTIONS(2458),
    [anon_sym_typename] = ACTIONS(2458),
    [anon_sym_template] = ACTIONS(2458),
    [anon_sym_operator] = ACTIONS(2458),
    [anon_sym_try] = ACTIONS(2458),
    [anon_sym_delete] = ACTIONS(2458),
    [anon_sym_throw] = ACTIONS(2458),
    [anon_sym_namespace] = ACTIONS(2458),
    [anon_sym_using] = ACTIONS(2458),
    [anon_sym_static_assert] = ACTIONS(2458),
    [anon_sym_concept] = ACTIONS(2458),
    [anon_sym_co_return] = ACTIONS(2458),
    [anon_sym_co_yield] = ACTIONS(2458),
    [anon_sym_R_DQUOTE] = ACTIONS(2460),
    [anon_sym_LR_DQUOTE] = ACTIONS(2460),
    [anon_sym_uR_DQUOTE] = ACTIONS(2460),
    [anon_sym_UR_DQUOTE] = ACTIONS(2460),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2460),
    [anon_sym_co_await] = ACTIONS(2458),
    [anon_sym_new] = ACTIONS(2458),
    [anon_sym_requires] = ACTIONS(2458),
    [sym_this] = ACTIONS(2458),
    [anon_sym_discard] = ACTIONS(2458),
    [anon_sym_precise] = ACTIONS(2458),
    [anon_sym_shared] = ACTIONS(2458),
    [anon_sym_groupshared] = ACTIONS(2458),
    [anon_sym_uniform] = ACTIONS(2458),
    [anon_sym_row_major] = ACTIONS(2458),
    [anon_sym_column_major] = ACTIONS(2458),
    [anon_sym_globallycoherent] = ACTIONS(2458),
    [anon_sym_centroid] = ACTIONS(2458),
    [anon_sym_noperspective] = ACTIONS(2458),
    [anon_sym_nointerpolation] = ACTIONS(2458),
    [anon_sym_sample] = ACTIONS(2458),
    [anon_sym_linear] = ACTIONS(2458),
    [anon_sym_snorm] = ACTIONS(2458),
    [anon_sym_unorm] = ACTIONS(2458),
    [anon_sym_point] = ACTIONS(2458),
    [anon_sym_line] = ACTIONS(2458),
    [anon_sym_triangleadj] = ACTIONS(2458),
    [anon_sym_lineadj] = ACTIONS(2458),
    [anon_sym_triangle] = ACTIONS(2458),
    [anon_sym_cbuffer] = ACTIONS(2458),
  },
  [623] = {
    [sym_identifier] = ACTIONS(2292),
    [aux_sym_preproc_include_token1] = ACTIONS(2292),
    [aux_sym_preproc_def_token1] = ACTIONS(2292),
    [aux_sym_preproc_if_token1] = ACTIONS(2292),
    [aux_sym_preproc_if_token2] = ACTIONS(2292),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2292),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2292),
    [sym_preproc_directive] = ACTIONS(2292),
    [anon_sym_LPAREN2] = ACTIONS(2294),
    [anon_sym_BANG] = ACTIONS(2294),
    [anon_sym_TILDE] = ACTIONS(2294),
    [anon_sym_DASH] = ACTIONS(2292),
    [anon_sym_PLUS] = ACTIONS(2292),
    [anon_sym_STAR] = ACTIONS(2294),
    [anon_sym_AMP_AMP] = ACTIONS(2294),
    [anon_sym_AMP] = ACTIONS(2292),
    [anon_sym_SEMI] = ACTIONS(2294),
    [anon_sym___extension__] = ACTIONS(2292),
    [anon_sym_typedef] = ACTIONS(2292),
    [anon_sym_in] = ACTIONS(2292),
    [anon_sym_out] = ACTIONS(2292),
    [anon_sym_inout] = ACTIONS(2292),
    [anon_sym_extern] = ACTIONS(2292),
    [anon_sym___attribute__] = ACTIONS(2292),
    [anon_sym_COLON_COLON] = ACTIONS(2294),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2294),
    [anon_sym___declspec] = ACTIONS(2292),
    [anon_sym___based] = ACTIONS(2292),
    [anon_sym___cdecl] = ACTIONS(2292),
    [anon_sym___clrcall] = ACTIONS(2292),
    [anon_sym___stdcall] = ACTIONS(2292),
    [anon_sym___fastcall] = ACTIONS(2292),
    [anon_sym___thiscall] = ACTIONS(2292),
    [anon_sym___vectorcall] = ACTIONS(2292),
    [anon_sym_LBRACE] = ACTIONS(2294),
    [anon_sym_signed] = ACTIONS(2292),
    [anon_sym_unsigned] = ACTIONS(2292),
    [anon_sym_long] = ACTIONS(2292),
    [anon_sym_short] = ACTIONS(2292),
    [anon_sym_LBRACK] = ACTIONS(2292),
    [anon_sym_static] = ACTIONS(2292),
    [anon_sym_register] = ACTIONS(2292),
    [anon_sym_inline] = ACTIONS(2292),
    [anon_sym___inline] = ACTIONS(2292),
    [anon_sym___inline__] = ACTIONS(2292),
    [anon_sym___forceinline] = ACTIONS(2292),
    [anon_sym_thread_local] = ACTIONS(2292),
    [anon_sym___thread] = ACTIONS(2292),
    [anon_sym_const] = ACTIONS(2292),
    [anon_sym_constexpr] = ACTIONS(2292),
    [anon_sym_volatile] = ACTIONS(2292),
    [anon_sym_restrict] = ACTIONS(2292),
    [anon_sym___restrict__] = ACTIONS(2292),
    [anon_sym__Atomic] = ACTIONS(2292),
    [anon_sym__Noreturn] = ACTIONS(2292),
    [anon_sym_noreturn] = ACTIONS(2292),
    [anon_sym_mutable] = ACTIONS(2292),
    [anon_sym_constinit] = ACTIONS(2292),
    [anon_sym_consteval] = ACTIONS(2292),
    [anon_sym_alignas] = ACTIONS(2292),
    [anon_sym__Alignas] = ACTIONS(2292),
    [sym_primitive_type] = ACTIONS(2292),
    [anon_sym_enum] = ACTIONS(2292),
    [anon_sym_class] = ACTIONS(2292),
    [anon_sym_struct] = ACTIONS(2292),
    [anon_sym_union] = ACTIONS(2292),
    [anon_sym_if] = ACTIONS(2292),
    [anon_sym_switch] = ACTIONS(2292),
    [anon_sym_case] = ACTIONS(2292),
    [anon_sym_default] = ACTIONS(2292),
    [anon_sym_while] = ACTIONS(2292),
    [anon_sym_do] = ACTIONS(2292),
    [anon_sym_for] = ACTIONS(2292),
    [anon_sym_return] = ACTIONS(2292),
    [anon_sym_break] = ACTIONS(2292),
    [anon_sym_continue] = ACTIONS(2292),
    [anon_sym_goto] = ACTIONS(2292),
    [anon_sym___try] = ACTIONS(2292),
    [anon_sym___leave] = ACTIONS(2292),
    [anon_sym_not] = ACTIONS(2292),
    [anon_sym_compl] = ACTIONS(2292),
    [anon_sym_DASH_DASH] = ACTIONS(2294),
    [anon_sym_PLUS_PLUS] = ACTIONS(2294),
    [anon_sym_sizeof] = ACTIONS(2292),
    [anon_sym___alignof__] = ACTIONS(2292),
    [anon_sym___alignof] = ACTIONS(2292),
    [anon_sym__alignof] = ACTIONS(2292),
    [anon_sym_alignof] = ACTIONS(2292),
    [anon_sym__Alignof] = ACTIONS(2292),
    [anon_sym_offsetof] = ACTIONS(2292),
    [anon_sym__Generic] = ACTIONS(2292),
    [anon_sym_asm] = ACTIONS(2292),
    [anon_sym___asm__] = ACTIONS(2292),
    [sym_number_literal] = ACTIONS(2294),
    [anon_sym_L_SQUOTE] = ACTIONS(2294),
    [anon_sym_u_SQUOTE] = ACTIONS(2294),
    [anon_sym_U_SQUOTE] = ACTIONS(2294),
    [anon_sym_u8_SQUOTE] = ACTIONS(2294),
    [anon_sym_SQUOTE] = ACTIONS(2294),
    [anon_sym_L_DQUOTE] = ACTIONS(2294),
    [anon_sym_u_DQUOTE] = ACTIONS(2294),
    [anon_sym_U_DQUOTE] = ACTIONS(2294),
    [anon_sym_u8_DQUOTE] = ACTIONS(2294),
    [anon_sym_DQUOTE] = ACTIONS(2294),
    [sym_true] = ACTIONS(2292),
    [sym_false] = ACTIONS(2292),
    [anon_sym_NULL] = ACTIONS(2292),
    [anon_sym_nullptr] = ACTIONS(2292),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2292),
    [anon_sym_decltype] = ACTIONS(2292),
    [sym_virtual] = ACTIONS(2292),
    [anon_sym_explicit] = ACTIONS(2292),
    [anon_sym_typename] = ACTIONS(2292),
    [anon_sym_template] = ACTIONS(2292),
    [anon_sym_operator] = ACTIONS(2292),
    [anon_sym_try] = ACTIONS(2292),
    [anon_sym_delete] = ACTIONS(2292),
    [anon_sym_throw] = ACTIONS(2292),
    [anon_sym_namespace] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(2292),
    [anon_sym_static_assert] = ACTIONS(2292),
    [anon_sym_concept] = ACTIONS(2292),
    [anon_sym_co_return] = ACTIONS(2292),
    [anon_sym_co_yield] = ACTIONS(2292),
    [anon_sym_R_DQUOTE] = ACTIONS(2294),
    [anon_sym_LR_DQUOTE] = ACTIONS(2294),
    [anon_sym_uR_DQUOTE] = ACTIONS(2294),
    [anon_sym_UR_DQUOTE] = ACTIONS(2294),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2294),
    [anon_sym_co_await] = ACTIONS(2292),
    [anon_sym_new] = ACTIONS(2292),
    [anon_sym_requires] = ACTIONS(2292),
    [sym_this] = ACTIONS(2292),
    [anon_sym_discard] = ACTIONS(2292),
    [anon_sym_precise] = ACTIONS(2292),
    [anon_sym_shared] = ACTIONS(2292),
    [anon_sym_groupshared] = ACTIONS(2292),
    [anon_sym_uniform] = ACTIONS(2292),
    [anon_sym_row_major] = ACTIONS(2292),
    [anon_sym_column_major] = ACTIONS(2292),
    [anon_sym_globallycoherent] = ACTIONS(2292),
    [anon_sym_centroid] = ACTIONS(2292),
    [anon_sym_noperspective] = ACTIONS(2292),
    [anon_sym_nointerpolation] = ACTIONS(2292),
    [anon_sym_sample] = ACTIONS(2292),
    [anon_sym_linear] = ACTIONS(2292),
    [anon_sym_snorm] = ACTIONS(2292),
    [anon_sym_unorm] = ACTIONS(2292),
    [anon_sym_point] = ACTIONS(2292),
    [anon_sym_line] = ACTIONS(2292),
    [anon_sym_triangleadj] = ACTIONS(2292),
    [anon_sym_lineadj] = ACTIONS(2292),
    [anon_sym_triangle] = ACTIONS(2292),
    [anon_sym_cbuffer] = ACTIONS(2292),
  },
  [624] = {
    [sym_identifier] = ACTIONS(2549),
    [aux_sym_preproc_include_token1] = ACTIONS(2549),
    [aux_sym_preproc_def_token1] = ACTIONS(2549),
    [aux_sym_preproc_if_token1] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2549),
    [sym_preproc_directive] = ACTIONS(2549),
    [anon_sym_LPAREN2] = ACTIONS(2551),
    [anon_sym_BANG] = ACTIONS(2551),
    [anon_sym_TILDE] = ACTIONS(2551),
    [anon_sym_DASH] = ACTIONS(2549),
    [anon_sym_PLUS] = ACTIONS(2549),
    [anon_sym_STAR] = ACTIONS(2551),
    [anon_sym_AMP_AMP] = ACTIONS(2551),
    [anon_sym_AMP] = ACTIONS(2549),
    [anon_sym_SEMI] = ACTIONS(2551),
    [anon_sym___extension__] = ACTIONS(2549),
    [anon_sym_typedef] = ACTIONS(2549),
    [anon_sym_in] = ACTIONS(2549),
    [anon_sym_out] = ACTIONS(2549),
    [anon_sym_inout] = ACTIONS(2549),
    [anon_sym_extern] = ACTIONS(2549),
    [anon_sym___attribute__] = ACTIONS(2549),
    [anon_sym_COLON_COLON] = ACTIONS(2551),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2551),
    [anon_sym___declspec] = ACTIONS(2549),
    [anon_sym___based] = ACTIONS(2549),
    [anon_sym___cdecl] = ACTIONS(2549),
    [anon_sym___clrcall] = ACTIONS(2549),
    [anon_sym___stdcall] = ACTIONS(2549),
    [anon_sym___fastcall] = ACTIONS(2549),
    [anon_sym___thiscall] = ACTIONS(2549),
    [anon_sym___vectorcall] = ACTIONS(2549),
    [anon_sym_LBRACE] = ACTIONS(2551),
    [anon_sym_RBRACE] = ACTIONS(2551),
    [anon_sym_signed] = ACTIONS(2549),
    [anon_sym_unsigned] = ACTIONS(2549),
    [anon_sym_long] = ACTIONS(2549),
    [anon_sym_short] = ACTIONS(2549),
    [anon_sym_LBRACK] = ACTIONS(2549),
    [anon_sym_static] = ACTIONS(2549),
    [anon_sym_register] = ACTIONS(2549),
    [anon_sym_inline] = ACTIONS(2549),
    [anon_sym___inline] = ACTIONS(2549),
    [anon_sym___inline__] = ACTIONS(2549),
    [anon_sym___forceinline] = ACTIONS(2549),
    [anon_sym_thread_local] = ACTIONS(2549),
    [anon_sym___thread] = ACTIONS(2549),
    [anon_sym_const] = ACTIONS(2549),
    [anon_sym_constexpr] = ACTIONS(2549),
    [anon_sym_volatile] = ACTIONS(2549),
    [anon_sym_restrict] = ACTIONS(2549),
    [anon_sym___restrict__] = ACTIONS(2549),
    [anon_sym__Atomic] = ACTIONS(2549),
    [anon_sym__Noreturn] = ACTIONS(2549),
    [anon_sym_noreturn] = ACTIONS(2549),
    [anon_sym_mutable] = ACTIONS(2549),
    [anon_sym_constinit] = ACTIONS(2549),
    [anon_sym_consteval] = ACTIONS(2549),
    [anon_sym_alignas] = ACTIONS(2549),
    [anon_sym__Alignas] = ACTIONS(2549),
    [sym_primitive_type] = ACTIONS(2549),
    [anon_sym_enum] = ACTIONS(2549),
    [anon_sym_class] = ACTIONS(2549),
    [anon_sym_struct] = ACTIONS(2549),
    [anon_sym_union] = ACTIONS(2549),
    [anon_sym_if] = ACTIONS(2549),
    [anon_sym_switch] = ACTIONS(2549),
    [anon_sym_case] = ACTIONS(2549),
    [anon_sym_default] = ACTIONS(2549),
    [anon_sym_while] = ACTIONS(2549),
    [anon_sym_do] = ACTIONS(2549),
    [anon_sym_for] = ACTIONS(2549),
    [anon_sym_return] = ACTIONS(2549),
    [anon_sym_break] = ACTIONS(2549),
    [anon_sym_continue] = ACTIONS(2549),
    [anon_sym_goto] = ACTIONS(2549),
    [anon_sym___try] = ACTIONS(2549),
    [anon_sym___leave] = ACTIONS(2549),
    [anon_sym_not] = ACTIONS(2549),
    [anon_sym_compl] = ACTIONS(2549),
    [anon_sym_DASH_DASH] = ACTIONS(2551),
    [anon_sym_PLUS_PLUS] = ACTIONS(2551),
    [anon_sym_sizeof] = ACTIONS(2549),
    [anon_sym___alignof__] = ACTIONS(2549),
    [anon_sym___alignof] = ACTIONS(2549),
    [anon_sym__alignof] = ACTIONS(2549),
    [anon_sym_alignof] = ACTIONS(2549),
    [anon_sym__Alignof] = ACTIONS(2549),
    [anon_sym_offsetof] = ACTIONS(2549),
    [anon_sym__Generic] = ACTIONS(2549),
    [anon_sym_asm] = ACTIONS(2549),
    [anon_sym___asm__] = ACTIONS(2549),
    [sym_number_literal] = ACTIONS(2551),
    [anon_sym_L_SQUOTE] = ACTIONS(2551),
    [anon_sym_u_SQUOTE] = ACTIONS(2551),
    [anon_sym_U_SQUOTE] = ACTIONS(2551),
    [anon_sym_u8_SQUOTE] = ACTIONS(2551),
    [anon_sym_SQUOTE] = ACTIONS(2551),
    [anon_sym_L_DQUOTE] = ACTIONS(2551),
    [anon_sym_u_DQUOTE] = ACTIONS(2551),
    [anon_sym_U_DQUOTE] = ACTIONS(2551),
    [anon_sym_u8_DQUOTE] = ACTIONS(2551),
    [anon_sym_DQUOTE] = ACTIONS(2551),
    [sym_true] = ACTIONS(2549),
    [sym_false] = ACTIONS(2549),
    [anon_sym_NULL] = ACTIONS(2549),
    [anon_sym_nullptr] = ACTIONS(2549),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2549),
    [anon_sym_decltype] = ACTIONS(2549),
    [sym_virtual] = ACTIONS(2549),
    [anon_sym_explicit] = ACTIONS(2549),
    [anon_sym_typename] = ACTIONS(2549),
    [anon_sym_template] = ACTIONS(2549),
    [anon_sym_operator] = ACTIONS(2549),
    [anon_sym_try] = ACTIONS(2549),
    [anon_sym_delete] = ACTIONS(2549),
    [anon_sym_throw] = ACTIONS(2549),
    [anon_sym_namespace] = ACTIONS(2549),
    [anon_sym_using] = ACTIONS(2549),
    [anon_sym_static_assert] = ACTIONS(2549),
    [anon_sym_concept] = ACTIONS(2549),
    [anon_sym_co_return] = ACTIONS(2549),
    [anon_sym_co_yield] = ACTIONS(2549),
    [anon_sym_R_DQUOTE] = ACTIONS(2551),
    [anon_sym_LR_DQUOTE] = ACTIONS(2551),
    [anon_sym_uR_DQUOTE] = ACTIONS(2551),
    [anon_sym_UR_DQUOTE] = ACTIONS(2551),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2551),
    [anon_sym_co_await] = ACTIONS(2549),
    [anon_sym_new] = ACTIONS(2549),
    [anon_sym_requires] = ACTIONS(2549),
    [sym_this] = ACTIONS(2549),
    [anon_sym_discard] = ACTIONS(2549),
    [anon_sym_precise] = ACTIONS(2549),
    [anon_sym_shared] = ACTIONS(2549),
    [anon_sym_groupshared] = ACTIONS(2549),
    [anon_sym_uniform] = ACTIONS(2549),
    [anon_sym_row_major] = ACTIONS(2549),
    [anon_sym_column_major] = ACTIONS(2549),
    [anon_sym_globallycoherent] = ACTIONS(2549),
    [anon_sym_centroid] = ACTIONS(2549),
    [anon_sym_noperspective] = ACTIONS(2549),
    [anon_sym_nointerpolation] = ACTIONS(2549),
    [anon_sym_sample] = ACTIONS(2549),
    [anon_sym_linear] = ACTIONS(2549),
    [anon_sym_snorm] = ACTIONS(2549),
    [anon_sym_unorm] = ACTIONS(2549),
    [anon_sym_point] = ACTIONS(2549),
    [anon_sym_line] = ACTIONS(2549),
    [anon_sym_triangleadj] = ACTIONS(2549),
    [anon_sym_lineadj] = ACTIONS(2549),
    [anon_sym_triangle] = ACTIONS(2549),
    [anon_sym_cbuffer] = ACTIONS(2549),
  },
  [625] = {
    [sym_identifier] = ACTIONS(2540),
    [aux_sym_preproc_include_token1] = ACTIONS(2540),
    [aux_sym_preproc_def_token1] = ACTIONS(2540),
    [aux_sym_preproc_if_token1] = ACTIONS(2540),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2540),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2540),
    [sym_preproc_directive] = ACTIONS(2540),
    [anon_sym_LPAREN2] = ACTIONS(2542),
    [anon_sym_BANG] = ACTIONS(2542),
    [anon_sym_TILDE] = ACTIONS(2542),
    [anon_sym_DASH] = ACTIONS(2540),
    [anon_sym_PLUS] = ACTIONS(2540),
    [anon_sym_STAR] = ACTIONS(2542),
    [anon_sym_AMP_AMP] = ACTIONS(2542),
    [anon_sym_AMP] = ACTIONS(2540),
    [anon_sym_SEMI] = ACTIONS(2542),
    [anon_sym___extension__] = ACTIONS(2540),
    [anon_sym_typedef] = ACTIONS(2540),
    [anon_sym_in] = ACTIONS(2540),
    [anon_sym_out] = ACTIONS(2540),
    [anon_sym_inout] = ACTIONS(2540),
    [anon_sym_extern] = ACTIONS(2540),
    [anon_sym___attribute__] = ACTIONS(2540),
    [anon_sym_COLON_COLON] = ACTIONS(2542),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2542),
    [anon_sym___declspec] = ACTIONS(2540),
    [anon_sym___based] = ACTIONS(2540),
    [anon_sym___cdecl] = ACTIONS(2540),
    [anon_sym___clrcall] = ACTIONS(2540),
    [anon_sym___stdcall] = ACTIONS(2540),
    [anon_sym___fastcall] = ACTIONS(2540),
    [anon_sym___thiscall] = ACTIONS(2540),
    [anon_sym___vectorcall] = ACTIONS(2540),
    [anon_sym_LBRACE] = ACTIONS(2542),
    [anon_sym_RBRACE] = ACTIONS(2542),
    [anon_sym_signed] = ACTIONS(2540),
    [anon_sym_unsigned] = ACTIONS(2540),
    [anon_sym_long] = ACTIONS(2540),
    [anon_sym_short] = ACTIONS(2540),
    [anon_sym_LBRACK] = ACTIONS(2540),
    [anon_sym_static] = ACTIONS(2540),
    [anon_sym_register] = ACTIONS(2540),
    [anon_sym_inline] = ACTIONS(2540),
    [anon_sym___inline] = ACTIONS(2540),
    [anon_sym___inline__] = ACTIONS(2540),
    [anon_sym___forceinline] = ACTIONS(2540),
    [anon_sym_thread_local] = ACTIONS(2540),
    [anon_sym___thread] = ACTIONS(2540),
    [anon_sym_const] = ACTIONS(2540),
    [anon_sym_constexpr] = ACTIONS(2540),
    [anon_sym_volatile] = ACTIONS(2540),
    [anon_sym_restrict] = ACTIONS(2540),
    [anon_sym___restrict__] = ACTIONS(2540),
    [anon_sym__Atomic] = ACTIONS(2540),
    [anon_sym__Noreturn] = ACTIONS(2540),
    [anon_sym_noreturn] = ACTIONS(2540),
    [anon_sym_mutable] = ACTIONS(2540),
    [anon_sym_constinit] = ACTIONS(2540),
    [anon_sym_consteval] = ACTIONS(2540),
    [anon_sym_alignas] = ACTIONS(2540),
    [anon_sym__Alignas] = ACTIONS(2540),
    [sym_primitive_type] = ACTIONS(2540),
    [anon_sym_enum] = ACTIONS(2540),
    [anon_sym_class] = ACTIONS(2540),
    [anon_sym_struct] = ACTIONS(2540),
    [anon_sym_union] = ACTIONS(2540),
    [anon_sym_if] = ACTIONS(2540),
    [anon_sym_switch] = ACTIONS(2540),
    [anon_sym_case] = ACTIONS(2540),
    [anon_sym_default] = ACTIONS(2540),
    [anon_sym_while] = ACTIONS(2540),
    [anon_sym_do] = ACTIONS(2540),
    [anon_sym_for] = ACTIONS(2540),
    [anon_sym_return] = ACTIONS(2540),
    [anon_sym_break] = ACTIONS(2540),
    [anon_sym_continue] = ACTIONS(2540),
    [anon_sym_goto] = ACTIONS(2540),
    [anon_sym___try] = ACTIONS(2540),
    [anon_sym___leave] = ACTIONS(2540),
    [anon_sym_not] = ACTIONS(2540),
    [anon_sym_compl] = ACTIONS(2540),
    [anon_sym_DASH_DASH] = ACTIONS(2542),
    [anon_sym_PLUS_PLUS] = ACTIONS(2542),
    [anon_sym_sizeof] = ACTIONS(2540),
    [anon_sym___alignof__] = ACTIONS(2540),
    [anon_sym___alignof] = ACTIONS(2540),
    [anon_sym__alignof] = ACTIONS(2540),
    [anon_sym_alignof] = ACTIONS(2540),
    [anon_sym__Alignof] = ACTIONS(2540),
    [anon_sym_offsetof] = ACTIONS(2540),
    [anon_sym__Generic] = ACTIONS(2540),
    [anon_sym_asm] = ACTIONS(2540),
    [anon_sym___asm__] = ACTIONS(2540),
    [sym_number_literal] = ACTIONS(2542),
    [anon_sym_L_SQUOTE] = ACTIONS(2542),
    [anon_sym_u_SQUOTE] = ACTIONS(2542),
    [anon_sym_U_SQUOTE] = ACTIONS(2542),
    [anon_sym_u8_SQUOTE] = ACTIONS(2542),
    [anon_sym_SQUOTE] = ACTIONS(2542),
    [anon_sym_L_DQUOTE] = ACTIONS(2542),
    [anon_sym_u_DQUOTE] = ACTIONS(2542),
    [anon_sym_U_DQUOTE] = ACTIONS(2542),
    [anon_sym_u8_DQUOTE] = ACTIONS(2542),
    [anon_sym_DQUOTE] = ACTIONS(2542),
    [sym_true] = ACTIONS(2540),
    [sym_false] = ACTIONS(2540),
    [anon_sym_NULL] = ACTIONS(2540),
    [anon_sym_nullptr] = ACTIONS(2540),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2540),
    [anon_sym_decltype] = ACTIONS(2540),
    [sym_virtual] = ACTIONS(2540),
    [anon_sym_explicit] = ACTIONS(2540),
    [anon_sym_typename] = ACTIONS(2540),
    [anon_sym_template] = ACTIONS(2540),
    [anon_sym_operator] = ACTIONS(2540),
    [anon_sym_try] = ACTIONS(2540),
    [anon_sym_delete] = ACTIONS(2540),
    [anon_sym_throw] = ACTIONS(2540),
    [anon_sym_namespace] = ACTIONS(2540),
    [anon_sym_using] = ACTIONS(2540),
    [anon_sym_static_assert] = ACTIONS(2540),
    [anon_sym_concept] = ACTIONS(2540),
    [anon_sym_co_return] = ACTIONS(2540),
    [anon_sym_co_yield] = ACTIONS(2540),
    [anon_sym_R_DQUOTE] = ACTIONS(2542),
    [anon_sym_LR_DQUOTE] = ACTIONS(2542),
    [anon_sym_uR_DQUOTE] = ACTIONS(2542),
    [anon_sym_UR_DQUOTE] = ACTIONS(2542),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2542),
    [anon_sym_co_await] = ACTIONS(2540),
    [anon_sym_new] = ACTIONS(2540),
    [anon_sym_requires] = ACTIONS(2540),
    [sym_this] = ACTIONS(2540),
    [anon_sym_discard] = ACTIONS(2540),
    [anon_sym_precise] = ACTIONS(2540),
    [anon_sym_shared] = ACTIONS(2540),
    [anon_sym_groupshared] = ACTIONS(2540),
    [anon_sym_uniform] = ACTIONS(2540),
    [anon_sym_row_major] = ACTIONS(2540),
    [anon_sym_column_major] = ACTIONS(2540),
    [anon_sym_globallycoherent] = ACTIONS(2540),
    [anon_sym_centroid] = ACTIONS(2540),
    [anon_sym_noperspective] = ACTIONS(2540),
    [anon_sym_nointerpolation] = ACTIONS(2540),
    [anon_sym_sample] = ACTIONS(2540),
    [anon_sym_linear] = ACTIONS(2540),
    [anon_sym_snorm] = ACTIONS(2540),
    [anon_sym_unorm] = ACTIONS(2540),
    [anon_sym_point] = ACTIONS(2540),
    [anon_sym_line] = ACTIONS(2540),
    [anon_sym_triangleadj] = ACTIONS(2540),
    [anon_sym_lineadj] = ACTIONS(2540),
    [anon_sym_triangle] = ACTIONS(2540),
    [anon_sym_cbuffer] = ACTIONS(2540),
  },
  [626] = {
    [sym_identifier] = ACTIONS(2328),
    [aux_sym_preproc_include_token1] = ACTIONS(2328),
    [aux_sym_preproc_def_token1] = ACTIONS(2328),
    [aux_sym_preproc_if_token1] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2328),
    [sym_preproc_directive] = ACTIONS(2328),
    [anon_sym_LPAREN2] = ACTIONS(2330),
    [anon_sym_BANG] = ACTIONS(2330),
    [anon_sym_TILDE] = ACTIONS(2330),
    [anon_sym_DASH] = ACTIONS(2328),
    [anon_sym_PLUS] = ACTIONS(2328),
    [anon_sym_STAR] = ACTIONS(2330),
    [anon_sym_AMP_AMP] = ACTIONS(2330),
    [anon_sym_AMP] = ACTIONS(2328),
    [anon_sym_SEMI] = ACTIONS(2330),
    [anon_sym___extension__] = ACTIONS(2328),
    [anon_sym_typedef] = ACTIONS(2328),
    [anon_sym_in] = ACTIONS(2328),
    [anon_sym_out] = ACTIONS(2328),
    [anon_sym_inout] = ACTIONS(2328),
    [anon_sym_extern] = ACTIONS(2328),
    [anon_sym___attribute__] = ACTIONS(2328),
    [anon_sym_COLON_COLON] = ACTIONS(2330),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2330),
    [anon_sym___declspec] = ACTIONS(2328),
    [anon_sym___based] = ACTIONS(2328),
    [anon_sym___cdecl] = ACTIONS(2328),
    [anon_sym___clrcall] = ACTIONS(2328),
    [anon_sym___stdcall] = ACTIONS(2328),
    [anon_sym___fastcall] = ACTIONS(2328),
    [anon_sym___thiscall] = ACTIONS(2328),
    [anon_sym___vectorcall] = ACTIONS(2328),
    [anon_sym_LBRACE] = ACTIONS(2330),
    [anon_sym_RBRACE] = ACTIONS(2330),
    [anon_sym_signed] = ACTIONS(2328),
    [anon_sym_unsigned] = ACTIONS(2328),
    [anon_sym_long] = ACTIONS(2328),
    [anon_sym_short] = ACTIONS(2328),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_static] = ACTIONS(2328),
    [anon_sym_register] = ACTIONS(2328),
    [anon_sym_inline] = ACTIONS(2328),
    [anon_sym___inline] = ACTIONS(2328),
    [anon_sym___inline__] = ACTIONS(2328),
    [anon_sym___forceinline] = ACTIONS(2328),
    [anon_sym_thread_local] = ACTIONS(2328),
    [anon_sym___thread] = ACTIONS(2328),
    [anon_sym_const] = ACTIONS(2328),
    [anon_sym_constexpr] = ACTIONS(2328),
    [anon_sym_volatile] = ACTIONS(2328),
    [anon_sym_restrict] = ACTIONS(2328),
    [anon_sym___restrict__] = ACTIONS(2328),
    [anon_sym__Atomic] = ACTIONS(2328),
    [anon_sym__Noreturn] = ACTIONS(2328),
    [anon_sym_noreturn] = ACTIONS(2328),
    [anon_sym_mutable] = ACTIONS(2328),
    [anon_sym_constinit] = ACTIONS(2328),
    [anon_sym_consteval] = ACTIONS(2328),
    [anon_sym_alignas] = ACTIONS(2328),
    [anon_sym__Alignas] = ACTIONS(2328),
    [sym_primitive_type] = ACTIONS(2328),
    [anon_sym_enum] = ACTIONS(2328),
    [anon_sym_class] = ACTIONS(2328),
    [anon_sym_struct] = ACTIONS(2328),
    [anon_sym_union] = ACTIONS(2328),
    [anon_sym_if] = ACTIONS(2328),
    [anon_sym_switch] = ACTIONS(2328),
    [anon_sym_case] = ACTIONS(2328),
    [anon_sym_default] = ACTIONS(2328),
    [anon_sym_while] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(2328),
    [anon_sym_for] = ACTIONS(2328),
    [anon_sym_return] = ACTIONS(2328),
    [anon_sym_break] = ACTIONS(2328),
    [anon_sym_continue] = ACTIONS(2328),
    [anon_sym_goto] = ACTIONS(2328),
    [anon_sym___try] = ACTIONS(2328),
    [anon_sym___leave] = ACTIONS(2328),
    [anon_sym_not] = ACTIONS(2328),
    [anon_sym_compl] = ACTIONS(2328),
    [anon_sym_DASH_DASH] = ACTIONS(2330),
    [anon_sym_PLUS_PLUS] = ACTIONS(2330),
    [anon_sym_sizeof] = ACTIONS(2328),
    [anon_sym___alignof__] = ACTIONS(2328),
    [anon_sym___alignof] = ACTIONS(2328),
    [anon_sym__alignof] = ACTIONS(2328),
    [anon_sym_alignof] = ACTIONS(2328),
    [anon_sym__Alignof] = ACTIONS(2328),
    [anon_sym_offsetof] = ACTIONS(2328),
    [anon_sym__Generic] = ACTIONS(2328),
    [anon_sym_asm] = ACTIONS(2328),
    [anon_sym___asm__] = ACTIONS(2328),
    [sym_number_literal] = ACTIONS(2330),
    [anon_sym_L_SQUOTE] = ACTIONS(2330),
    [anon_sym_u_SQUOTE] = ACTIONS(2330),
    [anon_sym_U_SQUOTE] = ACTIONS(2330),
    [anon_sym_u8_SQUOTE] = ACTIONS(2330),
    [anon_sym_SQUOTE] = ACTIONS(2330),
    [anon_sym_L_DQUOTE] = ACTIONS(2330),
    [anon_sym_u_DQUOTE] = ACTIONS(2330),
    [anon_sym_U_DQUOTE] = ACTIONS(2330),
    [anon_sym_u8_DQUOTE] = ACTIONS(2330),
    [anon_sym_DQUOTE] = ACTIONS(2330),
    [sym_true] = ACTIONS(2328),
    [sym_false] = ACTIONS(2328),
    [anon_sym_NULL] = ACTIONS(2328),
    [anon_sym_nullptr] = ACTIONS(2328),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2328),
    [anon_sym_decltype] = ACTIONS(2328),
    [sym_virtual] = ACTIONS(2328),
    [anon_sym_explicit] = ACTIONS(2328),
    [anon_sym_typename] = ACTIONS(2328),
    [anon_sym_template] = ACTIONS(2328),
    [anon_sym_operator] = ACTIONS(2328),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_delete] = ACTIONS(2328),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_namespace] = ACTIONS(2328),
    [anon_sym_using] = ACTIONS(2328),
    [anon_sym_static_assert] = ACTIONS(2328),
    [anon_sym_concept] = ACTIONS(2328),
    [anon_sym_co_return] = ACTIONS(2328),
    [anon_sym_co_yield] = ACTIONS(2328),
    [anon_sym_R_DQUOTE] = ACTIONS(2330),
    [anon_sym_LR_DQUOTE] = ACTIONS(2330),
    [anon_sym_uR_DQUOTE] = ACTIONS(2330),
    [anon_sym_UR_DQUOTE] = ACTIONS(2330),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2330),
    [anon_sym_co_await] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(2328),
    [anon_sym_requires] = ACTIONS(2328),
    [sym_this] = ACTIONS(2328),
    [anon_sym_discard] = ACTIONS(2328),
    [anon_sym_precise] = ACTIONS(2328),
    [anon_sym_shared] = ACTIONS(2328),
    [anon_sym_groupshared] = ACTIONS(2328),
    [anon_sym_uniform] = ACTIONS(2328),
    [anon_sym_row_major] = ACTIONS(2328),
    [anon_sym_column_major] = ACTIONS(2328),
    [anon_sym_globallycoherent] = ACTIONS(2328),
    [anon_sym_centroid] = ACTIONS(2328),
    [anon_sym_noperspective] = ACTIONS(2328),
    [anon_sym_nointerpolation] = ACTIONS(2328),
    [anon_sym_sample] = ACTIONS(2328),
    [anon_sym_linear] = ACTIONS(2328),
    [anon_sym_snorm] = ACTIONS(2328),
    [anon_sym_unorm] = ACTIONS(2328),
    [anon_sym_point] = ACTIONS(2328),
    [anon_sym_line] = ACTIONS(2328),
    [anon_sym_triangleadj] = ACTIONS(2328),
    [anon_sym_lineadj] = ACTIONS(2328),
    [anon_sym_triangle] = ACTIONS(2328),
    [anon_sym_cbuffer] = ACTIONS(2328),
  },
  [627] = {
    [sym_identifier] = ACTIONS(2532),
    [aux_sym_preproc_include_token1] = ACTIONS(2532),
    [aux_sym_preproc_def_token1] = ACTIONS(2532),
    [aux_sym_preproc_if_token1] = ACTIONS(2532),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2532),
    [sym_preproc_directive] = ACTIONS(2532),
    [anon_sym_LPAREN2] = ACTIONS(2534),
    [anon_sym_BANG] = ACTIONS(2534),
    [anon_sym_TILDE] = ACTIONS(2534),
    [anon_sym_DASH] = ACTIONS(2532),
    [anon_sym_PLUS] = ACTIONS(2532),
    [anon_sym_STAR] = ACTIONS(2534),
    [anon_sym_AMP_AMP] = ACTIONS(2534),
    [anon_sym_AMP] = ACTIONS(2532),
    [anon_sym_SEMI] = ACTIONS(2534),
    [anon_sym___extension__] = ACTIONS(2532),
    [anon_sym_typedef] = ACTIONS(2532),
    [anon_sym_in] = ACTIONS(2532),
    [anon_sym_out] = ACTIONS(2532),
    [anon_sym_inout] = ACTIONS(2532),
    [anon_sym_extern] = ACTIONS(2532),
    [anon_sym___attribute__] = ACTIONS(2532),
    [anon_sym_COLON_COLON] = ACTIONS(2534),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2534),
    [anon_sym___declspec] = ACTIONS(2532),
    [anon_sym___based] = ACTIONS(2532),
    [anon_sym___cdecl] = ACTIONS(2532),
    [anon_sym___clrcall] = ACTIONS(2532),
    [anon_sym___stdcall] = ACTIONS(2532),
    [anon_sym___fastcall] = ACTIONS(2532),
    [anon_sym___thiscall] = ACTIONS(2532),
    [anon_sym___vectorcall] = ACTIONS(2532),
    [anon_sym_LBRACE] = ACTIONS(2534),
    [anon_sym_RBRACE] = ACTIONS(2534),
    [anon_sym_signed] = ACTIONS(2532),
    [anon_sym_unsigned] = ACTIONS(2532),
    [anon_sym_long] = ACTIONS(2532),
    [anon_sym_short] = ACTIONS(2532),
    [anon_sym_LBRACK] = ACTIONS(2532),
    [anon_sym_static] = ACTIONS(2532),
    [anon_sym_register] = ACTIONS(2532),
    [anon_sym_inline] = ACTIONS(2532),
    [anon_sym___inline] = ACTIONS(2532),
    [anon_sym___inline__] = ACTIONS(2532),
    [anon_sym___forceinline] = ACTIONS(2532),
    [anon_sym_thread_local] = ACTIONS(2532),
    [anon_sym___thread] = ACTIONS(2532),
    [anon_sym_const] = ACTIONS(2532),
    [anon_sym_constexpr] = ACTIONS(2532),
    [anon_sym_volatile] = ACTIONS(2532),
    [anon_sym_restrict] = ACTIONS(2532),
    [anon_sym___restrict__] = ACTIONS(2532),
    [anon_sym__Atomic] = ACTIONS(2532),
    [anon_sym__Noreturn] = ACTIONS(2532),
    [anon_sym_noreturn] = ACTIONS(2532),
    [anon_sym_mutable] = ACTIONS(2532),
    [anon_sym_constinit] = ACTIONS(2532),
    [anon_sym_consteval] = ACTIONS(2532),
    [anon_sym_alignas] = ACTIONS(2532),
    [anon_sym__Alignas] = ACTIONS(2532),
    [sym_primitive_type] = ACTIONS(2532),
    [anon_sym_enum] = ACTIONS(2532),
    [anon_sym_class] = ACTIONS(2532),
    [anon_sym_struct] = ACTIONS(2532),
    [anon_sym_union] = ACTIONS(2532),
    [anon_sym_if] = ACTIONS(2532),
    [anon_sym_switch] = ACTIONS(2532),
    [anon_sym_case] = ACTIONS(2532),
    [anon_sym_default] = ACTIONS(2532),
    [anon_sym_while] = ACTIONS(2532),
    [anon_sym_do] = ACTIONS(2532),
    [anon_sym_for] = ACTIONS(2532),
    [anon_sym_return] = ACTIONS(2532),
    [anon_sym_break] = ACTIONS(2532),
    [anon_sym_continue] = ACTIONS(2532),
    [anon_sym_goto] = ACTIONS(2532),
    [anon_sym___try] = ACTIONS(2532),
    [anon_sym___leave] = ACTIONS(2532),
    [anon_sym_not] = ACTIONS(2532),
    [anon_sym_compl] = ACTIONS(2532),
    [anon_sym_DASH_DASH] = ACTIONS(2534),
    [anon_sym_PLUS_PLUS] = ACTIONS(2534),
    [anon_sym_sizeof] = ACTIONS(2532),
    [anon_sym___alignof__] = ACTIONS(2532),
    [anon_sym___alignof] = ACTIONS(2532),
    [anon_sym__alignof] = ACTIONS(2532),
    [anon_sym_alignof] = ACTIONS(2532),
    [anon_sym__Alignof] = ACTIONS(2532),
    [anon_sym_offsetof] = ACTIONS(2532),
    [anon_sym__Generic] = ACTIONS(2532),
    [anon_sym_asm] = ACTIONS(2532),
    [anon_sym___asm__] = ACTIONS(2532),
    [sym_number_literal] = ACTIONS(2534),
    [anon_sym_L_SQUOTE] = ACTIONS(2534),
    [anon_sym_u_SQUOTE] = ACTIONS(2534),
    [anon_sym_U_SQUOTE] = ACTIONS(2534),
    [anon_sym_u8_SQUOTE] = ACTIONS(2534),
    [anon_sym_SQUOTE] = ACTIONS(2534),
    [anon_sym_L_DQUOTE] = ACTIONS(2534),
    [anon_sym_u_DQUOTE] = ACTIONS(2534),
    [anon_sym_U_DQUOTE] = ACTIONS(2534),
    [anon_sym_u8_DQUOTE] = ACTIONS(2534),
    [anon_sym_DQUOTE] = ACTIONS(2534),
    [sym_true] = ACTIONS(2532),
    [sym_false] = ACTIONS(2532),
    [anon_sym_NULL] = ACTIONS(2532),
    [anon_sym_nullptr] = ACTIONS(2532),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2532),
    [anon_sym_decltype] = ACTIONS(2532),
    [sym_virtual] = ACTIONS(2532),
    [anon_sym_explicit] = ACTIONS(2532),
    [anon_sym_typename] = ACTIONS(2532),
    [anon_sym_template] = ACTIONS(2532),
    [anon_sym_operator] = ACTIONS(2532),
    [anon_sym_try] = ACTIONS(2532),
    [anon_sym_delete] = ACTIONS(2532),
    [anon_sym_throw] = ACTIONS(2532),
    [anon_sym_namespace] = ACTIONS(2532),
    [anon_sym_using] = ACTIONS(2532),
    [anon_sym_static_assert] = ACTIONS(2532),
    [anon_sym_concept] = ACTIONS(2532),
    [anon_sym_co_return] = ACTIONS(2532),
    [anon_sym_co_yield] = ACTIONS(2532),
    [anon_sym_R_DQUOTE] = ACTIONS(2534),
    [anon_sym_LR_DQUOTE] = ACTIONS(2534),
    [anon_sym_uR_DQUOTE] = ACTIONS(2534),
    [anon_sym_UR_DQUOTE] = ACTIONS(2534),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2534),
    [anon_sym_co_await] = ACTIONS(2532),
    [anon_sym_new] = ACTIONS(2532),
    [anon_sym_requires] = ACTIONS(2532),
    [sym_this] = ACTIONS(2532),
    [anon_sym_discard] = ACTIONS(2532),
    [anon_sym_precise] = ACTIONS(2532),
    [anon_sym_shared] = ACTIONS(2532),
    [anon_sym_groupshared] = ACTIONS(2532),
    [anon_sym_uniform] = ACTIONS(2532),
    [anon_sym_row_major] = ACTIONS(2532),
    [anon_sym_column_major] = ACTIONS(2532),
    [anon_sym_globallycoherent] = ACTIONS(2532),
    [anon_sym_centroid] = ACTIONS(2532),
    [anon_sym_noperspective] = ACTIONS(2532),
    [anon_sym_nointerpolation] = ACTIONS(2532),
    [anon_sym_sample] = ACTIONS(2532),
    [anon_sym_linear] = ACTIONS(2532),
    [anon_sym_snorm] = ACTIONS(2532),
    [anon_sym_unorm] = ACTIONS(2532),
    [anon_sym_point] = ACTIONS(2532),
    [anon_sym_line] = ACTIONS(2532),
    [anon_sym_triangleadj] = ACTIONS(2532),
    [anon_sym_lineadj] = ACTIONS(2532),
    [anon_sym_triangle] = ACTIONS(2532),
    [anon_sym_cbuffer] = ACTIONS(2532),
  },
  [628] = {
    [sym_identifier] = ACTIONS(2416),
    [aux_sym_preproc_include_token1] = ACTIONS(2416),
    [aux_sym_preproc_def_token1] = ACTIONS(2416),
    [aux_sym_preproc_if_token1] = ACTIONS(2416),
    [aux_sym_preproc_if_token2] = ACTIONS(2416),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2416),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2416),
    [sym_preproc_directive] = ACTIONS(2416),
    [anon_sym_LPAREN2] = ACTIONS(2418),
    [anon_sym_BANG] = ACTIONS(2418),
    [anon_sym_TILDE] = ACTIONS(2418),
    [anon_sym_DASH] = ACTIONS(2416),
    [anon_sym_PLUS] = ACTIONS(2416),
    [anon_sym_STAR] = ACTIONS(2418),
    [anon_sym_AMP_AMP] = ACTIONS(2418),
    [anon_sym_AMP] = ACTIONS(2416),
    [anon_sym_SEMI] = ACTIONS(2418),
    [anon_sym___extension__] = ACTIONS(2416),
    [anon_sym_typedef] = ACTIONS(2416),
    [anon_sym_in] = ACTIONS(2416),
    [anon_sym_out] = ACTIONS(2416),
    [anon_sym_inout] = ACTIONS(2416),
    [anon_sym_extern] = ACTIONS(2416),
    [anon_sym___attribute__] = ACTIONS(2416),
    [anon_sym_COLON_COLON] = ACTIONS(2418),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2418),
    [anon_sym___declspec] = ACTIONS(2416),
    [anon_sym___based] = ACTIONS(2416),
    [anon_sym___cdecl] = ACTIONS(2416),
    [anon_sym___clrcall] = ACTIONS(2416),
    [anon_sym___stdcall] = ACTIONS(2416),
    [anon_sym___fastcall] = ACTIONS(2416),
    [anon_sym___thiscall] = ACTIONS(2416),
    [anon_sym___vectorcall] = ACTIONS(2416),
    [anon_sym_LBRACE] = ACTIONS(2418),
    [anon_sym_signed] = ACTIONS(2416),
    [anon_sym_unsigned] = ACTIONS(2416),
    [anon_sym_long] = ACTIONS(2416),
    [anon_sym_short] = ACTIONS(2416),
    [anon_sym_LBRACK] = ACTIONS(2416),
    [anon_sym_static] = ACTIONS(2416),
    [anon_sym_register] = ACTIONS(2416),
    [anon_sym_inline] = ACTIONS(2416),
    [anon_sym___inline] = ACTIONS(2416),
    [anon_sym___inline__] = ACTIONS(2416),
    [anon_sym___forceinline] = ACTIONS(2416),
    [anon_sym_thread_local] = ACTIONS(2416),
    [anon_sym___thread] = ACTIONS(2416),
    [anon_sym_const] = ACTIONS(2416),
    [anon_sym_constexpr] = ACTIONS(2416),
    [anon_sym_volatile] = ACTIONS(2416),
    [anon_sym_restrict] = ACTIONS(2416),
    [anon_sym___restrict__] = ACTIONS(2416),
    [anon_sym__Atomic] = ACTIONS(2416),
    [anon_sym__Noreturn] = ACTIONS(2416),
    [anon_sym_noreturn] = ACTIONS(2416),
    [anon_sym_mutable] = ACTIONS(2416),
    [anon_sym_constinit] = ACTIONS(2416),
    [anon_sym_consteval] = ACTIONS(2416),
    [anon_sym_alignas] = ACTIONS(2416),
    [anon_sym__Alignas] = ACTIONS(2416),
    [sym_primitive_type] = ACTIONS(2416),
    [anon_sym_enum] = ACTIONS(2416),
    [anon_sym_class] = ACTIONS(2416),
    [anon_sym_struct] = ACTIONS(2416),
    [anon_sym_union] = ACTIONS(2416),
    [anon_sym_if] = ACTIONS(2416),
    [anon_sym_switch] = ACTIONS(2416),
    [anon_sym_case] = ACTIONS(2416),
    [anon_sym_default] = ACTIONS(2416),
    [anon_sym_while] = ACTIONS(2416),
    [anon_sym_do] = ACTIONS(2416),
    [anon_sym_for] = ACTIONS(2416),
    [anon_sym_return] = ACTIONS(2416),
    [anon_sym_break] = ACTIONS(2416),
    [anon_sym_continue] = ACTIONS(2416),
    [anon_sym_goto] = ACTIONS(2416),
    [anon_sym___try] = ACTIONS(2416),
    [anon_sym___leave] = ACTIONS(2416),
    [anon_sym_not] = ACTIONS(2416),
    [anon_sym_compl] = ACTIONS(2416),
    [anon_sym_DASH_DASH] = ACTIONS(2418),
    [anon_sym_PLUS_PLUS] = ACTIONS(2418),
    [anon_sym_sizeof] = ACTIONS(2416),
    [anon_sym___alignof__] = ACTIONS(2416),
    [anon_sym___alignof] = ACTIONS(2416),
    [anon_sym__alignof] = ACTIONS(2416),
    [anon_sym_alignof] = ACTIONS(2416),
    [anon_sym__Alignof] = ACTIONS(2416),
    [anon_sym_offsetof] = ACTIONS(2416),
    [anon_sym__Generic] = ACTIONS(2416),
    [anon_sym_asm] = ACTIONS(2416),
    [anon_sym___asm__] = ACTIONS(2416),
    [sym_number_literal] = ACTIONS(2418),
    [anon_sym_L_SQUOTE] = ACTIONS(2418),
    [anon_sym_u_SQUOTE] = ACTIONS(2418),
    [anon_sym_U_SQUOTE] = ACTIONS(2418),
    [anon_sym_u8_SQUOTE] = ACTIONS(2418),
    [anon_sym_SQUOTE] = ACTIONS(2418),
    [anon_sym_L_DQUOTE] = ACTIONS(2418),
    [anon_sym_u_DQUOTE] = ACTIONS(2418),
    [anon_sym_U_DQUOTE] = ACTIONS(2418),
    [anon_sym_u8_DQUOTE] = ACTIONS(2418),
    [anon_sym_DQUOTE] = ACTIONS(2418),
    [sym_true] = ACTIONS(2416),
    [sym_false] = ACTIONS(2416),
    [anon_sym_NULL] = ACTIONS(2416),
    [anon_sym_nullptr] = ACTIONS(2416),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2416),
    [anon_sym_decltype] = ACTIONS(2416),
    [sym_virtual] = ACTIONS(2416),
    [anon_sym_explicit] = ACTIONS(2416),
    [anon_sym_typename] = ACTIONS(2416),
    [anon_sym_template] = ACTIONS(2416),
    [anon_sym_operator] = ACTIONS(2416),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_delete] = ACTIONS(2416),
    [anon_sym_throw] = ACTIONS(2416),
    [anon_sym_namespace] = ACTIONS(2416),
    [anon_sym_using] = ACTIONS(2416),
    [anon_sym_static_assert] = ACTIONS(2416),
    [anon_sym_concept] = ACTIONS(2416),
    [anon_sym_co_return] = ACTIONS(2416),
    [anon_sym_co_yield] = ACTIONS(2416),
    [anon_sym_R_DQUOTE] = ACTIONS(2418),
    [anon_sym_LR_DQUOTE] = ACTIONS(2418),
    [anon_sym_uR_DQUOTE] = ACTIONS(2418),
    [anon_sym_UR_DQUOTE] = ACTIONS(2418),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2418),
    [anon_sym_co_await] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(2416),
    [anon_sym_requires] = ACTIONS(2416),
    [sym_this] = ACTIONS(2416),
    [anon_sym_discard] = ACTIONS(2416),
    [anon_sym_precise] = ACTIONS(2416),
    [anon_sym_shared] = ACTIONS(2416),
    [anon_sym_groupshared] = ACTIONS(2416),
    [anon_sym_uniform] = ACTIONS(2416),
    [anon_sym_row_major] = ACTIONS(2416),
    [anon_sym_column_major] = ACTIONS(2416),
    [anon_sym_globallycoherent] = ACTIONS(2416),
    [anon_sym_centroid] = ACTIONS(2416),
    [anon_sym_noperspective] = ACTIONS(2416),
    [anon_sym_nointerpolation] = ACTIONS(2416),
    [anon_sym_sample] = ACTIONS(2416),
    [anon_sym_linear] = ACTIONS(2416),
    [anon_sym_snorm] = ACTIONS(2416),
    [anon_sym_unorm] = ACTIONS(2416),
    [anon_sym_point] = ACTIONS(2416),
    [anon_sym_line] = ACTIONS(2416),
    [anon_sym_triangleadj] = ACTIONS(2416),
    [anon_sym_lineadj] = ACTIONS(2416),
    [anon_sym_triangle] = ACTIONS(2416),
    [anon_sym_cbuffer] = ACTIONS(2416),
  },
  [629] = {
    [sym_identifier] = ACTIONS(2420),
    [aux_sym_preproc_include_token1] = ACTIONS(2420),
    [aux_sym_preproc_def_token1] = ACTIONS(2420),
    [aux_sym_preproc_if_token1] = ACTIONS(2420),
    [aux_sym_preproc_if_token2] = ACTIONS(2420),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2420),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2420),
    [sym_preproc_directive] = ACTIONS(2420),
    [anon_sym_LPAREN2] = ACTIONS(2422),
    [anon_sym_BANG] = ACTIONS(2422),
    [anon_sym_TILDE] = ACTIONS(2422),
    [anon_sym_DASH] = ACTIONS(2420),
    [anon_sym_PLUS] = ACTIONS(2420),
    [anon_sym_STAR] = ACTIONS(2422),
    [anon_sym_AMP_AMP] = ACTIONS(2422),
    [anon_sym_AMP] = ACTIONS(2420),
    [anon_sym_SEMI] = ACTIONS(2422),
    [anon_sym___extension__] = ACTIONS(2420),
    [anon_sym_typedef] = ACTIONS(2420),
    [anon_sym_in] = ACTIONS(2420),
    [anon_sym_out] = ACTIONS(2420),
    [anon_sym_inout] = ACTIONS(2420),
    [anon_sym_extern] = ACTIONS(2420),
    [anon_sym___attribute__] = ACTIONS(2420),
    [anon_sym_COLON_COLON] = ACTIONS(2422),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2422),
    [anon_sym___declspec] = ACTIONS(2420),
    [anon_sym___based] = ACTIONS(2420),
    [anon_sym___cdecl] = ACTIONS(2420),
    [anon_sym___clrcall] = ACTIONS(2420),
    [anon_sym___stdcall] = ACTIONS(2420),
    [anon_sym___fastcall] = ACTIONS(2420),
    [anon_sym___thiscall] = ACTIONS(2420),
    [anon_sym___vectorcall] = ACTIONS(2420),
    [anon_sym_LBRACE] = ACTIONS(2422),
    [anon_sym_signed] = ACTIONS(2420),
    [anon_sym_unsigned] = ACTIONS(2420),
    [anon_sym_long] = ACTIONS(2420),
    [anon_sym_short] = ACTIONS(2420),
    [anon_sym_LBRACK] = ACTIONS(2420),
    [anon_sym_static] = ACTIONS(2420),
    [anon_sym_register] = ACTIONS(2420),
    [anon_sym_inline] = ACTIONS(2420),
    [anon_sym___inline] = ACTIONS(2420),
    [anon_sym___inline__] = ACTIONS(2420),
    [anon_sym___forceinline] = ACTIONS(2420),
    [anon_sym_thread_local] = ACTIONS(2420),
    [anon_sym___thread] = ACTIONS(2420),
    [anon_sym_const] = ACTIONS(2420),
    [anon_sym_constexpr] = ACTIONS(2420),
    [anon_sym_volatile] = ACTIONS(2420),
    [anon_sym_restrict] = ACTIONS(2420),
    [anon_sym___restrict__] = ACTIONS(2420),
    [anon_sym__Atomic] = ACTIONS(2420),
    [anon_sym__Noreturn] = ACTIONS(2420),
    [anon_sym_noreturn] = ACTIONS(2420),
    [anon_sym_mutable] = ACTIONS(2420),
    [anon_sym_constinit] = ACTIONS(2420),
    [anon_sym_consteval] = ACTIONS(2420),
    [anon_sym_alignas] = ACTIONS(2420),
    [anon_sym__Alignas] = ACTIONS(2420),
    [sym_primitive_type] = ACTIONS(2420),
    [anon_sym_enum] = ACTIONS(2420),
    [anon_sym_class] = ACTIONS(2420),
    [anon_sym_struct] = ACTIONS(2420),
    [anon_sym_union] = ACTIONS(2420),
    [anon_sym_if] = ACTIONS(2420),
    [anon_sym_switch] = ACTIONS(2420),
    [anon_sym_case] = ACTIONS(2420),
    [anon_sym_default] = ACTIONS(2420),
    [anon_sym_while] = ACTIONS(2420),
    [anon_sym_do] = ACTIONS(2420),
    [anon_sym_for] = ACTIONS(2420),
    [anon_sym_return] = ACTIONS(2420),
    [anon_sym_break] = ACTIONS(2420),
    [anon_sym_continue] = ACTIONS(2420),
    [anon_sym_goto] = ACTIONS(2420),
    [anon_sym___try] = ACTIONS(2420),
    [anon_sym___leave] = ACTIONS(2420),
    [anon_sym_not] = ACTIONS(2420),
    [anon_sym_compl] = ACTIONS(2420),
    [anon_sym_DASH_DASH] = ACTIONS(2422),
    [anon_sym_PLUS_PLUS] = ACTIONS(2422),
    [anon_sym_sizeof] = ACTIONS(2420),
    [anon_sym___alignof__] = ACTIONS(2420),
    [anon_sym___alignof] = ACTIONS(2420),
    [anon_sym__alignof] = ACTIONS(2420),
    [anon_sym_alignof] = ACTIONS(2420),
    [anon_sym__Alignof] = ACTIONS(2420),
    [anon_sym_offsetof] = ACTIONS(2420),
    [anon_sym__Generic] = ACTIONS(2420),
    [anon_sym_asm] = ACTIONS(2420),
    [anon_sym___asm__] = ACTIONS(2420),
    [sym_number_literal] = ACTIONS(2422),
    [anon_sym_L_SQUOTE] = ACTIONS(2422),
    [anon_sym_u_SQUOTE] = ACTIONS(2422),
    [anon_sym_U_SQUOTE] = ACTIONS(2422),
    [anon_sym_u8_SQUOTE] = ACTIONS(2422),
    [anon_sym_SQUOTE] = ACTIONS(2422),
    [anon_sym_L_DQUOTE] = ACTIONS(2422),
    [anon_sym_u_DQUOTE] = ACTIONS(2422),
    [anon_sym_U_DQUOTE] = ACTIONS(2422),
    [anon_sym_u8_DQUOTE] = ACTIONS(2422),
    [anon_sym_DQUOTE] = ACTIONS(2422),
    [sym_true] = ACTIONS(2420),
    [sym_false] = ACTIONS(2420),
    [anon_sym_NULL] = ACTIONS(2420),
    [anon_sym_nullptr] = ACTIONS(2420),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2420),
    [anon_sym_decltype] = ACTIONS(2420),
    [sym_virtual] = ACTIONS(2420),
    [anon_sym_explicit] = ACTIONS(2420),
    [anon_sym_typename] = ACTIONS(2420),
    [anon_sym_template] = ACTIONS(2420),
    [anon_sym_operator] = ACTIONS(2420),
    [anon_sym_try] = ACTIONS(2420),
    [anon_sym_delete] = ACTIONS(2420),
    [anon_sym_throw] = ACTIONS(2420),
    [anon_sym_namespace] = ACTIONS(2420),
    [anon_sym_using] = ACTIONS(2420),
    [anon_sym_static_assert] = ACTIONS(2420),
    [anon_sym_concept] = ACTIONS(2420),
    [anon_sym_co_return] = ACTIONS(2420),
    [anon_sym_co_yield] = ACTIONS(2420),
    [anon_sym_R_DQUOTE] = ACTIONS(2422),
    [anon_sym_LR_DQUOTE] = ACTIONS(2422),
    [anon_sym_uR_DQUOTE] = ACTIONS(2422),
    [anon_sym_UR_DQUOTE] = ACTIONS(2422),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2422),
    [anon_sym_co_await] = ACTIONS(2420),
    [anon_sym_new] = ACTIONS(2420),
    [anon_sym_requires] = ACTIONS(2420),
    [sym_this] = ACTIONS(2420),
    [anon_sym_discard] = ACTIONS(2420),
    [anon_sym_precise] = ACTIONS(2420),
    [anon_sym_shared] = ACTIONS(2420),
    [anon_sym_groupshared] = ACTIONS(2420),
    [anon_sym_uniform] = ACTIONS(2420),
    [anon_sym_row_major] = ACTIONS(2420),
    [anon_sym_column_major] = ACTIONS(2420),
    [anon_sym_globallycoherent] = ACTIONS(2420),
    [anon_sym_centroid] = ACTIONS(2420),
    [anon_sym_noperspective] = ACTIONS(2420),
    [anon_sym_nointerpolation] = ACTIONS(2420),
    [anon_sym_sample] = ACTIONS(2420),
    [anon_sym_linear] = ACTIONS(2420),
    [anon_sym_snorm] = ACTIONS(2420),
    [anon_sym_unorm] = ACTIONS(2420),
    [anon_sym_point] = ACTIONS(2420),
    [anon_sym_line] = ACTIONS(2420),
    [anon_sym_triangleadj] = ACTIONS(2420),
    [anon_sym_lineadj] = ACTIONS(2420),
    [anon_sym_triangle] = ACTIONS(2420),
    [anon_sym_cbuffer] = ACTIONS(2420),
  },
  [630] = {
    [sym_identifier] = ACTIONS(2428),
    [aux_sym_preproc_include_token1] = ACTIONS(2428),
    [aux_sym_preproc_def_token1] = ACTIONS(2428),
    [aux_sym_preproc_if_token1] = ACTIONS(2428),
    [aux_sym_preproc_if_token2] = ACTIONS(2428),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2428),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2428),
    [sym_preproc_directive] = ACTIONS(2428),
    [anon_sym_LPAREN2] = ACTIONS(2430),
    [anon_sym_BANG] = ACTIONS(2430),
    [anon_sym_TILDE] = ACTIONS(2430),
    [anon_sym_DASH] = ACTIONS(2428),
    [anon_sym_PLUS] = ACTIONS(2428),
    [anon_sym_STAR] = ACTIONS(2430),
    [anon_sym_AMP_AMP] = ACTIONS(2430),
    [anon_sym_AMP] = ACTIONS(2428),
    [anon_sym_SEMI] = ACTIONS(2430),
    [anon_sym___extension__] = ACTIONS(2428),
    [anon_sym_typedef] = ACTIONS(2428),
    [anon_sym_in] = ACTIONS(2428),
    [anon_sym_out] = ACTIONS(2428),
    [anon_sym_inout] = ACTIONS(2428),
    [anon_sym_extern] = ACTIONS(2428),
    [anon_sym___attribute__] = ACTIONS(2428),
    [anon_sym_COLON_COLON] = ACTIONS(2430),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2430),
    [anon_sym___declspec] = ACTIONS(2428),
    [anon_sym___based] = ACTIONS(2428),
    [anon_sym___cdecl] = ACTIONS(2428),
    [anon_sym___clrcall] = ACTIONS(2428),
    [anon_sym___stdcall] = ACTIONS(2428),
    [anon_sym___fastcall] = ACTIONS(2428),
    [anon_sym___thiscall] = ACTIONS(2428),
    [anon_sym___vectorcall] = ACTIONS(2428),
    [anon_sym_LBRACE] = ACTIONS(2430),
    [anon_sym_signed] = ACTIONS(2428),
    [anon_sym_unsigned] = ACTIONS(2428),
    [anon_sym_long] = ACTIONS(2428),
    [anon_sym_short] = ACTIONS(2428),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [anon_sym_static] = ACTIONS(2428),
    [anon_sym_register] = ACTIONS(2428),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym___inline] = ACTIONS(2428),
    [anon_sym___inline__] = ACTIONS(2428),
    [anon_sym___forceinline] = ACTIONS(2428),
    [anon_sym_thread_local] = ACTIONS(2428),
    [anon_sym___thread] = ACTIONS(2428),
    [anon_sym_const] = ACTIONS(2428),
    [anon_sym_constexpr] = ACTIONS(2428),
    [anon_sym_volatile] = ACTIONS(2428),
    [anon_sym_restrict] = ACTIONS(2428),
    [anon_sym___restrict__] = ACTIONS(2428),
    [anon_sym__Atomic] = ACTIONS(2428),
    [anon_sym__Noreturn] = ACTIONS(2428),
    [anon_sym_noreturn] = ACTIONS(2428),
    [anon_sym_mutable] = ACTIONS(2428),
    [anon_sym_constinit] = ACTIONS(2428),
    [anon_sym_consteval] = ACTIONS(2428),
    [anon_sym_alignas] = ACTIONS(2428),
    [anon_sym__Alignas] = ACTIONS(2428),
    [sym_primitive_type] = ACTIONS(2428),
    [anon_sym_enum] = ACTIONS(2428),
    [anon_sym_class] = ACTIONS(2428),
    [anon_sym_struct] = ACTIONS(2428),
    [anon_sym_union] = ACTIONS(2428),
    [anon_sym_if] = ACTIONS(2428),
    [anon_sym_switch] = ACTIONS(2428),
    [anon_sym_case] = ACTIONS(2428),
    [anon_sym_default] = ACTIONS(2428),
    [anon_sym_while] = ACTIONS(2428),
    [anon_sym_do] = ACTIONS(2428),
    [anon_sym_for] = ACTIONS(2428),
    [anon_sym_return] = ACTIONS(2428),
    [anon_sym_break] = ACTIONS(2428),
    [anon_sym_continue] = ACTIONS(2428),
    [anon_sym_goto] = ACTIONS(2428),
    [anon_sym___try] = ACTIONS(2428),
    [anon_sym___leave] = ACTIONS(2428),
    [anon_sym_not] = ACTIONS(2428),
    [anon_sym_compl] = ACTIONS(2428),
    [anon_sym_DASH_DASH] = ACTIONS(2430),
    [anon_sym_PLUS_PLUS] = ACTIONS(2430),
    [anon_sym_sizeof] = ACTIONS(2428),
    [anon_sym___alignof__] = ACTIONS(2428),
    [anon_sym___alignof] = ACTIONS(2428),
    [anon_sym__alignof] = ACTIONS(2428),
    [anon_sym_alignof] = ACTIONS(2428),
    [anon_sym__Alignof] = ACTIONS(2428),
    [anon_sym_offsetof] = ACTIONS(2428),
    [anon_sym__Generic] = ACTIONS(2428),
    [anon_sym_asm] = ACTIONS(2428),
    [anon_sym___asm__] = ACTIONS(2428),
    [sym_number_literal] = ACTIONS(2430),
    [anon_sym_L_SQUOTE] = ACTIONS(2430),
    [anon_sym_u_SQUOTE] = ACTIONS(2430),
    [anon_sym_U_SQUOTE] = ACTIONS(2430),
    [anon_sym_u8_SQUOTE] = ACTIONS(2430),
    [anon_sym_SQUOTE] = ACTIONS(2430),
    [anon_sym_L_DQUOTE] = ACTIONS(2430),
    [anon_sym_u_DQUOTE] = ACTIONS(2430),
    [anon_sym_U_DQUOTE] = ACTIONS(2430),
    [anon_sym_u8_DQUOTE] = ACTIONS(2430),
    [anon_sym_DQUOTE] = ACTIONS(2430),
    [sym_true] = ACTIONS(2428),
    [sym_false] = ACTIONS(2428),
    [anon_sym_NULL] = ACTIONS(2428),
    [anon_sym_nullptr] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2428),
    [anon_sym_decltype] = ACTIONS(2428),
    [sym_virtual] = ACTIONS(2428),
    [anon_sym_explicit] = ACTIONS(2428),
    [anon_sym_typename] = ACTIONS(2428),
    [anon_sym_template] = ACTIONS(2428),
    [anon_sym_operator] = ACTIONS(2428),
    [anon_sym_try] = ACTIONS(2428),
    [anon_sym_delete] = ACTIONS(2428),
    [anon_sym_throw] = ACTIONS(2428),
    [anon_sym_namespace] = ACTIONS(2428),
    [anon_sym_using] = ACTIONS(2428),
    [anon_sym_static_assert] = ACTIONS(2428),
    [anon_sym_concept] = ACTIONS(2428),
    [anon_sym_co_return] = ACTIONS(2428),
    [anon_sym_co_yield] = ACTIONS(2428),
    [anon_sym_R_DQUOTE] = ACTIONS(2430),
    [anon_sym_LR_DQUOTE] = ACTIONS(2430),
    [anon_sym_uR_DQUOTE] = ACTIONS(2430),
    [anon_sym_UR_DQUOTE] = ACTIONS(2430),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2430),
    [anon_sym_co_await] = ACTIONS(2428),
    [anon_sym_new] = ACTIONS(2428),
    [anon_sym_requires] = ACTIONS(2428),
    [sym_this] = ACTIONS(2428),
    [anon_sym_discard] = ACTIONS(2428),
    [anon_sym_precise] = ACTIONS(2428),
    [anon_sym_shared] = ACTIONS(2428),
    [anon_sym_groupshared] = ACTIONS(2428),
    [anon_sym_uniform] = ACTIONS(2428),
    [anon_sym_row_major] = ACTIONS(2428),
    [anon_sym_column_major] = ACTIONS(2428),
    [anon_sym_globallycoherent] = ACTIONS(2428),
    [anon_sym_centroid] = ACTIONS(2428),
    [anon_sym_noperspective] = ACTIONS(2428),
    [anon_sym_nointerpolation] = ACTIONS(2428),
    [anon_sym_sample] = ACTIONS(2428),
    [anon_sym_linear] = ACTIONS(2428),
    [anon_sym_snorm] = ACTIONS(2428),
    [anon_sym_unorm] = ACTIONS(2428),
    [anon_sym_point] = ACTIONS(2428),
    [anon_sym_line] = ACTIONS(2428),
    [anon_sym_triangleadj] = ACTIONS(2428),
    [anon_sym_lineadj] = ACTIONS(2428),
    [anon_sym_triangle] = ACTIONS(2428),
    [anon_sym_cbuffer] = ACTIONS(2428),
  },
  [631] = {
    [sym_identifier] = ACTIONS(2532),
    [aux_sym_preproc_include_token1] = ACTIONS(2532),
    [aux_sym_preproc_def_token1] = ACTIONS(2532),
    [aux_sym_preproc_if_token1] = ACTIONS(2532),
    [aux_sym_preproc_if_token2] = ACTIONS(2532),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2532),
    [sym_preproc_directive] = ACTIONS(2532),
    [anon_sym_LPAREN2] = ACTIONS(2534),
    [anon_sym_BANG] = ACTIONS(2534),
    [anon_sym_TILDE] = ACTIONS(2534),
    [anon_sym_DASH] = ACTIONS(2532),
    [anon_sym_PLUS] = ACTIONS(2532),
    [anon_sym_STAR] = ACTIONS(2534),
    [anon_sym_AMP_AMP] = ACTIONS(2534),
    [anon_sym_AMP] = ACTIONS(2532),
    [anon_sym_SEMI] = ACTIONS(2534),
    [anon_sym___extension__] = ACTIONS(2532),
    [anon_sym_typedef] = ACTIONS(2532),
    [anon_sym_in] = ACTIONS(2532),
    [anon_sym_out] = ACTIONS(2532),
    [anon_sym_inout] = ACTIONS(2532),
    [anon_sym_extern] = ACTIONS(2532),
    [anon_sym___attribute__] = ACTIONS(2532),
    [anon_sym_COLON_COLON] = ACTIONS(2534),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2534),
    [anon_sym___declspec] = ACTIONS(2532),
    [anon_sym___based] = ACTIONS(2532),
    [anon_sym___cdecl] = ACTIONS(2532),
    [anon_sym___clrcall] = ACTIONS(2532),
    [anon_sym___stdcall] = ACTIONS(2532),
    [anon_sym___fastcall] = ACTIONS(2532),
    [anon_sym___thiscall] = ACTIONS(2532),
    [anon_sym___vectorcall] = ACTIONS(2532),
    [anon_sym_LBRACE] = ACTIONS(2534),
    [anon_sym_signed] = ACTIONS(2532),
    [anon_sym_unsigned] = ACTIONS(2532),
    [anon_sym_long] = ACTIONS(2532),
    [anon_sym_short] = ACTIONS(2532),
    [anon_sym_LBRACK] = ACTIONS(2532),
    [anon_sym_static] = ACTIONS(2532),
    [anon_sym_register] = ACTIONS(2532),
    [anon_sym_inline] = ACTIONS(2532),
    [anon_sym___inline] = ACTIONS(2532),
    [anon_sym___inline__] = ACTIONS(2532),
    [anon_sym___forceinline] = ACTIONS(2532),
    [anon_sym_thread_local] = ACTIONS(2532),
    [anon_sym___thread] = ACTIONS(2532),
    [anon_sym_const] = ACTIONS(2532),
    [anon_sym_constexpr] = ACTIONS(2532),
    [anon_sym_volatile] = ACTIONS(2532),
    [anon_sym_restrict] = ACTIONS(2532),
    [anon_sym___restrict__] = ACTIONS(2532),
    [anon_sym__Atomic] = ACTIONS(2532),
    [anon_sym__Noreturn] = ACTIONS(2532),
    [anon_sym_noreturn] = ACTIONS(2532),
    [anon_sym_mutable] = ACTIONS(2532),
    [anon_sym_constinit] = ACTIONS(2532),
    [anon_sym_consteval] = ACTIONS(2532),
    [anon_sym_alignas] = ACTIONS(2532),
    [anon_sym__Alignas] = ACTIONS(2532),
    [sym_primitive_type] = ACTIONS(2532),
    [anon_sym_enum] = ACTIONS(2532),
    [anon_sym_class] = ACTIONS(2532),
    [anon_sym_struct] = ACTIONS(2532),
    [anon_sym_union] = ACTIONS(2532),
    [anon_sym_if] = ACTIONS(2532),
    [anon_sym_switch] = ACTIONS(2532),
    [anon_sym_case] = ACTIONS(2532),
    [anon_sym_default] = ACTIONS(2532),
    [anon_sym_while] = ACTIONS(2532),
    [anon_sym_do] = ACTIONS(2532),
    [anon_sym_for] = ACTIONS(2532),
    [anon_sym_return] = ACTIONS(2532),
    [anon_sym_break] = ACTIONS(2532),
    [anon_sym_continue] = ACTIONS(2532),
    [anon_sym_goto] = ACTIONS(2532),
    [anon_sym___try] = ACTIONS(2532),
    [anon_sym___leave] = ACTIONS(2532),
    [anon_sym_not] = ACTIONS(2532),
    [anon_sym_compl] = ACTIONS(2532),
    [anon_sym_DASH_DASH] = ACTIONS(2534),
    [anon_sym_PLUS_PLUS] = ACTIONS(2534),
    [anon_sym_sizeof] = ACTIONS(2532),
    [anon_sym___alignof__] = ACTIONS(2532),
    [anon_sym___alignof] = ACTIONS(2532),
    [anon_sym__alignof] = ACTIONS(2532),
    [anon_sym_alignof] = ACTIONS(2532),
    [anon_sym__Alignof] = ACTIONS(2532),
    [anon_sym_offsetof] = ACTIONS(2532),
    [anon_sym__Generic] = ACTIONS(2532),
    [anon_sym_asm] = ACTIONS(2532),
    [anon_sym___asm__] = ACTIONS(2532),
    [sym_number_literal] = ACTIONS(2534),
    [anon_sym_L_SQUOTE] = ACTIONS(2534),
    [anon_sym_u_SQUOTE] = ACTIONS(2534),
    [anon_sym_U_SQUOTE] = ACTIONS(2534),
    [anon_sym_u8_SQUOTE] = ACTIONS(2534),
    [anon_sym_SQUOTE] = ACTIONS(2534),
    [anon_sym_L_DQUOTE] = ACTIONS(2534),
    [anon_sym_u_DQUOTE] = ACTIONS(2534),
    [anon_sym_U_DQUOTE] = ACTIONS(2534),
    [anon_sym_u8_DQUOTE] = ACTIONS(2534),
    [anon_sym_DQUOTE] = ACTIONS(2534),
    [sym_true] = ACTIONS(2532),
    [sym_false] = ACTIONS(2532),
    [anon_sym_NULL] = ACTIONS(2532),
    [anon_sym_nullptr] = ACTIONS(2532),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2532),
    [anon_sym_decltype] = ACTIONS(2532),
    [sym_virtual] = ACTIONS(2532),
    [anon_sym_explicit] = ACTIONS(2532),
    [anon_sym_typename] = ACTIONS(2532),
    [anon_sym_template] = ACTIONS(2532),
    [anon_sym_operator] = ACTIONS(2532),
    [anon_sym_try] = ACTIONS(2532),
    [anon_sym_delete] = ACTIONS(2532),
    [anon_sym_throw] = ACTIONS(2532),
    [anon_sym_namespace] = ACTIONS(2532),
    [anon_sym_using] = ACTIONS(2532),
    [anon_sym_static_assert] = ACTIONS(2532),
    [anon_sym_concept] = ACTIONS(2532),
    [anon_sym_co_return] = ACTIONS(2532),
    [anon_sym_co_yield] = ACTIONS(2532),
    [anon_sym_R_DQUOTE] = ACTIONS(2534),
    [anon_sym_LR_DQUOTE] = ACTIONS(2534),
    [anon_sym_uR_DQUOTE] = ACTIONS(2534),
    [anon_sym_UR_DQUOTE] = ACTIONS(2534),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2534),
    [anon_sym_co_await] = ACTIONS(2532),
    [anon_sym_new] = ACTIONS(2532),
    [anon_sym_requires] = ACTIONS(2532),
    [sym_this] = ACTIONS(2532),
    [anon_sym_discard] = ACTIONS(2532),
    [anon_sym_precise] = ACTIONS(2532),
    [anon_sym_shared] = ACTIONS(2532),
    [anon_sym_groupshared] = ACTIONS(2532),
    [anon_sym_uniform] = ACTIONS(2532),
    [anon_sym_row_major] = ACTIONS(2532),
    [anon_sym_column_major] = ACTIONS(2532),
    [anon_sym_globallycoherent] = ACTIONS(2532),
    [anon_sym_centroid] = ACTIONS(2532),
    [anon_sym_noperspective] = ACTIONS(2532),
    [anon_sym_nointerpolation] = ACTIONS(2532),
    [anon_sym_sample] = ACTIONS(2532),
    [anon_sym_linear] = ACTIONS(2532),
    [anon_sym_snorm] = ACTIONS(2532),
    [anon_sym_unorm] = ACTIONS(2532),
    [anon_sym_point] = ACTIONS(2532),
    [anon_sym_line] = ACTIONS(2532),
    [anon_sym_triangleadj] = ACTIONS(2532),
    [anon_sym_lineadj] = ACTIONS(2532),
    [anon_sym_triangle] = ACTIONS(2532),
    [anon_sym_cbuffer] = ACTIONS(2532),
  },
  [632] = {
    [sym_identifier] = ACTIONS(2536),
    [aux_sym_preproc_include_token1] = ACTIONS(2536),
    [aux_sym_preproc_def_token1] = ACTIONS(2536),
    [aux_sym_preproc_if_token1] = ACTIONS(2536),
    [aux_sym_preproc_if_token2] = ACTIONS(2536),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2536),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2536),
    [sym_preproc_directive] = ACTIONS(2536),
    [anon_sym_LPAREN2] = ACTIONS(2538),
    [anon_sym_BANG] = ACTIONS(2538),
    [anon_sym_TILDE] = ACTIONS(2538),
    [anon_sym_DASH] = ACTIONS(2536),
    [anon_sym_PLUS] = ACTIONS(2536),
    [anon_sym_STAR] = ACTIONS(2538),
    [anon_sym_AMP_AMP] = ACTIONS(2538),
    [anon_sym_AMP] = ACTIONS(2536),
    [anon_sym_SEMI] = ACTIONS(2538),
    [anon_sym___extension__] = ACTIONS(2536),
    [anon_sym_typedef] = ACTIONS(2536),
    [anon_sym_in] = ACTIONS(2536),
    [anon_sym_out] = ACTIONS(2536),
    [anon_sym_inout] = ACTIONS(2536),
    [anon_sym_extern] = ACTIONS(2536),
    [anon_sym___attribute__] = ACTIONS(2536),
    [anon_sym_COLON_COLON] = ACTIONS(2538),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2538),
    [anon_sym___declspec] = ACTIONS(2536),
    [anon_sym___based] = ACTIONS(2536),
    [anon_sym___cdecl] = ACTIONS(2536),
    [anon_sym___clrcall] = ACTIONS(2536),
    [anon_sym___stdcall] = ACTIONS(2536),
    [anon_sym___fastcall] = ACTIONS(2536),
    [anon_sym___thiscall] = ACTIONS(2536),
    [anon_sym___vectorcall] = ACTIONS(2536),
    [anon_sym_LBRACE] = ACTIONS(2538),
    [anon_sym_signed] = ACTIONS(2536),
    [anon_sym_unsigned] = ACTIONS(2536),
    [anon_sym_long] = ACTIONS(2536),
    [anon_sym_short] = ACTIONS(2536),
    [anon_sym_LBRACK] = ACTIONS(2536),
    [anon_sym_static] = ACTIONS(2536),
    [anon_sym_register] = ACTIONS(2536),
    [anon_sym_inline] = ACTIONS(2536),
    [anon_sym___inline] = ACTIONS(2536),
    [anon_sym___inline__] = ACTIONS(2536),
    [anon_sym___forceinline] = ACTIONS(2536),
    [anon_sym_thread_local] = ACTIONS(2536),
    [anon_sym___thread] = ACTIONS(2536),
    [anon_sym_const] = ACTIONS(2536),
    [anon_sym_constexpr] = ACTIONS(2536),
    [anon_sym_volatile] = ACTIONS(2536),
    [anon_sym_restrict] = ACTIONS(2536),
    [anon_sym___restrict__] = ACTIONS(2536),
    [anon_sym__Atomic] = ACTIONS(2536),
    [anon_sym__Noreturn] = ACTIONS(2536),
    [anon_sym_noreturn] = ACTIONS(2536),
    [anon_sym_mutable] = ACTIONS(2536),
    [anon_sym_constinit] = ACTIONS(2536),
    [anon_sym_consteval] = ACTIONS(2536),
    [anon_sym_alignas] = ACTIONS(2536),
    [anon_sym__Alignas] = ACTIONS(2536),
    [sym_primitive_type] = ACTIONS(2536),
    [anon_sym_enum] = ACTIONS(2536),
    [anon_sym_class] = ACTIONS(2536),
    [anon_sym_struct] = ACTIONS(2536),
    [anon_sym_union] = ACTIONS(2536),
    [anon_sym_if] = ACTIONS(2536),
    [anon_sym_switch] = ACTIONS(2536),
    [anon_sym_case] = ACTIONS(2536),
    [anon_sym_default] = ACTIONS(2536),
    [anon_sym_while] = ACTIONS(2536),
    [anon_sym_do] = ACTIONS(2536),
    [anon_sym_for] = ACTIONS(2536),
    [anon_sym_return] = ACTIONS(2536),
    [anon_sym_break] = ACTIONS(2536),
    [anon_sym_continue] = ACTIONS(2536),
    [anon_sym_goto] = ACTIONS(2536),
    [anon_sym___try] = ACTIONS(2536),
    [anon_sym___leave] = ACTIONS(2536),
    [anon_sym_not] = ACTIONS(2536),
    [anon_sym_compl] = ACTIONS(2536),
    [anon_sym_DASH_DASH] = ACTIONS(2538),
    [anon_sym_PLUS_PLUS] = ACTIONS(2538),
    [anon_sym_sizeof] = ACTIONS(2536),
    [anon_sym___alignof__] = ACTIONS(2536),
    [anon_sym___alignof] = ACTIONS(2536),
    [anon_sym__alignof] = ACTIONS(2536),
    [anon_sym_alignof] = ACTIONS(2536),
    [anon_sym__Alignof] = ACTIONS(2536),
    [anon_sym_offsetof] = ACTIONS(2536),
    [anon_sym__Generic] = ACTIONS(2536),
    [anon_sym_asm] = ACTIONS(2536),
    [anon_sym___asm__] = ACTIONS(2536),
    [sym_number_literal] = ACTIONS(2538),
    [anon_sym_L_SQUOTE] = ACTIONS(2538),
    [anon_sym_u_SQUOTE] = ACTIONS(2538),
    [anon_sym_U_SQUOTE] = ACTIONS(2538),
    [anon_sym_u8_SQUOTE] = ACTIONS(2538),
    [anon_sym_SQUOTE] = ACTIONS(2538),
    [anon_sym_L_DQUOTE] = ACTIONS(2538),
    [anon_sym_u_DQUOTE] = ACTIONS(2538),
    [anon_sym_U_DQUOTE] = ACTIONS(2538),
    [anon_sym_u8_DQUOTE] = ACTIONS(2538),
    [anon_sym_DQUOTE] = ACTIONS(2538),
    [sym_true] = ACTIONS(2536),
    [sym_false] = ACTIONS(2536),
    [anon_sym_NULL] = ACTIONS(2536),
    [anon_sym_nullptr] = ACTIONS(2536),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2536),
    [anon_sym_decltype] = ACTIONS(2536),
    [sym_virtual] = ACTIONS(2536),
    [anon_sym_explicit] = ACTIONS(2536),
    [anon_sym_typename] = ACTIONS(2536),
    [anon_sym_template] = ACTIONS(2536),
    [anon_sym_operator] = ACTIONS(2536),
    [anon_sym_try] = ACTIONS(2536),
    [anon_sym_delete] = ACTIONS(2536),
    [anon_sym_throw] = ACTIONS(2536),
    [anon_sym_namespace] = ACTIONS(2536),
    [anon_sym_using] = ACTIONS(2536),
    [anon_sym_static_assert] = ACTIONS(2536),
    [anon_sym_concept] = ACTIONS(2536),
    [anon_sym_co_return] = ACTIONS(2536),
    [anon_sym_co_yield] = ACTIONS(2536),
    [anon_sym_R_DQUOTE] = ACTIONS(2538),
    [anon_sym_LR_DQUOTE] = ACTIONS(2538),
    [anon_sym_uR_DQUOTE] = ACTIONS(2538),
    [anon_sym_UR_DQUOTE] = ACTIONS(2538),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2538),
    [anon_sym_co_await] = ACTIONS(2536),
    [anon_sym_new] = ACTIONS(2536),
    [anon_sym_requires] = ACTIONS(2536),
    [sym_this] = ACTIONS(2536),
    [anon_sym_discard] = ACTIONS(2536),
    [anon_sym_precise] = ACTIONS(2536),
    [anon_sym_shared] = ACTIONS(2536),
    [anon_sym_groupshared] = ACTIONS(2536),
    [anon_sym_uniform] = ACTIONS(2536),
    [anon_sym_row_major] = ACTIONS(2536),
    [anon_sym_column_major] = ACTIONS(2536),
    [anon_sym_globallycoherent] = ACTIONS(2536),
    [anon_sym_centroid] = ACTIONS(2536),
    [anon_sym_noperspective] = ACTIONS(2536),
    [anon_sym_nointerpolation] = ACTIONS(2536),
    [anon_sym_sample] = ACTIONS(2536),
    [anon_sym_linear] = ACTIONS(2536),
    [anon_sym_snorm] = ACTIONS(2536),
    [anon_sym_unorm] = ACTIONS(2536),
    [anon_sym_point] = ACTIONS(2536),
    [anon_sym_line] = ACTIONS(2536),
    [anon_sym_triangleadj] = ACTIONS(2536),
    [anon_sym_lineadj] = ACTIONS(2536),
    [anon_sym_triangle] = ACTIONS(2536),
    [anon_sym_cbuffer] = ACTIONS(2536),
  },
  [633] = {
    [sym_identifier] = ACTIONS(2432),
    [aux_sym_preproc_include_token1] = ACTIONS(2432),
    [aux_sym_preproc_def_token1] = ACTIONS(2432),
    [aux_sym_preproc_if_token1] = ACTIONS(2432),
    [aux_sym_preproc_if_token2] = ACTIONS(2432),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2432),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2432),
    [sym_preproc_directive] = ACTIONS(2432),
    [anon_sym_LPAREN2] = ACTIONS(2434),
    [anon_sym_BANG] = ACTIONS(2434),
    [anon_sym_TILDE] = ACTIONS(2434),
    [anon_sym_DASH] = ACTIONS(2432),
    [anon_sym_PLUS] = ACTIONS(2432),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_AMP_AMP] = ACTIONS(2434),
    [anon_sym_AMP] = ACTIONS(2432),
    [anon_sym_SEMI] = ACTIONS(2434),
    [anon_sym___extension__] = ACTIONS(2432),
    [anon_sym_typedef] = ACTIONS(2432),
    [anon_sym_in] = ACTIONS(2432),
    [anon_sym_out] = ACTIONS(2432),
    [anon_sym_inout] = ACTIONS(2432),
    [anon_sym_extern] = ACTIONS(2432),
    [anon_sym___attribute__] = ACTIONS(2432),
    [anon_sym_COLON_COLON] = ACTIONS(2434),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2434),
    [anon_sym___declspec] = ACTIONS(2432),
    [anon_sym___based] = ACTIONS(2432),
    [anon_sym___cdecl] = ACTIONS(2432),
    [anon_sym___clrcall] = ACTIONS(2432),
    [anon_sym___stdcall] = ACTIONS(2432),
    [anon_sym___fastcall] = ACTIONS(2432),
    [anon_sym___thiscall] = ACTIONS(2432),
    [anon_sym___vectorcall] = ACTIONS(2432),
    [anon_sym_LBRACE] = ACTIONS(2434),
    [anon_sym_signed] = ACTIONS(2432),
    [anon_sym_unsigned] = ACTIONS(2432),
    [anon_sym_long] = ACTIONS(2432),
    [anon_sym_short] = ACTIONS(2432),
    [anon_sym_LBRACK] = ACTIONS(2432),
    [anon_sym_static] = ACTIONS(2432),
    [anon_sym_register] = ACTIONS(2432),
    [anon_sym_inline] = ACTIONS(2432),
    [anon_sym___inline] = ACTIONS(2432),
    [anon_sym___inline__] = ACTIONS(2432),
    [anon_sym___forceinline] = ACTIONS(2432),
    [anon_sym_thread_local] = ACTIONS(2432),
    [anon_sym___thread] = ACTIONS(2432),
    [anon_sym_const] = ACTIONS(2432),
    [anon_sym_constexpr] = ACTIONS(2432),
    [anon_sym_volatile] = ACTIONS(2432),
    [anon_sym_restrict] = ACTIONS(2432),
    [anon_sym___restrict__] = ACTIONS(2432),
    [anon_sym__Atomic] = ACTIONS(2432),
    [anon_sym__Noreturn] = ACTIONS(2432),
    [anon_sym_noreturn] = ACTIONS(2432),
    [anon_sym_mutable] = ACTIONS(2432),
    [anon_sym_constinit] = ACTIONS(2432),
    [anon_sym_consteval] = ACTIONS(2432),
    [anon_sym_alignas] = ACTIONS(2432),
    [anon_sym__Alignas] = ACTIONS(2432),
    [sym_primitive_type] = ACTIONS(2432),
    [anon_sym_enum] = ACTIONS(2432),
    [anon_sym_class] = ACTIONS(2432),
    [anon_sym_struct] = ACTIONS(2432),
    [anon_sym_union] = ACTIONS(2432),
    [anon_sym_if] = ACTIONS(2432),
    [anon_sym_switch] = ACTIONS(2432),
    [anon_sym_case] = ACTIONS(2432),
    [anon_sym_default] = ACTIONS(2432),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_do] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2432),
    [anon_sym_return] = ACTIONS(2432),
    [anon_sym_break] = ACTIONS(2432),
    [anon_sym_continue] = ACTIONS(2432),
    [anon_sym_goto] = ACTIONS(2432),
    [anon_sym___try] = ACTIONS(2432),
    [anon_sym___leave] = ACTIONS(2432),
    [anon_sym_not] = ACTIONS(2432),
    [anon_sym_compl] = ACTIONS(2432),
    [anon_sym_DASH_DASH] = ACTIONS(2434),
    [anon_sym_PLUS_PLUS] = ACTIONS(2434),
    [anon_sym_sizeof] = ACTIONS(2432),
    [anon_sym___alignof__] = ACTIONS(2432),
    [anon_sym___alignof] = ACTIONS(2432),
    [anon_sym__alignof] = ACTIONS(2432),
    [anon_sym_alignof] = ACTIONS(2432),
    [anon_sym__Alignof] = ACTIONS(2432),
    [anon_sym_offsetof] = ACTIONS(2432),
    [anon_sym__Generic] = ACTIONS(2432),
    [anon_sym_asm] = ACTIONS(2432),
    [anon_sym___asm__] = ACTIONS(2432),
    [sym_number_literal] = ACTIONS(2434),
    [anon_sym_L_SQUOTE] = ACTIONS(2434),
    [anon_sym_u_SQUOTE] = ACTIONS(2434),
    [anon_sym_U_SQUOTE] = ACTIONS(2434),
    [anon_sym_u8_SQUOTE] = ACTIONS(2434),
    [anon_sym_SQUOTE] = ACTIONS(2434),
    [anon_sym_L_DQUOTE] = ACTIONS(2434),
    [anon_sym_u_DQUOTE] = ACTIONS(2434),
    [anon_sym_U_DQUOTE] = ACTIONS(2434),
    [anon_sym_u8_DQUOTE] = ACTIONS(2434),
    [anon_sym_DQUOTE] = ACTIONS(2434),
    [sym_true] = ACTIONS(2432),
    [sym_false] = ACTIONS(2432),
    [anon_sym_NULL] = ACTIONS(2432),
    [anon_sym_nullptr] = ACTIONS(2432),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2432),
    [anon_sym_decltype] = ACTIONS(2432),
    [sym_virtual] = ACTIONS(2432),
    [anon_sym_explicit] = ACTIONS(2432),
    [anon_sym_typename] = ACTIONS(2432),
    [anon_sym_template] = ACTIONS(2432),
    [anon_sym_operator] = ACTIONS(2432),
    [anon_sym_try] = ACTIONS(2432),
    [anon_sym_delete] = ACTIONS(2432),
    [anon_sym_throw] = ACTIONS(2432),
    [anon_sym_namespace] = ACTIONS(2432),
    [anon_sym_using] = ACTIONS(2432),
    [anon_sym_static_assert] = ACTIONS(2432),
    [anon_sym_concept] = ACTIONS(2432),
    [anon_sym_co_return] = ACTIONS(2432),
    [anon_sym_co_yield] = ACTIONS(2432),
    [anon_sym_R_DQUOTE] = ACTIONS(2434),
    [anon_sym_LR_DQUOTE] = ACTIONS(2434),
    [anon_sym_uR_DQUOTE] = ACTIONS(2434),
    [anon_sym_UR_DQUOTE] = ACTIONS(2434),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2434),
    [anon_sym_co_await] = ACTIONS(2432),
    [anon_sym_new] = ACTIONS(2432),
    [anon_sym_requires] = ACTIONS(2432),
    [sym_this] = ACTIONS(2432),
    [anon_sym_discard] = ACTIONS(2432),
    [anon_sym_precise] = ACTIONS(2432),
    [anon_sym_shared] = ACTIONS(2432),
    [anon_sym_groupshared] = ACTIONS(2432),
    [anon_sym_uniform] = ACTIONS(2432),
    [anon_sym_row_major] = ACTIONS(2432),
    [anon_sym_column_major] = ACTIONS(2432),
    [anon_sym_globallycoherent] = ACTIONS(2432),
    [anon_sym_centroid] = ACTIONS(2432),
    [anon_sym_noperspective] = ACTIONS(2432),
    [anon_sym_nointerpolation] = ACTIONS(2432),
    [anon_sym_sample] = ACTIONS(2432),
    [anon_sym_linear] = ACTIONS(2432),
    [anon_sym_snorm] = ACTIONS(2432),
    [anon_sym_unorm] = ACTIONS(2432),
    [anon_sym_point] = ACTIONS(2432),
    [anon_sym_line] = ACTIONS(2432),
    [anon_sym_triangleadj] = ACTIONS(2432),
    [anon_sym_lineadj] = ACTIONS(2432),
    [anon_sym_triangle] = ACTIONS(2432),
    [anon_sym_cbuffer] = ACTIONS(2432),
  },
  [634] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_include_token1] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_BANG] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_DASH] = ACTIONS(2332),
    [anon_sym_PLUS] = ACTIONS(2332),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym_SEMI] = ACTIONS(2334),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym___cdecl] = ACTIONS(2332),
    [anon_sym___clrcall] = ACTIONS(2332),
    [anon_sym___stdcall] = ACTIONS(2332),
    [anon_sym___fastcall] = ACTIONS(2332),
    [anon_sym___thiscall] = ACTIONS(2332),
    [anon_sym___vectorcall] = ACTIONS(2332),
    [anon_sym_LBRACE] = ACTIONS(2334),
    [anon_sym_RBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_switch] = ACTIONS(2332),
    [anon_sym_case] = ACTIONS(2332),
    [anon_sym_default] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2332),
    [anon_sym_do] = ACTIONS(2332),
    [anon_sym_for] = ACTIONS(2332),
    [anon_sym_return] = ACTIONS(2332),
    [anon_sym_break] = ACTIONS(2332),
    [anon_sym_continue] = ACTIONS(2332),
    [anon_sym_goto] = ACTIONS(2332),
    [anon_sym___try] = ACTIONS(2332),
    [anon_sym___leave] = ACTIONS(2332),
    [anon_sym_not] = ACTIONS(2332),
    [anon_sym_compl] = ACTIONS(2332),
    [anon_sym_DASH_DASH] = ACTIONS(2334),
    [anon_sym_PLUS_PLUS] = ACTIONS(2334),
    [anon_sym_sizeof] = ACTIONS(2332),
    [anon_sym___alignof__] = ACTIONS(2332),
    [anon_sym___alignof] = ACTIONS(2332),
    [anon_sym__alignof] = ACTIONS(2332),
    [anon_sym_alignof] = ACTIONS(2332),
    [anon_sym__Alignof] = ACTIONS(2332),
    [anon_sym_offsetof] = ACTIONS(2332),
    [anon_sym__Generic] = ACTIONS(2332),
    [anon_sym_asm] = ACTIONS(2332),
    [anon_sym___asm__] = ACTIONS(2332),
    [sym_number_literal] = ACTIONS(2334),
    [anon_sym_L_SQUOTE] = ACTIONS(2334),
    [anon_sym_u_SQUOTE] = ACTIONS(2334),
    [anon_sym_U_SQUOTE] = ACTIONS(2334),
    [anon_sym_u8_SQUOTE] = ACTIONS(2334),
    [anon_sym_SQUOTE] = ACTIONS(2334),
    [anon_sym_L_DQUOTE] = ACTIONS(2334),
    [anon_sym_u_DQUOTE] = ACTIONS(2334),
    [anon_sym_U_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8_DQUOTE] = ACTIONS(2334),
    [anon_sym_DQUOTE] = ACTIONS(2334),
    [sym_true] = ACTIONS(2332),
    [sym_false] = ACTIONS(2332),
    [anon_sym_NULL] = ACTIONS(2332),
    [anon_sym_nullptr] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_try] = ACTIONS(2332),
    [anon_sym_delete] = ACTIONS(2332),
    [anon_sym_throw] = ACTIONS(2332),
    [anon_sym_namespace] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_concept] = ACTIONS(2332),
    [anon_sym_co_return] = ACTIONS(2332),
    [anon_sym_co_yield] = ACTIONS(2332),
    [anon_sym_R_DQUOTE] = ACTIONS(2334),
    [anon_sym_LR_DQUOTE] = ACTIONS(2334),
    [anon_sym_uR_DQUOTE] = ACTIONS(2334),
    [anon_sym_UR_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2334),
    [anon_sym_co_await] = ACTIONS(2332),
    [anon_sym_new] = ACTIONS(2332),
    [anon_sym_requires] = ACTIONS(2332),
    [sym_this] = ACTIONS(2332),
    [anon_sym_discard] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
    [anon_sym_cbuffer] = ACTIONS(2332),
  },
  [635] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_include_token1] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_BANG] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_DASH] = ACTIONS(2332),
    [anon_sym_PLUS] = ACTIONS(2332),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym_SEMI] = ACTIONS(2334),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym___cdecl] = ACTIONS(2332),
    [anon_sym___clrcall] = ACTIONS(2332),
    [anon_sym___stdcall] = ACTIONS(2332),
    [anon_sym___fastcall] = ACTIONS(2332),
    [anon_sym___thiscall] = ACTIONS(2332),
    [anon_sym___vectorcall] = ACTIONS(2332),
    [anon_sym_LBRACE] = ACTIONS(2334),
    [anon_sym_RBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_switch] = ACTIONS(2332),
    [anon_sym_case] = ACTIONS(2332),
    [anon_sym_default] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2332),
    [anon_sym_do] = ACTIONS(2332),
    [anon_sym_for] = ACTIONS(2332),
    [anon_sym_return] = ACTIONS(2332),
    [anon_sym_break] = ACTIONS(2332),
    [anon_sym_continue] = ACTIONS(2332),
    [anon_sym_goto] = ACTIONS(2332),
    [anon_sym___try] = ACTIONS(2332),
    [anon_sym___leave] = ACTIONS(2332),
    [anon_sym_not] = ACTIONS(2332),
    [anon_sym_compl] = ACTIONS(2332),
    [anon_sym_DASH_DASH] = ACTIONS(2334),
    [anon_sym_PLUS_PLUS] = ACTIONS(2334),
    [anon_sym_sizeof] = ACTIONS(2332),
    [anon_sym___alignof__] = ACTIONS(2332),
    [anon_sym___alignof] = ACTIONS(2332),
    [anon_sym__alignof] = ACTIONS(2332),
    [anon_sym_alignof] = ACTIONS(2332),
    [anon_sym__Alignof] = ACTIONS(2332),
    [anon_sym_offsetof] = ACTIONS(2332),
    [anon_sym__Generic] = ACTIONS(2332),
    [anon_sym_asm] = ACTIONS(2332),
    [anon_sym___asm__] = ACTIONS(2332),
    [sym_number_literal] = ACTIONS(2334),
    [anon_sym_L_SQUOTE] = ACTIONS(2334),
    [anon_sym_u_SQUOTE] = ACTIONS(2334),
    [anon_sym_U_SQUOTE] = ACTIONS(2334),
    [anon_sym_u8_SQUOTE] = ACTIONS(2334),
    [anon_sym_SQUOTE] = ACTIONS(2334),
    [anon_sym_L_DQUOTE] = ACTIONS(2334),
    [anon_sym_u_DQUOTE] = ACTIONS(2334),
    [anon_sym_U_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8_DQUOTE] = ACTIONS(2334),
    [anon_sym_DQUOTE] = ACTIONS(2334),
    [sym_true] = ACTIONS(2332),
    [sym_false] = ACTIONS(2332),
    [anon_sym_NULL] = ACTIONS(2332),
    [anon_sym_nullptr] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_try] = ACTIONS(2332),
    [anon_sym_delete] = ACTIONS(2332),
    [anon_sym_throw] = ACTIONS(2332),
    [anon_sym_namespace] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_concept] = ACTIONS(2332),
    [anon_sym_co_return] = ACTIONS(2332),
    [anon_sym_co_yield] = ACTIONS(2332),
    [anon_sym_R_DQUOTE] = ACTIONS(2334),
    [anon_sym_LR_DQUOTE] = ACTIONS(2334),
    [anon_sym_uR_DQUOTE] = ACTIONS(2334),
    [anon_sym_UR_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2334),
    [anon_sym_co_await] = ACTIONS(2332),
    [anon_sym_new] = ACTIONS(2332),
    [anon_sym_requires] = ACTIONS(2332),
    [sym_this] = ACTIONS(2332),
    [anon_sym_discard] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
    [anon_sym_cbuffer] = ACTIONS(2332),
  },
  [636] = {
    [sym_identifier] = ACTIONS(2336),
    [aux_sym_preproc_include_token1] = ACTIONS(2336),
    [aux_sym_preproc_def_token1] = ACTIONS(2336),
    [aux_sym_preproc_if_token1] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2336),
    [sym_preproc_directive] = ACTIONS(2336),
    [anon_sym_LPAREN2] = ACTIONS(2338),
    [anon_sym_BANG] = ACTIONS(2338),
    [anon_sym_TILDE] = ACTIONS(2338),
    [anon_sym_DASH] = ACTIONS(2336),
    [anon_sym_PLUS] = ACTIONS(2336),
    [anon_sym_STAR] = ACTIONS(2338),
    [anon_sym_AMP_AMP] = ACTIONS(2338),
    [anon_sym_AMP] = ACTIONS(2336),
    [anon_sym_SEMI] = ACTIONS(2338),
    [anon_sym___extension__] = ACTIONS(2336),
    [anon_sym_typedef] = ACTIONS(2336),
    [anon_sym_in] = ACTIONS(2336),
    [anon_sym_out] = ACTIONS(2336),
    [anon_sym_inout] = ACTIONS(2336),
    [anon_sym_extern] = ACTIONS(2336),
    [anon_sym___attribute__] = ACTIONS(2336),
    [anon_sym_COLON_COLON] = ACTIONS(2338),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2338),
    [anon_sym___declspec] = ACTIONS(2336),
    [anon_sym___based] = ACTIONS(2336),
    [anon_sym___cdecl] = ACTIONS(2336),
    [anon_sym___clrcall] = ACTIONS(2336),
    [anon_sym___stdcall] = ACTIONS(2336),
    [anon_sym___fastcall] = ACTIONS(2336),
    [anon_sym___thiscall] = ACTIONS(2336),
    [anon_sym___vectorcall] = ACTIONS(2336),
    [anon_sym_LBRACE] = ACTIONS(2338),
    [anon_sym_RBRACE] = ACTIONS(2338),
    [anon_sym_signed] = ACTIONS(2336),
    [anon_sym_unsigned] = ACTIONS(2336),
    [anon_sym_long] = ACTIONS(2336),
    [anon_sym_short] = ACTIONS(2336),
    [anon_sym_LBRACK] = ACTIONS(2336),
    [anon_sym_static] = ACTIONS(2336),
    [anon_sym_register] = ACTIONS(2336),
    [anon_sym_inline] = ACTIONS(2336),
    [anon_sym___inline] = ACTIONS(2336),
    [anon_sym___inline__] = ACTIONS(2336),
    [anon_sym___forceinline] = ACTIONS(2336),
    [anon_sym_thread_local] = ACTIONS(2336),
    [anon_sym___thread] = ACTIONS(2336),
    [anon_sym_const] = ACTIONS(2336),
    [anon_sym_constexpr] = ACTIONS(2336),
    [anon_sym_volatile] = ACTIONS(2336),
    [anon_sym_restrict] = ACTIONS(2336),
    [anon_sym___restrict__] = ACTIONS(2336),
    [anon_sym__Atomic] = ACTIONS(2336),
    [anon_sym__Noreturn] = ACTIONS(2336),
    [anon_sym_noreturn] = ACTIONS(2336),
    [anon_sym_mutable] = ACTIONS(2336),
    [anon_sym_constinit] = ACTIONS(2336),
    [anon_sym_consteval] = ACTIONS(2336),
    [anon_sym_alignas] = ACTIONS(2336),
    [anon_sym__Alignas] = ACTIONS(2336),
    [sym_primitive_type] = ACTIONS(2336),
    [anon_sym_enum] = ACTIONS(2336),
    [anon_sym_class] = ACTIONS(2336),
    [anon_sym_struct] = ACTIONS(2336),
    [anon_sym_union] = ACTIONS(2336),
    [anon_sym_if] = ACTIONS(2336),
    [anon_sym_switch] = ACTIONS(2336),
    [anon_sym_case] = ACTIONS(2336),
    [anon_sym_default] = ACTIONS(2336),
    [anon_sym_while] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(2336),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_return] = ACTIONS(2336),
    [anon_sym_break] = ACTIONS(2336),
    [anon_sym_continue] = ACTIONS(2336),
    [anon_sym_goto] = ACTIONS(2336),
    [anon_sym___try] = ACTIONS(2336),
    [anon_sym___leave] = ACTIONS(2336),
    [anon_sym_not] = ACTIONS(2336),
    [anon_sym_compl] = ACTIONS(2336),
    [anon_sym_DASH_DASH] = ACTIONS(2338),
    [anon_sym_PLUS_PLUS] = ACTIONS(2338),
    [anon_sym_sizeof] = ACTIONS(2336),
    [anon_sym___alignof__] = ACTIONS(2336),
    [anon_sym___alignof] = ACTIONS(2336),
    [anon_sym__alignof] = ACTIONS(2336),
    [anon_sym_alignof] = ACTIONS(2336),
    [anon_sym__Alignof] = ACTIONS(2336),
    [anon_sym_offsetof] = ACTIONS(2336),
    [anon_sym__Generic] = ACTIONS(2336),
    [anon_sym_asm] = ACTIONS(2336),
    [anon_sym___asm__] = ACTIONS(2336),
    [sym_number_literal] = ACTIONS(2338),
    [anon_sym_L_SQUOTE] = ACTIONS(2338),
    [anon_sym_u_SQUOTE] = ACTIONS(2338),
    [anon_sym_U_SQUOTE] = ACTIONS(2338),
    [anon_sym_u8_SQUOTE] = ACTIONS(2338),
    [anon_sym_SQUOTE] = ACTIONS(2338),
    [anon_sym_L_DQUOTE] = ACTIONS(2338),
    [anon_sym_u_DQUOTE] = ACTIONS(2338),
    [anon_sym_U_DQUOTE] = ACTIONS(2338),
    [anon_sym_u8_DQUOTE] = ACTIONS(2338),
    [anon_sym_DQUOTE] = ACTIONS(2338),
    [sym_true] = ACTIONS(2336),
    [sym_false] = ACTIONS(2336),
    [anon_sym_NULL] = ACTIONS(2336),
    [anon_sym_nullptr] = ACTIONS(2336),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2336),
    [anon_sym_decltype] = ACTIONS(2336),
    [sym_virtual] = ACTIONS(2336),
    [anon_sym_explicit] = ACTIONS(2336),
    [anon_sym_typename] = ACTIONS(2336),
    [anon_sym_template] = ACTIONS(2336),
    [anon_sym_operator] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2336),
    [anon_sym_delete] = ACTIONS(2336),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_namespace] = ACTIONS(2336),
    [anon_sym_using] = ACTIONS(2336),
    [anon_sym_static_assert] = ACTIONS(2336),
    [anon_sym_concept] = ACTIONS(2336),
    [anon_sym_co_return] = ACTIONS(2336),
    [anon_sym_co_yield] = ACTIONS(2336),
    [anon_sym_R_DQUOTE] = ACTIONS(2338),
    [anon_sym_LR_DQUOTE] = ACTIONS(2338),
    [anon_sym_uR_DQUOTE] = ACTIONS(2338),
    [anon_sym_UR_DQUOTE] = ACTIONS(2338),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2338),
    [anon_sym_co_await] = ACTIONS(2336),
    [anon_sym_new] = ACTIONS(2336),
    [anon_sym_requires] = ACTIONS(2336),
    [sym_this] = ACTIONS(2336),
    [anon_sym_discard] = ACTIONS(2336),
    [anon_sym_precise] = ACTIONS(2336),
    [anon_sym_shared] = ACTIONS(2336),
    [anon_sym_groupshared] = ACTIONS(2336),
    [anon_sym_uniform] = ACTIONS(2336),
    [anon_sym_row_major] = ACTIONS(2336),
    [anon_sym_column_major] = ACTIONS(2336),
    [anon_sym_globallycoherent] = ACTIONS(2336),
    [anon_sym_centroid] = ACTIONS(2336),
    [anon_sym_noperspective] = ACTIONS(2336),
    [anon_sym_nointerpolation] = ACTIONS(2336),
    [anon_sym_sample] = ACTIONS(2336),
    [anon_sym_linear] = ACTIONS(2336),
    [anon_sym_snorm] = ACTIONS(2336),
    [anon_sym_unorm] = ACTIONS(2336),
    [anon_sym_point] = ACTIONS(2336),
    [anon_sym_line] = ACTIONS(2336),
    [anon_sym_triangleadj] = ACTIONS(2336),
    [anon_sym_lineadj] = ACTIONS(2336),
    [anon_sym_triangle] = ACTIONS(2336),
    [anon_sym_cbuffer] = ACTIONS(2336),
  },
  [637] = {
    [sym_identifier] = ACTIONS(2336),
    [aux_sym_preproc_include_token1] = ACTIONS(2336),
    [aux_sym_preproc_def_token1] = ACTIONS(2336),
    [aux_sym_preproc_if_token1] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2336),
    [sym_preproc_directive] = ACTIONS(2336),
    [anon_sym_LPAREN2] = ACTIONS(2338),
    [anon_sym_BANG] = ACTIONS(2338),
    [anon_sym_TILDE] = ACTIONS(2338),
    [anon_sym_DASH] = ACTIONS(2336),
    [anon_sym_PLUS] = ACTIONS(2336),
    [anon_sym_STAR] = ACTIONS(2338),
    [anon_sym_AMP_AMP] = ACTIONS(2338),
    [anon_sym_AMP] = ACTIONS(2336),
    [anon_sym_SEMI] = ACTIONS(2338),
    [anon_sym___extension__] = ACTIONS(2336),
    [anon_sym_typedef] = ACTIONS(2336),
    [anon_sym_in] = ACTIONS(2336),
    [anon_sym_out] = ACTIONS(2336),
    [anon_sym_inout] = ACTIONS(2336),
    [anon_sym_extern] = ACTIONS(2336),
    [anon_sym___attribute__] = ACTIONS(2336),
    [anon_sym_COLON_COLON] = ACTIONS(2338),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2338),
    [anon_sym___declspec] = ACTIONS(2336),
    [anon_sym___based] = ACTIONS(2336),
    [anon_sym___cdecl] = ACTIONS(2336),
    [anon_sym___clrcall] = ACTIONS(2336),
    [anon_sym___stdcall] = ACTIONS(2336),
    [anon_sym___fastcall] = ACTIONS(2336),
    [anon_sym___thiscall] = ACTIONS(2336),
    [anon_sym___vectorcall] = ACTIONS(2336),
    [anon_sym_LBRACE] = ACTIONS(2338),
    [anon_sym_RBRACE] = ACTIONS(2338),
    [anon_sym_signed] = ACTIONS(2336),
    [anon_sym_unsigned] = ACTIONS(2336),
    [anon_sym_long] = ACTIONS(2336),
    [anon_sym_short] = ACTIONS(2336),
    [anon_sym_LBRACK] = ACTIONS(2336),
    [anon_sym_static] = ACTIONS(2336),
    [anon_sym_register] = ACTIONS(2336),
    [anon_sym_inline] = ACTIONS(2336),
    [anon_sym___inline] = ACTIONS(2336),
    [anon_sym___inline__] = ACTIONS(2336),
    [anon_sym___forceinline] = ACTIONS(2336),
    [anon_sym_thread_local] = ACTIONS(2336),
    [anon_sym___thread] = ACTIONS(2336),
    [anon_sym_const] = ACTIONS(2336),
    [anon_sym_constexpr] = ACTIONS(2336),
    [anon_sym_volatile] = ACTIONS(2336),
    [anon_sym_restrict] = ACTIONS(2336),
    [anon_sym___restrict__] = ACTIONS(2336),
    [anon_sym__Atomic] = ACTIONS(2336),
    [anon_sym__Noreturn] = ACTIONS(2336),
    [anon_sym_noreturn] = ACTIONS(2336),
    [anon_sym_mutable] = ACTIONS(2336),
    [anon_sym_constinit] = ACTIONS(2336),
    [anon_sym_consteval] = ACTIONS(2336),
    [anon_sym_alignas] = ACTIONS(2336),
    [anon_sym__Alignas] = ACTIONS(2336),
    [sym_primitive_type] = ACTIONS(2336),
    [anon_sym_enum] = ACTIONS(2336),
    [anon_sym_class] = ACTIONS(2336),
    [anon_sym_struct] = ACTIONS(2336),
    [anon_sym_union] = ACTIONS(2336),
    [anon_sym_if] = ACTIONS(2336),
    [anon_sym_switch] = ACTIONS(2336),
    [anon_sym_case] = ACTIONS(2336),
    [anon_sym_default] = ACTIONS(2336),
    [anon_sym_while] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(2336),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_return] = ACTIONS(2336),
    [anon_sym_break] = ACTIONS(2336),
    [anon_sym_continue] = ACTIONS(2336),
    [anon_sym_goto] = ACTIONS(2336),
    [anon_sym___try] = ACTIONS(2336),
    [anon_sym___leave] = ACTIONS(2336),
    [anon_sym_not] = ACTIONS(2336),
    [anon_sym_compl] = ACTIONS(2336),
    [anon_sym_DASH_DASH] = ACTIONS(2338),
    [anon_sym_PLUS_PLUS] = ACTIONS(2338),
    [anon_sym_sizeof] = ACTIONS(2336),
    [anon_sym___alignof__] = ACTIONS(2336),
    [anon_sym___alignof] = ACTIONS(2336),
    [anon_sym__alignof] = ACTIONS(2336),
    [anon_sym_alignof] = ACTIONS(2336),
    [anon_sym__Alignof] = ACTIONS(2336),
    [anon_sym_offsetof] = ACTIONS(2336),
    [anon_sym__Generic] = ACTIONS(2336),
    [anon_sym_asm] = ACTIONS(2336),
    [anon_sym___asm__] = ACTIONS(2336),
    [sym_number_literal] = ACTIONS(2338),
    [anon_sym_L_SQUOTE] = ACTIONS(2338),
    [anon_sym_u_SQUOTE] = ACTIONS(2338),
    [anon_sym_U_SQUOTE] = ACTIONS(2338),
    [anon_sym_u8_SQUOTE] = ACTIONS(2338),
    [anon_sym_SQUOTE] = ACTIONS(2338),
    [anon_sym_L_DQUOTE] = ACTIONS(2338),
    [anon_sym_u_DQUOTE] = ACTIONS(2338),
    [anon_sym_U_DQUOTE] = ACTIONS(2338),
    [anon_sym_u8_DQUOTE] = ACTIONS(2338),
    [anon_sym_DQUOTE] = ACTIONS(2338),
    [sym_true] = ACTIONS(2336),
    [sym_false] = ACTIONS(2336),
    [anon_sym_NULL] = ACTIONS(2336),
    [anon_sym_nullptr] = ACTIONS(2336),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2336),
    [anon_sym_decltype] = ACTIONS(2336),
    [sym_virtual] = ACTIONS(2336),
    [anon_sym_explicit] = ACTIONS(2336),
    [anon_sym_typename] = ACTIONS(2336),
    [anon_sym_template] = ACTIONS(2336),
    [anon_sym_operator] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2336),
    [anon_sym_delete] = ACTIONS(2336),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_namespace] = ACTIONS(2336),
    [anon_sym_using] = ACTIONS(2336),
    [anon_sym_static_assert] = ACTIONS(2336),
    [anon_sym_concept] = ACTIONS(2336),
    [anon_sym_co_return] = ACTIONS(2336),
    [anon_sym_co_yield] = ACTIONS(2336),
    [anon_sym_R_DQUOTE] = ACTIONS(2338),
    [anon_sym_LR_DQUOTE] = ACTIONS(2338),
    [anon_sym_uR_DQUOTE] = ACTIONS(2338),
    [anon_sym_UR_DQUOTE] = ACTIONS(2338),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2338),
    [anon_sym_co_await] = ACTIONS(2336),
    [anon_sym_new] = ACTIONS(2336),
    [anon_sym_requires] = ACTIONS(2336),
    [sym_this] = ACTIONS(2336),
    [anon_sym_discard] = ACTIONS(2336),
    [anon_sym_precise] = ACTIONS(2336),
    [anon_sym_shared] = ACTIONS(2336),
    [anon_sym_groupshared] = ACTIONS(2336),
    [anon_sym_uniform] = ACTIONS(2336),
    [anon_sym_row_major] = ACTIONS(2336),
    [anon_sym_column_major] = ACTIONS(2336),
    [anon_sym_globallycoherent] = ACTIONS(2336),
    [anon_sym_centroid] = ACTIONS(2336),
    [anon_sym_noperspective] = ACTIONS(2336),
    [anon_sym_nointerpolation] = ACTIONS(2336),
    [anon_sym_sample] = ACTIONS(2336),
    [anon_sym_linear] = ACTIONS(2336),
    [anon_sym_snorm] = ACTIONS(2336),
    [anon_sym_unorm] = ACTIONS(2336),
    [anon_sym_point] = ACTIONS(2336),
    [anon_sym_line] = ACTIONS(2336),
    [anon_sym_triangleadj] = ACTIONS(2336),
    [anon_sym_lineadj] = ACTIONS(2336),
    [anon_sym_triangle] = ACTIONS(2336),
    [anon_sym_cbuffer] = ACTIONS(2336),
  },
  [638] = {
    [sym_identifier] = ACTIONS(2561),
    [aux_sym_preproc_include_token1] = ACTIONS(2561),
    [aux_sym_preproc_def_token1] = ACTIONS(2561),
    [aux_sym_preproc_if_token1] = ACTIONS(2561),
    [aux_sym_preproc_if_token2] = ACTIONS(2561),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2561),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2561),
    [sym_preproc_directive] = ACTIONS(2561),
    [anon_sym_LPAREN2] = ACTIONS(2563),
    [anon_sym_BANG] = ACTIONS(2563),
    [anon_sym_TILDE] = ACTIONS(2563),
    [anon_sym_DASH] = ACTIONS(2561),
    [anon_sym_PLUS] = ACTIONS(2561),
    [anon_sym_STAR] = ACTIONS(2563),
    [anon_sym_AMP_AMP] = ACTIONS(2563),
    [anon_sym_AMP] = ACTIONS(2561),
    [anon_sym_SEMI] = ACTIONS(2563),
    [anon_sym___extension__] = ACTIONS(2561),
    [anon_sym_typedef] = ACTIONS(2561),
    [anon_sym_in] = ACTIONS(2561),
    [anon_sym_out] = ACTIONS(2561),
    [anon_sym_inout] = ACTIONS(2561),
    [anon_sym_extern] = ACTIONS(2561),
    [anon_sym___attribute__] = ACTIONS(2561),
    [anon_sym_COLON_COLON] = ACTIONS(2563),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2563),
    [anon_sym___declspec] = ACTIONS(2561),
    [anon_sym___based] = ACTIONS(2561),
    [anon_sym___cdecl] = ACTIONS(2561),
    [anon_sym___clrcall] = ACTIONS(2561),
    [anon_sym___stdcall] = ACTIONS(2561),
    [anon_sym___fastcall] = ACTIONS(2561),
    [anon_sym___thiscall] = ACTIONS(2561),
    [anon_sym___vectorcall] = ACTIONS(2561),
    [anon_sym_LBRACE] = ACTIONS(2563),
    [anon_sym_signed] = ACTIONS(2561),
    [anon_sym_unsigned] = ACTIONS(2561),
    [anon_sym_long] = ACTIONS(2561),
    [anon_sym_short] = ACTIONS(2561),
    [anon_sym_LBRACK] = ACTIONS(2561),
    [anon_sym_static] = ACTIONS(2561),
    [anon_sym_register] = ACTIONS(2561),
    [anon_sym_inline] = ACTIONS(2561),
    [anon_sym___inline] = ACTIONS(2561),
    [anon_sym___inline__] = ACTIONS(2561),
    [anon_sym___forceinline] = ACTIONS(2561),
    [anon_sym_thread_local] = ACTIONS(2561),
    [anon_sym___thread] = ACTIONS(2561),
    [anon_sym_const] = ACTIONS(2561),
    [anon_sym_constexpr] = ACTIONS(2561),
    [anon_sym_volatile] = ACTIONS(2561),
    [anon_sym_restrict] = ACTIONS(2561),
    [anon_sym___restrict__] = ACTIONS(2561),
    [anon_sym__Atomic] = ACTIONS(2561),
    [anon_sym__Noreturn] = ACTIONS(2561),
    [anon_sym_noreturn] = ACTIONS(2561),
    [anon_sym_mutable] = ACTIONS(2561),
    [anon_sym_constinit] = ACTIONS(2561),
    [anon_sym_consteval] = ACTIONS(2561),
    [anon_sym_alignas] = ACTIONS(2561),
    [anon_sym__Alignas] = ACTIONS(2561),
    [sym_primitive_type] = ACTIONS(2561),
    [anon_sym_enum] = ACTIONS(2561),
    [anon_sym_class] = ACTIONS(2561),
    [anon_sym_struct] = ACTIONS(2561),
    [anon_sym_union] = ACTIONS(2561),
    [anon_sym_if] = ACTIONS(2561),
    [anon_sym_switch] = ACTIONS(2561),
    [anon_sym_case] = ACTIONS(2561),
    [anon_sym_default] = ACTIONS(2561),
    [anon_sym_while] = ACTIONS(2561),
    [anon_sym_do] = ACTIONS(2561),
    [anon_sym_for] = ACTIONS(2561),
    [anon_sym_return] = ACTIONS(2561),
    [anon_sym_break] = ACTIONS(2561),
    [anon_sym_continue] = ACTIONS(2561),
    [anon_sym_goto] = ACTIONS(2561),
    [anon_sym___try] = ACTIONS(2561),
    [anon_sym___leave] = ACTIONS(2561),
    [anon_sym_not] = ACTIONS(2561),
    [anon_sym_compl] = ACTIONS(2561),
    [anon_sym_DASH_DASH] = ACTIONS(2563),
    [anon_sym_PLUS_PLUS] = ACTIONS(2563),
    [anon_sym_sizeof] = ACTIONS(2561),
    [anon_sym___alignof__] = ACTIONS(2561),
    [anon_sym___alignof] = ACTIONS(2561),
    [anon_sym__alignof] = ACTIONS(2561),
    [anon_sym_alignof] = ACTIONS(2561),
    [anon_sym__Alignof] = ACTIONS(2561),
    [anon_sym_offsetof] = ACTIONS(2561),
    [anon_sym__Generic] = ACTIONS(2561),
    [anon_sym_asm] = ACTIONS(2561),
    [anon_sym___asm__] = ACTIONS(2561),
    [sym_number_literal] = ACTIONS(2563),
    [anon_sym_L_SQUOTE] = ACTIONS(2563),
    [anon_sym_u_SQUOTE] = ACTIONS(2563),
    [anon_sym_U_SQUOTE] = ACTIONS(2563),
    [anon_sym_u8_SQUOTE] = ACTIONS(2563),
    [anon_sym_SQUOTE] = ACTIONS(2563),
    [anon_sym_L_DQUOTE] = ACTIONS(2563),
    [anon_sym_u_DQUOTE] = ACTIONS(2563),
    [anon_sym_U_DQUOTE] = ACTIONS(2563),
    [anon_sym_u8_DQUOTE] = ACTIONS(2563),
    [anon_sym_DQUOTE] = ACTIONS(2563),
    [sym_true] = ACTIONS(2561),
    [sym_false] = ACTIONS(2561),
    [anon_sym_NULL] = ACTIONS(2561),
    [anon_sym_nullptr] = ACTIONS(2561),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2561),
    [anon_sym_decltype] = ACTIONS(2561),
    [sym_virtual] = ACTIONS(2561),
    [anon_sym_explicit] = ACTIONS(2561),
    [anon_sym_typename] = ACTIONS(2561),
    [anon_sym_template] = ACTIONS(2561),
    [anon_sym_operator] = ACTIONS(2561),
    [anon_sym_try] = ACTIONS(2561),
    [anon_sym_delete] = ACTIONS(2561),
    [anon_sym_throw] = ACTIONS(2561),
    [anon_sym_namespace] = ACTIONS(2561),
    [anon_sym_using] = ACTIONS(2561),
    [anon_sym_static_assert] = ACTIONS(2561),
    [anon_sym_concept] = ACTIONS(2561),
    [anon_sym_co_return] = ACTIONS(2561),
    [anon_sym_co_yield] = ACTIONS(2561),
    [anon_sym_R_DQUOTE] = ACTIONS(2563),
    [anon_sym_LR_DQUOTE] = ACTIONS(2563),
    [anon_sym_uR_DQUOTE] = ACTIONS(2563),
    [anon_sym_UR_DQUOTE] = ACTIONS(2563),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2563),
    [anon_sym_co_await] = ACTIONS(2561),
    [anon_sym_new] = ACTIONS(2561),
    [anon_sym_requires] = ACTIONS(2561),
    [sym_this] = ACTIONS(2561),
    [anon_sym_discard] = ACTIONS(2561),
    [anon_sym_precise] = ACTIONS(2561),
    [anon_sym_shared] = ACTIONS(2561),
    [anon_sym_groupshared] = ACTIONS(2561),
    [anon_sym_uniform] = ACTIONS(2561),
    [anon_sym_row_major] = ACTIONS(2561),
    [anon_sym_column_major] = ACTIONS(2561),
    [anon_sym_globallycoherent] = ACTIONS(2561),
    [anon_sym_centroid] = ACTIONS(2561),
    [anon_sym_noperspective] = ACTIONS(2561),
    [anon_sym_nointerpolation] = ACTIONS(2561),
    [anon_sym_sample] = ACTIONS(2561),
    [anon_sym_linear] = ACTIONS(2561),
    [anon_sym_snorm] = ACTIONS(2561),
    [anon_sym_unorm] = ACTIONS(2561),
    [anon_sym_point] = ACTIONS(2561),
    [anon_sym_line] = ACTIONS(2561),
    [anon_sym_triangleadj] = ACTIONS(2561),
    [anon_sym_lineadj] = ACTIONS(2561),
    [anon_sym_triangle] = ACTIONS(2561),
    [anon_sym_cbuffer] = ACTIONS(2561),
  },
  [639] = {
    [sym_identifier] = ACTIONS(2440),
    [aux_sym_preproc_include_token1] = ACTIONS(2440),
    [aux_sym_preproc_def_token1] = ACTIONS(2440),
    [aux_sym_preproc_if_token1] = ACTIONS(2440),
    [aux_sym_preproc_if_token2] = ACTIONS(2440),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2440),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2440),
    [sym_preproc_directive] = ACTIONS(2440),
    [anon_sym_LPAREN2] = ACTIONS(2442),
    [anon_sym_BANG] = ACTIONS(2442),
    [anon_sym_TILDE] = ACTIONS(2442),
    [anon_sym_DASH] = ACTIONS(2440),
    [anon_sym_PLUS] = ACTIONS(2440),
    [anon_sym_STAR] = ACTIONS(2442),
    [anon_sym_AMP_AMP] = ACTIONS(2442),
    [anon_sym_AMP] = ACTIONS(2440),
    [anon_sym_SEMI] = ACTIONS(2442),
    [anon_sym___extension__] = ACTIONS(2440),
    [anon_sym_typedef] = ACTIONS(2440),
    [anon_sym_in] = ACTIONS(2440),
    [anon_sym_out] = ACTIONS(2440),
    [anon_sym_inout] = ACTIONS(2440),
    [anon_sym_extern] = ACTIONS(2440),
    [anon_sym___attribute__] = ACTIONS(2440),
    [anon_sym_COLON_COLON] = ACTIONS(2442),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2442),
    [anon_sym___declspec] = ACTIONS(2440),
    [anon_sym___based] = ACTIONS(2440),
    [anon_sym___cdecl] = ACTIONS(2440),
    [anon_sym___clrcall] = ACTIONS(2440),
    [anon_sym___stdcall] = ACTIONS(2440),
    [anon_sym___fastcall] = ACTIONS(2440),
    [anon_sym___thiscall] = ACTIONS(2440),
    [anon_sym___vectorcall] = ACTIONS(2440),
    [anon_sym_LBRACE] = ACTIONS(2442),
    [anon_sym_signed] = ACTIONS(2440),
    [anon_sym_unsigned] = ACTIONS(2440),
    [anon_sym_long] = ACTIONS(2440),
    [anon_sym_short] = ACTIONS(2440),
    [anon_sym_LBRACK] = ACTIONS(2440),
    [anon_sym_static] = ACTIONS(2440),
    [anon_sym_register] = ACTIONS(2440),
    [anon_sym_inline] = ACTIONS(2440),
    [anon_sym___inline] = ACTIONS(2440),
    [anon_sym___inline__] = ACTIONS(2440),
    [anon_sym___forceinline] = ACTIONS(2440),
    [anon_sym_thread_local] = ACTIONS(2440),
    [anon_sym___thread] = ACTIONS(2440),
    [anon_sym_const] = ACTIONS(2440),
    [anon_sym_constexpr] = ACTIONS(2440),
    [anon_sym_volatile] = ACTIONS(2440),
    [anon_sym_restrict] = ACTIONS(2440),
    [anon_sym___restrict__] = ACTIONS(2440),
    [anon_sym__Atomic] = ACTIONS(2440),
    [anon_sym__Noreturn] = ACTIONS(2440),
    [anon_sym_noreturn] = ACTIONS(2440),
    [anon_sym_mutable] = ACTIONS(2440),
    [anon_sym_constinit] = ACTIONS(2440),
    [anon_sym_consteval] = ACTIONS(2440),
    [anon_sym_alignas] = ACTIONS(2440),
    [anon_sym__Alignas] = ACTIONS(2440),
    [sym_primitive_type] = ACTIONS(2440),
    [anon_sym_enum] = ACTIONS(2440),
    [anon_sym_class] = ACTIONS(2440),
    [anon_sym_struct] = ACTIONS(2440),
    [anon_sym_union] = ACTIONS(2440),
    [anon_sym_if] = ACTIONS(2440),
    [anon_sym_switch] = ACTIONS(2440),
    [anon_sym_case] = ACTIONS(2440),
    [anon_sym_default] = ACTIONS(2440),
    [anon_sym_while] = ACTIONS(2440),
    [anon_sym_do] = ACTIONS(2440),
    [anon_sym_for] = ACTIONS(2440),
    [anon_sym_return] = ACTIONS(2440),
    [anon_sym_break] = ACTIONS(2440),
    [anon_sym_continue] = ACTIONS(2440),
    [anon_sym_goto] = ACTIONS(2440),
    [anon_sym___try] = ACTIONS(2440),
    [anon_sym___leave] = ACTIONS(2440),
    [anon_sym_not] = ACTIONS(2440),
    [anon_sym_compl] = ACTIONS(2440),
    [anon_sym_DASH_DASH] = ACTIONS(2442),
    [anon_sym_PLUS_PLUS] = ACTIONS(2442),
    [anon_sym_sizeof] = ACTIONS(2440),
    [anon_sym___alignof__] = ACTIONS(2440),
    [anon_sym___alignof] = ACTIONS(2440),
    [anon_sym__alignof] = ACTIONS(2440),
    [anon_sym_alignof] = ACTIONS(2440),
    [anon_sym__Alignof] = ACTIONS(2440),
    [anon_sym_offsetof] = ACTIONS(2440),
    [anon_sym__Generic] = ACTIONS(2440),
    [anon_sym_asm] = ACTIONS(2440),
    [anon_sym___asm__] = ACTIONS(2440),
    [sym_number_literal] = ACTIONS(2442),
    [anon_sym_L_SQUOTE] = ACTIONS(2442),
    [anon_sym_u_SQUOTE] = ACTIONS(2442),
    [anon_sym_U_SQUOTE] = ACTIONS(2442),
    [anon_sym_u8_SQUOTE] = ACTIONS(2442),
    [anon_sym_SQUOTE] = ACTIONS(2442),
    [anon_sym_L_DQUOTE] = ACTIONS(2442),
    [anon_sym_u_DQUOTE] = ACTIONS(2442),
    [anon_sym_U_DQUOTE] = ACTIONS(2442),
    [anon_sym_u8_DQUOTE] = ACTIONS(2442),
    [anon_sym_DQUOTE] = ACTIONS(2442),
    [sym_true] = ACTIONS(2440),
    [sym_false] = ACTIONS(2440),
    [anon_sym_NULL] = ACTIONS(2440),
    [anon_sym_nullptr] = ACTIONS(2440),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2440),
    [anon_sym_decltype] = ACTIONS(2440),
    [sym_virtual] = ACTIONS(2440),
    [anon_sym_explicit] = ACTIONS(2440),
    [anon_sym_typename] = ACTIONS(2440),
    [anon_sym_template] = ACTIONS(2440),
    [anon_sym_operator] = ACTIONS(2440),
    [anon_sym_try] = ACTIONS(2440),
    [anon_sym_delete] = ACTIONS(2440),
    [anon_sym_throw] = ACTIONS(2440),
    [anon_sym_namespace] = ACTIONS(2440),
    [anon_sym_using] = ACTIONS(2440),
    [anon_sym_static_assert] = ACTIONS(2440),
    [anon_sym_concept] = ACTIONS(2440),
    [anon_sym_co_return] = ACTIONS(2440),
    [anon_sym_co_yield] = ACTIONS(2440),
    [anon_sym_R_DQUOTE] = ACTIONS(2442),
    [anon_sym_LR_DQUOTE] = ACTIONS(2442),
    [anon_sym_uR_DQUOTE] = ACTIONS(2442),
    [anon_sym_UR_DQUOTE] = ACTIONS(2442),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2442),
    [anon_sym_co_await] = ACTIONS(2440),
    [anon_sym_new] = ACTIONS(2440),
    [anon_sym_requires] = ACTIONS(2440),
    [sym_this] = ACTIONS(2440),
    [anon_sym_discard] = ACTIONS(2440),
    [anon_sym_precise] = ACTIONS(2440),
    [anon_sym_shared] = ACTIONS(2440),
    [anon_sym_groupshared] = ACTIONS(2440),
    [anon_sym_uniform] = ACTIONS(2440),
    [anon_sym_row_major] = ACTIONS(2440),
    [anon_sym_column_major] = ACTIONS(2440),
    [anon_sym_globallycoherent] = ACTIONS(2440),
    [anon_sym_centroid] = ACTIONS(2440),
    [anon_sym_noperspective] = ACTIONS(2440),
    [anon_sym_nointerpolation] = ACTIONS(2440),
    [anon_sym_sample] = ACTIONS(2440),
    [anon_sym_linear] = ACTIONS(2440),
    [anon_sym_snorm] = ACTIONS(2440),
    [anon_sym_unorm] = ACTIONS(2440),
    [anon_sym_point] = ACTIONS(2440),
    [anon_sym_line] = ACTIONS(2440),
    [anon_sym_triangleadj] = ACTIONS(2440),
    [anon_sym_lineadj] = ACTIONS(2440),
    [anon_sym_triangle] = ACTIONS(2440),
    [anon_sym_cbuffer] = ACTIONS(2440),
  },
  [640] = {
    [sym_identifier] = ACTIONS(2462),
    [aux_sym_preproc_include_token1] = ACTIONS(2462),
    [aux_sym_preproc_def_token1] = ACTIONS(2462),
    [aux_sym_preproc_if_token1] = ACTIONS(2462),
    [aux_sym_preproc_if_token2] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2462),
    [sym_preproc_directive] = ACTIONS(2462),
    [anon_sym_LPAREN2] = ACTIONS(2464),
    [anon_sym_BANG] = ACTIONS(2464),
    [anon_sym_TILDE] = ACTIONS(2464),
    [anon_sym_DASH] = ACTIONS(2462),
    [anon_sym_PLUS] = ACTIONS(2462),
    [anon_sym_STAR] = ACTIONS(2464),
    [anon_sym_AMP_AMP] = ACTIONS(2464),
    [anon_sym_AMP] = ACTIONS(2462),
    [anon_sym_SEMI] = ACTIONS(2464),
    [anon_sym___extension__] = ACTIONS(2462),
    [anon_sym_typedef] = ACTIONS(2462),
    [anon_sym_in] = ACTIONS(2462),
    [anon_sym_out] = ACTIONS(2462),
    [anon_sym_inout] = ACTIONS(2462),
    [anon_sym_extern] = ACTIONS(2462),
    [anon_sym___attribute__] = ACTIONS(2462),
    [anon_sym_COLON_COLON] = ACTIONS(2464),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2464),
    [anon_sym___declspec] = ACTIONS(2462),
    [anon_sym___based] = ACTIONS(2462),
    [anon_sym___cdecl] = ACTIONS(2462),
    [anon_sym___clrcall] = ACTIONS(2462),
    [anon_sym___stdcall] = ACTIONS(2462),
    [anon_sym___fastcall] = ACTIONS(2462),
    [anon_sym___thiscall] = ACTIONS(2462),
    [anon_sym___vectorcall] = ACTIONS(2462),
    [anon_sym_LBRACE] = ACTIONS(2464),
    [anon_sym_signed] = ACTIONS(2462),
    [anon_sym_unsigned] = ACTIONS(2462),
    [anon_sym_long] = ACTIONS(2462),
    [anon_sym_short] = ACTIONS(2462),
    [anon_sym_LBRACK] = ACTIONS(2462),
    [anon_sym_static] = ACTIONS(2462),
    [anon_sym_register] = ACTIONS(2462),
    [anon_sym_inline] = ACTIONS(2462),
    [anon_sym___inline] = ACTIONS(2462),
    [anon_sym___inline__] = ACTIONS(2462),
    [anon_sym___forceinline] = ACTIONS(2462),
    [anon_sym_thread_local] = ACTIONS(2462),
    [anon_sym___thread] = ACTIONS(2462),
    [anon_sym_const] = ACTIONS(2462),
    [anon_sym_constexpr] = ACTIONS(2462),
    [anon_sym_volatile] = ACTIONS(2462),
    [anon_sym_restrict] = ACTIONS(2462),
    [anon_sym___restrict__] = ACTIONS(2462),
    [anon_sym__Atomic] = ACTIONS(2462),
    [anon_sym__Noreturn] = ACTIONS(2462),
    [anon_sym_noreturn] = ACTIONS(2462),
    [anon_sym_mutable] = ACTIONS(2462),
    [anon_sym_constinit] = ACTIONS(2462),
    [anon_sym_consteval] = ACTIONS(2462),
    [anon_sym_alignas] = ACTIONS(2462),
    [anon_sym__Alignas] = ACTIONS(2462),
    [sym_primitive_type] = ACTIONS(2462),
    [anon_sym_enum] = ACTIONS(2462),
    [anon_sym_class] = ACTIONS(2462),
    [anon_sym_struct] = ACTIONS(2462),
    [anon_sym_union] = ACTIONS(2462),
    [anon_sym_if] = ACTIONS(2462),
    [anon_sym_switch] = ACTIONS(2462),
    [anon_sym_case] = ACTIONS(2462),
    [anon_sym_default] = ACTIONS(2462),
    [anon_sym_while] = ACTIONS(2462),
    [anon_sym_do] = ACTIONS(2462),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_break] = ACTIONS(2462),
    [anon_sym_continue] = ACTIONS(2462),
    [anon_sym_goto] = ACTIONS(2462),
    [anon_sym___try] = ACTIONS(2462),
    [anon_sym___leave] = ACTIONS(2462),
    [anon_sym_not] = ACTIONS(2462),
    [anon_sym_compl] = ACTIONS(2462),
    [anon_sym_DASH_DASH] = ACTIONS(2464),
    [anon_sym_PLUS_PLUS] = ACTIONS(2464),
    [anon_sym_sizeof] = ACTIONS(2462),
    [anon_sym___alignof__] = ACTIONS(2462),
    [anon_sym___alignof] = ACTIONS(2462),
    [anon_sym__alignof] = ACTIONS(2462),
    [anon_sym_alignof] = ACTIONS(2462),
    [anon_sym__Alignof] = ACTIONS(2462),
    [anon_sym_offsetof] = ACTIONS(2462),
    [anon_sym__Generic] = ACTIONS(2462),
    [anon_sym_asm] = ACTIONS(2462),
    [anon_sym___asm__] = ACTIONS(2462),
    [sym_number_literal] = ACTIONS(2464),
    [anon_sym_L_SQUOTE] = ACTIONS(2464),
    [anon_sym_u_SQUOTE] = ACTIONS(2464),
    [anon_sym_U_SQUOTE] = ACTIONS(2464),
    [anon_sym_u8_SQUOTE] = ACTIONS(2464),
    [anon_sym_SQUOTE] = ACTIONS(2464),
    [anon_sym_L_DQUOTE] = ACTIONS(2464),
    [anon_sym_u_DQUOTE] = ACTIONS(2464),
    [anon_sym_U_DQUOTE] = ACTIONS(2464),
    [anon_sym_u8_DQUOTE] = ACTIONS(2464),
    [anon_sym_DQUOTE] = ACTIONS(2464),
    [sym_true] = ACTIONS(2462),
    [sym_false] = ACTIONS(2462),
    [anon_sym_NULL] = ACTIONS(2462),
    [anon_sym_nullptr] = ACTIONS(2462),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2462),
    [anon_sym_decltype] = ACTIONS(2462),
    [sym_virtual] = ACTIONS(2462),
    [anon_sym_explicit] = ACTIONS(2462),
    [anon_sym_typename] = ACTIONS(2462),
    [anon_sym_template] = ACTIONS(2462),
    [anon_sym_operator] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2462),
    [anon_sym_delete] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2462),
    [anon_sym_namespace] = ACTIONS(2462),
    [anon_sym_using] = ACTIONS(2462),
    [anon_sym_static_assert] = ACTIONS(2462),
    [anon_sym_concept] = ACTIONS(2462),
    [anon_sym_co_return] = ACTIONS(2462),
    [anon_sym_co_yield] = ACTIONS(2462),
    [anon_sym_R_DQUOTE] = ACTIONS(2464),
    [anon_sym_LR_DQUOTE] = ACTIONS(2464),
    [anon_sym_uR_DQUOTE] = ACTIONS(2464),
    [anon_sym_UR_DQUOTE] = ACTIONS(2464),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2464),
    [anon_sym_co_await] = ACTIONS(2462),
    [anon_sym_new] = ACTIONS(2462),
    [anon_sym_requires] = ACTIONS(2462),
    [sym_this] = ACTIONS(2462),
    [anon_sym_discard] = ACTIONS(2462),
    [anon_sym_precise] = ACTIONS(2462),
    [anon_sym_shared] = ACTIONS(2462),
    [anon_sym_groupshared] = ACTIONS(2462),
    [anon_sym_uniform] = ACTIONS(2462),
    [anon_sym_row_major] = ACTIONS(2462),
    [anon_sym_column_major] = ACTIONS(2462),
    [anon_sym_globallycoherent] = ACTIONS(2462),
    [anon_sym_centroid] = ACTIONS(2462),
    [anon_sym_noperspective] = ACTIONS(2462),
    [anon_sym_nointerpolation] = ACTIONS(2462),
    [anon_sym_sample] = ACTIONS(2462),
    [anon_sym_linear] = ACTIONS(2462),
    [anon_sym_snorm] = ACTIONS(2462),
    [anon_sym_unorm] = ACTIONS(2462),
    [anon_sym_point] = ACTIONS(2462),
    [anon_sym_line] = ACTIONS(2462),
    [anon_sym_triangleadj] = ACTIONS(2462),
    [anon_sym_lineadj] = ACTIONS(2462),
    [anon_sym_triangle] = ACTIONS(2462),
    [anon_sym_cbuffer] = ACTIONS(2462),
  },
  [641] = {
    [sym_identifier] = ACTIONS(2577),
    [aux_sym_preproc_include_token1] = ACTIONS(2577),
    [aux_sym_preproc_def_token1] = ACTIONS(2577),
    [aux_sym_preproc_if_token1] = ACTIONS(2577),
    [aux_sym_preproc_if_token2] = ACTIONS(2577),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2577),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2577),
    [sym_preproc_directive] = ACTIONS(2577),
    [anon_sym_LPAREN2] = ACTIONS(2579),
    [anon_sym_BANG] = ACTIONS(2579),
    [anon_sym_TILDE] = ACTIONS(2579),
    [anon_sym_DASH] = ACTIONS(2577),
    [anon_sym_PLUS] = ACTIONS(2577),
    [anon_sym_STAR] = ACTIONS(2579),
    [anon_sym_AMP_AMP] = ACTIONS(2579),
    [anon_sym_AMP] = ACTIONS(2577),
    [anon_sym_SEMI] = ACTIONS(2579),
    [anon_sym___extension__] = ACTIONS(2577),
    [anon_sym_typedef] = ACTIONS(2577),
    [anon_sym_in] = ACTIONS(2577),
    [anon_sym_out] = ACTIONS(2577),
    [anon_sym_inout] = ACTIONS(2577),
    [anon_sym_extern] = ACTIONS(2577),
    [anon_sym___attribute__] = ACTIONS(2577),
    [anon_sym_COLON_COLON] = ACTIONS(2579),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2579),
    [anon_sym___declspec] = ACTIONS(2577),
    [anon_sym___based] = ACTIONS(2577),
    [anon_sym___cdecl] = ACTIONS(2577),
    [anon_sym___clrcall] = ACTIONS(2577),
    [anon_sym___stdcall] = ACTIONS(2577),
    [anon_sym___fastcall] = ACTIONS(2577),
    [anon_sym___thiscall] = ACTIONS(2577),
    [anon_sym___vectorcall] = ACTIONS(2577),
    [anon_sym_LBRACE] = ACTIONS(2579),
    [anon_sym_signed] = ACTIONS(2577),
    [anon_sym_unsigned] = ACTIONS(2577),
    [anon_sym_long] = ACTIONS(2577),
    [anon_sym_short] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2577),
    [anon_sym_static] = ACTIONS(2577),
    [anon_sym_register] = ACTIONS(2577),
    [anon_sym_inline] = ACTIONS(2577),
    [anon_sym___inline] = ACTIONS(2577),
    [anon_sym___inline__] = ACTIONS(2577),
    [anon_sym___forceinline] = ACTIONS(2577),
    [anon_sym_thread_local] = ACTIONS(2577),
    [anon_sym___thread] = ACTIONS(2577),
    [anon_sym_const] = ACTIONS(2577),
    [anon_sym_constexpr] = ACTIONS(2577),
    [anon_sym_volatile] = ACTIONS(2577),
    [anon_sym_restrict] = ACTIONS(2577),
    [anon_sym___restrict__] = ACTIONS(2577),
    [anon_sym__Atomic] = ACTIONS(2577),
    [anon_sym__Noreturn] = ACTIONS(2577),
    [anon_sym_noreturn] = ACTIONS(2577),
    [anon_sym_mutable] = ACTIONS(2577),
    [anon_sym_constinit] = ACTIONS(2577),
    [anon_sym_consteval] = ACTIONS(2577),
    [anon_sym_alignas] = ACTIONS(2577),
    [anon_sym__Alignas] = ACTIONS(2577),
    [sym_primitive_type] = ACTIONS(2577),
    [anon_sym_enum] = ACTIONS(2577),
    [anon_sym_class] = ACTIONS(2577),
    [anon_sym_struct] = ACTIONS(2577),
    [anon_sym_union] = ACTIONS(2577),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_switch] = ACTIONS(2577),
    [anon_sym_case] = ACTIONS(2577),
    [anon_sym_default] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(2577),
    [anon_sym_do] = ACTIONS(2577),
    [anon_sym_for] = ACTIONS(2577),
    [anon_sym_return] = ACTIONS(2577),
    [anon_sym_break] = ACTIONS(2577),
    [anon_sym_continue] = ACTIONS(2577),
    [anon_sym_goto] = ACTIONS(2577),
    [anon_sym___try] = ACTIONS(2577),
    [anon_sym___leave] = ACTIONS(2577),
    [anon_sym_not] = ACTIONS(2577),
    [anon_sym_compl] = ACTIONS(2577),
    [anon_sym_DASH_DASH] = ACTIONS(2579),
    [anon_sym_PLUS_PLUS] = ACTIONS(2579),
    [anon_sym_sizeof] = ACTIONS(2577),
    [anon_sym___alignof__] = ACTIONS(2577),
    [anon_sym___alignof] = ACTIONS(2577),
    [anon_sym__alignof] = ACTIONS(2577),
    [anon_sym_alignof] = ACTIONS(2577),
    [anon_sym__Alignof] = ACTIONS(2577),
    [anon_sym_offsetof] = ACTIONS(2577),
    [anon_sym__Generic] = ACTIONS(2577),
    [anon_sym_asm] = ACTIONS(2577),
    [anon_sym___asm__] = ACTIONS(2577),
    [sym_number_literal] = ACTIONS(2579),
    [anon_sym_L_SQUOTE] = ACTIONS(2579),
    [anon_sym_u_SQUOTE] = ACTIONS(2579),
    [anon_sym_U_SQUOTE] = ACTIONS(2579),
    [anon_sym_u8_SQUOTE] = ACTIONS(2579),
    [anon_sym_SQUOTE] = ACTIONS(2579),
    [anon_sym_L_DQUOTE] = ACTIONS(2579),
    [anon_sym_u_DQUOTE] = ACTIONS(2579),
    [anon_sym_U_DQUOTE] = ACTIONS(2579),
    [anon_sym_u8_DQUOTE] = ACTIONS(2579),
    [anon_sym_DQUOTE] = ACTIONS(2579),
    [sym_true] = ACTIONS(2577),
    [sym_false] = ACTIONS(2577),
    [anon_sym_NULL] = ACTIONS(2577),
    [anon_sym_nullptr] = ACTIONS(2577),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2577),
    [anon_sym_decltype] = ACTIONS(2577),
    [sym_virtual] = ACTIONS(2577),
    [anon_sym_explicit] = ACTIONS(2577),
    [anon_sym_typename] = ACTIONS(2577),
    [anon_sym_template] = ACTIONS(2577),
    [anon_sym_operator] = ACTIONS(2577),
    [anon_sym_try] = ACTIONS(2577),
    [anon_sym_delete] = ACTIONS(2577),
    [anon_sym_throw] = ACTIONS(2577),
    [anon_sym_namespace] = ACTIONS(2577),
    [anon_sym_using] = ACTIONS(2577),
    [anon_sym_static_assert] = ACTIONS(2577),
    [anon_sym_concept] = ACTIONS(2577),
    [anon_sym_co_return] = ACTIONS(2577),
    [anon_sym_co_yield] = ACTIONS(2577),
    [anon_sym_R_DQUOTE] = ACTIONS(2579),
    [anon_sym_LR_DQUOTE] = ACTIONS(2579),
    [anon_sym_uR_DQUOTE] = ACTIONS(2579),
    [anon_sym_UR_DQUOTE] = ACTIONS(2579),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2579),
    [anon_sym_co_await] = ACTIONS(2577),
    [anon_sym_new] = ACTIONS(2577),
    [anon_sym_requires] = ACTIONS(2577),
    [sym_this] = ACTIONS(2577),
    [anon_sym_discard] = ACTIONS(2577),
    [anon_sym_precise] = ACTIONS(2577),
    [anon_sym_shared] = ACTIONS(2577),
    [anon_sym_groupshared] = ACTIONS(2577),
    [anon_sym_uniform] = ACTIONS(2577),
    [anon_sym_row_major] = ACTIONS(2577),
    [anon_sym_column_major] = ACTIONS(2577),
    [anon_sym_globallycoherent] = ACTIONS(2577),
    [anon_sym_centroid] = ACTIONS(2577),
    [anon_sym_noperspective] = ACTIONS(2577),
    [anon_sym_nointerpolation] = ACTIONS(2577),
    [anon_sym_sample] = ACTIONS(2577),
    [anon_sym_linear] = ACTIONS(2577),
    [anon_sym_snorm] = ACTIONS(2577),
    [anon_sym_unorm] = ACTIONS(2577),
    [anon_sym_point] = ACTIONS(2577),
    [anon_sym_line] = ACTIONS(2577),
    [anon_sym_triangleadj] = ACTIONS(2577),
    [anon_sym_lineadj] = ACTIONS(2577),
    [anon_sym_triangle] = ACTIONS(2577),
    [anon_sym_cbuffer] = ACTIONS(2577),
  },
  [642] = {
    [sym_identifier] = ACTIONS(2510),
    [aux_sym_preproc_include_token1] = ACTIONS(2510),
    [aux_sym_preproc_def_token1] = ACTIONS(2510),
    [aux_sym_preproc_if_token1] = ACTIONS(2510),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2510),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2510),
    [sym_preproc_directive] = ACTIONS(2510),
    [anon_sym_LPAREN2] = ACTIONS(2512),
    [anon_sym_BANG] = ACTIONS(2512),
    [anon_sym_TILDE] = ACTIONS(2512),
    [anon_sym_DASH] = ACTIONS(2510),
    [anon_sym_PLUS] = ACTIONS(2510),
    [anon_sym_STAR] = ACTIONS(2512),
    [anon_sym_AMP_AMP] = ACTIONS(2512),
    [anon_sym_AMP] = ACTIONS(2510),
    [anon_sym_SEMI] = ACTIONS(2512),
    [anon_sym___extension__] = ACTIONS(2510),
    [anon_sym_typedef] = ACTIONS(2510),
    [anon_sym_in] = ACTIONS(2510),
    [anon_sym_out] = ACTIONS(2510),
    [anon_sym_inout] = ACTIONS(2510),
    [anon_sym_extern] = ACTIONS(2510),
    [anon_sym___attribute__] = ACTIONS(2510),
    [anon_sym_COLON_COLON] = ACTIONS(2512),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2512),
    [anon_sym___declspec] = ACTIONS(2510),
    [anon_sym___based] = ACTIONS(2510),
    [anon_sym___cdecl] = ACTIONS(2510),
    [anon_sym___clrcall] = ACTIONS(2510),
    [anon_sym___stdcall] = ACTIONS(2510),
    [anon_sym___fastcall] = ACTIONS(2510),
    [anon_sym___thiscall] = ACTIONS(2510),
    [anon_sym___vectorcall] = ACTIONS(2510),
    [anon_sym_LBRACE] = ACTIONS(2512),
    [anon_sym_RBRACE] = ACTIONS(2512),
    [anon_sym_signed] = ACTIONS(2510),
    [anon_sym_unsigned] = ACTIONS(2510),
    [anon_sym_long] = ACTIONS(2510),
    [anon_sym_short] = ACTIONS(2510),
    [anon_sym_LBRACK] = ACTIONS(2510),
    [anon_sym_static] = ACTIONS(2510),
    [anon_sym_register] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(2510),
    [anon_sym___inline] = ACTIONS(2510),
    [anon_sym___inline__] = ACTIONS(2510),
    [anon_sym___forceinline] = ACTIONS(2510),
    [anon_sym_thread_local] = ACTIONS(2510),
    [anon_sym___thread] = ACTIONS(2510),
    [anon_sym_const] = ACTIONS(2510),
    [anon_sym_constexpr] = ACTIONS(2510),
    [anon_sym_volatile] = ACTIONS(2510),
    [anon_sym_restrict] = ACTIONS(2510),
    [anon_sym___restrict__] = ACTIONS(2510),
    [anon_sym__Atomic] = ACTIONS(2510),
    [anon_sym__Noreturn] = ACTIONS(2510),
    [anon_sym_noreturn] = ACTIONS(2510),
    [anon_sym_mutable] = ACTIONS(2510),
    [anon_sym_constinit] = ACTIONS(2510),
    [anon_sym_consteval] = ACTIONS(2510),
    [anon_sym_alignas] = ACTIONS(2510),
    [anon_sym__Alignas] = ACTIONS(2510),
    [sym_primitive_type] = ACTIONS(2510),
    [anon_sym_enum] = ACTIONS(2510),
    [anon_sym_class] = ACTIONS(2510),
    [anon_sym_struct] = ACTIONS(2510),
    [anon_sym_union] = ACTIONS(2510),
    [anon_sym_if] = ACTIONS(2510),
    [anon_sym_switch] = ACTIONS(2510),
    [anon_sym_case] = ACTIONS(2510),
    [anon_sym_default] = ACTIONS(2510),
    [anon_sym_while] = ACTIONS(2510),
    [anon_sym_do] = ACTIONS(2510),
    [anon_sym_for] = ACTIONS(2510),
    [anon_sym_return] = ACTIONS(2510),
    [anon_sym_break] = ACTIONS(2510),
    [anon_sym_continue] = ACTIONS(2510),
    [anon_sym_goto] = ACTIONS(2510),
    [anon_sym___try] = ACTIONS(2510),
    [anon_sym___leave] = ACTIONS(2510),
    [anon_sym_not] = ACTIONS(2510),
    [anon_sym_compl] = ACTIONS(2510),
    [anon_sym_DASH_DASH] = ACTIONS(2512),
    [anon_sym_PLUS_PLUS] = ACTIONS(2512),
    [anon_sym_sizeof] = ACTIONS(2510),
    [anon_sym___alignof__] = ACTIONS(2510),
    [anon_sym___alignof] = ACTIONS(2510),
    [anon_sym__alignof] = ACTIONS(2510),
    [anon_sym_alignof] = ACTIONS(2510),
    [anon_sym__Alignof] = ACTIONS(2510),
    [anon_sym_offsetof] = ACTIONS(2510),
    [anon_sym__Generic] = ACTIONS(2510),
    [anon_sym_asm] = ACTIONS(2510),
    [anon_sym___asm__] = ACTIONS(2510),
    [sym_number_literal] = ACTIONS(2512),
    [anon_sym_L_SQUOTE] = ACTIONS(2512),
    [anon_sym_u_SQUOTE] = ACTIONS(2512),
    [anon_sym_U_SQUOTE] = ACTIONS(2512),
    [anon_sym_u8_SQUOTE] = ACTIONS(2512),
    [anon_sym_SQUOTE] = ACTIONS(2512),
    [anon_sym_L_DQUOTE] = ACTIONS(2512),
    [anon_sym_u_DQUOTE] = ACTIONS(2512),
    [anon_sym_U_DQUOTE] = ACTIONS(2512),
    [anon_sym_u8_DQUOTE] = ACTIONS(2512),
    [anon_sym_DQUOTE] = ACTIONS(2512),
    [sym_true] = ACTIONS(2510),
    [sym_false] = ACTIONS(2510),
    [anon_sym_NULL] = ACTIONS(2510),
    [anon_sym_nullptr] = ACTIONS(2510),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2510),
    [anon_sym_decltype] = ACTIONS(2510),
    [sym_virtual] = ACTIONS(2510),
    [anon_sym_explicit] = ACTIONS(2510),
    [anon_sym_typename] = ACTIONS(2510),
    [anon_sym_template] = ACTIONS(2510),
    [anon_sym_operator] = ACTIONS(2510),
    [anon_sym_try] = ACTIONS(2510),
    [anon_sym_delete] = ACTIONS(2510),
    [anon_sym_throw] = ACTIONS(2510),
    [anon_sym_namespace] = ACTIONS(2510),
    [anon_sym_using] = ACTIONS(2510),
    [anon_sym_static_assert] = ACTIONS(2510),
    [anon_sym_concept] = ACTIONS(2510),
    [anon_sym_co_return] = ACTIONS(2510),
    [anon_sym_co_yield] = ACTIONS(2510),
    [anon_sym_R_DQUOTE] = ACTIONS(2512),
    [anon_sym_LR_DQUOTE] = ACTIONS(2512),
    [anon_sym_uR_DQUOTE] = ACTIONS(2512),
    [anon_sym_UR_DQUOTE] = ACTIONS(2512),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2512),
    [anon_sym_co_await] = ACTIONS(2510),
    [anon_sym_new] = ACTIONS(2510),
    [anon_sym_requires] = ACTIONS(2510),
    [sym_this] = ACTIONS(2510),
    [anon_sym_discard] = ACTIONS(2510),
    [anon_sym_precise] = ACTIONS(2510),
    [anon_sym_shared] = ACTIONS(2510),
    [anon_sym_groupshared] = ACTIONS(2510),
    [anon_sym_uniform] = ACTIONS(2510),
    [anon_sym_row_major] = ACTIONS(2510),
    [anon_sym_column_major] = ACTIONS(2510),
    [anon_sym_globallycoherent] = ACTIONS(2510),
    [anon_sym_centroid] = ACTIONS(2510),
    [anon_sym_noperspective] = ACTIONS(2510),
    [anon_sym_nointerpolation] = ACTIONS(2510),
    [anon_sym_sample] = ACTIONS(2510),
    [anon_sym_linear] = ACTIONS(2510),
    [anon_sym_snorm] = ACTIONS(2510),
    [anon_sym_unorm] = ACTIONS(2510),
    [anon_sym_point] = ACTIONS(2510),
    [anon_sym_line] = ACTIONS(2510),
    [anon_sym_triangleadj] = ACTIONS(2510),
    [anon_sym_lineadj] = ACTIONS(2510),
    [anon_sym_triangle] = ACTIONS(2510),
    [anon_sym_cbuffer] = ACTIONS(2510),
  },
  [643] = {
    [sym_identifier] = ACTIONS(2340),
    [aux_sym_preproc_include_token1] = ACTIONS(2340),
    [aux_sym_preproc_def_token1] = ACTIONS(2340),
    [aux_sym_preproc_if_token1] = ACTIONS(2340),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2340),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2340),
    [sym_preproc_directive] = ACTIONS(2340),
    [anon_sym_LPAREN2] = ACTIONS(2342),
    [anon_sym_BANG] = ACTIONS(2342),
    [anon_sym_TILDE] = ACTIONS(2342),
    [anon_sym_DASH] = ACTIONS(2340),
    [anon_sym_PLUS] = ACTIONS(2340),
    [anon_sym_STAR] = ACTIONS(2342),
    [anon_sym_AMP_AMP] = ACTIONS(2342),
    [anon_sym_AMP] = ACTIONS(2340),
    [anon_sym_SEMI] = ACTIONS(2342),
    [anon_sym___extension__] = ACTIONS(2340),
    [anon_sym_typedef] = ACTIONS(2340),
    [anon_sym_in] = ACTIONS(2340),
    [anon_sym_out] = ACTIONS(2340),
    [anon_sym_inout] = ACTIONS(2340),
    [anon_sym_extern] = ACTIONS(2340),
    [anon_sym___attribute__] = ACTIONS(2340),
    [anon_sym_COLON_COLON] = ACTIONS(2342),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2342),
    [anon_sym___declspec] = ACTIONS(2340),
    [anon_sym___based] = ACTIONS(2340),
    [anon_sym___cdecl] = ACTIONS(2340),
    [anon_sym___clrcall] = ACTIONS(2340),
    [anon_sym___stdcall] = ACTIONS(2340),
    [anon_sym___fastcall] = ACTIONS(2340),
    [anon_sym___thiscall] = ACTIONS(2340),
    [anon_sym___vectorcall] = ACTIONS(2340),
    [anon_sym_LBRACE] = ACTIONS(2342),
    [anon_sym_RBRACE] = ACTIONS(2342),
    [anon_sym_signed] = ACTIONS(2340),
    [anon_sym_unsigned] = ACTIONS(2340),
    [anon_sym_long] = ACTIONS(2340),
    [anon_sym_short] = ACTIONS(2340),
    [anon_sym_LBRACK] = ACTIONS(2340),
    [anon_sym_static] = ACTIONS(2340),
    [anon_sym_register] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(2340),
    [anon_sym___inline] = ACTIONS(2340),
    [anon_sym___inline__] = ACTIONS(2340),
    [anon_sym___forceinline] = ACTIONS(2340),
    [anon_sym_thread_local] = ACTIONS(2340),
    [anon_sym___thread] = ACTIONS(2340),
    [anon_sym_const] = ACTIONS(2340),
    [anon_sym_constexpr] = ACTIONS(2340),
    [anon_sym_volatile] = ACTIONS(2340),
    [anon_sym_restrict] = ACTIONS(2340),
    [anon_sym___restrict__] = ACTIONS(2340),
    [anon_sym__Atomic] = ACTIONS(2340),
    [anon_sym__Noreturn] = ACTIONS(2340),
    [anon_sym_noreturn] = ACTIONS(2340),
    [anon_sym_mutable] = ACTIONS(2340),
    [anon_sym_constinit] = ACTIONS(2340),
    [anon_sym_consteval] = ACTIONS(2340),
    [anon_sym_alignas] = ACTIONS(2340),
    [anon_sym__Alignas] = ACTIONS(2340),
    [sym_primitive_type] = ACTIONS(2340),
    [anon_sym_enum] = ACTIONS(2340),
    [anon_sym_class] = ACTIONS(2340),
    [anon_sym_struct] = ACTIONS(2340),
    [anon_sym_union] = ACTIONS(2340),
    [anon_sym_if] = ACTIONS(2340),
    [anon_sym_switch] = ACTIONS(2340),
    [anon_sym_case] = ACTIONS(2340),
    [anon_sym_default] = ACTIONS(2340),
    [anon_sym_while] = ACTIONS(2340),
    [anon_sym_do] = ACTIONS(2340),
    [anon_sym_for] = ACTIONS(2340),
    [anon_sym_return] = ACTIONS(2340),
    [anon_sym_break] = ACTIONS(2340),
    [anon_sym_continue] = ACTIONS(2340),
    [anon_sym_goto] = ACTIONS(2340),
    [anon_sym___try] = ACTIONS(2340),
    [anon_sym___leave] = ACTIONS(2340),
    [anon_sym_not] = ACTIONS(2340),
    [anon_sym_compl] = ACTIONS(2340),
    [anon_sym_DASH_DASH] = ACTIONS(2342),
    [anon_sym_PLUS_PLUS] = ACTIONS(2342),
    [anon_sym_sizeof] = ACTIONS(2340),
    [anon_sym___alignof__] = ACTIONS(2340),
    [anon_sym___alignof] = ACTIONS(2340),
    [anon_sym__alignof] = ACTIONS(2340),
    [anon_sym_alignof] = ACTIONS(2340),
    [anon_sym__Alignof] = ACTIONS(2340),
    [anon_sym_offsetof] = ACTIONS(2340),
    [anon_sym__Generic] = ACTIONS(2340),
    [anon_sym_asm] = ACTIONS(2340),
    [anon_sym___asm__] = ACTIONS(2340),
    [sym_number_literal] = ACTIONS(2342),
    [anon_sym_L_SQUOTE] = ACTIONS(2342),
    [anon_sym_u_SQUOTE] = ACTIONS(2342),
    [anon_sym_U_SQUOTE] = ACTIONS(2342),
    [anon_sym_u8_SQUOTE] = ACTIONS(2342),
    [anon_sym_SQUOTE] = ACTIONS(2342),
    [anon_sym_L_DQUOTE] = ACTIONS(2342),
    [anon_sym_u_DQUOTE] = ACTIONS(2342),
    [anon_sym_U_DQUOTE] = ACTIONS(2342),
    [anon_sym_u8_DQUOTE] = ACTIONS(2342),
    [anon_sym_DQUOTE] = ACTIONS(2342),
    [sym_true] = ACTIONS(2340),
    [sym_false] = ACTIONS(2340),
    [anon_sym_NULL] = ACTIONS(2340),
    [anon_sym_nullptr] = ACTIONS(2340),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2340),
    [anon_sym_decltype] = ACTIONS(2340),
    [sym_virtual] = ACTIONS(2340),
    [anon_sym_explicit] = ACTIONS(2340),
    [anon_sym_typename] = ACTIONS(2340),
    [anon_sym_template] = ACTIONS(2340),
    [anon_sym_operator] = ACTIONS(2340),
    [anon_sym_try] = ACTIONS(2340),
    [anon_sym_delete] = ACTIONS(2340),
    [anon_sym_throw] = ACTIONS(2340),
    [anon_sym_namespace] = ACTIONS(2340),
    [anon_sym_using] = ACTIONS(2340),
    [anon_sym_static_assert] = ACTIONS(2340),
    [anon_sym_concept] = ACTIONS(2340),
    [anon_sym_co_return] = ACTIONS(2340),
    [anon_sym_co_yield] = ACTIONS(2340),
    [anon_sym_R_DQUOTE] = ACTIONS(2342),
    [anon_sym_LR_DQUOTE] = ACTIONS(2342),
    [anon_sym_uR_DQUOTE] = ACTIONS(2342),
    [anon_sym_UR_DQUOTE] = ACTIONS(2342),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2342),
    [anon_sym_co_await] = ACTIONS(2340),
    [anon_sym_new] = ACTIONS(2340),
    [anon_sym_requires] = ACTIONS(2340),
    [sym_this] = ACTIONS(2340),
    [anon_sym_discard] = ACTIONS(2340),
    [anon_sym_precise] = ACTIONS(2340),
    [anon_sym_shared] = ACTIONS(2340),
    [anon_sym_groupshared] = ACTIONS(2340),
    [anon_sym_uniform] = ACTIONS(2340),
    [anon_sym_row_major] = ACTIONS(2340),
    [anon_sym_column_major] = ACTIONS(2340),
    [anon_sym_globallycoherent] = ACTIONS(2340),
    [anon_sym_centroid] = ACTIONS(2340),
    [anon_sym_noperspective] = ACTIONS(2340),
    [anon_sym_nointerpolation] = ACTIONS(2340),
    [anon_sym_sample] = ACTIONS(2340),
    [anon_sym_linear] = ACTIONS(2340),
    [anon_sym_snorm] = ACTIONS(2340),
    [anon_sym_unorm] = ACTIONS(2340),
    [anon_sym_point] = ACTIONS(2340),
    [anon_sym_line] = ACTIONS(2340),
    [anon_sym_triangleadj] = ACTIONS(2340),
    [anon_sym_lineadj] = ACTIONS(2340),
    [anon_sym_triangle] = ACTIONS(2340),
    [anon_sym_cbuffer] = ACTIONS(2340),
  },
  [644] = {
    [sym_identifier] = ACTIONS(2344),
    [aux_sym_preproc_include_token1] = ACTIONS(2344),
    [aux_sym_preproc_def_token1] = ACTIONS(2344),
    [aux_sym_preproc_if_token1] = ACTIONS(2344),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2344),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2344),
    [sym_preproc_directive] = ACTIONS(2344),
    [anon_sym_LPAREN2] = ACTIONS(2346),
    [anon_sym_BANG] = ACTIONS(2346),
    [anon_sym_TILDE] = ACTIONS(2346),
    [anon_sym_DASH] = ACTIONS(2344),
    [anon_sym_PLUS] = ACTIONS(2344),
    [anon_sym_STAR] = ACTIONS(2346),
    [anon_sym_AMP_AMP] = ACTIONS(2346),
    [anon_sym_AMP] = ACTIONS(2344),
    [anon_sym_SEMI] = ACTIONS(2346),
    [anon_sym___extension__] = ACTIONS(2344),
    [anon_sym_typedef] = ACTIONS(2344),
    [anon_sym_in] = ACTIONS(2344),
    [anon_sym_out] = ACTIONS(2344),
    [anon_sym_inout] = ACTIONS(2344),
    [anon_sym_extern] = ACTIONS(2344),
    [anon_sym___attribute__] = ACTIONS(2344),
    [anon_sym_COLON_COLON] = ACTIONS(2346),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2346),
    [anon_sym___declspec] = ACTIONS(2344),
    [anon_sym___based] = ACTIONS(2344),
    [anon_sym___cdecl] = ACTIONS(2344),
    [anon_sym___clrcall] = ACTIONS(2344),
    [anon_sym___stdcall] = ACTIONS(2344),
    [anon_sym___fastcall] = ACTIONS(2344),
    [anon_sym___thiscall] = ACTIONS(2344),
    [anon_sym___vectorcall] = ACTIONS(2344),
    [anon_sym_LBRACE] = ACTIONS(2346),
    [anon_sym_RBRACE] = ACTIONS(2346),
    [anon_sym_signed] = ACTIONS(2344),
    [anon_sym_unsigned] = ACTIONS(2344),
    [anon_sym_long] = ACTIONS(2344),
    [anon_sym_short] = ACTIONS(2344),
    [anon_sym_LBRACK] = ACTIONS(2344),
    [anon_sym_static] = ACTIONS(2344),
    [anon_sym_register] = ACTIONS(2344),
    [anon_sym_inline] = ACTIONS(2344),
    [anon_sym___inline] = ACTIONS(2344),
    [anon_sym___inline__] = ACTIONS(2344),
    [anon_sym___forceinline] = ACTIONS(2344),
    [anon_sym_thread_local] = ACTIONS(2344),
    [anon_sym___thread] = ACTIONS(2344),
    [anon_sym_const] = ACTIONS(2344),
    [anon_sym_constexpr] = ACTIONS(2344),
    [anon_sym_volatile] = ACTIONS(2344),
    [anon_sym_restrict] = ACTIONS(2344),
    [anon_sym___restrict__] = ACTIONS(2344),
    [anon_sym__Atomic] = ACTIONS(2344),
    [anon_sym__Noreturn] = ACTIONS(2344),
    [anon_sym_noreturn] = ACTIONS(2344),
    [anon_sym_mutable] = ACTIONS(2344),
    [anon_sym_constinit] = ACTIONS(2344),
    [anon_sym_consteval] = ACTIONS(2344),
    [anon_sym_alignas] = ACTIONS(2344),
    [anon_sym__Alignas] = ACTIONS(2344),
    [sym_primitive_type] = ACTIONS(2344),
    [anon_sym_enum] = ACTIONS(2344),
    [anon_sym_class] = ACTIONS(2344),
    [anon_sym_struct] = ACTIONS(2344),
    [anon_sym_union] = ACTIONS(2344),
    [anon_sym_if] = ACTIONS(2344),
    [anon_sym_switch] = ACTIONS(2344),
    [anon_sym_case] = ACTIONS(2344),
    [anon_sym_default] = ACTIONS(2344),
    [anon_sym_while] = ACTIONS(2344),
    [anon_sym_do] = ACTIONS(2344),
    [anon_sym_for] = ACTIONS(2344),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_break] = ACTIONS(2344),
    [anon_sym_continue] = ACTIONS(2344),
    [anon_sym_goto] = ACTIONS(2344),
    [anon_sym___try] = ACTIONS(2344),
    [anon_sym___leave] = ACTIONS(2344),
    [anon_sym_not] = ACTIONS(2344),
    [anon_sym_compl] = ACTIONS(2344),
    [anon_sym_DASH_DASH] = ACTIONS(2346),
    [anon_sym_PLUS_PLUS] = ACTIONS(2346),
    [anon_sym_sizeof] = ACTIONS(2344),
    [anon_sym___alignof__] = ACTIONS(2344),
    [anon_sym___alignof] = ACTIONS(2344),
    [anon_sym__alignof] = ACTIONS(2344),
    [anon_sym_alignof] = ACTIONS(2344),
    [anon_sym__Alignof] = ACTIONS(2344),
    [anon_sym_offsetof] = ACTIONS(2344),
    [anon_sym__Generic] = ACTIONS(2344),
    [anon_sym_asm] = ACTIONS(2344),
    [anon_sym___asm__] = ACTIONS(2344),
    [sym_number_literal] = ACTIONS(2346),
    [anon_sym_L_SQUOTE] = ACTIONS(2346),
    [anon_sym_u_SQUOTE] = ACTIONS(2346),
    [anon_sym_U_SQUOTE] = ACTIONS(2346),
    [anon_sym_u8_SQUOTE] = ACTIONS(2346),
    [anon_sym_SQUOTE] = ACTIONS(2346),
    [anon_sym_L_DQUOTE] = ACTIONS(2346),
    [anon_sym_u_DQUOTE] = ACTIONS(2346),
    [anon_sym_U_DQUOTE] = ACTIONS(2346),
    [anon_sym_u8_DQUOTE] = ACTIONS(2346),
    [anon_sym_DQUOTE] = ACTIONS(2346),
    [sym_true] = ACTIONS(2344),
    [sym_false] = ACTIONS(2344),
    [anon_sym_NULL] = ACTIONS(2344),
    [anon_sym_nullptr] = ACTIONS(2344),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2344),
    [anon_sym_decltype] = ACTIONS(2344),
    [sym_virtual] = ACTIONS(2344),
    [anon_sym_explicit] = ACTIONS(2344),
    [anon_sym_typename] = ACTIONS(2344),
    [anon_sym_template] = ACTIONS(2344),
    [anon_sym_operator] = ACTIONS(2344),
    [anon_sym_try] = ACTIONS(2344),
    [anon_sym_delete] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2344),
    [anon_sym_namespace] = ACTIONS(2344),
    [anon_sym_using] = ACTIONS(2344),
    [anon_sym_static_assert] = ACTIONS(2344),
    [anon_sym_concept] = ACTIONS(2344),
    [anon_sym_co_return] = ACTIONS(2344),
    [anon_sym_co_yield] = ACTIONS(2344),
    [anon_sym_R_DQUOTE] = ACTIONS(2346),
    [anon_sym_LR_DQUOTE] = ACTIONS(2346),
    [anon_sym_uR_DQUOTE] = ACTIONS(2346),
    [anon_sym_UR_DQUOTE] = ACTIONS(2346),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2346),
    [anon_sym_co_await] = ACTIONS(2344),
    [anon_sym_new] = ACTIONS(2344),
    [anon_sym_requires] = ACTIONS(2344),
    [sym_this] = ACTIONS(2344),
    [anon_sym_discard] = ACTIONS(2344),
    [anon_sym_precise] = ACTIONS(2344),
    [anon_sym_shared] = ACTIONS(2344),
    [anon_sym_groupshared] = ACTIONS(2344),
    [anon_sym_uniform] = ACTIONS(2344),
    [anon_sym_row_major] = ACTIONS(2344),
    [anon_sym_column_major] = ACTIONS(2344),
    [anon_sym_globallycoherent] = ACTIONS(2344),
    [anon_sym_centroid] = ACTIONS(2344),
    [anon_sym_noperspective] = ACTIONS(2344),
    [anon_sym_nointerpolation] = ACTIONS(2344),
    [anon_sym_sample] = ACTIONS(2344),
    [anon_sym_linear] = ACTIONS(2344),
    [anon_sym_snorm] = ACTIONS(2344),
    [anon_sym_unorm] = ACTIONS(2344),
    [anon_sym_point] = ACTIONS(2344),
    [anon_sym_line] = ACTIONS(2344),
    [anon_sym_triangleadj] = ACTIONS(2344),
    [anon_sym_lineadj] = ACTIONS(2344),
    [anon_sym_triangle] = ACTIONS(2344),
    [anon_sym_cbuffer] = ACTIONS(2344),
  },
  [645] = {
    [sym_identifier] = ACTIONS(2348),
    [aux_sym_preproc_include_token1] = ACTIONS(2348),
    [aux_sym_preproc_def_token1] = ACTIONS(2348),
    [aux_sym_preproc_if_token1] = ACTIONS(2348),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2348),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2348),
    [sym_preproc_directive] = ACTIONS(2348),
    [anon_sym_LPAREN2] = ACTIONS(2350),
    [anon_sym_BANG] = ACTIONS(2350),
    [anon_sym_TILDE] = ACTIONS(2350),
    [anon_sym_DASH] = ACTIONS(2348),
    [anon_sym_PLUS] = ACTIONS(2348),
    [anon_sym_STAR] = ACTIONS(2350),
    [anon_sym_AMP_AMP] = ACTIONS(2350),
    [anon_sym_AMP] = ACTIONS(2348),
    [anon_sym_SEMI] = ACTIONS(2350),
    [anon_sym___extension__] = ACTIONS(2348),
    [anon_sym_typedef] = ACTIONS(2348),
    [anon_sym_in] = ACTIONS(2348),
    [anon_sym_out] = ACTIONS(2348),
    [anon_sym_inout] = ACTIONS(2348),
    [anon_sym_extern] = ACTIONS(2348),
    [anon_sym___attribute__] = ACTIONS(2348),
    [anon_sym_COLON_COLON] = ACTIONS(2350),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2350),
    [anon_sym___declspec] = ACTIONS(2348),
    [anon_sym___based] = ACTIONS(2348),
    [anon_sym___cdecl] = ACTIONS(2348),
    [anon_sym___clrcall] = ACTIONS(2348),
    [anon_sym___stdcall] = ACTIONS(2348),
    [anon_sym___fastcall] = ACTIONS(2348),
    [anon_sym___thiscall] = ACTIONS(2348),
    [anon_sym___vectorcall] = ACTIONS(2348),
    [anon_sym_LBRACE] = ACTIONS(2350),
    [anon_sym_RBRACE] = ACTIONS(2350),
    [anon_sym_signed] = ACTIONS(2348),
    [anon_sym_unsigned] = ACTIONS(2348),
    [anon_sym_long] = ACTIONS(2348),
    [anon_sym_short] = ACTIONS(2348),
    [anon_sym_LBRACK] = ACTIONS(2348),
    [anon_sym_static] = ACTIONS(2348),
    [anon_sym_register] = ACTIONS(2348),
    [anon_sym_inline] = ACTIONS(2348),
    [anon_sym___inline] = ACTIONS(2348),
    [anon_sym___inline__] = ACTIONS(2348),
    [anon_sym___forceinline] = ACTIONS(2348),
    [anon_sym_thread_local] = ACTIONS(2348),
    [anon_sym___thread] = ACTIONS(2348),
    [anon_sym_const] = ACTIONS(2348),
    [anon_sym_constexpr] = ACTIONS(2348),
    [anon_sym_volatile] = ACTIONS(2348),
    [anon_sym_restrict] = ACTIONS(2348),
    [anon_sym___restrict__] = ACTIONS(2348),
    [anon_sym__Atomic] = ACTIONS(2348),
    [anon_sym__Noreturn] = ACTIONS(2348),
    [anon_sym_noreturn] = ACTIONS(2348),
    [anon_sym_mutable] = ACTIONS(2348),
    [anon_sym_constinit] = ACTIONS(2348),
    [anon_sym_consteval] = ACTIONS(2348),
    [anon_sym_alignas] = ACTIONS(2348),
    [anon_sym__Alignas] = ACTIONS(2348),
    [sym_primitive_type] = ACTIONS(2348),
    [anon_sym_enum] = ACTIONS(2348),
    [anon_sym_class] = ACTIONS(2348),
    [anon_sym_struct] = ACTIONS(2348),
    [anon_sym_union] = ACTIONS(2348),
    [anon_sym_if] = ACTIONS(2348),
    [anon_sym_switch] = ACTIONS(2348),
    [anon_sym_case] = ACTIONS(2348),
    [anon_sym_default] = ACTIONS(2348),
    [anon_sym_while] = ACTIONS(2348),
    [anon_sym_do] = ACTIONS(2348),
    [anon_sym_for] = ACTIONS(2348),
    [anon_sym_return] = ACTIONS(2348),
    [anon_sym_break] = ACTIONS(2348),
    [anon_sym_continue] = ACTIONS(2348),
    [anon_sym_goto] = ACTIONS(2348),
    [anon_sym___try] = ACTIONS(2348),
    [anon_sym___leave] = ACTIONS(2348),
    [anon_sym_not] = ACTIONS(2348),
    [anon_sym_compl] = ACTIONS(2348),
    [anon_sym_DASH_DASH] = ACTIONS(2350),
    [anon_sym_PLUS_PLUS] = ACTIONS(2350),
    [anon_sym_sizeof] = ACTIONS(2348),
    [anon_sym___alignof__] = ACTIONS(2348),
    [anon_sym___alignof] = ACTIONS(2348),
    [anon_sym__alignof] = ACTIONS(2348),
    [anon_sym_alignof] = ACTIONS(2348),
    [anon_sym__Alignof] = ACTIONS(2348),
    [anon_sym_offsetof] = ACTIONS(2348),
    [anon_sym__Generic] = ACTIONS(2348),
    [anon_sym_asm] = ACTIONS(2348),
    [anon_sym___asm__] = ACTIONS(2348),
    [sym_number_literal] = ACTIONS(2350),
    [anon_sym_L_SQUOTE] = ACTIONS(2350),
    [anon_sym_u_SQUOTE] = ACTIONS(2350),
    [anon_sym_U_SQUOTE] = ACTIONS(2350),
    [anon_sym_u8_SQUOTE] = ACTIONS(2350),
    [anon_sym_SQUOTE] = ACTIONS(2350),
    [anon_sym_L_DQUOTE] = ACTIONS(2350),
    [anon_sym_u_DQUOTE] = ACTIONS(2350),
    [anon_sym_U_DQUOTE] = ACTIONS(2350),
    [anon_sym_u8_DQUOTE] = ACTIONS(2350),
    [anon_sym_DQUOTE] = ACTIONS(2350),
    [sym_true] = ACTIONS(2348),
    [sym_false] = ACTIONS(2348),
    [anon_sym_NULL] = ACTIONS(2348),
    [anon_sym_nullptr] = ACTIONS(2348),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2348),
    [anon_sym_decltype] = ACTIONS(2348),
    [sym_virtual] = ACTIONS(2348),
    [anon_sym_explicit] = ACTIONS(2348),
    [anon_sym_typename] = ACTIONS(2348),
    [anon_sym_template] = ACTIONS(2348),
    [anon_sym_operator] = ACTIONS(2348),
    [anon_sym_try] = ACTIONS(2348),
    [anon_sym_delete] = ACTIONS(2348),
    [anon_sym_throw] = ACTIONS(2348),
    [anon_sym_namespace] = ACTIONS(2348),
    [anon_sym_using] = ACTIONS(2348),
    [anon_sym_static_assert] = ACTIONS(2348),
    [anon_sym_concept] = ACTIONS(2348),
    [anon_sym_co_return] = ACTIONS(2348),
    [anon_sym_co_yield] = ACTIONS(2348),
    [anon_sym_R_DQUOTE] = ACTIONS(2350),
    [anon_sym_LR_DQUOTE] = ACTIONS(2350),
    [anon_sym_uR_DQUOTE] = ACTIONS(2350),
    [anon_sym_UR_DQUOTE] = ACTIONS(2350),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2350),
    [anon_sym_co_await] = ACTIONS(2348),
    [anon_sym_new] = ACTIONS(2348),
    [anon_sym_requires] = ACTIONS(2348),
    [sym_this] = ACTIONS(2348),
    [anon_sym_discard] = ACTIONS(2348),
    [anon_sym_precise] = ACTIONS(2348),
    [anon_sym_shared] = ACTIONS(2348),
    [anon_sym_groupshared] = ACTIONS(2348),
    [anon_sym_uniform] = ACTIONS(2348),
    [anon_sym_row_major] = ACTIONS(2348),
    [anon_sym_column_major] = ACTIONS(2348),
    [anon_sym_globallycoherent] = ACTIONS(2348),
    [anon_sym_centroid] = ACTIONS(2348),
    [anon_sym_noperspective] = ACTIONS(2348),
    [anon_sym_nointerpolation] = ACTIONS(2348),
    [anon_sym_sample] = ACTIONS(2348),
    [anon_sym_linear] = ACTIONS(2348),
    [anon_sym_snorm] = ACTIONS(2348),
    [anon_sym_unorm] = ACTIONS(2348),
    [anon_sym_point] = ACTIONS(2348),
    [anon_sym_line] = ACTIONS(2348),
    [anon_sym_triangleadj] = ACTIONS(2348),
    [anon_sym_lineadj] = ACTIONS(2348),
    [anon_sym_triangle] = ACTIONS(2348),
    [anon_sym_cbuffer] = ACTIONS(2348),
  },
  [646] = {
    [sym_identifier] = ACTIONS(2352),
    [aux_sym_preproc_include_token1] = ACTIONS(2352),
    [aux_sym_preproc_def_token1] = ACTIONS(2352),
    [aux_sym_preproc_if_token1] = ACTIONS(2352),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2352),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2352),
    [sym_preproc_directive] = ACTIONS(2352),
    [anon_sym_LPAREN2] = ACTIONS(2354),
    [anon_sym_BANG] = ACTIONS(2354),
    [anon_sym_TILDE] = ACTIONS(2354),
    [anon_sym_DASH] = ACTIONS(2352),
    [anon_sym_PLUS] = ACTIONS(2352),
    [anon_sym_STAR] = ACTIONS(2354),
    [anon_sym_AMP_AMP] = ACTIONS(2354),
    [anon_sym_AMP] = ACTIONS(2352),
    [anon_sym_SEMI] = ACTIONS(2354),
    [anon_sym___extension__] = ACTIONS(2352),
    [anon_sym_typedef] = ACTIONS(2352),
    [anon_sym_in] = ACTIONS(2352),
    [anon_sym_out] = ACTIONS(2352),
    [anon_sym_inout] = ACTIONS(2352),
    [anon_sym_extern] = ACTIONS(2352),
    [anon_sym___attribute__] = ACTIONS(2352),
    [anon_sym_COLON_COLON] = ACTIONS(2354),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2354),
    [anon_sym___declspec] = ACTIONS(2352),
    [anon_sym___based] = ACTIONS(2352),
    [anon_sym___cdecl] = ACTIONS(2352),
    [anon_sym___clrcall] = ACTIONS(2352),
    [anon_sym___stdcall] = ACTIONS(2352),
    [anon_sym___fastcall] = ACTIONS(2352),
    [anon_sym___thiscall] = ACTIONS(2352),
    [anon_sym___vectorcall] = ACTIONS(2352),
    [anon_sym_LBRACE] = ACTIONS(2354),
    [anon_sym_RBRACE] = ACTIONS(2354),
    [anon_sym_signed] = ACTIONS(2352),
    [anon_sym_unsigned] = ACTIONS(2352),
    [anon_sym_long] = ACTIONS(2352),
    [anon_sym_short] = ACTIONS(2352),
    [anon_sym_LBRACK] = ACTIONS(2352),
    [anon_sym_static] = ACTIONS(2352),
    [anon_sym_register] = ACTIONS(2352),
    [anon_sym_inline] = ACTIONS(2352),
    [anon_sym___inline] = ACTIONS(2352),
    [anon_sym___inline__] = ACTIONS(2352),
    [anon_sym___forceinline] = ACTIONS(2352),
    [anon_sym_thread_local] = ACTIONS(2352),
    [anon_sym___thread] = ACTIONS(2352),
    [anon_sym_const] = ACTIONS(2352),
    [anon_sym_constexpr] = ACTIONS(2352),
    [anon_sym_volatile] = ACTIONS(2352),
    [anon_sym_restrict] = ACTIONS(2352),
    [anon_sym___restrict__] = ACTIONS(2352),
    [anon_sym__Atomic] = ACTIONS(2352),
    [anon_sym__Noreturn] = ACTIONS(2352),
    [anon_sym_noreturn] = ACTIONS(2352),
    [anon_sym_mutable] = ACTIONS(2352),
    [anon_sym_constinit] = ACTIONS(2352),
    [anon_sym_consteval] = ACTIONS(2352),
    [anon_sym_alignas] = ACTIONS(2352),
    [anon_sym__Alignas] = ACTIONS(2352),
    [sym_primitive_type] = ACTIONS(2352),
    [anon_sym_enum] = ACTIONS(2352),
    [anon_sym_class] = ACTIONS(2352),
    [anon_sym_struct] = ACTIONS(2352),
    [anon_sym_union] = ACTIONS(2352),
    [anon_sym_if] = ACTIONS(2352),
    [anon_sym_switch] = ACTIONS(2352),
    [anon_sym_case] = ACTIONS(2352),
    [anon_sym_default] = ACTIONS(2352),
    [anon_sym_while] = ACTIONS(2352),
    [anon_sym_do] = ACTIONS(2352),
    [anon_sym_for] = ACTIONS(2352),
    [anon_sym_return] = ACTIONS(2352),
    [anon_sym_break] = ACTIONS(2352),
    [anon_sym_continue] = ACTIONS(2352),
    [anon_sym_goto] = ACTIONS(2352),
    [anon_sym___try] = ACTIONS(2352),
    [anon_sym___leave] = ACTIONS(2352),
    [anon_sym_not] = ACTIONS(2352),
    [anon_sym_compl] = ACTIONS(2352),
    [anon_sym_DASH_DASH] = ACTIONS(2354),
    [anon_sym_PLUS_PLUS] = ACTIONS(2354),
    [anon_sym_sizeof] = ACTIONS(2352),
    [anon_sym___alignof__] = ACTIONS(2352),
    [anon_sym___alignof] = ACTIONS(2352),
    [anon_sym__alignof] = ACTIONS(2352),
    [anon_sym_alignof] = ACTIONS(2352),
    [anon_sym__Alignof] = ACTIONS(2352),
    [anon_sym_offsetof] = ACTIONS(2352),
    [anon_sym__Generic] = ACTIONS(2352),
    [anon_sym_asm] = ACTIONS(2352),
    [anon_sym___asm__] = ACTIONS(2352),
    [sym_number_literal] = ACTIONS(2354),
    [anon_sym_L_SQUOTE] = ACTIONS(2354),
    [anon_sym_u_SQUOTE] = ACTIONS(2354),
    [anon_sym_U_SQUOTE] = ACTIONS(2354),
    [anon_sym_u8_SQUOTE] = ACTIONS(2354),
    [anon_sym_SQUOTE] = ACTIONS(2354),
    [anon_sym_L_DQUOTE] = ACTIONS(2354),
    [anon_sym_u_DQUOTE] = ACTIONS(2354),
    [anon_sym_U_DQUOTE] = ACTIONS(2354),
    [anon_sym_u8_DQUOTE] = ACTIONS(2354),
    [anon_sym_DQUOTE] = ACTIONS(2354),
    [sym_true] = ACTIONS(2352),
    [sym_false] = ACTIONS(2352),
    [anon_sym_NULL] = ACTIONS(2352),
    [anon_sym_nullptr] = ACTIONS(2352),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2352),
    [anon_sym_decltype] = ACTIONS(2352),
    [sym_virtual] = ACTIONS(2352),
    [anon_sym_explicit] = ACTIONS(2352),
    [anon_sym_typename] = ACTIONS(2352),
    [anon_sym_template] = ACTIONS(2352),
    [anon_sym_operator] = ACTIONS(2352),
    [anon_sym_try] = ACTIONS(2352),
    [anon_sym_delete] = ACTIONS(2352),
    [anon_sym_throw] = ACTIONS(2352),
    [anon_sym_namespace] = ACTIONS(2352),
    [anon_sym_using] = ACTIONS(2352),
    [anon_sym_static_assert] = ACTIONS(2352),
    [anon_sym_concept] = ACTIONS(2352),
    [anon_sym_co_return] = ACTIONS(2352),
    [anon_sym_co_yield] = ACTIONS(2352),
    [anon_sym_R_DQUOTE] = ACTIONS(2354),
    [anon_sym_LR_DQUOTE] = ACTIONS(2354),
    [anon_sym_uR_DQUOTE] = ACTIONS(2354),
    [anon_sym_UR_DQUOTE] = ACTIONS(2354),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2354),
    [anon_sym_co_await] = ACTIONS(2352),
    [anon_sym_new] = ACTIONS(2352),
    [anon_sym_requires] = ACTIONS(2352),
    [sym_this] = ACTIONS(2352),
    [anon_sym_discard] = ACTIONS(2352),
    [anon_sym_precise] = ACTIONS(2352),
    [anon_sym_shared] = ACTIONS(2352),
    [anon_sym_groupshared] = ACTIONS(2352),
    [anon_sym_uniform] = ACTIONS(2352),
    [anon_sym_row_major] = ACTIONS(2352),
    [anon_sym_column_major] = ACTIONS(2352),
    [anon_sym_globallycoherent] = ACTIONS(2352),
    [anon_sym_centroid] = ACTIONS(2352),
    [anon_sym_noperspective] = ACTIONS(2352),
    [anon_sym_nointerpolation] = ACTIONS(2352),
    [anon_sym_sample] = ACTIONS(2352),
    [anon_sym_linear] = ACTIONS(2352),
    [anon_sym_snorm] = ACTIONS(2352),
    [anon_sym_unorm] = ACTIONS(2352),
    [anon_sym_point] = ACTIONS(2352),
    [anon_sym_line] = ACTIONS(2352),
    [anon_sym_triangleadj] = ACTIONS(2352),
    [anon_sym_lineadj] = ACTIONS(2352),
    [anon_sym_triangle] = ACTIONS(2352),
    [anon_sym_cbuffer] = ACTIONS(2352),
  },
  [647] = {
    [sym_identifier] = ACTIONS(2462),
    [aux_sym_preproc_include_token1] = ACTIONS(2462),
    [aux_sym_preproc_def_token1] = ACTIONS(2462),
    [aux_sym_preproc_if_token1] = ACTIONS(2462),
    [aux_sym_preproc_if_token2] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2462),
    [sym_preproc_directive] = ACTIONS(2462),
    [anon_sym_LPAREN2] = ACTIONS(2464),
    [anon_sym_BANG] = ACTIONS(2464),
    [anon_sym_TILDE] = ACTIONS(2464),
    [anon_sym_DASH] = ACTIONS(2462),
    [anon_sym_PLUS] = ACTIONS(2462),
    [anon_sym_STAR] = ACTIONS(2464),
    [anon_sym_AMP_AMP] = ACTIONS(2464),
    [anon_sym_AMP] = ACTIONS(2462),
    [anon_sym_SEMI] = ACTIONS(2464),
    [anon_sym___extension__] = ACTIONS(2462),
    [anon_sym_typedef] = ACTIONS(2462),
    [anon_sym_in] = ACTIONS(2462),
    [anon_sym_out] = ACTIONS(2462),
    [anon_sym_inout] = ACTIONS(2462),
    [anon_sym_extern] = ACTIONS(2462),
    [anon_sym___attribute__] = ACTIONS(2462),
    [anon_sym_COLON_COLON] = ACTIONS(2464),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2464),
    [anon_sym___declspec] = ACTIONS(2462),
    [anon_sym___based] = ACTIONS(2462),
    [anon_sym___cdecl] = ACTIONS(2462),
    [anon_sym___clrcall] = ACTIONS(2462),
    [anon_sym___stdcall] = ACTIONS(2462),
    [anon_sym___fastcall] = ACTIONS(2462),
    [anon_sym___thiscall] = ACTIONS(2462),
    [anon_sym___vectorcall] = ACTIONS(2462),
    [anon_sym_LBRACE] = ACTIONS(2464),
    [anon_sym_signed] = ACTIONS(2462),
    [anon_sym_unsigned] = ACTIONS(2462),
    [anon_sym_long] = ACTIONS(2462),
    [anon_sym_short] = ACTIONS(2462),
    [anon_sym_LBRACK] = ACTIONS(2462),
    [anon_sym_static] = ACTIONS(2462),
    [anon_sym_register] = ACTIONS(2462),
    [anon_sym_inline] = ACTIONS(2462),
    [anon_sym___inline] = ACTIONS(2462),
    [anon_sym___inline__] = ACTIONS(2462),
    [anon_sym___forceinline] = ACTIONS(2462),
    [anon_sym_thread_local] = ACTIONS(2462),
    [anon_sym___thread] = ACTIONS(2462),
    [anon_sym_const] = ACTIONS(2462),
    [anon_sym_constexpr] = ACTIONS(2462),
    [anon_sym_volatile] = ACTIONS(2462),
    [anon_sym_restrict] = ACTIONS(2462),
    [anon_sym___restrict__] = ACTIONS(2462),
    [anon_sym__Atomic] = ACTIONS(2462),
    [anon_sym__Noreturn] = ACTIONS(2462),
    [anon_sym_noreturn] = ACTIONS(2462),
    [anon_sym_mutable] = ACTIONS(2462),
    [anon_sym_constinit] = ACTIONS(2462),
    [anon_sym_consteval] = ACTIONS(2462),
    [anon_sym_alignas] = ACTIONS(2462),
    [anon_sym__Alignas] = ACTIONS(2462),
    [sym_primitive_type] = ACTIONS(2462),
    [anon_sym_enum] = ACTIONS(2462),
    [anon_sym_class] = ACTIONS(2462),
    [anon_sym_struct] = ACTIONS(2462),
    [anon_sym_union] = ACTIONS(2462),
    [anon_sym_if] = ACTIONS(2462),
    [anon_sym_switch] = ACTIONS(2462),
    [anon_sym_case] = ACTIONS(2462),
    [anon_sym_default] = ACTIONS(2462),
    [anon_sym_while] = ACTIONS(2462),
    [anon_sym_do] = ACTIONS(2462),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_break] = ACTIONS(2462),
    [anon_sym_continue] = ACTIONS(2462),
    [anon_sym_goto] = ACTIONS(2462),
    [anon_sym___try] = ACTIONS(2462),
    [anon_sym___leave] = ACTIONS(2462),
    [anon_sym_not] = ACTIONS(2462),
    [anon_sym_compl] = ACTIONS(2462),
    [anon_sym_DASH_DASH] = ACTIONS(2464),
    [anon_sym_PLUS_PLUS] = ACTIONS(2464),
    [anon_sym_sizeof] = ACTIONS(2462),
    [anon_sym___alignof__] = ACTIONS(2462),
    [anon_sym___alignof] = ACTIONS(2462),
    [anon_sym__alignof] = ACTIONS(2462),
    [anon_sym_alignof] = ACTIONS(2462),
    [anon_sym__Alignof] = ACTIONS(2462),
    [anon_sym_offsetof] = ACTIONS(2462),
    [anon_sym__Generic] = ACTIONS(2462),
    [anon_sym_asm] = ACTIONS(2462),
    [anon_sym___asm__] = ACTIONS(2462),
    [sym_number_literal] = ACTIONS(2464),
    [anon_sym_L_SQUOTE] = ACTIONS(2464),
    [anon_sym_u_SQUOTE] = ACTIONS(2464),
    [anon_sym_U_SQUOTE] = ACTIONS(2464),
    [anon_sym_u8_SQUOTE] = ACTIONS(2464),
    [anon_sym_SQUOTE] = ACTIONS(2464),
    [anon_sym_L_DQUOTE] = ACTIONS(2464),
    [anon_sym_u_DQUOTE] = ACTIONS(2464),
    [anon_sym_U_DQUOTE] = ACTIONS(2464),
    [anon_sym_u8_DQUOTE] = ACTIONS(2464),
    [anon_sym_DQUOTE] = ACTIONS(2464),
    [sym_true] = ACTIONS(2462),
    [sym_false] = ACTIONS(2462),
    [anon_sym_NULL] = ACTIONS(2462),
    [anon_sym_nullptr] = ACTIONS(2462),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2462),
    [anon_sym_decltype] = ACTIONS(2462),
    [sym_virtual] = ACTIONS(2462),
    [anon_sym_explicit] = ACTIONS(2462),
    [anon_sym_typename] = ACTIONS(2462),
    [anon_sym_template] = ACTIONS(2462),
    [anon_sym_operator] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2462),
    [anon_sym_delete] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2462),
    [anon_sym_namespace] = ACTIONS(2462),
    [anon_sym_using] = ACTIONS(2462),
    [anon_sym_static_assert] = ACTIONS(2462),
    [anon_sym_concept] = ACTIONS(2462),
    [anon_sym_co_return] = ACTIONS(2462),
    [anon_sym_co_yield] = ACTIONS(2462),
    [anon_sym_R_DQUOTE] = ACTIONS(2464),
    [anon_sym_LR_DQUOTE] = ACTIONS(2464),
    [anon_sym_uR_DQUOTE] = ACTIONS(2464),
    [anon_sym_UR_DQUOTE] = ACTIONS(2464),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2464),
    [anon_sym_co_await] = ACTIONS(2462),
    [anon_sym_new] = ACTIONS(2462),
    [anon_sym_requires] = ACTIONS(2462),
    [sym_this] = ACTIONS(2462),
    [anon_sym_discard] = ACTIONS(2462),
    [anon_sym_precise] = ACTIONS(2462),
    [anon_sym_shared] = ACTIONS(2462),
    [anon_sym_groupshared] = ACTIONS(2462),
    [anon_sym_uniform] = ACTIONS(2462),
    [anon_sym_row_major] = ACTIONS(2462),
    [anon_sym_column_major] = ACTIONS(2462),
    [anon_sym_globallycoherent] = ACTIONS(2462),
    [anon_sym_centroid] = ACTIONS(2462),
    [anon_sym_noperspective] = ACTIONS(2462),
    [anon_sym_nointerpolation] = ACTIONS(2462),
    [anon_sym_sample] = ACTIONS(2462),
    [anon_sym_linear] = ACTIONS(2462),
    [anon_sym_snorm] = ACTIONS(2462),
    [anon_sym_unorm] = ACTIONS(2462),
    [anon_sym_point] = ACTIONS(2462),
    [anon_sym_line] = ACTIONS(2462),
    [anon_sym_triangleadj] = ACTIONS(2462),
    [anon_sym_lineadj] = ACTIONS(2462),
    [anon_sym_triangle] = ACTIONS(2462),
    [anon_sym_cbuffer] = ACTIONS(2462),
  },
  [648] = {
    [sym_identifier] = ACTIONS(2516),
    [aux_sym_preproc_include_token1] = ACTIONS(2516),
    [aux_sym_preproc_def_token1] = ACTIONS(2516),
    [aux_sym_preproc_if_token1] = ACTIONS(2516),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2516),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2516),
    [sym_preproc_directive] = ACTIONS(2516),
    [anon_sym_LPAREN2] = ACTIONS(2518),
    [anon_sym_BANG] = ACTIONS(2518),
    [anon_sym_TILDE] = ACTIONS(2518),
    [anon_sym_DASH] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(2516),
    [anon_sym_STAR] = ACTIONS(2518),
    [anon_sym_AMP_AMP] = ACTIONS(2518),
    [anon_sym_AMP] = ACTIONS(2516),
    [anon_sym_SEMI] = ACTIONS(2518),
    [anon_sym___extension__] = ACTIONS(2516),
    [anon_sym_typedef] = ACTIONS(2516),
    [anon_sym_in] = ACTIONS(2516),
    [anon_sym_out] = ACTIONS(2516),
    [anon_sym_inout] = ACTIONS(2516),
    [anon_sym_extern] = ACTIONS(2516),
    [anon_sym___attribute__] = ACTIONS(2516),
    [anon_sym_COLON_COLON] = ACTIONS(2518),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2518),
    [anon_sym___declspec] = ACTIONS(2516),
    [anon_sym___based] = ACTIONS(2516),
    [anon_sym___cdecl] = ACTIONS(2516),
    [anon_sym___clrcall] = ACTIONS(2516),
    [anon_sym___stdcall] = ACTIONS(2516),
    [anon_sym___fastcall] = ACTIONS(2516),
    [anon_sym___thiscall] = ACTIONS(2516),
    [anon_sym___vectorcall] = ACTIONS(2516),
    [anon_sym_LBRACE] = ACTIONS(2518),
    [anon_sym_RBRACE] = ACTIONS(2518),
    [anon_sym_signed] = ACTIONS(2516),
    [anon_sym_unsigned] = ACTIONS(2516),
    [anon_sym_long] = ACTIONS(2516),
    [anon_sym_short] = ACTIONS(2516),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_static] = ACTIONS(2516),
    [anon_sym_register] = ACTIONS(2516),
    [anon_sym_inline] = ACTIONS(2516),
    [anon_sym___inline] = ACTIONS(2516),
    [anon_sym___inline__] = ACTIONS(2516),
    [anon_sym___forceinline] = ACTIONS(2516),
    [anon_sym_thread_local] = ACTIONS(2516),
    [anon_sym___thread] = ACTIONS(2516),
    [anon_sym_const] = ACTIONS(2516),
    [anon_sym_constexpr] = ACTIONS(2516),
    [anon_sym_volatile] = ACTIONS(2516),
    [anon_sym_restrict] = ACTIONS(2516),
    [anon_sym___restrict__] = ACTIONS(2516),
    [anon_sym__Atomic] = ACTIONS(2516),
    [anon_sym__Noreturn] = ACTIONS(2516),
    [anon_sym_noreturn] = ACTIONS(2516),
    [anon_sym_mutable] = ACTIONS(2516),
    [anon_sym_constinit] = ACTIONS(2516),
    [anon_sym_consteval] = ACTIONS(2516),
    [anon_sym_alignas] = ACTIONS(2516),
    [anon_sym__Alignas] = ACTIONS(2516),
    [sym_primitive_type] = ACTIONS(2516),
    [anon_sym_enum] = ACTIONS(2516),
    [anon_sym_class] = ACTIONS(2516),
    [anon_sym_struct] = ACTIONS(2516),
    [anon_sym_union] = ACTIONS(2516),
    [anon_sym_if] = ACTIONS(2516),
    [anon_sym_switch] = ACTIONS(2516),
    [anon_sym_case] = ACTIONS(2516),
    [anon_sym_default] = ACTIONS(2516),
    [anon_sym_while] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(2516),
    [anon_sym_for] = ACTIONS(2516),
    [anon_sym_return] = ACTIONS(2516),
    [anon_sym_break] = ACTIONS(2516),
    [anon_sym_continue] = ACTIONS(2516),
    [anon_sym_goto] = ACTIONS(2516),
    [anon_sym___try] = ACTIONS(2516),
    [anon_sym___leave] = ACTIONS(2516),
    [anon_sym_not] = ACTIONS(2516),
    [anon_sym_compl] = ACTIONS(2516),
    [anon_sym_DASH_DASH] = ACTIONS(2518),
    [anon_sym_PLUS_PLUS] = ACTIONS(2518),
    [anon_sym_sizeof] = ACTIONS(2516),
    [anon_sym___alignof__] = ACTIONS(2516),
    [anon_sym___alignof] = ACTIONS(2516),
    [anon_sym__alignof] = ACTIONS(2516),
    [anon_sym_alignof] = ACTIONS(2516),
    [anon_sym__Alignof] = ACTIONS(2516),
    [anon_sym_offsetof] = ACTIONS(2516),
    [anon_sym__Generic] = ACTIONS(2516),
    [anon_sym_asm] = ACTIONS(2516),
    [anon_sym___asm__] = ACTIONS(2516),
    [sym_number_literal] = ACTIONS(2518),
    [anon_sym_L_SQUOTE] = ACTIONS(2518),
    [anon_sym_u_SQUOTE] = ACTIONS(2518),
    [anon_sym_U_SQUOTE] = ACTIONS(2518),
    [anon_sym_u8_SQUOTE] = ACTIONS(2518),
    [anon_sym_SQUOTE] = ACTIONS(2518),
    [anon_sym_L_DQUOTE] = ACTIONS(2518),
    [anon_sym_u_DQUOTE] = ACTIONS(2518),
    [anon_sym_U_DQUOTE] = ACTIONS(2518),
    [anon_sym_u8_DQUOTE] = ACTIONS(2518),
    [anon_sym_DQUOTE] = ACTIONS(2518),
    [sym_true] = ACTIONS(2516),
    [sym_false] = ACTIONS(2516),
    [anon_sym_NULL] = ACTIONS(2516),
    [anon_sym_nullptr] = ACTIONS(2516),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2516),
    [anon_sym_decltype] = ACTIONS(2516),
    [sym_virtual] = ACTIONS(2516),
    [anon_sym_explicit] = ACTIONS(2516),
    [anon_sym_typename] = ACTIONS(2516),
    [anon_sym_template] = ACTIONS(2516),
    [anon_sym_operator] = ACTIONS(2516),
    [anon_sym_try] = ACTIONS(2516),
    [anon_sym_delete] = ACTIONS(2516),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_namespace] = ACTIONS(2516),
    [anon_sym_using] = ACTIONS(2516),
    [anon_sym_static_assert] = ACTIONS(2516),
    [anon_sym_concept] = ACTIONS(2516),
    [anon_sym_co_return] = ACTIONS(2516),
    [anon_sym_co_yield] = ACTIONS(2516),
    [anon_sym_R_DQUOTE] = ACTIONS(2518),
    [anon_sym_LR_DQUOTE] = ACTIONS(2518),
    [anon_sym_uR_DQUOTE] = ACTIONS(2518),
    [anon_sym_UR_DQUOTE] = ACTIONS(2518),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2518),
    [anon_sym_co_await] = ACTIONS(2516),
    [anon_sym_new] = ACTIONS(2516),
    [anon_sym_requires] = ACTIONS(2516),
    [sym_this] = ACTIONS(2516),
    [anon_sym_discard] = ACTIONS(2516),
    [anon_sym_precise] = ACTIONS(2516),
    [anon_sym_shared] = ACTIONS(2516),
    [anon_sym_groupshared] = ACTIONS(2516),
    [anon_sym_uniform] = ACTIONS(2516),
    [anon_sym_row_major] = ACTIONS(2516),
    [anon_sym_column_major] = ACTIONS(2516),
    [anon_sym_globallycoherent] = ACTIONS(2516),
    [anon_sym_centroid] = ACTIONS(2516),
    [anon_sym_noperspective] = ACTIONS(2516),
    [anon_sym_nointerpolation] = ACTIONS(2516),
    [anon_sym_sample] = ACTIONS(2516),
    [anon_sym_linear] = ACTIONS(2516),
    [anon_sym_snorm] = ACTIONS(2516),
    [anon_sym_unorm] = ACTIONS(2516),
    [anon_sym_point] = ACTIONS(2516),
    [anon_sym_line] = ACTIONS(2516),
    [anon_sym_triangleadj] = ACTIONS(2516),
    [anon_sym_lineadj] = ACTIONS(2516),
    [anon_sym_triangle] = ACTIONS(2516),
    [anon_sym_cbuffer] = ACTIONS(2516),
  },
  [649] = {
    [sym_identifier] = ACTIONS(2444),
    [aux_sym_preproc_include_token1] = ACTIONS(2444),
    [aux_sym_preproc_def_token1] = ACTIONS(2444),
    [aux_sym_preproc_if_token1] = ACTIONS(2444),
    [aux_sym_preproc_if_token2] = ACTIONS(2444),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2444),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2444),
    [sym_preproc_directive] = ACTIONS(2444),
    [anon_sym_LPAREN2] = ACTIONS(2446),
    [anon_sym_BANG] = ACTIONS(2446),
    [anon_sym_TILDE] = ACTIONS(2446),
    [anon_sym_DASH] = ACTIONS(2444),
    [anon_sym_PLUS] = ACTIONS(2444),
    [anon_sym_STAR] = ACTIONS(2446),
    [anon_sym_AMP_AMP] = ACTIONS(2446),
    [anon_sym_AMP] = ACTIONS(2444),
    [anon_sym_SEMI] = ACTIONS(2446),
    [anon_sym___extension__] = ACTIONS(2444),
    [anon_sym_typedef] = ACTIONS(2444),
    [anon_sym_in] = ACTIONS(2444),
    [anon_sym_out] = ACTIONS(2444),
    [anon_sym_inout] = ACTIONS(2444),
    [anon_sym_extern] = ACTIONS(2444),
    [anon_sym___attribute__] = ACTIONS(2444),
    [anon_sym_COLON_COLON] = ACTIONS(2446),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2446),
    [anon_sym___declspec] = ACTIONS(2444),
    [anon_sym___based] = ACTIONS(2444),
    [anon_sym___cdecl] = ACTIONS(2444),
    [anon_sym___clrcall] = ACTIONS(2444),
    [anon_sym___stdcall] = ACTIONS(2444),
    [anon_sym___fastcall] = ACTIONS(2444),
    [anon_sym___thiscall] = ACTIONS(2444),
    [anon_sym___vectorcall] = ACTIONS(2444),
    [anon_sym_LBRACE] = ACTIONS(2446),
    [anon_sym_signed] = ACTIONS(2444),
    [anon_sym_unsigned] = ACTIONS(2444),
    [anon_sym_long] = ACTIONS(2444),
    [anon_sym_short] = ACTIONS(2444),
    [anon_sym_LBRACK] = ACTIONS(2444),
    [anon_sym_static] = ACTIONS(2444),
    [anon_sym_register] = ACTIONS(2444),
    [anon_sym_inline] = ACTIONS(2444),
    [anon_sym___inline] = ACTIONS(2444),
    [anon_sym___inline__] = ACTIONS(2444),
    [anon_sym___forceinline] = ACTIONS(2444),
    [anon_sym_thread_local] = ACTIONS(2444),
    [anon_sym___thread] = ACTIONS(2444),
    [anon_sym_const] = ACTIONS(2444),
    [anon_sym_constexpr] = ACTIONS(2444),
    [anon_sym_volatile] = ACTIONS(2444),
    [anon_sym_restrict] = ACTIONS(2444),
    [anon_sym___restrict__] = ACTIONS(2444),
    [anon_sym__Atomic] = ACTIONS(2444),
    [anon_sym__Noreturn] = ACTIONS(2444),
    [anon_sym_noreturn] = ACTIONS(2444),
    [anon_sym_mutable] = ACTIONS(2444),
    [anon_sym_constinit] = ACTIONS(2444),
    [anon_sym_consteval] = ACTIONS(2444),
    [anon_sym_alignas] = ACTIONS(2444),
    [anon_sym__Alignas] = ACTIONS(2444),
    [sym_primitive_type] = ACTIONS(2444),
    [anon_sym_enum] = ACTIONS(2444),
    [anon_sym_class] = ACTIONS(2444),
    [anon_sym_struct] = ACTIONS(2444),
    [anon_sym_union] = ACTIONS(2444),
    [anon_sym_if] = ACTIONS(2444),
    [anon_sym_switch] = ACTIONS(2444),
    [anon_sym_case] = ACTIONS(2444),
    [anon_sym_default] = ACTIONS(2444),
    [anon_sym_while] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(2444),
    [anon_sym_for] = ACTIONS(2444),
    [anon_sym_return] = ACTIONS(2444),
    [anon_sym_break] = ACTIONS(2444),
    [anon_sym_continue] = ACTIONS(2444),
    [anon_sym_goto] = ACTIONS(2444),
    [anon_sym___try] = ACTIONS(2444),
    [anon_sym___leave] = ACTIONS(2444),
    [anon_sym_not] = ACTIONS(2444),
    [anon_sym_compl] = ACTIONS(2444),
    [anon_sym_DASH_DASH] = ACTIONS(2446),
    [anon_sym_PLUS_PLUS] = ACTIONS(2446),
    [anon_sym_sizeof] = ACTIONS(2444),
    [anon_sym___alignof__] = ACTIONS(2444),
    [anon_sym___alignof] = ACTIONS(2444),
    [anon_sym__alignof] = ACTIONS(2444),
    [anon_sym_alignof] = ACTIONS(2444),
    [anon_sym__Alignof] = ACTIONS(2444),
    [anon_sym_offsetof] = ACTIONS(2444),
    [anon_sym__Generic] = ACTIONS(2444),
    [anon_sym_asm] = ACTIONS(2444),
    [anon_sym___asm__] = ACTIONS(2444),
    [sym_number_literal] = ACTIONS(2446),
    [anon_sym_L_SQUOTE] = ACTIONS(2446),
    [anon_sym_u_SQUOTE] = ACTIONS(2446),
    [anon_sym_U_SQUOTE] = ACTIONS(2446),
    [anon_sym_u8_SQUOTE] = ACTIONS(2446),
    [anon_sym_SQUOTE] = ACTIONS(2446),
    [anon_sym_L_DQUOTE] = ACTIONS(2446),
    [anon_sym_u_DQUOTE] = ACTIONS(2446),
    [anon_sym_U_DQUOTE] = ACTIONS(2446),
    [anon_sym_u8_DQUOTE] = ACTIONS(2446),
    [anon_sym_DQUOTE] = ACTIONS(2446),
    [sym_true] = ACTIONS(2444),
    [sym_false] = ACTIONS(2444),
    [anon_sym_NULL] = ACTIONS(2444),
    [anon_sym_nullptr] = ACTIONS(2444),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2444),
    [anon_sym_decltype] = ACTIONS(2444),
    [sym_virtual] = ACTIONS(2444),
    [anon_sym_explicit] = ACTIONS(2444),
    [anon_sym_typename] = ACTIONS(2444),
    [anon_sym_template] = ACTIONS(2444),
    [anon_sym_operator] = ACTIONS(2444),
    [anon_sym_try] = ACTIONS(2444),
    [anon_sym_delete] = ACTIONS(2444),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_namespace] = ACTIONS(2444),
    [anon_sym_using] = ACTIONS(2444),
    [anon_sym_static_assert] = ACTIONS(2444),
    [anon_sym_concept] = ACTIONS(2444),
    [anon_sym_co_return] = ACTIONS(2444),
    [anon_sym_co_yield] = ACTIONS(2444),
    [anon_sym_R_DQUOTE] = ACTIONS(2446),
    [anon_sym_LR_DQUOTE] = ACTIONS(2446),
    [anon_sym_uR_DQUOTE] = ACTIONS(2446),
    [anon_sym_UR_DQUOTE] = ACTIONS(2446),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2446),
    [anon_sym_co_await] = ACTIONS(2444),
    [anon_sym_new] = ACTIONS(2444),
    [anon_sym_requires] = ACTIONS(2444),
    [sym_this] = ACTIONS(2444),
    [anon_sym_discard] = ACTIONS(2444),
    [anon_sym_precise] = ACTIONS(2444),
    [anon_sym_shared] = ACTIONS(2444),
    [anon_sym_groupshared] = ACTIONS(2444),
    [anon_sym_uniform] = ACTIONS(2444),
    [anon_sym_row_major] = ACTIONS(2444),
    [anon_sym_column_major] = ACTIONS(2444),
    [anon_sym_globallycoherent] = ACTIONS(2444),
    [anon_sym_centroid] = ACTIONS(2444),
    [anon_sym_noperspective] = ACTIONS(2444),
    [anon_sym_nointerpolation] = ACTIONS(2444),
    [anon_sym_sample] = ACTIONS(2444),
    [anon_sym_linear] = ACTIONS(2444),
    [anon_sym_snorm] = ACTIONS(2444),
    [anon_sym_unorm] = ACTIONS(2444),
    [anon_sym_point] = ACTIONS(2444),
    [anon_sym_line] = ACTIONS(2444),
    [anon_sym_triangleadj] = ACTIONS(2444),
    [anon_sym_lineadj] = ACTIONS(2444),
    [anon_sym_triangle] = ACTIONS(2444),
    [anon_sym_cbuffer] = ACTIONS(2444),
  },
  [650] = {
    [sym_identifier] = ACTIONS(2448),
    [aux_sym_preproc_include_token1] = ACTIONS(2448),
    [aux_sym_preproc_def_token1] = ACTIONS(2448),
    [aux_sym_preproc_if_token1] = ACTIONS(2448),
    [aux_sym_preproc_if_token2] = ACTIONS(2448),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2448),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2448),
    [sym_preproc_directive] = ACTIONS(2448),
    [anon_sym_LPAREN2] = ACTIONS(2450),
    [anon_sym_BANG] = ACTIONS(2450),
    [anon_sym_TILDE] = ACTIONS(2450),
    [anon_sym_DASH] = ACTIONS(2448),
    [anon_sym_PLUS] = ACTIONS(2448),
    [anon_sym_STAR] = ACTIONS(2450),
    [anon_sym_AMP_AMP] = ACTIONS(2450),
    [anon_sym_AMP] = ACTIONS(2448),
    [anon_sym_SEMI] = ACTIONS(2450),
    [anon_sym___extension__] = ACTIONS(2448),
    [anon_sym_typedef] = ACTIONS(2448),
    [anon_sym_in] = ACTIONS(2448),
    [anon_sym_out] = ACTIONS(2448),
    [anon_sym_inout] = ACTIONS(2448),
    [anon_sym_extern] = ACTIONS(2448),
    [anon_sym___attribute__] = ACTIONS(2448),
    [anon_sym_COLON_COLON] = ACTIONS(2450),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2450),
    [anon_sym___declspec] = ACTIONS(2448),
    [anon_sym___based] = ACTIONS(2448),
    [anon_sym___cdecl] = ACTIONS(2448),
    [anon_sym___clrcall] = ACTIONS(2448),
    [anon_sym___stdcall] = ACTIONS(2448),
    [anon_sym___fastcall] = ACTIONS(2448),
    [anon_sym___thiscall] = ACTIONS(2448),
    [anon_sym___vectorcall] = ACTIONS(2448),
    [anon_sym_LBRACE] = ACTIONS(2450),
    [anon_sym_signed] = ACTIONS(2448),
    [anon_sym_unsigned] = ACTIONS(2448),
    [anon_sym_long] = ACTIONS(2448),
    [anon_sym_short] = ACTIONS(2448),
    [anon_sym_LBRACK] = ACTIONS(2448),
    [anon_sym_static] = ACTIONS(2448),
    [anon_sym_register] = ACTIONS(2448),
    [anon_sym_inline] = ACTIONS(2448),
    [anon_sym___inline] = ACTIONS(2448),
    [anon_sym___inline__] = ACTIONS(2448),
    [anon_sym___forceinline] = ACTIONS(2448),
    [anon_sym_thread_local] = ACTIONS(2448),
    [anon_sym___thread] = ACTIONS(2448),
    [anon_sym_const] = ACTIONS(2448),
    [anon_sym_constexpr] = ACTIONS(2448),
    [anon_sym_volatile] = ACTIONS(2448),
    [anon_sym_restrict] = ACTIONS(2448),
    [anon_sym___restrict__] = ACTIONS(2448),
    [anon_sym__Atomic] = ACTIONS(2448),
    [anon_sym__Noreturn] = ACTIONS(2448),
    [anon_sym_noreturn] = ACTIONS(2448),
    [anon_sym_mutable] = ACTIONS(2448),
    [anon_sym_constinit] = ACTIONS(2448),
    [anon_sym_consteval] = ACTIONS(2448),
    [anon_sym_alignas] = ACTIONS(2448),
    [anon_sym__Alignas] = ACTIONS(2448),
    [sym_primitive_type] = ACTIONS(2448),
    [anon_sym_enum] = ACTIONS(2448),
    [anon_sym_class] = ACTIONS(2448),
    [anon_sym_struct] = ACTIONS(2448),
    [anon_sym_union] = ACTIONS(2448),
    [anon_sym_if] = ACTIONS(2448),
    [anon_sym_switch] = ACTIONS(2448),
    [anon_sym_case] = ACTIONS(2448),
    [anon_sym_default] = ACTIONS(2448),
    [anon_sym_while] = ACTIONS(2448),
    [anon_sym_do] = ACTIONS(2448),
    [anon_sym_for] = ACTIONS(2448),
    [anon_sym_return] = ACTIONS(2448),
    [anon_sym_break] = ACTIONS(2448),
    [anon_sym_continue] = ACTIONS(2448),
    [anon_sym_goto] = ACTIONS(2448),
    [anon_sym___try] = ACTIONS(2448),
    [anon_sym___leave] = ACTIONS(2448),
    [anon_sym_not] = ACTIONS(2448),
    [anon_sym_compl] = ACTIONS(2448),
    [anon_sym_DASH_DASH] = ACTIONS(2450),
    [anon_sym_PLUS_PLUS] = ACTIONS(2450),
    [anon_sym_sizeof] = ACTIONS(2448),
    [anon_sym___alignof__] = ACTIONS(2448),
    [anon_sym___alignof] = ACTIONS(2448),
    [anon_sym__alignof] = ACTIONS(2448),
    [anon_sym_alignof] = ACTIONS(2448),
    [anon_sym__Alignof] = ACTIONS(2448),
    [anon_sym_offsetof] = ACTIONS(2448),
    [anon_sym__Generic] = ACTIONS(2448),
    [anon_sym_asm] = ACTIONS(2448),
    [anon_sym___asm__] = ACTIONS(2448),
    [sym_number_literal] = ACTIONS(2450),
    [anon_sym_L_SQUOTE] = ACTIONS(2450),
    [anon_sym_u_SQUOTE] = ACTIONS(2450),
    [anon_sym_U_SQUOTE] = ACTIONS(2450),
    [anon_sym_u8_SQUOTE] = ACTIONS(2450),
    [anon_sym_SQUOTE] = ACTIONS(2450),
    [anon_sym_L_DQUOTE] = ACTIONS(2450),
    [anon_sym_u_DQUOTE] = ACTIONS(2450),
    [anon_sym_U_DQUOTE] = ACTIONS(2450),
    [anon_sym_u8_DQUOTE] = ACTIONS(2450),
    [anon_sym_DQUOTE] = ACTIONS(2450),
    [sym_true] = ACTIONS(2448),
    [sym_false] = ACTIONS(2448),
    [anon_sym_NULL] = ACTIONS(2448),
    [anon_sym_nullptr] = ACTIONS(2448),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2448),
    [anon_sym_decltype] = ACTIONS(2448),
    [sym_virtual] = ACTIONS(2448),
    [anon_sym_explicit] = ACTIONS(2448),
    [anon_sym_typename] = ACTIONS(2448),
    [anon_sym_template] = ACTIONS(2448),
    [anon_sym_operator] = ACTIONS(2448),
    [anon_sym_try] = ACTIONS(2448),
    [anon_sym_delete] = ACTIONS(2448),
    [anon_sym_throw] = ACTIONS(2448),
    [anon_sym_namespace] = ACTIONS(2448),
    [anon_sym_using] = ACTIONS(2448),
    [anon_sym_static_assert] = ACTIONS(2448),
    [anon_sym_concept] = ACTIONS(2448),
    [anon_sym_co_return] = ACTIONS(2448),
    [anon_sym_co_yield] = ACTIONS(2448),
    [anon_sym_R_DQUOTE] = ACTIONS(2450),
    [anon_sym_LR_DQUOTE] = ACTIONS(2450),
    [anon_sym_uR_DQUOTE] = ACTIONS(2450),
    [anon_sym_UR_DQUOTE] = ACTIONS(2450),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2450),
    [anon_sym_co_await] = ACTIONS(2448),
    [anon_sym_new] = ACTIONS(2448),
    [anon_sym_requires] = ACTIONS(2448),
    [sym_this] = ACTIONS(2448),
    [anon_sym_discard] = ACTIONS(2448),
    [anon_sym_precise] = ACTIONS(2448),
    [anon_sym_shared] = ACTIONS(2448),
    [anon_sym_groupshared] = ACTIONS(2448),
    [anon_sym_uniform] = ACTIONS(2448),
    [anon_sym_row_major] = ACTIONS(2448),
    [anon_sym_column_major] = ACTIONS(2448),
    [anon_sym_globallycoherent] = ACTIONS(2448),
    [anon_sym_centroid] = ACTIONS(2448),
    [anon_sym_noperspective] = ACTIONS(2448),
    [anon_sym_nointerpolation] = ACTIONS(2448),
    [anon_sym_sample] = ACTIONS(2448),
    [anon_sym_linear] = ACTIONS(2448),
    [anon_sym_snorm] = ACTIONS(2448),
    [anon_sym_unorm] = ACTIONS(2448),
    [anon_sym_point] = ACTIONS(2448),
    [anon_sym_line] = ACTIONS(2448),
    [anon_sym_triangleadj] = ACTIONS(2448),
    [anon_sym_lineadj] = ACTIONS(2448),
    [anon_sym_triangle] = ACTIONS(2448),
    [anon_sym_cbuffer] = ACTIONS(2448),
  },
  [651] = {
    [sym_identifier] = ACTIONS(2474),
    [aux_sym_preproc_include_token1] = ACTIONS(2474),
    [aux_sym_preproc_def_token1] = ACTIONS(2474),
    [aux_sym_preproc_if_token1] = ACTIONS(2474),
    [aux_sym_preproc_if_token2] = ACTIONS(2474),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2474),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2474),
    [sym_preproc_directive] = ACTIONS(2474),
    [anon_sym_LPAREN2] = ACTIONS(2476),
    [anon_sym_BANG] = ACTIONS(2476),
    [anon_sym_TILDE] = ACTIONS(2476),
    [anon_sym_DASH] = ACTIONS(2474),
    [anon_sym_PLUS] = ACTIONS(2474),
    [anon_sym_STAR] = ACTIONS(2476),
    [anon_sym_AMP_AMP] = ACTIONS(2476),
    [anon_sym_AMP] = ACTIONS(2474),
    [anon_sym_SEMI] = ACTIONS(2476),
    [anon_sym___extension__] = ACTIONS(2474),
    [anon_sym_typedef] = ACTIONS(2474),
    [anon_sym_in] = ACTIONS(2474),
    [anon_sym_out] = ACTIONS(2474),
    [anon_sym_inout] = ACTIONS(2474),
    [anon_sym_extern] = ACTIONS(2474),
    [anon_sym___attribute__] = ACTIONS(2474),
    [anon_sym_COLON_COLON] = ACTIONS(2476),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2476),
    [anon_sym___declspec] = ACTIONS(2474),
    [anon_sym___based] = ACTIONS(2474),
    [anon_sym___cdecl] = ACTIONS(2474),
    [anon_sym___clrcall] = ACTIONS(2474),
    [anon_sym___stdcall] = ACTIONS(2474),
    [anon_sym___fastcall] = ACTIONS(2474),
    [anon_sym___thiscall] = ACTIONS(2474),
    [anon_sym___vectorcall] = ACTIONS(2474),
    [anon_sym_LBRACE] = ACTIONS(2476),
    [anon_sym_signed] = ACTIONS(2474),
    [anon_sym_unsigned] = ACTIONS(2474),
    [anon_sym_long] = ACTIONS(2474),
    [anon_sym_short] = ACTIONS(2474),
    [anon_sym_LBRACK] = ACTIONS(2474),
    [anon_sym_static] = ACTIONS(2474),
    [anon_sym_register] = ACTIONS(2474),
    [anon_sym_inline] = ACTIONS(2474),
    [anon_sym___inline] = ACTIONS(2474),
    [anon_sym___inline__] = ACTIONS(2474),
    [anon_sym___forceinline] = ACTIONS(2474),
    [anon_sym_thread_local] = ACTIONS(2474),
    [anon_sym___thread] = ACTIONS(2474),
    [anon_sym_const] = ACTIONS(2474),
    [anon_sym_constexpr] = ACTIONS(2474),
    [anon_sym_volatile] = ACTIONS(2474),
    [anon_sym_restrict] = ACTIONS(2474),
    [anon_sym___restrict__] = ACTIONS(2474),
    [anon_sym__Atomic] = ACTIONS(2474),
    [anon_sym__Noreturn] = ACTIONS(2474),
    [anon_sym_noreturn] = ACTIONS(2474),
    [anon_sym_mutable] = ACTIONS(2474),
    [anon_sym_constinit] = ACTIONS(2474),
    [anon_sym_consteval] = ACTIONS(2474),
    [anon_sym_alignas] = ACTIONS(2474),
    [anon_sym__Alignas] = ACTIONS(2474),
    [sym_primitive_type] = ACTIONS(2474),
    [anon_sym_enum] = ACTIONS(2474),
    [anon_sym_class] = ACTIONS(2474),
    [anon_sym_struct] = ACTIONS(2474),
    [anon_sym_union] = ACTIONS(2474),
    [anon_sym_if] = ACTIONS(2474),
    [anon_sym_switch] = ACTIONS(2474),
    [anon_sym_case] = ACTIONS(2474),
    [anon_sym_default] = ACTIONS(2474),
    [anon_sym_while] = ACTIONS(2474),
    [anon_sym_do] = ACTIONS(2474),
    [anon_sym_for] = ACTIONS(2474),
    [anon_sym_return] = ACTIONS(2474),
    [anon_sym_break] = ACTIONS(2474),
    [anon_sym_continue] = ACTIONS(2474),
    [anon_sym_goto] = ACTIONS(2474),
    [anon_sym___try] = ACTIONS(2474),
    [anon_sym___leave] = ACTIONS(2474),
    [anon_sym_not] = ACTIONS(2474),
    [anon_sym_compl] = ACTIONS(2474),
    [anon_sym_DASH_DASH] = ACTIONS(2476),
    [anon_sym_PLUS_PLUS] = ACTIONS(2476),
    [anon_sym_sizeof] = ACTIONS(2474),
    [anon_sym___alignof__] = ACTIONS(2474),
    [anon_sym___alignof] = ACTIONS(2474),
    [anon_sym__alignof] = ACTIONS(2474),
    [anon_sym_alignof] = ACTIONS(2474),
    [anon_sym__Alignof] = ACTIONS(2474),
    [anon_sym_offsetof] = ACTIONS(2474),
    [anon_sym__Generic] = ACTIONS(2474),
    [anon_sym_asm] = ACTIONS(2474),
    [anon_sym___asm__] = ACTIONS(2474),
    [sym_number_literal] = ACTIONS(2476),
    [anon_sym_L_SQUOTE] = ACTIONS(2476),
    [anon_sym_u_SQUOTE] = ACTIONS(2476),
    [anon_sym_U_SQUOTE] = ACTIONS(2476),
    [anon_sym_u8_SQUOTE] = ACTIONS(2476),
    [anon_sym_SQUOTE] = ACTIONS(2476),
    [anon_sym_L_DQUOTE] = ACTIONS(2476),
    [anon_sym_u_DQUOTE] = ACTIONS(2476),
    [anon_sym_U_DQUOTE] = ACTIONS(2476),
    [anon_sym_u8_DQUOTE] = ACTIONS(2476),
    [anon_sym_DQUOTE] = ACTIONS(2476),
    [sym_true] = ACTIONS(2474),
    [sym_false] = ACTIONS(2474),
    [anon_sym_NULL] = ACTIONS(2474),
    [anon_sym_nullptr] = ACTIONS(2474),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2474),
    [anon_sym_decltype] = ACTIONS(2474),
    [sym_virtual] = ACTIONS(2474),
    [anon_sym_explicit] = ACTIONS(2474),
    [anon_sym_typename] = ACTIONS(2474),
    [anon_sym_template] = ACTIONS(2474),
    [anon_sym_operator] = ACTIONS(2474),
    [anon_sym_try] = ACTIONS(2474),
    [anon_sym_delete] = ACTIONS(2474),
    [anon_sym_throw] = ACTIONS(2474),
    [anon_sym_namespace] = ACTIONS(2474),
    [anon_sym_using] = ACTIONS(2474),
    [anon_sym_static_assert] = ACTIONS(2474),
    [anon_sym_concept] = ACTIONS(2474),
    [anon_sym_co_return] = ACTIONS(2474),
    [anon_sym_co_yield] = ACTIONS(2474),
    [anon_sym_R_DQUOTE] = ACTIONS(2476),
    [anon_sym_LR_DQUOTE] = ACTIONS(2476),
    [anon_sym_uR_DQUOTE] = ACTIONS(2476),
    [anon_sym_UR_DQUOTE] = ACTIONS(2476),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2476),
    [anon_sym_co_await] = ACTIONS(2474),
    [anon_sym_new] = ACTIONS(2474),
    [anon_sym_requires] = ACTIONS(2474),
    [sym_this] = ACTIONS(2474),
    [anon_sym_discard] = ACTIONS(2474),
    [anon_sym_precise] = ACTIONS(2474),
    [anon_sym_shared] = ACTIONS(2474),
    [anon_sym_groupshared] = ACTIONS(2474),
    [anon_sym_uniform] = ACTIONS(2474),
    [anon_sym_row_major] = ACTIONS(2474),
    [anon_sym_column_major] = ACTIONS(2474),
    [anon_sym_globallycoherent] = ACTIONS(2474),
    [anon_sym_centroid] = ACTIONS(2474),
    [anon_sym_noperspective] = ACTIONS(2474),
    [anon_sym_nointerpolation] = ACTIONS(2474),
    [anon_sym_sample] = ACTIONS(2474),
    [anon_sym_linear] = ACTIONS(2474),
    [anon_sym_snorm] = ACTIONS(2474),
    [anon_sym_unorm] = ACTIONS(2474),
    [anon_sym_point] = ACTIONS(2474),
    [anon_sym_line] = ACTIONS(2474),
    [anon_sym_triangleadj] = ACTIONS(2474),
    [anon_sym_lineadj] = ACTIONS(2474),
    [anon_sym_triangle] = ACTIONS(2474),
    [anon_sym_cbuffer] = ACTIONS(2474),
  },
  [652] = {
    [sym_identifier] = ACTIONS(2573),
    [aux_sym_preproc_include_token1] = ACTIONS(2573),
    [aux_sym_preproc_def_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token2] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2573),
    [sym_preproc_directive] = ACTIONS(2573),
    [anon_sym_LPAREN2] = ACTIONS(2575),
    [anon_sym_BANG] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(2575),
    [anon_sym_DASH] = ACTIONS(2573),
    [anon_sym_PLUS] = ACTIONS(2573),
    [anon_sym_STAR] = ACTIONS(2575),
    [anon_sym_AMP_AMP] = ACTIONS(2575),
    [anon_sym_AMP] = ACTIONS(2573),
    [anon_sym_SEMI] = ACTIONS(2575),
    [anon_sym___extension__] = ACTIONS(2573),
    [anon_sym_typedef] = ACTIONS(2573),
    [anon_sym_in] = ACTIONS(2573),
    [anon_sym_out] = ACTIONS(2573),
    [anon_sym_inout] = ACTIONS(2573),
    [anon_sym_extern] = ACTIONS(2573),
    [anon_sym___attribute__] = ACTIONS(2573),
    [anon_sym_COLON_COLON] = ACTIONS(2575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2575),
    [anon_sym___declspec] = ACTIONS(2573),
    [anon_sym___based] = ACTIONS(2573),
    [anon_sym___cdecl] = ACTIONS(2573),
    [anon_sym___clrcall] = ACTIONS(2573),
    [anon_sym___stdcall] = ACTIONS(2573),
    [anon_sym___fastcall] = ACTIONS(2573),
    [anon_sym___thiscall] = ACTIONS(2573),
    [anon_sym___vectorcall] = ACTIONS(2573),
    [anon_sym_LBRACE] = ACTIONS(2575),
    [anon_sym_signed] = ACTIONS(2573),
    [anon_sym_unsigned] = ACTIONS(2573),
    [anon_sym_long] = ACTIONS(2573),
    [anon_sym_short] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2573),
    [anon_sym_static] = ACTIONS(2573),
    [anon_sym_register] = ACTIONS(2573),
    [anon_sym_inline] = ACTIONS(2573),
    [anon_sym___inline] = ACTIONS(2573),
    [anon_sym___inline__] = ACTIONS(2573),
    [anon_sym___forceinline] = ACTIONS(2573),
    [anon_sym_thread_local] = ACTIONS(2573),
    [anon_sym___thread] = ACTIONS(2573),
    [anon_sym_const] = ACTIONS(2573),
    [anon_sym_constexpr] = ACTIONS(2573),
    [anon_sym_volatile] = ACTIONS(2573),
    [anon_sym_restrict] = ACTIONS(2573),
    [anon_sym___restrict__] = ACTIONS(2573),
    [anon_sym__Atomic] = ACTIONS(2573),
    [anon_sym__Noreturn] = ACTIONS(2573),
    [anon_sym_noreturn] = ACTIONS(2573),
    [anon_sym_mutable] = ACTIONS(2573),
    [anon_sym_constinit] = ACTIONS(2573),
    [anon_sym_consteval] = ACTIONS(2573),
    [anon_sym_alignas] = ACTIONS(2573),
    [anon_sym__Alignas] = ACTIONS(2573),
    [sym_primitive_type] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_class] = ACTIONS(2573),
    [anon_sym_struct] = ACTIONS(2573),
    [anon_sym_union] = ACTIONS(2573),
    [anon_sym_if] = ACTIONS(2573),
    [anon_sym_switch] = ACTIONS(2573),
    [anon_sym_case] = ACTIONS(2573),
    [anon_sym_default] = ACTIONS(2573),
    [anon_sym_while] = ACTIONS(2573),
    [anon_sym_do] = ACTIONS(2573),
    [anon_sym_for] = ACTIONS(2573),
    [anon_sym_return] = ACTIONS(2573),
    [anon_sym_break] = ACTIONS(2573),
    [anon_sym_continue] = ACTIONS(2573),
    [anon_sym_goto] = ACTIONS(2573),
    [anon_sym___try] = ACTIONS(2573),
    [anon_sym___leave] = ACTIONS(2573),
    [anon_sym_not] = ACTIONS(2573),
    [anon_sym_compl] = ACTIONS(2573),
    [anon_sym_DASH_DASH] = ACTIONS(2575),
    [anon_sym_PLUS_PLUS] = ACTIONS(2575),
    [anon_sym_sizeof] = ACTIONS(2573),
    [anon_sym___alignof__] = ACTIONS(2573),
    [anon_sym___alignof] = ACTIONS(2573),
    [anon_sym__alignof] = ACTIONS(2573),
    [anon_sym_alignof] = ACTIONS(2573),
    [anon_sym__Alignof] = ACTIONS(2573),
    [anon_sym_offsetof] = ACTIONS(2573),
    [anon_sym__Generic] = ACTIONS(2573),
    [anon_sym_asm] = ACTIONS(2573),
    [anon_sym___asm__] = ACTIONS(2573),
    [sym_number_literal] = ACTIONS(2575),
    [anon_sym_L_SQUOTE] = ACTIONS(2575),
    [anon_sym_u_SQUOTE] = ACTIONS(2575),
    [anon_sym_U_SQUOTE] = ACTIONS(2575),
    [anon_sym_u8_SQUOTE] = ACTIONS(2575),
    [anon_sym_SQUOTE] = ACTIONS(2575),
    [anon_sym_L_DQUOTE] = ACTIONS(2575),
    [anon_sym_u_DQUOTE] = ACTIONS(2575),
    [anon_sym_U_DQUOTE] = ACTIONS(2575),
    [anon_sym_u8_DQUOTE] = ACTIONS(2575),
    [anon_sym_DQUOTE] = ACTIONS(2575),
    [sym_true] = ACTIONS(2573),
    [sym_false] = ACTIONS(2573),
    [anon_sym_NULL] = ACTIONS(2573),
    [anon_sym_nullptr] = ACTIONS(2573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2573),
    [anon_sym_decltype] = ACTIONS(2573),
    [sym_virtual] = ACTIONS(2573),
    [anon_sym_explicit] = ACTIONS(2573),
    [anon_sym_typename] = ACTIONS(2573),
    [anon_sym_template] = ACTIONS(2573),
    [anon_sym_operator] = ACTIONS(2573),
    [anon_sym_try] = ACTIONS(2573),
    [anon_sym_delete] = ACTIONS(2573),
    [anon_sym_throw] = ACTIONS(2573),
    [anon_sym_namespace] = ACTIONS(2573),
    [anon_sym_using] = ACTIONS(2573),
    [anon_sym_static_assert] = ACTIONS(2573),
    [anon_sym_concept] = ACTIONS(2573),
    [anon_sym_co_return] = ACTIONS(2573),
    [anon_sym_co_yield] = ACTIONS(2573),
    [anon_sym_R_DQUOTE] = ACTIONS(2575),
    [anon_sym_LR_DQUOTE] = ACTIONS(2575),
    [anon_sym_uR_DQUOTE] = ACTIONS(2575),
    [anon_sym_UR_DQUOTE] = ACTIONS(2575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2575),
    [anon_sym_co_await] = ACTIONS(2573),
    [anon_sym_new] = ACTIONS(2573),
    [anon_sym_requires] = ACTIONS(2573),
    [sym_this] = ACTIONS(2573),
    [anon_sym_discard] = ACTIONS(2573),
    [anon_sym_precise] = ACTIONS(2573),
    [anon_sym_shared] = ACTIONS(2573),
    [anon_sym_groupshared] = ACTIONS(2573),
    [anon_sym_uniform] = ACTIONS(2573),
    [anon_sym_row_major] = ACTIONS(2573),
    [anon_sym_column_major] = ACTIONS(2573),
    [anon_sym_globallycoherent] = ACTIONS(2573),
    [anon_sym_centroid] = ACTIONS(2573),
    [anon_sym_noperspective] = ACTIONS(2573),
    [anon_sym_nointerpolation] = ACTIONS(2573),
    [anon_sym_sample] = ACTIONS(2573),
    [anon_sym_linear] = ACTIONS(2573),
    [anon_sym_snorm] = ACTIONS(2573),
    [anon_sym_unorm] = ACTIONS(2573),
    [anon_sym_point] = ACTIONS(2573),
    [anon_sym_line] = ACTIONS(2573),
    [anon_sym_triangleadj] = ACTIONS(2573),
    [anon_sym_lineadj] = ACTIONS(2573),
    [anon_sym_triangle] = ACTIONS(2573),
    [anon_sym_cbuffer] = ACTIONS(2573),
  },
  [653] = {
    [sym_identifier] = ACTIONS(2478),
    [aux_sym_preproc_include_token1] = ACTIONS(2478),
    [aux_sym_preproc_def_token1] = ACTIONS(2478),
    [aux_sym_preproc_if_token1] = ACTIONS(2478),
    [aux_sym_preproc_if_token2] = ACTIONS(2478),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2478),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2478),
    [sym_preproc_directive] = ACTIONS(2478),
    [anon_sym_LPAREN2] = ACTIONS(2480),
    [anon_sym_BANG] = ACTIONS(2480),
    [anon_sym_TILDE] = ACTIONS(2480),
    [anon_sym_DASH] = ACTIONS(2478),
    [anon_sym_PLUS] = ACTIONS(2478),
    [anon_sym_STAR] = ACTIONS(2480),
    [anon_sym_AMP_AMP] = ACTIONS(2480),
    [anon_sym_AMP] = ACTIONS(2478),
    [anon_sym_SEMI] = ACTIONS(2480),
    [anon_sym___extension__] = ACTIONS(2478),
    [anon_sym_typedef] = ACTIONS(2478),
    [anon_sym_in] = ACTIONS(2478),
    [anon_sym_out] = ACTIONS(2478),
    [anon_sym_inout] = ACTIONS(2478),
    [anon_sym_extern] = ACTIONS(2478),
    [anon_sym___attribute__] = ACTIONS(2478),
    [anon_sym_COLON_COLON] = ACTIONS(2480),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2480),
    [anon_sym___declspec] = ACTIONS(2478),
    [anon_sym___based] = ACTIONS(2478),
    [anon_sym___cdecl] = ACTIONS(2478),
    [anon_sym___clrcall] = ACTIONS(2478),
    [anon_sym___stdcall] = ACTIONS(2478),
    [anon_sym___fastcall] = ACTIONS(2478),
    [anon_sym___thiscall] = ACTIONS(2478),
    [anon_sym___vectorcall] = ACTIONS(2478),
    [anon_sym_LBRACE] = ACTIONS(2480),
    [anon_sym_signed] = ACTIONS(2478),
    [anon_sym_unsigned] = ACTIONS(2478),
    [anon_sym_long] = ACTIONS(2478),
    [anon_sym_short] = ACTIONS(2478),
    [anon_sym_LBRACK] = ACTIONS(2478),
    [anon_sym_static] = ACTIONS(2478),
    [anon_sym_register] = ACTIONS(2478),
    [anon_sym_inline] = ACTIONS(2478),
    [anon_sym___inline] = ACTIONS(2478),
    [anon_sym___inline__] = ACTIONS(2478),
    [anon_sym___forceinline] = ACTIONS(2478),
    [anon_sym_thread_local] = ACTIONS(2478),
    [anon_sym___thread] = ACTIONS(2478),
    [anon_sym_const] = ACTIONS(2478),
    [anon_sym_constexpr] = ACTIONS(2478),
    [anon_sym_volatile] = ACTIONS(2478),
    [anon_sym_restrict] = ACTIONS(2478),
    [anon_sym___restrict__] = ACTIONS(2478),
    [anon_sym__Atomic] = ACTIONS(2478),
    [anon_sym__Noreturn] = ACTIONS(2478),
    [anon_sym_noreturn] = ACTIONS(2478),
    [anon_sym_mutable] = ACTIONS(2478),
    [anon_sym_constinit] = ACTIONS(2478),
    [anon_sym_consteval] = ACTIONS(2478),
    [anon_sym_alignas] = ACTIONS(2478),
    [anon_sym__Alignas] = ACTIONS(2478),
    [sym_primitive_type] = ACTIONS(2478),
    [anon_sym_enum] = ACTIONS(2478),
    [anon_sym_class] = ACTIONS(2478),
    [anon_sym_struct] = ACTIONS(2478),
    [anon_sym_union] = ACTIONS(2478),
    [anon_sym_if] = ACTIONS(2478),
    [anon_sym_switch] = ACTIONS(2478),
    [anon_sym_case] = ACTIONS(2478),
    [anon_sym_default] = ACTIONS(2478),
    [anon_sym_while] = ACTIONS(2478),
    [anon_sym_do] = ACTIONS(2478),
    [anon_sym_for] = ACTIONS(2478),
    [anon_sym_return] = ACTIONS(2478),
    [anon_sym_break] = ACTIONS(2478),
    [anon_sym_continue] = ACTIONS(2478),
    [anon_sym_goto] = ACTIONS(2478),
    [anon_sym___try] = ACTIONS(2478),
    [anon_sym___leave] = ACTIONS(2478),
    [anon_sym_not] = ACTIONS(2478),
    [anon_sym_compl] = ACTIONS(2478),
    [anon_sym_DASH_DASH] = ACTIONS(2480),
    [anon_sym_PLUS_PLUS] = ACTIONS(2480),
    [anon_sym_sizeof] = ACTIONS(2478),
    [anon_sym___alignof__] = ACTIONS(2478),
    [anon_sym___alignof] = ACTIONS(2478),
    [anon_sym__alignof] = ACTIONS(2478),
    [anon_sym_alignof] = ACTIONS(2478),
    [anon_sym__Alignof] = ACTIONS(2478),
    [anon_sym_offsetof] = ACTIONS(2478),
    [anon_sym__Generic] = ACTIONS(2478),
    [anon_sym_asm] = ACTIONS(2478),
    [anon_sym___asm__] = ACTIONS(2478),
    [sym_number_literal] = ACTIONS(2480),
    [anon_sym_L_SQUOTE] = ACTIONS(2480),
    [anon_sym_u_SQUOTE] = ACTIONS(2480),
    [anon_sym_U_SQUOTE] = ACTIONS(2480),
    [anon_sym_u8_SQUOTE] = ACTIONS(2480),
    [anon_sym_SQUOTE] = ACTIONS(2480),
    [anon_sym_L_DQUOTE] = ACTIONS(2480),
    [anon_sym_u_DQUOTE] = ACTIONS(2480),
    [anon_sym_U_DQUOTE] = ACTIONS(2480),
    [anon_sym_u8_DQUOTE] = ACTIONS(2480),
    [anon_sym_DQUOTE] = ACTIONS(2480),
    [sym_true] = ACTIONS(2478),
    [sym_false] = ACTIONS(2478),
    [anon_sym_NULL] = ACTIONS(2478),
    [anon_sym_nullptr] = ACTIONS(2478),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2478),
    [anon_sym_decltype] = ACTIONS(2478),
    [sym_virtual] = ACTIONS(2478),
    [anon_sym_explicit] = ACTIONS(2478),
    [anon_sym_typename] = ACTIONS(2478),
    [anon_sym_template] = ACTIONS(2478),
    [anon_sym_operator] = ACTIONS(2478),
    [anon_sym_try] = ACTIONS(2478),
    [anon_sym_delete] = ACTIONS(2478),
    [anon_sym_throw] = ACTIONS(2478),
    [anon_sym_namespace] = ACTIONS(2478),
    [anon_sym_using] = ACTIONS(2478),
    [anon_sym_static_assert] = ACTIONS(2478),
    [anon_sym_concept] = ACTIONS(2478),
    [anon_sym_co_return] = ACTIONS(2478),
    [anon_sym_co_yield] = ACTIONS(2478),
    [anon_sym_R_DQUOTE] = ACTIONS(2480),
    [anon_sym_LR_DQUOTE] = ACTIONS(2480),
    [anon_sym_uR_DQUOTE] = ACTIONS(2480),
    [anon_sym_UR_DQUOTE] = ACTIONS(2480),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2480),
    [anon_sym_co_await] = ACTIONS(2478),
    [anon_sym_new] = ACTIONS(2478),
    [anon_sym_requires] = ACTIONS(2478),
    [sym_this] = ACTIONS(2478),
    [anon_sym_discard] = ACTIONS(2478),
    [anon_sym_precise] = ACTIONS(2478),
    [anon_sym_shared] = ACTIONS(2478),
    [anon_sym_groupshared] = ACTIONS(2478),
    [anon_sym_uniform] = ACTIONS(2478),
    [anon_sym_row_major] = ACTIONS(2478),
    [anon_sym_column_major] = ACTIONS(2478),
    [anon_sym_globallycoherent] = ACTIONS(2478),
    [anon_sym_centroid] = ACTIONS(2478),
    [anon_sym_noperspective] = ACTIONS(2478),
    [anon_sym_nointerpolation] = ACTIONS(2478),
    [anon_sym_sample] = ACTIONS(2478),
    [anon_sym_linear] = ACTIONS(2478),
    [anon_sym_snorm] = ACTIONS(2478),
    [anon_sym_unorm] = ACTIONS(2478),
    [anon_sym_point] = ACTIONS(2478),
    [anon_sym_line] = ACTIONS(2478),
    [anon_sym_triangleadj] = ACTIONS(2478),
    [anon_sym_lineadj] = ACTIONS(2478),
    [anon_sym_triangle] = ACTIONS(2478),
    [anon_sym_cbuffer] = ACTIONS(2478),
  },
  [654] = {
    [sym_identifier] = ACTIONS(2454),
    [aux_sym_preproc_include_token1] = ACTIONS(2454),
    [aux_sym_preproc_def_token1] = ACTIONS(2454),
    [aux_sym_preproc_if_token1] = ACTIONS(2454),
    [aux_sym_preproc_if_token2] = ACTIONS(2454),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2454),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2454),
    [sym_preproc_directive] = ACTIONS(2454),
    [anon_sym_LPAREN2] = ACTIONS(2456),
    [anon_sym_BANG] = ACTIONS(2456),
    [anon_sym_TILDE] = ACTIONS(2456),
    [anon_sym_DASH] = ACTIONS(2454),
    [anon_sym_PLUS] = ACTIONS(2454),
    [anon_sym_STAR] = ACTIONS(2456),
    [anon_sym_AMP_AMP] = ACTIONS(2456),
    [anon_sym_AMP] = ACTIONS(2454),
    [anon_sym_SEMI] = ACTIONS(2456),
    [anon_sym___extension__] = ACTIONS(2454),
    [anon_sym_typedef] = ACTIONS(2454),
    [anon_sym_in] = ACTIONS(2454),
    [anon_sym_out] = ACTIONS(2454),
    [anon_sym_inout] = ACTIONS(2454),
    [anon_sym_extern] = ACTIONS(2454),
    [anon_sym___attribute__] = ACTIONS(2454),
    [anon_sym_COLON_COLON] = ACTIONS(2456),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2456),
    [anon_sym___declspec] = ACTIONS(2454),
    [anon_sym___based] = ACTIONS(2454),
    [anon_sym___cdecl] = ACTIONS(2454),
    [anon_sym___clrcall] = ACTIONS(2454),
    [anon_sym___stdcall] = ACTIONS(2454),
    [anon_sym___fastcall] = ACTIONS(2454),
    [anon_sym___thiscall] = ACTIONS(2454),
    [anon_sym___vectorcall] = ACTIONS(2454),
    [anon_sym_LBRACE] = ACTIONS(2456),
    [anon_sym_signed] = ACTIONS(2454),
    [anon_sym_unsigned] = ACTIONS(2454),
    [anon_sym_long] = ACTIONS(2454),
    [anon_sym_short] = ACTIONS(2454),
    [anon_sym_LBRACK] = ACTIONS(2454),
    [anon_sym_static] = ACTIONS(2454),
    [anon_sym_register] = ACTIONS(2454),
    [anon_sym_inline] = ACTIONS(2454),
    [anon_sym___inline] = ACTIONS(2454),
    [anon_sym___inline__] = ACTIONS(2454),
    [anon_sym___forceinline] = ACTIONS(2454),
    [anon_sym_thread_local] = ACTIONS(2454),
    [anon_sym___thread] = ACTIONS(2454),
    [anon_sym_const] = ACTIONS(2454),
    [anon_sym_constexpr] = ACTIONS(2454),
    [anon_sym_volatile] = ACTIONS(2454),
    [anon_sym_restrict] = ACTIONS(2454),
    [anon_sym___restrict__] = ACTIONS(2454),
    [anon_sym__Atomic] = ACTIONS(2454),
    [anon_sym__Noreturn] = ACTIONS(2454),
    [anon_sym_noreturn] = ACTIONS(2454),
    [anon_sym_mutable] = ACTIONS(2454),
    [anon_sym_constinit] = ACTIONS(2454),
    [anon_sym_consteval] = ACTIONS(2454),
    [anon_sym_alignas] = ACTIONS(2454),
    [anon_sym__Alignas] = ACTIONS(2454),
    [sym_primitive_type] = ACTIONS(2454),
    [anon_sym_enum] = ACTIONS(2454),
    [anon_sym_class] = ACTIONS(2454),
    [anon_sym_struct] = ACTIONS(2454),
    [anon_sym_union] = ACTIONS(2454),
    [anon_sym_if] = ACTIONS(2454),
    [anon_sym_switch] = ACTIONS(2454),
    [anon_sym_case] = ACTIONS(2454),
    [anon_sym_default] = ACTIONS(2454),
    [anon_sym_while] = ACTIONS(2454),
    [anon_sym_do] = ACTIONS(2454),
    [anon_sym_for] = ACTIONS(2454),
    [anon_sym_return] = ACTIONS(2454),
    [anon_sym_break] = ACTIONS(2454),
    [anon_sym_continue] = ACTIONS(2454),
    [anon_sym_goto] = ACTIONS(2454),
    [anon_sym___try] = ACTIONS(2454),
    [anon_sym___leave] = ACTIONS(2454),
    [anon_sym_not] = ACTIONS(2454),
    [anon_sym_compl] = ACTIONS(2454),
    [anon_sym_DASH_DASH] = ACTIONS(2456),
    [anon_sym_PLUS_PLUS] = ACTIONS(2456),
    [anon_sym_sizeof] = ACTIONS(2454),
    [anon_sym___alignof__] = ACTIONS(2454),
    [anon_sym___alignof] = ACTIONS(2454),
    [anon_sym__alignof] = ACTIONS(2454),
    [anon_sym_alignof] = ACTIONS(2454),
    [anon_sym__Alignof] = ACTIONS(2454),
    [anon_sym_offsetof] = ACTIONS(2454),
    [anon_sym__Generic] = ACTIONS(2454),
    [anon_sym_asm] = ACTIONS(2454),
    [anon_sym___asm__] = ACTIONS(2454),
    [sym_number_literal] = ACTIONS(2456),
    [anon_sym_L_SQUOTE] = ACTIONS(2456),
    [anon_sym_u_SQUOTE] = ACTIONS(2456),
    [anon_sym_U_SQUOTE] = ACTIONS(2456),
    [anon_sym_u8_SQUOTE] = ACTIONS(2456),
    [anon_sym_SQUOTE] = ACTIONS(2456),
    [anon_sym_L_DQUOTE] = ACTIONS(2456),
    [anon_sym_u_DQUOTE] = ACTIONS(2456),
    [anon_sym_U_DQUOTE] = ACTIONS(2456),
    [anon_sym_u8_DQUOTE] = ACTIONS(2456),
    [anon_sym_DQUOTE] = ACTIONS(2456),
    [sym_true] = ACTIONS(2454),
    [sym_false] = ACTIONS(2454),
    [anon_sym_NULL] = ACTIONS(2454),
    [anon_sym_nullptr] = ACTIONS(2454),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2454),
    [anon_sym_decltype] = ACTIONS(2454),
    [sym_virtual] = ACTIONS(2454),
    [anon_sym_explicit] = ACTIONS(2454),
    [anon_sym_typename] = ACTIONS(2454),
    [anon_sym_template] = ACTIONS(2454),
    [anon_sym_operator] = ACTIONS(2454),
    [anon_sym_try] = ACTIONS(2454),
    [anon_sym_delete] = ACTIONS(2454),
    [anon_sym_throw] = ACTIONS(2454),
    [anon_sym_namespace] = ACTIONS(2454),
    [anon_sym_using] = ACTIONS(2454),
    [anon_sym_static_assert] = ACTIONS(2454),
    [anon_sym_concept] = ACTIONS(2454),
    [anon_sym_co_return] = ACTIONS(2454),
    [anon_sym_co_yield] = ACTIONS(2454),
    [anon_sym_R_DQUOTE] = ACTIONS(2456),
    [anon_sym_LR_DQUOTE] = ACTIONS(2456),
    [anon_sym_uR_DQUOTE] = ACTIONS(2456),
    [anon_sym_UR_DQUOTE] = ACTIONS(2456),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2456),
    [anon_sym_co_await] = ACTIONS(2454),
    [anon_sym_new] = ACTIONS(2454),
    [anon_sym_requires] = ACTIONS(2454),
    [sym_this] = ACTIONS(2454),
    [anon_sym_discard] = ACTIONS(2454),
    [anon_sym_precise] = ACTIONS(2454),
    [anon_sym_shared] = ACTIONS(2454),
    [anon_sym_groupshared] = ACTIONS(2454),
    [anon_sym_uniform] = ACTIONS(2454),
    [anon_sym_row_major] = ACTIONS(2454),
    [anon_sym_column_major] = ACTIONS(2454),
    [anon_sym_globallycoherent] = ACTIONS(2454),
    [anon_sym_centroid] = ACTIONS(2454),
    [anon_sym_noperspective] = ACTIONS(2454),
    [anon_sym_nointerpolation] = ACTIONS(2454),
    [anon_sym_sample] = ACTIONS(2454),
    [anon_sym_linear] = ACTIONS(2454),
    [anon_sym_snorm] = ACTIONS(2454),
    [anon_sym_unorm] = ACTIONS(2454),
    [anon_sym_point] = ACTIONS(2454),
    [anon_sym_line] = ACTIONS(2454),
    [anon_sym_triangleadj] = ACTIONS(2454),
    [anon_sym_lineadj] = ACTIONS(2454),
    [anon_sym_triangle] = ACTIONS(2454),
    [anon_sym_cbuffer] = ACTIONS(2454),
  },
  [655] = {
    [sym_identifier] = ACTIONS(2312),
    [aux_sym_preproc_include_token1] = ACTIONS(2312),
    [aux_sym_preproc_def_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token2] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2312),
    [sym_preproc_directive] = ACTIONS(2312),
    [anon_sym_LPAREN2] = ACTIONS(2314),
    [anon_sym_BANG] = ACTIONS(2314),
    [anon_sym_TILDE] = ACTIONS(2314),
    [anon_sym_DASH] = ACTIONS(2312),
    [anon_sym_PLUS] = ACTIONS(2312),
    [anon_sym_STAR] = ACTIONS(2314),
    [anon_sym_AMP_AMP] = ACTIONS(2314),
    [anon_sym_AMP] = ACTIONS(2312),
    [anon_sym_SEMI] = ACTIONS(2314),
    [anon_sym___extension__] = ACTIONS(2312),
    [anon_sym_typedef] = ACTIONS(2312),
    [anon_sym_in] = ACTIONS(2312),
    [anon_sym_out] = ACTIONS(2312),
    [anon_sym_inout] = ACTIONS(2312),
    [anon_sym_extern] = ACTIONS(2312),
    [anon_sym___attribute__] = ACTIONS(2312),
    [anon_sym_COLON_COLON] = ACTIONS(2314),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2314),
    [anon_sym___declspec] = ACTIONS(2312),
    [anon_sym___based] = ACTIONS(2312),
    [anon_sym___cdecl] = ACTIONS(2312),
    [anon_sym___clrcall] = ACTIONS(2312),
    [anon_sym___stdcall] = ACTIONS(2312),
    [anon_sym___fastcall] = ACTIONS(2312),
    [anon_sym___thiscall] = ACTIONS(2312),
    [anon_sym___vectorcall] = ACTIONS(2312),
    [anon_sym_LBRACE] = ACTIONS(2314),
    [anon_sym_signed] = ACTIONS(2312),
    [anon_sym_unsigned] = ACTIONS(2312),
    [anon_sym_long] = ACTIONS(2312),
    [anon_sym_short] = ACTIONS(2312),
    [anon_sym_LBRACK] = ACTIONS(2312),
    [anon_sym_static] = ACTIONS(2312),
    [anon_sym_register] = ACTIONS(2312),
    [anon_sym_inline] = ACTIONS(2312),
    [anon_sym___inline] = ACTIONS(2312),
    [anon_sym___inline__] = ACTIONS(2312),
    [anon_sym___forceinline] = ACTIONS(2312),
    [anon_sym_thread_local] = ACTIONS(2312),
    [anon_sym___thread] = ACTIONS(2312),
    [anon_sym_const] = ACTIONS(2312),
    [anon_sym_constexpr] = ACTIONS(2312),
    [anon_sym_volatile] = ACTIONS(2312),
    [anon_sym_restrict] = ACTIONS(2312),
    [anon_sym___restrict__] = ACTIONS(2312),
    [anon_sym__Atomic] = ACTIONS(2312),
    [anon_sym__Noreturn] = ACTIONS(2312),
    [anon_sym_noreturn] = ACTIONS(2312),
    [anon_sym_mutable] = ACTIONS(2312),
    [anon_sym_constinit] = ACTIONS(2312),
    [anon_sym_consteval] = ACTIONS(2312),
    [anon_sym_alignas] = ACTIONS(2312),
    [anon_sym__Alignas] = ACTIONS(2312),
    [sym_primitive_type] = ACTIONS(2312),
    [anon_sym_enum] = ACTIONS(2312),
    [anon_sym_class] = ACTIONS(2312),
    [anon_sym_struct] = ACTIONS(2312),
    [anon_sym_union] = ACTIONS(2312),
    [anon_sym_if] = ACTIONS(2312),
    [anon_sym_switch] = ACTIONS(2312),
    [anon_sym_case] = ACTIONS(2312),
    [anon_sym_default] = ACTIONS(2312),
    [anon_sym_while] = ACTIONS(2312),
    [anon_sym_do] = ACTIONS(2312),
    [anon_sym_for] = ACTIONS(2312),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_break] = ACTIONS(2312),
    [anon_sym_continue] = ACTIONS(2312),
    [anon_sym_goto] = ACTIONS(2312),
    [anon_sym___try] = ACTIONS(2312),
    [anon_sym___leave] = ACTIONS(2312),
    [anon_sym_not] = ACTIONS(2312),
    [anon_sym_compl] = ACTIONS(2312),
    [anon_sym_DASH_DASH] = ACTIONS(2314),
    [anon_sym_PLUS_PLUS] = ACTIONS(2314),
    [anon_sym_sizeof] = ACTIONS(2312),
    [anon_sym___alignof__] = ACTIONS(2312),
    [anon_sym___alignof] = ACTIONS(2312),
    [anon_sym__alignof] = ACTIONS(2312),
    [anon_sym_alignof] = ACTIONS(2312),
    [anon_sym__Alignof] = ACTIONS(2312),
    [anon_sym_offsetof] = ACTIONS(2312),
    [anon_sym__Generic] = ACTIONS(2312),
    [anon_sym_asm] = ACTIONS(2312),
    [anon_sym___asm__] = ACTIONS(2312),
    [sym_number_literal] = ACTIONS(2314),
    [anon_sym_L_SQUOTE] = ACTIONS(2314),
    [anon_sym_u_SQUOTE] = ACTIONS(2314),
    [anon_sym_U_SQUOTE] = ACTIONS(2314),
    [anon_sym_u8_SQUOTE] = ACTIONS(2314),
    [anon_sym_SQUOTE] = ACTIONS(2314),
    [anon_sym_L_DQUOTE] = ACTIONS(2314),
    [anon_sym_u_DQUOTE] = ACTIONS(2314),
    [anon_sym_U_DQUOTE] = ACTIONS(2314),
    [anon_sym_u8_DQUOTE] = ACTIONS(2314),
    [anon_sym_DQUOTE] = ACTIONS(2314),
    [sym_true] = ACTIONS(2312),
    [sym_false] = ACTIONS(2312),
    [anon_sym_NULL] = ACTIONS(2312),
    [anon_sym_nullptr] = ACTIONS(2312),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2312),
    [anon_sym_decltype] = ACTIONS(2312),
    [sym_virtual] = ACTIONS(2312),
    [anon_sym_explicit] = ACTIONS(2312),
    [anon_sym_typename] = ACTIONS(2312),
    [anon_sym_template] = ACTIONS(2312),
    [anon_sym_operator] = ACTIONS(2312),
    [anon_sym_try] = ACTIONS(2312),
    [anon_sym_delete] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2312),
    [anon_sym_namespace] = ACTIONS(2312),
    [anon_sym_using] = ACTIONS(2312),
    [anon_sym_static_assert] = ACTIONS(2312),
    [anon_sym_concept] = ACTIONS(2312),
    [anon_sym_co_return] = ACTIONS(2312),
    [anon_sym_co_yield] = ACTIONS(2312),
    [anon_sym_R_DQUOTE] = ACTIONS(2314),
    [anon_sym_LR_DQUOTE] = ACTIONS(2314),
    [anon_sym_uR_DQUOTE] = ACTIONS(2314),
    [anon_sym_UR_DQUOTE] = ACTIONS(2314),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2314),
    [anon_sym_co_await] = ACTIONS(2312),
    [anon_sym_new] = ACTIONS(2312),
    [anon_sym_requires] = ACTIONS(2312),
    [sym_this] = ACTIONS(2312),
    [anon_sym_discard] = ACTIONS(2312),
    [anon_sym_precise] = ACTIONS(2312),
    [anon_sym_shared] = ACTIONS(2312),
    [anon_sym_groupshared] = ACTIONS(2312),
    [anon_sym_uniform] = ACTIONS(2312),
    [anon_sym_row_major] = ACTIONS(2312),
    [anon_sym_column_major] = ACTIONS(2312),
    [anon_sym_globallycoherent] = ACTIONS(2312),
    [anon_sym_centroid] = ACTIONS(2312),
    [anon_sym_noperspective] = ACTIONS(2312),
    [anon_sym_nointerpolation] = ACTIONS(2312),
    [anon_sym_sample] = ACTIONS(2312),
    [anon_sym_linear] = ACTIONS(2312),
    [anon_sym_snorm] = ACTIONS(2312),
    [anon_sym_unorm] = ACTIONS(2312),
    [anon_sym_point] = ACTIONS(2312),
    [anon_sym_line] = ACTIONS(2312),
    [anon_sym_triangleadj] = ACTIONS(2312),
    [anon_sym_lineadj] = ACTIONS(2312),
    [anon_sym_triangle] = ACTIONS(2312),
    [anon_sym_cbuffer] = ACTIONS(2312),
  },
  [656] = {
    [sym_identifier] = ACTIONS(2296),
    [aux_sym_preproc_include_token1] = ACTIONS(2296),
    [aux_sym_preproc_def_token1] = ACTIONS(2296),
    [aux_sym_preproc_if_token1] = ACTIONS(2296),
    [aux_sym_preproc_if_token2] = ACTIONS(2296),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2296),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2296),
    [sym_preproc_directive] = ACTIONS(2296),
    [anon_sym_LPAREN2] = ACTIONS(2298),
    [anon_sym_BANG] = ACTIONS(2298),
    [anon_sym_TILDE] = ACTIONS(2298),
    [anon_sym_DASH] = ACTIONS(2296),
    [anon_sym_PLUS] = ACTIONS(2296),
    [anon_sym_STAR] = ACTIONS(2298),
    [anon_sym_AMP_AMP] = ACTIONS(2298),
    [anon_sym_AMP] = ACTIONS(2296),
    [anon_sym_SEMI] = ACTIONS(2298),
    [anon_sym___extension__] = ACTIONS(2296),
    [anon_sym_typedef] = ACTIONS(2296),
    [anon_sym_in] = ACTIONS(2296),
    [anon_sym_out] = ACTIONS(2296),
    [anon_sym_inout] = ACTIONS(2296),
    [anon_sym_extern] = ACTIONS(2296),
    [anon_sym___attribute__] = ACTIONS(2296),
    [anon_sym_COLON_COLON] = ACTIONS(2298),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2298),
    [anon_sym___declspec] = ACTIONS(2296),
    [anon_sym___based] = ACTIONS(2296),
    [anon_sym___cdecl] = ACTIONS(2296),
    [anon_sym___clrcall] = ACTIONS(2296),
    [anon_sym___stdcall] = ACTIONS(2296),
    [anon_sym___fastcall] = ACTIONS(2296),
    [anon_sym___thiscall] = ACTIONS(2296),
    [anon_sym___vectorcall] = ACTIONS(2296),
    [anon_sym_LBRACE] = ACTIONS(2298),
    [anon_sym_signed] = ACTIONS(2296),
    [anon_sym_unsigned] = ACTIONS(2296),
    [anon_sym_long] = ACTIONS(2296),
    [anon_sym_short] = ACTIONS(2296),
    [anon_sym_LBRACK] = ACTIONS(2296),
    [anon_sym_static] = ACTIONS(2296),
    [anon_sym_register] = ACTIONS(2296),
    [anon_sym_inline] = ACTIONS(2296),
    [anon_sym___inline] = ACTIONS(2296),
    [anon_sym___inline__] = ACTIONS(2296),
    [anon_sym___forceinline] = ACTIONS(2296),
    [anon_sym_thread_local] = ACTIONS(2296),
    [anon_sym___thread] = ACTIONS(2296),
    [anon_sym_const] = ACTIONS(2296),
    [anon_sym_constexpr] = ACTIONS(2296),
    [anon_sym_volatile] = ACTIONS(2296),
    [anon_sym_restrict] = ACTIONS(2296),
    [anon_sym___restrict__] = ACTIONS(2296),
    [anon_sym__Atomic] = ACTIONS(2296),
    [anon_sym__Noreturn] = ACTIONS(2296),
    [anon_sym_noreturn] = ACTIONS(2296),
    [anon_sym_mutable] = ACTIONS(2296),
    [anon_sym_constinit] = ACTIONS(2296),
    [anon_sym_consteval] = ACTIONS(2296),
    [anon_sym_alignas] = ACTIONS(2296),
    [anon_sym__Alignas] = ACTIONS(2296),
    [sym_primitive_type] = ACTIONS(2296),
    [anon_sym_enum] = ACTIONS(2296),
    [anon_sym_class] = ACTIONS(2296),
    [anon_sym_struct] = ACTIONS(2296),
    [anon_sym_union] = ACTIONS(2296),
    [anon_sym_if] = ACTIONS(2296),
    [anon_sym_switch] = ACTIONS(2296),
    [anon_sym_case] = ACTIONS(2296),
    [anon_sym_default] = ACTIONS(2296),
    [anon_sym_while] = ACTIONS(2296),
    [anon_sym_do] = ACTIONS(2296),
    [anon_sym_for] = ACTIONS(2296),
    [anon_sym_return] = ACTIONS(2296),
    [anon_sym_break] = ACTIONS(2296),
    [anon_sym_continue] = ACTIONS(2296),
    [anon_sym_goto] = ACTIONS(2296),
    [anon_sym___try] = ACTIONS(2296),
    [anon_sym___leave] = ACTIONS(2296),
    [anon_sym_not] = ACTIONS(2296),
    [anon_sym_compl] = ACTIONS(2296),
    [anon_sym_DASH_DASH] = ACTIONS(2298),
    [anon_sym_PLUS_PLUS] = ACTIONS(2298),
    [anon_sym_sizeof] = ACTIONS(2296),
    [anon_sym___alignof__] = ACTIONS(2296),
    [anon_sym___alignof] = ACTIONS(2296),
    [anon_sym__alignof] = ACTIONS(2296),
    [anon_sym_alignof] = ACTIONS(2296),
    [anon_sym__Alignof] = ACTIONS(2296),
    [anon_sym_offsetof] = ACTIONS(2296),
    [anon_sym__Generic] = ACTIONS(2296),
    [anon_sym_asm] = ACTIONS(2296),
    [anon_sym___asm__] = ACTIONS(2296),
    [sym_number_literal] = ACTIONS(2298),
    [anon_sym_L_SQUOTE] = ACTIONS(2298),
    [anon_sym_u_SQUOTE] = ACTIONS(2298),
    [anon_sym_U_SQUOTE] = ACTIONS(2298),
    [anon_sym_u8_SQUOTE] = ACTIONS(2298),
    [anon_sym_SQUOTE] = ACTIONS(2298),
    [anon_sym_L_DQUOTE] = ACTIONS(2298),
    [anon_sym_u_DQUOTE] = ACTIONS(2298),
    [anon_sym_U_DQUOTE] = ACTIONS(2298),
    [anon_sym_u8_DQUOTE] = ACTIONS(2298),
    [anon_sym_DQUOTE] = ACTIONS(2298),
    [sym_true] = ACTIONS(2296),
    [sym_false] = ACTIONS(2296),
    [anon_sym_NULL] = ACTIONS(2296),
    [anon_sym_nullptr] = ACTIONS(2296),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2296),
    [anon_sym_decltype] = ACTIONS(2296),
    [sym_virtual] = ACTIONS(2296),
    [anon_sym_explicit] = ACTIONS(2296),
    [anon_sym_typename] = ACTIONS(2296),
    [anon_sym_template] = ACTIONS(2296),
    [anon_sym_operator] = ACTIONS(2296),
    [anon_sym_try] = ACTIONS(2296),
    [anon_sym_delete] = ACTIONS(2296),
    [anon_sym_throw] = ACTIONS(2296),
    [anon_sym_namespace] = ACTIONS(2296),
    [anon_sym_using] = ACTIONS(2296),
    [anon_sym_static_assert] = ACTIONS(2296),
    [anon_sym_concept] = ACTIONS(2296),
    [anon_sym_co_return] = ACTIONS(2296),
    [anon_sym_co_yield] = ACTIONS(2296),
    [anon_sym_R_DQUOTE] = ACTIONS(2298),
    [anon_sym_LR_DQUOTE] = ACTIONS(2298),
    [anon_sym_uR_DQUOTE] = ACTIONS(2298),
    [anon_sym_UR_DQUOTE] = ACTIONS(2298),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2298),
    [anon_sym_co_await] = ACTIONS(2296),
    [anon_sym_new] = ACTIONS(2296),
    [anon_sym_requires] = ACTIONS(2296),
    [sym_this] = ACTIONS(2296),
    [anon_sym_discard] = ACTIONS(2296),
    [anon_sym_precise] = ACTIONS(2296),
    [anon_sym_shared] = ACTIONS(2296),
    [anon_sym_groupshared] = ACTIONS(2296),
    [anon_sym_uniform] = ACTIONS(2296),
    [anon_sym_row_major] = ACTIONS(2296),
    [anon_sym_column_major] = ACTIONS(2296),
    [anon_sym_globallycoherent] = ACTIONS(2296),
    [anon_sym_centroid] = ACTIONS(2296),
    [anon_sym_noperspective] = ACTIONS(2296),
    [anon_sym_nointerpolation] = ACTIONS(2296),
    [anon_sym_sample] = ACTIONS(2296),
    [anon_sym_linear] = ACTIONS(2296),
    [anon_sym_snorm] = ACTIONS(2296),
    [anon_sym_unorm] = ACTIONS(2296),
    [anon_sym_point] = ACTIONS(2296),
    [anon_sym_line] = ACTIONS(2296),
    [anon_sym_triangleadj] = ACTIONS(2296),
    [anon_sym_lineadj] = ACTIONS(2296),
    [anon_sym_triangle] = ACTIONS(2296),
    [anon_sym_cbuffer] = ACTIONS(2296),
  },
  [657] = {
    [sym_identifier] = ACTIONS(2486),
    [aux_sym_preproc_include_token1] = ACTIONS(2486),
    [aux_sym_preproc_def_token1] = ACTIONS(2486),
    [aux_sym_preproc_if_token1] = ACTIONS(2486),
    [aux_sym_preproc_if_token2] = ACTIONS(2486),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2486),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2486),
    [sym_preproc_directive] = ACTIONS(2486),
    [anon_sym_LPAREN2] = ACTIONS(2488),
    [anon_sym_BANG] = ACTIONS(2488),
    [anon_sym_TILDE] = ACTIONS(2488),
    [anon_sym_DASH] = ACTIONS(2486),
    [anon_sym_PLUS] = ACTIONS(2486),
    [anon_sym_STAR] = ACTIONS(2488),
    [anon_sym_AMP_AMP] = ACTIONS(2488),
    [anon_sym_AMP] = ACTIONS(2486),
    [anon_sym_SEMI] = ACTIONS(2488),
    [anon_sym___extension__] = ACTIONS(2486),
    [anon_sym_typedef] = ACTIONS(2486),
    [anon_sym_in] = ACTIONS(2486),
    [anon_sym_out] = ACTIONS(2486),
    [anon_sym_inout] = ACTIONS(2486),
    [anon_sym_extern] = ACTIONS(2486),
    [anon_sym___attribute__] = ACTIONS(2486),
    [anon_sym_COLON_COLON] = ACTIONS(2488),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2488),
    [anon_sym___declspec] = ACTIONS(2486),
    [anon_sym___based] = ACTIONS(2486),
    [anon_sym___cdecl] = ACTIONS(2486),
    [anon_sym___clrcall] = ACTIONS(2486),
    [anon_sym___stdcall] = ACTIONS(2486),
    [anon_sym___fastcall] = ACTIONS(2486),
    [anon_sym___thiscall] = ACTIONS(2486),
    [anon_sym___vectorcall] = ACTIONS(2486),
    [anon_sym_LBRACE] = ACTIONS(2488),
    [anon_sym_signed] = ACTIONS(2486),
    [anon_sym_unsigned] = ACTIONS(2486),
    [anon_sym_long] = ACTIONS(2486),
    [anon_sym_short] = ACTIONS(2486),
    [anon_sym_LBRACK] = ACTIONS(2486),
    [anon_sym_static] = ACTIONS(2486),
    [anon_sym_register] = ACTIONS(2486),
    [anon_sym_inline] = ACTIONS(2486),
    [anon_sym___inline] = ACTIONS(2486),
    [anon_sym___inline__] = ACTIONS(2486),
    [anon_sym___forceinline] = ACTIONS(2486),
    [anon_sym_thread_local] = ACTIONS(2486),
    [anon_sym___thread] = ACTIONS(2486),
    [anon_sym_const] = ACTIONS(2486),
    [anon_sym_constexpr] = ACTIONS(2486),
    [anon_sym_volatile] = ACTIONS(2486),
    [anon_sym_restrict] = ACTIONS(2486),
    [anon_sym___restrict__] = ACTIONS(2486),
    [anon_sym__Atomic] = ACTIONS(2486),
    [anon_sym__Noreturn] = ACTIONS(2486),
    [anon_sym_noreturn] = ACTIONS(2486),
    [anon_sym_mutable] = ACTIONS(2486),
    [anon_sym_constinit] = ACTIONS(2486),
    [anon_sym_consteval] = ACTIONS(2486),
    [anon_sym_alignas] = ACTIONS(2486),
    [anon_sym__Alignas] = ACTIONS(2486),
    [sym_primitive_type] = ACTIONS(2486),
    [anon_sym_enum] = ACTIONS(2486),
    [anon_sym_class] = ACTIONS(2486),
    [anon_sym_struct] = ACTIONS(2486),
    [anon_sym_union] = ACTIONS(2486),
    [anon_sym_if] = ACTIONS(2486),
    [anon_sym_switch] = ACTIONS(2486),
    [anon_sym_case] = ACTIONS(2486),
    [anon_sym_default] = ACTIONS(2486),
    [anon_sym_while] = ACTIONS(2486),
    [anon_sym_do] = ACTIONS(2486),
    [anon_sym_for] = ACTIONS(2486),
    [anon_sym_return] = ACTIONS(2486),
    [anon_sym_break] = ACTIONS(2486),
    [anon_sym_continue] = ACTIONS(2486),
    [anon_sym_goto] = ACTIONS(2486),
    [anon_sym___try] = ACTIONS(2486),
    [anon_sym___leave] = ACTIONS(2486),
    [anon_sym_not] = ACTIONS(2486),
    [anon_sym_compl] = ACTIONS(2486),
    [anon_sym_DASH_DASH] = ACTIONS(2488),
    [anon_sym_PLUS_PLUS] = ACTIONS(2488),
    [anon_sym_sizeof] = ACTIONS(2486),
    [anon_sym___alignof__] = ACTIONS(2486),
    [anon_sym___alignof] = ACTIONS(2486),
    [anon_sym__alignof] = ACTIONS(2486),
    [anon_sym_alignof] = ACTIONS(2486),
    [anon_sym__Alignof] = ACTIONS(2486),
    [anon_sym_offsetof] = ACTIONS(2486),
    [anon_sym__Generic] = ACTIONS(2486),
    [anon_sym_asm] = ACTIONS(2486),
    [anon_sym___asm__] = ACTIONS(2486),
    [sym_number_literal] = ACTIONS(2488),
    [anon_sym_L_SQUOTE] = ACTIONS(2488),
    [anon_sym_u_SQUOTE] = ACTIONS(2488),
    [anon_sym_U_SQUOTE] = ACTIONS(2488),
    [anon_sym_u8_SQUOTE] = ACTIONS(2488),
    [anon_sym_SQUOTE] = ACTIONS(2488),
    [anon_sym_L_DQUOTE] = ACTIONS(2488),
    [anon_sym_u_DQUOTE] = ACTIONS(2488),
    [anon_sym_U_DQUOTE] = ACTIONS(2488),
    [anon_sym_u8_DQUOTE] = ACTIONS(2488),
    [anon_sym_DQUOTE] = ACTIONS(2488),
    [sym_true] = ACTIONS(2486),
    [sym_false] = ACTIONS(2486),
    [anon_sym_NULL] = ACTIONS(2486),
    [anon_sym_nullptr] = ACTIONS(2486),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2486),
    [anon_sym_decltype] = ACTIONS(2486),
    [sym_virtual] = ACTIONS(2486),
    [anon_sym_explicit] = ACTIONS(2486),
    [anon_sym_typename] = ACTIONS(2486),
    [anon_sym_template] = ACTIONS(2486),
    [anon_sym_operator] = ACTIONS(2486),
    [anon_sym_try] = ACTIONS(2486),
    [anon_sym_delete] = ACTIONS(2486),
    [anon_sym_throw] = ACTIONS(2486),
    [anon_sym_namespace] = ACTIONS(2486),
    [anon_sym_using] = ACTIONS(2486),
    [anon_sym_static_assert] = ACTIONS(2486),
    [anon_sym_concept] = ACTIONS(2486),
    [anon_sym_co_return] = ACTIONS(2486),
    [anon_sym_co_yield] = ACTIONS(2486),
    [anon_sym_R_DQUOTE] = ACTIONS(2488),
    [anon_sym_LR_DQUOTE] = ACTIONS(2488),
    [anon_sym_uR_DQUOTE] = ACTIONS(2488),
    [anon_sym_UR_DQUOTE] = ACTIONS(2488),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2488),
    [anon_sym_co_await] = ACTIONS(2486),
    [anon_sym_new] = ACTIONS(2486),
    [anon_sym_requires] = ACTIONS(2486),
    [sym_this] = ACTIONS(2486),
    [anon_sym_discard] = ACTIONS(2486),
    [anon_sym_precise] = ACTIONS(2486),
    [anon_sym_shared] = ACTIONS(2486),
    [anon_sym_groupshared] = ACTIONS(2486),
    [anon_sym_uniform] = ACTIONS(2486),
    [anon_sym_row_major] = ACTIONS(2486),
    [anon_sym_column_major] = ACTIONS(2486),
    [anon_sym_globallycoherent] = ACTIONS(2486),
    [anon_sym_centroid] = ACTIONS(2486),
    [anon_sym_noperspective] = ACTIONS(2486),
    [anon_sym_nointerpolation] = ACTIONS(2486),
    [anon_sym_sample] = ACTIONS(2486),
    [anon_sym_linear] = ACTIONS(2486),
    [anon_sym_snorm] = ACTIONS(2486),
    [anon_sym_unorm] = ACTIONS(2486),
    [anon_sym_point] = ACTIONS(2486),
    [anon_sym_line] = ACTIONS(2486),
    [anon_sym_triangleadj] = ACTIONS(2486),
    [anon_sym_lineadj] = ACTIONS(2486),
    [anon_sym_triangle] = ACTIONS(2486),
    [anon_sym_cbuffer] = ACTIONS(2486),
  },
  [658] = {
    [sym_identifier] = ACTIONS(2565),
    [aux_sym_preproc_include_token1] = ACTIONS(2565),
    [aux_sym_preproc_def_token1] = ACTIONS(2565),
    [aux_sym_preproc_if_token1] = ACTIONS(2565),
    [aux_sym_preproc_if_token2] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2565),
    [sym_preproc_directive] = ACTIONS(2565),
    [anon_sym_LPAREN2] = ACTIONS(2567),
    [anon_sym_BANG] = ACTIONS(2567),
    [anon_sym_TILDE] = ACTIONS(2567),
    [anon_sym_DASH] = ACTIONS(2565),
    [anon_sym_PLUS] = ACTIONS(2565),
    [anon_sym_STAR] = ACTIONS(2567),
    [anon_sym_AMP_AMP] = ACTIONS(2567),
    [anon_sym_AMP] = ACTIONS(2565),
    [anon_sym_SEMI] = ACTIONS(2567),
    [anon_sym___extension__] = ACTIONS(2565),
    [anon_sym_typedef] = ACTIONS(2565),
    [anon_sym_in] = ACTIONS(2565),
    [anon_sym_out] = ACTIONS(2565),
    [anon_sym_inout] = ACTIONS(2565),
    [anon_sym_extern] = ACTIONS(2565),
    [anon_sym___attribute__] = ACTIONS(2565),
    [anon_sym_COLON_COLON] = ACTIONS(2567),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2567),
    [anon_sym___declspec] = ACTIONS(2565),
    [anon_sym___based] = ACTIONS(2565),
    [anon_sym___cdecl] = ACTIONS(2565),
    [anon_sym___clrcall] = ACTIONS(2565),
    [anon_sym___stdcall] = ACTIONS(2565),
    [anon_sym___fastcall] = ACTIONS(2565),
    [anon_sym___thiscall] = ACTIONS(2565),
    [anon_sym___vectorcall] = ACTIONS(2565),
    [anon_sym_LBRACE] = ACTIONS(2567),
    [anon_sym_signed] = ACTIONS(2565),
    [anon_sym_unsigned] = ACTIONS(2565),
    [anon_sym_long] = ACTIONS(2565),
    [anon_sym_short] = ACTIONS(2565),
    [anon_sym_LBRACK] = ACTIONS(2565),
    [anon_sym_static] = ACTIONS(2565),
    [anon_sym_register] = ACTIONS(2565),
    [anon_sym_inline] = ACTIONS(2565),
    [anon_sym___inline] = ACTIONS(2565),
    [anon_sym___inline__] = ACTIONS(2565),
    [anon_sym___forceinline] = ACTIONS(2565),
    [anon_sym_thread_local] = ACTIONS(2565),
    [anon_sym___thread] = ACTIONS(2565),
    [anon_sym_const] = ACTIONS(2565),
    [anon_sym_constexpr] = ACTIONS(2565),
    [anon_sym_volatile] = ACTIONS(2565),
    [anon_sym_restrict] = ACTIONS(2565),
    [anon_sym___restrict__] = ACTIONS(2565),
    [anon_sym__Atomic] = ACTIONS(2565),
    [anon_sym__Noreturn] = ACTIONS(2565),
    [anon_sym_noreturn] = ACTIONS(2565),
    [anon_sym_mutable] = ACTIONS(2565),
    [anon_sym_constinit] = ACTIONS(2565),
    [anon_sym_consteval] = ACTIONS(2565),
    [anon_sym_alignas] = ACTIONS(2565),
    [anon_sym__Alignas] = ACTIONS(2565),
    [sym_primitive_type] = ACTIONS(2565),
    [anon_sym_enum] = ACTIONS(2565),
    [anon_sym_class] = ACTIONS(2565),
    [anon_sym_struct] = ACTIONS(2565),
    [anon_sym_union] = ACTIONS(2565),
    [anon_sym_if] = ACTIONS(2565),
    [anon_sym_switch] = ACTIONS(2565),
    [anon_sym_case] = ACTIONS(2565),
    [anon_sym_default] = ACTIONS(2565),
    [anon_sym_while] = ACTIONS(2565),
    [anon_sym_do] = ACTIONS(2565),
    [anon_sym_for] = ACTIONS(2565),
    [anon_sym_return] = ACTIONS(2565),
    [anon_sym_break] = ACTIONS(2565),
    [anon_sym_continue] = ACTIONS(2565),
    [anon_sym_goto] = ACTIONS(2565),
    [anon_sym___try] = ACTIONS(2565),
    [anon_sym___leave] = ACTIONS(2565),
    [anon_sym_not] = ACTIONS(2565),
    [anon_sym_compl] = ACTIONS(2565),
    [anon_sym_DASH_DASH] = ACTIONS(2567),
    [anon_sym_PLUS_PLUS] = ACTIONS(2567),
    [anon_sym_sizeof] = ACTIONS(2565),
    [anon_sym___alignof__] = ACTIONS(2565),
    [anon_sym___alignof] = ACTIONS(2565),
    [anon_sym__alignof] = ACTIONS(2565),
    [anon_sym_alignof] = ACTIONS(2565),
    [anon_sym__Alignof] = ACTIONS(2565),
    [anon_sym_offsetof] = ACTIONS(2565),
    [anon_sym__Generic] = ACTIONS(2565),
    [anon_sym_asm] = ACTIONS(2565),
    [anon_sym___asm__] = ACTIONS(2565),
    [sym_number_literal] = ACTIONS(2567),
    [anon_sym_L_SQUOTE] = ACTIONS(2567),
    [anon_sym_u_SQUOTE] = ACTIONS(2567),
    [anon_sym_U_SQUOTE] = ACTIONS(2567),
    [anon_sym_u8_SQUOTE] = ACTIONS(2567),
    [anon_sym_SQUOTE] = ACTIONS(2567),
    [anon_sym_L_DQUOTE] = ACTIONS(2567),
    [anon_sym_u_DQUOTE] = ACTIONS(2567),
    [anon_sym_U_DQUOTE] = ACTIONS(2567),
    [anon_sym_u8_DQUOTE] = ACTIONS(2567),
    [anon_sym_DQUOTE] = ACTIONS(2567),
    [sym_true] = ACTIONS(2565),
    [sym_false] = ACTIONS(2565),
    [anon_sym_NULL] = ACTIONS(2565),
    [anon_sym_nullptr] = ACTIONS(2565),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2565),
    [anon_sym_decltype] = ACTIONS(2565),
    [sym_virtual] = ACTIONS(2565),
    [anon_sym_explicit] = ACTIONS(2565),
    [anon_sym_typename] = ACTIONS(2565),
    [anon_sym_template] = ACTIONS(2565),
    [anon_sym_operator] = ACTIONS(2565),
    [anon_sym_try] = ACTIONS(2565),
    [anon_sym_delete] = ACTIONS(2565),
    [anon_sym_throw] = ACTIONS(2565),
    [anon_sym_namespace] = ACTIONS(2565),
    [anon_sym_using] = ACTIONS(2565),
    [anon_sym_static_assert] = ACTIONS(2565),
    [anon_sym_concept] = ACTIONS(2565),
    [anon_sym_co_return] = ACTIONS(2565),
    [anon_sym_co_yield] = ACTIONS(2565),
    [anon_sym_R_DQUOTE] = ACTIONS(2567),
    [anon_sym_LR_DQUOTE] = ACTIONS(2567),
    [anon_sym_uR_DQUOTE] = ACTIONS(2567),
    [anon_sym_UR_DQUOTE] = ACTIONS(2567),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2567),
    [anon_sym_co_await] = ACTIONS(2565),
    [anon_sym_new] = ACTIONS(2565),
    [anon_sym_requires] = ACTIONS(2565),
    [sym_this] = ACTIONS(2565),
    [anon_sym_discard] = ACTIONS(2565),
    [anon_sym_precise] = ACTIONS(2565),
    [anon_sym_shared] = ACTIONS(2565),
    [anon_sym_groupshared] = ACTIONS(2565),
    [anon_sym_uniform] = ACTIONS(2565),
    [anon_sym_row_major] = ACTIONS(2565),
    [anon_sym_column_major] = ACTIONS(2565),
    [anon_sym_globallycoherent] = ACTIONS(2565),
    [anon_sym_centroid] = ACTIONS(2565),
    [anon_sym_noperspective] = ACTIONS(2565),
    [anon_sym_nointerpolation] = ACTIONS(2565),
    [anon_sym_sample] = ACTIONS(2565),
    [anon_sym_linear] = ACTIONS(2565),
    [anon_sym_snorm] = ACTIONS(2565),
    [anon_sym_unorm] = ACTIONS(2565),
    [anon_sym_point] = ACTIONS(2565),
    [anon_sym_line] = ACTIONS(2565),
    [anon_sym_triangleadj] = ACTIONS(2565),
    [anon_sym_lineadj] = ACTIONS(2565),
    [anon_sym_triangle] = ACTIONS(2565),
    [anon_sym_cbuffer] = ACTIONS(2565),
  },
  [659] = {
    [sym_identifier] = ACTIONS(2400),
    [aux_sym_preproc_include_token1] = ACTIONS(2400),
    [aux_sym_preproc_def_token1] = ACTIONS(2400),
    [aux_sym_preproc_if_token1] = ACTIONS(2400),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2400),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2400),
    [sym_preproc_directive] = ACTIONS(2400),
    [anon_sym_LPAREN2] = ACTIONS(2402),
    [anon_sym_BANG] = ACTIONS(2402),
    [anon_sym_TILDE] = ACTIONS(2402),
    [anon_sym_DASH] = ACTIONS(2400),
    [anon_sym_PLUS] = ACTIONS(2400),
    [anon_sym_STAR] = ACTIONS(2402),
    [anon_sym_AMP_AMP] = ACTIONS(2402),
    [anon_sym_AMP] = ACTIONS(2400),
    [anon_sym_SEMI] = ACTIONS(2402),
    [anon_sym___extension__] = ACTIONS(2400),
    [anon_sym_typedef] = ACTIONS(2400),
    [anon_sym_in] = ACTIONS(2400),
    [anon_sym_out] = ACTIONS(2400),
    [anon_sym_inout] = ACTIONS(2400),
    [anon_sym_extern] = ACTIONS(2400),
    [anon_sym___attribute__] = ACTIONS(2400),
    [anon_sym_COLON_COLON] = ACTIONS(2402),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2402),
    [anon_sym___declspec] = ACTIONS(2400),
    [anon_sym___based] = ACTIONS(2400),
    [anon_sym___cdecl] = ACTIONS(2400),
    [anon_sym___clrcall] = ACTIONS(2400),
    [anon_sym___stdcall] = ACTIONS(2400),
    [anon_sym___fastcall] = ACTIONS(2400),
    [anon_sym___thiscall] = ACTIONS(2400),
    [anon_sym___vectorcall] = ACTIONS(2400),
    [anon_sym_LBRACE] = ACTIONS(2402),
    [anon_sym_RBRACE] = ACTIONS(2402),
    [anon_sym_signed] = ACTIONS(2400),
    [anon_sym_unsigned] = ACTIONS(2400),
    [anon_sym_long] = ACTIONS(2400),
    [anon_sym_short] = ACTIONS(2400),
    [anon_sym_LBRACK] = ACTIONS(2400),
    [anon_sym_static] = ACTIONS(2400),
    [anon_sym_register] = ACTIONS(2400),
    [anon_sym_inline] = ACTIONS(2400),
    [anon_sym___inline] = ACTIONS(2400),
    [anon_sym___inline__] = ACTIONS(2400),
    [anon_sym___forceinline] = ACTIONS(2400),
    [anon_sym_thread_local] = ACTIONS(2400),
    [anon_sym___thread] = ACTIONS(2400),
    [anon_sym_const] = ACTIONS(2400),
    [anon_sym_constexpr] = ACTIONS(2400),
    [anon_sym_volatile] = ACTIONS(2400),
    [anon_sym_restrict] = ACTIONS(2400),
    [anon_sym___restrict__] = ACTIONS(2400),
    [anon_sym__Atomic] = ACTIONS(2400),
    [anon_sym__Noreturn] = ACTIONS(2400),
    [anon_sym_noreturn] = ACTIONS(2400),
    [anon_sym_mutable] = ACTIONS(2400),
    [anon_sym_constinit] = ACTIONS(2400),
    [anon_sym_consteval] = ACTIONS(2400),
    [anon_sym_alignas] = ACTIONS(2400),
    [anon_sym__Alignas] = ACTIONS(2400),
    [sym_primitive_type] = ACTIONS(2400),
    [anon_sym_enum] = ACTIONS(2400),
    [anon_sym_class] = ACTIONS(2400),
    [anon_sym_struct] = ACTIONS(2400),
    [anon_sym_union] = ACTIONS(2400),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_switch] = ACTIONS(2400),
    [anon_sym_case] = ACTIONS(2400),
    [anon_sym_default] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(2400),
    [anon_sym_do] = ACTIONS(2400),
    [anon_sym_for] = ACTIONS(2400),
    [anon_sym_return] = ACTIONS(2400),
    [anon_sym_break] = ACTIONS(2400),
    [anon_sym_continue] = ACTIONS(2400),
    [anon_sym_goto] = ACTIONS(2400),
    [anon_sym___try] = ACTIONS(2400),
    [anon_sym___leave] = ACTIONS(2400),
    [anon_sym_not] = ACTIONS(2400),
    [anon_sym_compl] = ACTIONS(2400),
    [anon_sym_DASH_DASH] = ACTIONS(2402),
    [anon_sym_PLUS_PLUS] = ACTIONS(2402),
    [anon_sym_sizeof] = ACTIONS(2400),
    [anon_sym___alignof__] = ACTIONS(2400),
    [anon_sym___alignof] = ACTIONS(2400),
    [anon_sym__alignof] = ACTIONS(2400),
    [anon_sym_alignof] = ACTIONS(2400),
    [anon_sym__Alignof] = ACTIONS(2400),
    [anon_sym_offsetof] = ACTIONS(2400),
    [anon_sym__Generic] = ACTIONS(2400),
    [anon_sym_asm] = ACTIONS(2400),
    [anon_sym___asm__] = ACTIONS(2400),
    [sym_number_literal] = ACTIONS(2402),
    [anon_sym_L_SQUOTE] = ACTIONS(2402),
    [anon_sym_u_SQUOTE] = ACTIONS(2402),
    [anon_sym_U_SQUOTE] = ACTIONS(2402),
    [anon_sym_u8_SQUOTE] = ACTIONS(2402),
    [anon_sym_SQUOTE] = ACTIONS(2402),
    [anon_sym_L_DQUOTE] = ACTIONS(2402),
    [anon_sym_u_DQUOTE] = ACTIONS(2402),
    [anon_sym_U_DQUOTE] = ACTIONS(2402),
    [anon_sym_u8_DQUOTE] = ACTIONS(2402),
    [anon_sym_DQUOTE] = ACTIONS(2402),
    [sym_true] = ACTIONS(2400),
    [sym_false] = ACTIONS(2400),
    [anon_sym_NULL] = ACTIONS(2400),
    [anon_sym_nullptr] = ACTIONS(2400),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2400),
    [anon_sym_decltype] = ACTIONS(2400),
    [sym_virtual] = ACTIONS(2400),
    [anon_sym_explicit] = ACTIONS(2400),
    [anon_sym_typename] = ACTIONS(2400),
    [anon_sym_template] = ACTIONS(2400),
    [anon_sym_operator] = ACTIONS(2400),
    [anon_sym_try] = ACTIONS(2400),
    [anon_sym_delete] = ACTIONS(2400),
    [anon_sym_throw] = ACTIONS(2400),
    [anon_sym_namespace] = ACTIONS(2400),
    [anon_sym_using] = ACTIONS(2400),
    [anon_sym_static_assert] = ACTIONS(2400),
    [anon_sym_concept] = ACTIONS(2400),
    [anon_sym_co_return] = ACTIONS(2400),
    [anon_sym_co_yield] = ACTIONS(2400),
    [anon_sym_R_DQUOTE] = ACTIONS(2402),
    [anon_sym_LR_DQUOTE] = ACTIONS(2402),
    [anon_sym_uR_DQUOTE] = ACTIONS(2402),
    [anon_sym_UR_DQUOTE] = ACTIONS(2402),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2402),
    [anon_sym_co_await] = ACTIONS(2400),
    [anon_sym_new] = ACTIONS(2400),
    [anon_sym_requires] = ACTIONS(2400),
    [sym_this] = ACTIONS(2400),
    [anon_sym_discard] = ACTIONS(2400),
    [anon_sym_precise] = ACTIONS(2400),
    [anon_sym_shared] = ACTIONS(2400),
    [anon_sym_groupshared] = ACTIONS(2400),
    [anon_sym_uniform] = ACTIONS(2400),
    [anon_sym_row_major] = ACTIONS(2400),
    [anon_sym_column_major] = ACTIONS(2400),
    [anon_sym_globallycoherent] = ACTIONS(2400),
    [anon_sym_centroid] = ACTIONS(2400),
    [anon_sym_noperspective] = ACTIONS(2400),
    [anon_sym_nointerpolation] = ACTIONS(2400),
    [anon_sym_sample] = ACTIONS(2400),
    [anon_sym_linear] = ACTIONS(2400),
    [anon_sym_snorm] = ACTIONS(2400),
    [anon_sym_unorm] = ACTIONS(2400),
    [anon_sym_point] = ACTIONS(2400),
    [anon_sym_line] = ACTIONS(2400),
    [anon_sym_triangleadj] = ACTIONS(2400),
    [anon_sym_lineadj] = ACTIONS(2400),
    [anon_sym_triangle] = ACTIONS(2400),
    [anon_sym_cbuffer] = ACTIONS(2400),
  },
  [660] = {
    [sym_identifier] = ACTIONS(2557),
    [aux_sym_preproc_include_token1] = ACTIONS(2557),
    [aux_sym_preproc_def_token1] = ACTIONS(2557),
    [aux_sym_preproc_if_token1] = ACTIONS(2557),
    [aux_sym_preproc_if_token2] = ACTIONS(2557),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2557),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2557),
    [sym_preproc_directive] = ACTIONS(2557),
    [anon_sym_LPAREN2] = ACTIONS(2559),
    [anon_sym_BANG] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(2559),
    [anon_sym_DASH] = ACTIONS(2557),
    [anon_sym_PLUS] = ACTIONS(2557),
    [anon_sym_STAR] = ACTIONS(2559),
    [anon_sym_AMP_AMP] = ACTIONS(2559),
    [anon_sym_AMP] = ACTIONS(2557),
    [anon_sym_SEMI] = ACTIONS(2559),
    [anon_sym___extension__] = ACTIONS(2557),
    [anon_sym_typedef] = ACTIONS(2557),
    [anon_sym_in] = ACTIONS(2557),
    [anon_sym_out] = ACTIONS(2557),
    [anon_sym_inout] = ACTIONS(2557),
    [anon_sym_extern] = ACTIONS(2557),
    [anon_sym___attribute__] = ACTIONS(2557),
    [anon_sym_COLON_COLON] = ACTIONS(2559),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2559),
    [anon_sym___declspec] = ACTIONS(2557),
    [anon_sym___based] = ACTIONS(2557),
    [anon_sym___cdecl] = ACTIONS(2557),
    [anon_sym___clrcall] = ACTIONS(2557),
    [anon_sym___stdcall] = ACTIONS(2557),
    [anon_sym___fastcall] = ACTIONS(2557),
    [anon_sym___thiscall] = ACTIONS(2557),
    [anon_sym___vectorcall] = ACTIONS(2557),
    [anon_sym_LBRACE] = ACTIONS(2559),
    [anon_sym_signed] = ACTIONS(2557),
    [anon_sym_unsigned] = ACTIONS(2557),
    [anon_sym_long] = ACTIONS(2557),
    [anon_sym_short] = ACTIONS(2557),
    [anon_sym_LBRACK] = ACTIONS(2557),
    [anon_sym_static] = ACTIONS(2557),
    [anon_sym_register] = ACTIONS(2557),
    [anon_sym_inline] = ACTIONS(2557),
    [anon_sym___inline] = ACTIONS(2557),
    [anon_sym___inline__] = ACTIONS(2557),
    [anon_sym___forceinline] = ACTIONS(2557),
    [anon_sym_thread_local] = ACTIONS(2557),
    [anon_sym___thread] = ACTIONS(2557),
    [anon_sym_const] = ACTIONS(2557),
    [anon_sym_constexpr] = ACTIONS(2557),
    [anon_sym_volatile] = ACTIONS(2557),
    [anon_sym_restrict] = ACTIONS(2557),
    [anon_sym___restrict__] = ACTIONS(2557),
    [anon_sym__Atomic] = ACTIONS(2557),
    [anon_sym__Noreturn] = ACTIONS(2557),
    [anon_sym_noreturn] = ACTIONS(2557),
    [anon_sym_mutable] = ACTIONS(2557),
    [anon_sym_constinit] = ACTIONS(2557),
    [anon_sym_consteval] = ACTIONS(2557),
    [anon_sym_alignas] = ACTIONS(2557),
    [anon_sym__Alignas] = ACTIONS(2557),
    [sym_primitive_type] = ACTIONS(2557),
    [anon_sym_enum] = ACTIONS(2557),
    [anon_sym_class] = ACTIONS(2557),
    [anon_sym_struct] = ACTIONS(2557),
    [anon_sym_union] = ACTIONS(2557),
    [anon_sym_if] = ACTIONS(2557),
    [anon_sym_switch] = ACTIONS(2557),
    [anon_sym_case] = ACTIONS(2557),
    [anon_sym_default] = ACTIONS(2557),
    [anon_sym_while] = ACTIONS(2557),
    [anon_sym_do] = ACTIONS(2557),
    [anon_sym_for] = ACTIONS(2557),
    [anon_sym_return] = ACTIONS(2557),
    [anon_sym_break] = ACTIONS(2557),
    [anon_sym_continue] = ACTIONS(2557),
    [anon_sym_goto] = ACTIONS(2557),
    [anon_sym___try] = ACTIONS(2557),
    [anon_sym___leave] = ACTIONS(2557),
    [anon_sym_not] = ACTIONS(2557),
    [anon_sym_compl] = ACTIONS(2557),
    [anon_sym_DASH_DASH] = ACTIONS(2559),
    [anon_sym_PLUS_PLUS] = ACTIONS(2559),
    [anon_sym_sizeof] = ACTIONS(2557),
    [anon_sym___alignof__] = ACTIONS(2557),
    [anon_sym___alignof] = ACTIONS(2557),
    [anon_sym__alignof] = ACTIONS(2557),
    [anon_sym_alignof] = ACTIONS(2557),
    [anon_sym__Alignof] = ACTIONS(2557),
    [anon_sym_offsetof] = ACTIONS(2557),
    [anon_sym__Generic] = ACTIONS(2557),
    [anon_sym_asm] = ACTIONS(2557),
    [anon_sym___asm__] = ACTIONS(2557),
    [sym_number_literal] = ACTIONS(2559),
    [anon_sym_L_SQUOTE] = ACTIONS(2559),
    [anon_sym_u_SQUOTE] = ACTIONS(2559),
    [anon_sym_U_SQUOTE] = ACTIONS(2559),
    [anon_sym_u8_SQUOTE] = ACTIONS(2559),
    [anon_sym_SQUOTE] = ACTIONS(2559),
    [anon_sym_L_DQUOTE] = ACTIONS(2559),
    [anon_sym_u_DQUOTE] = ACTIONS(2559),
    [anon_sym_U_DQUOTE] = ACTIONS(2559),
    [anon_sym_u8_DQUOTE] = ACTIONS(2559),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_true] = ACTIONS(2557),
    [sym_false] = ACTIONS(2557),
    [anon_sym_NULL] = ACTIONS(2557),
    [anon_sym_nullptr] = ACTIONS(2557),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2557),
    [anon_sym_decltype] = ACTIONS(2557),
    [sym_virtual] = ACTIONS(2557),
    [anon_sym_explicit] = ACTIONS(2557),
    [anon_sym_typename] = ACTIONS(2557),
    [anon_sym_template] = ACTIONS(2557),
    [anon_sym_operator] = ACTIONS(2557),
    [anon_sym_try] = ACTIONS(2557),
    [anon_sym_delete] = ACTIONS(2557),
    [anon_sym_throw] = ACTIONS(2557),
    [anon_sym_namespace] = ACTIONS(2557),
    [anon_sym_using] = ACTIONS(2557),
    [anon_sym_static_assert] = ACTIONS(2557),
    [anon_sym_concept] = ACTIONS(2557),
    [anon_sym_co_return] = ACTIONS(2557),
    [anon_sym_co_yield] = ACTIONS(2557),
    [anon_sym_R_DQUOTE] = ACTIONS(2559),
    [anon_sym_LR_DQUOTE] = ACTIONS(2559),
    [anon_sym_uR_DQUOTE] = ACTIONS(2559),
    [anon_sym_UR_DQUOTE] = ACTIONS(2559),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2559),
    [anon_sym_co_await] = ACTIONS(2557),
    [anon_sym_new] = ACTIONS(2557),
    [anon_sym_requires] = ACTIONS(2557),
    [sym_this] = ACTIONS(2557),
    [anon_sym_discard] = ACTIONS(2557),
    [anon_sym_precise] = ACTIONS(2557),
    [anon_sym_shared] = ACTIONS(2557),
    [anon_sym_groupshared] = ACTIONS(2557),
    [anon_sym_uniform] = ACTIONS(2557),
    [anon_sym_row_major] = ACTIONS(2557),
    [anon_sym_column_major] = ACTIONS(2557),
    [anon_sym_globallycoherent] = ACTIONS(2557),
    [anon_sym_centroid] = ACTIONS(2557),
    [anon_sym_noperspective] = ACTIONS(2557),
    [anon_sym_nointerpolation] = ACTIONS(2557),
    [anon_sym_sample] = ACTIONS(2557),
    [anon_sym_linear] = ACTIONS(2557),
    [anon_sym_snorm] = ACTIONS(2557),
    [anon_sym_unorm] = ACTIONS(2557),
    [anon_sym_point] = ACTIONS(2557),
    [anon_sym_line] = ACTIONS(2557),
    [anon_sym_triangleadj] = ACTIONS(2557),
    [anon_sym_lineadj] = ACTIONS(2557),
    [anon_sym_triangle] = ACTIONS(2557),
    [anon_sym_cbuffer] = ACTIONS(2557),
  },
  [661] = {
    [sym_identifier] = ACTIONS(2569),
    [aux_sym_preproc_include_token1] = ACTIONS(2569),
    [aux_sym_preproc_def_token1] = ACTIONS(2569),
    [aux_sym_preproc_if_token1] = ACTIONS(2569),
    [aux_sym_preproc_if_token2] = ACTIONS(2569),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2569),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2569),
    [sym_preproc_directive] = ACTIONS(2569),
    [anon_sym_LPAREN2] = ACTIONS(2571),
    [anon_sym_BANG] = ACTIONS(2571),
    [anon_sym_TILDE] = ACTIONS(2571),
    [anon_sym_DASH] = ACTIONS(2569),
    [anon_sym_PLUS] = ACTIONS(2569),
    [anon_sym_STAR] = ACTIONS(2571),
    [anon_sym_AMP_AMP] = ACTIONS(2571),
    [anon_sym_AMP] = ACTIONS(2569),
    [anon_sym_SEMI] = ACTIONS(2571),
    [anon_sym___extension__] = ACTIONS(2569),
    [anon_sym_typedef] = ACTIONS(2569),
    [anon_sym_in] = ACTIONS(2569),
    [anon_sym_out] = ACTIONS(2569),
    [anon_sym_inout] = ACTIONS(2569),
    [anon_sym_extern] = ACTIONS(2569),
    [anon_sym___attribute__] = ACTIONS(2569),
    [anon_sym_COLON_COLON] = ACTIONS(2571),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2571),
    [anon_sym___declspec] = ACTIONS(2569),
    [anon_sym___based] = ACTIONS(2569),
    [anon_sym___cdecl] = ACTIONS(2569),
    [anon_sym___clrcall] = ACTIONS(2569),
    [anon_sym___stdcall] = ACTIONS(2569),
    [anon_sym___fastcall] = ACTIONS(2569),
    [anon_sym___thiscall] = ACTIONS(2569),
    [anon_sym___vectorcall] = ACTIONS(2569),
    [anon_sym_LBRACE] = ACTIONS(2571),
    [anon_sym_signed] = ACTIONS(2569),
    [anon_sym_unsigned] = ACTIONS(2569),
    [anon_sym_long] = ACTIONS(2569),
    [anon_sym_short] = ACTIONS(2569),
    [anon_sym_LBRACK] = ACTIONS(2569),
    [anon_sym_static] = ACTIONS(2569),
    [anon_sym_register] = ACTIONS(2569),
    [anon_sym_inline] = ACTIONS(2569),
    [anon_sym___inline] = ACTIONS(2569),
    [anon_sym___inline__] = ACTIONS(2569),
    [anon_sym___forceinline] = ACTIONS(2569),
    [anon_sym_thread_local] = ACTIONS(2569),
    [anon_sym___thread] = ACTIONS(2569),
    [anon_sym_const] = ACTIONS(2569),
    [anon_sym_constexpr] = ACTIONS(2569),
    [anon_sym_volatile] = ACTIONS(2569),
    [anon_sym_restrict] = ACTIONS(2569),
    [anon_sym___restrict__] = ACTIONS(2569),
    [anon_sym__Atomic] = ACTIONS(2569),
    [anon_sym__Noreturn] = ACTIONS(2569),
    [anon_sym_noreturn] = ACTIONS(2569),
    [anon_sym_mutable] = ACTIONS(2569),
    [anon_sym_constinit] = ACTIONS(2569),
    [anon_sym_consteval] = ACTIONS(2569),
    [anon_sym_alignas] = ACTIONS(2569),
    [anon_sym__Alignas] = ACTIONS(2569),
    [sym_primitive_type] = ACTIONS(2569),
    [anon_sym_enum] = ACTIONS(2569),
    [anon_sym_class] = ACTIONS(2569),
    [anon_sym_struct] = ACTIONS(2569),
    [anon_sym_union] = ACTIONS(2569),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_switch] = ACTIONS(2569),
    [anon_sym_case] = ACTIONS(2569),
    [anon_sym_default] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2569),
    [anon_sym_do] = ACTIONS(2569),
    [anon_sym_for] = ACTIONS(2569),
    [anon_sym_return] = ACTIONS(2569),
    [anon_sym_break] = ACTIONS(2569),
    [anon_sym_continue] = ACTIONS(2569),
    [anon_sym_goto] = ACTIONS(2569),
    [anon_sym___try] = ACTIONS(2569),
    [anon_sym___leave] = ACTIONS(2569),
    [anon_sym_not] = ACTIONS(2569),
    [anon_sym_compl] = ACTIONS(2569),
    [anon_sym_DASH_DASH] = ACTIONS(2571),
    [anon_sym_PLUS_PLUS] = ACTIONS(2571),
    [anon_sym_sizeof] = ACTIONS(2569),
    [anon_sym___alignof__] = ACTIONS(2569),
    [anon_sym___alignof] = ACTIONS(2569),
    [anon_sym__alignof] = ACTIONS(2569),
    [anon_sym_alignof] = ACTIONS(2569),
    [anon_sym__Alignof] = ACTIONS(2569),
    [anon_sym_offsetof] = ACTIONS(2569),
    [anon_sym__Generic] = ACTIONS(2569),
    [anon_sym_asm] = ACTIONS(2569),
    [anon_sym___asm__] = ACTIONS(2569),
    [sym_number_literal] = ACTIONS(2571),
    [anon_sym_L_SQUOTE] = ACTIONS(2571),
    [anon_sym_u_SQUOTE] = ACTIONS(2571),
    [anon_sym_U_SQUOTE] = ACTIONS(2571),
    [anon_sym_u8_SQUOTE] = ACTIONS(2571),
    [anon_sym_SQUOTE] = ACTIONS(2571),
    [anon_sym_L_DQUOTE] = ACTIONS(2571),
    [anon_sym_u_DQUOTE] = ACTIONS(2571),
    [anon_sym_U_DQUOTE] = ACTIONS(2571),
    [anon_sym_u8_DQUOTE] = ACTIONS(2571),
    [anon_sym_DQUOTE] = ACTIONS(2571),
    [sym_true] = ACTIONS(2569),
    [sym_false] = ACTIONS(2569),
    [anon_sym_NULL] = ACTIONS(2569),
    [anon_sym_nullptr] = ACTIONS(2569),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2569),
    [anon_sym_decltype] = ACTIONS(2569),
    [sym_virtual] = ACTIONS(2569),
    [anon_sym_explicit] = ACTIONS(2569),
    [anon_sym_typename] = ACTIONS(2569),
    [anon_sym_template] = ACTIONS(2569),
    [anon_sym_operator] = ACTIONS(2569),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_delete] = ACTIONS(2569),
    [anon_sym_throw] = ACTIONS(2569),
    [anon_sym_namespace] = ACTIONS(2569),
    [anon_sym_using] = ACTIONS(2569),
    [anon_sym_static_assert] = ACTIONS(2569),
    [anon_sym_concept] = ACTIONS(2569),
    [anon_sym_co_return] = ACTIONS(2569),
    [anon_sym_co_yield] = ACTIONS(2569),
    [anon_sym_R_DQUOTE] = ACTIONS(2571),
    [anon_sym_LR_DQUOTE] = ACTIONS(2571),
    [anon_sym_uR_DQUOTE] = ACTIONS(2571),
    [anon_sym_UR_DQUOTE] = ACTIONS(2571),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2571),
    [anon_sym_co_await] = ACTIONS(2569),
    [anon_sym_new] = ACTIONS(2569),
    [anon_sym_requires] = ACTIONS(2569),
    [sym_this] = ACTIONS(2569),
    [anon_sym_discard] = ACTIONS(2569),
    [anon_sym_precise] = ACTIONS(2569),
    [anon_sym_shared] = ACTIONS(2569),
    [anon_sym_groupshared] = ACTIONS(2569),
    [anon_sym_uniform] = ACTIONS(2569),
    [anon_sym_row_major] = ACTIONS(2569),
    [anon_sym_column_major] = ACTIONS(2569),
    [anon_sym_globallycoherent] = ACTIONS(2569),
    [anon_sym_centroid] = ACTIONS(2569),
    [anon_sym_noperspective] = ACTIONS(2569),
    [anon_sym_nointerpolation] = ACTIONS(2569),
    [anon_sym_sample] = ACTIONS(2569),
    [anon_sym_linear] = ACTIONS(2569),
    [anon_sym_snorm] = ACTIONS(2569),
    [anon_sym_unorm] = ACTIONS(2569),
    [anon_sym_point] = ACTIONS(2569),
    [anon_sym_line] = ACTIONS(2569),
    [anon_sym_triangleadj] = ACTIONS(2569),
    [anon_sym_lineadj] = ACTIONS(2569),
    [anon_sym_triangle] = ACTIONS(2569),
    [anon_sym_cbuffer] = ACTIONS(2569),
  },
  [662] = {
    [sym_identifier] = ACTIONS(2553),
    [aux_sym_preproc_include_token1] = ACTIONS(2553),
    [aux_sym_preproc_def_token1] = ACTIONS(2553),
    [aux_sym_preproc_if_token1] = ACTIONS(2553),
    [aux_sym_preproc_if_token2] = ACTIONS(2553),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2553),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2553),
    [sym_preproc_directive] = ACTIONS(2553),
    [anon_sym_LPAREN2] = ACTIONS(2555),
    [anon_sym_BANG] = ACTIONS(2555),
    [anon_sym_TILDE] = ACTIONS(2555),
    [anon_sym_DASH] = ACTIONS(2553),
    [anon_sym_PLUS] = ACTIONS(2553),
    [anon_sym_STAR] = ACTIONS(2555),
    [anon_sym_AMP_AMP] = ACTIONS(2555),
    [anon_sym_AMP] = ACTIONS(2553),
    [anon_sym_SEMI] = ACTIONS(2555),
    [anon_sym___extension__] = ACTIONS(2553),
    [anon_sym_typedef] = ACTIONS(2553),
    [anon_sym_in] = ACTIONS(2553),
    [anon_sym_out] = ACTIONS(2553),
    [anon_sym_inout] = ACTIONS(2553),
    [anon_sym_extern] = ACTIONS(2553),
    [anon_sym___attribute__] = ACTIONS(2553),
    [anon_sym_COLON_COLON] = ACTIONS(2555),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2555),
    [anon_sym___declspec] = ACTIONS(2553),
    [anon_sym___based] = ACTIONS(2553),
    [anon_sym___cdecl] = ACTIONS(2553),
    [anon_sym___clrcall] = ACTIONS(2553),
    [anon_sym___stdcall] = ACTIONS(2553),
    [anon_sym___fastcall] = ACTIONS(2553),
    [anon_sym___thiscall] = ACTIONS(2553),
    [anon_sym___vectorcall] = ACTIONS(2553),
    [anon_sym_LBRACE] = ACTIONS(2555),
    [anon_sym_signed] = ACTIONS(2553),
    [anon_sym_unsigned] = ACTIONS(2553),
    [anon_sym_long] = ACTIONS(2553),
    [anon_sym_short] = ACTIONS(2553),
    [anon_sym_LBRACK] = ACTIONS(2553),
    [anon_sym_static] = ACTIONS(2553),
    [anon_sym_register] = ACTIONS(2553),
    [anon_sym_inline] = ACTIONS(2553),
    [anon_sym___inline] = ACTIONS(2553),
    [anon_sym___inline__] = ACTIONS(2553),
    [anon_sym___forceinline] = ACTIONS(2553),
    [anon_sym_thread_local] = ACTIONS(2553),
    [anon_sym___thread] = ACTIONS(2553),
    [anon_sym_const] = ACTIONS(2553),
    [anon_sym_constexpr] = ACTIONS(2553),
    [anon_sym_volatile] = ACTIONS(2553),
    [anon_sym_restrict] = ACTIONS(2553),
    [anon_sym___restrict__] = ACTIONS(2553),
    [anon_sym__Atomic] = ACTIONS(2553),
    [anon_sym__Noreturn] = ACTIONS(2553),
    [anon_sym_noreturn] = ACTIONS(2553),
    [anon_sym_mutable] = ACTIONS(2553),
    [anon_sym_constinit] = ACTIONS(2553),
    [anon_sym_consteval] = ACTIONS(2553),
    [anon_sym_alignas] = ACTIONS(2553),
    [anon_sym__Alignas] = ACTIONS(2553),
    [sym_primitive_type] = ACTIONS(2553),
    [anon_sym_enum] = ACTIONS(2553),
    [anon_sym_class] = ACTIONS(2553),
    [anon_sym_struct] = ACTIONS(2553),
    [anon_sym_union] = ACTIONS(2553),
    [anon_sym_if] = ACTIONS(2553),
    [anon_sym_switch] = ACTIONS(2553),
    [anon_sym_case] = ACTIONS(2553),
    [anon_sym_default] = ACTIONS(2553),
    [anon_sym_while] = ACTIONS(2553),
    [anon_sym_do] = ACTIONS(2553),
    [anon_sym_for] = ACTIONS(2553),
    [anon_sym_return] = ACTIONS(2553),
    [anon_sym_break] = ACTIONS(2553),
    [anon_sym_continue] = ACTIONS(2553),
    [anon_sym_goto] = ACTIONS(2553),
    [anon_sym___try] = ACTIONS(2553),
    [anon_sym___leave] = ACTIONS(2553),
    [anon_sym_not] = ACTIONS(2553),
    [anon_sym_compl] = ACTIONS(2553),
    [anon_sym_DASH_DASH] = ACTIONS(2555),
    [anon_sym_PLUS_PLUS] = ACTIONS(2555),
    [anon_sym_sizeof] = ACTIONS(2553),
    [anon_sym___alignof__] = ACTIONS(2553),
    [anon_sym___alignof] = ACTIONS(2553),
    [anon_sym__alignof] = ACTIONS(2553),
    [anon_sym_alignof] = ACTIONS(2553),
    [anon_sym__Alignof] = ACTIONS(2553),
    [anon_sym_offsetof] = ACTIONS(2553),
    [anon_sym__Generic] = ACTIONS(2553),
    [anon_sym_asm] = ACTIONS(2553),
    [anon_sym___asm__] = ACTIONS(2553),
    [sym_number_literal] = ACTIONS(2555),
    [anon_sym_L_SQUOTE] = ACTIONS(2555),
    [anon_sym_u_SQUOTE] = ACTIONS(2555),
    [anon_sym_U_SQUOTE] = ACTIONS(2555),
    [anon_sym_u8_SQUOTE] = ACTIONS(2555),
    [anon_sym_SQUOTE] = ACTIONS(2555),
    [anon_sym_L_DQUOTE] = ACTIONS(2555),
    [anon_sym_u_DQUOTE] = ACTIONS(2555),
    [anon_sym_U_DQUOTE] = ACTIONS(2555),
    [anon_sym_u8_DQUOTE] = ACTIONS(2555),
    [anon_sym_DQUOTE] = ACTIONS(2555),
    [sym_true] = ACTIONS(2553),
    [sym_false] = ACTIONS(2553),
    [anon_sym_NULL] = ACTIONS(2553),
    [anon_sym_nullptr] = ACTIONS(2553),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2553),
    [anon_sym_decltype] = ACTIONS(2553),
    [sym_virtual] = ACTIONS(2553),
    [anon_sym_explicit] = ACTIONS(2553),
    [anon_sym_typename] = ACTIONS(2553),
    [anon_sym_template] = ACTIONS(2553),
    [anon_sym_operator] = ACTIONS(2553),
    [anon_sym_try] = ACTIONS(2553),
    [anon_sym_delete] = ACTIONS(2553),
    [anon_sym_throw] = ACTIONS(2553),
    [anon_sym_namespace] = ACTIONS(2553),
    [anon_sym_using] = ACTIONS(2553),
    [anon_sym_static_assert] = ACTIONS(2553),
    [anon_sym_concept] = ACTIONS(2553),
    [anon_sym_co_return] = ACTIONS(2553),
    [anon_sym_co_yield] = ACTIONS(2553),
    [anon_sym_R_DQUOTE] = ACTIONS(2555),
    [anon_sym_LR_DQUOTE] = ACTIONS(2555),
    [anon_sym_uR_DQUOTE] = ACTIONS(2555),
    [anon_sym_UR_DQUOTE] = ACTIONS(2555),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2555),
    [anon_sym_co_await] = ACTIONS(2553),
    [anon_sym_new] = ACTIONS(2553),
    [anon_sym_requires] = ACTIONS(2553),
    [sym_this] = ACTIONS(2553),
    [anon_sym_discard] = ACTIONS(2553),
    [anon_sym_precise] = ACTIONS(2553),
    [anon_sym_shared] = ACTIONS(2553),
    [anon_sym_groupshared] = ACTIONS(2553),
    [anon_sym_uniform] = ACTIONS(2553),
    [anon_sym_row_major] = ACTIONS(2553),
    [anon_sym_column_major] = ACTIONS(2553),
    [anon_sym_globallycoherent] = ACTIONS(2553),
    [anon_sym_centroid] = ACTIONS(2553),
    [anon_sym_noperspective] = ACTIONS(2553),
    [anon_sym_nointerpolation] = ACTIONS(2553),
    [anon_sym_sample] = ACTIONS(2553),
    [anon_sym_linear] = ACTIONS(2553),
    [anon_sym_snorm] = ACTIONS(2553),
    [anon_sym_unorm] = ACTIONS(2553),
    [anon_sym_point] = ACTIONS(2553),
    [anon_sym_line] = ACTIONS(2553),
    [anon_sym_triangleadj] = ACTIONS(2553),
    [anon_sym_lineadj] = ACTIONS(2553),
    [anon_sym_triangle] = ACTIONS(2553),
    [anon_sym_cbuffer] = ACTIONS(2553),
  },
  [663] = {
    [sym_identifier] = ACTIONS(2356),
    [aux_sym_preproc_include_token1] = ACTIONS(2356),
    [aux_sym_preproc_def_token1] = ACTIONS(2356),
    [aux_sym_preproc_if_token1] = ACTIONS(2356),
    [aux_sym_preproc_if_token2] = ACTIONS(2356),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2356),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2356),
    [sym_preproc_directive] = ACTIONS(2356),
    [anon_sym_LPAREN2] = ACTIONS(2358),
    [anon_sym_BANG] = ACTIONS(2358),
    [anon_sym_TILDE] = ACTIONS(2358),
    [anon_sym_DASH] = ACTIONS(2356),
    [anon_sym_PLUS] = ACTIONS(2356),
    [anon_sym_STAR] = ACTIONS(2358),
    [anon_sym_AMP_AMP] = ACTIONS(2358),
    [anon_sym_AMP] = ACTIONS(2356),
    [anon_sym_SEMI] = ACTIONS(2358),
    [anon_sym___extension__] = ACTIONS(2356),
    [anon_sym_typedef] = ACTIONS(2356),
    [anon_sym_in] = ACTIONS(2356),
    [anon_sym_out] = ACTIONS(2356),
    [anon_sym_inout] = ACTIONS(2356),
    [anon_sym_extern] = ACTIONS(2356),
    [anon_sym___attribute__] = ACTIONS(2356),
    [anon_sym_COLON_COLON] = ACTIONS(2358),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2358),
    [anon_sym___declspec] = ACTIONS(2356),
    [anon_sym___based] = ACTIONS(2356),
    [anon_sym___cdecl] = ACTIONS(2356),
    [anon_sym___clrcall] = ACTIONS(2356),
    [anon_sym___stdcall] = ACTIONS(2356),
    [anon_sym___fastcall] = ACTIONS(2356),
    [anon_sym___thiscall] = ACTIONS(2356),
    [anon_sym___vectorcall] = ACTIONS(2356),
    [anon_sym_LBRACE] = ACTIONS(2358),
    [anon_sym_signed] = ACTIONS(2356),
    [anon_sym_unsigned] = ACTIONS(2356),
    [anon_sym_long] = ACTIONS(2356),
    [anon_sym_short] = ACTIONS(2356),
    [anon_sym_LBRACK] = ACTIONS(2356),
    [anon_sym_static] = ACTIONS(2356),
    [anon_sym_register] = ACTIONS(2356),
    [anon_sym_inline] = ACTIONS(2356),
    [anon_sym___inline] = ACTIONS(2356),
    [anon_sym___inline__] = ACTIONS(2356),
    [anon_sym___forceinline] = ACTIONS(2356),
    [anon_sym_thread_local] = ACTIONS(2356),
    [anon_sym___thread] = ACTIONS(2356),
    [anon_sym_const] = ACTIONS(2356),
    [anon_sym_constexpr] = ACTIONS(2356),
    [anon_sym_volatile] = ACTIONS(2356),
    [anon_sym_restrict] = ACTIONS(2356),
    [anon_sym___restrict__] = ACTIONS(2356),
    [anon_sym__Atomic] = ACTIONS(2356),
    [anon_sym__Noreturn] = ACTIONS(2356),
    [anon_sym_noreturn] = ACTIONS(2356),
    [anon_sym_mutable] = ACTIONS(2356),
    [anon_sym_constinit] = ACTIONS(2356),
    [anon_sym_consteval] = ACTIONS(2356),
    [anon_sym_alignas] = ACTIONS(2356),
    [anon_sym__Alignas] = ACTIONS(2356),
    [sym_primitive_type] = ACTIONS(2356),
    [anon_sym_enum] = ACTIONS(2356),
    [anon_sym_class] = ACTIONS(2356),
    [anon_sym_struct] = ACTIONS(2356),
    [anon_sym_union] = ACTIONS(2356),
    [anon_sym_if] = ACTIONS(2356),
    [anon_sym_switch] = ACTIONS(2356),
    [anon_sym_case] = ACTIONS(2356),
    [anon_sym_default] = ACTIONS(2356),
    [anon_sym_while] = ACTIONS(2356),
    [anon_sym_do] = ACTIONS(2356),
    [anon_sym_for] = ACTIONS(2356),
    [anon_sym_return] = ACTIONS(2356),
    [anon_sym_break] = ACTIONS(2356),
    [anon_sym_continue] = ACTIONS(2356),
    [anon_sym_goto] = ACTIONS(2356),
    [anon_sym___try] = ACTIONS(2356),
    [anon_sym___leave] = ACTIONS(2356),
    [anon_sym_not] = ACTIONS(2356),
    [anon_sym_compl] = ACTIONS(2356),
    [anon_sym_DASH_DASH] = ACTIONS(2358),
    [anon_sym_PLUS_PLUS] = ACTIONS(2358),
    [anon_sym_sizeof] = ACTIONS(2356),
    [anon_sym___alignof__] = ACTIONS(2356),
    [anon_sym___alignof] = ACTIONS(2356),
    [anon_sym__alignof] = ACTIONS(2356),
    [anon_sym_alignof] = ACTIONS(2356),
    [anon_sym__Alignof] = ACTIONS(2356),
    [anon_sym_offsetof] = ACTIONS(2356),
    [anon_sym__Generic] = ACTIONS(2356),
    [anon_sym_asm] = ACTIONS(2356),
    [anon_sym___asm__] = ACTIONS(2356),
    [sym_number_literal] = ACTIONS(2358),
    [anon_sym_L_SQUOTE] = ACTIONS(2358),
    [anon_sym_u_SQUOTE] = ACTIONS(2358),
    [anon_sym_U_SQUOTE] = ACTIONS(2358),
    [anon_sym_u8_SQUOTE] = ACTIONS(2358),
    [anon_sym_SQUOTE] = ACTIONS(2358),
    [anon_sym_L_DQUOTE] = ACTIONS(2358),
    [anon_sym_u_DQUOTE] = ACTIONS(2358),
    [anon_sym_U_DQUOTE] = ACTIONS(2358),
    [anon_sym_u8_DQUOTE] = ACTIONS(2358),
    [anon_sym_DQUOTE] = ACTIONS(2358),
    [sym_true] = ACTIONS(2356),
    [sym_false] = ACTIONS(2356),
    [anon_sym_NULL] = ACTIONS(2356),
    [anon_sym_nullptr] = ACTIONS(2356),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2356),
    [anon_sym_decltype] = ACTIONS(2356),
    [sym_virtual] = ACTIONS(2356),
    [anon_sym_explicit] = ACTIONS(2356),
    [anon_sym_typename] = ACTIONS(2356),
    [anon_sym_template] = ACTIONS(2356),
    [anon_sym_operator] = ACTIONS(2356),
    [anon_sym_try] = ACTIONS(2356),
    [anon_sym_delete] = ACTIONS(2356),
    [anon_sym_throw] = ACTIONS(2356),
    [anon_sym_namespace] = ACTIONS(2356),
    [anon_sym_using] = ACTIONS(2356),
    [anon_sym_static_assert] = ACTIONS(2356),
    [anon_sym_concept] = ACTIONS(2356),
    [anon_sym_co_return] = ACTIONS(2356),
    [anon_sym_co_yield] = ACTIONS(2356),
    [anon_sym_R_DQUOTE] = ACTIONS(2358),
    [anon_sym_LR_DQUOTE] = ACTIONS(2358),
    [anon_sym_uR_DQUOTE] = ACTIONS(2358),
    [anon_sym_UR_DQUOTE] = ACTIONS(2358),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2358),
    [anon_sym_co_await] = ACTIONS(2356),
    [anon_sym_new] = ACTIONS(2356),
    [anon_sym_requires] = ACTIONS(2356),
    [sym_this] = ACTIONS(2356),
    [anon_sym_discard] = ACTIONS(2356),
    [anon_sym_precise] = ACTIONS(2356),
    [anon_sym_shared] = ACTIONS(2356),
    [anon_sym_groupshared] = ACTIONS(2356),
    [anon_sym_uniform] = ACTIONS(2356),
    [anon_sym_row_major] = ACTIONS(2356),
    [anon_sym_column_major] = ACTIONS(2356),
    [anon_sym_globallycoherent] = ACTIONS(2356),
    [anon_sym_centroid] = ACTIONS(2356),
    [anon_sym_noperspective] = ACTIONS(2356),
    [anon_sym_nointerpolation] = ACTIONS(2356),
    [anon_sym_sample] = ACTIONS(2356),
    [anon_sym_linear] = ACTIONS(2356),
    [anon_sym_snorm] = ACTIONS(2356),
    [anon_sym_unorm] = ACTIONS(2356),
    [anon_sym_point] = ACTIONS(2356),
    [anon_sym_line] = ACTIONS(2356),
    [anon_sym_triangleadj] = ACTIONS(2356),
    [anon_sym_lineadj] = ACTIONS(2356),
    [anon_sym_triangle] = ACTIONS(2356),
    [anon_sym_cbuffer] = ACTIONS(2356),
  },
  [664] = {
    [sym_identifier] = ACTIONS(2569),
    [aux_sym_preproc_include_token1] = ACTIONS(2569),
    [aux_sym_preproc_def_token1] = ACTIONS(2569),
    [aux_sym_preproc_if_token1] = ACTIONS(2569),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2569),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2569),
    [sym_preproc_directive] = ACTIONS(2569),
    [anon_sym_LPAREN2] = ACTIONS(2571),
    [anon_sym_BANG] = ACTIONS(2571),
    [anon_sym_TILDE] = ACTIONS(2571),
    [anon_sym_DASH] = ACTIONS(2569),
    [anon_sym_PLUS] = ACTIONS(2569),
    [anon_sym_STAR] = ACTIONS(2571),
    [anon_sym_AMP_AMP] = ACTIONS(2571),
    [anon_sym_AMP] = ACTIONS(2569),
    [anon_sym_SEMI] = ACTIONS(2571),
    [anon_sym___extension__] = ACTIONS(2569),
    [anon_sym_typedef] = ACTIONS(2569),
    [anon_sym_in] = ACTIONS(2569),
    [anon_sym_out] = ACTIONS(2569),
    [anon_sym_inout] = ACTIONS(2569),
    [anon_sym_extern] = ACTIONS(2569),
    [anon_sym___attribute__] = ACTIONS(2569),
    [anon_sym_COLON_COLON] = ACTIONS(2571),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2571),
    [anon_sym___declspec] = ACTIONS(2569),
    [anon_sym___based] = ACTIONS(2569),
    [anon_sym___cdecl] = ACTIONS(2569),
    [anon_sym___clrcall] = ACTIONS(2569),
    [anon_sym___stdcall] = ACTIONS(2569),
    [anon_sym___fastcall] = ACTIONS(2569),
    [anon_sym___thiscall] = ACTIONS(2569),
    [anon_sym___vectorcall] = ACTIONS(2569),
    [anon_sym_LBRACE] = ACTIONS(2571),
    [anon_sym_RBRACE] = ACTIONS(2571),
    [anon_sym_signed] = ACTIONS(2569),
    [anon_sym_unsigned] = ACTIONS(2569),
    [anon_sym_long] = ACTIONS(2569),
    [anon_sym_short] = ACTIONS(2569),
    [anon_sym_LBRACK] = ACTIONS(2569),
    [anon_sym_static] = ACTIONS(2569),
    [anon_sym_register] = ACTIONS(2569),
    [anon_sym_inline] = ACTIONS(2569),
    [anon_sym___inline] = ACTIONS(2569),
    [anon_sym___inline__] = ACTIONS(2569),
    [anon_sym___forceinline] = ACTIONS(2569),
    [anon_sym_thread_local] = ACTIONS(2569),
    [anon_sym___thread] = ACTIONS(2569),
    [anon_sym_const] = ACTIONS(2569),
    [anon_sym_constexpr] = ACTIONS(2569),
    [anon_sym_volatile] = ACTIONS(2569),
    [anon_sym_restrict] = ACTIONS(2569),
    [anon_sym___restrict__] = ACTIONS(2569),
    [anon_sym__Atomic] = ACTIONS(2569),
    [anon_sym__Noreturn] = ACTIONS(2569),
    [anon_sym_noreturn] = ACTIONS(2569),
    [anon_sym_mutable] = ACTIONS(2569),
    [anon_sym_constinit] = ACTIONS(2569),
    [anon_sym_consteval] = ACTIONS(2569),
    [anon_sym_alignas] = ACTIONS(2569),
    [anon_sym__Alignas] = ACTIONS(2569),
    [sym_primitive_type] = ACTIONS(2569),
    [anon_sym_enum] = ACTIONS(2569),
    [anon_sym_class] = ACTIONS(2569),
    [anon_sym_struct] = ACTIONS(2569),
    [anon_sym_union] = ACTIONS(2569),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_switch] = ACTIONS(2569),
    [anon_sym_case] = ACTIONS(2569),
    [anon_sym_default] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2569),
    [anon_sym_do] = ACTIONS(2569),
    [anon_sym_for] = ACTIONS(2569),
    [anon_sym_return] = ACTIONS(2569),
    [anon_sym_break] = ACTIONS(2569),
    [anon_sym_continue] = ACTIONS(2569),
    [anon_sym_goto] = ACTIONS(2569),
    [anon_sym___try] = ACTIONS(2569),
    [anon_sym___leave] = ACTIONS(2569),
    [anon_sym_not] = ACTIONS(2569),
    [anon_sym_compl] = ACTIONS(2569),
    [anon_sym_DASH_DASH] = ACTIONS(2571),
    [anon_sym_PLUS_PLUS] = ACTIONS(2571),
    [anon_sym_sizeof] = ACTIONS(2569),
    [anon_sym___alignof__] = ACTIONS(2569),
    [anon_sym___alignof] = ACTIONS(2569),
    [anon_sym__alignof] = ACTIONS(2569),
    [anon_sym_alignof] = ACTIONS(2569),
    [anon_sym__Alignof] = ACTIONS(2569),
    [anon_sym_offsetof] = ACTIONS(2569),
    [anon_sym__Generic] = ACTIONS(2569),
    [anon_sym_asm] = ACTIONS(2569),
    [anon_sym___asm__] = ACTIONS(2569),
    [sym_number_literal] = ACTIONS(2571),
    [anon_sym_L_SQUOTE] = ACTIONS(2571),
    [anon_sym_u_SQUOTE] = ACTIONS(2571),
    [anon_sym_U_SQUOTE] = ACTIONS(2571),
    [anon_sym_u8_SQUOTE] = ACTIONS(2571),
    [anon_sym_SQUOTE] = ACTIONS(2571),
    [anon_sym_L_DQUOTE] = ACTIONS(2571),
    [anon_sym_u_DQUOTE] = ACTIONS(2571),
    [anon_sym_U_DQUOTE] = ACTIONS(2571),
    [anon_sym_u8_DQUOTE] = ACTIONS(2571),
    [anon_sym_DQUOTE] = ACTIONS(2571),
    [sym_true] = ACTIONS(2569),
    [sym_false] = ACTIONS(2569),
    [anon_sym_NULL] = ACTIONS(2569),
    [anon_sym_nullptr] = ACTIONS(2569),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2569),
    [anon_sym_decltype] = ACTIONS(2569),
    [sym_virtual] = ACTIONS(2569),
    [anon_sym_explicit] = ACTIONS(2569),
    [anon_sym_typename] = ACTIONS(2569),
    [anon_sym_template] = ACTIONS(2569),
    [anon_sym_operator] = ACTIONS(2569),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_delete] = ACTIONS(2569),
    [anon_sym_throw] = ACTIONS(2569),
    [anon_sym_namespace] = ACTIONS(2569),
    [anon_sym_using] = ACTIONS(2569),
    [anon_sym_static_assert] = ACTIONS(2569),
    [anon_sym_concept] = ACTIONS(2569),
    [anon_sym_co_return] = ACTIONS(2569),
    [anon_sym_co_yield] = ACTIONS(2569),
    [anon_sym_R_DQUOTE] = ACTIONS(2571),
    [anon_sym_LR_DQUOTE] = ACTIONS(2571),
    [anon_sym_uR_DQUOTE] = ACTIONS(2571),
    [anon_sym_UR_DQUOTE] = ACTIONS(2571),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2571),
    [anon_sym_co_await] = ACTIONS(2569),
    [anon_sym_new] = ACTIONS(2569),
    [anon_sym_requires] = ACTIONS(2569),
    [sym_this] = ACTIONS(2569),
    [anon_sym_discard] = ACTIONS(2569),
    [anon_sym_precise] = ACTIONS(2569),
    [anon_sym_shared] = ACTIONS(2569),
    [anon_sym_groupshared] = ACTIONS(2569),
    [anon_sym_uniform] = ACTIONS(2569),
    [anon_sym_row_major] = ACTIONS(2569),
    [anon_sym_column_major] = ACTIONS(2569),
    [anon_sym_globallycoherent] = ACTIONS(2569),
    [anon_sym_centroid] = ACTIONS(2569),
    [anon_sym_noperspective] = ACTIONS(2569),
    [anon_sym_nointerpolation] = ACTIONS(2569),
    [anon_sym_sample] = ACTIONS(2569),
    [anon_sym_linear] = ACTIONS(2569),
    [anon_sym_snorm] = ACTIONS(2569),
    [anon_sym_unorm] = ACTIONS(2569),
    [anon_sym_point] = ACTIONS(2569),
    [anon_sym_line] = ACTIONS(2569),
    [anon_sym_triangleadj] = ACTIONS(2569),
    [anon_sym_lineadj] = ACTIONS(2569),
    [anon_sym_triangle] = ACTIONS(2569),
    [anon_sym_cbuffer] = ACTIONS(2569),
  },
  [665] = {
    [sym_identifier] = ACTIONS(2565),
    [aux_sym_preproc_include_token1] = ACTIONS(2565),
    [aux_sym_preproc_def_token1] = ACTIONS(2565),
    [aux_sym_preproc_if_token1] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2565),
    [sym_preproc_directive] = ACTIONS(2565),
    [anon_sym_LPAREN2] = ACTIONS(2567),
    [anon_sym_BANG] = ACTIONS(2567),
    [anon_sym_TILDE] = ACTIONS(2567),
    [anon_sym_DASH] = ACTIONS(2565),
    [anon_sym_PLUS] = ACTIONS(2565),
    [anon_sym_STAR] = ACTIONS(2567),
    [anon_sym_AMP_AMP] = ACTIONS(2567),
    [anon_sym_AMP] = ACTIONS(2565),
    [anon_sym_SEMI] = ACTIONS(2567),
    [anon_sym___extension__] = ACTIONS(2565),
    [anon_sym_typedef] = ACTIONS(2565),
    [anon_sym_in] = ACTIONS(2565),
    [anon_sym_out] = ACTIONS(2565),
    [anon_sym_inout] = ACTIONS(2565),
    [anon_sym_extern] = ACTIONS(2565),
    [anon_sym___attribute__] = ACTIONS(2565),
    [anon_sym_COLON_COLON] = ACTIONS(2567),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2567),
    [anon_sym___declspec] = ACTIONS(2565),
    [anon_sym___based] = ACTIONS(2565),
    [anon_sym___cdecl] = ACTIONS(2565),
    [anon_sym___clrcall] = ACTIONS(2565),
    [anon_sym___stdcall] = ACTIONS(2565),
    [anon_sym___fastcall] = ACTIONS(2565),
    [anon_sym___thiscall] = ACTIONS(2565),
    [anon_sym___vectorcall] = ACTIONS(2565),
    [anon_sym_LBRACE] = ACTIONS(2567),
    [anon_sym_RBRACE] = ACTIONS(2567),
    [anon_sym_signed] = ACTIONS(2565),
    [anon_sym_unsigned] = ACTIONS(2565),
    [anon_sym_long] = ACTIONS(2565),
    [anon_sym_short] = ACTIONS(2565),
    [anon_sym_LBRACK] = ACTIONS(2565),
    [anon_sym_static] = ACTIONS(2565),
    [anon_sym_register] = ACTIONS(2565),
    [anon_sym_inline] = ACTIONS(2565),
    [anon_sym___inline] = ACTIONS(2565),
    [anon_sym___inline__] = ACTIONS(2565),
    [anon_sym___forceinline] = ACTIONS(2565),
    [anon_sym_thread_local] = ACTIONS(2565),
    [anon_sym___thread] = ACTIONS(2565),
    [anon_sym_const] = ACTIONS(2565),
    [anon_sym_constexpr] = ACTIONS(2565),
    [anon_sym_volatile] = ACTIONS(2565),
    [anon_sym_restrict] = ACTIONS(2565),
    [anon_sym___restrict__] = ACTIONS(2565),
    [anon_sym__Atomic] = ACTIONS(2565),
    [anon_sym__Noreturn] = ACTIONS(2565),
    [anon_sym_noreturn] = ACTIONS(2565),
    [anon_sym_mutable] = ACTIONS(2565),
    [anon_sym_constinit] = ACTIONS(2565),
    [anon_sym_consteval] = ACTIONS(2565),
    [anon_sym_alignas] = ACTIONS(2565),
    [anon_sym__Alignas] = ACTIONS(2565),
    [sym_primitive_type] = ACTIONS(2565),
    [anon_sym_enum] = ACTIONS(2565),
    [anon_sym_class] = ACTIONS(2565),
    [anon_sym_struct] = ACTIONS(2565),
    [anon_sym_union] = ACTIONS(2565),
    [anon_sym_if] = ACTIONS(2565),
    [anon_sym_switch] = ACTIONS(2565),
    [anon_sym_case] = ACTIONS(2565),
    [anon_sym_default] = ACTIONS(2565),
    [anon_sym_while] = ACTIONS(2565),
    [anon_sym_do] = ACTIONS(2565),
    [anon_sym_for] = ACTIONS(2565),
    [anon_sym_return] = ACTIONS(2565),
    [anon_sym_break] = ACTIONS(2565),
    [anon_sym_continue] = ACTIONS(2565),
    [anon_sym_goto] = ACTIONS(2565),
    [anon_sym___try] = ACTIONS(2565),
    [anon_sym___leave] = ACTIONS(2565),
    [anon_sym_not] = ACTIONS(2565),
    [anon_sym_compl] = ACTIONS(2565),
    [anon_sym_DASH_DASH] = ACTIONS(2567),
    [anon_sym_PLUS_PLUS] = ACTIONS(2567),
    [anon_sym_sizeof] = ACTIONS(2565),
    [anon_sym___alignof__] = ACTIONS(2565),
    [anon_sym___alignof] = ACTIONS(2565),
    [anon_sym__alignof] = ACTIONS(2565),
    [anon_sym_alignof] = ACTIONS(2565),
    [anon_sym__Alignof] = ACTIONS(2565),
    [anon_sym_offsetof] = ACTIONS(2565),
    [anon_sym__Generic] = ACTIONS(2565),
    [anon_sym_asm] = ACTIONS(2565),
    [anon_sym___asm__] = ACTIONS(2565),
    [sym_number_literal] = ACTIONS(2567),
    [anon_sym_L_SQUOTE] = ACTIONS(2567),
    [anon_sym_u_SQUOTE] = ACTIONS(2567),
    [anon_sym_U_SQUOTE] = ACTIONS(2567),
    [anon_sym_u8_SQUOTE] = ACTIONS(2567),
    [anon_sym_SQUOTE] = ACTIONS(2567),
    [anon_sym_L_DQUOTE] = ACTIONS(2567),
    [anon_sym_u_DQUOTE] = ACTIONS(2567),
    [anon_sym_U_DQUOTE] = ACTIONS(2567),
    [anon_sym_u8_DQUOTE] = ACTIONS(2567),
    [anon_sym_DQUOTE] = ACTIONS(2567),
    [sym_true] = ACTIONS(2565),
    [sym_false] = ACTIONS(2565),
    [anon_sym_NULL] = ACTIONS(2565),
    [anon_sym_nullptr] = ACTIONS(2565),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2565),
    [anon_sym_decltype] = ACTIONS(2565),
    [sym_virtual] = ACTIONS(2565),
    [anon_sym_explicit] = ACTIONS(2565),
    [anon_sym_typename] = ACTIONS(2565),
    [anon_sym_template] = ACTIONS(2565),
    [anon_sym_operator] = ACTIONS(2565),
    [anon_sym_try] = ACTIONS(2565),
    [anon_sym_delete] = ACTIONS(2565),
    [anon_sym_throw] = ACTIONS(2565),
    [anon_sym_namespace] = ACTIONS(2565),
    [anon_sym_using] = ACTIONS(2565),
    [anon_sym_static_assert] = ACTIONS(2565),
    [anon_sym_concept] = ACTIONS(2565),
    [anon_sym_co_return] = ACTIONS(2565),
    [anon_sym_co_yield] = ACTIONS(2565),
    [anon_sym_R_DQUOTE] = ACTIONS(2567),
    [anon_sym_LR_DQUOTE] = ACTIONS(2567),
    [anon_sym_uR_DQUOTE] = ACTIONS(2567),
    [anon_sym_UR_DQUOTE] = ACTIONS(2567),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2567),
    [anon_sym_co_await] = ACTIONS(2565),
    [anon_sym_new] = ACTIONS(2565),
    [anon_sym_requires] = ACTIONS(2565),
    [sym_this] = ACTIONS(2565),
    [anon_sym_discard] = ACTIONS(2565),
    [anon_sym_precise] = ACTIONS(2565),
    [anon_sym_shared] = ACTIONS(2565),
    [anon_sym_groupshared] = ACTIONS(2565),
    [anon_sym_uniform] = ACTIONS(2565),
    [anon_sym_row_major] = ACTIONS(2565),
    [anon_sym_column_major] = ACTIONS(2565),
    [anon_sym_globallycoherent] = ACTIONS(2565),
    [anon_sym_centroid] = ACTIONS(2565),
    [anon_sym_noperspective] = ACTIONS(2565),
    [anon_sym_nointerpolation] = ACTIONS(2565),
    [anon_sym_sample] = ACTIONS(2565),
    [anon_sym_linear] = ACTIONS(2565),
    [anon_sym_snorm] = ACTIONS(2565),
    [anon_sym_unorm] = ACTIONS(2565),
    [anon_sym_point] = ACTIONS(2565),
    [anon_sym_line] = ACTIONS(2565),
    [anon_sym_triangleadj] = ACTIONS(2565),
    [anon_sym_lineadj] = ACTIONS(2565),
    [anon_sym_triangle] = ACTIONS(2565),
    [anon_sym_cbuffer] = ACTIONS(2565),
  },
  [666] = {
    [sym_identifier] = ACTIONS(2424),
    [aux_sym_preproc_include_token1] = ACTIONS(2424),
    [aux_sym_preproc_def_token1] = ACTIONS(2424),
    [aux_sym_preproc_if_token1] = ACTIONS(2424),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2424),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2424),
    [sym_preproc_directive] = ACTIONS(2424),
    [anon_sym_LPAREN2] = ACTIONS(2426),
    [anon_sym_BANG] = ACTIONS(2426),
    [anon_sym_TILDE] = ACTIONS(2426),
    [anon_sym_DASH] = ACTIONS(2424),
    [anon_sym_PLUS] = ACTIONS(2424),
    [anon_sym_STAR] = ACTIONS(2426),
    [anon_sym_AMP_AMP] = ACTIONS(2426),
    [anon_sym_AMP] = ACTIONS(2424),
    [anon_sym_SEMI] = ACTIONS(2426),
    [anon_sym___extension__] = ACTIONS(2424),
    [anon_sym_typedef] = ACTIONS(2424),
    [anon_sym_in] = ACTIONS(2424),
    [anon_sym_out] = ACTIONS(2424),
    [anon_sym_inout] = ACTIONS(2424),
    [anon_sym_extern] = ACTIONS(2424),
    [anon_sym___attribute__] = ACTIONS(2424),
    [anon_sym_COLON_COLON] = ACTIONS(2426),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2426),
    [anon_sym___declspec] = ACTIONS(2424),
    [anon_sym___based] = ACTIONS(2424),
    [anon_sym___cdecl] = ACTIONS(2424),
    [anon_sym___clrcall] = ACTIONS(2424),
    [anon_sym___stdcall] = ACTIONS(2424),
    [anon_sym___fastcall] = ACTIONS(2424),
    [anon_sym___thiscall] = ACTIONS(2424),
    [anon_sym___vectorcall] = ACTIONS(2424),
    [anon_sym_LBRACE] = ACTIONS(2426),
    [anon_sym_RBRACE] = ACTIONS(2426),
    [anon_sym_signed] = ACTIONS(2424),
    [anon_sym_unsigned] = ACTIONS(2424),
    [anon_sym_long] = ACTIONS(2424),
    [anon_sym_short] = ACTIONS(2424),
    [anon_sym_LBRACK] = ACTIONS(2424),
    [anon_sym_static] = ACTIONS(2424),
    [anon_sym_register] = ACTIONS(2424),
    [anon_sym_inline] = ACTIONS(2424),
    [anon_sym___inline] = ACTIONS(2424),
    [anon_sym___inline__] = ACTIONS(2424),
    [anon_sym___forceinline] = ACTIONS(2424),
    [anon_sym_thread_local] = ACTIONS(2424),
    [anon_sym___thread] = ACTIONS(2424),
    [anon_sym_const] = ACTIONS(2424),
    [anon_sym_constexpr] = ACTIONS(2424),
    [anon_sym_volatile] = ACTIONS(2424),
    [anon_sym_restrict] = ACTIONS(2424),
    [anon_sym___restrict__] = ACTIONS(2424),
    [anon_sym__Atomic] = ACTIONS(2424),
    [anon_sym__Noreturn] = ACTIONS(2424),
    [anon_sym_noreturn] = ACTIONS(2424),
    [anon_sym_mutable] = ACTIONS(2424),
    [anon_sym_constinit] = ACTIONS(2424),
    [anon_sym_consteval] = ACTIONS(2424),
    [anon_sym_alignas] = ACTIONS(2424),
    [anon_sym__Alignas] = ACTIONS(2424),
    [sym_primitive_type] = ACTIONS(2424),
    [anon_sym_enum] = ACTIONS(2424),
    [anon_sym_class] = ACTIONS(2424),
    [anon_sym_struct] = ACTIONS(2424),
    [anon_sym_union] = ACTIONS(2424),
    [anon_sym_if] = ACTIONS(2424),
    [anon_sym_switch] = ACTIONS(2424),
    [anon_sym_case] = ACTIONS(2424),
    [anon_sym_default] = ACTIONS(2424),
    [anon_sym_while] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(2424),
    [anon_sym_for] = ACTIONS(2424),
    [anon_sym_return] = ACTIONS(2424),
    [anon_sym_break] = ACTIONS(2424),
    [anon_sym_continue] = ACTIONS(2424),
    [anon_sym_goto] = ACTIONS(2424),
    [anon_sym___try] = ACTIONS(2424),
    [anon_sym___leave] = ACTIONS(2424),
    [anon_sym_not] = ACTIONS(2424),
    [anon_sym_compl] = ACTIONS(2424),
    [anon_sym_DASH_DASH] = ACTIONS(2426),
    [anon_sym_PLUS_PLUS] = ACTIONS(2426),
    [anon_sym_sizeof] = ACTIONS(2424),
    [anon_sym___alignof__] = ACTIONS(2424),
    [anon_sym___alignof] = ACTIONS(2424),
    [anon_sym__alignof] = ACTIONS(2424),
    [anon_sym_alignof] = ACTIONS(2424),
    [anon_sym__Alignof] = ACTIONS(2424),
    [anon_sym_offsetof] = ACTIONS(2424),
    [anon_sym__Generic] = ACTIONS(2424),
    [anon_sym_asm] = ACTIONS(2424),
    [anon_sym___asm__] = ACTIONS(2424),
    [sym_number_literal] = ACTIONS(2426),
    [anon_sym_L_SQUOTE] = ACTIONS(2426),
    [anon_sym_u_SQUOTE] = ACTIONS(2426),
    [anon_sym_U_SQUOTE] = ACTIONS(2426),
    [anon_sym_u8_SQUOTE] = ACTIONS(2426),
    [anon_sym_SQUOTE] = ACTIONS(2426),
    [anon_sym_L_DQUOTE] = ACTIONS(2426),
    [anon_sym_u_DQUOTE] = ACTIONS(2426),
    [anon_sym_U_DQUOTE] = ACTIONS(2426),
    [anon_sym_u8_DQUOTE] = ACTIONS(2426),
    [anon_sym_DQUOTE] = ACTIONS(2426),
    [sym_true] = ACTIONS(2424),
    [sym_false] = ACTIONS(2424),
    [anon_sym_NULL] = ACTIONS(2424),
    [anon_sym_nullptr] = ACTIONS(2424),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2424),
    [anon_sym_decltype] = ACTIONS(2424),
    [sym_virtual] = ACTIONS(2424),
    [anon_sym_explicit] = ACTIONS(2424),
    [anon_sym_typename] = ACTIONS(2424),
    [anon_sym_template] = ACTIONS(2424),
    [anon_sym_operator] = ACTIONS(2424),
    [anon_sym_try] = ACTIONS(2424),
    [anon_sym_delete] = ACTIONS(2424),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_namespace] = ACTIONS(2424),
    [anon_sym_using] = ACTIONS(2424),
    [anon_sym_static_assert] = ACTIONS(2424),
    [anon_sym_concept] = ACTIONS(2424),
    [anon_sym_co_return] = ACTIONS(2424),
    [anon_sym_co_yield] = ACTIONS(2424),
    [anon_sym_R_DQUOTE] = ACTIONS(2426),
    [anon_sym_LR_DQUOTE] = ACTIONS(2426),
    [anon_sym_uR_DQUOTE] = ACTIONS(2426),
    [anon_sym_UR_DQUOTE] = ACTIONS(2426),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2426),
    [anon_sym_co_await] = ACTIONS(2424),
    [anon_sym_new] = ACTIONS(2424),
    [anon_sym_requires] = ACTIONS(2424),
    [sym_this] = ACTIONS(2424),
    [anon_sym_discard] = ACTIONS(2424),
    [anon_sym_precise] = ACTIONS(2424),
    [anon_sym_shared] = ACTIONS(2424),
    [anon_sym_groupshared] = ACTIONS(2424),
    [anon_sym_uniform] = ACTIONS(2424),
    [anon_sym_row_major] = ACTIONS(2424),
    [anon_sym_column_major] = ACTIONS(2424),
    [anon_sym_globallycoherent] = ACTIONS(2424),
    [anon_sym_centroid] = ACTIONS(2424),
    [anon_sym_noperspective] = ACTIONS(2424),
    [anon_sym_nointerpolation] = ACTIONS(2424),
    [anon_sym_sample] = ACTIONS(2424),
    [anon_sym_linear] = ACTIONS(2424),
    [anon_sym_snorm] = ACTIONS(2424),
    [anon_sym_unorm] = ACTIONS(2424),
    [anon_sym_point] = ACTIONS(2424),
    [anon_sym_line] = ACTIONS(2424),
    [anon_sym_triangleadj] = ACTIONS(2424),
    [anon_sym_lineadj] = ACTIONS(2424),
    [anon_sym_triangle] = ACTIONS(2424),
    [anon_sym_cbuffer] = ACTIONS(2424),
  },
  [667] = {
    [sym_identifier] = ACTIONS(2316),
    [aux_sym_preproc_include_token1] = ACTIONS(2316),
    [aux_sym_preproc_def_token1] = ACTIONS(2316),
    [aux_sym_preproc_if_token1] = ACTIONS(2316),
    [aux_sym_preproc_if_token2] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2316),
    [sym_preproc_directive] = ACTIONS(2316),
    [anon_sym_LPAREN2] = ACTIONS(2318),
    [anon_sym_BANG] = ACTIONS(2318),
    [anon_sym_TILDE] = ACTIONS(2318),
    [anon_sym_DASH] = ACTIONS(2316),
    [anon_sym_PLUS] = ACTIONS(2316),
    [anon_sym_STAR] = ACTIONS(2318),
    [anon_sym_AMP_AMP] = ACTIONS(2318),
    [anon_sym_AMP] = ACTIONS(2316),
    [anon_sym_SEMI] = ACTIONS(2318),
    [anon_sym___extension__] = ACTIONS(2316),
    [anon_sym_typedef] = ACTIONS(2316),
    [anon_sym_in] = ACTIONS(2316),
    [anon_sym_out] = ACTIONS(2316),
    [anon_sym_inout] = ACTIONS(2316),
    [anon_sym_extern] = ACTIONS(2316),
    [anon_sym___attribute__] = ACTIONS(2316),
    [anon_sym_COLON_COLON] = ACTIONS(2318),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2318),
    [anon_sym___declspec] = ACTIONS(2316),
    [anon_sym___based] = ACTIONS(2316),
    [anon_sym___cdecl] = ACTIONS(2316),
    [anon_sym___clrcall] = ACTIONS(2316),
    [anon_sym___stdcall] = ACTIONS(2316),
    [anon_sym___fastcall] = ACTIONS(2316),
    [anon_sym___thiscall] = ACTIONS(2316),
    [anon_sym___vectorcall] = ACTIONS(2316),
    [anon_sym_LBRACE] = ACTIONS(2318),
    [anon_sym_signed] = ACTIONS(2316),
    [anon_sym_unsigned] = ACTIONS(2316),
    [anon_sym_long] = ACTIONS(2316),
    [anon_sym_short] = ACTIONS(2316),
    [anon_sym_LBRACK] = ACTIONS(2316),
    [anon_sym_static] = ACTIONS(2316),
    [anon_sym_register] = ACTIONS(2316),
    [anon_sym_inline] = ACTIONS(2316),
    [anon_sym___inline] = ACTIONS(2316),
    [anon_sym___inline__] = ACTIONS(2316),
    [anon_sym___forceinline] = ACTIONS(2316),
    [anon_sym_thread_local] = ACTIONS(2316),
    [anon_sym___thread] = ACTIONS(2316),
    [anon_sym_const] = ACTIONS(2316),
    [anon_sym_constexpr] = ACTIONS(2316),
    [anon_sym_volatile] = ACTIONS(2316),
    [anon_sym_restrict] = ACTIONS(2316),
    [anon_sym___restrict__] = ACTIONS(2316),
    [anon_sym__Atomic] = ACTIONS(2316),
    [anon_sym__Noreturn] = ACTIONS(2316),
    [anon_sym_noreturn] = ACTIONS(2316),
    [anon_sym_mutable] = ACTIONS(2316),
    [anon_sym_constinit] = ACTIONS(2316),
    [anon_sym_consteval] = ACTIONS(2316),
    [anon_sym_alignas] = ACTIONS(2316),
    [anon_sym__Alignas] = ACTIONS(2316),
    [sym_primitive_type] = ACTIONS(2316),
    [anon_sym_enum] = ACTIONS(2316),
    [anon_sym_class] = ACTIONS(2316),
    [anon_sym_struct] = ACTIONS(2316),
    [anon_sym_union] = ACTIONS(2316),
    [anon_sym_if] = ACTIONS(2316),
    [anon_sym_switch] = ACTIONS(2316),
    [anon_sym_case] = ACTIONS(2316),
    [anon_sym_default] = ACTIONS(2316),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2316),
    [anon_sym_return] = ACTIONS(2316),
    [anon_sym_break] = ACTIONS(2316),
    [anon_sym_continue] = ACTIONS(2316),
    [anon_sym_goto] = ACTIONS(2316),
    [anon_sym___try] = ACTIONS(2316),
    [anon_sym___leave] = ACTIONS(2316),
    [anon_sym_not] = ACTIONS(2316),
    [anon_sym_compl] = ACTIONS(2316),
    [anon_sym_DASH_DASH] = ACTIONS(2318),
    [anon_sym_PLUS_PLUS] = ACTIONS(2318),
    [anon_sym_sizeof] = ACTIONS(2316),
    [anon_sym___alignof__] = ACTIONS(2316),
    [anon_sym___alignof] = ACTIONS(2316),
    [anon_sym__alignof] = ACTIONS(2316),
    [anon_sym_alignof] = ACTIONS(2316),
    [anon_sym__Alignof] = ACTIONS(2316),
    [anon_sym_offsetof] = ACTIONS(2316),
    [anon_sym__Generic] = ACTIONS(2316),
    [anon_sym_asm] = ACTIONS(2316),
    [anon_sym___asm__] = ACTIONS(2316),
    [sym_number_literal] = ACTIONS(2318),
    [anon_sym_L_SQUOTE] = ACTIONS(2318),
    [anon_sym_u_SQUOTE] = ACTIONS(2318),
    [anon_sym_U_SQUOTE] = ACTIONS(2318),
    [anon_sym_u8_SQUOTE] = ACTIONS(2318),
    [anon_sym_SQUOTE] = ACTIONS(2318),
    [anon_sym_L_DQUOTE] = ACTIONS(2318),
    [anon_sym_u_DQUOTE] = ACTIONS(2318),
    [anon_sym_U_DQUOTE] = ACTIONS(2318),
    [anon_sym_u8_DQUOTE] = ACTIONS(2318),
    [anon_sym_DQUOTE] = ACTIONS(2318),
    [sym_true] = ACTIONS(2316),
    [sym_false] = ACTIONS(2316),
    [anon_sym_NULL] = ACTIONS(2316),
    [anon_sym_nullptr] = ACTIONS(2316),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2316),
    [anon_sym_decltype] = ACTIONS(2316),
    [sym_virtual] = ACTIONS(2316),
    [anon_sym_explicit] = ACTIONS(2316),
    [anon_sym_typename] = ACTIONS(2316),
    [anon_sym_template] = ACTIONS(2316),
    [anon_sym_operator] = ACTIONS(2316),
    [anon_sym_try] = ACTIONS(2316),
    [anon_sym_delete] = ACTIONS(2316),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_namespace] = ACTIONS(2316),
    [anon_sym_using] = ACTIONS(2316),
    [anon_sym_static_assert] = ACTIONS(2316),
    [anon_sym_concept] = ACTIONS(2316),
    [anon_sym_co_return] = ACTIONS(2316),
    [anon_sym_co_yield] = ACTIONS(2316),
    [anon_sym_R_DQUOTE] = ACTIONS(2318),
    [anon_sym_LR_DQUOTE] = ACTIONS(2318),
    [anon_sym_uR_DQUOTE] = ACTIONS(2318),
    [anon_sym_UR_DQUOTE] = ACTIONS(2318),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2318),
    [anon_sym_co_await] = ACTIONS(2316),
    [anon_sym_new] = ACTIONS(2316),
    [anon_sym_requires] = ACTIONS(2316),
    [sym_this] = ACTIONS(2316),
    [anon_sym_discard] = ACTIONS(2316),
    [anon_sym_precise] = ACTIONS(2316),
    [anon_sym_shared] = ACTIONS(2316),
    [anon_sym_groupshared] = ACTIONS(2316),
    [anon_sym_uniform] = ACTIONS(2316),
    [anon_sym_row_major] = ACTIONS(2316),
    [anon_sym_column_major] = ACTIONS(2316),
    [anon_sym_globallycoherent] = ACTIONS(2316),
    [anon_sym_centroid] = ACTIONS(2316),
    [anon_sym_noperspective] = ACTIONS(2316),
    [anon_sym_nointerpolation] = ACTIONS(2316),
    [anon_sym_sample] = ACTIONS(2316),
    [anon_sym_linear] = ACTIONS(2316),
    [anon_sym_snorm] = ACTIONS(2316),
    [anon_sym_unorm] = ACTIONS(2316),
    [anon_sym_point] = ACTIONS(2316),
    [anon_sym_line] = ACTIONS(2316),
    [anon_sym_triangleadj] = ACTIONS(2316),
    [anon_sym_lineadj] = ACTIONS(2316),
    [anon_sym_triangle] = ACTIONS(2316),
    [anon_sym_cbuffer] = ACTIONS(2316),
  },
  [668] = {
    [sym_identifier] = ACTIONS(2371),
    [aux_sym_preproc_include_token1] = ACTIONS(2371),
    [aux_sym_preproc_def_token1] = ACTIONS(2371),
    [aux_sym_preproc_if_token1] = ACTIONS(2371),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2371),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2371),
    [sym_preproc_directive] = ACTIONS(2371),
    [anon_sym_LPAREN2] = ACTIONS(2373),
    [anon_sym_BANG] = ACTIONS(2373),
    [anon_sym_TILDE] = ACTIONS(2373),
    [anon_sym_DASH] = ACTIONS(2371),
    [anon_sym_PLUS] = ACTIONS(2371),
    [anon_sym_STAR] = ACTIONS(2373),
    [anon_sym_AMP_AMP] = ACTIONS(2373),
    [anon_sym_AMP] = ACTIONS(2371),
    [anon_sym_SEMI] = ACTIONS(2373),
    [anon_sym___extension__] = ACTIONS(2371),
    [anon_sym_typedef] = ACTIONS(2371),
    [anon_sym_in] = ACTIONS(2371),
    [anon_sym_out] = ACTIONS(2371),
    [anon_sym_inout] = ACTIONS(2371),
    [anon_sym_extern] = ACTIONS(2371),
    [anon_sym___attribute__] = ACTIONS(2371),
    [anon_sym_COLON_COLON] = ACTIONS(2373),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2373),
    [anon_sym___declspec] = ACTIONS(2371),
    [anon_sym___based] = ACTIONS(2371),
    [anon_sym___cdecl] = ACTIONS(2371),
    [anon_sym___clrcall] = ACTIONS(2371),
    [anon_sym___stdcall] = ACTIONS(2371),
    [anon_sym___fastcall] = ACTIONS(2371),
    [anon_sym___thiscall] = ACTIONS(2371),
    [anon_sym___vectorcall] = ACTIONS(2371),
    [anon_sym_LBRACE] = ACTIONS(2373),
    [anon_sym_RBRACE] = ACTIONS(2373),
    [anon_sym_signed] = ACTIONS(2371),
    [anon_sym_unsigned] = ACTIONS(2371),
    [anon_sym_long] = ACTIONS(2371),
    [anon_sym_short] = ACTIONS(2371),
    [anon_sym_LBRACK] = ACTIONS(2371),
    [anon_sym_static] = ACTIONS(2371),
    [anon_sym_register] = ACTIONS(2371),
    [anon_sym_inline] = ACTIONS(2371),
    [anon_sym___inline] = ACTIONS(2371),
    [anon_sym___inline__] = ACTIONS(2371),
    [anon_sym___forceinline] = ACTIONS(2371),
    [anon_sym_thread_local] = ACTIONS(2371),
    [anon_sym___thread] = ACTIONS(2371),
    [anon_sym_const] = ACTIONS(2371),
    [anon_sym_constexpr] = ACTIONS(2371),
    [anon_sym_volatile] = ACTIONS(2371),
    [anon_sym_restrict] = ACTIONS(2371),
    [anon_sym___restrict__] = ACTIONS(2371),
    [anon_sym__Atomic] = ACTIONS(2371),
    [anon_sym__Noreturn] = ACTIONS(2371),
    [anon_sym_noreturn] = ACTIONS(2371),
    [anon_sym_mutable] = ACTIONS(2371),
    [anon_sym_constinit] = ACTIONS(2371),
    [anon_sym_consteval] = ACTIONS(2371),
    [anon_sym_alignas] = ACTIONS(2371),
    [anon_sym__Alignas] = ACTIONS(2371),
    [sym_primitive_type] = ACTIONS(2371),
    [anon_sym_enum] = ACTIONS(2371),
    [anon_sym_class] = ACTIONS(2371),
    [anon_sym_struct] = ACTIONS(2371),
    [anon_sym_union] = ACTIONS(2371),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_switch] = ACTIONS(2371),
    [anon_sym_case] = ACTIONS(2371),
    [anon_sym_default] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(2371),
    [anon_sym_do] = ACTIONS(2371),
    [anon_sym_for] = ACTIONS(2371),
    [anon_sym_return] = ACTIONS(2371),
    [anon_sym_break] = ACTIONS(2371),
    [anon_sym_continue] = ACTIONS(2371),
    [anon_sym_goto] = ACTIONS(2371),
    [anon_sym___try] = ACTIONS(2371),
    [anon_sym___leave] = ACTIONS(2371),
    [anon_sym_not] = ACTIONS(2371),
    [anon_sym_compl] = ACTIONS(2371),
    [anon_sym_DASH_DASH] = ACTIONS(2373),
    [anon_sym_PLUS_PLUS] = ACTIONS(2373),
    [anon_sym_sizeof] = ACTIONS(2371),
    [anon_sym___alignof__] = ACTIONS(2371),
    [anon_sym___alignof] = ACTIONS(2371),
    [anon_sym__alignof] = ACTIONS(2371),
    [anon_sym_alignof] = ACTIONS(2371),
    [anon_sym__Alignof] = ACTIONS(2371),
    [anon_sym_offsetof] = ACTIONS(2371),
    [anon_sym__Generic] = ACTIONS(2371),
    [anon_sym_asm] = ACTIONS(2371),
    [anon_sym___asm__] = ACTIONS(2371),
    [sym_number_literal] = ACTIONS(2373),
    [anon_sym_L_SQUOTE] = ACTIONS(2373),
    [anon_sym_u_SQUOTE] = ACTIONS(2373),
    [anon_sym_U_SQUOTE] = ACTIONS(2373),
    [anon_sym_u8_SQUOTE] = ACTIONS(2373),
    [anon_sym_SQUOTE] = ACTIONS(2373),
    [anon_sym_L_DQUOTE] = ACTIONS(2373),
    [anon_sym_u_DQUOTE] = ACTIONS(2373),
    [anon_sym_U_DQUOTE] = ACTIONS(2373),
    [anon_sym_u8_DQUOTE] = ACTIONS(2373),
    [anon_sym_DQUOTE] = ACTIONS(2373),
    [sym_true] = ACTIONS(2371),
    [sym_false] = ACTIONS(2371),
    [anon_sym_NULL] = ACTIONS(2371),
    [anon_sym_nullptr] = ACTIONS(2371),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2371),
    [anon_sym_decltype] = ACTIONS(2371),
    [sym_virtual] = ACTIONS(2371),
    [anon_sym_explicit] = ACTIONS(2371),
    [anon_sym_typename] = ACTIONS(2371),
    [anon_sym_template] = ACTIONS(2371),
    [anon_sym_operator] = ACTIONS(2371),
    [anon_sym_try] = ACTIONS(2371),
    [anon_sym_delete] = ACTIONS(2371),
    [anon_sym_throw] = ACTIONS(2371),
    [anon_sym_namespace] = ACTIONS(2371),
    [anon_sym_using] = ACTIONS(2371),
    [anon_sym_static_assert] = ACTIONS(2371),
    [anon_sym_concept] = ACTIONS(2371),
    [anon_sym_co_return] = ACTIONS(2371),
    [anon_sym_co_yield] = ACTIONS(2371),
    [anon_sym_R_DQUOTE] = ACTIONS(2373),
    [anon_sym_LR_DQUOTE] = ACTIONS(2373),
    [anon_sym_uR_DQUOTE] = ACTIONS(2373),
    [anon_sym_UR_DQUOTE] = ACTIONS(2373),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2373),
    [anon_sym_co_await] = ACTIONS(2371),
    [anon_sym_new] = ACTIONS(2371),
    [anon_sym_requires] = ACTIONS(2371),
    [sym_this] = ACTIONS(2371),
    [anon_sym_discard] = ACTIONS(2371),
    [anon_sym_precise] = ACTIONS(2371),
    [anon_sym_shared] = ACTIONS(2371),
    [anon_sym_groupshared] = ACTIONS(2371),
    [anon_sym_uniform] = ACTIONS(2371),
    [anon_sym_row_major] = ACTIONS(2371),
    [anon_sym_column_major] = ACTIONS(2371),
    [anon_sym_globallycoherent] = ACTIONS(2371),
    [anon_sym_centroid] = ACTIONS(2371),
    [anon_sym_noperspective] = ACTIONS(2371),
    [anon_sym_nointerpolation] = ACTIONS(2371),
    [anon_sym_sample] = ACTIONS(2371),
    [anon_sym_linear] = ACTIONS(2371),
    [anon_sym_snorm] = ACTIONS(2371),
    [anon_sym_unorm] = ACTIONS(2371),
    [anon_sym_point] = ACTIONS(2371),
    [anon_sym_line] = ACTIONS(2371),
    [anon_sym_triangleadj] = ACTIONS(2371),
    [anon_sym_lineadj] = ACTIONS(2371),
    [anon_sym_triangle] = ACTIONS(2371),
    [anon_sym_cbuffer] = ACTIONS(2371),
  },
  [669] = {
    [sym_identifier] = ACTIONS(2466),
    [aux_sym_preproc_include_token1] = ACTIONS(2466),
    [aux_sym_preproc_def_token1] = ACTIONS(2466),
    [aux_sym_preproc_if_token1] = ACTIONS(2466),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2466),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2466),
    [sym_preproc_directive] = ACTIONS(2466),
    [anon_sym_LPAREN2] = ACTIONS(2468),
    [anon_sym_BANG] = ACTIONS(2468),
    [anon_sym_TILDE] = ACTIONS(2468),
    [anon_sym_DASH] = ACTIONS(2466),
    [anon_sym_PLUS] = ACTIONS(2466),
    [anon_sym_STAR] = ACTIONS(2468),
    [anon_sym_AMP_AMP] = ACTIONS(2468),
    [anon_sym_AMP] = ACTIONS(2466),
    [anon_sym_SEMI] = ACTIONS(2468),
    [anon_sym___extension__] = ACTIONS(2466),
    [anon_sym_typedef] = ACTIONS(2466),
    [anon_sym_in] = ACTIONS(2466),
    [anon_sym_out] = ACTIONS(2466),
    [anon_sym_inout] = ACTIONS(2466),
    [anon_sym_extern] = ACTIONS(2466),
    [anon_sym___attribute__] = ACTIONS(2466),
    [anon_sym_COLON_COLON] = ACTIONS(2468),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2468),
    [anon_sym___declspec] = ACTIONS(2466),
    [anon_sym___based] = ACTIONS(2466),
    [anon_sym___cdecl] = ACTIONS(2466),
    [anon_sym___clrcall] = ACTIONS(2466),
    [anon_sym___stdcall] = ACTIONS(2466),
    [anon_sym___fastcall] = ACTIONS(2466),
    [anon_sym___thiscall] = ACTIONS(2466),
    [anon_sym___vectorcall] = ACTIONS(2466),
    [anon_sym_LBRACE] = ACTIONS(2468),
    [anon_sym_RBRACE] = ACTIONS(2468),
    [anon_sym_signed] = ACTIONS(2466),
    [anon_sym_unsigned] = ACTIONS(2466),
    [anon_sym_long] = ACTIONS(2466),
    [anon_sym_short] = ACTIONS(2466),
    [anon_sym_LBRACK] = ACTIONS(2466),
    [anon_sym_static] = ACTIONS(2466),
    [anon_sym_register] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2466),
    [anon_sym___inline] = ACTIONS(2466),
    [anon_sym___inline__] = ACTIONS(2466),
    [anon_sym___forceinline] = ACTIONS(2466),
    [anon_sym_thread_local] = ACTIONS(2466),
    [anon_sym___thread] = ACTIONS(2466),
    [anon_sym_const] = ACTIONS(2466),
    [anon_sym_constexpr] = ACTIONS(2466),
    [anon_sym_volatile] = ACTIONS(2466),
    [anon_sym_restrict] = ACTIONS(2466),
    [anon_sym___restrict__] = ACTIONS(2466),
    [anon_sym__Atomic] = ACTIONS(2466),
    [anon_sym__Noreturn] = ACTIONS(2466),
    [anon_sym_noreturn] = ACTIONS(2466),
    [anon_sym_mutable] = ACTIONS(2466),
    [anon_sym_constinit] = ACTIONS(2466),
    [anon_sym_consteval] = ACTIONS(2466),
    [anon_sym_alignas] = ACTIONS(2466),
    [anon_sym__Alignas] = ACTIONS(2466),
    [sym_primitive_type] = ACTIONS(2466),
    [anon_sym_enum] = ACTIONS(2466),
    [anon_sym_class] = ACTIONS(2466),
    [anon_sym_struct] = ACTIONS(2466),
    [anon_sym_union] = ACTIONS(2466),
    [anon_sym_if] = ACTIONS(2466),
    [anon_sym_switch] = ACTIONS(2466),
    [anon_sym_case] = ACTIONS(2466),
    [anon_sym_default] = ACTIONS(2466),
    [anon_sym_while] = ACTIONS(2466),
    [anon_sym_do] = ACTIONS(2466),
    [anon_sym_for] = ACTIONS(2466),
    [anon_sym_return] = ACTIONS(2466),
    [anon_sym_break] = ACTIONS(2466),
    [anon_sym_continue] = ACTIONS(2466),
    [anon_sym_goto] = ACTIONS(2466),
    [anon_sym___try] = ACTIONS(2466),
    [anon_sym___leave] = ACTIONS(2466),
    [anon_sym_not] = ACTIONS(2466),
    [anon_sym_compl] = ACTIONS(2466),
    [anon_sym_DASH_DASH] = ACTIONS(2468),
    [anon_sym_PLUS_PLUS] = ACTIONS(2468),
    [anon_sym_sizeof] = ACTIONS(2466),
    [anon_sym___alignof__] = ACTIONS(2466),
    [anon_sym___alignof] = ACTIONS(2466),
    [anon_sym__alignof] = ACTIONS(2466),
    [anon_sym_alignof] = ACTIONS(2466),
    [anon_sym__Alignof] = ACTIONS(2466),
    [anon_sym_offsetof] = ACTIONS(2466),
    [anon_sym__Generic] = ACTIONS(2466),
    [anon_sym_asm] = ACTIONS(2466),
    [anon_sym___asm__] = ACTIONS(2466),
    [sym_number_literal] = ACTIONS(2468),
    [anon_sym_L_SQUOTE] = ACTIONS(2468),
    [anon_sym_u_SQUOTE] = ACTIONS(2468),
    [anon_sym_U_SQUOTE] = ACTIONS(2468),
    [anon_sym_u8_SQUOTE] = ACTIONS(2468),
    [anon_sym_SQUOTE] = ACTIONS(2468),
    [anon_sym_L_DQUOTE] = ACTIONS(2468),
    [anon_sym_u_DQUOTE] = ACTIONS(2468),
    [anon_sym_U_DQUOTE] = ACTIONS(2468),
    [anon_sym_u8_DQUOTE] = ACTIONS(2468),
    [anon_sym_DQUOTE] = ACTIONS(2468),
    [sym_true] = ACTIONS(2466),
    [sym_false] = ACTIONS(2466),
    [anon_sym_NULL] = ACTIONS(2466),
    [anon_sym_nullptr] = ACTIONS(2466),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2466),
    [anon_sym_decltype] = ACTIONS(2466),
    [sym_virtual] = ACTIONS(2466),
    [anon_sym_explicit] = ACTIONS(2466),
    [anon_sym_typename] = ACTIONS(2466),
    [anon_sym_template] = ACTIONS(2466),
    [anon_sym_operator] = ACTIONS(2466),
    [anon_sym_try] = ACTIONS(2466),
    [anon_sym_delete] = ACTIONS(2466),
    [anon_sym_throw] = ACTIONS(2466),
    [anon_sym_namespace] = ACTIONS(2466),
    [anon_sym_using] = ACTIONS(2466),
    [anon_sym_static_assert] = ACTIONS(2466),
    [anon_sym_concept] = ACTIONS(2466),
    [anon_sym_co_return] = ACTIONS(2466),
    [anon_sym_co_yield] = ACTIONS(2466),
    [anon_sym_R_DQUOTE] = ACTIONS(2468),
    [anon_sym_LR_DQUOTE] = ACTIONS(2468),
    [anon_sym_uR_DQUOTE] = ACTIONS(2468),
    [anon_sym_UR_DQUOTE] = ACTIONS(2468),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2468),
    [anon_sym_co_await] = ACTIONS(2466),
    [anon_sym_new] = ACTIONS(2466),
    [anon_sym_requires] = ACTIONS(2466),
    [sym_this] = ACTIONS(2466),
    [anon_sym_discard] = ACTIONS(2466),
    [anon_sym_precise] = ACTIONS(2466),
    [anon_sym_shared] = ACTIONS(2466),
    [anon_sym_groupshared] = ACTIONS(2466),
    [anon_sym_uniform] = ACTIONS(2466),
    [anon_sym_row_major] = ACTIONS(2466),
    [anon_sym_column_major] = ACTIONS(2466),
    [anon_sym_globallycoherent] = ACTIONS(2466),
    [anon_sym_centroid] = ACTIONS(2466),
    [anon_sym_noperspective] = ACTIONS(2466),
    [anon_sym_nointerpolation] = ACTIONS(2466),
    [anon_sym_sample] = ACTIONS(2466),
    [anon_sym_linear] = ACTIONS(2466),
    [anon_sym_snorm] = ACTIONS(2466),
    [anon_sym_unorm] = ACTIONS(2466),
    [anon_sym_point] = ACTIONS(2466),
    [anon_sym_line] = ACTIONS(2466),
    [anon_sym_triangleadj] = ACTIONS(2466),
    [anon_sym_lineadj] = ACTIONS(2466),
    [anon_sym_triangle] = ACTIONS(2466),
    [anon_sym_cbuffer] = ACTIONS(2466),
  },
  [670] = {
    [sym_identifier] = ACTIONS(2375),
    [aux_sym_preproc_include_token1] = ACTIONS(2375),
    [aux_sym_preproc_def_token1] = ACTIONS(2375),
    [aux_sym_preproc_if_token1] = ACTIONS(2375),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2375),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2375),
    [sym_preproc_directive] = ACTIONS(2375),
    [anon_sym_LPAREN2] = ACTIONS(2377),
    [anon_sym_BANG] = ACTIONS(2377),
    [anon_sym_TILDE] = ACTIONS(2377),
    [anon_sym_DASH] = ACTIONS(2375),
    [anon_sym_PLUS] = ACTIONS(2375),
    [anon_sym_STAR] = ACTIONS(2377),
    [anon_sym_AMP_AMP] = ACTIONS(2377),
    [anon_sym_AMP] = ACTIONS(2375),
    [anon_sym_SEMI] = ACTIONS(2377),
    [anon_sym___extension__] = ACTIONS(2375),
    [anon_sym_typedef] = ACTIONS(2375),
    [anon_sym_in] = ACTIONS(2375),
    [anon_sym_out] = ACTIONS(2375),
    [anon_sym_inout] = ACTIONS(2375),
    [anon_sym_extern] = ACTIONS(2375),
    [anon_sym___attribute__] = ACTIONS(2375),
    [anon_sym_COLON_COLON] = ACTIONS(2377),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2377),
    [anon_sym___declspec] = ACTIONS(2375),
    [anon_sym___based] = ACTIONS(2375),
    [anon_sym___cdecl] = ACTIONS(2375),
    [anon_sym___clrcall] = ACTIONS(2375),
    [anon_sym___stdcall] = ACTIONS(2375),
    [anon_sym___fastcall] = ACTIONS(2375),
    [anon_sym___thiscall] = ACTIONS(2375),
    [anon_sym___vectorcall] = ACTIONS(2375),
    [anon_sym_LBRACE] = ACTIONS(2377),
    [anon_sym_RBRACE] = ACTIONS(2377),
    [anon_sym_signed] = ACTIONS(2375),
    [anon_sym_unsigned] = ACTIONS(2375),
    [anon_sym_long] = ACTIONS(2375),
    [anon_sym_short] = ACTIONS(2375),
    [anon_sym_LBRACK] = ACTIONS(2375),
    [anon_sym_static] = ACTIONS(2375),
    [anon_sym_register] = ACTIONS(2375),
    [anon_sym_inline] = ACTIONS(2375),
    [anon_sym___inline] = ACTIONS(2375),
    [anon_sym___inline__] = ACTIONS(2375),
    [anon_sym___forceinline] = ACTIONS(2375),
    [anon_sym_thread_local] = ACTIONS(2375),
    [anon_sym___thread] = ACTIONS(2375),
    [anon_sym_const] = ACTIONS(2375),
    [anon_sym_constexpr] = ACTIONS(2375),
    [anon_sym_volatile] = ACTIONS(2375),
    [anon_sym_restrict] = ACTIONS(2375),
    [anon_sym___restrict__] = ACTIONS(2375),
    [anon_sym__Atomic] = ACTIONS(2375),
    [anon_sym__Noreturn] = ACTIONS(2375),
    [anon_sym_noreturn] = ACTIONS(2375),
    [anon_sym_mutable] = ACTIONS(2375),
    [anon_sym_constinit] = ACTIONS(2375),
    [anon_sym_consteval] = ACTIONS(2375),
    [anon_sym_alignas] = ACTIONS(2375),
    [anon_sym__Alignas] = ACTIONS(2375),
    [sym_primitive_type] = ACTIONS(2375),
    [anon_sym_enum] = ACTIONS(2375),
    [anon_sym_class] = ACTIONS(2375),
    [anon_sym_struct] = ACTIONS(2375),
    [anon_sym_union] = ACTIONS(2375),
    [anon_sym_if] = ACTIONS(2375),
    [anon_sym_switch] = ACTIONS(2375),
    [anon_sym_case] = ACTIONS(2375),
    [anon_sym_default] = ACTIONS(2375),
    [anon_sym_while] = ACTIONS(2375),
    [anon_sym_do] = ACTIONS(2375),
    [anon_sym_for] = ACTIONS(2375),
    [anon_sym_return] = ACTIONS(2375),
    [anon_sym_break] = ACTIONS(2375),
    [anon_sym_continue] = ACTIONS(2375),
    [anon_sym_goto] = ACTIONS(2375),
    [anon_sym___try] = ACTIONS(2375),
    [anon_sym___leave] = ACTIONS(2375),
    [anon_sym_not] = ACTIONS(2375),
    [anon_sym_compl] = ACTIONS(2375),
    [anon_sym_DASH_DASH] = ACTIONS(2377),
    [anon_sym_PLUS_PLUS] = ACTIONS(2377),
    [anon_sym_sizeof] = ACTIONS(2375),
    [anon_sym___alignof__] = ACTIONS(2375),
    [anon_sym___alignof] = ACTIONS(2375),
    [anon_sym__alignof] = ACTIONS(2375),
    [anon_sym_alignof] = ACTIONS(2375),
    [anon_sym__Alignof] = ACTIONS(2375),
    [anon_sym_offsetof] = ACTIONS(2375),
    [anon_sym__Generic] = ACTIONS(2375),
    [anon_sym_asm] = ACTIONS(2375),
    [anon_sym___asm__] = ACTIONS(2375),
    [sym_number_literal] = ACTIONS(2377),
    [anon_sym_L_SQUOTE] = ACTIONS(2377),
    [anon_sym_u_SQUOTE] = ACTIONS(2377),
    [anon_sym_U_SQUOTE] = ACTIONS(2377),
    [anon_sym_u8_SQUOTE] = ACTIONS(2377),
    [anon_sym_SQUOTE] = ACTIONS(2377),
    [anon_sym_L_DQUOTE] = ACTIONS(2377),
    [anon_sym_u_DQUOTE] = ACTIONS(2377),
    [anon_sym_U_DQUOTE] = ACTIONS(2377),
    [anon_sym_u8_DQUOTE] = ACTIONS(2377),
    [anon_sym_DQUOTE] = ACTIONS(2377),
    [sym_true] = ACTIONS(2375),
    [sym_false] = ACTIONS(2375),
    [anon_sym_NULL] = ACTIONS(2375),
    [anon_sym_nullptr] = ACTIONS(2375),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2375),
    [anon_sym_decltype] = ACTIONS(2375),
    [sym_virtual] = ACTIONS(2375),
    [anon_sym_explicit] = ACTIONS(2375),
    [anon_sym_typename] = ACTIONS(2375),
    [anon_sym_template] = ACTIONS(2375),
    [anon_sym_operator] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_delete] = ACTIONS(2375),
    [anon_sym_throw] = ACTIONS(2375),
    [anon_sym_namespace] = ACTIONS(2375),
    [anon_sym_using] = ACTIONS(2375),
    [anon_sym_static_assert] = ACTIONS(2375),
    [anon_sym_concept] = ACTIONS(2375),
    [anon_sym_co_return] = ACTIONS(2375),
    [anon_sym_co_yield] = ACTIONS(2375),
    [anon_sym_R_DQUOTE] = ACTIONS(2377),
    [anon_sym_LR_DQUOTE] = ACTIONS(2377),
    [anon_sym_uR_DQUOTE] = ACTIONS(2377),
    [anon_sym_UR_DQUOTE] = ACTIONS(2377),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2377),
    [anon_sym_co_await] = ACTIONS(2375),
    [anon_sym_new] = ACTIONS(2375),
    [anon_sym_requires] = ACTIONS(2375),
    [sym_this] = ACTIONS(2375),
    [anon_sym_discard] = ACTIONS(2375),
    [anon_sym_precise] = ACTIONS(2375),
    [anon_sym_shared] = ACTIONS(2375),
    [anon_sym_groupshared] = ACTIONS(2375),
    [anon_sym_uniform] = ACTIONS(2375),
    [anon_sym_row_major] = ACTIONS(2375),
    [anon_sym_column_major] = ACTIONS(2375),
    [anon_sym_globallycoherent] = ACTIONS(2375),
    [anon_sym_centroid] = ACTIONS(2375),
    [anon_sym_noperspective] = ACTIONS(2375),
    [anon_sym_nointerpolation] = ACTIONS(2375),
    [anon_sym_sample] = ACTIONS(2375),
    [anon_sym_linear] = ACTIONS(2375),
    [anon_sym_snorm] = ACTIONS(2375),
    [anon_sym_unorm] = ACTIONS(2375),
    [anon_sym_point] = ACTIONS(2375),
    [anon_sym_line] = ACTIONS(2375),
    [anon_sym_triangleadj] = ACTIONS(2375),
    [anon_sym_lineadj] = ACTIONS(2375),
    [anon_sym_triangle] = ACTIONS(2375),
    [anon_sym_cbuffer] = ACTIONS(2375),
  },
  [671] = {
    [sym_identifier] = ACTIONS(2490),
    [aux_sym_preproc_include_token1] = ACTIONS(2490),
    [aux_sym_preproc_def_token1] = ACTIONS(2490),
    [aux_sym_preproc_if_token1] = ACTIONS(2490),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2490),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2490),
    [sym_preproc_directive] = ACTIONS(2490),
    [anon_sym_LPAREN2] = ACTIONS(2492),
    [anon_sym_BANG] = ACTIONS(2492),
    [anon_sym_TILDE] = ACTIONS(2492),
    [anon_sym_DASH] = ACTIONS(2490),
    [anon_sym_PLUS] = ACTIONS(2490),
    [anon_sym_STAR] = ACTIONS(2492),
    [anon_sym_AMP_AMP] = ACTIONS(2492),
    [anon_sym_AMP] = ACTIONS(2490),
    [anon_sym_SEMI] = ACTIONS(2492),
    [anon_sym___extension__] = ACTIONS(2490),
    [anon_sym_typedef] = ACTIONS(2490),
    [anon_sym_in] = ACTIONS(2490),
    [anon_sym_out] = ACTIONS(2490),
    [anon_sym_inout] = ACTIONS(2490),
    [anon_sym_extern] = ACTIONS(2490),
    [anon_sym___attribute__] = ACTIONS(2490),
    [anon_sym_COLON_COLON] = ACTIONS(2492),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2492),
    [anon_sym___declspec] = ACTIONS(2490),
    [anon_sym___based] = ACTIONS(2490),
    [anon_sym___cdecl] = ACTIONS(2490),
    [anon_sym___clrcall] = ACTIONS(2490),
    [anon_sym___stdcall] = ACTIONS(2490),
    [anon_sym___fastcall] = ACTIONS(2490),
    [anon_sym___thiscall] = ACTIONS(2490),
    [anon_sym___vectorcall] = ACTIONS(2490),
    [anon_sym_LBRACE] = ACTIONS(2492),
    [anon_sym_RBRACE] = ACTIONS(2492),
    [anon_sym_signed] = ACTIONS(2490),
    [anon_sym_unsigned] = ACTIONS(2490),
    [anon_sym_long] = ACTIONS(2490),
    [anon_sym_short] = ACTIONS(2490),
    [anon_sym_LBRACK] = ACTIONS(2490),
    [anon_sym_static] = ACTIONS(2490),
    [anon_sym_register] = ACTIONS(2490),
    [anon_sym_inline] = ACTIONS(2490),
    [anon_sym___inline] = ACTIONS(2490),
    [anon_sym___inline__] = ACTIONS(2490),
    [anon_sym___forceinline] = ACTIONS(2490),
    [anon_sym_thread_local] = ACTIONS(2490),
    [anon_sym___thread] = ACTIONS(2490),
    [anon_sym_const] = ACTIONS(2490),
    [anon_sym_constexpr] = ACTIONS(2490),
    [anon_sym_volatile] = ACTIONS(2490),
    [anon_sym_restrict] = ACTIONS(2490),
    [anon_sym___restrict__] = ACTIONS(2490),
    [anon_sym__Atomic] = ACTIONS(2490),
    [anon_sym__Noreturn] = ACTIONS(2490),
    [anon_sym_noreturn] = ACTIONS(2490),
    [anon_sym_mutable] = ACTIONS(2490),
    [anon_sym_constinit] = ACTIONS(2490),
    [anon_sym_consteval] = ACTIONS(2490),
    [anon_sym_alignas] = ACTIONS(2490),
    [anon_sym__Alignas] = ACTIONS(2490),
    [sym_primitive_type] = ACTIONS(2490),
    [anon_sym_enum] = ACTIONS(2490),
    [anon_sym_class] = ACTIONS(2490),
    [anon_sym_struct] = ACTIONS(2490),
    [anon_sym_union] = ACTIONS(2490),
    [anon_sym_if] = ACTIONS(2490),
    [anon_sym_switch] = ACTIONS(2490),
    [anon_sym_case] = ACTIONS(2490),
    [anon_sym_default] = ACTIONS(2490),
    [anon_sym_while] = ACTIONS(2490),
    [anon_sym_do] = ACTIONS(2490),
    [anon_sym_for] = ACTIONS(2490),
    [anon_sym_return] = ACTIONS(2490),
    [anon_sym_break] = ACTIONS(2490),
    [anon_sym_continue] = ACTIONS(2490),
    [anon_sym_goto] = ACTIONS(2490),
    [anon_sym___try] = ACTIONS(2490),
    [anon_sym___leave] = ACTIONS(2490),
    [anon_sym_not] = ACTIONS(2490),
    [anon_sym_compl] = ACTIONS(2490),
    [anon_sym_DASH_DASH] = ACTIONS(2492),
    [anon_sym_PLUS_PLUS] = ACTIONS(2492),
    [anon_sym_sizeof] = ACTIONS(2490),
    [anon_sym___alignof__] = ACTIONS(2490),
    [anon_sym___alignof] = ACTIONS(2490),
    [anon_sym__alignof] = ACTIONS(2490),
    [anon_sym_alignof] = ACTIONS(2490),
    [anon_sym__Alignof] = ACTIONS(2490),
    [anon_sym_offsetof] = ACTIONS(2490),
    [anon_sym__Generic] = ACTIONS(2490),
    [anon_sym_asm] = ACTIONS(2490),
    [anon_sym___asm__] = ACTIONS(2490),
    [sym_number_literal] = ACTIONS(2492),
    [anon_sym_L_SQUOTE] = ACTIONS(2492),
    [anon_sym_u_SQUOTE] = ACTIONS(2492),
    [anon_sym_U_SQUOTE] = ACTIONS(2492),
    [anon_sym_u8_SQUOTE] = ACTIONS(2492),
    [anon_sym_SQUOTE] = ACTIONS(2492),
    [anon_sym_L_DQUOTE] = ACTIONS(2492),
    [anon_sym_u_DQUOTE] = ACTIONS(2492),
    [anon_sym_U_DQUOTE] = ACTIONS(2492),
    [anon_sym_u8_DQUOTE] = ACTIONS(2492),
    [anon_sym_DQUOTE] = ACTIONS(2492),
    [sym_true] = ACTIONS(2490),
    [sym_false] = ACTIONS(2490),
    [anon_sym_NULL] = ACTIONS(2490),
    [anon_sym_nullptr] = ACTIONS(2490),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2490),
    [anon_sym_decltype] = ACTIONS(2490),
    [sym_virtual] = ACTIONS(2490),
    [anon_sym_explicit] = ACTIONS(2490),
    [anon_sym_typename] = ACTIONS(2490),
    [anon_sym_template] = ACTIONS(2490),
    [anon_sym_operator] = ACTIONS(2490),
    [anon_sym_try] = ACTIONS(2490),
    [anon_sym_delete] = ACTIONS(2490),
    [anon_sym_throw] = ACTIONS(2490),
    [anon_sym_namespace] = ACTIONS(2490),
    [anon_sym_using] = ACTIONS(2490),
    [anon_sym_static_assert] = ACTIONS(2490),
    [anon_sym_concept] = ACTIONS(2490),
    [anon_sym_co_return] = ACTIONS(2490),
    [anon_sym_co_yield] = ACTIONS(2490),
    [anon_sym_R_DQUOTE] = ACTIONS(2492),
    [anon_sym_LR_DQUOTE] = ACTIONS(2492),
    [anon_sym_uR_DQUOTE] = ACTIONS(2492),
    [anon_sym_UR_DQUOTE] = ACTIONS(2492),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2492),
    [anon_sym_co_await] = ACTIONS(2490),
    [anon_sym_new] = ACTIONS(2490),
    [anon_sym_requires] = ACTIONS(2490),
    [sym_this] = ACTIONS(2490),
    [anon_sym_discard] = ACTIONS(2490),
    [anon_sym_precise] = ACTIONS(2490),
    [anon_sym_shared] = ACTIONS(2490),
    [anon_sym_groupshared] = ACTIONS(2490),
    [anon_sym_uniform] = ACTIONS(2490),
    [anon_sym_row_major] = ACTIONS(2490),
    [anon_sym_column_major] = ACTIONS(2490),
    [anon_sym_globallycoherent] = ACTIONS(2490),
    [anon_sym_centroid] = ACTIONS(2490),
    [anon_sym_noperspective] = ACTIONS(2490),
    [anon_sym_nointerpolation] = ACTIONS(2490),
    [anon_sym_sample] = ACTIONS(2490),
    [anon_sym_linear] = ACTIONS(2490),
    [anon_sym_snorm] = ACTIONS(2490),
    [anon_sym_unorm] = ACTIONS(2490),
    [anon_sym_point] = ACTIONS(2490),
    [anon_sym_line] = ACTIONS(2490),
    [anon_sym_triangleadj] = ACTIONS(2490),
    [anon_sym_lineadj] = ACTIONS(2490),
    [anon_sym_triangle] = ACTIONS(2490),
    [anon_sym_cbuffer] = ACTIONS(2490),
  },
  [672] = {
    [sym_identifier] = ACTIONS(2379),
    [aux_sym_preproc_include_token1] = ACTIONS(2379),
    [aux_sym_preproc_def_token1] = ACTIONS(2379),
    [aux_sym_preproc_if_token1] = ACTIONS(2379),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2379),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2379),
    [sym_preproc_directive] = ACTIONS(2379),
    [anon_sym_LPAREN2] = ACTIONS(2381),
    [anon_sym_BANG] = ACTIONS(2381),
    [anon_sym_TILDE] = ACTIONS(2381),
    [anon_sym_DASH] = ACTIONS(2379),
    [anon_sym_PLUS] = ACTIONS(2379),
    [anon_sym_STAR] = ACTIONS(2381),
    [anon_sym_AMP_AMP] = ACTIONS(2381),
    [anon_sym_AMP] = ACTIONS(2379),
    [anon_sym_SEMI] = ACTIONS(2381),
    [anon_sym___extension__] = ACTIONS(2379),
    [anon_sym_typedef] = ACTIONS(2379),
    [anon_sym_in] = ACTIONS(2379),
    [anon_sym_out] = ACTIONS(2379),
    [anon_sym_inout] = ACTIONS(2379),
    [anon_sym_extern] = ACTIONS(2379),
    [anon_sym___attribute__] = ACTIONS(2379),
    [anon_sym_COLON_COLON] = ACTIONS(2381),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2381),
    [anon_sym___declspec] = ACTIONS(2379),
    [anon_sym___based] = ACTIONS(2379),
    [anon_sym___cdecl] = ACTIONS(2379),
    [anon_sym___clrcall] = ACTIONS(2379),
    [anon_sym___stdcall] = ACTIONS(2379),
    [anon_sym___fastcall] = ACTIONS(2379),
    [anon_sym___thiscall] = ACTIONS(2379),
    [anon_sym___vectorcall] = ACTIONS(2379),
    [anon_sym_LBRACE] = ACTIONS(2381),
    [anon_sym_RBRACE] = ACTIONS(2381),
    [anon_sym_signed] = ACTIONS(2379),
    [anon_sym_unsigned] = ACTIONS(2379),
    [anon_sym_long] = ACTIONS(2379),
    [anon_sym_short] = ACTIONS(2379),
    [anon_sym_LBRACK] = ACTIONS(2379),
    [anon_sym_static] = ACTIONS(2379),
    [anon_sym_register] = ACTIONS(2379),
    [anon_sym_inline] = ACTIONS(2379),
    [anon_sym___inline] = ACTIONS(2379),
    [anon_sym___inline__] = ACTIONS(2379),
    [anon_sym___forceinline] = ACTIONS(2379),
    [anon_sym_thread_local] = ACTIONS(2379),
    [anon_sym___thread] = ACTIONS(2379),
    [anon_sym_const] = ACTIONS(2379),
    [anon_sym_constexpr] = ACTIONS(2379),
    [anon_sym_volatile] = ACTIONS(2379),
    [anon_sym_restrict] = ACTIONS(2379),
    [anon_sym___restrict__] = ACTIONS(2379),
    [anon_sym__Atomic] = ACTIONS(2379),
    [anon_sym__Noreturn] = ACTIONS(2379),
    [anon_sym_noreturn] = ACTIONS(2379),
    [anon_sym_mutable] = ACTIONS(2379),
    [anon_sym_constinit] = ACTIONS(2379),
    [anon_sym_consteval] = ACTIONS(2379),
    [anon_sym_alignas] = ACTIONS(2379),
    [anon_sym__Alignas] = ACTIONS(2379),
    [sym_primitive_type] = ACTIONS(2379),
    [anon_sym_enum] = ACTIONS(2379),
    [anon_sym_class] = ACTIONS(2379),
    [anon_sym_struct] = ACTIONS(2379),
    [anon_sym_union] = ACTIONS(2379),
    [anon_sym_if] = ACTIONS(2379),
    [anon_sym_switch] = ACTIONS(2379),
    [anon_sym_case] = ACTIONS(2379),
    [anon_sym_default] = ACTIONS(2379),
    [anon_sym_while] = ACTIONS(2379),
    [anon_sym_do] = ACTIONS(2379),
    [anon_sym_for] = ACTIONS(2379),
    [anon_sym_return] = ACTIONS(2379),
    [anon_sym_break] = ACTIONS(2379),
    [anon_sym_continue] = ACTIONS(2379),
    [anon_sym_goto] = ACTIONS(2379),
    [anon_sym___try] = ACTIONS(2379),
    [anon_sym___leave] = ACTIONS(2379),
    [anon_sym_not] = ACTIONS(2379),
    [anon_sym_compl] = ACTIONS(2379),
    [anon_sym_DASH_DASH] = ACTIONS(2381),
    [anon_sym_PLUS_PLUS] = ACTIONS(2381),
    [anon_sym_sizeof] = ACTIONS(2379),
    [anon_sym___alignof__] = ACTIONS(2379),
    [anon_sym___alignof] = ACTIONS(2379),
    [anon_sym__alignof] = ACTIONS(2379),
    [anon_sym_alignof] = ACTIONS(2379),
    [anon_sym__Alignof] = ACTIONS(2379),
    [anon_sym_offsetof] = ACTIONS(2379),
    [anon_sym__Generic] = ACTIONS(2379),
    [anon_sym_asm] = ACTIONS(2379),
    [anon_sym___asm__] = ACTIONS(2379),
    [sym_number_literal] = ACTIONS(2381),
    [anon_sym_L_SQUOTE] = ACTIONS(2381),
    [anon_sym_u_SQUOTE] = ACTIONS(2381),
    [anon_sym_U_SQUOTE] = ACTIONS(2381),
    [anon_sym_u8_SQUOTE] = ACTIONS(2381),
    [anon_sym_SQUOTE] = ACTIONS(2381),
    [anon_sym_L_DQUOTE] = ACTIONS(2381),
    [anon_sym_u_DQUOTE] = ACTIONS(2381),
    [anon_sym_U_DQUOTE] = ACTIONS(2381),
    [anon_sym_u8_DQUOTE] = ACTIONS(2381),
    [anon_sym_DQUOTE] = ACTIONS(2381),
    [sym_true] = ACTIONS(2379),
    [sym_false] = ACTIONS(2379),
    [anon_sym_NULL] = ACTIONS(2379),
    [anon_sym_nullptr] = ACTIONS(2379),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2379),
    [anon_sym_decltype] = ACTIONS(2379),
    [sym_virtual] = ACTIONS(2379),
    [anon_sym_explicit] = ACTIONS(2379),
    [anon_sym_typename] = ACTIONS(2379),
    [anon_sym_template] = ACTIONS(2379),
    [anon_sym_operator] = ACTIONS(2379),
    [anon_sym_try] = ACTIONS(2379),
    [anon_sym_delete] = ACTIONS(2379),
    [anon_sym_throw] = ACTIONS(2379),
    [anon_sym_namespace] = ACTIONS(2379),
    [anon_sym_using] = ACTIONS(2379),
    [anon_sym_static_assert] = ACTIONS(2379),
    [anon_sym_concept] = ACTIONS(2379),
    [anon_sym_co_return] = ACTIONS(2379),
    [anon_sym_co_yield] = ACTIONS(2379),
    [anon_sym_R_DQUOTE] = ACTIONS(2381),
    [anon_sym_LR_DQUOTE] = ACTIONS(2381),
    [anon_sym_uR_DQUOTE] = ACTIONS(2381),
    [anon_sym_UR_DQUOTE] = ACTIONS(2381),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2381),
    [anon_sym_co_await] = ACTIONS(2379),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_requires] = ACTIONS(2379),
    [sym_this] = ACTIONS(2379),
    [anon_sym_discard] = ACTIONS(2379),
    [anon_sym_precise] = ACTIONS(2379),
    [anon_sym_shared] = ACTIONS(2379),
    [anon_sym_groupshared] = ACTIONS(2379),
    [anon_sym_uniform] = ACTIONS(2379),
    [anon_sym_row_major] = ACTIONS(2379),
    [anon_sym_column_major] = ACTIONS(2379),
    [anon_sym_globallycoherent] = ACTIONS(2379),
    [anon_sym_centroid] = ACTIONS(2379),
    [anon_sym_noperspective] = ACTIONS(2379),
    [anon_sym_nointerpolation] = ACTIONS(2379),
    [anon_sym_sample] = ACTIONS(2379),
    [anon_sym_linear] = ACTIONS(2379),
    [anon_sym_snorm] = ACTIONS(2379),
    [anon_sym_unorm] = ACTIONS(2379),
    [anon_sym_point] = ACTIONS(2379),
    [anon_sym_line] = ACTIONS(2379),
    [anon_sym_triangleadj] = ACTIONS(2379),
    [anon_sym_lineadj] = ACTIONS(2379),
    [anon_sym_triangle] = ACTIONS(2379),
    [anon_sym_cbuffer] = ACTIONS(2379),
  },
  [673] = {
    [sym_identifier] = ACTIONS(2308),
    [aux_sym_preproc_include_token1] = ACTIONS(2308),
    [aux_sym_preproc_def_token1] = ACTIONS(2308),
    [aux_sym_preproc_if_token1] = ACTIONS(2308),
    [aux_sym_preproc_if_token2] = ACTIONS(2308),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2308),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2308),
    [sym_preproc_directive] = ACTIONS(2308),
    [anon_sym_LPAREN2] = ACTIONS(2310),
    [anon_sym_BANG] = ACTIONS(2310),
    [anon_sym_TILDE] = ACTIONS(2310),
    [anon_sym_DASH] = ACTIONS(2308),
    [anon_sym_PLUS] = ACTIONS(2308),
    [anon_sym_STAR] = ACTIONS(2310),
    [anon_sym_AMP_AMP] = ACTIONS(2310),
    [anon_sym_AMP] = ACTIONS(2308),
    [anon_sym_SEMI] = ACTIONS(2310),
    [anon_sym___extension__] = ACTIONS(2308),
    [anon_sym_typedef] = ACTIONS(2308),
    [anon_sym_in] = ACTIONS(2308),
    [anon_sym_out] = ACTIONS(2308),
    [anon_sym_inout] = ACTIONS(2308),
    [anon_sym_extern] = ACTIONS(2308),
    [anon_sym___attribute__] = ACTIONS(2308),
    [anon_sym_COLON_COLON] = ACTIONS(2310),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2310),
    [anon_sym___declspec] = ACTIONS(2308),
    [anon_sym___based] = ACTIONS(2308),
    [anon_sym___cdecl] = ACTIONS(2308),
    [anon_sym___clrcall] = ACTIONS(2308),
    [anon_sym___stdcall] = ACTIONS(2308),
    [anon_sym___fastcall] = ACTIONS(2308),
    [anon_sym___thiscall] = ACTIONS(2308),
    [anon_sym___vectorcall] = ACTIONS(2308),
    [anon_sym_LBRACE] = ACTIONS(2310),
    [anon_sym_signed] = ACTIONS(2308),
    [anon_sym_unsigned] = ACTIONS(2308),
    [anon_sym_long] = ACTIONS(2308),
    [anon_sym_short] = ACTIONS(2308),
    [anon_sym_LBRACK] = ACTIONS(2308),
    [anon_sym_static] = ACTIONS(2308),
    [anon_sym_register] = ACTIONS(2308),
    [anon_sym_inline] = ACTIONS(2308),
    [anon_sym___inline] = ACTIONS(2308),
    [anon_sym___inline__] = ACTIONS(2308),
    [anon_sym___forceinline] = ACTIONS(2308),
    [anon_sym_thread_local] = ACTIONS(2308),
    [anon_sym___thread] = ACTIONS(2308),
    [anon_sym_const] = ACTIONS(2308),
    [anon_sym_constexpr] = ACTIONS(2308),
    [anon_sym_volatile] = ACTIONS(2308),
    [anon_sym_restrict] = ACTIONS(2308),
    [anon_sym___restrict__] = ACTIONS(2308),
    [anon_sym__Atomic] = ACTIONS(2308),
    [anon_sym__Noreturn] = ACTIONS(2308),
    [anon_sym_noreturn] = ACTIONS(2308),
    [anon_sym_mutable] = ACTIONS(2308),
    [anon_sym_constinit] = ACTIONS(2308),
    [anon_sym_consteval] = ACTIONS(2308),
    [anon_sym_alignas] = ACTIONS(2308),
    [anon_sym__Alignas] = ACTIONS(2308),
    [sym_primitive_type] = ACTIONS(2308),
    [anon_sym_enum] = ACTIONS(2308),
    [anon_sym_class] = ACTIONS(2308),
    [anon_sym_struct] = ACTIONS(2308),
    [anon_sym_union] = ACTIONS(2308),
    [anon_sym_if] = ACTIONS(2308),
    [anon_sym_switch] = ACTIONS(2308),
    [anon_sym_case] = ACTIONS(2308),
    [anon_sym_default] = ACTIONS(2308),
    [anon_sym_while] = ACTIONS(2308),
    [anon_sym_do] = ACTIONS(2308),
    [anon_sym_for] = ACTIONS(2308),
    [anon_sym_return] = ACTIONS(2308),
    [anon_sym_break] = ACTIONS(2308),
    [anon_sym_continue] = ACTIONS(2308),
    [anon_sym_goto] = ACTIONS(2308),
    [anon_sym___try] = ACTIONS(2308),
    [anon_sym___leave] = ACTIONS(2308),
    [anon_sym_not] = ACTIONS(2308),
    [anon_sym_compl] = ACTIONS(2308),
    [anon_sym_DASH_DASH] = ACTIONS(2310),
    [anon_sym_PLUS_PLUS] = ACTIONS(2310),
    [anon_sym_sizeof] = ACTIONS(2308),
    [anon_sym___alignof__] = ACTIONS(2308),
    [anon_sym___alignof] = ACTIONS(2308),
    [anon_sym__alignof] = ACTIONS(2308),
    [anon_sym_alignof] = ACTIONS(2308),
    [anon_sym__Alignof] = ACTIONS(2308),
    [anon_sym_offsetof] = ACTIONS(2308),
    [anon_sym__Generic] = ACTIONS(2308),
    [anon_sym_asm] = ACTIONS(2308),
    [anon_sym___asm__] = ACTIONS(2308),
    [sym_number_literal] = ACTIONS(2310),
    [anon_sym_L_SQUOTE] = ACTIONS(2310),
    [anon_sym_u_SQUOTE] = ACTIONS(2310),
    [anon_sym_U_SQUOTE] = ACTIONS(2310),
    [anon_sym_u8_SQUOTE] = ACTIONS(2310),
    [anon_sym_SQUOTE] = ACTIONS(2310),
    [anon_sym_L_DQUOTE] = ACTIONS(2310),
    [anon_sym_u_DQUOTE] = ACTIONS(2310),
    [anon_sym_U_DQUOTE] = ACTIONS(2310),
    [anon_sym_u8_DQUOTE] = ACTIONS(2310),
    [anon_sym_DQUOTE] = ACTIONS(2310),
    [sym_true] = ACTIONS(2308),
    [sym_false] = ACTIONS(2308),
    [anon_sym_NULL] = ACTIONS(2308),
    [anon_sym_nullptr] = ACTIONS(2308),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2308),
    [anon_sym_decltype] = ACTIONS(2308),
    [sym_virtual] = ACTIONS(2308),
    [anon_sym_explicit] = ACTIONS(2308),
    [anon_sym_typename] = ACTIONS(2308),
    [anon_sym_template] = ACTIONS(2308),
    [anon_sym_operator] = ACTIONS(2308),
    [anon_sym_try] = ACTIONS(2308),
    [anon_sym_delete] = ACTIONS(2308),
    [anon_sym_throw] = ACTIONS(2308),
    [anon_sym_namespace] = ACTIONS(2308),
    [anon_sym_using] = ACTIONS(2308),
    [anon_sym_static_assert] = ACTIONS(2308),
    [anon_sym_concept] = ACTIONS(2308),
    [anon_sym_co_return] = ACTIONS(2308),
    [anon_sym_co_yield] = ACTIONS(2308),
    [anon_sym_R_DQUOTE] = ACTIONS(2310),
    [anon_sym_LR_DQUOTE] = ACTIONS(2310),
    [anon_sym_uR_DQUOTE] = ACTIONS(2310),
    [anon_sym_UR_DQUOTE] = ACTIONS(2310),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2310),
    [anon_sym_co_await] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(2308),
    [anon_sym_requires] = ACTIONS(2308),
    [sym_this] = ACTIONS(2308),
    [anon_sym_discard] = ACTIONS(2308),
    [anon_sym_precise] = ACTIONS(2308),
    [anon_sym_shared] = ACTIONS(2308),
    [anon_sym_groupshared] = ACTIONS(2308),
    [anon_sym_uniform] = ACTIONS(2308),
    [anon_sym_row_major] = ACTIONS(2308),
    [anon_sym_column_major] = ACTIONS(2308),
    [anon_sym_globallycoherent] = ACTIONS(2308),
    [anon_sym_centroid] = ACTIONS(2308),
    [anon_sym_noperspective] = ACTIONS(2308),
    [anon_sym_nointerpolation] = ACTIONS(2308),
    [anon_sym_sample] = ACTIONS(2308),
    [anon_sym_linear] = ACTIONS(2308),
    [anon_sym_snorm] = ACTIONS(2308),
    [anon_sym_unorm] = ACTIONS(2308),
    [anon_sym_point] = ACTIONS(2308),
    [anon_sym_line] = ACTIONS(2308),
    [anon_sym_triangleadj] = ACTIONS(2308),
    [anon_sym_lineadj] = ACTIONS(2308),
    [anon_sym_triangle] = ACTIONS(2308),
    [anon_sym_cbuffer] = ACTIONS(2308),
  },
  [674] = {
    [sym_identifier] = ACTIONS(2494),
    [aux_sym_preproc_include_token1] = ACTIONS(2494),
    [aux_sym_preproc_def_token1] = ACTIONS(2494),
    [aux_sym_preproc_if_token1] = ACTIONS(2494),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2494),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2494),
    [sym_preproc_directive] = ACTIONS(2494),
    [anon_sym_LPAREN2] = ACTIONS(2496),
    [anon_sym_BANG] = ACTIONS(2496),
    [anon_sym_TILDE] = ACTIONS(2496),
    [anon_sym_DASH] = ACTIONS(2494),
    [anon_sym_PLUS] = ACTIONS(2494),
    [anon_sym_STAR] = ACTIONS(2496),
    [anon_sym_AMP_AMP] = ACTIONS(2496),
    [anon_sym_AMP] = ACTIONS(2494),
    [anon_sym_SEMI] = ACTIONS(2496),
    [anon_sym___extension__] = ACTIONS(2494),
    [anon_sym_typedef] = ACTIONS(2494),
    [anon_sym_in] = ACTIONS(2494),
    [anon_sym_out] = ACTIONS(2494),
    [anon_sym_inout] = ACTIONS(2494),
    [anon_sym_extern] = ACTIONS(2494),
    [anon_sym___attribute__] = ACTIONS(2494),
    [anon_sym_COLON_COLON] = ACTIONS(2496),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2496),
    [anon_sym___declspec] = ACTIONS(2494),
    [anon_sym___based] = ACTIONS(2494),
    [anon_sym___cdecl] = ACTIONS(2494),
    [anon_sym___clrcall] = ACTIONS(2494),
    [anon_sym___stdcall] = ACTIONS(2494),
    [anon_sym___fastcall] = ACTIONS(2494),
    [anon_sym___thiscall] = ACTIONS(2494),
    [anon_sym___vectorcall] = ACTIONS(2494),
    [anon_sym_LBRACE] = ACTIONS(2496),
    [anon_sym_RBRACE] = ACTIONS(2496),
    [anon_sym_signed] = ACTIONS(2494),
    [anon_sym_unsigned] = ACTIONS(2494),
    [anon_sym_long] = ACTIONS(2494),
    [anon_sym_short] = ACTIONS(2494),
    [anon_sym_LBRACK] = ACTIONS(2494),
    [anon_sym_static] = ACTIONS(2494),
    [anon_sym_register] = ACTIONS(2494),
    [anon_sym_inline] = ACTIONS(2494),
    [anon_sym___inline] = ACTIONS(2494),
    [anon_sym___inline__] = ACTIONS(2494),
    [anon_sym___forceinline] = ACTIONS(2494),
    [anon_sym_thread_local] = ACTIONS(2494),
    [anon_sym___thread] = ACTIONS(2494),
    [anon_sym_const] = ACTIONS(2494),
    [anon_sym_constexpr] = ACTIONS(2494),
    [anon_sym_volatile] = ACTIONS(2494),
    [anon_sym_restrict] = ACTIONS(2494),
    [anon_sym___restrict__] = ACTIONS(2494),
    [anon_sym__Atomic] = ACTIONS(2494),
    [anon_sym__Noreturn] = ACTIONS(2494),
    [anon_sym_noreturn] = ACTIONS(2494),
    [anon_sym_mutable] = ACTIONS(2494),
    [anon_sym_constinit] = ACTIONS(2494),
    [anon_sym_consteval] = ACTIONS(2494),
    [anon_sym_alignas] = ACTIONS(2494),
    [anon_sym__Alignas] = ACTIONS(2494),
    [sym_primitive_type] = ACTIONS(2494),
    [anon_sym_enum] = ACTIONS(2494),
    [anon_sym_class] = ACTIONS(2494),
    [anon_sym_struct] = ACTIONS(2494),
    [anon_sym_union] = ACTIONS(2494),
    [anon_sym_if] = ACTIONS(2494),
    [anon_sym_switch] = ACTIONS(2494),
    [anon_sym_case] = ACTIONS(2494),
    [anon_sym_default] = ACTIONS(2494),
    [anon_sym_while] = ACTIONS(2494),
    [anon_sym_do] = ACTIONS(2494),
    [anon_sym_for] = ACTIONS(2494),
    [anon_sym_return] = ACTIONS(2494),
    [anon_sym_break] = ACTIONS(2494),
    [anon_sym_continue] = ACTIONS(2494),
    [anon_sym_goto] = ACTIONS(2494),
    [anon_sym___try] = ACTIONS(2494),
    [anon_sym___leave] = ACTIONS(2494),
    [anon_sym_not] = ACTIONS(2494),
    [anon_sym_compl] = ACTIONS(2494),
    [anon_sym_DASH_DASH] = ACTIONS(2496),
    [anon_sym_PLUS_PLUS] = ACTIONS(2496),
    [anon_sym_sizeof] = ACTIONS(2494),
    [anon_sym___alignof__] = ACTIONS(2494),
    [anon_sym___alignof] = ACTIONS(2494),
    [anon_sym__alignof] = ACTIONS(2494),
    [anon_sym_alignof] = ACTIONS(2494),
    [anon_sym__Alignof] = ACTIONS(2494),
    [anon_sym_offsetof] = ACTIONS(2494),
    [anon_sym__Generic] = ACTIONS(2494),
    [anon_sym_asm] = ACTIONS(2494),
    [anon_sym___asm__] = ACTIONS(2494),
    [sym_number_literal] = ACTIONS(2496),
    [anon_sym_L_SQUOTE] = ACTIONS(2496),
    [anon_sym_u_SQUOTE] = ACTIONS(2496),
    [anon_sym_U_SQUOTE] = ACTIONS(2496),
    [anon_sym_u8_SQUOTE] = ACTIONS(2496),
    [anon_sym_SQUOTE] = ACTIONS(2496),
    [anon_sym_L_DQUOTE] = ACTIONS(2496),
    [anon_sym_u_DQUOTE] = ACTIONS(2496),
    [anon_sym_U_DQUOTE] = ACTIONS(2496),
    [anon_sym_u8_DQUOTE] = ACTIONS(2496),
    [anon_sym_DQUOTE] = ACTIONS(2496),
    [sym_true] = ACTIONS(2494),
    [sym_false] = ACTIONS(2494),
    [anon_sym_NULL] = ACTIONS(2494),
    [anon_sym_nullptr] = ACTIONS(2494),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2494),
    [anon_sym_decltype] = ACTIONS(2494),
    [sym_virtual] = ACTIONS(2494),
    [anon_sym_explicit] = ACTIONS(2494),
    [anon_sym_typename] = ACTIONS(2494),
    [anon_sym_template] = ACTIONS(2494),
    [anon_sym_operator] = ACTIONS(2494),
    [anon_sym_try] = ACTIONS(2494),
    [anon_sym_delete] = ACTIONS(2494),
    [anon_sym_throw] = ACTIONS(2494),
    [anon_sym_namespace] = ACTIONS(2494),
    [anon_sym_using] = ACTIONS(2494),
    [anon_sym_static_assert] = ACTIONS(2494),
    [anon_sym_concept] = ACTIONS(2494),
    [anon_sym_co_return] = ACTIONS(2494),
    [anon_sym_co_yield] = ACTIONS(2494),
    [anon_sym_R_DQUOTE] = ACTIONS(2496),
    [anon_sym_LR_DQUOTE] = ACTIONS(2496),
    [anon_sym_uR_DQUOTE] = ACTIONS(2496),
    [anon_sym_UR_DQUOTE] = ACTIONS(2496),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2496),
    [anon_sym_co_await] = ACTIONS(2494),
    [anon_sym_new] = ACTIONS(2494),
    [anon_sym_requires] = ACTIONS(2494),
    [sym_this] = ACTIONS(2494),
    [anon_sym_discard] = ACTIONS(2494),
    [anon_sym_precise] = ACTIONS(2494),
    [anon_sym_shared] = ACTIONS(2494),
    [anon_sym_groupshared] = ACTIONS(2494),
    [anon_sym_uniform] = ACTIONS(2494),
    [anon_sym_row_major] = ACTIONS(2494),
    [anon_sym_column_major] = ACTIONS(2494),
    [anon_sym_globallycoherent] = ACTIONS(2494),
    [anon_sym_centroid] = ACTIONS(2494),
    [anon_sym_noperspective] = ACTIONS(2494),
    [anon_sym_nointerpolation] = ACTIONS(2494),
    [anon_sym_sample] = ACTIONS(2494),
    [anon_sym_linear] = ACTIONS(2494),
    [anon_sym_snorm] = ACTIONS(2494),
    [anon_sym_unorm] = ACTIONS(2494),
    [anon_sym_point] = ACTIONS(2494),
    [anon_sym_line] = ACTIONS(2494),
    [anon_sym_triangleadj] = ACTIONS(2494),
    [anon_sym_lineadj] = ACTIONS(2494),
    [anon_sym_triangle] = ACTIONS(2494),
    [anon_sym_cbuffer] = ACTIONS(2494),
  },
  [675] = {
    [sym_identifier] = ACTIONS(2494),
    [aux_sym_preproc_include_token1] = ACTIONS(2494),
    [aux_sym_preproc_def_token1] = ACTIONS(2494),
    [aux_sym_preproc_if_token1] = ACTIONS(2494),
    [aux_sym_preproc_if_token2] = ACTIONS(2494),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2494),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2494),
    [sym_preproc_directive] = ACTIONS(2494),
    [anon_sym_LPAREN2] = ACTIONS(2496),
    [anon_sym_BANG] = ACTIONS(2496),
    [anon_sym_TILDE] = ACTIONS(2496),
    [anon_sym_DASH] = ACTIONS(2494),
    [anon_sym_PLUS] = ACTIONS(2494),
    [anon_sym_STAR] = ACTIONS(2496),
    [anon_sym_AMP_AMP] = ACTIONS(2496),
    [anon_sym_AMP] = ACTIONS(2494),
    [anon_sym_SEMI] = ACTIONS(2496),
    [anon_sym___extension__] = ACTIONS(2494),
    [anon_sym_typedef] = ACTIONS(2494),
    [anon_sym_in] = ACTIONS(2494),
    [anon_sym_out] = ACTIONS(2494),
    [anon_sym_inout] = ACTIONS(2494),
    [anon_sym_extern] = ACTIONS(2494),
    [anon_sym___attribute__] = ACTIONS(2494),
    [anon_sym_COLON_COLON] = ACTIONS(2496),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2496),
    [anon_sym___declspec] = ACTIONS(2494),
    [anon_sym___based] = ACTIONS(2494),
    [anon_sym___cdecl] = ACTIONS(2494),
    [anon_sym___clrcall] = ACTIONS(2494),
    [anon_sym___stdcall] = ACTIONS(2494),
    [anon_sym___fastcall] = ACTIONS(2494),
    [anon_sym___thiscall] = ACTIONS(2494),
    [anon_sym___vectorcall] = ACTIONS(2494),
    [anon_sym_LBRACE] = ACTIONS(2496),
    [anon_sym_signed] = ACTIONS(2494),
    [anon_sym_unsigned] = ACTIONS(2494),
    [anon_sym_long] = ACTIONS(2494),
    [anon_sym_short] = ACTIONS(2494),
    [anon_sym_LBRACK] = ACTIONS(2494),
    [anon_sym_static] = ACTIONS(2494),
    [anon_sym_register] = ACTIONS(2494),
    [anon_sym_inline] = ACTIONS(2494),
    [anon_sym___inline] = ACTIONS(2494),
    [anon_sym___inline__] = ACTIONS(2494),
    [anon_sym___forceinline] = ACTIONS(2494),
    [anon_sym_thread_local] = ACTIONS(2494),
    [anon_sym___thread] = ACTIONS(2494),
    [anon_sym_const] = ACTIONS(2494),
    [anon_sym_constexpr] = ACTIONS(2494),
    [anon_sym_volatile] = ACTIONS(2494),
    [anon_sym_restrict] = ACTIONS(2494),
    [anon_sym___restrict__] = ACTIONS(2494),
    [anon_sym__Atomic] = ACTIONS(2494),
    [anon_sym__Noreturn] = ACTIONS(2494),
    [anon_sym_noreturn] = ACTIONS(2494),
    [anon_sym_mutable] = ACTIONS(2494),
    [anon_sym_constinit] = ACTIONS(2494),
    [anon_sym_consteval] = ACTIONS(2494),
    [anon_sym_alignas] = ACTIONS(2494),
    [anon_sym__Alignas] = ACTIONS(2494),
    [sym_primitive_type] = ACTIONS(2494),
    [anon_sym_enum] = ACTIONS(2494),
    [anon_sym_class] = ACTIONS(2494),
    [anon_sym_struct] = ACTIONS(2494),
    [anon_sym_union] = ACTIONS(2494),
    [anon_sym_if] = ACTIONS(2494),
    [anon_sym_switch] = ACTIONS(2494),
    [anon_sym_case] = ACTIONS(2494),
    [anon_sym_default] = ACTIONS(2494),
    [anon_sym_while] = ACTIONS(2494),
    [anon_sym_do] = ACTIONS(2494),
    [anon_sym_for] = ACTIONS(2494),
    [anon_sym_return] = ACTIONS(2494),
    [anon_sym_break] = ACTIONS(2494),
    [anon_sym_continue] = ACTIONS(2494),
    [anon_sym_goto] = ACTIONS(2494),
    [anon_sym___try] = ACTIONS(2494),
    [anon_sym___leave] = ACTIONS(2494),
    [anon_sym_not] = ACTIONS(2494),
    [anon_sym_compl] = ACTIONS(2494),
    [anon_sym_DASH_DASH] = ACTIONS(2496),
    [anon_sym_PLUS_PLUS] = ACTIONS(2496),
    [anon_sym_sizeof] = ACTIONS(2494),
    [anon_sym___alignof__] = ACTIONS(2494),
    [anon_sym___alignof] = ACTIONS(2494),
    [anon_sym__alignof] = ACTIONS(2494),
    [anon_sym_alignof] = ACTIONS(2494),
    [anon_sym__Alignof] = ACTIONS(2494),
    [anon_sym_offsetof] = ACTIONS(2494),
    [anon_sym__Generic] = ACTIONS(2494),
    [anon_sym_asm] = ACTIONS(2494),
    [anon_sym___asm__] = ACTIONS(2494),
    [sym_number_literal] = ACTIONS(2496),
    [anon_sym_L_SQUOTE] = ACTIONS(2496),
    [anon_sym_u_SQUOTE] = ACTIONS(2496),
    [anon_sym_U_SQUOTE] = ACTIONS(2496),
    [anon_sym_u8_SQUOTE] = ACTIONS(2496),
    [anon_sym_SQUOTE] = ACTIONS(2496),
    [anon_sym_L_DQUOTE] = ACTIONS(2496),
    [anon_sym_u_DQUOTE] = ACTIONS(2496),
    [anon_sym_U_DQUOTE] = ACTIONS(2496),
    [anon_sym_u8_DQUOTE] = ACTIONS(2496),
    [anon_sym_DQUOTE] = ACTIONS(2496),
    [sym_true] = ACTIONS(2494),
    [sym_false] = ACTIONS(2494),
    [anon_sym_NULL] = ACTIONS(2494),
    [anon_sym_nullptr] = ACTIONS(2494),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2494),
    [anon_sym_decltype] = ACTIONS(2494),
    [sym_virtual] = ACTIONS(2494),
    [anon_sym_explicit] = ACTIONS(2494),
    [anon_sym_typename] = ACTIONS(2494),
    [anon_sym_template] = ACTIONS(2494),
    [anon_sym_operator] = ACTIONS(2494),
    [anon_sym_try] = ACTIONS(2494),
    [anon_sym_delete] = ACTIONS(2494),
    [anon_sym_throw] = ACTIONS(2494),
    [anon_sym_namespace] = ACTIONS(2494),
    [anon_sym_using] = ACTIONS(2494),
    [anon_sym_static_assert] = ACTIONS(2494),
    [anon_sym_concept] = ACTIONS(2494),
    [anon_sym_co_return] = ACTIONS(2494),
    [anon_sym_co_yield] = ACTIONS(2494),
    [anon_sym_R_DQUOTE] = ACTIONS(2496),
    [anon_sym_LR_DQUOTE] = ACTIONS(2496),
    [anon_sym_uR_DQUOTE] = ACTIONS(2496),
    [anon_sym_UR_DQUOTE] = ACTIONS(2496),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2496),
    [anon_sym_co_await] = ACTIONS(2494),
    [anon_sym_new] = ACTIONS(2494),
    [anon_sym_requires] = ACTIONS(2494),
    [sym_this] = ACTIONS(2494),
    [anon_sym_discard] = ACTIONS(2494),
    [anon_sym_precise] = ACTIONS(2494),
    [anon_sym_shared] = ACTIONS(2494),
    [anon_sym_groupshared] = ACTIONS(2494),
    [anon_sym_uniform] = ACTIONS(2494),
    [anon_sym_row_major] = ACTIONS(2494),
    [anon_sym_column_major] = ACTIONS(2494),
    [anon_sym_globallycoherent] = ACTIONS(2494),
    [anon_sym_centroid] = ACTIONS(2494),
    [anon_sym_noperspective] = ACTIONS(2494),
    [anon_sym_nointerpolation] = ACTIONS(2494),
    [anon_sym_sample] = ACTIONS(2494),
    [anon_sym_linear] = ACTIONS(2494),
    [anon_sym_snorm] = ACTIONS(2494),
    [anon_sym_unorm] = ACTIONS(2494),
    [anon_sym_point] = ACTIONS(2494),
    [anon_sym_line] = ACTIONS(2494),
    [anon_sym_triangleadj] = ACTIONS(2494),
    [anon_sym_lineadj] = ACTIONS(2494),
    [anon_sym_triangle] = ACTIONS(2494),
    [anon_sym_cbuffer] = ACTIONS(2494),
  },
  [676] = {
    [sym_identifier] = ACTIONS(2424),
    [aux_sym_preproc_include_token1] = ACTIONS(2424),
    [aux_sym_preproc_def_token1] = ACTIONS(2424),
    [aux_sym_preproc_if_token1] = ACTIONS(2424),
    [aux_sym_preproc_if_token2] = ACTIONS(2424),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2424),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2424),
    [sym_preproc_directive] = ACTIONS(2424),
    [anon_sym_LPAREN2] = ACTIONS(2426),
    [anon_sym_BANG] = ACTIONS(2426),
    [anon_sym_TILDE] = ACTIONS(2426),
    [anon_sym_DASH] = ACTIONS(2424),
    [anon_sym_PLUS] = ACTIONS(2424),
    [anon_sym_STAR] = ACTIONS(2426),
    [anon_sym_AMP_AMP] = ACTIONS(2426),
    [anon_sym_AMP] = ACTIONS(2424),
    [anon_sym_SEMI] = ACTIONS(2426),
    [anon_sym___extension__] = ACTIONS(2424),
    [anon_sym_typedef] = ACTIONS(2424),
    [anon_sym_in] = ACTIONS(2424),
    [anon_sym_out] = ACTIONS(2424),
    [anon_sym_inout] = ACTIONS(2424),
    [anon_sym_extern] = ACTIONS(2424),
    [anon_sym___attribute__] = ACTIONS(2424),
    [anon_sym_COLON_COLON] = ACTIONS(2426),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2426),
    [anon_sym___declspec] = ACTIONS(2424),
    [anon_sym___based] = ACTIONS(2424),
    [anon_sym___cdecl] = ACTIONS(2424),
    [anon_sym___clrcall] = ACTIONS(2424),
    [anon_sym___stdcall] = ACTIONS(2424),
    [anon_sym___fastcall] = ACTIONS(2424),
    [anon_sym___thiscall] = ACTIONS(2424),
    [anon_sym___vectorcall] = ACTIONS(2424),
    [anon_sym_LBRACE] = ACTIONS(2426),
    [anon_sym_signed] = ACTIONS(2424),
    [anon_sym_unsigned] = ACTIONS(2424),
    [anon_sym_long] = ACTIONS(2424),
    [anon_sym_short] = ACTIONS(2424),
    [anon_sym_LBRACK] = ACTIONS(2424),
    [anon_sym_static] = ACTIONS(2424),
    [anon_sym_register] = ACTIONS(2424),
    [anon_sym_inline] = ACTIONS(2424),
    [anon_sym___inline] = ACTIONS(2424),
    [anon_sym___inline__] = ACTIONS(2424),
    [anon_sym___forceinline] = ACTIONS(2424),
    [anon_sym_thread_local] = ACTIONS(2424),
    [anon_sym___thread] = ACTIONS(2424),
    [anon_sym_const] = ACTIONS(2424),
    [anon_sym_constexpr] = ACTIONS(2424),
    [anon_sym_volatile] = ACTIONS(2424),
    [anon_sym_restrict] = ACTIONS(2424),
    [anon_sym___restrict__] = ACTIONS(2424),
    [anon_sym__Atomic] = ACTIONS(2424),
    [anon_sym__Noreturn] = ACTIONS(2424),
    [anon_sym_noreturn] = ACTIONS(2424),
    [anon_sym_mutable] = ACTIONS(2424),
    [anon_sym_constinit] = ACTIONS(2424),
    [anon_sym_consteval] = ACTIONS(2424),
    [anon_sym_alignas] = ACTIONS(2424),
    [anon_sym__Alignas] = ACTIONS(2424),
    [sym_primitive_type] = ACTIONS(2424),
    [anon_sym_enum] = ACTIONS(2424),
    [anon_sym_class] = ACTIONS(2424),
    [anon_sym_struct] = ACTIONS(2424),
    [anon_sym_union] = ACTIONS(2424),
    [anon_sym_if] = ACTIONS(2424),
    [anon_sym_switch] = ACTIONS(2424),
    [anon_sym_case] = ACTIONS(2424),
    [anon_sym_default] = ACTIONS(2424),
    [anon_sym_while] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(2424),
    [anon_sym_for] = ACTIONS(2424),
    [anon_sym_return] = ACTIONS(2424),
    [anon_sym_break] = ACTIONS(2424),
    [anon_sym_continue] = ACTIONS(2424),
    [anon_sym_goto] = ACTIONS(2424),
    [anon_sym___try] = ACTIONS(2424),
    [anon_sym___leave] = ACTIONS(2424),
    [anon_sym_not] = ACTIONS(2424),
    [anon_sym_compl] = ACTIONS(2424),
    [anon_sym_DASH_DASH] = ACTIONS(2426),
    [anon_sym_PLUS_PLUS] = ACTIONS(2426),
    [anon_sym_sizeof] = ACTIONS(2424),
    [anon_sym___alignof__] = ACTIONS(2424),
    [anon_sym___alignof] = ACTIONS(2424),
    [anon_sym__alignof] = ACTIONS(2424),
    [anon_sym_alignof] = ACTIONS(2424),
    [anon_sym__Alignof] = ACTIONS(2424),
    [anon_sym_offsetof] = ACTIONS(2424),
    [anon_sym__Generic] = ACTIONS(2424),
    [anon_sym_asm] = ACTIONS(2424),
    [anon_sym___asm__] = ACTIONS(2424),
    [sym_number_literal] = ACTIONS(2426),
    [anon_sym_L_SQUOTE] = ACTIONS(2426),
    [anon_sym_u_SQUOTE] = ACTIONS(2426),
    [anon_sym_U_SQUOTE] = ACTIONS(2426),
    [anon_sym_u8_SQUOTE] = ACTIONS(2426),
    [anon_sym_SQUOTE] = ACTIONS(2426),
    [anon_sym_L_DQUOTE] = ACTIONS(2426),
    [anon_sym_u_DQUOTE] = ACTIONS(2426),
    [anon_sym_U_DQUOTE] = ACTIONS(2426),
    [anon_sym_u8_DQUOTE] = ACTIONS(2426),
    [anon_sym_DQUOTE] = ACTIONS(2426),
    [sym_true] = ACTIONS(2424),
    [sym_false] = ACTIONS(2424),
    [anon_sym_NULL] = ACTIONS(2424),
    [anon_sym_nullptr] = ACTIONS(2424),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2424),
    [anon_sym_decltype] = ACTIONS(2424),
    [sym_virtual] = ACTIONS(2424),
    [anon_sym_explicit] = ACTIONS(2424),
    [anon_sym_typename] = ACTIONS(2424),
    [anon_sym_template] = ACTIONS(2424),
    [anon_sym_operator] = ACTIONS(2424),
    [anon_sym_try] = ACTIONS(2424),
    [anon_sym_delete] = ACTIONS(2424),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_namespace] = ACTIONS(2424),
    [anon_sym_using] = ACTIONS(2424),
    [anon_sym_static_assert] = ACTIONS(2424),
    [anon_sym_concept] = ACTIONS(2424),
    [anon_sym_co_return] = ACTIONS(2424),
    [anon_sym_co_yield] = ACTIONS(2424),
    [anon_sym_R_DQUOTE] = ACTIONS(2426),
    [anon_sym_LR_DQUOTE] = ACTIONS(2426),
    [anon_sym_uR_DQUOTE] = ACTIONS(2426),
    [anon_sym_UR_DQUOTE] = ACTIONS(2426),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2426),
    [anon_sym_co_await] = ACTIONS(2424),
    [anon_sym_new] = ACTIONS(2424),
    [anon_sym_requires] = ACTIONS(2424),
    [sym_this] = ACTIONS(2424),
    [anon_sym_discard] = ACTIONS(2424),
    [anon_sym_precise] = ACTIONS(2424),
    [anon_sym_shared] = ACTIONS(2424),
    [anon_sym_groupshared] = ACTIONS(2424),
    [anon_sym_uniform] = ACTIONS(2424),
    [anon_sym_row_major] = ACTIONS(2424),
    [anon_sym_column_major] = ACTIONS(2424),
    [anon_sym_globallycoherent] = ACTIONS(2424),
    [anon_sym_centroid] = ACTIONS(2424),
    [anon_sym_noperspective] = ACTIONS(2424),
    [anon_sym_nointerpolation] = ACTIONS(2424),
    [anon_sym_sample] = ACTIONS(2424),
    [anon_sym_linear] = ACTIONS(2424),
    [anon_sym_snorm] = ACTIONS(2424),
    [anon_sym_unorm] = ACTIONS(2424),
    [anon_sym_point] = ACTIONS(2424),
    [anon_sym_line] = ACTIONS(2424),
    [anon_sym_triangleadj] = ACTIONS(2424),
    [anon_sym_lineadj] = ACTIONS(2424),
    [anon_sym_triangle] = ACTIONS(2424),
    [anon_sym_cbuffer] = ACTIONS(2424),
  },
  [677] = {
    [sym_identifier] = ACTIONS(2482),
    [aux_sym_preproc_include_token1] = ACTIONS(2482),
    [aux_sym_preproc_def_token1] = ACTIONS(2482),
    [aux_sym_preproc_if_token1] = ACTIONS(2482),
    [aux_sym_preproc_if_token2] = ACTIONS(2482),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2482),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2482),
    [sym_preproc_directive] = ACTIONS(2482),
    [anon_sym_LPAREN2] = ACTIONS(2484),
    [anon_sym_BANG] = ACTIONS(2484),
    [anon_sym_TILDE] = ACTIONS(2484),
    [anon_sym_DASH] = ACTIONS(2482),
    [anon_sym_PLUS] = ACTIONS(2482),
    [anon_sym_STAR] = ACTIONS(2484),
    [anon_sym_AMP_AMP] = ACTIONS(2484),
    [anon_sym_AMP] = ACTIONS(2482),
    [anon_sym_SEMI] = ACTIONS(2484),
    [anon_sym___extension__] = ACTIONS(2482),
    [anon_sym_typedef] = ACTIONS(2482),
    [anon_sym_in] = ACTIONS(2482),
    [anon_sym_out] = ACTIONS(2482),
    [anon_sym_inout] = ACTIONS(2482),
    [anon_sym_extern] = ACTIONS(2482),
    [anon_sym___attribute__] = ACTIONS(2482),
    [anon_sym_COLON_COLON] = ACTIONS(2484),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2484),
    [anon_sym___declspec] = ACTIONS(2482),
    [anon_sym___based] = ACTIONS(2482),
    [anon_sym___cdecl] = ACTIONS(2482),
    [anon_sym___clrcall] = ACTIONS(2482),
    [anon_sym___stdcall] = ACTIONS(2482),
    [anon_sym___fastcall] = ACTIONS(2482),
    [anon_sym___thiscall] = ACTIONS(2482),
    [anon_sym___vectorcall] = ACTIONS(2482),
    [anon_sym_LBRACE] = ACTIONS(2484),
    [anon_sym_signed] = ACTIONS(2482),
    [anon_sym_unsigned] = ACTIONS(2482),
    [anon_sym_long] = ACTIONS(2482),
    [anon_sym_short] = ACTIONS(2482),
    [anon_sym_LBRACK] = ACTIONS(2482),
    [anon_sym_static] = ACTIONS(2482),
    [anon_sym_register] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(2482),
    [anon_sym___inline] = ACTIONS(2482),
    [anon_sym___inline__] = ACTIONS(2482),
    [anon_sym___forceinline] = ACTIONS(2482),
    [anon_sym_thread_local] = ACTIONS(2482),
    [anon_sym___thread] = ACTIONS(2482),
    [anon_sym_const] = ACTIONS(2482),
    [anon_sym_constexpr] = ACTIONS(2482),
    [anon_sym_volatile] = ACTIONS(2482),
    [anon_sym_restrict] = ACTIONS(2482),
    [anon_sym___restrict__] = ACTIONS(2482),
    [anon_sym__Atomic] = ACTIONS(2482),
    [anon_sym__Noreturn] = ACTIONS(2482),
    [anon_sym_noreturn] = ACTIONS(2482),
    [anon_sym_mutable] = ACTIONS(2482),
    [anon_sym_constinit] = ACTIONS(2482),
    [anon_sym_consteval] = ACTIONS(2482),
    [anon_sym_alignas] = ACTIONS(2482),
    [anon_sym__Alignas] = ACTIONS(2482),
    [sym_primitive_type] = ACTIONS(2482),
    [anon_sym_enum] = ACTIONS(2482),
    [anon_sym_class] = ACTIONS(2482),
    [anon_sym_struct] = ACTIONS(2482),
    [anon_sym_union] = ACTIONS(2482),
    [anon_sym_if] = ACTIONS(2482),
    [anon_sym_switch] = ACTIONS(2482),
    [anon_sym_case] = ACTIONS(2482),
    [anon_sym_default] = ACTIONS(2482),
    [anon_sym_while] = ACTIONS(2482),
    [anon_sym_do] = ACTIONS(2482),
    [anon_sym_for] = ACTIONS(2482),
    [anon_sym_return] = ACTIONS(2482),
    [anon_sym_break] = ACTIONS(2482),
    [anon_sym_continue] = ACTIONS(2482),
    [anon_sym_goto] = ACTIONS(2482),
    [anon_sym___try] = ACTIONS(2482),
    [anon_sym___leave] = ACTIONS(2482),
    [anon_sym_not] = ACTIONS(2482),
    [anon_sym_compl] = ACTIONS(2482),
    [anon_sym_DASH_DASH] = ACTIONS(2484),
    [anon_sym_PLUS_PLUS] = ACTIONS(2484),
    [anon_sym_sizeof] = ACTIONS(2482),
    [anon_sym___alignof__] = ACTIONS(2482),
    [anon_sym___alignof] = ACTIONS(2482),
    [anon_sym__alignof] = ACTIONS(2482),
    [anon_sym_alignof] = ACTIONS(2482),
    [anon_sym__Alignof] = ACTIONS(2482),
    [anon_sym_offsetof] = ACTIONS(2482),
    [anon_sym__Generic] = ACTIONS(2482),
    [anon_sym_asm] = ACTIONS(2482),
    [anon_sym___asm__] = ACTIONS(2482),
    [sym_number_literal] = ACTIONS(2484),
    [anon_sym_L_SQUOTE] = ACTIONS(2484),
    [anon_sym_u_SQUOTE] = ACTIONS(2484),
    [anon_sym_U_SQUOTE] = ACTIONS(2484),
    [anon_sym_u8_SQUOTE] = ACTIONS(2484),
    [anon_sym_SQUOTE] = ACTIONS(2484),
    [anon_sym_L_DQUOTE] = ACTIONS(2484),
    [anon_sym_u_DQUOTE] = ACTIONS(2484),
    [anon_sym_U_DQUOTE] = ACTIONS(2484),
    [anon_sym_u8_DQUOTE] = ACTIONS(2484),
    [anon_sym_DQUOTE] = ACTIONS(2484),
    [sym_true] = ACTIONS(2482),
    [sym_false] = ACTIONS(2482),
    [anon_sym_NULL] = ACTIONS(2482),
    [anon_sym_nullptr] = ACTIONS(2482),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2482),
    [anon_sym_decltype] = ACTIONS(2482),
    [sym_virtual] = ACTIONS(2482),
    [anon_sym_explicit] = ACTIONS(2482),
    [anon_sym_typename] = ACTIONS(2482),
    [anon_sym_template] = ACTIONS(2482),
    [anon_sym_operator] = ACTIONS(2482),
    [anon_sym_try] = ACTIONS(2482),
    [anon_sym_delete] = ACTIONS(2482),
    [anon_sym_throw] = ACTIONS(2482),
    [anon_sym_namespace] = ACTIONS(2482),
    [anon_sym_using] = ACTIONS(2482),
    [anon_sym_static_assert] = ACTIONS(2482),
    [anon_sym_concept] = ACTIONS(2482),
    [anon_sym_co_return] = ACTIONS(2482),
    [anon_sym_co_yield] = ACTIONS(2482),
    [anon_sym_R_DQUOTE] = ACTIONS(2484),
    [anon_sym_LR_DQUOTE] = ACTIONS(2484),
    [anon_sym_uR_DQUOTE] = ACTIONS(2484),
    [anon_sym_UR_DQUOTE] = ACTIONS(2484),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2484),
    [anon_sym_co_await] = ACTIONS(2482),
    [anon_sym_new] = ACTIONS(2482),
    [anon_sym_requires] = ACTIONS(2482),
    [sym_this] = ACTIONS(2482),
    [anon_sym_discard] = ACTIONS(2482),
    [anon_sym_precise] = ACTIONS(2482),
    [anon_sym_shared] = ACTIONS(2482),
    [anon_sym_groupshared] = ACTIONS(2482),
    [anon_sym_uniform] = ACTIONS(2482),
    [anon_sym_row_major] = ACTIONS(2482),
    [anon_sym_column_major] = ACTIONS(2482),
    [anon_sym_globallycoherent] = ACTIONS(2482),
    [anon_sym_centroid] = ACTIONS(2482),
    [anon_sym_noperspective] = ACTIONS(2482),
    [anon_sym_nointerpolation] = ACTIONS(2482),
    [anon_sym_sample] = ACTIONS(2482),
    [anon_sym_linear] = ACTIONS(2482),
    [anon_sym_snorm] = ACTIONS(2482),
    [anon_sym_unorm] = ACTIONS(2482),
    [anon_sym_point] = ACTIONS(2482),
    [anon_sym_line] = ACTIONS(2482),
    [anon_sym_triangleadj] = ACTIONS(2482),
    [anon_sym_lineadj] = ACTIONS(2482),
    [anon_sym_triangle] = ACTIONS(2482),
    [anon_sym_cbuffer] = ACTIONS(2482),
  },
  [678] = {
    [sym_identifier] = ACTIONS(2292),
    [aux_sym_preproc_include_token1] = ACTIONS(2292),
    [aux_sym_preproc_def_token1] = ACTIONS(2292),
    [aux_sym_preproc_if_token1] = ACTIONS(2292),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2292),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2292),
    [sym_preproc_directive] = ACTIONS(2292),
    [anon_sym_LPAREN2] = ACTIONS(2294),
    [anon_sym_BANG] = ACTIONS(2294),
    [anon_sym_TILDE] = ACTIONS(2294),
    [anon_sym_DASH] = ACTIONS(2292),
    [anon_sym_PLUS] = ACTIONS(2292),
    [anon_sym_STAR] = ACTIONS(2294),
    [anon_sym_AMP_AMP] = ACTIONS(2294),
    [anon_sym_AMP] = ACTIONS(2292),
    [anon_sym_SEMI] = ACTIONS(2294),
    [anon_sym___extension__] = ACTIONS(2292),
    [anon_sym_typedef] = ACTIONS(2292),
    [anon_sym_in] = ACTIONS(2292),
    [anon_sym_out] = ACTIONS(2292),
    [anon_sym_inout] = ACTIONS(2292),
    [anon_sym_extern] = ACTIONS(2292),
    [anon_sym___attribute__] = ACTIONS(2292),
    [anon_sym_COLON_COLON] = ACTIONS(2294),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2294),
    [anon_sym___declspec] = ACTIONS(2292),
    [anon_sym___based] = ACTIONS(2292),
    [anon_sym___cdecl] = ACTIONS(2292),
    [anon_sym___clrcall] = ACTIONS(2292),
    [anon_sym___stdcall] = ACTIONS(2292),
    [anon_sym___fastcall] = ACTIONS(2292),
    [anon_sym___thiscall] = ACTIONS(2292),
    [anon_sym___vectorcall] = ACTIONS(2292),
    [anon_sym_LBRACE] = ACTIONS(2294),
    [anon_sym_RBRACE] = ACTIONS(2294),
    [anon_sym_signed] = ACTIONS(2292),
    [anon_sym_unsigned] = ACTIONS(2292),
    [anon_sym_long] = ACTIONS(2292),
    [anon_sym_short] = ACTIONS(2292),
    [anon_sym_LBRACK] = ACTIONS(2292),
    [anon_sym_static] = ACTIONS(2292),
    [anon_sym_register] = ACTIONS(2292),
    [anon_sym_inline] = ACTIONS(2292),
    [anon_sym___inline] = ACTIONS(2292),
    [anon_sym___inline__] = ACTIONS(2292),
    [anon_sym___forceinline] = ACTIONS(2292),
    [anon_sym_thread_local] = ACTIONS(2292),
    [anon_sym___thread] = ACTIONS(2292),
    [anon_sym_const] = ACTIONS(2292),
    [anon_sym_constexpr] = ACTIONS(2292),
    [anon_sym_volatile] = ACTIONS(2292),
    [anon_sym_restrict] = ACTIONS(2292),
    [anon_sym___restrict__] = ACTIONS(2292),
    [anon_sym__Atomic] = ACTIONS(2292),
    [anon_sym__Noreturn] = ACTIONS(2292),
    [anon_sym_noreturn] = ACTIONS(2292),
    [anon_sym_mutable] = ACTIONS(2292),
    [anon_sym_constinit] = ACTIONS(2292),
    [anon_sym_consteval] = ACTIONS(2292),
    [anon_sym_alignas] = ACTIONS(2292),
    [anon_sym__Alignas] = ACTIONS(2292),
    [sym_primitive_type] = ACTIONS(2292),
    [anon_sym_enum] = ACTIONS(2292),
    [anon_sym_class] = ACTIONS(2292),
    [anon_sym_struct] = ACTIONS(2292),
    [anon_sym_union] = ACTIONS(2292),
    [anon_sym_if] = ACTIONS(2292),
    [anon_sym_switch] = ACTIONS(2292),
    [anon_sym_case] = ACTIONS(2292),
    [anon_sym_default] = ACTIONS(2292),
    [anon_sym_while] = ACTIONS(2292),
    [anon_sym_do] = ACTIONS(2292),
    [anon_sym_for] = ACTIONS(2292),
    [anon_sym_return] = ACTIONS(2292),
    [anon_sym_break] = ACTIONS(2292),
    [anon_sym_continue] = ACTIONS(2292),
    [anon_sym_goto] = ACTIONS(2292),
    [anon_sym___try] = ACTIONS(2292),
    [anon_sym___leave] = ACTIONS(2292),
    [anon_sym_not] = ACTIONS(2292),
    [anon_sym_compl] = ACTIONS(2292),
    [anon_sym_DASH_DASH] = ACTIONS(2294),
    [anon_sym_PLUS_PLUS] = ACTIONS(2294),
    [anon_sym_sizeof] = ACTIONS(2292),
    [anon_sym___alignof__] = ACTIONS(2292),
    [anon_sym___alignof] = ACTIONS(2292),
    [anon_sym__alignof] = ACTIONS(2292),
    [anon_sym_alignof] = ACTIONS(2292),
    [anon_sym__Alignof] = ACTIONS(2292),
    [anon_sym_offsetof] = ACTIONS(2292),
    [anon_sym__Generic] = ACTIONS(2292),
    [anon_sym_asm] = ACTIONS(2292),
    [anon_sym___asm__] = ACTIONS(2292),
    [sym_number_literal] = ACTIONS(2294),
    [anon_sym_L_SQUOTE] = ACTIONS(2294),
    [anon_sym_u_SQUOTE] = ACTIONS(2294),
    [anon_sym_U_SQUOTE] = ACTIONS(2294),
    [anon_sym_u8_SQUOTE] = ACTIONS(2294),
    [anon_sym_SQUOTE] = ACTIONS(2294),
    [anon_sym_L_DQUOTE] = ACTIONS(2294),
    [anon_sym_u_DQUOTE] = ACTIONS(2294),
    [anon_sym_U_DQUOTE] = ACTIONS(2294),
    [anon_sym_u8_DQUOTE] = ACTIONS(2294),
    [anon_sym_DQUOTE] = ACTIONS(2294),
    [sym_true] = ACTIONS(2292),
    [sym_false] = ACTIONS(2292),
    [anon_sym_NULL] = ACTIONS(2292),
    [anon_sym_nullptr] = ACTIONS(2292),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2292),
    [anon_sym_decltype] = ACTIONS(2292),
    [sym_virtual] = ACTIONS(2292),
    [anon_sym_explicit] = ACTIONS(2292),
    [anon_sym_typename] = ACTIONS(2292),
    [anon_sym_template] = ACTIONS(2292),
    [anon_sym_operator] = ACTIONS(2292),
    [anon_sym_try] = ACTIONS(2292),
    [anon_sym_delete] = ACTIONS(2292),
    [anon_sym_throw] = ACTIONS(2292),
    [anon_sym_namespace] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(2292),
    [anon_sym_static_assert] = ACTIONS(2292),
    [anon_sym_concept] = ACTIONS(2292),
    [anon_sym_co_return] = ACTIONS(2292),
    [anon_sym_co_yield] = ACTIONS(2292),
    [anon_sym_R_DQUOTE] = ACTIONS(2294),
    [anon_sym_LR_DQUOTE] = ACTIONS(2294),
    [anon_sym_uR_DQUOTE] = ACTIONS(2294),
    [anon_sym_UR_DQUOTE] = ACTIONS(2294),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2294),
    [anon_sym_co_await] = ACTIONS(2292),
    [anon_sym_new] = ACTIONS(2292),
    [anon_sym_requires] = ACTIONS(2292),
    [sym_this] = ACTIONS(2292),
    [anon_sym_discard] = ACTIONS(2292),
    [anon_sym_precise] = ACTIONS(2292),
    [anon_sym_shared] = ACTIONS(2292),
    [anon_sym_groupshared] = ACTIONS(2292),
    [anon_sym_uniform] = ACTIONS(2292),
    [anon_sym_row_major] = ACTIONS(2292),
    [anon_sym_column_major] = ACTIONS(2292),
    [anon_sym_globallycoherent] = ACTIONS(2292),
    [anon_sym_centroid] = ACTIONS(2292),
    [anon_sym_noperspective] = ACTIONS(2292),
    [anon_sym_nointerpolation] = ACTIONS(2292),
    [anon_sym_sample] = ACTIONS(2292),
    [anon_sym_linear] = ACTIONS(2292),
    [anon_sym_snorm] = ACTIONS(2292),
    [anon_sym_unorm] = ACTIONS(2292),
    [anon_sym_point] = ACTIONS(2292),
    [anon_sym_line] = ACTIONS(2292),
    [anon_sym_triangleadj] = ACTIONS(2292),
    [anon_sym_lineadj] = ACTIONS(2292),
    [anon_sym_triangle] = ACTIONS(2292),
    [anon_sym_cbuffer] = ACTIONS(2292),
  },
  [679] = {
    [sym_identifier] = ACTIONS(2412),
    [aux_sym_preproc_include_token1] = ACTIONS(2412),
    [aux_sym_preproc_def_token1] = ACTIONS(2412),
    [aux_sym_preproc_if_token1] = ACTIONS(2412),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2412),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2412),
    [sym_preproc_directive] = ACTIONS(2412),
    [anon_sym_LPAREN2] = ACTIONS(2414),
    [anon_sym_BANG] = ACTIONS(2414),
    [anon_sym_TILDE] = ACTIONS(2414),
    [anon_sym_DASH] = ACTIONS(2412),
    [anon_sym_PLUS] = ACTIONS(2412),
    [anon_sym_STAR] = ACTIONS(2414),
    [anon_sym_AMP_AMP] = ACTIONS(2414),
    [anon_sym_AMP] = ACTIONS(2412),
    [anon_sym_SEMI] = ACTIONS(2414),
    [anon_sym___extension__] = ACTIONS(2412),
    [anon_sym_typedef] = ACTIONS(2412),
    [anon_sym_in] = ACTIONS(2412),
    [anon_sym_out] = ACTIONS(2412),
    [anon_sym_inout] = ACTIONS(2412),
    [anon_sym_extern] = ACTIONS(2412),
    [anon_sym___attribute__] = ACTIONS(2412),
    [anon_sym_COLON_COLON] = ACTIONS(2414),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2414),
    [anon_sym___declspec] = ACTIONS(2412),
    [anon_sym___based] = ACTIONS(2412),
    [anon_sym___cdecl] = ACTIONS(2412),
    [anon_sym___clrcall] = ACTIONS(2412),
    [anon_sym___stdcall] = ACTIONS(2412),
    [anon_sym___fastcall] = ACTIONS(2412),
    [anon_sym___thiscall] = ACTIONS(2412),
    [anon_sym___vectorcall] = ACTIONS(2412),
    [anon_sym_LBRACE] = ACTIONS(2414),
    [anon_sym_RBRACE] = ACTIONS(2414),
    [anon_sym_signed] = ACTIONS(2412),
    [anon_sym_unsigned] = ACTIONS(2412),
    [anon_sym_long] = ACTIONS(2412),
    [anon_sym_short] = ACTIONS(2412),
    [anon_sym_LBRACK] = ACTIONS(2412),
    [anon_sym_static] = ACTIONS(2412),
    [anon_sym_register] = ACTIONS(2412),
    [anon_sym_inline] = ACTIONS(2412),
    [anon_sym___inline] = ACTIONS(2412),
    [anon_sym___inline__] = ACTIONS(2412),
    [anon_sym___forceinline] = ACTIONS(2412),
    [anon_sym_thread_local] = ACTIONS(2412),
    [anon_sym___thread] = ACTIONS(2412),
    [anon_sym_const] = ACTIONS(2412),
    [anon_sym_constexpr] = ACTIONS(2412),
    [anon_sym_volatile] = ACTIONS(2412),
    [anon_sym_restrict] = ACTIONS(2412),
    [anon_sym___restrict__] = ACTIONS(2412),
    [anon_sym__Atomic] = ACTIONS(2412),
    [anon_sym__Noreturn] = ACTIONS(2412),
    [anon_sym_noreturn] = ACTIONS(2412),
    [anon_sym_mutable] = ACTIONS(2412),
    [anon_sym_constinit] = ACTIONS(2412),
    [anon_sym_consteval] = ACTIONS(2412),
    [anon_sym_alignas] = ACTIONS(2412),
    [anon_sym__Alignas] = ACTIONS(2412),
    [sym_primitive_type] = ACTIONS(2412),
    [anon_sym_enum] = ACTIONS(2412),
    [anon_sym_class] = ACTIONS(2412),
    [anon_sym_struct] = ACTIONS(2412),
    [anon_sym_union] = ACTIONS(2412),
    [anon_sym_if] = ACTIONS(2412),
    [anon_sym_switch] = ACTIONS(2412),
    [anon_sym_case] = ACTIONS(2412),
    [anon_sym_default] = ACTIONS(2412),
    [anon_sym_while] = ACTIONS(2412),
    [anon_sym_do] = ACTIONS(2412),
    [anon_sym_for] = ACTIONS(2412),
    [anon_sym_return] = ACTIONS(2412),
    [anon_sym_break] = ACTIONS(2412),
    [anon_sym_continue] = ACTIONS(2412),
    [anon_sym_goto] = ACTIONS(2412),
    [anon_sym___try] = ACTIONS(2412),
    [anon_sym___leave] = ACTIONS(2412),
    [anon_sym_not] = ACTIONS(2412),
    [anon_sym_compl] = ACTIONS(2412),
    [anon_sym_DASH_DASH] = ACTIONS(2414),
    [anon_sym_PLUS_PLUS] = ACTIONS(2414),
    [anon_sym_sizeof] = ACTIONS(2412),
    [anon_sym___alignof__] = ACTIONS(2412),
    [anon_sym___alignof] = ACTIONS(2412),
    [anon_sym__alignof] = ACTIONS(2412),
    [anon_sym_alignof] = ACTIONS(2412),
    [anon_sym__Alignof] = ACTIONS(2412),
    [anon_sym_offsetof] = ACTIONS(2412),
    [anon_sym__Generic] = ACTIONS(2412),
    [anon_sym_asm] = ACTIONS(2412),
    [anon_sym___asm__] = ACTIONS(2412),
    [sym_number_literal] = ACTIONS(2414),
    [anon_sym_L_SQUOTE] = ACTIONS(2414),
    [anon_sym_u_SQUOTE] = ACTIONS(2414),
    [anon_sym_U_SQUOTE] = ACTIONS(2414),
    [anon_sym_u8_SQUOTE] = ACTIONS(2414),
    [anon_sym_SQUOTE] = ACTIONS(2414),
    [anon_sym_L_DQUOTE] = ACTIONS(2414),
    [anon_sym_u_DQUOTE] = ACTIONS(2414),
    [anon_sym_U_DQUOTE] = ACTIONS(2414),
    [anon_sym_u8_DQUOTE] = ACTIONS(2414),
    [anon_sym_DQUOTE] = ACTIONS(2414),
    [sym_true] = ACTIONS(2412),
    [sym_false] = ACTIONS(2412),
    [anon_sym_NULL] = ACTIONS(2412),
    [anon_sym_nullptr] = ACTIONS(2412),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2412),
    [anon_sym_decltype] = ACTIONS(2412),
    [sym_virtual] = ACTIONS(2412),
    [anon_sym_explicit] = ACTIONS(2412),
    [anon_sym_typename] = ACTIONS(2412),
    [anon_sym_template] = ACTIONS(2412),
    [anon_sym_operator] = ACTIONS(2412),
    [anon_sym_try] = ACTIONS(2412),
    [anon_sym_delete] = ACTIONS(2412),
    [anon_sym_throw] = ACTIONS(2412),
    [anon_sym_namespace] = ACTIONS(2412),
    [anon_sym_using] = ACTIONS(2412),
    [anon_sym_static_assert] = ACTIONS(2412),
    [anon_sym_concept] = ACTIONS(2412),
    [anon_sym_co_return] = ACTIONS(2412),
    [anon_sym_co_yield] = ACTIONS(2412),
    [anon_sym_R_DQUOTE] = ACTIONS(2414),
    [anon_sym_LR_DQUOTE] = ACTIONS(2414),
    [anon_sym_uR_DQUOTE] = ACTIONS(2414),
    [anon_sym_UR_DQUOTE] = ACTIONS(2414),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2414),
    [anon_sym_co_await] = ACTIONS(2412),
    [anon_sym_new] = ACTIONS(2412),
    [anon_sym_requires] = ACTIONS(2412),
    [sym_this] = ACTIONS(2412),
    [anon_sym_discard] = ACTIONS(2412),
    [anon_sym_precise] = ACTIONS(2412),
    [anon_sym_shared] = ACTIONS(2412),
    [anon_sym_groupshared] = ACTIONS(2412),
    [anon_sym_uniform] = ACTIONS(2412),
    [anon_sym_row_major] = ACTIONS(2412),
    [anon_sym_column_major] = ACTIONS(2412),
    [anon_sym_globallycoherent] = ACTIONS(2412),
    [anon_sym_centroid] = ACTIONS(2412),
    [anon_sym_noperspective] = ACTIONS(2412),
    [anon_sym_nointerpolation] = ACTIONS(2412),
    [anon_sym_sample] = ACTIONS(2412),
    [anon_sym_linear] = ACTIONS(2412),
    [anon_sym_snorm] = ACTIONS(2412),
    [anon_sym_unorm] = ACTIONS(2412),
    [anon_sym_point] = ACTIONS(2412),
    [anon_sym_line] = ACTIONS(2412),
    [anon_sym_triangleadj] = ACTIONS(2412),
    [anon_sym_lineadj] = ACTIONS(2412),
    [anon_sym_triangle] = ACTIONS(2412),
    [anon_sym_cbuffer] = ACTIONS(2412),
  },
  [680] = {
    [sym_identifier] = ACTIONS(2416),
    [aux_sym_preproc_include_token1] = ACTIONS(2416),
    [aux_sym_preproc_def_token1] = ACTIONS(2416),
    [aux_sym_preproc_if_token1] = ACTIONS(2416),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2416),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2416),
    [sym_preproc_directive] = ACTIONS(2416),
    [anon_sym_LPAREN2] = ACTIONS(2418),
    [anon_sym_BANG] = ACTIONS(2418),
    [anon_sym_TILDE] = ACTIONS(2418),
    [anon_sym_DASH] = ACTIONS(2416),
    [anon_sym_PLUS] = ACTIONS(2416),
    [anon_sym_STAR] = ACTIONS(2418),
    [anon_sym_AMP_AMP] = ACTIONS(2418),
    [anon_sym_AMP] = ACTIONS(2416),
    [anon_sym_SEMI] = ACTIONS(2418),
    [anon_sym___extension__] = ACTIONS(2416),
    [anon_sym_typedef] = ACTIONS(2416),
    [anon_sym_in] = ACTIONS(2416),
    [anon_sym_out] = ACTIONS(2416),
    [anon_sym_inout] = ACTIONS(2416),
    [anon_sym_extern] = ACTIONS(2416),
    [anon_sym___attribute__] = ACTIONS(2416),
    [anon_sym_COLON_COLON] = ACTIONS(2418),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2418),
    [anon_sym___declspec] = ACTIONS(2416),
    [anon_sym___based] = ACTIONS(2416),
    [anon_sym___cdecl] = ACTIONS(2416),
    [anon_sym___clrcall] = ACTIONS(2416),
    [anon_sym___stdcall] = ACTIONS(2416),
    [anon_sym___fastcall] = ACTIONS(2416),
    [anon_sym___thiscall] = ACTIONS(2416),
    [anon_sym___vectorcall] = ACTIONS(2416),
    [anon_sym_LBRACE] = ACTIONS(2418),
    [anon_sym_RBRACE] = ACTIONS(2418),
    [anon_sym_signed] = ACTIONS(2416),
    [anon_sym_unsigned] = ACTIONS(2416),
    [anon_sym_long] = ACTIONS(2416),
    [anon_sym_short] = ACTIONS(2416),
    [anon_sym_LBRACK] = ACTIONS(2416),
    [anon_sym_static] = ACTIONS(2416),
    [anon_sym_register] = ACTIONS(2416),
    [anon_sym_inline] = ACTIONS(2416),
    [anon_sym___inline] = ACTIONS(2416),
    [anon_sym___inline__] = ACTIONS(2416),
    [anon_sym___forceinline] = ACTIONS(2416),
    [anon_sym_thread_local] = ACTIONS(2416),
    [anon_sym___thread] = ACTIONS(2416),
    [anon_sym_const] = ACTIONS(2416),
    [anon_sym_constexpr] = ACTIONS(2416),
    [anon_sym_volatile] = ACTIONS(2416),
    [anon_sym_restrict] = ACTIONS(2416),
    [anon_sym___restrict__] = ACTIONS(2416),
    [anon_sym__Atomic] = ACTIONS(2416),
    [anon_sym__Noreturn] = ACTIONS(2416),
    [anon_sym_noreturn] = ACTIONS(2416),
    [anon_sym_mutable] = ACTIONS(2416),
    [anon_sym_constinit] = ACTIONS(2416),
    [anon_sym_consteval] = ACTIONS(2416),
    [anon_sym_alignas] = ACTIONS(2416),
    [anon_sym__Alignas] = ACTIONS(2416),
    [sym_primitive_type] = ACTIONS(2416),
    [anon_sym_enum] = ACTIONS(2416),
    [anon_sym_class] = ACTIONS(2416),
    [anon_sym_struct] = ACTIONS(2416),
    [anon_sym_union] = ACTIONS(2416),
    [anon_sym_if] = ACTIONS(2416),
    [anon_sym_switch] = ACTIONS(2416),
    [anon_sym_case] = ACTIONS(2416),
    [anon_sym_default] = ACTIONS(2416),
    [anon_sym_while] = ACTIONS(2416),
    [anon_sym_do] = ACTIONS(2416),
    [anon_sym_for] = ACTIONS(2416),
    [anon_sym_return] = ACTIONS(2416),
    [anon_sym_break] = ACTIONS(2416),
    [anon_sym_continue] = ACTIONS(2416),
    [anon_sym_goto] = ACTIONS(2416),
    [anon_sym___try] = ACTIONS(2416),
    [anon_sym___leave] = ACTIONS(2416),
    [anon_sym_not] = ACTIONS(2416),
    [anon_sym_compl] = ACTIONS(2416),
    [anon_sym_DASH_DASH] = ACTIONS(2418),
    [anon_sym_PLUS_PLUS] = ACTIONS(2418),
    [anon_sym_sizeof] = ACTIONS(2416),
    [anon_sym___alignof__] = ACTIONS(2416),
    [anon_sym___alignof] = ACTIONS(2416),
    [anon_sym__alignof] = ACTIONS(2416),
    [anon_sym_alignof] = ACTIONS(2416),
    [anon_sym__Alignof] = ACTIONS(2416),
    [anon_sym_offsetof] = ACTIONS(2416),
    [anon_sym__Generic] = ACTIONS(2416),
    [anon_sym_asm] = ACTIONS(2416),
    [anon_sym___asm__] = ACTIONS(2416),
    [sym_number_literal] = ACTIONS(2418),
    [anon_sym_L_SQUOTE] = ACTIONS(2418),
    [anon_sym_u_SQUOTE] = ACTIONS(2418),
    [anon_sym_U_SQUOTE] = ACTIONS(2418),
    [anon_sym_u8_SQUOTE] = ACTIONS(2418),
    [anon_sym_SQUOTE] = ACTIONS(2418),
    [anon_sym_L_DQUOTE] = ACTIONS(2418),
    [anon_sym_u_DQUOTE] = ACTIONS(2418),
    [anon_sym_U_DQUOTE] = ACTIONS(2418),
    [anon_sym_u8_DQUOTE] = ACTIONS(2418),
    [anon_sym_DQUOTE] = ACTIONS(2418),
    [sym_true] = ACTIONS(2416),
    [sym_false] = ACTIONS(2416),
    [anon_sym_NULL] = ACTIONS(2416),
    [anon_sym_nullptr] = ACTIONS(2416),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2416),
    [anon_sym_decltype] = ACTIONS(2416),
    [sym_virtual] = ACTIONS(2416),
    [anon_sym_explicit] = ACTIONS(2416),
    [anon_sym_typename] = ACTIONS(2416),
    [anon_sym_template] = ACTIONS(2416),
    [anon_sym_operator] = ACTIONS(2416),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_delete] = ACTIONS(2416),
    [anon_sym_throw] = ACTIONS(2416),
    [anon_sym_namespace] = ACTIONS(2416),
    [anon_sym_using] = ACTIONS(2416),
    [anon_sym_static_assert] = ACTIONS(2416),
    [anon_sym_concept] = ACTIONS(2416),
    [anon_sym_co_return] = ACTIONS(2416),
    [anon_sym_co_yield] = ACTIONS(2416),
    [anon_sym_R_DQUOTE] = ACTIONS(2418),
    [anon_sym_LR_DQUOTE] = ACTIONS(2418),
    [anon_sym_uR_DQUOTE] = ACTIONS(2418),
    [anon_sym_UR_DQUOTE] = ACTIONS(2418),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2418),
    [anon_sym_co_await] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(2416),
    [anon_sym_requires] = ACTIONS(2416),
    [sym_this] = ACTIONS(2416),
    [anon_sym_discard] = ACTIONS(2416),
    [anon_sym_precise] = ACTIONS(2416),
    [anon_sym_shared] = ACTIONS(2416),
    [anon_sym_groupshared] = ACTIONS(2416),
    [anon_sym_uniform] = ACTIONS(2416),
    [anon_sym_row_major] = ACTIONS(2416),
    [anon_sym_column_major] = ACTIONS(2416),
    [anon_sym_globallycoherent] = ACTIONS(2416),
    [anon_sym_centroid] = ACTIONS(2416),
    [anon_sym_noperspective] = ACTIONS(2416),
    [anon_sym_nointerpolation] = ACTIONS(2416),
    [anon_sym_sample] = ACTIONS(2416),
    [anon_sym_linear] = ACTIONS(2416),
    [anon_sym_snorm] = ACTIONS(2416),
    [anon_sym_unorm] = ACTIONS(2416),
    [anon_sym_point] = ACTIONS(2416),
    [anon_sym_line] = ACTIONS(2416),
    [anon_sym_triangleadj] = ACTIONS(2416),
    [anon_sym_lineadj] = ACTIONS(2416),
    [anon_sym_triangle] = ACTIONS(2416),
    [anon_sym_cbuffer] = ACTIONS(2416),
  },
  [681] = {
    [sym_identifier] = ACTIONS(2420),
    [aux_sym_preproc_include_token1] = ACTIONS(2420),
    [aux_sym_preproc_def_token1] = ACTIONS(2420),
    [aux_sym_preproc_if_token1] = ACTIONS(2420),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2420),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2420),
    [sym_preproc_directive] = ACTIONS(2420),
    [anon_sym_LPAREN2] = ACTIONS(2422),
    [anon_sym_BANG] = ACTIONS(2422),
    [anon_sym_TILDE] = ACTIONS(2422),
    [anon_sym_DASH] = ACTIONS(2420),
    [anon_sym_PLUS] = ACTIONS(2420),
    [anon_sym_STAR] = ACTIONS(2422),
    [anon_sym_AMP_AMP] = ACTIONS(2422),
    [anon_sym_AMP] = ACTIONS(2420),
    [anon_sym_SEMI] = ACTIONS(2422),
    [anon_sym___extension__] = ACTIONS(2420),
    [anon_sym_typedef] = ACTIONS(2420),
    [anon_sym_in] = ACTIONS(2420),
    [anon_sym_out] = ACTIONS(2420),
    [anon_sym_inout] = ACTIONS(2420),
    [anon_sym_extern] = ACTIONS(2420),
    [anon_sym___attribute__] = ACTIONS(2420),
    [anon_sym_COLON_COLON] = ACTIONS(2422),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2422),
    [anon_sym___declspec] = ACTIONS(2420),
    [anon_sym___based] = ACTIONS(2420),
    [anon_sym___cdecl] = ACTIONS(2420),
    [anon_sym___clrcall] = ACTIONS(2420),
    [anon_sym___stdcall] = ACTIONS(2420),
    [anon_sym___fastcall] = ACTIONS(2420),
    [anon_sym___thiscall] = ACTIONS(2420),
    [anon_sym___vectorcall] = ACTIONS(2420),
    [anon_sym_LBRACE] = ACTIONS(2422),
    [anon_sym_RBRACE] = ACTIONS(2422),
    [anon_sym_signed] = ACTIONS(2420),
    [anon_sym_unsigned] = ACTIONS(2420),
    [anon_sym_long] = ACTIONS(2420),
    [anon_sym_short] = ACTIONS(2420),
    [anon_sym_LBRACK] = ACTIONS(2420),
    [anon_sym_static] = ACTIONS(2420),
    [anon_sym_register] = ACTIONS(2420),
    [anon_sym_inline] = ACTIONS(2420),
    [anon_sym___inline] = ACTIONS(2420),
    [anon_sym___inline__] = ACTIONS(2420),
    [anon_sym___forceinline] = ACTIONS(2420),
    [anon_sym_thread_local] = ACTIONS(2420),
    [anon_sym___thread] = ACTIONS(2420),
    [anon_sym_const] = ACTIONS(2420),
    [anon_sym_constexpr] = ACTIONS(2420),
    [anon_sym_volatile] = ACTIONS(2420),
    [anon_sym_restrict] = ACTIONS(2420),
    [anon_sym___restrict__] = ACTIONS(2420),
    [anon_sym__Atomic] = ACTIONS(2420),
    [anon_sym__Noreturn] = ACTIONS(2420),
    [anon_sym_noreturn] = ACTIONS(2420),
    [anon_sym_mutable] = ACTIONS(2420),
    [anon_sym_constinit] = ACTIONS(2420),
    [anon_sym_consteval] = ACTIONS(2420),
    [anon_sym_alignas] = ACTIONS(2420),
    [anon_sym__Alignas] = ACTIONS(2420),
    [sym_primitive_type] = ACTIONS(2420),
    [anon_sym_enum] = ACTIONS(2420),
    [anon_sym_class] = ACTIONS(2420),
    [anon_sym_struct] = ACTIONS(2420),
    [anon_sym_union] = ACTIONS(2420),
    [anon_sym_if] = ACTIONS(2420),
    [anon_sym_switch] = ACTIONS(2420),
    [anon_sym_case] = ACTIONS(2420),
    [anon_sym_default] = ACTIONS(2420),
    [anon_sym_while] = ACTIONS(2420),
    [anon_sym_do] = ACTIONS(2420),
    [anon_sym_for] = ACTIONS(2420),
    [anon_sym_return] = ACTIONS(2420),
    [anon_sym_break] = ACTIONS(2420),
    [anon_sym_continue] = ACTIONS(2420),
    [anon_sym_goto] = ACTIONS(2420),
    [anon_sym___try] = ACTIONS(2420),
    [anon_sym___leave] = ACTIONS(2420),
    [anon_sym_not] = ACTIONS(2420),
    [anon_sym_compl] = ACTIONS(2420),
    [anon_sym_DASH_DASH] = ACTIONS(2422),
    [anon_sym_PLUS_PLUS] = ACTIONS(2422),
    [anon_sym_sizeof] = ACTIONS(2420),
    [anon_sym___alignof__] = ACTIONS(2420),
    [anon_sym___alignof] = ACTIONS(2420),
    [anon_sym__alignof] = ACTIONS(2420),
    [anon_sym_alignof] = ACTIONS(2420),
    [anon_sym__Alignof] = ACTIONS(2420),
    [anon_sym_offsetof] = ACTIONS(2420),
    [anon_sym__Generic] = ACTIONS(2420),
    [anon_sym_asm] = ACTIONS(2420),
    [anon_sym___asm__] = ACTIONS(2420),
    [sym_number_literal] = ACTIONS(2422),
    [anon_sym_L_SQUOTE] = ACTIONS(2422),
    [anon_sym_u_SQUOTE] = ACTIONS(2422),
    [anon_sym_U_SQUOTE] = ACTIONS(2422),
    [anon_sym_u8_SQUOTE] = ACTIONS(2422),
    [anon_sym_SQUOTE] = ACTIONS(2422),
    [anon_sym_L_DQUOTE] = ACTIONS(2422),
    [anon_sym_u_DQUOTE] = ACTIONS(2422),
    [anon_sym_U_DQUOTE] = ACTIONS(2422),
    [anon_sym_u8_DQUOTE] = ACTIONS(2422),
    [anon_sym_DQUOTE] = ACTIONS(2422),
    [sym_true] = ACTIONS(2420),
    [sym_false] = ACTIONS(2420),
    [anon_sym_NULL] = ACTIONS(2420),
    [anon_sym_nullptr] = ACTIONS(2420),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2420),
    [anon_sym_decltype] = ACTIONS(2420),
    [sym_virtual] = ACTIONS(2420),
    [anon_sym_explicit] = ACTIONS(2420),
    [anon_sym_typename] = ACTIONS(2420),
    [anon_sym_template] = ACTIONS(2420),
    [anon_sym_operator] = ACTIONS(2420),
    [anon_sym_try] = ACTIONS(2420),
    [anon_sym_delete] = ACTIONS(2420),
    [anon_sym_throw] = ACTIONS(2420),
    [anon_sym_namespace] = ACTIONS(2420),
    [anon_sym_using] = ACTIONS(2420),
    [anon_sym_static_assert] = ACTIONS(2420),
    [anon_sym_concept] = ACTIONS(2420),
    [anon_sym_co_return] = ACTIONS(2420),
    [anon_sym_co_yield] = ACTIONS(2420),
    [anon_sym_R_DQUOTE] = ACTIONS(2422),
    [anon_sym_LR_DQUOTE] = ACTIONS(2422),
    [anon_sym_uR_DQUOTE] = ACTIONS(2422),
    [anon_sym_UR_DQUOTE] = ACTIONS(2422),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2422),
    [anon_sym_co_await] = ACTIONS(2420),
    [anon_sym_new] = ACTIONS(2420),
    [anon_sym_requires] = ACTIONS(2420),
    [sym_this] = ACTIONS(2420),
    [anon_sym_discard] = ACTIONS(2420),
    [anon_sym_precise] = ACTIONS(2420),
    [anon_sym_shared] = ACTIONS(2420),
    [anon_sym_groupshared] = ACTIONS(2420),
    [anon_sym_uniform] = ACTIONS(2420),
    [anon_sym_row_major] = ACTIONS(2420),
    [anon_sym_column_major] = ACTIONS(2420),
    [anon_sym_globallycoherent] = ACTIONS(2420),
    [anon_sym_centroid] = ACTIONS(2420),
    [anon_sym_noperspective] = ACTIONS(2420),
    [anon_sym_nointerpolation] = ACTIONS(2420),
    [anon_sym_sample] = ACTIONS(2420),
    [anon_sym_linear] = ACTIONS(2420),
    [anon_sym_snorm] = ACTIONS(2420),
    [anon_sym_unorm] = ACTIONS(2420),
    [anon_sym_point] = ACTIONS(2420),
    [anon_sym_line] = ACTIONS(2420),
    [anon_sym_triangleadj] = ACTIONS(2420),
    [anon_sym_lineadj] = ACTIONS(2420),
    [anon_sym_triangle] = ACTIONS(2420),
    [anon_sym_cbuffer] = ACTIONS(2420),
  },
  [682] = {
    [sym_identifier] = ACTIONS(2428),
    [aux_sym_preproc_include_token1] = ACTIONS(2428),
    [aux_sym_preproc_def_token1] = ACTIONS(2428),
    [aux_sym_preproc_if_token1] = ACTIONS(2428),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2428),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2428),
    [sym_preproc_directive] = ACTIONS(2428),
    [anon_sym_LPAREN2] = ACTIONS(2430),
    [anon_sym_BANG] = ACTIONS(2430),
    [anon_sym_TILDE] = ACTIONS(2430),
    [anon_sym_DASH] = ACTIONS(2428),
    [anon_sym_PLUS] = ACTIONS(2428),
    [anon_sym_STAR] = ACTIONS(2430),
    [anon_sym_AMP_AMP] = ACTIONS(2430),
    [anon_sym_AMP] = ACTIONS(2428),
    [anon_sym_SEMI] = ACTIONS(2430),
    [anon_sym___extension__] = ACTIONS(2428),
    [anon_sym_typedef] = ACTIONS(2428),
    [anon_sym_in] = ACTIONS(2428),
    [anon_sym_out] = ACTIONS(2428),
    [anon_sym_inout] = ACTIONS(2428),
    [anon_sym_extern] = ACTIONS(2428),
    [anon_sym___attribute__] = ACTIONS(2428),
    [anon_sym_COLON_COLON] = ACTIONS(2430),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2430),
    [anon_sym___declspec] = ACTIONS(2428),
    [anon_sym___based] = ACTIONS(2428),
    [anon_sym___cdecl] = ACTIONS(2428),
    [anon_sym___clrcall] = ACTIONS(2428),
    [anon_sym___stdcall] = ACTIONS(2428),
    [anon_sym___fastcall] = ACTIONS(2428),
    [anon_sym___thiscall] = ACTIONS(2428),
    [anon_sym___vectorcall] = ACTIONS(2428),
    [anon_sym_LBRACE] = ACTIONS(2430),
    [anon_sym_RBRACE] = ACTIONS(2430),
    [anon_sym_signed] = ACTIONS(2428),
    [anon_sym_unsigned] = ACTIONS(2428),
    [anon_sym_long] = ACTIONS(2428),
    [anon_sym_short] = ACTIONS(2428),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [anon_sym_static] = ACTIONS(2428),
    [anon_sym_register] = ACTIONS(2428),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym___inline] = ACTIONS(2428),
    [anon_sym___inline__] = ACTIONS(2428),
    [anon_sym___forceinline] = ACTIONS(2428),
    [anon_sym_thread_local] = ACTIONS(2428),
    [anon_sym___thread] = ACTIONS(2428),
    [anon_sym_const] = ACTIONS(2428),
    [anon_sym_constexpr] = ACTIONS(2428),
    [anon_sym_volatile] = ACTIONS(2428),
    [anon_sym_restrict] = ACTIONS(2428),
    [anon_sym___restrict__] = ACTIONS(2428),
    [anon_sym__Atomic] = ACTIONS(2428),
    [anon_sym__Noreturn] = ACTIONS(2428),
    [anon_sym_noreturn] = ACTIONS(2428),
    [anon_sym_mutable] = ACTIONS(2428),
    [anon_sym_constinit] = ACTIONS(2428),
    [anon_sym_consteval] = ACTIONS(2428),
    [anon_sym_alignas] = ACTIONS(2428),
    [anon_sym__Alignas] = ACTIONS(2428),
    [sym_primitive_type] = ACTIONS(2428),
    [anon_sym_enum] = ACTIONS(2428),
    [anon_sym_class] = ACTIONS(2428),
    [anon_sym_struct] = ACTIONS(2428),
    [anon_sym_union] = ACTIONS(2428),
    [anon_sym_if] = ACTIONS(2428),
    [anon_sym_switch] = ACTIONS(2428),
    [anon_sym_case] = ACTIONS(2428),
    [anon_sym_default] = ACTIONS(2428),
    [anon_sym_while] = ACTIONS(2428),
    [anon_sym_do] = ACTIONS(2428),
    [anon_sym_for] = ACTIONS(2428),
    [anon_sym_return] = ACTIONS(2428),
    [anon_sym_break] = ACTIONS(2428),
    [anon_sym_continue] = ACTIONS(2428),
    [anon_sym_goto] = ACTIONS(2428),
    [anon_sym___try] = ACTIONS(2428),
    [anon_sym___leave] = ACTIONS(2428),
    [anon_sym_not] = ACTIONS(2428),
    [anon_sym_compl] = ACTIONS(2428),
    [anon_sym_DASH_DASH] = ACTIONS(2430),
    [anon_sym_PLUS_PLUS] = ACTIONS(2430),
    [anon_sym_sizeof] = ACTIONS(2428),
    [anon_sym___alignof__] = ACTIONS(2428),
    [anon_sym___alignof] = ACTIONS(2428),
    [anon_sym__alignof] = ACTIONS(2428),
    [anon_sym_alignof] = ACTIONS(2428),
    [anon_sym__Alignof] = ACTIONS(2428),
    [anon_sym_offsetof] = ACTIONS(2428),
    [anon_sym__Generic] = ACTIONS(2428),
    [anon_sym_asm] = ACTIONS(2428),
    [anon_sym___asm__] = ACTIONS(2428),
    [sym_number_literal] = ACTIONS(2430),
    [anon_sym_L_SQUOTE] = ACTIONS(2430),
    [anon_sym_u_SQUOTE] = ACTIONS(2430),
    [anon_sym_U_SQUOTE] = ACTIONS(2430),
    [anon_sym_u8_SQUOTE] = ACTIONS(2430),
    [anon_sym_SQUOTE] = ACTIONS(2430),
    [anon_sym_L_DQUOTE] = ACTIONS(2430),
    [anon_sym_u_DQUOTE] = ACTIONS(2430),
    [anon_sym_U_DQUOTE] = ACTIONS(2430),
    [anon_sym_u8_DQUOTE] = ACTIONS(2430),
    [anon_sym_DQUOTE] = ACTIONS(2430),
    [sym_true] = ACTIONS(2428),
    [sym_false] = ACTIONS(2428),
    [anon_sym_NULL] = ACTIONS(2428),
    [anon_sym_nullptr] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2428),
    [anon_sym_decltype] = ACTIONS(2428),
    [sym_virtual] = ACTIONS(2428),
    [anon_sym_explicit] = ACTIONS(2428),
    [anon_sym_typename] = ACTIONS(2428),
    [anon_sym_template] = ACTIONS(2428),
    [anon_sym_operator] = ACTIONS(2428),
    [anon_sym_try] = ACTIONS(2428),
    [anon_sym_delete] = ACTIONS(2428),
    [anon_sym_throw] = ACTIONS(2428),
    [anon_sym_namespace] = ACTIONS(2428),
    [anon_sym_using] = ACTIONS(2428),
    [anon_sym_static_assert] = ACTIONS(2428),
    [anon_sym_concept] = ACTIONS(2428),
    [anon_sym_co_return] = ACTIONS(2428),
    [anon_sym_co_yield] = ACTIONS(2428),
    [anon_sym_R_DQUOTE] = ACTIONS(2430),
    [anon_sym_LR_DQUOTE] = ACTIONS(2430),
    [anon_sym_uR_DQUOTE] = ACTIONS(2430),
    [anon_sym_UR_DQUOTE] = ACTIONS(2430),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2430),
    [anon_sym_co_await] = ACTIONS(2428),
    [anon_sym_new] = ACTIONS(2428),
    [anon_sym_requires] = ACTIONS(2428),
    [sym_this] = ACTIONS(2428),
    [anon_sym_discard] = ACTIONS(2428),
    [anon_sym_precise] = ACTIONS(2428),
    [anon_sym_shared] = ACTIONS(2428),
    [anon_sym_groupshared] = ACTIONS(2428),
    [anon_sym_uniform] = ACTIONS(2428),
    [anon_sym_row_major] = ACTIONS(2428),
    [anon_sym_column_major] = ACTIONS(2428),
    [anon_sym_globallycoherent] = ACTIONS(2428),
    [anon_sym_centroid] = ACTIONS(2428),
    [anon_sym_noperspective] = ACTIONS(2428),
    [anon_sym_nointerpolation] = ACTIONS(2428),
    [anon_sym_sample] = ACTIONS(2428),
    [anon_sym_linear] = ACTIONS(2428),
    [anon_sym_snorm] = ACTIONS(2428),
    [anon_sym_unorm] = ACTIONS(2428),
    [anon_sym_point] = ACTIONS(2428),
    [anon_sym_line] = ACTIONS(2428),
    [anon_sym_triangleadj] = ACTIONS(2428),
    [anon_sym_lineadj] = ACTIONS(2428),
    [anon_sym_triangle] = ACTIONS(2428),
    [anon_sym_cbuffer] = ACTIONS(2428),
  },
  [683] = {
    [sym_identifier] = ACTIONS(2432),
    [aux_sym_preproc_include_token1] = ACTIONS(2432),
    [aux_sym_preproc_def_token1] = ACTIONS(2432),
    [aux_sym_preproc_if_token1] = ACTIONS(2432),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2432),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2432),
    [sym_preproc_directive] = ACTIONS(2432),
    [anon_sym_LPAREN2] = ACTIONS(2434),
    [anon_sym_BANG] = ACTIONS(2434),
    [anon_sym_TILDE] = ACTIONS(2434),
    [anon_sym_DASH] = ACTIONS(2432),
    [anon_sym_PLUS] = ACTIONS(2432),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_AMP_AMP] = ACTIONS(2434),
    [anon_sym_AMP] = ACTIONS(2432),
    [anon_sym_SEMI] = ACTIONS(2434),
    [anon_sym___extension__] = ACTIONS(2432),
    [anon_sym_typedef] = ACTIONS(2432),
    [anon_sym_in] = ACTIONS(2432),
    [anon_sym_out] = ACTIONS(2432),
    [anon_sym_inout] = ACTIONS(2432),
    [anon_sym_extern] = ACTIONS(2432),
    [anon_sym___attribute__] = ACTIONS(2432),
    [anon_sym_COLON_COLON] = ACTIONS(2434),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2434),
    [anon_sym___declspec] = ACTIONS(2432),
    [anon_sym___based] = ACTIONS(2432),
    [anon_sym___cdecl] = ACTIONS(2432),
    [anon_sym___clrcall] = ACTIONS(2432),
    [anon_sym___stdcall] = ACTIONS(2432),
    [anon_sym___fastcall] = ACTIONS(2432),
    [anon_sym___thiscall] = ACTIONS(2432),
    [anon_sym___vectorcall] = ACTIONS(2432),
    [anon_sym_LBRACE] = ACTIONS(2434),
    [anon_sym_RBRACE] = ACTIONS(2434),
    [anon_sym_signed] = ACTIONS(2432),
    [anon_sym_unsigned] = ACTIONS(2432),
    [anon_sym_long] = ACTIONS(2432),
    [anon_sym_short] = ACTIONS(2432),
    [anon_sym_LBRACK] = ACTIONS(2432),
    [anon_sym_static] = ACTIONS(2432),
    [anon_sym_register] = ACTIONS(2432),
    [anon_sym_inline] = ACTIONS(2432),
    [anon_sym___inline] = ACTIONS(2432),
    [anon_sym___inline__] = ACTIONS(2432),
    [anon_sym___forceinline] = ACTIONS(2432),
    [anon_sym_thread_local] = ACTIONS(2432),
    [anon_sym___thread] = ACTIONS(2432),
    [anon_sym_const] = ACTIONS(2432),
    [anon_sym_constexpr] = ACTIONS(2432),
    [anon_sym_volatile] = ACTIONS(2432),
    [anon_sym_restrict] = ACTIONS(2432),
    [anon_sym___restrict__] = ACTIONS(2432),
    [anon_sym__Atomic] = ACTIONS(2432),
    [anon_sym__Noreturn] = ACTIONS(2432),
    [anon_sym_noreturn] = ACTIONS(2432),
    [anon_sym_mutable] = ACTIONS(2432),
    [anon_sym_constinit] = ACTIONS(2432),
    [anon_sym_consteval] = ACTIONS(2432),
    [anon_sym_alignas] = ACTIONS(2432),
    [anon_sym__Alignas] = ACTIONS(2432),
    [sym_primitive_type] = ACTIONS(2432),
    [anon_sym_enum] = ACTIONS(2432),
    [anon_sym_class] = ACTIONS(2432),
    [anon_sym_struct] = ACTIONS(2432),
    [anon_sym_union] = ACTIONS(2432),
    [anon_sym_if] = ACTIONS(2432),
    [anon_sym_switch] = ACTIONS(2432),
    [anon_sym_case] = ACTIONS(2432),
    [anon_sym_default] = ACTIONS(2432),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_do] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2432),
    [anon_sym_return] = ACTIONS(2432),
    [anon_sym_break] = ACTIONS(2432),
    [anon_sym_continue] = ACTIONS(2432),
    [anon_sym_goto] = ACTIONS(2432),
    [anon_sym___try] = ACTIONS(2432),
    [anon_sym___leave] = ACTIONS(2432),
    [anon_sym_not] = ACTIONS(2432),
    [anon_sym_compl] = ACTIONS(2432),
    [anon_sym_DASH_DASH] = ACTIONS(2434),
    [anon_sym_PLUS_PLUS] = ACTIONS(2434),
    [anon_sym_sizeof] = ACTIONS(2432),
    [anon_sym___alignof__] = ACTIONS(2432),
    [anon_sym___alignof] = ACTIONS(2432),
    [anon_sym__alignof] = ACTIONS(2432),
    [anon_sym_alignof] = ACTIONS(2432),
    [anon_sym__Alignof] = ACTIONS(2432),
    [anon_sym_offsetof] = ACTIONS(2432),
    [anon_sym__Generic] = ACTIONS(2432),
    [anon_sym_asm] = ACTIONS(2432),
    [anon_sym___asm__] = ACTIONS(2432),
    [sym_number_literal] = ACTIONS(2434),
    [anon_sym_L_SQUOTE] = ACTIONS(2434),
    [anon_sym_u_SQUOTE] = ACTIONS(2434),
    [anon_sym_U_SQUOTE] = ACTIONS(2434),
    [anon_sym_u8_SQUOTE] = ACTIONS(2434),
    [anon_sym_SQUOTE] = ACTIONS(2434),
    [anon_sym_L_DQUOTE] = ACTIONS(2434),
    [anon_sym_u_DQUOTE] = ACTIONS(2434),
    [anon_sym_U_DQUOTE] = ACTIONS(2434),
    [anon_sym_u8_DQUOTE] = ACTIONS(2434),
    [anon_sym_DQUOTE] = ACTIONS(2434),
    [sym_true] = ACTIONS(2432),
    [sym_false] = ACTIONS(2432),
    [anon_sym_NULL] = ACTIONS(2432),
    [anon_sym_nullptr] = ACTIONS(2432),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2432),
    [anon_sym_decltype] = ACTIONS(2432),
    [sym_virtual] = ACTIONS(2432),
    [anon_sym_explicit] = ACTIONS(2432),
    [anon_sym_typename] = ACTIONS(2432),
    [anon_sym_template] = ACTIONS(2432),
    [anon_sym_operator] = ACTIONS(2432),
    [anon_sym_try] = ACTIONS(2432),
    [anon_sym_delete] = ACTIONS(2432),
    [anon_sym_throw] = ACTIONS(2432),
    [anon_sym_namespace] = ACTIONS(2432),
    [anon_sym_using] = ACTIONS(2432),
    [anon_sym_static_assert] = ACTIONS(2432),
    [anon_sym_concept] = ACTIONS(2432),
    [anon_sym_co_return] = ACTIONS(2432),
    [anon_sym_co_yield] = ACTIONS(2432),
    [anon_sym_R_DQUOTE] = ACTIONS(2434),
    [anon_sym_LR_DQUOTE] = ACTIONS(2434),
    [anon_sym_uR_DQUOTE] = ACTIONS(2434),
    [anon_sym_UR_DQUOTE] = ACTIONS(2434),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2434),
    [anon_sym_co_await] = ACTIONS(2432),
    [anon_sym_new] = ACTIONS(2432),
    [anon_sym_requires] = ACTIONS(2432),
    [sym_this] = ACTIONS(2432),
    [anon_sym_discard] = ACTIONS(2432),
    [anon_sym_precise] = ACTIONS(2432),
    [anon_sym_shared] = ACTIONS(2432),
    [anon_sym_groupshared] = ACTIONS(2432),
    [anon_sym_uniform] = ACTIONS(2432),
    [anon_sym_row_major] = ACTIONS(2432),
    [anon_sym_column_major] = ACTIONS(2432),
    [anon_sym_globallycoherent] = ACTIONS(2432),
    [anon_sym_centroid] = ACTIONS(2432),
    [anon_sym_noperspective] = ACTIONS(2432),
    [anon_sym_nointerpolation] = ACTIONS(2432),
    [anon_sym_sample] = ACTIONS(2432),
    [anon_sym_linear] = ACTIONS(2432),
    [anon_sym_snorm] = ACTIONS(2432),
    [anon_sym_unorm] = ACTIONS(2432),
    [anon_sym_point] = ACTIONS(2432),
    [anon_sym_line] = ACTIONS(2432),
    [anon_sym_triangleadj] = ACTIONS(2432),
    [anon_sym_lineadj] = ACTIONS(2432),
    [anon_sym_triangle] = ACTIONS(2432),
    [anon_sym_cbuffer] = ACTIONS(2432),
  },
  [684] = {
    [sym_identifier] = ACTIONS(2440),
    [aux_sym_preproc_include_token1] = ACTIONS(2440),
    [aux_sym_preproc_def_token1] = ACTIONS(2440),
    [aux_sym_preproc_if_token1] = ACTIONS(2440),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2440),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2440),
    [sym_preproc_directive] = ACTIONS(2440),
    [anon_sym_LPAREN2] = ACTIONS(2442),
    [anon_sym_BANG] = ACTIONS(2442),
    [anon_sym_TILDE] = ACTIONS(2442),
    [anon_sym_DASH] = ACTIONS(2440),
    [anon_sym_PLUS] = ACTIONS(2440),
    [anon_sym_STAR] = ACTIONS(2442),
    [anon_sym_AMP_AMP] = ACTIONS(2442),
    [anon_sym_AMP] = ACTIONS(2440),
    [anon_sym_SEMI] = ACTIONS(2442),
    [anon_sym___extension__] = ACTIONS(2440),
    [anon_sym_typedef] = ACTIONS(2440),
    [anon_sym_in] = ACTIONS(2440),
    [anon_sym_out] = ACTIONS(2440),
    [anon_sym_inout] = ACTIONS(2440),
    [anon_sym_extern] = ACTIONS(2440),
    [anon_sym___attribute__] = ACTIONS(2440),
    [anon_sym_COLON_COLON] = ACTIONS(2442),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2442),
    [anon_sym___declspec] = ACTIONS(2440),
    [anon_sym___based] = ACTIONS(2440),
    [anon_sym___cdecl] = ACTIONS(2440),
    [anon_sym___clrcall] = ACTIONS(2440),
    [anon_sym___stdcall] = ACTIONS(2440),
    [anon_sym___fastcall] = ACTIONS(2440),
    [anon_sym___thiscall] = ACTIONS(2440),
    [anon_sym___vectorcall] = ACTIONS(2440),
    [anon_sym_LBRACE] = ACTIONS(2442),
    [anon_sym_RBRACE] = ACTIONS(2442),
    [anon_sym_signed] = ACTIONS(2440),
    [anon_sym_unsigned] = ACTIONS(2440),
    [anon_sym_long] = ACTIONS(2440),
    [anon_sym_short] = ACTIONS(2440),
    [anon_sym_LBRACK] = ACTIONS(2440),
    [anon_sym_static] = ACTIONS(2440),
    [anon_sym_register] = ACTIONS(2440),
    [anon_sym_inline] = ACTIONS(2440),
    [anon_sym___inline] = ACTIONS(2440),
    [anon_sym___inline__] = ACTIONS(2440),
    [anon_sym___forceinline] = ACTIONS(2440),
    [anon_sym_thread_local] = ACTIONS(2440),
    [anon_sym___thread] = ACTIONS(2440),
    [anon_sym_const] = ACTIONS(2440),
    [anon_sym_constexpr] = ACTIONS(2440),
    [anon_sym_volatile] = ACTIONS(2440),
    [anon_sym_restrict] = ACTIONS(2440),
    [anon_sym___restrict__] = ACTIONS(2440),
    [anon_sym__Atomic] = ACTIONS(2440),
    [anon_sym__Noreturn] = ACTIONS(2440),
    [anon_sym_noreturn] = ACTIONS(2440),
    [anon_sym_mutable] = ACTIONS(2440),
    [anon_sym_constinit] = ACTIONS(2440),
    [anon_sym_consteval] = ACTIONS(2440),
    [anon_sym_alignas] = ACTIONS(2440),
    [anon_sym__Alignas] = ACTIONS(2440),
    [sym_primitive_type] = ACTIONS(2440),
    [anon_sym_enum] = ACTIONS(2440),
    [anon_sym_class] = ACTIONS(2440),
    [anon_sym_struct] = ACTIONS(2440),
    [anon_sym_union] = ACTIONS(2440),
    [anon_sym_if] = ACTIONS(2440),
    [anon_sym_switch] = ACTIONS(2440),
    [anon_sym_case] = ACTIONS(2440),
    [anon_sym_default] = ACTIONS(2440),
    [anon_sym_while] = ACTIONS(2440),
    [anon_sym_do] = ACTIONS(2440),
    [anon_sym_for] = ACTIONS(2440),
    [anon_sym_return] = ACTIONS(2440),
    [anon_sym_break] = ACTIONS(2440),
    [anon_sym_continue] = ACTIONS(2440),
    [anon_sym_goto] = ACTIONS(2440),
    [anon_sym___try] = ACTIONS(2440),
    [anon_sym___leave] = ACTIONS(2440),
    [anon_sym_not] = ACTIONS(2440),
    [anon_sym_compl] = ACTIONS(2440),
    [anon_sym_DASH_DASH] = ACTIONS(2442),
    [anon_sym_PLUS_PLUS] = ACTIONS(2442),
    [anon_sym_sizeof] = ACTIONS(2440),
    [anon_sym___alignof__] = ACTIONS(2440),
    [anon_sym___alignof] = ACTIONS(2440),
    [anon_sym__alignof] = ACTIONS(2440),
    [anon_sym_alignof] = ACTIONS(2440),
    [anon_sym__Alignof] = ACTIONS(2440),
    [anon_sym_offsetof] = ACTIONS(2440),
    [anon_sym__Generic] = ACTIONS(2440),
    [anon_sym_asm] = ACTIONS(2440),
    [anon_sym___asm__] = ACTIONS(2440),
    [sym_number_literal] = ACTIONS(2442),
    [anon_sym_L_SQUOTE] = ACTIONS(2442),
    [anon_sym_u_SQUOTE] = ACTIONS(2442),
    [anon_sym_U_SQUOTE] = ACTIONS(2442),
    [anon_sym_u8_SQUOTE] = ACTIONS(2442),
    [anon_sym_SQUOTE] = ACTIONS(2442),
    [anon_sym_L_DQUOTE] = ACTIONS(2442),
    [anon_sym_u_DQUOTE] = ACTIONS(2442),
    [anon_sym_U_DQUOTE] = ACTIONS(2442),
    [anon_sym_u8_DQUOTE] = ACTIONS(2442),
    [anon_sym_DQUOTE] = ACTIONS(2442),
    [sym_true] = ACTIONS(2440),
    [sym_false] = ACTIONS(2440),
    [anon_sym_NULL] = ACTIONS(2440),
    [anon_sym_nullptr] = ACTIONS(2440),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2440),
    [anon_sym_decltype] = ACTIONS(2440),
    [sym_virtual] = ACTIONS(2440),
    [anon_sym_explicit] = ACTIONS(2440),
    [anon_sym_typename] = ACTIONS(2440),
    [anon_sym_template] = ACTIONS(2440),
    [anon_sym_operator] = ACTIONS(2440),
    [anon_sym_try] = ACTIONS(2440),
    [anon_sym_delete] = ACTIONS(2440),
    [anon_sym_throw] = ACTIONS(2440),
    [anon_sym_namespace] = ACTIONS(2440),
    [anon_sym_using] = ACTIONS(2440),
    [anon_sym_static_assert] = ACTIONS(2440),
    [anon_sym_concept] = ACTIONS(2440),
    [anon_sym_co_return] = ACTIONS(2440),
    [anon_sym_co_yield] = ACTIONS(2440),
    [anon_sym_R_DQUOTE] = ACTIONS(2442),
    [anon_sym_LR_DQUOTE] = ACTIONS(2442),
    [anon_sym_uR_DQUOTE] = ACTIONS(2442),
    [anon_sym_UR_DQUOTE] = ACTIONS(2442),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2442),
    [anon_sym_co_await] = ACTIONS(2440),
    [anon_sym_new] = ACTIONS(2440),
    [anon_sym_requires] = ACTIONS(2440),
    [sym_this] = ACTIONS(2440),
    [anon_sym_discard] = ACTIONS(2440),
    [anon_sym_precise] = ACTIONS(2440),
    [anon_sym_shared] = ACTIONS(2440),
    [anon_sym_groupshared] = ACTIONS(2440),
    [anon_sym_uniform] = ACTIONS(2440),
    [anon_sym_row_major] = ACTIONS(2440),
    [anon_sym_column_major] = ACTIONS(2440),
    [anon_sym_globallycoherent] = ACTIONS(2440),
    [anon_sym_centroid] = ACTIONS(2440),
    [anon_sym_noperspective] = ACTIONS(2440),
    [anon_sym_nointerpolation] = ACTIONS(2440),
    [anon_sym_sample] = ACTIONS(2440),
    [anon_sym_linear] = ACTIONS(2440),
    [anon_sym_snorm] = ACTIONS(2440),
    [anon_sym_unorm] = ACTIONS(2440),
    [anon_sym_point] = ACTIONS(2440),
    [anon_sym_line] = ACTIONS(2440),
    [anon_sym_triangleadj] = ACTIONS(2440),
    [anon_sym_lineadj] = ACTIONS(2440),
    [anon_sym_triangle] = ACTIONS(2440),
    [anon_sym_cbuffer] = ACTIONS(2440),
  },
  [685] = {
    [sym_identifier] = ACTIONS(2444),
    [aux_sym_preproc_include_token1] = ACTIONS(2444),
    [aux_sym_preproc_def_token1] = ACTIONS(2444),
    [aux_sym_preproc_if_token1] = ACTIONS(2444),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2444),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2444),
    [sym_preproc_directive] = ACTIONS(2444),
    [anon_sym_LPAREN2] = ACTIONS(2446),
    [anon_sym_BANG] = ACTIONS(2446),
    [anon_sym_TILDE] = ACTIONS(2446),
    [anon_sym_DASH] = ACTIONS(2444),
    [anon_sym_PLUS] = ACTIONS(2444),
    [anon_sym_STAR] = ACTIONS(2446),
    [anon_sym_AMP_AMP] = ACTIONS(2446),
    [anon_sym_AMP] = ACTIONS(2444),
    [anon_sym_SEMI] = ACTIONS(2446),
    [anon_sym___extension__] = ACTIONS(2444),
    [anon_sym_typedef] = ACTIONS(2444),
    [anon_sym_in] = ACTIONS(2444),
    [anon_sym_out] = ACTIONS(2444),
    [anon_sym_inout] = ACTIONS(2444),
    [anon_sym_extern] = ACTIONS(2444),
    [anon_sym___attribute__] = ACTIONS(2444),
    [anon_sym_COLON_COLON] = ACTIONS(2446),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2446),
    [anon_sym___declspec] = ACTIONS(2444),
    [anon_sym___based] = ACTIONS(2444),
    [anon_sym___cdecl] = ACTIONS(2444),
    [anon_sym___clrcall] = ACTIONS(2444),
    [anon_sym___stdcall] = ACTIONS(2444),
    [anon_sym___fastcall] = ACTIONS(2444),
    [anon_sym___thiscall] = ACTIONS(2444),
    [anon_sym___vectorcall] = ACTIONS(2444),
    [anon_sym_LBRACE] = ACTIONS(2446),
    [anon_sym_RBRACE] = ACTIONS(2446),
    [anon_sym_signed] = ACTIONS(2444),
    [anon_sym_unsigned] = ACTIONS(2444),
    [anon_sym_long] = ACTIONS(2444),
    [anon_sym_short] = ACTIONS(2444),
    [anon_sym_LBRACK] = ACTIONS(2444),
    [anon_sym_static] = ACTIONS(2444),
    [anon_sym_register] = ACTIONS(2444),
    [anon_sym_inline] = ACTIONS(2444),
    [anon_sym___inline] = ACTIONS(2444),
    [anon_sym___inline__] = ACTIONS(2444),
    [anon_sym___forceinline] = ACTIONS(2444),
    [anon_sym_thread_local] = ACTIONS(2444),
    [anon_sym___thread] = ACTIONS(2444),
    [anon_sym_const] = ACTIONS(2444),
    [anon_sym_constexpr] = ACTIONS(2444),
    [anon_sym_volatile] = ACTIONS(2444),
    [anon_sym_restrict] = ACTIONS(2444),
    [anon_sym___restrict__] = ACTIONS(2444),
    [anon_sym__Atomic] = ACTIONS(2444),
    [anon_sym__Noreturn] = ACTIONS(2444),
    [anon_sym_noreturn] = ACTIONS(2444),
    [anon_sym_mutable] = ACTIONS(2444),
    [anon_sym_constinit] = ACTIONS(2444),
    [anon_sym_consteval] = ACTIONS(2444),
    [anon_sym_alignas] = ACTIONS(2444),
    [anon_sym__Alignas] = ACTIONS(2444),
    [sym_primitive_type] = ACTIONS(2444),
    [anon_sym_enum] = ACTIONS(2444),
    [anon_sym_class] = ACTIONS(2444),
    [anon_sym_struct] = ACTIONS(2444),
    [anon_sym_union] = ACTIONS(2444),
    [anon_sym_if] = ACTIONS(2444),
    [anon_sym_switch] = ACTIONS(2444),
    [anon_sym_case] = ACTIONS(2444),
    [anon_sym_default] = ACTIONS(2444),
    [anon_sym_while] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(2444),
    [anon_sym_for] = ACTIONS(2444),
    [anon_sym_return] = ACTIONS(2444),
    [anon_sym_break] = ACTIONS(2444),
    [anon_sym_continue] = ACTIONS(2444),
    [anon_sym_goto] = ACTIONS(2444),
    [anon_sym___try] = ACTIONS(2444),
    [anon_sym___leave] = ACTIONS(2444),
    [anon_sym_not] = ACTIONS(2444),
    [anon_sym_compl] = ACTIONS(2444),
    [anon_sym_DASH_DASH] = ACTIONS(2446),
    [anon_sym_PLUS_PLUS] = ACTIONS(2446),
    [anon_sym_sizeof] = ACTIONS(2444),
    [anon_sym___alignof__] = ACTIONS(2444),
    [anon_sym___alignof] = ACTIONS(2444),
    [anon_sym__alignof] = ACTIONS(2444),
    [anon_sym_alignof] = ACTIONS(2444),
    [anon_sym__Alignof] = ACTIONS(2444),
    [anon_sym_offsetof] = ACTIONS(2444),
    [anon_sym__Generic] = ACTIONS(2444),
    [anon_sym_asm] = ACTIONS(2444),
    [anon_sym___asm__] = ACTIONS(2444),
    [sym_number_literal] = ACTIONS(2446),
    [anon_sym_L_SQUOTE] = ACTIONS(2446),
    [anon_sym_u_SQUOTE] = ACTIONS(2446),
    [anon_sym_U_SQUOTE] = ACTIONS(2446),
    [anon_sym_u8_SQUOTE] = ACTIONS(2446),
    [anon_sym_SQUOTE] = ACTIONS(2446),
    [anon_sym_L_DQUOTE] = ACTIONS(2446),
    [anon_sym_u_DQUOTE] = ACTIONS(2446),
    [anon_sym_U_DQUOTE] = ACTIONS(2446),
    [anon_sym_u8_DQUOTE] = ACTIONS(2446),
    [anon_sym_DQUOTE] = ACTIONS(2446),
    [sym_true] = ACTIONS(2444),
    [sym_false] = ACTIONS(2444),
    [anon_sym_NULL] = ACTIONS(2444),
    [anon_sym_nullptr] = ACTIONS(2444),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2444),
    [anon_sym_decltype] = ACTIONS(2444),
    [sym_virtual] = ACTIONS(2444),
    [anon_sym_explicit] = ACTIONS(2444),
    [anon_sym_typename] = ACTIONS(2444),
    [anon_sym_template] = ACTIONS(2444),
    [anon_sym_operator] = ACTIONS(2444),
    [anon_sym_try] = ACTIONS(2444),
    [anon_sym_delete] = ACTIONS(2444),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_namespace] = ACTIONS(2444),
    [anon_sym_using] = ACTIONS(2444),
    [anon_sym_static_assert] = ACTIONS(2444),
    [anon_sym_concept] = ACTIONS(2444),
    [anon_sym_co_return] = ACTIONS(2444),
    [anon_sym_co_yield] = ACTIONS(2444),
    [anon_sym_R_DQUOTE] = ACTIONS(2446),
    [anon_sym_LR_DQUOTE] = ACTIONS(2446),
    [anon_sym_uR_DQUOTE] = ACTIONS(2446),
    [anon_sym_UR_DQUOTE] = ACTIONS(2446),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2446),
    [anon_sym_co_await] = ACTIONS(2444),
    [anon_sym_new] = ACTIONS(2444),
    [anon_sym_requires] = ACTIONS(2444),
    [sym_this] = ACTIONS(2444),
    [anon_sym_discard] = ACTIONS(2444),
    [anon_sym_precise] = ACTIONS(2444),
    [anon_sym_shared] = ACTIONS(2444),
    [anon_sym_groupshared] = ACTIONS(2444),
    [anon_sym_uniform] = ACTIONS(2444),
    [anon_sym_row_major] = ACTIONS(2444),
    [anon_sym_column_major] = ACTIONS(2444),
    [anon_sym_globallycoherent] = ACTIONS(2444),
    [anon_sym_centroid] = ACTIONS(2444),
    [anon_sym_noperspective] = ACTIONS(2444),
    [anon_sym_nointerpolation] = ACTIONS(2444),
    [anon_sym_sample] = ACTIONS(2444),
    [anon_sym_linear] = ACTIONS(2444),
    [anon_sym_snorm] = ACTIONS(2444),
    [anon_sym_unorm] = ACTIONS(2444),
    [anon_sym_point] = ACTIONS(2444),
    [anon_sym_line] = ACTIONS(2444),
    [anon_sym_triangleadj] = ACTIONS(2444),
    [anon_sym_lineadj] = ACTIONS(2444),
    [anon_sym_triangle] = ACTIONS(2444),
    [anon_sym_cbuffer] = ACTIONS(2444),
  },
  [686] = {
    [sym_identifier] = ACTIONS(2448),
    [aux_sym_preproc_include_token1] = ACTIONS(2448),
    [aux_sym_preproc_def_token1] = ACTIONS(2448),
    [aux_sym_preproc_if_token1] = ACTIONS(2448),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2448),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2448),
    [sym_preproc_directive] = ACTIONS(2448),
    [anon_sym_LPAREN2] = ACTIONS(2450),
    [anon_sym_BANG] = ACTIONS(2450),
    [anon_sym_TILDE] = ACTIONS(2450),
    [anon_sym_DASH] = ACTIONS(2448),
    [anon_sym_PLUS] = ACTIONS(2448),
    [anon_sym_STAR] = ACTIONS(2450),
    [anon_sym_AMP_AMP] = ACTIONS(2450),
    [anon_sym_AMP] = ACTIONS(2448),
    [anon_sym_SEMI] = ACTIONS(2450),
    [anon_sym___extension__] = ACTIONS(2448),
    [anon_sym_typedef] = ACTIONS(2448),
    [anon_sym_in] = ACTIONS(2448),
    [anon_sym_out] = ACTIONS(2448),
    [anon_sym_inout] = ACTIONS(2448),
    [anon_sym_extern] = ACTIONS(2448),
    [anon_sym___attribute__] = ACTIONS(2448),
    [anon_sym_COLON_COLON] = ACTIONS(2450),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2450),
    [anon_sym___declspec] = ACTIONS(2448),
    [anon_sym___based] = ACTIONS(2448),
    [anon_sym___cdecl] = ACTIONS(2448),
    [anon_sym___clrcall] = ACTIONS(2448),
    [anon_sym___stdcall] = ACTIONS(2448),
    [anon_sym___fastcall] = ACTIONS(2448),
    [anon_sym___thiscall] = ACTIONS(2448),
    [anon_sym___vectorcall] = ACTIONS(2448),
    [anon_sym_LBRACE] = ACTIONS(2450),
    [anon_sym_RBRACE] = ACTIONS(2450),
    [anon_sym_signed] = ACTIONS(2448),
    [anon_sym_unsigned] = ACTIONS(2448),
    [anon_sym_long] = ACTIONS(2448),
    [anon_sym_short] = ACTIONS(2448),
    [anon_sym_LBRACK] = ACTIONS(2448),
    [anon_sym_static] = ACTIONS(2448),
    [anon_sym_register] = ACTIONS(2448),
    [anon_sym_inline] = ACTIONS(2448),
    [anon_sym___inline] = ACTIONS(2448),
    [anon_sym___inline__] = ACTIONS(2448),
    [anon_sym___forceinline] = ACTIONS(2448),
    [anon_sym_thread_local] = ACTIONS(2448),
    [anon_sym___thread] = ACTIONS(2448),
    [anon_sym_const] = ACTIONS(2448),
    [anon_sym_constexpr] = ACTIONS(2448),
    [anon_sym_volatile] = ACTIONS(2448),
    [anon_sym_restrict] = ACTIONS(2448),
    [anon_sym___restrict__] = ACTIONS(2448),
    [anon_sym__Atomic] = ACTIONS(2448),
    [anon_sym__Noreturn] = ACTIONS(2448),
    [anon_sym_noreturn] = ACTIONS(2448),
    [anon_sym_mutable] = ACTIONS(2448),
    [anon_sym_constinit] = ACTIONS(2448),
    [anon_sym_consteval] = ACTIONS(2448),
    [anon_sym_alignas] = ACTIONS(2448),
    [anon_sym__Alignas] = ACTIONS(2448),
    [sym_primitive_type] = ACTIONS(2448),
    [anon_sym_enum] = ACTIONS(2448),
    [anon_sym_class] = ACTIONS(2448),
    [anon_sym_struct] = ACTIONS(2448),
    [anon_sym_union] = ACTIONS(2448),
    [anon_sym_if] = ACTIONS(2448),
    [anon_sym_switch] = ACTIONS(2448),
    [anon_sym_case] = ACTIONS(2448),
    [anon_sym_default] = ACTIONS(2448),
    [anon_sym_while] = ACTIONS(2448),
    [anon_sym_do] = ACTIONS(2448),
    [anon_sym_for] = ACTIONS(2448),
    [anon_sym_return] = ACTIONS(2448),
    [anon_sym_break] = ACTIONS(2448),
    [anon_sym_continue] = ACTIONS(2448),
    [anon_sym_goto] = ACTIONS(2448),
    [anon_sym___try] = ACTIONS(2448),
    [anon_sym___leave] = ACTIONS(2448),
    [anon_sym_not] = ACTIONS(2448),
    [anon_sym_compl] = ACTIONS(2448),
    [anon_sym_DASH_DASH] = ACTIONS(2450),
    [anon_sym_PLUS_PLUS] = ACTIONS(2450),
    [anon_sym_sizeof] = ACTIONS(2448),
    [anon_sym___alignof__] = ACTIONS(2448),
    [anon_sym___alignof] = ACTIONS(2448),
    [anon_sym__alignof] = ACTIONS(2448),
    [anon_sym_alignof] = ACTIONS(2448),
    [anon_sym__Alignof] = ACTIONS(2448),
    [anon_sym_offsetof] = ACTIONS(2448),
    [anon_sym__Generic] = ACTIONS(2448),
    [anon_sym_asm] = ACTIONS(2448),
    [anon_sym___asm__] = ACTIONS(2448),
    [sym_number_literal] = ACTIONS(2450),
    [anon_sym_L_SQUOTE] = ACTIONS(2450),
    [anon_sym_u_SQUOTE] = ACTIONS(2450),
    [anon_sym_U_SQUOTE] = ACTIONS(2450),
    [anon_sym_u8_SQUOTE] = ACTIONS(2450),
    [anon_sym_SQUOTE] = ACTIONS(2450),
    [anon_sym_L_DQUOTE] = ACTIONS(2450),
    [anon_sym_u_DQUOTE] = ACTIONS(2450),
    [anon_sym_U_DQUOTE] = ACTIONS(2450),
    [anon_sym_u8_DQUOTE] = ACTIONS(2450),
    [anon_sym_DQUOTE] = ACTIONS(2450),
    [sym_true] = ACTIONS(2448),
    [sym_false] = ACTIONS(2448),
    [anon_sym_NULL] = ACTIONS(2448),
    [anon_sym_nullptr] = ACTIONS(2448),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2448),
    [anon_sym_decltype] = ACTIONS(2448),
    [sym_virtual] = ACTIONS(2448),
    [anon_sym_explicit] = ACTIONS(2448),
    [anon_sym_typename] = ACTIONS(2448),
    [anon_sym_template] = ACTIONS(2448),
    [anon_sym_operator] = ACTIONS(2448),
    [anon_sym_try] = ACTIONS(2448),
    [anon_sym_delete] = ACTIONS(2448),
    [anon_sym_throw] = ACTIONS(2448),
    [anon_sym_namespace] = ACTIONS(2448),
    [anon_sym_using] = ACTIONS(2448),
    [anon_sym_static_assert] = ACTIONS(2448),
    [anon_sym_concept] = ACTIONS(2448),
    [anon_sym_co_return] = ACTIONS(2448),
    [anon_sym_co_yield] = ACTIONS(2448),
    [anon_sym_R_DQUOTE] = ACTIONS(2450),
    [anon_sym_LR_DQUOTE] = ACTIONS(2450),
    [anon_sym_uR_DQUOTE] = ACTIONS(2450),
    [anon_sym_UR_DQUOTE] = ACTIONS(2450),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2450),
    [anon_sym_co_await] = ACTIONS(2448),
    [anon_sym_new] = ACTIONS(2448),
    [anon_sym_requires] = ACTIONS(2448),
    [sym_this] = ACTIONS(2448),
    [anon_sym_discard] = ACTIONS(2448),
    [anon_sym_precise] = ACTIONS(2448),
    [anon_sym_shared] = ACTIONS(2448),
    [anon_sym_groupshared] = ACTIONS(2448),
    [anon_sym_uniform] = ACTIONS(2448),
    [anon_sym_row_major] = ACTIONS(2448),
    [anon_sym_column_major] = ACTIONS(2448),
    [anon_sym_globallycoherent] = ACTIONS(2448),
    [anon_sym_centroid] = ACTIONS(2448),
    [anon_sym_noperspective] = ACTIONS(2448),
    [anon_sym_nointerpolation] = ACTIONS(2448),
    [anon_sym_sample] = ACTIONS(2448),
    [anon_sym_linear] = ACTIONS(2448),
    [anon_sym_snorm] = ACTIONS(2448),
    [anon_sym_unorm] = ACTIONS(2448),
    [anon_sym_point] = ACTIONS(2448),
    [anon_sym_line] = ACTIONS(2448),
    [anon_sym_triangleadj] = ACTIONS(2448),
    [anon_sym_lineadj] = ACTIONS(2448),
    [anon_sym_triangle] = ACTIONS(2448),
    [anon_sym_cbuffer] = ACTIONS(2448),
  },
  [687] = {
    [sym_identifier] = ACTIONS(2577),
    [aux_sym_preproc_include_token1] = ACTIONS(2577),
    [aux_sym_preproc_def_token1] = ACTIONS(2577),
    [aux_sym_preproc_if_token1] = ACTIONS(2577),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2577),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2577),
    [sym_preproc_directive] = ACTIONS(2577),
    [anon_sym_LPAREN2] = ACTIONS(2579),
    [anon_sym_BANG] = ACTIONS(2579),
    [anon_sym_TILDE] = ACTIONS(2579),
    [anon_sym_DASH] = ACTIONS(2577),
    [anon_sym_PLUS] = ACTIONS(2577),
    [anon_sym_STAR] = ACTIONS(2579),
    [anon_sym_AMP_AMP] = ACTIONS(2579),
    [anon_sym_AMP] = ACTIONS(2577),
    [anon_sym_SEMI] = ACTIONS(2579),
    [anon_sym___extension__] = ACTIONS(2577),
    [anon_sym_typedef] = ACTIONS(2577),
    [anon_sym_in] = ACTIONS(2577),
    [anon_sym_out] = ACTIONS(2577),
    [anon_sym_inout] = ACTIONS(2577),
    [anon_sym_extern] = ACTIONS(2577),
    [anon_sym___attribute__] = ACTIONS(2577),
    [anon_sym_COLON_COLON] = ACTIONS(2579),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2579),
    [anon_sym___declspec] = ACTIONS(2577),
    [anon_sym___based] = ACTIONS(2577),
    [anon_sym___cdecl] = ACTIONS(2577),
    [anon_sym___clrcall] = ACTIONS(2577),
    [anon_sym___stdcall] = ACTIONS(2577),
    [anon_sym___fastcall] = ACTIONS(2577),
    [anon_sym___thiscall] = ACTIONS(2577),
    [anon_sym___vectorcall] = ACTIONS(2577),
    [anon_sym_LBRACE] = ACTIONS(2579),
    [anon_sym_RBRACE] = ACTIONS(2579),
    [anon_sym_signed] = ACTIONS(2577),
    [anon_sym_unsigned] = ACTIONS(2577),
    [anon_sym_long] = ACTIONS(2577),
    [anon_sym_short] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2577),
    [anon_sym_static] = ACTIONS(2577),
    [anon_sym_register] = ACTIONS(2577),
    [anon_sym_inline] = ACTIONS(2577),
    [anon_sym___inline] = ACTIONS(2577),
    [anon_sym___inline__] = ACTIONS(2577),
    [anon_sym___forceinline] = ACTIONS(2577),
    [anon_sym_thread_local] = ACTIONS(2577),
    [anon_sym___thread] = ACTIONS(2577),
    [anon_sym_const] = ACTIONS(2577),
    [anon_sym_constexpr] = ACTIONS(2577),
    [anon_sym_volatile] = ACTIONS(2577),
    [anon_sym_restrict] = ACTIONS(2577),
    [anon_sym___restrict__] = ACTIONS(2577),
    [anon_sym__Atomic] = ACTIONS(2577),
    [anon_sym__Noreturn] = ACTIONS(2577),
    [anon_sym_noreturn] = ACTIONS(2577),
    [anon_sym_mutable] = ACTIONS(2577),
    [anon_sym_constinit] = ACTIONS(2577),
    [anon_sym_consteval] = ACTIONS(2577),
    [anon_sym_alignas] = ACTIONS(2577),
    [anon_sym__Alignas] = ACTIONS(2577),
    [sym_primitive_type] = ACTIONS(2577),
    [anon_sym_enum] = ACTIONS(2577),
    [anon_sym_class] = ACTIONS(2577),
    [anon_sym_struct] = ACTIONS(2577),
    [anon_sym_union] = ACTIONS(2577),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_switch] = ACTIONS(2577),
    [anon_sym_case] = ACTIONS(2577),
    [anon_sym_default] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(2577),
    [anon_sym_do] = ACTIONS(2577),
    [anon_sym_for] = ACTIONS(2577),
    [anon_sym_return] = ACTIONS(2577),
    [anon_sym_break] = ACTIONS(2577),
    [anon_sym_continue] = ACTIONS(2577),
    [anon_sym_goto] = ACTIONS(2577),
    [anon_sym___try] = ACTIONS(2577),
    [anon_sym___leave] = ACTIONS(2577),
    [anon_sym_not] = ACTIONS(2577),
    [anon_sym_compl] = ACTIONS(2577),
    [anon_sym_DASH_DASH] = ACTIONS(2579),
    [anon_sym_PLUS_PLUS] = ACTIONS(2579),
    [anon_sym_sizeof] = ACTIONS(2577),
    [anon_sym___alignof__] = ACTIONS(2577),
    [anon_sym___alignof] = ACTIONS(2577),
    [anon_sym__alignof] = ACTIONS(2577),
    [anon_sym_alignof] = ACTIONS(2577),
    [anon_sym__Alignof] = ACTIONS(2577),
    [anon_sym_offsetof] = ACTIONS(2577),
    [anon_sym__Generic] = ACTIONS(2577),
    [anon_sym_asm] = ACTIONS(2577),
    [anon_sym___asm__] = ACTIONS(2577),
    [sym_number_literal] = ACTIONS(2579),
    [anon_sym_L_SQUOTE] = ACTIONS(2579),
    [anon_sym_u_SQUOTE] = ACTIONS(2579),
    [anon_sym_U_SQUOTE] = ACTIONS(2579),
    [anon_sym_u8_SQUOTE] = ACTIONS(2579),
    [anon_sym_SQUOTE] = ACTIONS(2579),
    [anon_sym_L_DQUOTE] = ACTIONS(2579),
    [anon_sym_u_DQUOTE] = ACTIONS(2579),
    [anon_sym_U_DQUOTE] = ACTIONS(2579),
    [anon_sym_u8_DQUOTE] = ACTIONS(2579),
    [anon_sym_DQUOTE] = ACTIONS(2579),
    [sym_true] = ACTIONS(2577),
    [sym_false] = ACTIONS(2577),
    [anon_sym_NULL] = ACTIONS(2577),
    [anon_sym_nullptr] = ACTIONS(2577),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2577),
    [anon_sym_decltype] = ACTIONS(2577),
    [sym_virtual] = ACTIONS(2577),
    [anon_sym_explicit] = ACTIONS(2577),
    [anon_sym_typename] = ACTIONS(2577),
    [anon_sym_template] = ACTIONS(2577),
    [anon_sym_operator] = ACTIONS(2577),
    [anon_sym_try] = ACTIONS(2577),
    [anon_sym_delete] = ACTIONS(2577),
    [anon_sym_throw] = ACTIONS(2577),
    [anon_sym_namespace] = ACTIONS(2577),
    [anon_sym_using] = ACTIONS(2577),
    [anon_sym_static_assert] = ACTIONS(2577),
    [anon_sym_concept] = ACTIONS(2577),
    [anon_sym_co_return] = ACTIONS(2577),
    [anon_sym_co_yield] = ACTIONS(2577),
    [anon_sym_R_DQUOTE] = ACTIONS(2579),
    [anon_sym_LR_DQUOTE] = ACTIONS(2579),
    [anon_sym_uR_DQUOTE] = ACTIONS(2579),
    [anon_sym_UR_DQUOTE] = ACTIONS(2579),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2579),
    [anon_sym_co_await] = ACTIONS(2577),
    [anon_sym_new] = ACTIONS(2577),
    [anon_sym_requires] = ACTIONS(2577),
    [sym_this] = ACTIONS(2577),
    [anon_sym_discard] = ACTIONS(2577),
    [anon_sym_precise] = ACTIONS(2577),
    [anon_sym_shared] = ACTIONS(2577),
    [anon_sym_groupshared] = ACTIONS(2577),
    [anon_sym_uniform] = ACTIONS(2577),
    [anon_sym_row_major] = ACTIONS(2577),
    [anon_sym_column_major] = ACTIONS(2577),
    [anon_sym_globallycoherent] = ACTIONS(2577),
    [anon_sym_centroid] = ACTIONS(2577),
    [anon_sym_noperspective] = ACTIONS(2577),
    [anon_sym_nointerpolation] = ACTIONS(2577),
    [anon_sym_sample] = ACTIONS(2577),
    [anon_sym_linear] = ACTIONS(2577),
    [anon_sym_snorm] = ACTIONS(2577),
    [anon_sym_unorm] = ACTIONS(2577),
    [anon_sym_point] = ACTIONS(2577),
    [anon_sym_line] = ACTIONS(2577),
    [anon_sym_triangleadj] = ACTIONS(2577),
    [anon_sym_lineadj] = ACTIONS(2577),
    [anon_sym_triangle] = ACTIONS(2577),
    [anon_sym_cbuffer] = ACTIONS(2577),
  },
  [688] = {
    [sym_identifier] = ACTIONS(2561),
    [aux_sym_preproc_include_token1] = ACTIONS(2561),
    [aux_sym_preproc_def_token1] = ACTIONS(2561),
    [aux_sym_preproc_if_token1] = ACTIONS(2561),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2561),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2561),
    [sym_preproc_directive] = ACTIONS(2561),
    [anon_sym_LPAREN2] = ACTIONS(2563),
    [anon_sym_BANG] = ACTIONS(2563),
    [anon_sym_TILDE] = ACTIONS(2563),
    [anon_sym_DASH] = ACTIONS(2561),
    [anon_sym_PLUS] = ACTIONS(2561),
    [anon_sym_STAR] = ACTIONS(2563),
    [anon_sym_AMP_AMP] = ACTIONS(2563),
    [anon_sym_AMP] = ACTIONS(2561),
    [anon_sym_SEMI] = ACTIONS(2563),
    [anon_sym___extension__] = ACTIONS(2561),
    [anon_sym_typedef] = ACTIONS(2561),
    [anon_sym_in] = ACTIONS(2561),
    [anon_sym_out] = ACTIONS(2561),
    [anon_sym_inout] = ACTIONS(2561),
    [anon_sym_extern] = ACTIONS(2561),
    [anon_sym___attribute__] = ACTIONS(2561),
    [anon_sym_COLON_COLON] = ACTIONS(2563),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2563),
    [anon_sym___declspec] = ACTIONS(2561),
    [anon_sym___based] = ACTIONS(2561),
    [anon_sym___cdecl] = ACTIONS(2561),
    [anon_sym___clrcall] = ACTIONS(2561),
    [anon_sym___stdcall] = ACTIONS(2561),
    [anon_sym___fastcall] = ACTIONS(2561),
    [anon_sym___thiscall] = ACTIONS(2561),
    [anon_sym___vectorcall] = ACTIONS(2561),
    [anon_sym_LBRACE] = ACTIONS(2563),
    [anon_sym_RBRACE] = ACTIONS(2563),
    [anon_sym_signed] = ACTIONS(2561),
    [anon_sym_unsigned] = ACTIONS(2561),
    [anon_sym_long] = ACTIONS(2561),
    [anon_sym_short] = ACTIONS(2561),
    [anon_sym_LBRACK] = ACTIONS(2561),
    [anon_sym_static] = ACTIONS(2561),
    [anon_sym_register] = ACTIONS(2561),
    [anon_sym_inline] = ACTIONS(2561),
    [anon_sym___inline] = ACTIONS(2561),
    [anon_sym___inline__] = ACTIONS(2561),
    [anon_sym___forceinline] = ACTIONS(2561),
    [anon_sym_thread_local] = ACTIONS(2561),
    [anon_sym___thread] = ACTIONS(2561),
    [anon_sym_const] = ACTIONS(2561),
    [anon_sym_constexpr] = ACTIONS(2561),
    [anon_sym_volatile] = ACTIONS(2561),
    [anon_sym_restrict] = ACTIONS(2561),
    [anon_sym___restrict__] = ACTIONS(2561),
    [anon_sym__Atomic] = ACTIONS(2561),
    [anon_sym__Noreturn] = ACTIONS(2561),
    [anon_sym_noreturn] = ACTIONS(2561),
    [anon_sym_mutable] = ACTIONS(2561),
    [anon_sym_constinit] = ACTIONS(2561),
    [anon_sym_consteval] = ACTIONS(2561),
    [anon_sym_alignas] = ACTIONS(2561),
    [anon_sym__Alignas] = ACTIONS(2561),
    [sym_primitive_type] = ACTIONS(2561),
    [anon_sym_enum] = ACTIONS(2561),
    [anon_sym_class] = ACTIONS(2561),
    [anon_sym_struct] = ACTIONS(2561),
    [anon_sym_union] = ACTIONS(2561),
    [anon_sym_if] = ACTIONS(2561),
    [anon_sym_switch] = ACTIONS(2561),
    [anon_sym_case] = ACTIONS(2561),
    [anon_sym_default] = ACTIONS(2561),
    [anon_sym_while] = ACTIONS(2561),
    [anon_sym_do] = ACTIONS(2561),
    [anon_sym_for] = ACTIONS(2561),
    [anon_sym_return] = ACTIONS(2561),
    [anon_sym_break] = ACTIONS(2561),
    [anon_sym_continue] = ACTIONS(2561),
    [anon_sym_goto] = ACTIONS(2561),
    [anon_sym___try] = ACTIONS(2561),
    [anon_sym___leave] = ACTIONS(2561),
    [anon_sym_not] = ACTIONS(2561),
    [anon_sym_compl] = ACTIONS(2561),
    [anon_sym_DASH_DASH] = ACTIONS(2563),
    [anon_sym_PLUS_PLUS] = ACTIONS(2563),
    [anon_sym_sizeof] = ACTIONS(2561),
    [anon_sym___alignof__] = ACTIONS(2561),
    [anon_sym___alignof] = ACTIONS(2561),
    [anon_sym__alignof] = ACTIONS(2561),
    [anon_sym_alignof] = ACTIONS(2561),
    [anon_sym__Alignof] = ACTIONS(2561),
    [anon_sym_offsetof] = ACTIONS(2561),
    [anon_sym__Generic] = ACTIONS(2561),
    [anon_sym_asm] = ACTIONS(2561),
    [anon_sym___asm__] = ACTIONS(2561),
    [sym_number_literal] = ACTIONS(2563),
    [anon_sym_L_SQUOTE] = ACTIONS(2563),
    [anon_sym_u_SQUOTE] = ACTIONS(2563),
    [anon_sym_U_SQUOTE] = ACTIONS(2563),
    [anon_sym_u8_SQUOTE] = ACTIONS(2563),
    [anon_sym_SQUOTE] = ACTIONS(2563),
    [anon_sym_L_DQUOTE] = ACTIONS(2563),
    [anon_sym_u_DQUOTE] = ACTIONS(2563),
    [anon_sym_U_DQUOTE] = ACTIONS(2563),
    [anon_sym_u8_DQUOTE] = ACTIONS(2563),
    [anon_sym_DQUOTE] = ACTIONS(2563),
    [sym_true] = ACTIONS(2561),
    [sym_false] = ACTIONS(2561),
    [anon_sym_NULL] = ACTIONS(2561),
    [anon_sym_nullptr] = ACTIONS(2561),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2561),
    [anon_sym_decltype] = ACTIONS(2561),
    [sym_virtual] = ACTIONS(2561),
    [anon_sym_explicit] = ACTIONS(2561),
    [anon_sym_typename] = ACTIONS(2561),
    [anon_sym_template] = ACTIONS(2561),
    [anon_sym_operator] = ACTIONS(2561),
    [anon_sym_try] = ACTIONS(2561),
    [anon_sym_delete] = ACTIONS(2561),
    [anon_sym_throw] = ACTIONS(2561),
    [anon_sym_namespace] = ACTIONS(2561),
    [anon_sym_using] = ACTIONS(2561),
    [anon_sym_static_assert] = ACTIONS(2561),
    [anon_sym_concept] = ACTIONS(2561),
    [anon_sym_co_return] = ACTIONS(2561),
    [anon_sym_co_yield] = ACTIONS(2561),
    [anon_sym_R_DQUOTE] = ACTIONS(2563),
    [anon_sym_LR_DQUOTE] = ACTIONS(2563),
    [anon_sym_uR_DQUOTE] = ACTIONS(2563),
    [anon_sym_UR_DQUOTE] = ACTIONS(2563),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2563),
    [anon_sym_co_await] = ACTIONS(2561),
    [anon_sym_new] = ACTIONS(2561),
    [anon_sym_requires] = ACTIONS(2561),
    [sym_this] = ACTIONS(2561),
    [anon_sym_discard] = ACTIONS(2561),
    [anon_sym_precise] = ACTIONS(2561),
    [anon_sym_shared] = ACTIONS(2561),
    [anon_sym_groupshared] = ACTIONS(2561),
    [anon_sym_uniform] = ACTIONS(2561),
    [anon_sym_row_major] = ACTIONS(2561),
    [anon_sym_column_major] = ACTIONS(2561),
    [anon_sym_globallycoherent] = ACTIONS(2561),
    [anon_sym_centroid] = ACTIONS(2561),
    [anon_sym_noperspective] = ACTIONS(2561),
    [anon_sym_nointerpolation] = ACTIONS(2561),
    [anon_sym_sample] = ACTIONS(2561),
    [anon_sym_linear] = ACTIONS(2561),
    [anon_sym_snorm] = ACTIONS(2561),
    [anon_sym_unorm] = ACTIONS(2561),
    [anon_sym_point] = ACTIONS(2561),
    [anon_sym_line] = ACTIONS(2561),
    [anon_sym_triangleadj] = ACTIONS(2561),
    [anon_sym_lineadj] = ACTIONS(2561),
    [anon_sym_triangle] = ACTIONS(2561),
    [anon_sym_cbuffer] = ACTIONS(2561),
  },
  [689] = {
    [sym_identifier] = ACTIONS(2454),
    [aux_sym_preproc_include_token1] = ACTIONS(2454),
    [aux_sym_preproc_def_token1] = ACTIONS(2454),
    [aux_sym_preproc_if_token1] = ACTIONS(2454),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2454),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2454),
    [sym_preproc_directive] = ACTIONS(2454),
    [anon_sym_LPAREN2] = ACTIONS(2456),
    [anon_sym_BANG] = ACTIONS(2456),
    [anon_sym_TILDE] = ACTIONS(2456),
    [anon_sym_DASH] = ACTIONS(2454),
    [anon_sym_PLUS] = ACTIONS(2454),
    [anon_sym_STAR] = ACTIONS(2456),
    [anon_sym_AMP_AMP] = ACTIONS(2456),
    [anon_sym_AMP] = ACTIONS(2454),
    [anon_sym_SEMI] = ACTIONS(2456),
    [anon_sym___extension__] = ACTIONS(2454),
    [anon_sym_typedef] = ACTIONS(2454),
    [anon_sym_in] = ACTIONS(2454),
    [anon_sym_out] = ACTIONS(2454),
    [anon_sym_inout] = ACTIONS(2454),
    [anon_sym_extern] = ACTIONS(2454),
    [anon_sym___attribute__] = ACTIONS(2454),
    [anon_sym_COLON_COLON] = ACTIONS(2456),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2456),
    [anon_sym___declspec] = ACTIONS(2454),
    [anon_sym___based] = ACTIONS(2454),
    [anon_sym___cdecl] = ACTIONS(2454),
    [anon_sym___clrcall] = ACTIONS(2454),
    [anon_sym___stdcall] = ACTIONS(2454),
    [anon_sym___fastcall] = ACTIONS(2454),
    [anon_sym___thiscall] = ACTIONS(2454),
    [anon_sym___vectorcall] = ACTIONS(2454),
    [anon_sym_LBRACE] = ACTIONS(2456),
    [anon_sym_RBRACE] = ACTIONS(2456),
    [anon_sym_signed] = ACTIONS(2454),
    [anon_sym_unsigned] = ACTIONS(2454),
    [anon_sym_long] = ACTIONS(2454),
    [anon_sym_short] = ACTIONS(2454),
    [anon_sym_LBRACK] = ACTIONS(2454),
    [anon_sym_static] = ACTIONS(2454),
    [anon_sym_register] = ACTIONS(2454),
    [anon_sym_inline] = ACTIONS(2454),
    [anon_sym___inline] = ACTIONS(2454),
    [anon_sym___inline__] = ACTIONS(2454),
    [anon_sym___forceinline] = ACTIONS(2454),
    [anon_sym_thread_local] = ACTIONS(2454),
    [anon_sym___thread] = ACTIONS(2454),
    [anon_sym_const] = ACTIONS(2454),
    [anon_sym_constexpr] = ACTIONS(2454),
    [anon_sym_volatile] = ACTIONS(2454),
    [anon_sym_restrict] = ACTIONS(2454),
    [anon_sym___restrict__] = ACTIONS(2454),
    [anon_sym__Atomic] = ACTIONS(2454),
    [anon_sym__Noreturn] = ACTIONS(2454),
    [anon_sym_noreturn] = ACTIONS(2454),
    [anon_sym_mutable] = ACTIONS(2454),
    [anon_sym_constinit] = ACTIONS(2454),
    [anon_sym_consteval] = ACTIONS(2454),
    [anon_sym_alignas] = ACTIONS(2454),
    [anon_sym__Alignas] = ACTIONS(2454),
    [sym_primitive_type] = ACTIONS(2454),
    [anon_sym_enum] = ACTIONS(2454),
    [anon_sym_class] = ACTIONS(2454),
    [anon_sym_struct] = ACTIONS(2454),
    [anon_sym_union] = ACTIONS(2454),
    [anon_sym_if] = ACTIONS(2454),
    [anon_sym_switch] = ACTIONS(2454),
    [anon_sym_case] = ACTIONS(2454),
    [anon_sym_default] = ACTIONS(2454),
    [anon_sym_while] = ACTIONS(2454),
    [anon_sym_do] = ACTIONS(2454),
    [anon_sym_for] = ACTIONS(2454),
    [anon_sym_return] = ACTIONS(2454),
    [anon_sym_break] = ACTIONS(2454),
    [anon_sym_continue] = ACTIONS(2454),
    [anon_sym_goto] = ACTIONS(2454),
    [anon_sym___try] = ACTIONS(2454),
    [anon_sym___leave] = ACTIONS(2454),
    [anon_sym_not] = ACTIONS(2454),
    [anon_sym_compl] = ACTIONS(2454),
    [anon_sym_DASH_DASH] = ACTIONS(2456),
    [anon_sym_PLUS_PLUS] = ACTIONS(2456),
    [anon_sym_sizeof] = ACTIONS(2454),
    [anon_sym___alignof__] = ACTIONS(2454),
    [anon_sym___alignof] = ACTIONS(2454),
    [anon_sym__alignof] = ACTIONS(2454),
    [anon_sym_alignof] = ACTIONS(2454),
    [anon_sym__Alignof] = ACTIONS(2454),
    [anon_sym_offsetof] = ACTIONS(2454),
    [anon_sym__Generic] = ACTIONS(2454),
    [anon_sym_asm] = ACTIONS(2454),
    [anon_sym___asm__] = ACTIONS(2454),
    [sym_number_literal] = ACTIONS(2456),
    [anon_sym_L_SQUOTE] = ACTIONS(2456),
    [anon_sym_u_SQUOTE] = ACTIONS(2456),
    [anon_sym_U_SQUOTE] = ACTIONS(2456),
    [anon_sym_u8_SQUOTE] = ACTIONS(2456),
    [anon_sym_SQUOTE] = ACTIONS(2456),
    [anon_sym_L_DQUOTE] = ACTIONS(2456),
    [anon_sym_u_DQUOTE] = ACTIONS(2456),
    [anon_sym_U_DQUOTE] = ACTIONS(2456),
    [anon_sym_u8_DQUOTE] = ACTIONS(2456),
    [anon_sym_DQUOTE] = ACTIONS(2456),
    [sym_true] = ACTIONS(2454),
    [sym_false] = ACTIONS(2454),
    [anon_sym_NULL] = ACTIONS(2454),
    [anon_sym_nullptr] = ACTIONS(2454),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2454),
    [anon_sym_decltype] = ACTIONS(2454),
    [sym_virtual] = ACTIONS(2454),
    [anon_sym_explicit] = ACTIONS(2454),
    [anon_sym_typename] = ACTIONS(2454),
    [anon_sym_template] = ACTIONS(2454),
    [anon_sym_operator] = ACTIONS(2454),
    [anon_sym_try] = ACTIONS(2454),
    [anon_sym_delete] = ACTIONS(2454),
    [anon_sym_throw] = ACTIONS(2454),
    [anon_sym_namespace] = ACTIONS(2454),
    [anon_sym_using] = ACTIONS(2454),
    [anon_sym_static_assert] = ACTIONS(2454),
    [anon_sym_concept] = ACTIONS(2454),
    [anon_sym_co_return] = ACTIONS(2454),
    [anon_sym_co_yield] = ACTIONS(2454),
    [anon_sym_R_DQUOTE] = ACTIONS(2456),
    [anon_sym_LR_DQUOTE] = ACTIONS(2456),
    [anon_sym_uR_DQUOTE] = ACTIONS(2456),
    [anon_sym_UR_DQUOTE] = ACTIONS(2456),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2456),
    [anon_sym_co_await] = ACTIONS(2454),
    [anon_sym_new] = ACTIONS(2454),
    [anon_sym_requires] = ACTIONS(2454),
    [sym_this] = ACTIONS(2454),
    [anon_sym_discard] = ACTIONS(2454),
    [anon_sym_precise] = ACTIONS(2454),
    [anon_sym_shared] = ACTIONS(2454),
    [anon_sym_groupshared] = ACTIONS(2454),
    [anon_sym_uniform] = ACTIONS(2454),
    [anon_sym_row_major] = ACTIONS(2454),
    [anon_sym_column_major] = ACTIONS(2454),
    [anon_sym_globallycoherent] = ACTIONS(2454),
    [anon_sym_centroid] = ACTIONS(2454),
    [anon_sym_noperspective] = ACTIONS(2454),
    [anon_sym_nointerpolation] = ACTIONS(2454),
    [anon_sym_sample] = ACTIONS(2454),
    [anon_sym_linear] = ACTIONS(2454),
    [anon_sym_snorm] = ACTIONS(2454),
    [anon_sym_unorm] = ACTIONS(2454),
    [anon_sym_point] = ACTIONS(2454),
    [anon_sym_line] = ACTIONS(2454),
    [anon_sym_triangleadj] = ACTIONS(2454),
    [anon_sym_lineadj] = ACTIONS(2454),
    [anon_sym_triangle] = ACTIONS(2454),
    [anon_sym_cbuffer] = ACTIONS(2454),
  },
  [690] = {
    [sym_identifier] = ACTIONS(2462),
    [aux_sym_preproc_include_token1] = ACTIONS(2462),
    [aux_sym_preproc_def_token1] = ACTIONS(2462),
    [aux_sym_preproc_if_token1] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2462),
    [sym_preproc_directive] = ACTIONS(2462),
    [anon_sym_LPAREN2] = ACTIONS(2464),
    [anon_sym_BANG] = ACTIONS(2464),
    [anon_sym_TILDE] = ACTIONS(2464),
    [anon_sym_DASH] = ACTIONS(2462),
    [anon_sym_PLUS] = ACTIONS(2462),
    [anon_sym_STAR] = ACTIONS(2464),
    [anon_sym_AMP_AMP] = ACTIONS(2464),
    [anon_sym_AMP] = ACTIONS(2462),
    [anon_sym_SEMI] = ACTIONS(2464),
    [anon_sym___extension__] = ACTIONS(2462),
    [anon_sym_typedef] = ACTIONS(2462),
    [anon_sym_in] = ACTIONS(2462),
    [anon_sym_out] = ACTIONS(2462),
    [anon_sym_inout] = ACTIONS(2462),
    [anon_sym_extern] = ACTIONS(2462),
    [anon_sym___attribute__] = ACTIONS(2462),
    [anon_sym_COLON_COLON] = ACTIONS(2464),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2464),
    [anon_sym___declspec] = ACTIONS(2462),
    [anon_sym___based] = ACTIONS(2462),
    [anon_sym___cdecl] = ACTIONS(2462),
    [anon_sym___clrcall] = ACTIONS(2462),
    [anon_sym___stdcall] = ACTIONS(2462),
    [anon_sym___fastcall] = ACTIONS(2462),
    [anon_sym___thiscall] = ACTIONS(2462),
    [anon_sym___vectorcall] = ACTIONS(2462),
    [anon_sym_LBRACE] = ACTIONS(2464),
    [anon_sym_RBRACE] = ACTIONS(2464),
    [anon_sym_signed] = ACTIONS(2462),
    [anon_sym_unsigned] = ACTIONS(2462),
    [anon_sym_long] = ACTIONS(2462),
    [anon_sym_short] = ACTIONS(2462),
    [anon_sym_LBRACK] = ACTIONS(2462),
    [anon_sym_static] = ACTIONS(2462),
    [anon_sym_register] = ACTIONS(2462),
    [anon_sym_inline] = ACTIONS(2462),
    [anon_sym___inline] = ACTIONS(2462),
    [anon_sym___inline__] = ACTIONS(2462),
    [anon_sym___forceinline] = ACTIONS(2462),
    [anon_sym_thread_local] = ACTIONS(2462),
    [anon_sym___thread] = ACTIONS(2462),
    [anon_sym_const] = ACTIONS(2462),
    [anon_sym_constexpr] = ACTIONS(2462),
    [anon_sym_volatile] = ACTIONS(2462),
    [anon_sym_restrict] = ACTIONS(2462),
    [anon_sym___restrict__] = ACTIONS(2462),
    [anon_sym__Atomic] = ACTIONS(2462),
    [anon_sym__Noreturn] = ACTIONS(2462),
    [anon_sym_noreturn] = ACTIONS(2462),
    [anon_sym_mutable] = ACTIONS(2462),
    [anon_sym_constinit] = ACTIONS(2462),
    [anon_sym_consteval] = ACTIONS(2462),
    [anon_sym_alignas] = ACTIONS(2462),
    [anon_sym__Alignas] = ACTIONS(2462),
    [sym_primitive_type] = ACTIONS(2462),
    [anon_sym_enum] = ACTIONS(2462),
    [anon_sym_class] = ACTIONS(2462),
    [anon_sym_struct] = ACTIONS(2462),
    [anon_sym_union] = ACTIONS(2462),
    [anon_sym_if] = ACTIONS(2462),
    [anon_sym_switch] = ACTIONS(2462),
    [anon_sym_case] = ACTIONS(2462),
    [anon_sym_default] = ACTIONS(2462),
    [anon_sym_while] = ACTIONS(2462),
    [anon_sym_do] = ACTIONS(2462),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_break] = ACTIONS(2462),
    [anon_sym_continue] = ACTIONS(2462),
    [anon_sym_goto] = ACTIONS(2462),
    [anon_sym___try] = ACTIONS(2462),
    [anon_sym___leave] = ACTIONS(2462),
    [anon_sym_not] = ACTIONS(2462),
    [anon_sym_compl] = ACTIONS(2462),
    [anon_sym_DASH_DASH] = ACTIONS(2464),
    [anon_sym_PLUS_PLUS] = ACTIONS(2464),
    [anon_sym_sizeof] = ACTIONS(2462),
    [anon_sym___alignof__] = ACTIONS(2462),
    [anon_sym___alignof] = ACTIONS(2462),
    [anon_sym__alignof] = ACTIONS(2462),
    [anon_sym_alignof] = ACTIONS(2462),
    [anon_sym__Alignof] = ACTIONS(2462),
    [anon_sym_offsetof] = ACTIONS(2462),
    [anon_sym__Generic] = ACTIONS(2462),
    [anon_sym_asm] = ACTIONS(2462),
    [anon_sym___asm__] = ACTIONS(2462),
    [sym_number_literal] = ACTIONS(2464),
    [anon_sym_L_SQUOTE] = ACTIONS(2464),
    [anon_sym_u_SQUOTE] = ACTIONS(2464),
    [anon_sym_U_SQUOTE] = ACTIONS(2464),
    [anon_sym_u8_SQUOTE] = ACTIONS(2464),
    [anon_sym_SQUOTE] = ACTIONS(2464),
    [anon_sym_L_DQUOTE] = ACTIONS(2464),
    [anon_sym_u_DQUOTE] = ACTIONS(2464),
    [anon_sym_U_DQUOTE] = ACTIONS(2464),
    [anon_sym_u8_DQUOTE] = ACTIONS(2464),
    [anon_sym_DQUOTE] = ACTIONS(2464),
    [sym_true] = ACTIONS(2462),
    [sym_false] = ACTIONS(2462),
    [anon_sym_NULL] = ACTIONS(2462),
    [anon_sym_nullptr] = ACTIONS(2462),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2462),
    [anon_sym_decltype] = ACTIONS(2462),
    [sym_virtual] = ACTIONS(2462),
    [anon_sym_explicit] = ACTIONS(2462),
    [anon_sym_typename] = ACTIONS(2462),
    [anon_sym_template] = ACTIONS(2462),
    [anon_sym_operator] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2462),
    [anon_sym_delete] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2462),
    [anon_sym_namespace] = ACTIONS(2462),
    [anon_sym_using] = ACTIONS(2462),
    [anon_sym_static_assert] = ACTIONS(2462),
    [anon_sym_concept] = ACTIONS(2462),
    [anon_sym_co_return] = ACTIONS(2462),
    [anon_sym_co_yield] = ACTIONS(2462),
    [anon_sym_R_DQUOTE] = ACTIONS(2464),
    [anon_sym_LR_DQUOTE] = ACTIONS(2464),
    [anon_sym_uR_DQUOTE] = ACTIONS(2464),
    [anon_sym_UR_DQUOTE] = ACTIONS(2464),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2464),
    [anon_sym_co_await] = ACTIONS(2462),
    [anon_sym_new] = ACTIONS(2462),
    [anon_sym_requires] = ACTIONS(2462),
    [sym_this] = ACTIONS(2462),
    [anon_sym_discard] = ACTIONS(2462),
    [anon_sym_precise] = ACTIONS(2462),
    [anon_sym_shared] = ACTIONS(2462),
    [anon_sym_groupshared] = ACTIONS(2462),
    [anon_sym_uniform] = ACTIONS(2462),
    [anon_sym_row_major] = ACTIONS(2462),
    [anon_sym_column_major] = ACTIONS(2462),
    [anon_sym_globallycoherent] = ACTIONS(2462),
    [anon_sym_centroid] = ACTIONS(2462),
    [anon_sym_noperspective] = ACTIONS(2462),
    [anon_sym_nointerpolation] = ACTIONS(2462),
    [anon_sym_sample] = ACTIONS(2462),
    [anon_sym_linear] = ACTIONS(2462),
    [anon_sym_snorm] = ACTIONS(2462),
    [anon_sym_unorm] = ACTIONS(2462),
    [anon_sym_point] = ACTIONS(2462),
    [anon_sym_line] = ACTIONS(2462),
    [anon_sym_triangleadj] = ACTIONS(2462),
    [anon_sym_lineadj] = ACTIONS(2462),
    [anon_sym_triangle] = ACTIONS(2462),
    [anon_sym_cbuffer] = ACTIONS(2462),
  },
  [691] = {
    [sym_identifier] = ACTIONS(2462),
    [aux_sym_preproc_include_token1] = ACTIONS(2462),
    [aux_sym_preproc_def_token1] = ACTIONS(2462),
    [aux_sym_preproc_if_token1] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2462),
    [sym_preproc_directive] = ACTIONS(2462),
    [anon_sym_LPAREN2] = ACTIONS(2464),
    [anon_sym_BANG] = ACTIONS(2464),
    [anon_sym_TILDE] = ACTIONS(2464),
    [anon_sym_DASH] = ACTIONS(2462),
    [anon_sym_PLUS] = ACTIONS(2462),
    [anon_sym_STAR] = ACTIONS(2464),
    [anon_sym_AMP_AMP] = ACTIONS(2464),
    [anon_sym_AMP] = ACTIONS(2462),
    [anon_sym_SEMI] = ACTIONS(2464),
    [anon_sym___extension__] = ACTIONS(2462),
    [anon_sym_typedef] = ACTIONS(2462),
    [anon_sym_in] = ACTIONS(2462),
    [anon_sym_out] = ACTIONS(2462),
    [anon_sym_inout] = ACTIONS(2462),
    [anon_sym_extern] = ACTIONS(2462),
    [anon_sym___attribute__] = ACTIONS(2462),
    [anon_sym_COLON_COLON] = ACTIONS(2464),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2464),
    [anon_sym___declspec] = ACTIONS(2462),
    [anon_sym___based] = ACTIONS(2462),
    [anon_sym___cdecl] = ACTIONS(2462),
    [anon_sym___clrcall] = ACTIONS(2462),
    [anon_sym___stdcall] = ACTIONS(2462),
    [anon_sym___fastcall] = ACTIONS(2462),
    [anon_sym___thiscall] = ACTIONS(2462),
    [anon_sym___vectorcall] = ACTIONS(2462),
    [anon_sym_LBRACE] = ACTIONS(2464),
    [anon_sym_RBRACE] = ACTIONS(2464),
    [anon_sym_signed] = ACTIONS(2462),
    [anon_sym_unsigned] = ACTIONS(2462),
    [anon_sym_long] = ACTIONS(2462),
    [anon_sym_short] = ACTIONS(2462),
    [anon_sym_LBRACK] = ACTIONS(2462),
    [anon_sym_static] = ACTIONS(2462),
    [anon_sym_register] = ACTIONS(2462),
    [anon_sym_inline] = ACTIONS(2462),
    [anon_sym___inline] = ACTIONS(2462),
    [anon_sym___inline__] = ACTIONS(2462),
    [anon_sym___forceinline] = ACTIONS(2462),
    [anon_sym_thread_local] = ACTIONS(2462),
    [anon_sym___thread] = ACTIONS(2462),
    [anon_sym_const] = ACTIONS(2462),
    [anon_sym_constexpr] = ACTIONS(2462),
    [anon_sym_volatile] = ACTIONS(2462),
    [anon_sym_restrict] = ACTIONS(2462),
    [anon_sym___restrict__] = ACTIONS(2462),
    [anon_sym__Atomic] = ACTIONS(2462),
    [anon_sym__Noreturn] = ACTIONS(2462),
    [anon_sym_noreturn] = ACTIONS(2462),
    [anon_sym_mutable] = ACTIONS(2462),
    [anon_sym_constinit] = ACTIONS(2462),
    [anon_sym_consteval] = ACTIONS(2462),
    [anon_sym_alignas] = ACTIONS(2462),
    [anon_sym__Alignas] = ACTIONS(2462),
    [sym_primitive_type] = ACTIONS(2462),
    [anon_sym_enum] = ACTIONS(2462),
    [anon_sym_class] = ACTIONS(2462),
    [anon_sym_struct] = ACTIONS(2462),
    [anon_sym_union] = ACTIONS(2462),
    [anon_sym_if] = ACTIONS(2462),
    [anon_sym_switch] = ACTIONS(2462),
    [anon_sym_case] = ACTIONS(2462),
    [anon_sym_default] = ACTIONS(2462),
    [anon_sym_while] = ACTIONS(2462),
    [anon_sym_do] = ACTIONS(2462),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_break] = ACTIONS(2462),
    [anon_sym_continue] = ACTIONS(2462),
    [anon_sym_goto] = ACTIONS(2462),
    [anon_sym___try] = ACTIONS(2462),
    [anon_sym___leave] = ACTIONS(2462),
    [anon_sym_not] = ACTIONS(2462),
    [anon_sym_compl] = ACTIONS(2462),
    [anon_sym_DASH_DASH] = ACTIONS(2464),
    [anon_sym_PLUS_PLUS] = ACTIONS(2464),
    [anon_sym_sizeof] = ACTIONS(2462),
    [anon_sym___alignof__] = ACTIONS(2462),
    [anon_sym___alignof] = ACTIONS(2462),
    [anon_sym__alignof] = ACTIONS(2462),
    [anon_sym_alignof] = ACTIONS(2462),
    [anon_sym__Alignof] = ACTIONS(2462),
    [anon_sym_offsetof] = ACTIONS(2462),
    [anon_sym__Generic] = ACTIONS(2462),
    [anon_sym_asm] = ACTIONS(2462),
    [anon_sym___asm__] = ACTIONS(2462),
    [sym_number_literal] = ACTIONS(2464),
    [anon_sym_L_SQUOTE] = ACTIONS(2464),
    [anon_sym_u_SQUOTE] = ACTIONS(2464),
    [anon_sym_U_SQUOTE] = ACTIONS(2464),
    [anon_sym_u8_SQUOTE] = ACTIONS(2464),
    [anon_sym_SQUOTE] = ACTIONS(2464),
    [anon_sym_L_DQUOTE] = ACTIONS(2464),
    [anon_sym_u_DQUOTE] = ACTIONS(2464),
    [anon_sym_U_DQUOTE] = ACTIONS(2464),
    [anon_sym_u8_DQUOTE] = ACTIONS(2464),
    [anon_sym_DQUOTE] = ACTIONS(2464),
    [sym_true] = ACTIONS(2462),
    [sym_false] = ACTIONS(2462),
    [anon_sym_NULL] = ACTIONS(2462),
    [anon_sym_nullptr] = ACTIONS(2462),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2462),
    [anon_sym_decltype] = ACTIONS(2462),
    [sym_virtual] = ACTIONS(2462),
    [anon_sym_explicit] = ACTIONS(2462),
    [anon_sym_typename] = ACTIONS(2462),
    [anon_sym_template] = ACTIONS(2462),
    [anon_sym_operator] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2462),
    [anon_sym_delete] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2462),
    [anon_sym_namespace] = ACTIONS(2462),
    [anon_sym_using] = ACTIONS(2462),
    [anon_sym_static_assert] = ACTIONS(2462),
    [anon_sym_concept] = ACTIONS(2462),
    [anon_sym_co_return] = ACTIONS(2462),
    [anon_sym_co_yield] = ACTIONS(2462),
    [anon_sym_R_DQUOTE] = ACTIONS(2464),
    [anon_sym_LR_DQUOTE] = ACTIONS(2464),
    [anon_sym_uR_DQUOTE] = ACTIONS(2464),
    [anon_sym_UR_DQUOTE] = ACTIONS(2464),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2464),
    [anon_sym_co_await] = ACTIONS(2462),
    [anon_sym_new] = ACTIONS(2462),
    [anon_sym_requires] = ACTIONS(2462),
    [sym_this] = ACTIONS(2462),
    [anon_sym_discard] = ACTIONS(2462),
    [anon_sym_precise] = ACTIONS(2462),
    [anon_sym_shared] = ACTIONS(2462),
    [anon_sym_groupshared] = ACTIONS(2462),
    [anon_sym_uniform] = ACTIONS(2462),
    [anon_sym_row_major] = ACTIONS(2462),
    [anon_sym_column_major] = ACTIONS(2462),
    [anon_sym_globallycoherent] = ACTIONS(2462),
    [anon_sym_centroid] = ACTIONS(2462),
    [anon_sym_noperspective] = ACTIONS(2462),
    [anon_sym_nointerpolation] = ACTIONS(2462),
    [anon_sym_sample] = ACTIONS(2462),
    [anon_sym_linear] = ACTIONS(2462),
    [anon_sym_snorm] = ACTIONS(2462),
    [anon_sym_unorm] = ACTIONS(2462),
    [anon_sym_point] = ACTIONS(2462),
    [anon_sym_line] = ACTIONS(2462),
    [anon_sym_triangleadj] = ACTIONS(2462),
    [anon_sym_lineadj] = ACTIONS(2462),
    [anon_sym_triangle] = ACTIONS(2462),
    [anon_sym_cbuffer] = ACTIONS(2462),
  },
  [692] = {
    [sym_identifier] = ACTIONS(2470),
    [aux_sym_preproc_include_token1] = ACTIONS(2470),
    [aux_sym_preproc_def_token1] = ACTIONS(2470),
    [aux_sym_preproc_if_token1] = ACTIONS(2470),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2470),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2470),
    [sym_preproc_directive] = ACTIONS(2470),
    [anon_sym_LPAREN2] = ACTIONS(2472),
    [anon_sym_BANG] = ACTIONS(2472),
    [anon_sym_TILDE] = ACTIONS(2472),
    [anon_sym_DASH] = ACTIONS(2470),
    [anon_sym_PLUS] = ACTIONS(2470),
    [anon_sym_STAR] = ACTIONS(2472),
    [anon_sym_AMP_AMP] = ACTIONS(2472),
    [anon_sym_AMP] = ACTIONS(2470),
    [anon_sym_SEMI] = ACTIONS(2472),
    [anon_sym___extension__] = ACTIONS(2470),
    [anon_sym_typedef] = ACTIONS(2470),
    [anon_sym_in] = ACTIONS(2470),
    [anon_sym_out] = ACTIONS(2470),
    [anon_sym_inout] = ACTIONS(2470),
    [anon_sym_extern] = ACTIONS(2470),
    [anon_sym___attribute__] = ACTIONS(2470),
    [anon_sym_COLON_COLON] = ACTIONS(2472),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2472),
    [anon_sym___declspec] = ACTIONS(2470),
    [anon_sym___based] = ACTIONS(2470),
    [anon_sym___cdecl] = ACTIONS(2470),
    [anon_sym___clrcall] = ACTIONS(2470),
    [anon_sym___stdcall] = ACTIONS(2470),
    [anon_sym___fastcall] = ACTIONS(2470),
    [anon_sym___thiscall] = ACTIONS(2470),
    [anon_sym___vectorcall] = ACTIONS(2470),
    [anon_sym_LBRACE] = ACTIONS(2472),
    [anon_sym_RBRACE] = ACTIONS(2472),
    [anon_sym_signed] = ACTIONS(2470),
    [anon_sym_unsigned] = ACTIONS(2470),
    [anon_sym_long] = ACTIONS(2470),
    [anon_sym_short] = ACTIONS(2470),
    [anon_sym_LBRACK] = ACTIONS(2470),
    [anon_sym_static] = ACTIONS(2470),
    [anon_sym_register] = ACTIONS(2470),
    [anon_sym_inline] = ACTIONS(2470),
    [anon_sym___inline] = ACTIONS(2470),
    [anon_sym___inline__] = ACTIONS(2470),
    [anon_sym___forceinline] = ACTIONS(2470),
    [anon_sym_thread_local] = ACTIONS(2470),
    [anon_sym___thread] = ACTIONS(2470),
    [anon_sym_const] = ACTIONS(2470),
    [anon_sym_constexpr] = ACTIONS(2470),
    [anon_sym_volatile] = ACTIONS(2470),
    [anon_sym_restrict] = ACTIONS(2470),
    [anon_sym___restrict__] = ACTIONS(2470),
    [anon_sym__Atomic] = ACTIONS(2470),
    [anon_sym__Noreturn] = ACTIONS(2470),
    [anon_sym_noreturn] = ACTIONS(2470),
    [anon_sym_mutable] = ACTIONS(2470),
    [anon_sym_constinit] = ACTIONS(2470),
    [anon_sym_consteval] = ACTIONS(2470),
    [anon_sym_alignas] = ACTIONS(2470),
    [anon_sym__Alignas] = ACTIONS(2470),
    [sym_primitive_type] = ACTIONS(2470),
    [anon_sym_enum] = ACTIONS(2470),
    [anon_sym_class] = ACTIONS(2470),
    [anon_sym_struct] = ACTIONS(2470),
    [anon_sym_union] = ACTIONS(2470),
    [anon_sym_if] = ACTIONS(2470),
    [anon_sym_switch] = ACTIONS(2470),
    [anon_sym_case] = ACTIONS(2470),
    [anon_sym_default] = ACTIONS(2470),
    [anon_sym_while] = ACTIONS(2470),
    [anon_sym_do] = ACTIONS(2470),
    [anon_sym_for] = ACTIONS(2470),
    [anon_sym_return] = ACTIONS(2470),
    [anon_sym_break] = ACTIONS(2470),
    [anon_sym_continue] = ACTIONS(2470),
    [anon_sym_goto] = ACTIONS(2470),
    [anon_sym___try] = ACTIONS(2470),
    [anon_sym___leave] = ACTIONS(2470),
    [anon_sym_not] = ACTIONS(2470),
    [anon_sym_compl] = ACTIONS(2470),
    [anon_sym_DASH_DASH] = ACTIONS(2472),
    [anon_sym_PLUS_PLUS] = ACTIONS(2472),
    [anon_sym_sizeof] = ACTIONS(2470),
    [anon_sym___alignof__] = ACTIONS(2470),
    [anon_sym___alignof] = ACTIONS(2470),
    [anon_sym__alignof] = ACTIONS(2470),
    [anon_sym_alignof] = ACTIONS(2470),
    [anon_sym__Alignof] = ACTIONS(2470),
    [anon_sym_offsetof] = ACTIONS(2470),
    [anon_sym__Generic] = ACTIONS(2470),
    [anon_sym_asm] = ACTIONS(2470),
    [anon_sym___asm__] = ACTIONS(2470),
    [sym_number_literal] = ACTIONS(2472),
    [anon_sym_L_SQUOTE] = ACTIONS(2472),
    [anon_sym_u_SQUOTE] = ACTIONS(2472),
    [anon_sym_U_SQUOTE] = ACTIONS(2472),
    [anon_sym_u8_SQUOTE] = ACTIONS(2472),
    [anon_sym_SQUOTE] = ACTIONS(2472),
    [anon_sym_L_DQUOTE] = ACTIONS(2472),
    [anon_sym_u_DQUOTE] = ACTIONS(2472),
    [anon_sym_U_DQUOTE] = ACTIONS(2472),
    [anon_sym_u8_DQUOTE] = ACTIONS(2472),
    [anon_sym_DQUOTE] = ACTIONS(2472),
    [sym_true] = ACTIONS(2470),
    [sym_false] = ACTIONS(2470),
    [anon_sym_NULL] = ACTIONS(2470),
    [anon_sym_nullptr] = ACTIONS(2470),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2470),
    [anon_sym_decltype] = ACTIONS(2470),
    [sym_virtual] = ACTIONS(2470),
    [anon_sym_explicit] = ACTIONS(2470),
    [anon_sym_typename] = ACTIONS(2470),
    [anon_sym_template] = ACTIONS(2470),
    [anon_sym_operator] = ACTIONS(2470),
    [anon_sym_try] = ACTIONS(2470),
    [anon_sym_delete] = ACTIONS(2470),
    [anon_sym_throw] = ACTIONS(2470),
    [anon_sym_namespace] = ACTIONS(2470),
    [anon_sym_using] = ACTIONS(2470),
    [anon_sym_static_assert] = ACTIONS(2470),
    [anon_sym_concept] = ACTIONS(2470),
    [anon_sym_co_return] = ACTIONS(2470),
    [anon_sym_co_yield] = ACTIONS(2470),
    [anon_sym_R_DQUOTE] = ACTIONS(2472),
    [anon_sym_LR_DQUOTE] = ACTIONS(2472),
    [anon_sym_uR_DQUOTE] = ACTIONS(2472),
    [anon_sym_UR_DQUOTE] = ACTIONS(2472),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2472),
    [anon_sym_co_await] = ACTIONS(2470),
    [anon_sym_new] = ACTIONS(2470),
    [anon_sym_requires] = ACTIONS(2470),
    [sym_this] = ACTIONS(2470),
    [anon_sym_discard] = ACTIONS(2470),
    [anon_sym_precise] = ACTIONS(2470),
    [anon_sym_shared] = ACTIONS(2470),
    [anon_sym_groupshared] = ACTIONS(2470),
    [anon_sym_uniform] = ACTIONS(2470),
    [anon_sym_row_major] = ACTIONS(2470),
    [anon_sym_column_major] = ACTIONS(2470),
    [anon_sym_globallycoherent] = ACTIONS(2470),
    [anon_sym_centroid] = ACTIONS(2470),
    [anon_sym_noperspective] = ACTIONS(2470),
    [anon_sym_nointerpolation] = ACTIONS(2470),
    [anon_sym_sample] = ACTIONS(2470),
    [anon_sym_linear] = ACTIONS(2470),
    [anon_sym_snorm] = ACTIONS(2470),
    [anon_sym_unorm] = ACTIONS(2470),
    [anon_sym_point] = ACTIONS(2470),
    [anon_sym_line] = ACTIONS(2470),
    [anon_sym_triangleadj] = ACTIONS(2470),
    [anon_sym_lineadj] = ACTIONS(2470),
    [anon_sym_triangle] = ACTIONS(2470),
    [anon_sym_cbuffer] = ACTIONS(2470),
  },
  [693] = {
    [sym_identifier] = ACTIONS(2474),
    [aux_sym_preproc_include_token1] = ACTIONS(2474),
    [aux_sym_preproc_def_token1] = ACTIONS(2474),
    [aux_sym_preproc_if_token1] = ACTIONS(2474),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2474),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2474),
    [sym_preproc_directive] = ACTIONS(2474),
    [anon_sym_LPAREN2] = ACTIONS(2476),
    [anon_sym_BANG] = ACTIONS(2476),
    [anon_sym_TILDE] = ACTIONS(2476),
    [anon_sym_DASH] = ACTIONS(2474),
    [anon_sym_PLUS] = ACTIONS(2474),
    [anon_sym_STAR] = ACTIONS(2476),
    [anon_sym_AMP_AMP] = ACTIONS(2476),
    [anon_sym_AMP] = ACTIONS(2474),
    [anon_sym_SEMI] = ACTIONS(2476),
    [anon_sym___extension__] = ACTIONS(2474),
    [anon_sym_typedef] = ACTIONS(2474),
    [anon_sym_in] = ACTIONS(2474),
    [anon_sym_out] = ACTIONS(2474),
    [anon_sym_inout] = ACTIONS(2474),
    [anon_sym_extern] = ACTIONS(2474),
    [anon_sym___attribute__] = ACTIONS(2474),
    [anon_sym_COLON_COLON] = ACTIONS(2476),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2476),
    [anon_sym___declspec] = ACTIONS(2474),
    [anon_sym___based] = ACTIONS(2474),
    [anon_sym___cdecl] = ACTIONS(2474),
    [anon_sym___clrcall] = ACTIONS(2474),
    [anon_sym___stdcall] = ACTIONS(2474),
    [anon_sym___fastcall] = ACTIONS(2474),
    [anon_sym___thiscall] = ACTIONS(2474),
    [anon_sym___vectorcall] = ACTIONS(2474),
    [anon_sym_LBRACE] = ACTIONS(2476),
    [anon_sym_RBRACE] = ACTIONS(2476),
    [anon_sym_signed] = ACTIONS(2474),
    [anon_sym_unsigned] = ACTIONS(2474),
    [anon_sym_long] = ACTIONS(2474),
    [anon_sym_short] = ACTIONS(2474),
    [anon_sym_LBRACK] = ACTIONS(2474),
    [anon_sym_static] = ACTIONS(2474),
    [anon_sym_register] = ACTIONS(2474),
    [anon_sym_inline] = ACTIONS(2474),
    [anon_sym___inline] = ACTIONS(2474),
    [anon_sym___inline__] = ACTIONS(2474),
    [anon_sym___forceinline] = ACTIONS(2474),
    [anon_sym_thread_local] = ACTIONS(2474),
    [anon_sym___thread] = ACTIONS(2474),
    [anon_sym_const] = ACTIONS(2474),
    [anon_sym_constexpr] = ACTIONS(2474),
    [anon_sym_volatile] = ACTIONS(2474),
    [anon_sym_restrict] = ACTIONS(2474),
    [anon_sym___restrict__] = ACTIONS(2474),
    [anon_sym__Atomic] = ACTIONS(2474),
    [anon_sym__Noreturn] = ACTIONS(2474),
    [anon_sym_noreturn] = ACTIONS(2474),
    [anon_sym_mutable] = ACTIONS(2474),
    [anon_sym_constinit] = ACTIONS(2474),
    [anon_sym_consteval] = ACTIONS(2474),
    [anon_sym_alignas] = ACTIONS(2474),
    [anon_sym__Alignas] = ACTIONS(2474),
    [sym_primitive_type] = ACTIONS(2474),
    [anon_sym_enum] = ACTIONS(2474),
    [anon_sym_class] = ACTIONS(2474),
    [anon_sym_struct] = ACTIONS(2474),
    [anon_sym_union] = ACTIONS(2474),
    [anon_sym_if] = ACTIONS(2474),
    [anon_sym_switch] = ACTIONS(2474),
    [anon_sym_case] = ACTIONS(2474),
    [anon_sym_default] = ACTIONS(2474),
    [anon_sym_while] = ACTIONS(2474),
    [anon_sym_do] = ACTIONS(2474),
    [anon_sym_for] = ACTIONS(2474),
    [anon_sym_return] = ACTIONS(2474),
    [anon_sym_break] = ACTIONS(2474),
    [anon_sym_continue] = ACTIONS(2474),
    [anon_sym_goto] = ACTIONS(2474),
    [anon_sym___try] = ACTIONS(2474),
    [anon_sym___leave] = ACTIONS(2474),
    [anon_sym_not] = ACTIONS(2474),
    [anon_sym_compl] = ACTIONS(2474),
    [anon_sym_DASH_DASH] = ACTIONS(2476),
    [anon_sym_PLUS_PLUS] = ACTIONS(2476),
    [anon_sym_sizeof] = ACTIONS(2474),
    [anon_sym___alignof__] = ACTIONS(2474),
    [anon_sym___alignof] = ACTIONS(2474),
    [anon_sym__alignof] = ACTIONS(2474),
    [anon_sym_alignof] = ACTIONS(2474),
    [anon_sym__Alignof] = ACTIONS(2474),
    [anon_sym_offsetof] = ACTIONS(2474),
    [anon_sym__Generic] = ACTIONS(2474),
    [anon_sym_asm] = ACTIONS(2474),
    [anon_sym___asm__] = ACTIONS(2474),
    [sym_number_literal] = ACTIONS(2476),
    [anon_sym_L_SQUOTE] = ACTIONS(2476),
    [anon_sym_u_SQUOTE] = ACTIONS(2476),
    [anon_sym_U_SQUOTE] = ACTIONS(2476),
    [anon_sym_u8_SQUOTE] = ACTIONS(2476),
    [anon_sym_SQUOTE] = ACTIONS(2476),
    [anon_sym_L_DQUOTE] = ACTIONS(2476),
    [anon_sym_u_DQUOTE] = ACTIONS(2476),
    [anon_sym_U_DQUOTE] = ACTIONS(2476),
    [anon_sym_u8_DQUOTE] = ACTIONS(2476),
    [anon_sym_DQUOTE] = ACTIONS(2476),
    [sym_true] = ACTIONS(2474),
    [sym_false] = ACTIONS(2474),
    [anon_sym_NULL] = ACTIONS(2474),
    [anon_sym_nullptr] = ACTIONS(2474),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2474),
    [anon_sym_decltype] = ACTIONS(2474),
    [sym_virtual] = ACTIONS(2474),
    [anon_sym_explicit] = ACTIONS(2474),
    [anon_sym_typename] = ACTIONS(2474),
    [anon_sym_template] = ACTIONS(2474),
    [anon_sym_operator] = ACTIONS(2474),
    [anon_sym_try] = ACTIONS(2474),
    [anon_sym_delete] = ACTIONS(2474),
    [anon_sym_throw] = ACTIONS(2474),
    [anon_sym_namespace] = ACTIONS(2474),
    [anon_sym_using] = ACTIONS(2474),
    [anon_sym_static_assert] = ACTIONS(2474),
    [anon_sym_concept] = ACTIONS(2474),
    [anon_sym_co_return] = ACTIONS(2474),
    [anon_sym_co_yield] = ACTIONS(2474),
    [anon_sym_R_DQUOTE] = ACTIONS(2476),
    [anon_sym_LR_DQUOTE] = ACTIONS(2476),
    [anon_sym_uR_DQUOTE] = ACTIONS(2476),
    [anon_sym_UR_DQUOTE] = ACTIONS(2476),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2476),
    [anon_sym_co_await] = ACTIONS(2474),
    [anon_sym_new] = ACTIONS(2474),
    [anon_sym_requires] = ACTIONS(2474),
    [sym_this] = ACTIONS(2474),
    [anon_sym_discard] = ACTIONS(2474),
    [anon_sym_precise] = ACTIONS(2474),
    [anon_sym_shared] = ACTIONS(2474),
    [anon_sym_groupshared] = ACTIONS(2474),
    [anon_sym_uniform] = ACTIONS(2474),
    [anon_sym_row_major] = ACTIONS(2474),
    [anon_sym_column_major] = ACTIONS(2474),
    [anon_sym_globallycoherent] = ACTIONS(2474),
    [anon_sym_centroid] = ACTIONS(2474),
    [anon_sym_noperspective] = ACTIONS(2474),
    [anon_sym_nointerpolation] = ACTIONS(2474),
    [anon_sym_sample] = ACTIONS(2474),
    [anon_sym_linear] = ACTIONS(2474),
    [anon_sym_snorm] = ACTIONS(2474),
    [anon_sym_unorm] = ACTIONS(2474),
    [anon_sym_point] = ACTIONS(2474),
    [anon_sym_line] = ACTIONS(2474),
    [anon_sym_triangleadj] = ACTIONS(2474),
    [anon_sym_lineadj] = ACTIONS(2474),
    [anon_sym_triangle] = ACTIONS(2474),
    [anon_sym_cbuffer] = ACTIONS(2474),
  },
  [694] = {
    [sym_identifier] = ACTIONS(2478),
    [aux_sym_preproc_include_token1] = ACTIONS(2478),
    [aux_sym_preproc_def_token1] = ACTIONS(2478),
    [aux_sym_preproc_if_token1] = ACTIONS(2478),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2478),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2478),
    [sym_preproc_directive] = ACTIONS(2478),
    [anon_sym_LPAREN2] = ACTIONS(2480),
    [anon_sym_BANG] = ACTIONS(2480),
    [anon_sym_TILDE] = ACTIONS(2480),
    [anon_sym_DASH] = ACTIONS(2478),
    [anon_sym_PLUS] = ACTIONS(2478),
    [anon_sym_STAR] = ACTIONS(2480),
    [anon_sym_AMP_AMP] = ACTIONS(2480),
    [anon_sym_AMP] = ACTIONS(2478),
    [anon_sym_SEMI] = ACTIONS(2480),
    [anon_sym___extension__] = ACTIONS(2478),
    [anon_sym_typedef] = ACTIONS(2478),
    [anon_sym_in] = ACTIONS(2478),
    [anon_sym_out] = ACTIONS(2478),
    [anon_sym_inout] = ACTIONS(2478),
    [anon_sym_extern] = ACTIONS(2478),
    [anon_sym___attribute__] = ACTIONS(2478),
    [anon_sym_COLON_COLON] = ACTIONS(2480),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2480),
    [anon_sym___declspec] = ACTIONS(2478),
    [anon_sym___based] = ACTIONS(2478),
    [anon_sym___cdecl] = ACTIONS(2478),
    [anon_sym___clrcall] = ACTIONS(2478),
    [anon_sym___stdcall] = ACTIONS(2478),
    [anon_sym___fastcall] = ACTIONS(2478),
    [anon_sym___thiscall] = ACTIONS(2478),
    [anon_sym___vectorcall] = ACTIONS(2478),
    [anon_sym_LBRACE] = ACTIONS(2480),
    [anon_sym_RBRACE] = ACTIONS(2480),
    [anon_sym_signed] = ACTIONS(2478),
    [anon_sym_unsigned] = ACTIONS(2478),
    [anon_sym_long] = ACTIONS(2478),
    [anon_sym_short] = ACTIONS(2478),
    [anon_sym_LBRACK] = ACTIONS(2478),
    [anon_sym_static] = ACTIONS(2478),
    [anon_sym_register] = ACTIONS(2478),
    [anon_sym_inline] = ACTIONS(2478),
    [anon_sym___inline] = ACTIONS(2478),
    [anon_sym___inline__] = ACTIONS(2478),
    [anon_sym___forceinline] = ACTIONS(2478),
    [anon_sym_thread_local] = ACTIONS(2478),
    [anon_sym___thread] = ACTIONS(2478),
    [anon_sym_const] = ACTIONS(2478),
    [anon_sym_constexpr] = ACTIONS(2478),
    [anon_sym_volatile] = ACTIONS(2478),
    [anon_sym_restrict] = ACTIONS(2478),
    [anon_sym___restrict__] = ACTIONS(2478),
    [anon_sym__Atomic] = ACTIONS(2478),
    [anon_sym__Noreturn] = ACTIONS(2478),
    [anon_sym_noreturn] = ACTIONS(2478),
    [anon_sym_mutable] = ACTIONS(2478),
    [anon_sym_constinit] = ACTIONS(2478),
    [anon_sym_consteval] = ACTIONS(2478),
    [anon_sym_alignas] = ACTIONS(2478),
    [anon_sym__Alignas] = ACTIONS(2478),
    [sym_primitive_type] = ACTIONS(2478),
    [anon_sym_enum] = ACTIONS(2478),
    [anon_sym_class] = ACTIONS(2478),
    [anon_sym_struct] = ACTIONS(2478),
    [anon_sym_union] = ACTIONS(2478),
    [anon_sym_if] = ACTIONS(2478),
    [anon_sym_switch] = ACTIONS(2478),
    [anon_sym_case] = ACTIONS(2478),
    [anon_sym_default] = ACTIONS(2478),
    [anon_sym_while] = ACTIONS(2478),
    [anon_sym_do] = ACTIONS(2478),
    [anon_sym_for] = ACTIONS(2478),
    [anon_sym_return] = ACTIONS(2478),
    [anon_sym_break] = ACTIONS(2478),
    [anon_sym_continue] = ACTIONS(2478),
    [anon_sym_goto] = ACTIONS(2478),
    [anon_sym___try] = ACTIONS(2478),
    [anon_sym___leave] = ACTIONS(2478),
    [anon_sym_not] = ACTIONS(2478),
    [anon_sym_compl] = ACTIONS(2478),
    [anon_sym_DASH_DASH] = ACTIONS(2480),
    [anon_sym_PLUS_PLUS] = ACTIONS(2480),
    [anon_sym_sizeof] = ACTIONS(2478),
    [anon_sym___alignof__] = ACTIONS(2478),
    [anon_sym___alignof] = ACTIONS(2478),
    [anon_sym__alignof] = ACTIONS(2478),
    [anon_sym_alignof] = ACTIONS(2478),
    [anon_sym__Alignof] = ACTIONS(2478),
    [anon_sym_offsetof] = ACTIONS(2478),
    [anon_sym__Generic] = ACTIONS(2478),
    [anon_sym_asm] = ACTIONS(2478),
    [anon_sym___asm__] = ACTIONS(2478),
    [sym_number_literal] = ACTIONS(2480),
    [anon_sym_L_SQUOTE] = ACTIONS(2480),
    [anon_sym_u_SQUOTE] = ACTIONS(2480),
    [anon_sym_U_SQUOTE] = ACTIONS(2480),
    [anon_sym_u8_SQUOTE] = ACTIONS(2480),
    [anon_sym_SQUOTE] = ACTIONS(2480),
    [anon_sym_L_DQUOTE] = ACTIONS(2480),
    [anon_sym_u_DQUOTE] = ACTIONS(2480),
    [anon_sym_U_DQUOTE] = ACTIONS(2480),
    [anon_sym_u8_DQUOTE] = ACTIONS(2480),
    [anon_sym_DQUOTE] = ACTIONS(2480),
    [sym_true] = ACTIONS(2478),
    [sym_false] = ACTIONS(2478),
    [anon_sym_NULL] = ACTIONS(2478),
    [anon_sym_nullptr] = ACTIONS(2478),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2478),
    [anon_sym_decltype] = ACTIONS(2478),
    [sym_virtual] = ACTIONS(2478),
    [anon_sym_explicit] = ACTIONS(2478),
    [anon_sym_typename] = ACTIONS(2478),
    [anon_sym_template] = ACTIONS(2478),
    [anon_sym_operator] = ACTIONS(2478),
    [anon_sym_try] = ACTIONS(2478),
    [anon_sym_delete] = ACTIONS(2478),
    [anon_sym_throw] = ACTIONS(2478),
    [anon_sym_namespace] = ACTIONS(2478),
    [anon_sym_using] = ACTIONS(2478),
    [anon_sym_static_assert] = ACTIONS(2478),
    [anon_sym_concept] = ACTIONS(2478),
    [anon_sym_co_return] = ACTIONS(2478),
    [anon_sym_co_yield] = ACTIONS(2478),
    [anon_sym_R_DQUOTE] = ACTIONS(2480),
    [anon_sym_LR_DQUOTE] = ACTIONS(2480),
    [anon_sym_uR_DQUOTE] = ACTIONS(2480),
    [anon_sym_UR_DQUOTE] = ACTIONS(2480),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2480),
    [anon_sym_co_await] = ACTIONS(2478),
    [anon_sym_new] = ACTIONS(2478),
    [anon_sym_requires] = ACTIONS(2478),
    [sym_this] = ACTIONS(2478),
    [anon_sym_discard] = ACTIONS(2478),
    [anon_sym_precise] = ACTIONS(2478),
    [anon_sym_shared] = ACTIONS(2478),
    [anon_sym_groupshared] = ACTIONS(2478),
    [anon_sym_uniform] = ACTIONS(2478),
    [anon_sym_row_major] = ACTIONS(2478),
    [anon_sym_column_major] = ACTIONS(2478),
    [anon_sym_globallycoherent] = ACTIONS(2478),
    [anon_sym_centroid] = ACTIONS(2478),
    [anon_sym_noperspective] = ACTIONS(2478),
    [anon_sym_nointerpolation] = ACTIONS(2478),
    [anon_sym_sample] = ACTIONS(2478),
    [anon_sym_linear] = ACTIONS(2478),
    [anon_sym_snorm] = ACTIONS(2478),
    [anon_sym_unorm] = ACTIONS(2478),
    [anon_sym_point] = ACTIONS(2478),
    [anon_sym_line] = ACTIONS(2478),
    [anon_sym_triangleadj] = ACTIONS(2478),
    [anon_sym_lineadj] = ACTIONS(2478),
    [anon_sym_triangle] = ACTIONS(2478),
    [anon_sym_cbuffer] = ACTIONS(2478),
  },
  [695] = {
    [sym_identifier] = ACTIONS(2296),
    [aux_sym_preproc_include_token1] = ACTIONS(2296),
    [aux_sym_preproc_def_token1] = ACTIONS(2296),
    [aux_sym_preproc_if_token1] = ACTIONS(2296),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2296),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2296),
    [sym_preproc_directive] = ACTIONS(2296),
    [anon_sym_LPAREN2] = ACTIONS(2298),
    [anon_sym_BANG] = ACTIONS(2298),
    [anon_sym_TILDE] = ACTIONS(2298),
    [anon_sym_DASH] = ACTIONS(2296),
    [anon_sym_PLUS] = ACTIONS(2296),
    [anon_sym_STAR] = ACTIONS(2298),
    [anon_sym_AMP_AMP] = ACTIONS(2298),
    [anon_sym_AMP] = ACTIONS(2296),
    [anon_sym_SEMI] = ACTIONS(2298),
    [anon_sym___extension__] = ACTIONS(2296),
    [anon_sym_typedef] = ACTIONS(2296),
    [anon_sym_in] = ACTIONS(2296),
    [anon_sym_out] = ACTIONS(2296),
    [anon_sym_inout] = ACTIONS(2296),
    [anon_sym_extern] = ACTIONS(2296),
    [anon_sym___attribute__] = ACTIONS(2296),
    [anon_sym_COLON_COLON] = ACTIONS(2298),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2298),
    [anon_sym___declspec] = ACTIONS(2296),
    [anon_sym___based] = ACTIONS(2296),
    [anon_sym___cdecl] = ACTIONS(2296),
    [anon_sym___clrcall] = ACTIONS(2296),
    [anon_sym___stdcall] = ACTIONS(2296),
    [anon_sym___fastcall] = ACTIONS(2296),
    [anon_sym___thiscall] = ACTIONS(2296),
    [anon_sym___vectorcall] = ACTIONS(2296),
    [anon_sym_LBRACE] = ACTIONS(2298),
    [anon_sym_RBRACE] = ACTIONS(2298),
    [anon_sym_signed] = ACTIONS(2296),
    [anon_sym_unsigned] = ACTIONS(2296),
    [anon_sym_long] = ACTIONS(2296),
    [anon_sym_short] = ACTIONS(2296),
    [anon_sym_LBRACK] = ACTIONS(2296),
    [anon_sym_static] = ACTIONS(2296),
    [anon_sym_register] = ACTIONS(2296),
    [anon_sym_inline] = ACTIONS(2296),
    [anon_sym___inline] = ACTIONS(2296),
    [anon_sym___inline__] = ACTIONS(2296),
    [anon_sym___forceinline] = ACTIONS(2296),
    [anon_sym_thread_local] = ACTIONS(2296),
    [anon_sym___thread] = ACTIONS(2296),
    [anon_sym_const] = ACTIONS(2296),
    [anon_sym_constexpr] = ACTIONS(2296),
    [anon_sym_volatile] = ACTIONS(2296),
    [anon_sym_restrict] = ACTIONS(2296),
    [anon_sym___restrict__] = ACTIONS(2296),
    [anon_sym__Atomic] = ACTIONS(2296),
    [anon_sym__Noreturn] = ACTIONS(2296),
    [anon_sym_noreturn] = ACTIONS(2296),
    [anon_sym_mutable] = ACTIONS(2296),
    [anon_sym_constinit] = ACTIONS(2296),
    [anon_sym_consteval] = ACTIONS(2296),
    [anon_sym_alignas] = ACTIONS(2296),
    [anon_sym__Alignas] = ACTIONS(2296),
    [sym_primitive_type] = ACTIONS(2296),
    [anon_sym_enum] = ACTIONS(2296),
    [anon_sym_class] = ACTIONS(2296),
    [anon_sym_struct] = ACTIONS(2296),
    [anon_sym_union] = ACTIONS(2296),
    [anon_sym_if] = ACTIONS(2296),
    [anon_sym_switch] = ACTIONS(2296),
    [anon_sym_case] = ACTIONS(2296),
    [anon_sym_default] = ACTIONS(2296),
    [anon_sym_while] = ACTIONS(2296),
    [anon_sym_do] = ACTIONS(2296),
    [anon_sym_for] = ACTIONS(2296),
    [anon_sym_return] = ACTIONS(2296),
    [anon_sym_break] = ACTIONS(2296),
    [anon_sym_continue] = ACTIONS(2296),
    [anon_sym_goto] = ACTIONS(2296),
    [anon_sym___try] = ACTIONS(2296),
    [anon_sym___leave] = ACTIONS(2296),
    [anon_sym_not] = ACTIONS(2296),
    [anon_sym_compl] = ACTIONS(2296),
    [anon_sym_DASH_DASH] = ACTIONS(2298),
    [anon_sym_PLUS_PLUS] = ACTIONS(2298),
    [anon_sym_sizeof] = ACTIONS(2296),
    [anon_sym___alignof__] = ACTIONS(2296),
    [anon_sym___alignof] = ACTIONS(2296),
    [anon_sym__alignof] = ACTIONS(2296),
    [anon_sym_alignof] = ACTIONS(2296),
    [anon_sym__Alignof] = ACTIONS(2296),
    [anon_sym_offsetof] = ACTIONS(2296),
    [anon_sym__Generic] = ACTIONS(2296),
    [anon_sym_asm] = ACTIONS(2296),
    [anon_sym___asm__] = ACTIONS(2296),
    [sym_number_literal] = ACTIONS(2298),
    [anon_sym_L_SQUOTE] = ACTIONS(2298),
    [anon_sym_u_SQUOTE] = ACTIONS(2298),
    [anon_sym_U_SQUOTE] = ACTIONS(2298),
    [anon_sym_u8_SQUOTE] = ACTIONS(2298),
    [anon_sym_SQUOTE] = ACTIONS(2298),
    [anon_sym_L_DQUOTE] = ACTIONS(2298),
    [anon_sym_u_DQUOTE] = ACTIONS(2298),
    [anon_sym_U_DQUOTE] = ACTIONS(2298),
    [anon_sym_u8_DQUOTE] = ACTIONS(2298),
    [anon_sym_DQUOTE] = ACTIONS(2298),
    [sym_true] = ACTIONS(2296),
    [sym_false] = ACTIONS(2296),
    [anon_sym_NULL] = ACTIONS(2296),
    [anon_sym_nullptr] = ACTIONS(2296),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2296),
    [anon_sym_decltype] = ACTIONS(2296),
    [sym_virtual] = ACTIONS(2296),
    [anon_sym_explicit] = ACTIONS(2296),
    [anon_sym_typename] = ACTIONS(2296),
    [anon_sym_template] = ACTIONS(2296),
    [anon_sym_operator] = ACTIONS(2296),
    [anon_sym_try] = ACTIONS(2296),
    [anon_sym_delete] = ACTIONS(2296),
    [anon_sym_throw] = ACTIONS(2296),
    [anon_sym_namespace] = ACTIONS(2296),
    [anon_sym_using] = ACTIONS(2296),
    [anon_sym_static_assert] = ACTIONS(2296),
    [anon_sym_concept] = ACTIONS(2296),
    [anon_sym_co_return] = ACTIONS(2296),
    [anon_sym_co_yield] = ACTIONS(2296),
    [anon_sym_R_DQUOTE] = ACTIONS(2298),
    [anon_sym_LR_DQUOTE] = ACTIONS(2298),
    [anon_sym_uR_DQUOTE] = ACTIONS(2298),
    [anon_sym_UR_DQUOTE] = ACTIONS(2298),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2298),
    [anon_sym_co_await] = ACTIONS(2296),
    [anon_sym_new] = ACTIONS(2296),
    [anon_sym_requires] = ACTIONS(2296),
    [sym_this] = ACTIONS(2296),
    [anon_sym_discard] = ACTIONS(2296),
    [anon_sym_precise] = ACTIONS(2296),
    [anon_sym_shared] = ACTIONS(2296),
    [anon_sym_groupshared] = ACTIONS(2296),
    [anon_sym_uniform] = ACTIONS(2296),
    [anon_sym_row_major] = ACTIONS(2296),
    [anon_sym_column_major] = ACTIONS(2296),
    [anon_sym_globallycoherent] = ACTIONS(2296),
    [anon_sym_centroid] = ACTIONS(2296),
    [anon_sym_noperspective] = ACTIONS(2296),
    [anon_sym_nointerpolation] = ACTIONS(2296),
    [anon_sym_sample] = ACTIONS(2296),
    [anon_sym_linear] = ACTIONS(2296),
    [anon_sym_snorm] = ACTIONS(2296),
    [anon_sym_unorm] = ACTIONS(2296),
    [anon_sym_point] = ACTIONS(2296),
    [anon_sym_line] = ACTIONS(2296),
    [anon_sym_triangleadj] = ACTIONS(2296),
    [anon_sym_lineadj] = ACTIONS(2296),
    [anon_sym_triangle] = ACTIONS(2296),
    [anon_sym_cbuffer] = ACTIONS(2296),
  },
  [696] = {
    [sym_identifier] = ACTIONS(2482),
    [aux_sym_preproc_include_token1] = ACTIONS(2482),
    [aux_sym_preproc_def_token1] = ACTIONS(2482),
    [aux_sym_preproc_if_token1] = ACTIONS(2482),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2482),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2482),
    [sym_preproc_directive] = ACTIONS(2482),
    [anon_sym_LPAREN2] = ACTIONS(2484),
    [anon_sym_BANG] = ACTIONS(2484),
    [anon_sym_TILDE] = ACTIONS(2484),
    [anon_sym_DASH] = ACTIONS(2482),
    [anon_sym_PLUS] = ACTIONS(2482),
    [anon_sym_STAR] = ACTIONS(2484),
    [anon_sym_AMP_AMP] = ACTIONS(2484),
    [anon_sym_AMP] = ACTIONS(2482),
    [anon_sym_SEMI] = ACTIONS(2484),
    [anon_sym___extension__] = ACTIONS(2482),
    [anon_sym_typedef] = ACTIONS(2482),
    [anon_sym_in] = ACTIONS(2482),
    [anon_sym_out] = ACTIONS(2482),
    [anon_sym_inout] = ACTIONS(2482),
    [anon_sym_extern] = ACTIONS(2482),
    [anon_sym___attribute__] = ACTIONS(2482),
    [anon_sym_COLON_COLON] = ACTIONS(2484),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2484),
    [anon_sym___declspec] = ACTIONS(2482),
    [anon_sym___based] = ACTIONS(2482),
    [anon_sym___cdecl] = ACTIONS(2482),
    [anon_sym___clrcall] = ACTIONS(2482),
    [anon_sym___stdcall] = ACTIONS(2482),
    [anon_sym___fastcall] = ACTIONS(2482),
    [anon_sym___thiscall] = ACTIONS(2482),
    [anon_sym___vectorcall] = ACTIONS(2482),
    [anon_sym_LBRACE] = ACTIONS(2484),
    [anon_sym_RBRACE] = ACTIONS(2484),
    [anon_sym_signed] = ACTIONS(2482),
    [anon_sym_unsigned] = ACTIONS(2482),
    [anon_sym_long] = ACTIONS(2482),
    [anon_sym_short] = ACTIONS(2482),
    [anon_sym_LBRACK] = ACTIONS(2482),
    [anon_sym_static] = ACTIONS(2482),
    [anon_sym_register] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(2482),
    [anon_sym___inline] = ACTIONS(2482),
    [anon_sym___inline__] = ACTIONS(2482),
    [anon_sym___forceinline] = ACTIONS(2482),
    [anon_sym_thread_local] = ACTIONS(2482),
    [anon_sym___thread] = ACTIONS(2482),
    [anon_sym_const] = ACTIONS(2482),
    [anon_sym_constexpr] = ACTIONS(2482),
    [anon_sym_volatile] = ACTIONS(2482),
    [anon_sym_restrict] = ACTIONS(2482),
    [anon_sym___restrict__] = ACTIONS(2482),
    [anon_sym__Atomic] = ACTIONS(2482),
    [anon_sym__Noreturn] = ACTIONS(2482),
    [anon_sym_noreturn] = ACTIONS(2482),
    [anon_sym_mutable] = ACTIONS(2482),
    [anon_sym_constinit] = ACTIONS(2482),
    [anon_sym_consteval] = ACTIONS(2482),
    [anon_sym_alignas] = ACTIONS(2482),
    [anon_sym__Alignas] = ACTIONS(2482),
    [sym_primitive_type] = ACTIONS(2482),
    [anon_sym_enum] = ACTIONS(2482),
    [anon_sym_class] = ACTIONS(2482),
    [anon_sym_struct] = ACTIONS(2482),
    [anon_sym_union] = ACTIONS(2482),
    [anon_sym_if] = ACTIONS(2482),
    [anon_sym_switch] = ACTIONS(2482),
    [anon_sym_case] = ACTIONS(2482),
    [anon_sym_default] = ACTIONS(2482),
    [anon_sym_while] = ACTIONS(2482),
    [anon_sym_do] = ACTIONS(2482),
    [anon_sym_for] = ACTIONS(2482),
    [anon_sym_return] = ACTIONS(2482),
    [anon_sym_break] = ACTIONS(2482),
    [anon_sym_continue] = ACTIONS(2482),
    [anon_sym_goto] = ACTIONS(2482),
    [anon_sym___try] = ACTIONS(2482),
    [anon_sym___leave] = ACTIONS(2482),
    [anon_sym_not] = ACTIONS(2482),
    [anon_sym_compl] = ACTIONS(2482),
    [anon_sym_DASH_DASH] = ACTIONS(2484),
    [anon_sym_PLUS_PLUS] = ACTIONS(2484),
    [anon_sym_sizeof] = ACTIONS(2482),
    [anon_sym___alignof__] = ACTIONS(2482),
    [anon_sym___alignof] = ACTIONS(2482),
    [anon_sym__alignof] = ACTIONS(2482),
    [anon_sym_alignof] = ACTIONS(2482),
    [anon_sym__Alignof] = ACTIONS(2482),
    [anon_sym_offsetof] = ACTIONS(2482),
    [anon_sym__Generic] = ACTIONS(2482),
    [anon_sym_asm] = ACTIONS(2482),
    [anon_sym___asm__] = ACTIONS(2482),
    [sym_number_literal] = ACTIONS(2484),
    [anon_sym_L_SQUOTE] = ACTIONS(2484),
    [anon_sym_u_SQUOTE] = ACTIONS(2484),
    [anon_sym_U_SQUOTE] = ACTIONS(2484),
    [anon_sym_u8_SQUOTE] = ACTIONS(2484),
    [anon_sym_SQUOTE] = ACTIONS(2484),
    [anon_sym_L_DQUOTE] = ACTIONS(2484),
    [anon_sym_u_DQUOTE] = ACTIONS(2484),
    [anon_sym_U_DQUOTE] = ACTIONS(2484),
    [anon_sym_u8_DQUOTE] = ACTIONS(2484),
    [anon_sym_DQUOTE] = ACTIONS(2484),
    [sym_true] = ACTIONS(2482),
    [sym_false] = ACTIONS(2482),
    [anon_sym_NULL] = ACTIONS(2482),
    [anon_sym_nullptr] = ACTIONS(2482),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2482),
    [anon_sym_decltype] = ACTIONS(2482),
    [sym_virtual] = ACTIONS(2482),
    [anon_sym_explicit] = ACTIONS(2482),
    [anon_sym_typename] = ACTIONS(2482),
    [anon_sym_template] = ACTIONS(2482),
    [anon_sym_operator] = ACTIONS(2482),
    [anon_sym_try] = ACTIONS(2482),
    [anon_sym_delete] = ACTIONS(2482),
    [anon_sym_throw] = ACTIONS(2482),
    [anon_sym_namespace] = ACTIONS(2482),
    [anon_sym_using] = ACTIONS(2482),
    [anon_sym_static_assert] = ACTIONS(2482),
    [anon_sym_concept] = ACTIONS(2482),
    [anon_sym_co_return] = ACTIONS(2482),
    [anon_sym_co_yield] = ACTIONS(2482),
    [anon_sym_R_DQUOTE] = ACTIONS(2484),
    [anon_sym_LR_DQUOTE] = ACTIONS(2484),
    [anon_sym_uR_DQUOTE] = ACTIONS(2484),
    [anon_sym_UR_DQUOTE] = ACTIONS(2484),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2484),
    [anon_sym_co_await] = ACTIONS(2482),
    [anon_sym_new] = ACTIONS(2482),
    [anon_sym_requires] = ACTIONS(2482),
    [sym_this] = ACTIONS(2482),
    [anon_sym_discard] = ACTIONS(2482),
    [anon_sym_precise] = ACTIONS(2482),
    [anon_sym_shared] = ACTIONS(2482),
    [anon_sym_groupshared] = ACTIONS(2482),
    [anon_sym_uniform] = ACTIONS(2482),
    [anon_sym_row_major] = ACTIONS(2482),
    [anon_sym_column_major] = ACTIONS(2482),
    [anon_sym_globallycoherent] = ACTIONS(2482),
    [anon_sym_centroid] = ACTIONS(2482),
    [anon_sym_noperspective] = ACTIONS(2482),
    [anon_sym_nointerpolation] = ACTIONS(2482),
    [anon_sym_sample] = ACTIONS(2482),
    [anon_sym_linear] = ACTIONS(2482),
    [anon_sym_snorm] = ACTIONS(2482),
    [anon_sym_unorm] = ACTIONS(2482),
    [anon_sym_point] = ACTIONS(2482),
    [anon_sym_line] = ACTIONS(2482),
    [anon_sym_triangleadj] = ACTIONS(2482),
    [anon_sym_lineadj] = ACTIONS(2482),
    [anon_sym_triangle] = ACTIONS(2482),
    [anon_sym_cbuffer] = ACTIONS(2482),
  },
  [697] = {
    [sym_identifier] = ACTIONS(2486),
    [aux_sym_preproc_include_token1] = ACTIONS(2486),
    [aux_sym_preproc_def_token1] = ACTIONS(2486),
    [aux_sym_preproc_if_token1] = ACTIONS(2486),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2486),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2486),
    [sym_preproc_directive] = ACTIONS(2486),
    [anon_sym_LPAREN2] = ACTIONS(2488),
    [anon_sym_BANG] = ACTIONS(2488),
    [anon_sym_TILDE] = ACTIONS(2488),
    [anon_sym_DASH] = ACTIONS(2486),
    [anon_sym_PLUS] = ACTIONS(2486),
    [anon_sym_STAR] = ACTIONS(2488),
    [anon_sym_AMP_AMP] = ACTIONS(2488),
    [anon_sym_AMP] = ACTIONS(2486),
    [anon_sym_SEMI] = ACTIONS(2488),
    [anon_sym___extension__] = ACTIONS(2486),
    [anon_sym_typedef] = ACTIONS(2486),
    [anon_sym_in] = ACTIONS(2486),
    [anon_sym_out] = ACTIONS(2486),
    [anon_sym_inout] = ACTIONS(2486),
    [anon_sym_extern] = ACTIONS(2486),
    [anon_sym___attribute__] = ACTIONS(2486),
    [anon_sym_COLON_COLON] = ACTIONS(2488),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2488),
    [anon_sym___declspec] = ACTIONS(2486),
    [anon_sym___based] = ACTIONS(2486),
    [anon_sym___cdecl] = ACTIONS(2486),
    [anon_sym___clrcall] = ACTIONS(2486),
    [anon_sym___stdcall] = ACTIONS(2486),
    [anon_sym___fastcall] = ACTIONS(2486),
    [anon_sym___thiscall] = ACTIONS(2486),
    [anon_sym___vectorcall] = ACTIONS(2486),
    [anon_sym_LBRACE] = ACTIONS(2488),
    [anon_sym_RBRACE] = ACTIONS(2488),
    [anon_sym_signed] = ACTIONS(2486),
    [anon_sym_unsigned] = ACTIONS(2486),
    [anon_sym_long] = ACTIONS(2486),
    [anon_sym_short] = ACTIONS(2486),
    [anon_sym_LBRACK] = ACTIONS(2486),
    [anon_sym_static] = ACTIONS(2486),
    [anon_sym_register] = ACTIONS(2486),
    [anon_sym_inline] = ACTIONS(2486),
    [anon_sym___inline] = ACTIONS(2486),
    [anon_sym___inline__] = ACTIONS(2486),
    [anon_sym___forceinline] = ACTIONS(2486),
    [anon_sym_thread_local] = ACTIONS(2486),
    [anon_sym___thread] = ACTIONS(2486),
    [anon_sym_const] = ACTIONS(2486),
    [anon_sym_constexpr] = ACTIONS(2486),
    [anon_sym_volatile] = ACTIONS(2486),
    [anon_sym_restrict] = ACTIONS(2486),
    [anon_sym___restrict__] = ACTIONS(2486),
    [anon_sym__Atomic] = ACTIONS(2486),
    [anon_sym__Noreturn] = ACTIONS(2486),
    [anon_sym_noreturn] = ACTIONS(2486),
    [anon_sym_mutable] = ACTIONS(2486),
    [anon_sym_constinit] = ACTIONS(2486),
    [anon_sym_consteval] = ACTIONS(2486),
    [anon_sym_alignas] = ACTIONS(2486),
    [anon_sym__Alignas] = ACTIONS(2486),
    [sym_primitive_type] = ACTIONS(2486),
    [anon_sym_enum] = ACTIONS(2486),
    [anon_sym_class] = ACTIONS(2486),
    [anon_sym_struct] = ACTIONS(2486),
    [anon_sym_union] = ACTIONS(2486),
    [anon_sym_if] = ACTIONS(2486),
    [anon_sym_switch] = ACTIONS(2486),
    [anon_sym_case] = ACTIONS(2486),
    [anon_sym_default] = ACTIONS(2486),
    [anon_sym_while] = ACTIONS(2486),
    [anon_sym_do] = ACTIONS(2486),
    [anon_sym_for] = ACTIONS(2486),
    [anon_sym_return] = ACTIONS(2486),
    [anon_sym_break] = ACTIONS(2486),
    [anon_sym_continue] = ACTIONS(2486),
    [anon_sym_goto] = ACTIONS(2486),
    [anon_sym___try] = ACTIONS(2486),
    [anon_sym___leave] = ACTIONS(2486),
    [anon_sym_not] = ACTIONS(2486),
    [anon_sym_compl] = ACTIONS(2486),
    [anon_sym_DASH_DASH] = ACTIONS(2488),
    [anon_sym_PLUS_PLUS] = ACTIONS(2488),
    [anon_sym_sizeof] = ACTIONS(2486),
    [anon_sym___alignof__] = ACTIONS(2486),
    [anon_sym___alignof] = ACTIONS(2486),
    [anon_sym__alignof] = ACTIONS(2486),
    [anon_sym_alignof] = ACTIONS(2486),
    [anon_sym__Alignof] = ACTIONS(2486),
    [anon_sym_offsetof] = ACTIONS(2486),
    [anon_sym__Generic] = ACTIONS(2486),
    [anon_sym_asm] = ACTIONS(2486),
    [anon_sym___asm__] = ACTIONS(2486),
    [sym_number_literal] = ACTIONS(2488),
    [anon_sym_L_SQUOTE] = ACTIONS(2488),
    [anon_sym_u_SQUOTE] = ACTIONS(2488),
    [anon_sym_U_SQUOTE] = ACTIONS(2488),
    [anon_sym_u8_SQUOTE] = ACTIONS(2488),
    [anon_sym_SQUOTE] = ACTIONS(2488),
    [anon_sym_L_DQUOTE] = ACTIONS(2488),
    [anon_sym_u_DQUOTE] = ACTIONS(2488),
    [anon_sym_U_DQUOTE] = ACTIONS(2488),
    [anon_sym_u8_DQUOTE] = ACTIONS(2488),
    [anon_sym_DQUOTE] = ACTIONS(2488),
    [sym_true] = ACTIONS(2486),
    [sym_false] = ACTIONS(2486),
    [anon_sym_NULL] = ACTIONS(2486),
    [anon_sym_nullptr] = ACTIONS(2486),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2486),
    [anon_sym_decltype] = ACTIONS(2486),
    [sym_virtual] = ACTIONS(2486),
    [anon_sym_explicit] = ACTIONS(2486),
    [anon_sym_typename] = ACTIONS(2486),
    [anon_sym_template] = ACTIONS(2486),
    [anon_sym_operator] = ACTIONS(2486),
    [anon_sym_try] = ACTIONS(2486),
    [anon_sym_delete] = ACTIONS(2486),
    [anon_sym_throw] = ACTIONS(2486),
    [anon_sym_namespace] = ACTIONS(2486),
    [anon_sym_using] = ACTIONS(2486),
    [anon_sym_static_assert] = ACTIONS(2486),
    [anon_sym_concept] = ACTIONS(2486),
    [anon_sym_co_return] = ACTIONS(2486),
    [anon_sym_co_yield] = ACTIONS(2486),
    [anon_sym_R_DQUOTE] = ACTIONS(2488),
    [anon_sym_LR_DQUOTE] = ACTIONS(2488),
    [anon_sym_uR_DQUOTE] = ACTIONS(2488),
    [anon_sym_UR_DQUOTE] = ACTIONS(2488),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2488),
    [anon_sym_co_await] = ACTIONS(2486),
    [anon_sym_new] = ACTIONS(2486),
    [anon_sym_requires] = ACTIONS(2486),
    [sym_this] = ACTIONS(2486),
    [anon_sym_discard] = ACTIONS(2486),
    [anon_sym_precise] = ACTIONS(2486),
    [anon_sym_shared] = ACTIONS(2486),
    [anon_sym_groupshared] = ACTIONS(2486),
    [anon_sym_uniform] = ACTIONS(2486),
    [anon_sym_row_major] = ACTIONS(2486),
    [anon_sym_column_major] = ACTIONS(2486),
    [anon_sym_globallycoherent] = ACTIONS(2486),
    [anon_sym_centroid] = ACTIONS(2486),
    [anon_sym_noperspective] = ACTIONS(2486),
    [anon_sym_nointerpolation] = ACTIONS(2486),
    [anon_sym_sample] = ACTIONS(2486),
    [anon_sym_linear] = ACTIONS(2486),
    [anon_sym_snorm] = ACTIONS(2486),
    [anon_sym_unorm] = ACTIONS(2486),
    [anon_sym_point] = ACTIONS(2486),
    [anon_sym_line] = ACTIONS(2486),
    [anon_sym_triangleadj] = ACTIONS(2486),
    [anon_sym_lineadj] = ACTIONS(2486),
    [anon_sym_triangle] = ACTIONS(2486),
    [anon_sym_cbuffer] = ACTIONS(2486),
  },
  [698] = {
    [sym_identifier] = ACTIONS(2393),
    [aux_sym_preproc_include_token1] = ACTIONS(2393),
    [aux_sym_preproc_def_token1] = ACTIONS(2393),
    [aux_sym_preproc_if_token1] = ACTIONS(2393),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2393),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2393),
    [sym_preproc_directive] = ACTIONS(2393),
    [anon_sym_LPAREN2] = ACTIONS(2395),
    [anon_sym_BANG] = ACTIONS(2395),
    [anon_sym_TILDE] = ACTIONS(2395),
    [anon_sym_DASH] = ACTIONS(2393),
    [anon_sym_PLUS] = ACTIONS(2393),
    [anon_sym_STAR] = ACTIONS(2395),
    [anon_sym_AMP_AMP] = ACTIONS(2395),
    [anon_sym_AMP] = ACTIONS(2393),
    [anon_sym_SEMI] = ACTIONS(2395),
    [anon_sym___extension__] = ACTIONS(2393),
    [anon_sym_typedef] = ACTIONS(2393),
    [anon_sym_in] = ACTIONS(2393),
    [anon_sym_out] = ACTIONS(2393),
    [anon_sym_inout] = ACTIONS(2393),
    [anon_sym_extern] = ACTIONS(2393),
    [anon_sym___attribute__] = ACTIONS(2393),
    [anon_sym_COLON_COLON] = ACTIONS(2395),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2395),
    [anon_sym___declspec] = ACTIONS(2393),
    [anon_sym___based] = ACTIONS(2393),
    [anon_sym___cdecl] = ACTIONS(2393),
    [anon_sym___clrcall] = ACTIONS(2393),
    [anon_sym___stdcall] = ACTIONS(2393),
    [anon_sym___fastcall] = ACTIONS(2393),
    [anon_sym___thiscall] = ACTIONS(2393),
    [anon_sym___vectorcall] = ACTIONS(2393),
    [anon_sym_LBRACE] = ACTIONS(2395),
    [anon_sym_RBRACE] = ACTIONS(2395),
    [anon_sym_signed] = ACTIONS(2393),
    [anon_sym_unsigned] = ACTIONS(2393),
    [anon_sym_long] = ACTIONS(2393),
    [anon_sym_short] = ACTIONS(2393),
    [anon_sym_LBRACK] = ACTIONS(2393),
    [anon_sym_static] = ACTIONS(2393),
    [anon_sym_register] = ACTIONS(2393),
    [anon_sym_inline] = ACTIONS(2393),
    [anon_sym___inline] = ACTIONS(2393),
    [anon_sym___inline__] = ACTIONS(2393),
    [anon_sym___forceinline] = ACTIONS(2393),
    [anon_sym_thread_local] = ACTIONS(2393),
    [anon_sym___thread] = ACTIONS(2393),
    [anon_sym_const] = ACTIONS(2393),
    [anon_sym_constexpr] = ACTIONS(2393),
    [anon_sym_volatile] = ACTIONS(2393),
    [anon_sym_restrict] = ACTIONS(2393),
    [anon_sym___restrict__] = ACTIONS(2393),
    [anon_sym__Atomic] = ACTIONS(2393),
    [anon_sym__Noreturn] = ACTIONS(2393),
    [anon_sym_noreturn] = ACTIONS(2393),
    [anon_sym_mutable] = ACTIONS(2393),
    [anon_sym_constinit] = ACTIONS(2393),
    [anon_sym_consteval] = ACTIONS(2393),
    [anon_sym_alignas] = ACTIONS(2393),
    [anon_sym__Alignas] = ACTIONS(2393),
    [sym_primitive_type] = ACTIONS(2393),
    [anon_sym_enum] = ACTIONS(2393),
    [anon_sym_class] = ACTIONS(2393),
    [anon_sym_struct] = ACTIONS(2393),
    [anon_sym_union] = ACTIONS(2393),
    [anon_sym_if] = ACTIONS(2393),
    [anon_sym_switch] = ACTIONS(2393),
    [anon_sym_case] = ACTIONS(2393),
    [anon_sym_default] = ACTIONS(2393),
    [anon_sym_while] = ACTIONS(2393),
    [anon_sym_do] = ACTIONS(2393),
    [anon_sym_for] = ACTIONS(2393),
    [anon_sym_return] = ACTIONS(2393),
    [anon_sym_break] = ACTIONS(2393),
    [anon_sym_continue] = ACTIONS(2393),
    [anon_sym_goto] = ACTIONS(2393),
    [anon_sym___try] = ACTIONS(2393),
    [anon_sym___leave] = ACTIONS(2393),
    [anon_sym_not] = ACTIONS(2393),
    [anon_sym_compl] = ACTIONS(2393),
    [anon_sym_DASH_DASH] = ACTIONS(2395),
    [anon_sym_PLUS_PLUS] = ACTIONS(2395),
    [anon_sym_sizeof] = ACTIONS(2393),
    [anon_sym___alignof__] = ACTIONS(2393),
    [anon_sym___alignof] = ACTIONS(2393),
    [anon_sym__alignof] = ACTIONS(2393),
    [anon_sym_alignof] = ACTIONS(2393),
    [anon_sym__Alignof] = ACTIONS(2393),
    [anon_sym_offsetof] = ACTIONS(2393),
    [anon_sym__Generic] = ACTIONS(2393),
    [anon_sym_asm] = ACTIONS(2393),
    [anon_sym___asm__] = ACTIONS(2393),
    [sym_number_literal] = ACTIONS(2395),
    [anon_sym_L_SQUOTE] = ACTIONS(2395),
    [anon_sym_u_SQUOTE] = ACTIONS(2395),
    [anon_sym_U_SQUOTE] = ACTIONS(2395),
    [anon_sym_u8_SQUOTE] = ACTIONS(2395),
    [anon_sym_SQUOTE] = ACTIONS(2395),
    [anon_sym_L_DQUOTE] = ACTIONS(2395),
    [anon_sym_u_DQUOTE] = ACTIONS(2395),
    [anon_sym_U_DQUOTE] = ACTIONS(2395),
    [anon_sym_u8_DQUOTE] = ACTIONS(2395),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_true] = ACTIONS(2393),
    [sym_false] = ACTIONS(2393),
    [anon_sym_NULL] = ACTIONS(2393),
    [anon_sym_nullptr] = ACTIONS(2393),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2393),
    [anon_sym_decltype] = ACTIONS(2393),
    [sym_virtual] = ACTIONS(2393),
    [anon_sym_explicit] = ACTIONS(2393),
    [anon_sym_typename] = ACTIONS(2393),
    [anon_sym_template] = ACTIONS(2393),
    [anon_sym_operator] = ACTIONS(2393),
    [anon_sym_try] = ACTIONS(2393),
    [anon_sym_delete] = ACTIONS(2393),
    [anon_sym_throw] = ACTIONS(2393),
    [anon_sym_namespace] = ACTIONS(2393),
    [anon_sym_using] = ACTIONS(2393),
    [anon_sym_static_assert] = ACTIONS(2393),
    [anon_sym_concept] = ACTIONS(2393),
    [anon_sym_co_return] = ACTIONS(2393),
    [anon_sym_co_yield] = ACTIONS(2393),
    [anon_sym_R_DQUOTE] = ACTIONS(2395),
    [anon_sym_LR_DQUOTE] = ACTIONS(2395),
    [anon_sym_uR_DQUOTE] = ACTIONS(2395),
    [anon_sym_UR_DQUOTE] = ACTIONS(2395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2395),
    [anon_sym_co_await] = ACTIONS(2393),
    [anon_sym_new] = ACTIONS(2393),
    [anon_sym_requires] = ACTIONS(2393),
    [sym_this] = ACTIONS(2393),
    [anon_sym_discard] = ACTIONS(2393),
    [anon_sym_precise] = ACTIONS(2393),
    [anon_sym_shared] = ACTIONS(2393),
    [anon_sym_groupshared] = ACTIONS(2393),
    [anon_sym_uniform] = ACTIONS(2393),
    [anon_sym_row_major] = ACTIONS(2393),
    [anon_sym_column_major] = ACTIONS(2393),
    [anon_sym_globallycoherent] = ACTIONS(2393),
    [anon_sym_centroid] = ACTIONS(2393),
    [anon_sym_noperspective] = ACTIONS(2393),
    [anon_sym_nointerpolation] = ACTIONS(2393),
    [anon_sym_sample] = ACTIONS(2393),
    [anon_sym_linear] = ACTIONS(2393),
    [anon_sym_snorm] = ACTIONS(2393),
    [anon_sym_unorm] = ACTIONS(2393),
    [anon_sym_point] = ACTIONS(2393),
    [anon_sym_line] = ACTIONS(2393),
    [anon_sym_triangleadj] = ACTIONS(2393),
    [anon_sym_lineadj] = ACTIONS(2393),
    [anon_sym_triangle] = ACTIONS(2393),
    [anon_sym_cbuffer] = ACTIONS(2393),
  },
  [699] = {
    [sym_identifier] = ACTIONS(2520),
    [aux_sym_preproc_include_token1] = ACTIONS(2520),
    [aux_sym_preproc_def_token1] = ACTIONS(2520),
    [aux_sym_preproc_if_token1] = ACTIONS(2520),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2520),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2520),
    [sym_preproc_directive] = ACTIONS(2520),
    [anon_sym_LPAREN2] = ACTIONS(2522),
    [anon_sym_BANG] = ACTIONS(2522),
    [anon_sym_TILDE] = ACTIONS(2522),
    [anon_sym_DASH] = ACTIONS(2520),
    [anon_sym_PLUS] = ACTIONS(2520),
    [anon_sym_STAR] = ACTIONS(2522),
    [anon_sym_AMP_AMP] = ACTIONS(2522),
    [anon_sym_AMP] = ACTIONS(2520),
    [anon_sym_SEMI] = ACTIONS(2522),
    [anon_sym___extension__] = ACTIONS(2520),
    [anon_sym_typedef] = ACTIONS(2520),
    [anon_sym_in] = ACTIONS(2520),
    [anon_sym_out] = ACTIONS(2520),
    [anon_sym_inout] = ACTIONS(2520),
    [anon_sym_extern] = ACTIONS(2520),
    [anon_sym___attribute__] = ACTIONS(2520),
    [anon_sym_COLON_COLON] = ACTIONS(2522),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2522),
    [anon_sym___declspec] = ACTIONS(2520),
    [anon_sym___based] = ACTIONS(2520),
    [anon_sym___cdecl] = ACTIONS(2520),
    [anon_sym___clrcall] = ACTIONS(2520),
    [anon_sym___stdcall] = ACTIONS(2520),
    [anon_sym___fastcall] = ACTIONS(2520),
    [anon_sym___thiscall] = ACTIONS(2520),
    [anon_sym___vectorcall] = ACTIONS(2520),
    [anon_sym_LBRACE] = ACTIONS(2522),
    [anon_sym_RBRACE] = ACTIONS(2522),
    [anon_sym_signed] = ACTIONS(2520),
    [anon_sym_unsigned] = ACTIONS(2520),
    [anon_sym_long] = ACTIONS(2520),
    [anon_sym_short] = ACTIONS(2520),
    [anon_sym_LBRACK] = ACTIONS(2520),
    [anon_sym_static] = ACTIONS(2520),
    [anon_sym_register] = ACTIONS(2520),
    [anon_sym_inline] = ACTIONS(2520),
    [anon_sym___inline] = ACTIONS(2520),
    [anon_sym___inline__] = ACTIONS(2520),
    [anon_sym___forceinline] = ACTIONS(2520),
    [anon_sym_thread_local] = ACTIONS(2520),
    [anon_sym___thread] = ACTIONS(2520),
    [anon_sym_const] = ACTIONS(2520),
    [anon_sym_constexpr] = ACTIONS(2520),
    [anon_sym_volatile] = ACTIONS(2520),
    [anon_sym_restrict] = ACTIONS(2520),
    [anon_sym___restrict__] = ACTIONS(2520),
    [anon_sym__Atomic] = ACTIONS(2520),
    [anon_sym__Noreturn] = ACTIONS(2520),
    [anon_sym_noreturn] = ACTIONS(2520),
    [anon_sym_mutable] = ACTIONS(2520),
    [anon_sym_constinit] = ACTIONS(2520),
    [anon_sym_consteval] = ACTIONS(2520),
    [anon_sym_alignas] = ACTIONS(2520),
    [anon_sym__Alignas] = ACTIONS(2520),
    [sym_primitive_type] = ACTIONS(2520),
    [anon_sym_enum] = ACTIONS(2520),
    [anon_sym_class] = ACTIONS(2520),
    [anon_sym_struct] = ACTIONS(2520),
    [anon_sym_union] = ACTIONS(2520),
    [anon_sym_if] = ACTIONS(2520),
    [anon_sym_switch] = ACTIONS(2520),
    [anon_sym_case] = ACTIONS(2520),
    [anon_sym_default] = ACTIONS(2520),
    [anon_sym_while] = ACTIONS(2520),
    [anon_sym_do] = ACTIONS(2520),
    [anon_sym_for] = ACTIONS(2520),
    [anon_sym_return] = ACTIONS(2520),
    [anon_sym_break] = ACTIONS(2520),
    [anon_sym_continue] = ACTIONS(2520),
    [anon_sym_goto] = ACTIONS(2520),
    [anon_sym___try] = ACTIONS(2520),
    [anon_sym___leave] = ACTIONS(2520),
    [anon_sym_not] = ACTIONS(2520),
    [anon_sym_compl] = ACTIONS(2520),
    [anon_sym_DASH_DASH] = ACTIONS(2522),
    [anon_sym_PLUS_PLUS] = ACTIONS(2522),
    [anon_sym_sizeof] = ACTIONS(2520),
    [anon_sym___alignof__] = ACTIONS(2520),
    [anon_sym___alignof] = ACTIONS(2520),
    [anon_sym__alignof] = ACTIONS(2520),
    [anon_sym_alignof] = ACTIONS(2520),
    [anon_sym__Alignof] = ACTIONS(2520),
    [anon_sym_offsetof] = ACTIONS(2520),
    [anon_sym__Generic] = ACTIONS(2520),
    [anon_sym_asm] = ACTIONS(2520),
    [anon_sym___asm__] = ACTIONS(2520),
    [sym_number_literal] = ACTIONS(2522),
    [anon_sym_L_SQUOTE] = ACTIONS(2522),
    [anon_sym_u_SQUOTE] = ACTIONS(2522),
    [anon_sym_U_SQUOTE] = ACTIONS(2522),
    [anon_sym_u8_SQUOTE] = ACTIONS(2522),
    [anon_sym_SQUOTE] = ACTIONS(2522),
    [anon_sym_L_DQUOTE] = ACTIONS(2522),
    [anon_sym_u_DQUOTE] = ACTIONS(2522),
    [anon_sym_U_DQUOTE] = ACTIONS(2522),
    [anon_sym_u8_DQUOTE] = ACTIONS(2522),
    [anon_sym_DQUOTE] = ACTIONS(2522),
    [sym_true] = ACTIONS(2520),
    [sym_false] = ACTIONS(2520),
    [anon_sym_NULL] = ACTIONS(2520),
    [anon_sym_nullptr] = ACTIONS(2520),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2520),
    [anon_sym_decltype] = ACTIONS(2520),
    [sym_virtual] = ACTIONS(2520),
    [anon_sym_explicit] = ACTIONS(2520),
    [anon_sym_typename] = ACTIONS(2520),
    [anon_sym_template] = ACTIONS(2520),
    [anon_sym_operator] = ACTIONS(2520),
    [anon_sym_try] = ACTIONS(2520),
    [anon_sym_delete] = ACTIONS(2520),
    [anon_sym_throw] = ACTIONS(2520),
    [anon_sym_namespace] = ACTIONS(2520),
    [anon_sym_using] = ACTIONS(2520),
    [anon_sym_static_assert] = ACTIONS(2520),
    [anon_sym_concept] = ACTIONS(2520),
    [anon_sym_co_return] = ACTIONS(2520),
    [anon_sym_co_yield] = ACTIONS(2520),
    [anon_sym_R_DQUOTE] = ACTIONS(2522),
    [anon_sym_LR_DQUOTE] = ACTIONS(2522),
    [anon_sym_uR_DQUOTE] = ACTIONS(2522),
    [anon_sym_UR_DQUOTE] = ACTIONS(2522),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2522),
    [anon_sym_co_await] = ACTIONS(2520),
    [anon_sym_new] = ACTIONS(2520),
    [anon_sym_requires] = ACTIONS(2520),
    [sym_this] = ACTIONS(2520),
    [anon_sym_discard] = ACTIONS(2520),
    [anon_sym_precise] = ACTIONS(2520),
    [anon_sym_shared] = ACTIONS(2520),
    [anon_sym_groupshared] = ACTIONS(2520),
    [anon_sym_uniform] = ACTIONS(2520),
    [anon_sym_row_major] = ACTIONS(2520),
    [anon_sym_column_major] = ACTIONS(2520),
    [anon_sym_globallycoherent] = ACTIONS(2520),
    [anon_sym_centroid] = ACTIONS(2520),
    [anon_sym_noperspective] = ACTIONS(2520),
    [anon_sym_nointerpolation] = ACTIONS(2520),
    [anon_sym_sample] = ACTIONS(2520),
    [anon_sym_linear] = ACTIONS(2520),
    [anon_sym_snorm] = ACTIONS(2520),
    [anon_sym_unorm] = ACTIONS(2520),
    [anon_sym_point] = ACTIONS(2520),
    [anon_sym_line] = ACTIONS(2520),
    [anon_sym_triangleadj] = ACTIONS(2520),
    [anon_sym_lineadj] = ACTIONS(2520),
    [anon_sym_triangle] = ACTIONS(2520),
    [anon_sym_cbuffer] = ACTIONS(2520),
  },
  [700] = {
    [sym_identifier] = ACTIONS(2470),
    [aux_sym_preproc_include_token1] = ACTIONS(2470),
    [aux_sym_preproc_def_token1] = ACTIONS(2470),
    [aux_sym_preproc_if_token1] = ACTIONS(2470),
    [aux_sym_preproc_if_token2] = ACTIONS(2470),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2470),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2470),
    [sym_preproc_directive] = ACTIONS(2470),
    [anon_sym_LPAREN2] = ACTIONS(2472),
    [anon_sym_BANG] = ACTIONS(2472),
    [anon_sym_TILDE] = ACTIONS(2472),
    [anon_sym_DASH] = ACTIONS(2470),
    [anon_sym_PLUS] = ACTIONS(2470),
    [anon_sym_STAR] = ACTIONS(2472),
    [anon_sym_AMP_AMP] = ACTIONS(2472),
    [anon_sym_AMP] = ACTIONS(2470),
    [anon_sym_SEMI] = ACTIONS(2472),
    [anon_sym___extension__] = ACTIONS(2470),
    [anon_sym_typedef] = ACTIONS(2470),
    [anon_sym_in] = ACTIONS(2470),
    [anon_sym_out] = ACTIONS(2470),
    [anon_sym_inout] = ACTIONS(2470),
    [anon_sym_extern] = ACTIONS(2470),
    [anon_sym___attribute__] = ACTIONS(2470),
    [anon_sym_COLON_COLON] = ACTIONS(2472),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2472),
    [anon_sym___declspec] = ACTIONS(2470),
    [anon_sym___based] = ACTIONS(2470),
    [anon_sym___cdecl] = ACTIONS(2470),
    [anon_sym___clrcall] = ACTIONS(2470),
    [anon_sym___stdcall] = ACTIONS(2470),
    [anon_sym___fastcall] = ACTIONS(2470),
    [anon_sym___thiscall] = ACTIONS(2470),
    [anon_sym___vectorcall] = ACTIONS(2470),
    [anon_sym_LBRACE] = ACTIONS(2472),
    [anon_sym_signed] = ACTIONS(2470),
    [anon_sym_unsigned] = ACTIONS(2470),
    [anon_sym_long] = ACTIONS(2470),
    [anon_sym_short] = ACTIONS(2470),
    [anon_sym_LBRACK] = ACTIONS(2470),
    [anon_sym_static] = ACTIONS(2470),
    [anon_sym_register] = ACTIONS(2470),
    [anon_sym_inline] = ACTIONS(2470),
    [anon_sym___inline] = ACTIONS(2470),
    [anon_sym___inline__] = ACTIONS(2470),
    [anon_sym___forceinline] = ACTIONS(2470),
    [anon_sym_thread_local] = ACTIONS(2470),
    [anon_sym___thread] = ACTIONS(2470),
    [anon_sym_const] = ACTIONS(2470),
    [anon_sym_constexpr] = ACTIONS(2470),
    [anon_sym_volatile] = ACTIONS(2470),
    [anon_sym_restrict] = ACTIONS(2470),
    [anon_sym___restrict__] = ACTIONS(2470),
    [anon_sym__Atomic] = ACTIONS(2470),
    [anon_sym__Noreturn] = ACTIONS(2470),
    [anon_sym_noreturn] = ACTIONS(2470),
    [anon_sym_mutable] = ACTIONS(2470),
    [anon_sym_constinit] = ACTIONS(2470),
    [anon_sym_consteval] = ACTIONS(2470),
    [anon_sym_alignas] = ACTIONS(2470),
    [anon_sym__Alignas] = ACTIONS(2470),
    [sym_primitive_type] = ACTIONS(2470),
    [anon_sym_enum] = ACTIONS(2470),
    [anon_sym_class] = ACTIONS(2470),
    [anon_sym_struct] = ACTIONS(2470),
    [anon_sym_union] = ACTIONS(2470),
    [anon_sym_if] = ACTIONS(2470),
    [anon_sym_switch] = ACTIONS(2470),
    [anon_sym_case] = ACTIONS(2470),
    [anon_sym_default] = ACTIONS(2470),
    [anon_sym_while] = ACTIONS(2470),
    [anon_sym_do] = ACTIONS(2470),
    [anon_sym_for] = ACTIONS(2470),
    [anon_sym_return] = ACTIONS(2470),
    [anon_sym_break] = ACTIONS(2470),
    [anon_sym_continue] = ACTIONS(2470),
    [anon_sym_goto] = ACTIONS(2470),
    [anon_sym___try] = ACTIONS(2470),
    [anon_sym___leave] = ACTIONS(2470),
    [anon_sym_not] = ACTIONS(2470),
    [anon_sym_compl] = ACTIONS(2470),
    [anon_sym_DASH_DASH] = ACTIONS(2472),
    [anon_sym_PLUS_PLUS] = ACTIONS(2472),
    [anon_sym_sizeof] = ACTIONS(2470),
    [anon_sym___alignof__] = ACTIONS(2470),
    [anon_sym___alignof] = ACTIONS(2470),
    [anon_sym__alignof] = ACTIONS(2470),
    [anon_sym_alignof] = ACTIONS(2470),
    [anon_sym__Alignof] = ACTIONS(2470),
    [anon_sym_offsetof] = ACTIONS(2470),
    [anon_sym__Generic] = ACTIONS(2470),
    [anon_sym_asm] = ACTIONS(2470),
    [anon_sym___asm__] = ACTIONS(2470),
    [sym_number_literal] = ACTIONS(2472),
    [anon_sym_L_SQUOTE] = ACTIONS(2472),
    [anon_sym_u_SQUOTE] = ACTIONS(2472),
    [anon_sym_U_SQUOTE] = ACTIONS(2472),
    [anon_sym_u8_SQUOTE] = ACTIONS(2472),
    [anon_sym_SQUOTE] = ACTIONS(2472),
    [anon_sym_L_DQUOTE] = ACTIONS(2472),
    [anon_sym_u_DQUOTE] = ACTIONS(2472),
    [anon_sym_U_DQUOTE] = ACTIONS(2472),
    [anon_sym_u8_DQUOTE] = ACTIONS(2472),
    [anon_sym_DQUOTE] = ACTIONS(2472),
    [sym_true] = ACTIONS(2470),
    [sym_false] = ACTIONS(2470),
    [anon_sym_NULL] = ACTIONS(2470),
    [anon_sym_nullptr] = ACTIONS(2470),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2470),
    [anon_sym_decltype] = ACTIONS(2470),
    [sym_virtual] = ACTIONS(2470),
    [anon_sym_explicit] = ACTIONS(2470),
    [anon_sym_typename] = ACTIONS(2470),
    [anon_sym_template] = ACTIONS(2470),
    [anon_sym_operator] = ACTIONS(2470),
    [anon_sym_try] = ACTIONS(2470),
    [anon_sym_delete] = ACTIONS(2470),
    [anon_sym_throw] = ACTIONS(2470),
    [anon_sym_namespace] = ACTIONS(2470),
    [anon_sym_using] = ACTIONS(2470),
    [anon_sym_static_assert] = ACTIONS(2470),
    [anon_sym_concept] = ACTIONS(2470),
    [anon_sym_co_return] = ACTIONS(2470),
    [anon_sym_co_yield] = ACTIONS(2470),
    [anon_sym_R_DQUOTE] = ACTIONS(2472),
    [anon_sym_LR_DQUOTE] = ACTIONS(2472),
    [anon_sym_uR_DQUOTE] = ACTIONS(2472),
    [anon_sym_UR_DQUOTE] = ACTIONS(2472),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2472),
    [anon_sym_co_await] = ACTIONS(2470),
    [anon_sym_new] = ACTIONS(2470),
    [anon_sym_requires] = ACTIONS(2470),
    [sym_this] = ACTIONS(2470),
    [anon_sym_discard] = ACTIONS(2470),
    [anon_sym_precise] = ACTIONS(2470),
    [anon_sym_shared] = ACTIONS(2470),
    [anon_sym_groupshared] = ACTIONS(2470),
    [anon_sym_uniform] = ACTIONS(2470),
    [anon_sym_row_major] = ACTIONS(2470),
    [anon_sym_column_major] = ACTIONS(2470),
    [anon_sym_globallycoherent] = ACTIONS(2470),
    [anon_sym_centroid] = ACTIONS(2470),
    [anon_sym_noperspective] = ACTIONS(2470),
    [anon_sym_nointerpolation] = ACTIONS(2470),
    [anon_sym_sample] = ACTIONS(2470),
    [anon_sym_linear] = ACTIONS(2470),
    [anon_sym_snorm] = ACTIONS(2470),
    [anon_sym_unorm] = ACTIONS(2470),
    [anon_sym_point] = ACTIONS(2470),
    [anon_sym_line] = ACTIONS(2470),
    [anon_sym_triangleadj] = ACTIONS(2470),
    [anon_sym_lineadj] = ACTIONS(2470),
    [anon_sym_triangle] = ACTIONS(2470),
    [anon_sym_cbuffer] = ACTIONS(2470),
  },
  [701] = {
    [sym_identifier] = ACTIONS(2557),
    [aux_sym_preproc_include_token1] = ACTIONS(2557),
    [aux_sym_preproc_def_token1] = ACTIONS(2557),
    [aux_sym_preproc_if_token1] = ACTIONS(2557),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2557),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2557),
    [sym_preproc_directive] = ACTIONS(2557),
    [anon_sym_LPAREN2] = ACTIONS(2559),
    [anon_sym_BANG] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(2559),
    [anon_sym_DASH] = ACTIONS(2557),
    [anon_sym_PLUS] = ACTIONS(2557),
    [anon_sym_STAR] = ACTIONS(2559),
    [anon_sym_AMP_AMP] = ACTIONS(2559),
    [anon_sym_AMP] = ACTIONS(2557),
    [anon_sym_SEMI] = ACTIONS(2559),
    [anon_sym___extension__] = ACTIONS(2557),
    [anon_sym_typedef] = ACTIONS(2557),
    [anon_sym_in] = ACTIONS(2557),
    [anon_sym_out] = ACTIONS(2557),
    [anon_sym_inout] = ACTIONS(2557),
    [anon_sym_extern] = ACTIONS(2557),
    [anon_sym___attribute__] = ACTIONS(2557),
    [anon_sym_COLON_COLON] = ACTIONS(2559),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2559),
    [anon_sym___declspec] = ACTIONS(2557),
    [anon_sym___based] = ACTIONS(2557),
    [anon_sym___cdecl] = ACTIONS(2557),
    [anon_sym___clrcall] = ACTIONS(2557),
    [anon_sym___stdcall] = ACTIONS(2557),
    [anon_sym___fastcall] = ACTIONS(2557),
    [anon_sym___thiscall] = ACTIONS(2557),
    [anon_sym___vectorcall] = ACTIONS(2557),
    [anon_sym_LBRACE] = ACTIONS(2559),
    [anon_sym_RBRACE] = ACTIONS(2559),
    [anon_sym_signed] = ACTIONS(2557),
    [anon_sym_unsigned] = ACTIONS(2557),
    [anon_sym_long] = ACTIONS(2557),
    [anon_sym_short] = ACTIONS(2557),
    [anon_sym_LBRACK] = ACTIONS(2557),
    [anon_sym_static] = ACTIONS(2557),
    [anon_sym_register] = ACTIONS(2557),
    [anon_sym_inline] = ACTIONS(2557),
    [anon_sym___inline] = ACTIONS(2557),
    [anon_sym___inline__] = ACTIONS(2557),
    [anon_sym___forceinline] = ACTIONS(2557),
    [anon_sym_thread_local] = ACTIONS(2557),
    [anon_sym___thread] = ACTIONS(2557),
    [anon_sym_const] = ACTIONS(2557),
    [anon_sym_constexpr] = ACTIONS(2557),
    [anon_sym_volatile] = ACTIONS(2557),
    [anon_sym_restrict] = ACTIONS(2557),
    [anon_sym___restrict__] = ACTIONS(2557),
    [anon_sym__Atomic] = ACTIONS(2557),
    [anon_sym__Noreturn] = ACTIONS(2557),
    [anon_sym_noreturn] = ACTIONS(2557),
    [anon_sym_mutable] = ACTIONS(2557),
    [anon_sym_constinit] = ACTIONS(2557),
    [anon_sym_consteval] = ACTIONS(2557),
    [anon_sym_alignas] = ACTIONS(2557),
    [anon_sym__Alignas] = ACTIONS(2557),
    [sym_primitive_type] = ACTIONS(2557),
    [anon_sym_enum] = ACTIONS(2557),
    [anon_sym_class] = ACTIONS(2557),
    [anon_sym_struct] = ACTIONS(2557),
    [anon_sym_union] = ACTIONS(2557),
    [anon_sym_if] = ACTIONS(2557),
    [anon_sym_switch] = ACTIONS(2557),
    [anon_sym_case] = ACTIONS(2557),
    [anon_sym_default] = ACTIONS(2557),
    [anon_sym_while] = ACTIONS(2557),
    [anon_sym_do] = ACTIONS(2557),
    [anon_sym_for] = ACTIONS(2557),
    [anon_sym_return] = ACTIONS(2557),
    [anon_sym_break] = ACTIONS(2557),
    [anon_sym_continue] = ACTIONS(2557),
    [anon_sym_goto] = ACTIONS(2557),
    [anon_sym___try] = ACTIONS(2557),
    [anon_sym___leave] = ACTIONS(2557),
    [anon_sym_not] = ACTIONS(2557),
    [anon_sym_compl] = ACTIONS(2557),
    [anon_sym_DASH_DASH] = ACTIONS(2559),
    [anon_sym_PLUS_PLUS] = ACTIONS(2559),
    [anon_sym_sizeof] = ACTIONS(2557),
    [anon_sym___alignof__] = ACTIONS(2557),
    [anon_sym___alignof] = ACTIONS(2557),
    [anon_sym__alignof] = ACTIONS(2557),
    [anon_sym_alignof] = ACTIONS(2557),
    [anon_sym__Alignof] = ACTIONS(2557),
    [anon_sym_offsetof] = ACTIONS(2557),
    [anon_sym__Generic] = ACTIONS(2557),
    [anon_sym_asm] = ACTIONS(2557),
    [anon_sym___asm__] = ACTIONS(2557),
    [sym_number_literal] = ACTIONS(2559),
    [anon_sym_L_SQUOTE] = ACTIONS(2559),
    [anon_sym_u_SQUOTE] = ACTIONS(2559),
    [anon_sym_U_SQUOTE] = ACTIONS(2559),
    [anon_sym_u8_SQUOTE] = ACTIONS(2559),
    [anon_sym_SQUOTE] = ACTIONS(2559),
    [anon_sym_L_DQUOTE] = ACTIONS(2559),
    [anon_sym_u_DQUOTE] = ACTIONS(2559),
    [anon_sym_U_DQUOTE] = ACTIONS(2559),
    [anon_sym_u8_DQUOTE] = ACTIONS(2559),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_true] = ACTIONS(2557),
    [sym_false] = ACTIONS(2557),
    [anon_sym_NULL] = ACTIONS(2557),
    [anon_sym_nullptr] = ACTIONS(2557),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2557),
    [anon_sym_decltype] = ACTIONS(2557),
    [sym_virtual] = ACTIONS(2557),
    [anon_sym_explicit] = ACTIONS(2557),
    [anon_sym_typename] = ACTIONS(2557),
    [anon_sym_template] = ACTIONS(2557),
    [anon_sym_operator] = ACTIONS(2557),
    [anon_sym_try] = ACTIONS(2557),
    [anon_sym_delete] = ACTIONS(2557),
    [anon_sym_throw] = ACTIONS(2557),
    [anon_sym_namespace] = ACTIONS(2557),
    [anon_sym_using] = ACTIONS(2557),
    [anon_sym_static_assert] = ACTIONS(2557),
    [anon_sym_concept] = ACTIONS(2557),
    [anon_sym_co_return] = ACTIONS(2557),
    [anon_sym_co_yield] = ACTIONS(2557),
    [anon_sym_R_DQUOTE] = ACTIONS(2559),
    [anon_sym_LR_DQUOTE] = ACTIONS(2559),
    [anon_sym_uR_DQUOTE] = ACTIONS(2559),
    [anon_sym_UR_DQUOTE] = ACTIONS(2559),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2559),
    [anon_sym_co_await] = ACTIONS(2557),
    [anon_sym_new] = ACTIONS(2557),
    [anon_sym_requires] = ACTIONS(2557),
    [sym_this] = ACTIONS(2557),
    [anon_sym_discard] = ACTIONS(2557),
    [anon_sym_precise] = ACTIONS(2557),
    [anon_sym_shared] = ACTIONS(2557),
    [anon_sym_groupshared] = ACTIONS(2557),
    [anon_sym_uniform] = ACTIONS(2557),
    [anon_sym_row_major] = ACTIONS(2557),
    [anon_sym_column_major] = ACTIONS(2557),
    [anon_sym_globallycoherent] = ACTIONS(2557),
    [anon_sym_centroid] = ACTIONS(2557),
    [anon_sym_noperspective] = ACTIONS(2557),
    [anon_sym_nointerpolation] = ACTIONS(2557),
    [anon_sym_sample] = ACTIONS(2557),
    [anon_sym_linear] = ACTIONS(2557),
    [anon_sym_snorm] = ACTIONS(2557),
    [anon_sym_unorm] = ACTIONS(2557),
    [anon_sym_point] = ACTIONS(2557),
    [anon_sym_line] = ACTIONS(2557),
    [anon_sym_triangleadj] = ACTIONS(2557),
    [anon_sym_lineadj] = ACTIONS(2557),
    [anon_sym_triangle] = ACTIONS(2557),
    [anon_sym_cbuffer] = ACTIONS(2557),
  },
  [702] = {
    [sym_preproc_def] = STATE(702),
    [sym_preproc_function_def] = STATE(702),
    [sym_preproc_call] = STATE(702),
    [sym_preproc_if_in_field_declaration_list] = STATE(702),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(702),
    [sym_type_definition] = STATE(702),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5626),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6102),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(702),
    [sym_field_declaration] = STATE(702),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1832),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(702),
    [sym_operator_cast] = STATE(6636),
    [sym_inline_method_definition] = STATE(702),
    [sym__constructor_specifiers] = STATE(1832),
    [sym_operator_cast_definition] = STATE(702),
    [sym_operator_cast_declaration] = STATE(702),
    [sym_constructor_or_destructor_definition] = STATE(702),
    [sym_constructor_or_destructor_declaration] = STATE(702),
    [sym_friend_declaration] = STATE(702),
    [sym_access_specifier] = STATE(8379),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(702),
    [sym_alias_declaration] = STATE(702),
    [sym_static_assert_declaration] = STATE(702),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6636),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(702),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1832),
    [sym_identifier] = ACTIONS(2728),
    [aux_sym_preproc_def_token1] = ACTIONS(2731),
    [aux_sym_preproc_if_token1] = ACTIONS(2734),
    [aux_sym_preproc_if_token2] = ACTIONS(2737),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2739),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2739),
    [aux_sym_preproc_else_token1] = ACTIONS(2737),
    [aux_sym_preproc_elif_token1] = ACTIONS(2737),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2737),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2737),
    [sym_preproc_directive] = ACTIONS(2742),
    [anon_sym_LPAREN2] = ACTIONS(2745),
    [anon_sym_TILDE] = ACTIONS(2748),
    [anon_sym_STAR] = ACTIONS(2751),
    [anon_sym_AMP_AMP] = ACTIONS(2754),
    [anon_sym_AMP] = ACTIONS(2757),
    [anon_sym___extension__] = ACTIONS(2760),
    [anon_sym_typedef] = ACTIONS(2763),
    [anon_sym_in] = ACTIONS(2766),
    [anon_sym_out] = ACTIONS(2766),
    [anon_sym_inout] = ACTIONS(2766),
    [anon_sym_extern] = ACTIONS(2769),
    [anon_sym___attribute__] = ACTIONS(2772),
    [anon_sym_COLON_COLON] = ACTIONS(2775),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2778),
    [anon_sym___declspec] = ACTIONS(2781),
    [anon_sym___based] = ACTIONS(2784),
    [anon_sym_signed] = ACTIONS(2787),
    [anon_sym_unsigned] = ACTIONS(2787),
    [anon_sym_long] = ACTIONS(2787),
    [anon_sym_short] = ACTIONS(2787),
    [anon_sym_LBRACK] = ACTIONS(2790),
    [anon_sym_static] = ACTIONS(2769),
    [anon_sym_register] = ACTIONS(2769),
    [anon_sym_inline] = ACTIONS(2769),
    [anon_sym___inline] = ACTIONS(2769),
    [anon_sym___inline__] = ACTIONS(2769),
    [anon_sym___forceinline] = ACTIONS(2769),
    [anon_sym_thread_local] = ACTIONS(2769),
    [anon_sym___thread] = ACTIONS(2769),
    [anon_sym_const] = ACTIONS(2793),
    [anon_sym_constexpr] = ACTIONS(2793),
    [anon_sym_volatile] = ACTIONS(2793),
    [anon_sym_restrict] = ACTIONS(2793),
    [anon_sym___restrict__] = ACTIONS(2793),
    [anon_sym__Atomic] = ACTIONS(2793),
    [anon_sym__Noreturn] = ACTIONS(2793),
    [anon_sym_noreturn] = ACTIONS(2793),
    [anon_sym_mutable] = ACTIONS(2793),
    [anon_sym_constinit] = ACTIONS(2793),
    [anon_sym_consteval] = ACTIONS(2793),
    [anon_sym_alignas] = ACTIONS(2796),
    [anon_sym__Alignas] = ACTIONS(2796),
    [sym_primitive_type] = ACTIONS(2799),
    [anon_sym_enum] = ACTIONS(2802),
    [anon_sym_class] = ACTIONS(2805),
    [anon_sym_struct] = ACTIONS(2808),
    [anon_sym_union] = ACTIONS(2811),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2814),
    [anon_sym_decltype] = ACTIONS(2817),
    [sym_virtual] = ACTIONS(2766),
    [anon_sym_explicit] = ACTIONS(2820),
    [anon_sym_typename] = ACTIONS(2823),
    [anon_sym_template] = ACTIONS(2826),
    [anon_sym_operator] = ACTIONS(2829),
    [anon_sym_friend] = ACTIONS(2832),
    [anon_sym_public] = ACTIONS(2835),
    [anon_sym_private] = ACTIONS(2835),
    [anon_sym_protected] = ACTIONS(2835),
    [anon_sym_using] = ACTIONS(2838),
    [anon_sym_static_assert] = ACTIONS(2841),
    [anon_sym_precise] = ACTIONS(2844),
    [anon_sym_shared] = ACTIONS(2844),
    [anon_sym_groupshared] = ACTIONS(2844),
    [anon_sym_uniform] = ACTIONS(2844),
    [anon_sym_row_major] = ACTIONS(2844),
    [anon_sym_column_major] = ACTIONS(2844),
    [anon_sym_globallycoherent] = ACTIONS(2844),
    [anon_sym_centroid] = ACTIONS(2844),
    [anon_sym_noperspective] = ACTIONS(2844),
    [anon_sym_nointerpolation] = ACTIONS(2844),
    [anon_sym_sample] = ACTIONS(2844),
    [anon_sym_linear] = ACTIONS(2844),
    [anon_sym_snorm] = ACTIONS(2844),
    [anon_sym_unorm] = ACTIONS(2844),
    [anon_sym_point] = ACTIONS(2844),
    [anon_sym_line] = ACTIONS(2844),
    [anon_sym_triangleadj] = ACTIONS(2844),
    [anon_sym_lineadj] = ACTIONS(2844),
    [anon_sym_triangle] = ACTIONS(2844),
  },
  [703] = {
    [sym_expression] = STATE(4363),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(2849),
    [anon_sym_in] = ACTIONS(2849),
    [anon_sym_out] = ACTIONS(2849),
    [anon_sym_inout] = ACTIONS(2849),
    [anon_sym_extern] = ACTIONS(2849),
    [anon_sym___attribute__] = ACTIONS(2849),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2851),
    [anon_sym___declspec] = ACTIONS(2849),
    [anon_sym_signed] = ACTIONS(2849),
    [anon_sym_unsigned] = ACTIONS(2849),
    [anon_sym_long] = ACTIONS(2849),
    [anon_sym_short] = ACTIONS(2849),
    [anon_sym_LBRACK] = ACTIONS(1807),
    [anon_sym_static] = ACTIONS(2849),
    [anon_sym_register] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2849),
    [anon_sym___inline] = ACTIONS(2849),
    [anon_sym___inline__] = ACTIONS(2849),
    [anon_sym___forceinline] = ACTIONS(2849),
    [anon_sym_thread_local] = ACTIONS(2849),
    [anon_sym___thread] = ACTIONS(2849),
    [anon_sym_const] = ACTIONS(2849),
    [anon_sym_constexpr] = ACTIONS(2849),
    [anon_sym_volatile] = ACTIONS(2849),
    [anon_sym_restrict] = ACTIONS(2849),
    [anon_sym___restrict__] = ACTIONS(2849),
    [anon_sym__Atomic] = ACTIONS(2849),
    [anon_sym__Noreturn] = ACTIONS(2849),
    [anon_sym_noreturn] = ACTIONS(2849),
    [anon_sym_mutable] = ACTIONS(2849),
    [anon_sym_constinit] = ACTIONS(2849),
    [anon_sym_consteval] = ACTIONS(2849),
    [anon_sym_alignas] = ACTIONS(2849),
    [anon_sym__Alignas] = ACTIONS(2849),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_enum] = ACTIONS(2849),
    [anon_sym_class] = ACTIONS(2849),
    [anon_sym_struct] = ACTIONS(2849),
    [anon_sym_union] = ACTIONS(2849),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2849),
    [anon_sym_decltype] = ACTIONS(2855),
    [sym_virtual] = ACTIONS(2849),
    [anon_sym_typename] = ACTIONS(2849),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_precise] = ACTIONS(2849),
    [anon_sym_shared] = ACTIONS(2849),
    [anon_sym_groupshared] = ACTIONS(2849),
    [anon_sym_uniform] = ACTIONS(2849),
    [anon_sym_row_major] = ACTIONS(2849),
    [anon_sym_column_major] = ACTIONS(2849),
    [anon_sym_globallycoherent] = ACTIONS(2849),
    [anon_sym_centroid] = ACTIONS(2849),
    [anon_sym_noperspective] = ACTIONS(2849),
    [anon_sym_nointerpolation] = ACTIONS(2849),
    [anon_sym_sample] = ACTIONS(2849),
    [anon_sym_linear] = ACTIONS(2849),
    [anon_sym_snorm] = ACTIONS(2849),
    [anon_sym_unorm] = ACTIONS(2849),
    [anon_sym_point] = ACTIONS(2849),
    [anon_sym_line] = ACTIONS(2849),
    [anon_sym_triangleadj] = ACTIONS(2849),
    [anon_sym_lineadj] = ACTIONS(2849),
    [anon_sym_triangle] = ACTIONS(2849),
  },
  [704] = {
    [sym_catch_clause] = STATE(276),
    [aux_sym_constructor_try_statement_repeat1] = STATE(276),
    [ts_builtin_sym_end] = ACTIONS(1992),
    [sym_identifier] = ACTIONS(1990),
    [aux_sym_preproc_include_token1] = ACTIONS(1990),
    [aux_sym_preproc_def_token1] = ACTIONS(1990),
    [aux_sym_preproc_if_token1] = ACTIONS(1990),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1990),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1990),
    [sym_preproc_directive] = ACTIONS(1990),
    [anon_sym_LPAREN2] = ACTIONS(1992),
    [anon_sym_BANG] = ACTIONS(1992),
    [anon_sym_TILDE] = ACTIONS(1992),
    [anon_sym_DASH] = ACTIONS(1990),
    [anon_sym_PLUS] = ACTIONS(1990),
    [anon_sym_STAR] = ACTIONS(1992),
    [anon_sym_AMP_AMP] = ACTIONS(1992),
    [anon_sym_AMP] = ACTIONS(1990),
    [anon_sym___extension__] = ACTIONS(1990),
    [anon_sym_typedef] = ACTIONS(1990),
    [anon_sym_in] = ACTIONS(1990),
    [anon_sym_out] = ACTIONS(1990),
    [anon_sym_inout] = ACTIONS(1990),
    [anon_sym_extern] = ACTIONS(1990),
    [anon_sym___attribute__] = ACTIONS(1990),
    [anon_sym_COLON_COLON] = ACTIONS(1992),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1992),
    [anon_sym___declspec] = ACTIONS(1990),
    [anon_sym___based] = ACTIONS(1990),
    [anon_sym___cdecl] = ACTIONS(1990),
    [anon_sym___clrcall] = ACTIONS(1990),
    [anon_sym___stdcall] = ACTIONS(1990),
    [anon_sym___fastcall] = ACTIONS(1990),
    [anon_sym___thiscall] = ACTIONS(1990),
    [anon_sym___vectorcall] = ACTIONS(1990),
    [anon_sym_LBRACE] = ACTIONS(1992),
    [anon_sym_signed] = ACTIONS(1990),
    [anon_sym_unsigned] = ACTIONS(1990),
    [anon_sym_long] = ACTIONS(1990),
    [anon_sym_short] = ACTIONS(1990),
    [anon_sym_LBRACK] = ACTIONS(1990),
    [anon_sym_static] = ACTIONS(1990),
    [anon_sym_register] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1990),
    [anon_sym___inline] = ACTIONS(1990),
    [anon_sym___inline__] = ACTIONS(1990),
    [anon_sym___forceinline] = ACTIONS(1990),
    [anon_sym_thread_local] = ACTIONS(1990),
    [anon_sym___thread] = ACTIONS(1990),
    [anon_sym_const] = ACTIONS(1990),
    [anon_sym_constexpr] = ACTIONS(1990),
    [anon_sym_volatile] = ACTIONS(1990),
    [anon_sym_restrict] = ACTIONS(1990),
    [anon_sym___restrict__] = ACTIONS(1990),
    [anon_sym__Atomic] = ACTIONS(1990),
    [anon_sym__Noreturn] = ACTIONS(1990),
    [anon_sym_noreturn] = ACTIONS(1990),
    [anon_sym_mutable] = ACTIONS(1990),
    [anon_sym_constinit] = ACTIONS(1990),
    [anon_sym_consteval] = ACTIONS(1990),
    [anon_sym_alignas] = ACTIONS(1990),
    [anon_sym__Alignas] = ACTIONS(1990),
    [sym_primitive_type] = ACTIONS(1990),
    [anon_sym_enum] = ACTIONS(1990),
    [anon_sym_class] = ACTIONS(1990),
    [anon_sym_struct] = ACTIONS(1990),
    [anon_sym_union] = ACTIONS(1990),
    [anon_sym_if] = ACTIONS(1990),
    [anon_sym_switch] = ACTIONS(1990),
    [anon_sym_case] = ACTIONS(1990),
    [anon_sym_default] = ACTIONS(1990),
    [anon_sym_while] = ACTIONS(1990),
    [anon_sym_do] = ACTIONS(1990),
    [anon_sym_for] = ACTIONS(1990),
    [anon_sym_return] = ACTIONS(1990),
    [anon_sym_break] = ACTIONS(1990),
    [anon_sym_continue] = ACTIONS(1990),
    [anon_sym_goto] = ACTIONS(1990),
    [anon_sym_not] = ACTIONS(1990),
    [anon_sym_compl] = ACTIONS(1990),
    [anon_sym_DASH_DASH] = ACTIONS(1992),
    [anon_sym_PLUS_PLUS] = ACTIONS(1992),
    [anon_sym_sizeof] = ACTIONS(1990),
    [anon_sym___alignof__] = ACTIONS(1990),
    [anon_sym___alignof] = ACTIONS(1990),
    [anon_sym__alignof] = ACTIONS(1990),
    [anon_sym_alignof] = ACTIONS(1990),
    [anon_sym__Alignof] = ACTIONS(1990),
    [anon_sym_offsetof] = ACTIONS(1990),
    [anon_sym__Generic] = ACTIONS(1990),
    [anon_sym_asm] = ACTIONS(1990),
    [anon_sym___asm__] = ACTIONS(1990),
    [sym_number_literal] = ACTIONS(1992),
    [anon_sym_L_SQUOTE] = ACTIONS(1992),
    [anon_sym_u_SQUOTE] = ACTIONS(1992),
    [anon_sym_U_SQUOTE] = ACTIONS(1992),
    [anon_sym_u8_SQUOTE] = ACTIONS(1992),
    [anon_sym_SQUOTE] = ACTIONS(1992),
    [anon_sym_L_DQUOTE] = ACTIONS(1992),
    [anon_sym_u_DQUOTE] = ACTIONS(1992),
    [anon_sym_U_DQUOTE] = ACTIONS(1992),
    [anon_sym_u8_DQUOTE] = ACTIONS(1992),
    [anon_sym_DQUOTE] = ACTIONS(1992),
    [sym_true] = ACTIONS(1990),
    [sym_false] = ACTIONS(1990),
    [anon_sym_NULL] = ACTIONS(1990),
    [anon_sym_nullptr] = ACTIONS(1990),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1990),
    [anon_sym_decltype] = ACTIONS(1990),
    [sym_virtual] = ACTIONS(1990),
    [anon_sym_explicit] = ACTIONS(1990),
    [anon_sym_typename] = ACTIONS(1990),
    [anon_sym_template] = ACTIONS(1990),
    [anon_sym_operator] = ACTIONS(1990),
    [anon_sym_try] = ACTIONS(1990),
    [anon_sym_delete] = ACTIONS(1990),
    [anon_sym_throw] = ACTIONS(1990),
    [anon_sym_namespace] = ACTIONS(1990),
    [anon_sym_using] = ACTIONS(1990),
    [anon_sym_static_assert] = ACTIONS(1990),
    [anon_sym_concept] = ACTIONS(1990),
    [anon_sym_co_return] = ACTIONS(1990),
    [anon_sym_co_yield] = ACTIONS(1990),
    [anon_sym_catch] = ACTIONS(2514),
    [anon_sym_R_DQUOTE] = ACTIONS(1992),
    [anon_sym_LR_DQUOTE] = ACTIONS(1992),
    [anon_sym_uR_DQUOTE] = ACTIONS(1992),
    [anon_sym_UR_DQUOTE] = ACTIONS(1992),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1992),
    [anon_sym_co_await] = ACTIONS(1990),
    [anon_sym_new] = ACTIONS(1990),
    [anon_sym_requires] = ACTIONS(1990),
    [sym_this] = ACTIONS(1990),
    [anon_sym_precise] = ACTIONS(1990),
    [anon_sym_shared] = ACTIONS(1990),
    [anon_sym_groupshared] = ACTIONS(1990),
    [anon_sym_uniform] = ACTIONS(1990),
    [anon_sym_row_major] = ACTIONS(1990),
    [anon_sym_column_major] = ACTIONS(1990),
    [anon_sym_globallycoherent] = ACTIONS(1990),
    [anon_sym_centroid] = ACTIONS(1990),
    [anon_sym_noperspective] = ACTIONS(1990),
    [anon_sym_nointerpolation] = ACTIONS(1990),
    [anon_sym_sample] = ACTIONS(1990),
    [anon_sym_linear] = ACTIONS(1990),
    [anon_sym_snorm] = ACTIONS(1990),
    [anon_sym_unorm] = ACTIONS(1990),
    [anon_sym_point] = ACTIONS(1990),
    [anon_sym_line] = ACTIONS(1990),
    [anon_sym_triangleadj] = ACTIONS(1990),
    [anon_sym_lineadj] = ACTIONS(1990),
    [anon_sym_triangle] = ACTIONS(1990),
  },
  [705] = {
    [ts_builtin_sym_end] = ACTIONS(1945),
    [sym_identifier] = ACTIONS(1947),
    [aux_sym_preproc_include_token1] = ACTIONS(1947),
    [aux_sym_preproc_def_token1] = ACTIONS(1947),
    [anon_sym_COMMA] = ACTIONS(2202),
    [anon_sym_RPAREN] = ACTIONS(2202),
    [aux_sym_preproc_if_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1947),
    [sym_preproc_directive] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1945),
    [anon_sym_BANG] = ACTIONS(1945),
    [anon_sym_TILDE] = ACTIONS(1945),
    [anon_sym_DASH] = ACTIONS(1947),
    [anon_sym_PLUS] = ACTIONS(1947),
    [anon_sym_STAR] = ACTIONS(1945),
    [anon_sym_AMP_AMP] = ACTIONS(1945),
    [anon_sym_AMP] = ACTIONS(1947),
    [anon_sym_SEMI] = ACTIONS(2202),
    [anon_sym___extension__] = ACTIONS(1947),
    [anon_sym_typedef] = ACTIONS(1947),
    [anon_sym_in] = ACTIONS(1947),
    [anon_sym_out] = ACTIONS(1947),
    [anon_sym_inout] = ACTIONS(1947),
    [anon_sym_extern] = ACTIONS(1947),
    [anon_sym___attribute__] = ACTIONS(1947),
    [anon_sym_COLON_COLON] = ACTIONS(1945),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1945),
    [anon_sym___declspec] = ACTIONS(1947),
    [anon_sym___based] = ACTIONS(1947),
    [anon_sym___cdecl] = ACTIONS(1947),
    [anon_sym___clrcall] = ACTIONS(1947),
    [anon_sym___stdcall] = ACTIONS(1947),
    [anon_sym___fastcall] = ACTIONS(1947),
    [anon_sym___thiscall] = ACTIONS(1947),
    [anon_sym___vectorcall] = ACTIONS(1947),
    [anon_sym_LBRACE] = ACTIONS(1945),
    [anon_sym_signed] = ACTIONS(1947),
    [anon_sym_unsigned] = ACTIONS(1947),
    [anon_sym_long] = ACTIONS(1947),
    [anon_sym_short] = ACTIONS(1947),
    [anon_sym_LBRACK] = ACTIONS(1947),
    [anon_sym_static] = ACTIONS(1947),
    [anon_sym_register] = ACTIONS(1947),
    [anon_sym_inline] = ACTIONS(1947),
    [anon_sym___inline] = ACTIONS(1947),
    [anon_sym___inline__] = ACTIONS(1947),
    [anon_sym___forceinline] = ACTIONS(1947),
    [anon_sym_thread_local] = ACTIONS(1947),
    [anon_sym___thread] = ACTIONS(1947),
    [anon_sym_const] = ACTIONS(1947),
    [anon_sym_constexpr] = ACTIONS(1947),
    [anon_sym_volatile] = ACTIONS(1947),
    [anon_sym_restrict] = ACTIONS(1947),
    [anon_sym___restrict__] = ACTIONS(1947),
    [anon_sym__Atomic] = ACTIONS(1947),
    [anon_sym__Noreturn] = ACTIONS(1947),
    [anon_sym_noreturn] = ACTIONS(1947),
    [anon_sym_mutable] = ACTIONS(1947),
    [anon_sym_constinit] = ACTIONS(1947),
    [anon_sym_consteval] = ACTIONS(1947),
    [anon_sym_alignas] = ACTIONS(1947),
    [anon_sym__Alignas] = ACTIONS(1947),
    [sym_primitive_type] = ACTIONS(1947),
    [anon_sym_enum] = ACTIONS(1947),
    [anon_sym_class] = ACTIONS(1947),
    [anon_sym_struct] = ACTIONS(1947),
    [anon_sym_union] = ACTIONS(1947),
    [anon_sym_if] = ACTIONS(1947),
    [anon_sym_switch] = ACTIONS(1947),
    [anon_sym_case] = ACTIONS(1947),
    [anon_sym_default] = ACTIONS(1947),
    [anon_sym_while] = ACTIONS(1947),
    [anon_sym_do] = ACTIONS(1947),
    [anon_sym_for] = ACTIONS(1947),
    [anon_sym_return] = ACTIONS(1947),
    [anon_sym_break] = ACTIONS(1947),
    [anon_sym_continue] = ACTIONS(1947),
    [anon_sym_goto] = ACTIONS(1947),
    [anon_sym_not] = ACTIONS(1947),
    [anon_sym_compl] = ACTIONS(1947),
    [anon_sym_DASH_DASH] = ACTIONS(1945),
    [anon_sym_PLUS_PLUS] = ACTIONS(1945),
    [anon_sym_sizeof] = ACTIONS(1947),
    [anon_sym___alignof__] = ACTIONS(1947),
    [anon_sym___alignof] = ACTIONS(1947),
    [anon_sym__alignof] = ACTIONS(1947),
    [anon_sym_alignof] = ACTIONS(1947),
    [anon_sym__Alignof] = ACTIONS(1947),
    [anon_sym_offsetof] = ACTIONS(1947),
    [anon_sym__Generic] = ACTIONS(1947),
    [anon_sym_asm] = ACTIONS(1947),
    [anon_sym___asm__] = ACTIONS(1947),
    [sym_number_literal] = ACTIONS(1945),
    [anon_sym_L_SQUOTE] = ACTIONS(1945),
    [anon_sym_u_SQUOTE] = ACTIONS(1945),
    [anon_sym_U_SQUOTE] = ACTIONS(1945),
    [anon_sym_u8_SQUOTE] = ACTIONS(1945),
    [anon_sym_SQUOTE] = ACTIONS(1945),
    [anon_sym_L_DQUOTE] = ACTIONS(1945),
    [anon_sym_u_DQUOTE] = ACTIONS(1945),
    [anon_sym_U_DQUOTE] = ACTIONS(1945),
    [anon_sym_u8_DQUOTE] = ACTIONS(1945),
    [anon_sym_DQUOTE] = ACTIONS(1945),
    [sym_true] = ACTIONS(1947),
    [sym_false] = ACTIONS(1947),
    [anon_sym_NULL] = ACTIONS(1947),
    [anon_sym_nullptr] = ACTIONS(1947),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1947),
    [anon_sym_decltype] = ACTIONS(1947),
    [sym_virtual] = ACTIONS(1947),
    [anon_sym_explicit] = ACTIONS(1947),
    [anon_sym_typename] = ACTIONS(1947),
    [anon_sym_template] = ACTIONS(1947),
    [anon_sym_operator] = ACTIONS(1947),
    [anon_sym_try] = ACTIONS(1947),
    [anon_sym_delete] = ACTIONS(1947),
    [anon_sym_throw] = ACTIONS(1947),
    [anon_sym_namespace] = ACTIONS(1947),
    [anon_sym_using] = ACTIONS(1947),
    [anon_sym_static_assert] = ACTIONS(1947),
    [anon_sym_concept] = ACTIONS(1947),
    [anon_sym_co_return] = ACTIONS(1947),
    [anon_sym_co_yield] = ACTIONS(1947),
    [anon_sym_R_DQUOTE] = ACTIONS(1945),
    [anon_sym_LR_DQUOTE] = ACTIONS(1945),
    [anon_sym_uR_DQUOTE] = ACTIONS(1945),
    [anon_sym_UR_DQUOTE] = ACTIONS(1945),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1945),
    [anon_sym_co_await] = ACTIONS(1947),
    [anon_sym_new] = ACTIONS(1947),
    [anon_sym_requires] = ACTIONS(1947),
    [sym_this] = ACTIONS(1947),
    [anon_sym_precise] = ACTIONS(1947),
    [anon_sym_shared] = ACTIONS(1947),
    [anon_sym_groupshared] = ACTIONS(1947),
    [anon_sym_uniform] = ACTIONS(1947),
    [anon_sym_row_major] = ACTIONS(1947),
    [anon_sym_column_major] = ACTIONS(1947),
    [anon_sym_globallycoherent] = ACTIONS(1947),
    [anon_sym_centroid] = ACTIONS(1947),
    [anon_sym_noperspective] = ACTIONS(1947),
    [anon_sym_nointerpolation] = ACTIONS(1947),
    [anon_sym_sample] = ACTIONS(1947),
    [anon_sym_linear] = ACTIONS(1947),
    [anon_sym_snorm] = ACTIONS(1947),
    [anon_sym_unorm] = ACTIONS(1947),
    [anon_sym_point] = ACTIONS(1947),
    [anon_sym_line] = ACTIONS(1947),
    [anon_sym_triangleadj] = ACTIONS(1947),
    [anon_sym_lineadj] = ACTIONS(1947),
    [anon_sym_triangle] = ACTIONS(1947),
  },
  [706] = {
    [sym_catch_clause] = STATE(276),
    [aux_sym_constructor_try_statement_repeat1] = STATE(276),
    [ts_builtin_sym_end] = ACTIONS(1986),
    [sym_identifier] = ACTIONS(1984),
    [aux_sym_preproc_include_token1] = ACTIONS(1984),
    [aux_sym_preproc_def_token1] = ACTIONS(1984),
    [aux_sym_preproc_if_token1] = ACTIONS(1984),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1984),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1984),
    [sym_preproc_directive] = ACTIONS(1984),
    [anon_sym_LPAREN2] = ACTIONS(1986),
    [anon_sym_BANG] = ACTIONS(1986),
    [anon_sym_TILDE] = ACTIONS(1986),
    [anon_sym_DASH] = ACTIONS(1984),
    [anon_sym_PLUS] = ACTIONS(1984),
    [anon_sym_STAR] = ACTIONS(1986),
    [anon_sym_AMP_AMP] = ACTIONS(1986),
    [anon_sym_AMP] = ACTIONS(1984),
    [anon_sym___extension__] = ACTIONS(1984),
    [anon_sym_typedef] = ACTIONS(1984),
    [anon_sym_in] = ACTIONS(1984),
    [anon_sym_out] = ACTIONS(1984),
    [anon_sym_inout] = ACTIONS(1984),
    [anon_sym_extern] = ACTIONS(1984),
    [anon_sym___attribute__] = ACTIONS(1984),
    [anon_sym_COLON_COLON] = ACTIONS(1986),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1986),
    [anon_sym___declspec] = ACTIONS(1984),
    [anon_sym___based] = ACTIONS(1984),
    [anon_sym___cdecl] = ACTIONS(1984),
    [anon_sym___clrcall] = ACTIONS(1984),
    [anon_sym___stdcall] = ACTIONS(1984),
    [anon_sym___fastcall] = ACTIONS(1984),
    [anon_sym___thiscall] = ACTIONS(1984),
    [anon_sym___vectorcall] = ACTIONS(1984),
    [anon_sym_LBRACE] = ACTIONS(1986),
    [anon_sym_signed] = ACTIONS(1984),
    [anon_sym_unsigned] = ACTIONS(1984),
    [anon_sym_long] = ACTIONS(1984),
    [anon_sym_short] = ACTIONS(1984),
    [anon_sym_LBRACK] = ACTIONS(1984),
    [anon_sym_static] = ACTIONS(1984),
    [anon_sym_register] = ACTIONS(1984),
    [anon_sym_inline] = ACTIONS(1984),
    [anon_sym___inline] = ACTIONS(1984),
    [anon_sym___inline__] = ACTIONS(1984),
    [anon_sym___forceinline] = ACTIONS(1984),
    [anon_sym_thread_local] = ACTIONS(1984),
    [anon_sym___thread] = ACTIONS(1984),
    [anon_sym_const] = ACTIONS(1984),
    [anon_sym_constexpr] = ACTIONS(1984),
    [anon_sym_volatile] = ACTIONS(1984),
    [anon_sym_restrict] = ACTIONS(1984),
    [anon_sym___restrict__] = ACTIONS(1984),
    [anon_sym__Atomic] = ACTIONS(1984),
    [anon_sym__Noreturn] = ACTIONS(1984),
    [anon_sym_noreturn] = ACTIONS(1984),
    [anon_sym_mutable] = ACTIONS(1984),
    [anon_sym_constinit] = ACTIONS(1984),
    [anon_sym_consteval] = ACTIONS(1984),
    [anon_sym_alignas] = ACTIONS(1984),
    [anon_sym__Alignas] = ACTIONS(1984),
    [sym_primitive_type] = ACTIONS(1984),
    [anon_sym_enum] = ACTIONS(1984),
    [anon_sym_class] = ACTIONS(1984),
    [anon_sym_struct] = ACTIONS(1984),
    [anon_sym_union] = ACTIONS(1984),
    [anon_sym_if] = ACTIONS(1984),
    [anon_sym_switch] = ACTIONS(1984),
    [anon_sym_case] = ACTIONS(1984),
    [anon_sym_default] = ACTIONS(1984),
    [anon_sym_while] = ACTIONS(1984),
    [anon_sym_do] = ACTIONS(1984),
    [anon_sym_for] = ACTIONS(1984),
    [anon_sym_return] = ACTIONS(1984),
    [anon_sym_break] = ACTIONS(1984),
    [anon_sym_continue] = ACTIONS(1984),
    [anon_sym_goto] = ACTIONS(1984),
    [anon_sym_not] = ACTIONS(1984),
    [anon_sym_compl] = ACTIONS(1984),
    [anon_sym_DASH_DASH] = ACTIONS(1986),
    [anon_sym_PLUS_PLUS] = ACTIONS(1986),
    [anon_sym_sizeof] = ACTIONS(1984),
    [anon_sym___alignof__] = ACTIONS(1984),
    [anon_sym___alignof] = ACTIONS(1984),
    [anon_sym__alignof] = ACTIONS(1984),
    [anon_sym_alignof] = ACTIONS(1984),
    [anon_sym__Alignof] = ACTIONS(1984),
    [anon_sym_offsetof] = ACTIONS(1984),
    [anon_sym__Generic] = ACTIONS(1984),
    [anon_sym_asm] = ACTIONS(1984),
    [anon_sym___asm__] = ACTIONS(1984),
    [sym_number_literal] = ACTIONS(1986),
    [anon_sym_L_SQUOTE] = ACTIONS(1986),
    [anon_sym_u_SQUOTE] = ACTIONS(1986),
    [anon_sym_U_SQUOTE] = ACTIONS(1986),
    [anon_sym_u8_SQUOTE] = ACTIONS(1986),
    [anon_sym_SQUOTE] = ACTIONS(1986),
    [anon_sym_L_DQUOTE] = ACTIONS(1986),
    [anon_sym_u_DQUOTE] = ACTIONS(1986),
    [anon_sym_U_DQUOTE] = ACTIONS(1986),
    [anon_sym_u8_DQUOTE] = ACTIONS(1986),
    [anon_sym_DQUOTE] = ACTIONS(1986),
    [sym_true] = ACTIONS(1984),
    [sym_false] = ACTIONS(1984),
    [anon_sym_NULL] = ACTIONS(1984),
    [anon_sym_nullptr] = ACTIONS(1984),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1984),
    [anon_sym_decltype] = ACTIONS(1984),
    [sym_virtual] = ACTIONS(1984),
    [anon_sym_explicit] = ACTIONS(1984),
    [anon_sym_typename] = ACTIONS(1984),
    [anon_sym_template] = ACTIONS(1984),
    [anon_sym_operator] = ACTIONS(1984),
    [anon_sym_try] = ACTIONS(1984),
    [anon_sym_delete] = ACTIONS(1984),
    [anon_sym_throw] = ACTIONS(1984),
    [anon_sym_namespace] = ACTIONS(1984),
    [anon_sym_using] = ACTIONS(1984),
    [anon_sym_static_assert] = ACTIONS(1984),
    [anon_sym_concept] = ACTIONS(1984),
    [anon_sym_co_return] = ACTIONS(1984),
    [anon_sym_co_yield] = ACTIONS(1984),
    [anon_sym_catch] = ACTIONS(2514),
    [anon_sym_R_DQUOTE] = ACTIONS(1986),
    [anon_sym_LR_DQUOTE] = ACTIONS(1986),
    [anon_sym_uR_DQUOTE] = ACTIONS(1986),
    [anon_sym_UR_DQUOTE] = ACTIONS(1986),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1986),
    [anon_sym_co_await] = ACTIONS(1984),
    [anon_sym_new] = ACTIONS(1984),
    [anon_sym_requires] = ACTIONS(1984),
    [sym_this] = ACTIONS(1984),
    [anon_sym_precise] = ACTIONS(1984),
    [anon_sym_shared] = ACTIONS(1984),
    [anon_sym_groupshared] = ACTIONS(1984),
    [anon_sym_uniform] = ACTIONS(1984),
    [anon_sym_row_major] = ACTIONS(1984),
    [anon_sym_column_major] = ACTIONS(1984),
    [anon_sym_globallycoherent] = ACTIONS(1984),
    [anon_sym_centroid] = ACTIONS(1984),
    [anon_sym_noperspective] = ACTIONS(1984),
    [anon_sym_nointerpolation] = ACTIONS(1984),
    [anon_sym_sample] = ACTIONS(1984),
    [anon_sym_linear] = ACTIONS(1984),
    [anon_sym_snorm] = ACTIONS(1984),
    [anon_sym_unorm] = ACTIONS(1984),
    [anon_sym_point] = ACTIONS(1984),
    [anon_sym_line] = ACTIONS(1984),
    [anon_sym_triangleadj] = ACTIONS(1984),
    [anon_sym_lineadj] = ACTIONS(1984),
    [anon_sym_triangle] = ACTIONS(1984),
  },
  [707] = {
    [ts_builtin_sym_end] = ACTIONS(2402),
    [sym_identifier] = ACTIONS(2400),
    [aux_sym_preproc_include_token1] = ACTIONS(2400),
    [aux_sym_preproc_def_token1] = ACTIONS(2400),
    [anon_sym_COMMA] = ACTIONS(2402),
    [aux_sym_preproc_if_token1] = ACTIONS(2400),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2400),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2400),
    [sym_preproc_directive] = ACTIONS(2400),
    [anon_sym_LPAREN2] = ACTIONS(2402),
    [anon_sym_BANG] = ACTIONS(2402),
    [anon_sym_TILDE] = ACTIONS(2402),
    [anon_sym_DASH] = ACTIONS(2400),
    [anon_sym_PLUS] = ACTIONS(2400),
    [anon_sym_STAR] = ACTIONS(2402),
    [anon_sym_AMP_AMP] = ACTIONS(2402),
    [anon_sym_AMP] = ACTIONS(2400),
    [anon_sym___extension__] = ACTIONS(2400),
    [anon_sym_typedef] = ACTIONS(2400),
    [anon_sym_in] = ACTIONS(2400),
    [anon_sym_out] = ACTIONS(2400),
    [anon_sym_inout] = ACTIONS(2400),
    [anon_sym_extern] = ACTIONS(2400),
    [anon_sym___attribute__] = ACTIONS(2400),
    [anon_sym_COLON_COLON] = ACTIONS(2402),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2402),
    [anon_sym___declspec] = ACTIONS(2400),
    [anon_sym___based] = ACTIONS(2400),
    [anon_sym___cdecl] = ACTIONS(2400),
    [anon_sym___clrcall] = ACTIONS(2400),
    [anon_sym___stdcall] = ACTIONS(2400),
    [anon_sym___fastcall] = ACTIONS(2400),
    [anon_sym___thiscall] = ACTIONS(2400),
    [anon_sym___vectorcall] = ACTIONS(2400),
    [anon_sym_LBRACE] = ACTIONS(2402),
    [anon_sym_RBRACE] = ACTIONS(2402),
    [anon_sym_signed] = ACTIONS(2400),
    [anon_sym_unsigned] = ACTIONS(2400),
    [anon_sym_long] = ACTIONS(2400),
    [anon_sym_short] = ACTIONS(2400),
    [anon_sym_LBRACK] = ACTIONS(2400),
    [anon_sym_static] = ACTIONS(2400),
    [anon_sym_register] = ACTIONS(2400),
    [anon_sym_inline] = ACTIONS(2400),
    [anon_sym___inline] = ACTIONS(2400),
    [anon_sym___inline__] = ACTIONS(2400),
    [anon_sym___forceinline] = ACTIONS(2400),
    [anon_sym_thread_local] = ACTIONS(2400),
    [anon_sym___thread] = ACTIONS(2400),
    [anon_sym_const] = ACTIONS(2400),
    [anon_sym_constexpr] = ACTIONS(2400),
    [anon_sym_volatile] = ACTIONS(2400),
    [anon_sym_restrict] = ACTIONS(2400),
    [anon_sym___restrict__] = ACTIONS(2400),
    [anon_sym__Atomic] = ACTIONS(2400),
    [anon_sym__Noreturn] = ACTIONS(2400),
    [anon_sym_noreturn] = ACTIONS(2400),
    [anon_sym_mutable] = ACTIONS(2400),
    [anon_sym_constinit] = ACTIONS(2400),
    [anon_sym_consteval] = ACTIONS(2400),
    [anon_sym_alignas] = ACTIONS(2400),
    [anon_sym__Alignas] = ACTIONS(2400),
    [sym_primitive_type] = ACTIONS(2400),
    [anon_sym_enum] = ACTIONS(2400),
    [anon_sym_class] = ACTIONS(2400),
    [anon_sym_struct] = ACTIONS(2400),
    [anon_sym_union] = ACTIONS(2400),
    [anon_sym_if] = ACTIONS(2400),
    [anon_sym_switch] = ACTIONS(2400),
    [anon_sym_case] = ACTIONS(2400),
    [anon_sym_default] = ACTIONS(2400),
    [anon_sym_while] = ACTIONS(2400),
    [anon_sym_do] = ACTIONS(2400),
    [anon_sym_for] = ACTIONS(2400),
    [anon_sym_return] = ACTIONS(2400),
    [anon_sym_break] = ACTIONS(2400),
    [anon_sym_continue] = ACTIONS(2400),
    [anon_sym_goto] = ACTIONS(2400),
    [anon_sym_not] = ACTIONS(2400),
    [anon_sym_compl] = ACTIONS(2400),
    [anon_sym_DASH_DASH] = ACTIONS(2402),
    [anon_sym_PLUS_PLUS] = ACTIONS(2402),
    [anon_sym_sizeof] = ACTIONS(2400),
    [anon_sym___alignof__] = ACTIONS(2400),
    [anon_sym___alignof] = ACTIONS(2400),
    [anon_sym__alignof] = ACTIONS(2400),
    [anon_sym_alignof] = ACTIONS(2400),
    [anon_sym__Alignof] = ACTIONS(2400),
    [anon_sym_offsetof] = ACTIONS(2400),
    [anon_sym__Generic] = ACTIONS(2400),
    [anon_sym_asm] = ACTIONS(2400),
    [anon_sym___asm__] = ACTIONS(2400),
    [sym_number_literal] = ACTIONS(2402),
    [anon_sym_L_SQUOTE] = ACTIONS(2402),
    [anon_sym_u_SQUOTE] = ACTIONS(2402),
    [anon_sym_U_SQUOTE] = ACTIONS(2402),
    [anon_sym_u8_SQUOTE] = ACTIONS(2402),
    [anon_sym_SQUOTE] = ACTIONS(2402),
    [anon_sym_L_DQUOTE] = ACTIONS(2402),
    [anon_sym_u_DQUOTE] = ACTIONS(2402),
    [anon_sym_U_DQUOTE] = ACTIONS(2402),
    [anon_sym_u8_DQUOTE] = ACTIONS(2402),
    [anon_sym_DQUOTE] = ACTIONS(2402),
    [sym_true] = ACTIONS(2400),
    [sym_false] = ACTIONS(2400),
    [anon_sym_NULL] = ACTIONS(2400),
    [anon_sym_nullptr] = ACTIONS(2400),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2400),
    [anon_sym_decltype] = ACTIONS(2400),
    [sym_virtual] = ACTIONS(2400),
    [anon_sym_explicit] = ACTIONS(2400),
    [anon_sym_typename] = ACTIONS(2400),
    [anon_sym_template] = ACTIONS(2400),
    [anon_sym_operator] = ACTIONS(2400),
    [anon_sym_try] = ACTIONS(2400),
    [anon_sym_delete] = ACTIONS(2400),
    [anon_sym_throw] = ACTIONS(2400),
    [anon_sym_namespace] = ACTIONS(2400),
    [anon_sym_using] = ACTIONS(2400),
    [anon_sym_static_assert] = ACTIONS(2400),
    [anon_sym_concept] = ACTIONS(2400),
    [anon_sym_co_return] = ACTIONS(2400),
    [anon_sym_co_yield] = ACTIONS(2400),
    [anon_sym_R_DQUOTE] = ACTIONS(2402),
    [anon_sym_LR_DQUOTE] = ACTIONS(2402),
    [anon_sym_uR_DQUOTE] = ACTIONS(2402),
    [anon_sym_UR_DQUOTE] = ACTIONS(2402),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2402),
    [anon_sym_co_await] = ACTIONS(2400),
    [anon_sym_new] = ACTIONS(2400),
    [anon_sym_requires] = ACTIONS(2400),
    [sym_this] = ACTIONS(2400),
    [anon_sym_precise] = ACTIONS(2400),
    [anon_sym_shared] = ACTIONS(2400),
    [anon_sym_groupshared] = ACTIONS(2400),
    [anon_sym_uniform] = ACTIONS(2400),
    [anon_sym_row_major] = ACTIONS(2400),
    [anon_sym_column_major] = ACTIONS(2400),
    [anon_sym_globallycoherent] = ACTIONS(2400),
    [anon_sym_centroid] = ACTIONS(2400),
    [anon_sym_noperspective] = ACTIONS(2400),
    [anon_sym_nointerpolation] = ACTIONS(2400),
    [anon_sym_sample] = ACTIONS(2400),
    [anon_sym_linear] = ACTIONS(2400),
    [anon_sym_snorm] = ACTIONS(2400),
    [anon_sym_unorm] = ACTIONS(2400),
    [anon_sym_point] = ACTIONS(2400),
    [anon_sym_line] = ACTIONS(2400),
    [anon_sym_triangleadj] = ACTIONS(2400),
    [anon_sym_lineadj] = ACTIONS(2400),
    [anon_sym_triangle] = ACTIONS(2400),
  },
  [708] = {
    [ts_builtin_sym_end] = ACTIONS(2567),
    [sym_identifier] = ACTIONS(2565),
    [aux_sym_preproc_include_token1] = ACTIONS(2565),
    [aux_sym_preproc_def_token1] = ACTIONS(2565),
    [anon_sym_COMMA] = ACTIONS(2567),
    [aux_sym_preproc_if_token1] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2565),
    [sym_preproc_directive] = ACTIONS(2565),
    [anon_sym_LPAREN2] = ACTIONS(2567),
    [anon_sym_BANG] = ACTIONS(2567),
    [anon_sym_TILDE] = ACTIONS(2567),
    [anon_sym_DASH] = ACTIONS(2565),
    [anon_sym_PLUS] = ACTIONS(2565),
    [anon_sym_STAR] = ACTIONS(2567),
    [anon_sym_AMP_AMP] = ACTIONS(2567),
    [anon_sym_AMP] = ACTIONS(2565),
    [anon_sym___extension__] = ACTIONS(2565),
    [anon_sym_typedef] = ACTIONS(2565),
    [anon_sym_in] = ACTIONS(2565),
    [anon_sym_out] = ACTIONS(2565),
    [anon_sym_inout] = ACTIONS(2565),
    [anon_sym_extern] = ACTIONS(2565),
    [anon_sym___attribute__] = ACTIONS(2565),
    [anon_sym_COLON_COLON] = ACTIONS(2567),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2567),
    [anon_sym___declspec] = ACTIONS(2565),
    [anon_sym___based] = ACTIONS(2565),
    [anon_sym___cdecl] = ACTIONS(2565),
    [anon_sym___clrcall] = ACTIONS(2565),
    [anon_sym___stdcall] = ACTIONS(2565),
    [anon_sym___fastcall] = ACTIONS(2565),
    [anon_sym___thiscall] = ACTIONS(2565),
    [anon_sym___vectorcall] = ACTIONS(2565),
    [anon_sym_LBRACE] = ACTIONS(2567),
    [anon_sym_RBRACE] = ACTIONS(2567),
    [anon_sym_signed] = ACTIONS(2565),
    [anon_sym_unsigned] = ACTIONS(2565),
    [anon_sym_long] = ACTIONS(2565),
    [anon_sym_short] = ACTIONS(2565),
    [anon_sym_LBRACK] = ACTIONS(2565),
    [anon_sym_static] = ACTIONS(2565),
    [anon_sym_register] = ACTIONS(2565),
    [anon_sym_inline] = ACTIONS(2565),
    [anon_sym___inline] = ACTIONS(2565),
    [anon_sym___inline__] = ACTIONS(2565),
    [anon_sym___forceinline] = ACTIONS(2565),
    [anon_sym_thread_local] = ACTIONS(2565),
    [anon_sym___thread] = ACTIONS(2565),
    [anon_sym_const] = ACTIONS(2565),
    [anon_sym_constexpr] = ACTIONS(2565),
    [anon_sym_volatile] = ACTIONS(2565),
    [anon_sym_restrict] = ACTIONS(2565),
    [anon_sym___restrict__] = ACTIONS(2565),
    [anon_sym__Atomic] = ACTIONS(2565),
    [anon_sym__Noreturn] = ACTIONS(2565),
    [anon_sym_noreturn] = ACTIONS(2565),
    [anon_sym_mutable] = ACTIONS(2565),
    [anon_sym_constinit] = ACTIONS(2565),
    [anon_sym_consteval] = ACTIONS(2565),
    [anon_sym_alignas] = ACTIONS(2565),
    [anon_sym__Alignas] = ACTIONS(2565),
    [sym_primitive_type] = ACTIONS(2565),
    [anon_sym_enum] = ACTIONS(2565),
    [anon_sym_class] = ACTIONS(2565),
    [anon_sym_struct] = ACTIONS(2565),
    [anon_sym_union] = ACTIONS(2565),
    [anon_sym_if] = ACTIONS(2565),
    [anon_sym_switch] = ACTIONS(2565),
    [anon_sym_case] = ACTIONS(2565),
    [anon_sym_default] = ACTIONS(2565),
    [anon_sym_while] = ACTIONS(2565),
    [anon_sym_do] = ACTIONS(2565),
    [anon_sym_for] = ACTIONS(2565),
    [anon_sym_return] = ACTIONS(2565),
    [anon_sym_break] = ACTIONS(2565),
    [anon_sym_continue] = ACTIONS(2565),
    [anon_sym_goto] = ACTIONS(2565),
    [anon_sym_not] = ACTIONS(2565),
    [anon_sym_compl] = ACTIONS(2565),
    [anon_sym_DASH_DASH] = ACTIONS(2567),
    [anon_sym_PLUS_PLUS] = ACTIONS(2567),
    [anon_sym_sizeof] = ACTIONS(2565),
    [anon_sym___alignof__] = ACTIONS(2565),
    [anon_sym___alignof] = ACTIONS(2565),
    [anon_sym__alignof] = ACTIONS(2565),
    [anon_sym_alignof] = ACTIONS(2565),
    [anon_sym__Alignof] = ACTIONS(2565),
    [anon_sym_offsetof] = ACTIONS(2565),
    [anon_sym__Generic] = ACTIONS(2565),
    [anon_sym_asm] = ACTIONS(2565),
    [anon_sym___asm__] = ACTIONS(2565),
    [sym_number_literal] = ACTIONS(2567),
    [anon_sym_L_SQUOTE] = ACTIONS(2567),
    [anon_sym_u_SQUOTE] = ACTIONS(2567),
    [anon_sym_U_SQUOTE] = ACTIONS(2567),
    [anon_sym_u8_SQUOTE] = ACTIONS(2567),
    [anon_sym_SQUOTE] = ACTIONS(2567),
    [anon_sym_L_DQUOTE] = ACTIONS(2567),
    [anon_sym_u_DQUOTE] = ACTIONS(2567),
    [anon_sym_U_DQUOTE] = ACTIONS(2567),
    [anon_sym_u8_DQUOTE] = ACTIONS(2567),
    [anon_sym_DQUOTE] = ACTIONS(2567),
    [sym_true] = ACTIONS(2565),
    [sym_false] = ACTIONS(2565),
    [anon_sym_NULL] = ACTIONS(2565),
    [anon_sym_nullptr] = ACTIONS(2565),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2565),
    [anon_sym_decltype] = ACTIONS(2565),
    [sym_virtual] = ACTIONS(2565),
    [anon_sym_explicit] = ACTIONS(2565),
    [anon_sym_typename] = ACTIONS(2565),
    [anon_sym_template] = ACTIONS(2565),
    [anon_sym_operator] = ACTIONS(2565),
    [anon_sym_try] = ACTIONS(2565),
    [anon_sym_delete] = ACTIONS(2565),
    [anon_sym_throw] = ACTIONS(2565),
    [anon_sym_namespace] = ACTIONS(2565),
    [anon_sym_using] = ACTIONS(2565),
    [anon_sym_static_assert] = ACTIONS(2565),
    [anon_sym_concept] = ACTIONS(2565),
    [anon_sym_co_return] = ACTIONS(2565),
    [anon_sym_co_yield] = ACTIONS(2565),
    [anon_sym_R_DQUOTE] = ACTIONS(2567),
    [anon_sym_LR_DQUOTE] = ACTIONS(2567),
    [anon_sym_uR_DQUOTE] = ACTIONS(2567),
    [anon_sym_UR_DQUOTE] = ACTIONS(2567),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2567),
    [anon_sym_co_await] = ACTIONS(2565),
    [anon_sym_new] = ACTIONS(2565),
    [anon_sym_requires] = ACTIONS(2565),
    [sym_this] = ACTIONS(2565),
    [anon_sym_precise] = ACTIONS(2565),
    [anon_sym_shared] = ACTIONS(2565),
    [anon_sym_groupshared] = ACTIONS(2565),
    [anon_sym_uniform] = ACTIONS(2565),
    [anon_sym_row_major] = ACTIONS(2565),
    [anon_sym_column_major] = ACTIONS(2565),
    [anon_sym_globallycoherent] = ACTIONS(2565),
    [anon_sym_centroid] = ACTIONS(2565),
    [anon_sym_noperspective] = ACTIONS(2565),
    [anon_sym_nointerpolation] = ACTIONS(2565),
    [anon_sym_sample] = ACTIONS(2565),
    [anon_sym_linear] = ACTIONS(2565),
    [anon_sym_snorm] = ACTIONS(2565),
    [anon_sym_unorm] = ACTIONS(2565),
    [anon_sym_point] = ACTIONS(2565),
    [anon_sym_line] = ACTIONS(2565),
    [anon_sym_triangleadj] = ACTIONS(2565),
    [anon_sym_lineadj] = ACTIONS(2565),
    [anon_sym_triangle] = ACTIONS(2565),
  },
  [709] = {
    [ts_builtin_sym_end] = ACTIONS(2500),
    [sym_identifier] = ACTIONS(2498),
    [aux_sym_preproc_include_token1] = ACTIONS(2498),
    [aux_sym_preproc_def_token1] = ACTIONS(2498),
    [aux_sym_preproc_if_token1] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2498),
    [sym_preproc_directive] = ACTIONS(2498),
    [anon_sym_LPAREN2] = ACTIONS(2500),
    [anon_sym_BANG] = ACTIONS(2500),
    [anon_sym_TILDE] = ACTIONS(2500),
    [anon_sym_DASH] = ACTIONS(2498),
    [anon_sym_PLUS] = ACTIONS(2498),
    [anon_sym_STAR] = ACTIONS(2500),
    [anon_sym_AMP_AMP] = ACTIONS(2500),
    [anon_sym_AMP] = ACTIONS(2498),
    [anon_sym___extension__] = ACTIONS(2498),
    [anon_sym_typedef] = ACTIONS(2498),
    [anon_sym_in] = ACTIONS(2498),
    [anon_sym_out] = ACTIONS(2498),
    [anon_sym_inout] = ACTIONS(2498),
    [anon_sym_extern] = ACTIONS(2498),
    [anon_sym___attribute__] = ACTIONS(2498),
    [anon_sym_COLON_COLON] = ACTIONS(2500),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2500),
    [anon_sym___declspec] = ACTIONS(2498),
    [anon_sym___based] = ACTIONS(2498),
    [anon_sym___cdecl] = ACTIONS(2498),
    [anon_sym___clrcall] = ACTIONS(2498),
    [anon_sym___stdcall] = ACTIONS(2498),
    [anon_sym___fastcall] = ACTIONS(2498),
    [anon_sym___thiscall] = ACTIONS(2498),
    [anon_sym___vectorcall] = ACTIONS(2498),
    [anon_sym_LBRACE] = ACTIONS(2500),
    [anon_sym_signed] = ACTIONS(2498),
    [anon_sym_unsigned] = ACTIONS(2498),
    [anon_sym_long] = ACTIONS(2498),
    [anon_sym_short] = ACTIONS(2498),
    [anon_sym_LBRACK] = ACTIONS(2498),
    [anon_sym_static] = ACTIONS(2498),
    [anon_sym_register] = ACTIONS(2498),
    [anon_sym_inline] = ACTIONS(2498),
    [anon_sym___inline] = ACTIONS(2498),
    [anon_sym___inline__] = ACTIONS(2498),
    [anon_sym___forceinline] = ACTIONS(2498),
    [anon_sym_thread_local] = ACTIONS(2498),
    [anon_sym___thread] = ACTIONS(2498),
    [anon_sym_const] = ACTIONS(2498),
    [anon_sym_constexpr] = ACTIONS(2498),
    [anon_sym_volatile] = ACTIONS(2498),
    [anon_sym_restrict] = ACTIONS(2498),
    [anon_sym___restrict__] = ACTIONS(2498),
    [anon_sym__Atomic] = ACTIONS(2498),
    [anon_sym__Noreturn] = ACTIONS(2498),
    [anon_sym_noreturn] = ACTIONS(2498),
    [anon_sym_mutable] = ACTIONS(2498),
    [anon_sym_constinit] = ACTIONS(2498),
    [anon_sym_consteval] = ACTIONS(2498),
    [anon_sym_alignas] = ACTIONS(2498),
    [anon_sym__Alignas] = ACTIONS(2498),
    [sym_primitive_type] = ACTIONS(2498),
    [anon_sym_enum] = ACTIONS(2498),
    [anon_sym_class] = ACTIONS(2498),
    [anon_sym_struct] = ACTIONS(2498),
    [anon_sym_union] = ACTIONS(2498),
    [anon_sym_if] = ACTIONS(2498),
    [anon_sym_switch] = ACTIONS(2498),
    [anon_sym_case] = ACTIONS(2498),
    [anon_sym_default] = ACTIONS(2498),
    [anon_sym_while] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(2498),
    [anon_sym_for] = ACTIONS(2498),
    [anon_sym_return] = ACTIONS(2498),
    [anon_sym_break] = ACTIONS(2498),
    [anon_sym_continue] = ACTIONS(2498),
    [anon_sym_goto] = ACTIONS(2498),
    [anon_sym_not] = ACTIONS(2498),
    [anon_sym_compl] = ACTIONS(2498),
    [anon_sym_DASH_DASH] = ACTIONS(2500),
    [anon_sym_PLUS_PLUS] = ACTIONS(2500),
    [anon_sym_sizeof] = ACTIONS(2498),
    [anon_sym___alignof__] = ACTIONS(2498),
    [anon_sym___alignof] = ACTIONS(2498),
    [anon_sym__alignof] = ACTIONS(2498),
    [anon_sym_alignof] = ACTIONS(2498),
    [anon_sym__Alignof] = ACTIONS(2498),
    [anon_sym_offsetof] = ACTIONS(2498),
    [anon_sym__Generic] = ACTIONS(2498),
    [anon_sym_asm] = ACTIONS(2498),
    [anon_sym___asm__] = ACTIONS(2498),
    [sym_number_literal] = ACTIONS(2500),
    [anon_sym_L_SQUOTE] = ACTIONS(2500),
    [anon_sym_u_SQUOTE] = ACTIONS(2500),
    [anon_sym_U_SQUOTE] = ACTIONS(2500),
    [anon_sym_u8_SQUOTE] = ACTIONS(2500),
    [anon_sym_SQUOTE] = ACTIONS(2500),
    [anon_sym_L_DQUOTE] = ACTIONS(2500),
    [anon_sym_u_DQUOTE] = ACTIONS(2500),
    [anon_sym_U_DQUOTE] = ACTIONS(2500),
    [anon_sym_u8_DQUOTE] = ACTIONS(2500),
    [anon_sym_DQUOTE] = ACTIONS(2500),
    [sym_true] = ACTIONS(2498),
    [sym_false] = ACTIONS(2498),
    [anon_sym_NULL] = ACTIONS(2498),
    [anon_sym_nullptr] = ACTIONS(2498),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2498),
    [anon_sym_decltype] = ACTIONS(2498),
    [sym_virtual] = ACTIONS(2498),
    [anon_sym_explicit] = ACTIONS(2498),
    [anon_sym_typename] = ACTIONS(2498),
    [anon_sym_template] = ACTIONS(2498),
    [anon_sym_operator] = ACTIONS(2498),
    [anon_sym_try] = ACTIONS(2498),
    [anon_sym_delete] = ACTIONS(2498),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_namespace] = ACTIONS(2498),
    [anon_sym_using] = ACTIONS(2498),
    [anon_sym_static_assert] = ACTIONS(2498),
    [anon_sym_concept] = ACTIONS(2498),
    [anon_sym_co_return] = ACTIONS(2498),
    [anon_sym_co_yield] = ACTIONS(2498),
    [anon_sym_R_DQUOTE] = ACTIONS(2500),
    [anon_sym_LR_DQUOTE] = ACTIONS(2500),
    [anon_sym_uR_DQUOTE] = ACTIONS(2500),
    [anon_sym_UR_DQUOTE] = ACTIONS(2500),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2500),
    [anon_sym_co_await] = ACTIONS(2498),
    [anon_sym_new] = ACTIONS(2498),
    [anon_sym_requires] = ACTIONS(2498),
    [sym_this] = ACTIONS(2498),
    [anon_sym_precise] = ACTIONS(2498),
    [anon_sym_shared] = ACTIONS(2498),
    [anon_sym_groupshared] = ACTIONS(2498),
    [anon_sym_uniform] = ACTIONS(2498),
    [anon_sym_row_major] = ACTIONS(2498),
    [anon_sym_column_major] = ACTIONS(2498),
    [anon_sym_globallycoherent] = ACTIONS(2498),
    [anon_sym_centroid] = ACTIONS(2498),
    [anon_sym_noperspective] = ACTIONS(2498),
    [anon_sym_nointerpolation] = ACTIONS(2498),
    [anon_sym_sample] = ACTIONS(2498),
    [anon_sym_linear] = ACTIONS(2498),
    [anon_sym_snorm] = ACTIONS(2498),
    [anon_sym_unorm] = ACTIONS(2498),
    [anon_sym_point] = ACTIONS(2498),
    [anon_sym_line] = ACTIONS(2498),
    [anon_sym_triangleadj] = ACTIONS(2498),
    [anon_sym_lineadj] = ACTIONS(2498),
    [anon_sym_triangle] = ACTIONS(2498),
  },
  [710] = {
    [sym_preproc_def] = STATE(797),
    [sym_preproc_function_def] = STATE(797),
    [sym_preproc_call] = STATE(797),
    [sym_preproc_if_in_field_declaration_list] = STATE(797),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(797),
    [sym_type_definition] = STATE(797),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(797),
    [sym_field_declaration] = STATE(797),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(797),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(797),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(797),
    [sym_operator_cast_declaration] = STATE(797),
    [sym_constructor_or_destructor_definition] = STATE(797),
    [sym_constructor_or_destructor_declaration] = STATE(797),
    [sym_friend_declaration] = STATE(797),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(797),
    [sym_alias_declaration] = STATE(797),
    [sym_static_assert_declaration] = STATE(797),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(797),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2869),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [711] = {
    [ts_builtin_sym_end] = ACTIONS(2464),
    [sym_identifier] = ACTIONS(2462),
    [aux_sym_preproc_include_token1] = ACTIONS(2462),
    [aux_sym_preproc_def_token1] = ACTIONS(2462),
    [aux_sym_preproc_if_token1] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2462),
    [sym_preproc_directive] = ACTIONS(2462),
    [anon_sym_LPAREN2] = ACTIONS(2464),
    [anon_sym_BANG] = ACTIONS(2464),
    [anon_sym_TILDE] = ACTIONS(2464),
    [anon_sym_DASH] = ACTIONS(2462),
    [anon_sym_PLUS] = ACTIONS(2462),
    [anon_sym_STAR] = ACTIONS(2464),
    [anon_sym_AMP_AMP] = ACTIONS(2464),
    [anon_sym_AMP] = ACTIONS(2462),
    [anon_sym___extension__] = ACTIONS(2462),
    [anon_sym_typedef] = ACTIONS(2462),
    [anon_sym_in] = ACTIONS(2462),
    [anon_sym_out] = ACTIONS(2462),
    [anon_sym_inout] = ACTIONS(2462),
    [anon_sym_extern] = ACTIONS(2462),
    [anon_sym___attribute__] = ACTIONS(2462),
    [anon_sym_COLON_COLON] = ACTIONS(2464),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2464),
    [anon_sym___declspec] = ACTIONS(2462),
    [anon_sym___based] = ACTIONS(2462),
    [anon_sym___cdecl] = ACTIONS(2462),
    [anon_sym___clrcall] = ACTIONS(2462),
    [anon_sym___stdcall] = ACTIONS(2462),
    [anon_sym___fastcall] = ACTIONS(2462),
    [anon_sym___thiscall] = ACTIONS(2462),
    [anon_sym___vectorcall] = ACTIONS(2462),
    [anon_sym_LBRACE] = ACTIONS(2464),
    [anon_sym_signed] = ACTIONS(2462),
    [anon_sym_unsigned] = ACTIONS(2462),
    [anon_sym_long] = ACTIONS(2462),
    [anon_sym_short] = ACTIONS(2462),
    [anon_sym_LBRACK] = ACTIONS(2462),
    [anon_sym_static] = ACTIONS(2462),
    [anon_sym_register] = ACTIONS(2462),
    [anon_sym_inline] = ACTIONS(2462),
    [anon_sym___inline] = ACTIONS(2462),
    [anon_sym___inline__] = ACTIONS(2462),
    [anon_sym___forceinline] = ACTIONS(2462),
    [anon_sym_thread_local] = ACTIONS(2462),
    [anon_sym___thread] = ACTIONS(2462),
    [anon_sym_const] = ACTIONS(2462),
    [anon_sym_constexpr] = ACTIONS(2462),
    [anon_sym_volatile] = ACTIONS(2462),
    [anon_sym_restrict] = ACTIONS(2462),
    [anon_sym___restrict__] = ACTIONS(2462),
    [anon_sym__Atomic] = ACTIONS(2462),
    [anon_sym__Noreturn] = ACTIONS(2462),
    [anon_sym_noreturn] = ACTIONS(2462),
    [anon_sym_mutable] = ACTIONS(2462),
    [anon_sym_constinit] = ACTIONS(2462),
    [anon_sym_consteval] = ACTIONS(2462),
    [anon_sym_alignas] = ACTIONS(2462),
    [anon_sym__Alignas] = ACTIONS(2462),
    [sym_primitive_type] = ACTIONS(2462),
    [anon_sym_enum] = ACTIONS(2462),
    [anon_sym_class] = ACTIONS(2462),
    [anon_sym_struct] = ACTIONS(2462),
    [anon_sym_union] = ACTIONS(2462),
    [anon_sym_if] = ACTIONS(2462),
    [anon_sym_switch] = ACTIONS(2462),
    [anon_sym_case] = ACTIONS(2462),
    [anon_sym_default] = ACTIONS(2462),
    [anon_sym_while] = ACTIONS(2462),
    [anon_sym_do] = ACTIONS(2462),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_break] = ACTIONS(2462),
    [anon_sym_continue] = ACTIONS(2462),
    [anon_sym_goto] = ACTIONS(2462),
    [anon_sym_not] = ACTIONS(2462),
    [anon_sym_compl] = ACTIONS(2462),
    [anon_sym_DASH_DASH] = ACTIONS(2464),
    [anon_sym_PLUS_PLUS] = ACTIONS(2464),
    [anon_sym_sizeof] = ACTIONS(2462),
    [anon_sym___alignof__] = ACTIONS(2462),
    [anon_sym___alignof] = ACTIONS(2462),
    [anon_sym__alignof] = ACTIONS(2462),
    [anon_sym_alignof] = ACTIONS(2462),
    [anon_sym__Alignof] = ACTIONS(2462),
    [anon_sym_offsetof] = ACTIONS(2462),
    [anon_sym__Generic] = ACTIONS(2462),
    [anon_sym_asm] = ACTIONS(2462),
    [anon_sym___asm__] = ACTIONS(2462),
    [sym_number_literal] = ACTIONS(2464),
    [anon_sym_L_SQUOTE] = ACTIONS(2464),
    [anon_sym_u_SQUOTE] = ACTIONS(2464),
    [anon_sym_U_SQUOTE] = ACTIONS(2464),
    [anon_sym_u8_SQUOTE] = ACTIONS(2464),
    [anon_sym_SQUOTE] = ACTIONS(2464),
    [anon_sym_L_DQUOTE] = ACTIONS(2464),
    [anon_sym_u_DQUOTE] = ACTIONS(2464),
    [anon_sym_U_DQUOTE] = ACTIONS(2464),
    [anon_sym_u8_DQUOTE] = ACTIONS(2464),
    [anon_sym_DQUOTE] = ACTIONS(2464),
    [sym_true] = ACTIONS(2462),
    [sym_false] = ACTIONS(2462),
    [anon_sym_NULL] = ACTIONS(2462),
    [anon_sym_nullptr] = ACTIONS(2462),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2462),
    [anon_sym_decltype] = ACTIONS(2462),
    [sym_virtual] = ACTIONS(2462),
    [anon_sym_explicit] = ACTIONS(2462),
    [anon_sym_typename] = ACTIONS(2462),
    [anon_sym_template] = ACTIONS(2462),
    [anon_sym_operator] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2462),
    [anon_sym_delete] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2462),
    [anon_sym_namespace] = ACTIONS(2462),
    [anon_sym_using] = ACTIONS(2462),
    [anon_sym_static_assert] = ACTIONS(2462),
    [anon_sym_concept] = ACTIONS(2462),
    [anon_sym_co_return] = ACTIONS(2462),
    [anon_sym_co_yield] = ACTIONS(2462),
    [anon_sym_R_DQUOTE] = ACTIONS(2464),
    [anon_sym_LR_DQUOTE] = ACTIONS(2464),
    [anon_sym_uR_DQUOTE] = ACTIONS(2464),
    [anon_sym_UR_DQUOTE] = ACTIONS(2464),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2464),
    [anon_sym_co_await] = ACTIONS(2462),
    [anon_sym_new] = ACTIONS(2462),
    [anon_sym_requires] = ACTIONS(2462),
    [sym_this] = ACTIONS(2462),
    [anon_sym_precise] = ACTIONS(2462),
    [anon_sym_shared] = ACTIONS(2462),
    [anon_sym_groupshared] = ACTIONS(2462),
    [anon_sym_uniform] = ACTIONS(2462),
    [anon_sym_row_major] = ACTIONS(2462),
    [anon_sym_column_major] = ACTIONS(2462),
    [anon_sym_globallycoherent] = ACTIONS(2462),
    [anon_sym_centroid] = ACTIONS(2462),
    [anon_sym_noperspective] = ACTIONS(2462),
    [anon_sym_nointerpolation] = ACTIONS(2462),
    [anon_sym_sample] = ACTIONS(2462),
    [anon_sym_linear] = ACTIONS(2462),
    [anon_sym_snorm] = ACTIONS(2462),
    [anon_sym_unorm] = ACTIONS(2462),
    [anon_sym_point] = ACTIONS(2462),
    [anon_sym_line] = ACTIONS(2462),
    [anon_sym_triangleadj] = ACTIONS(2462),
    [anon_sym_lineadj] = ACTIONS(2462),
    [anon_sym_triangle] = ACTIONS(2462),
  },
  [712] = {
    [sym_preproc_def] = STATE(797),
    [sym_preproc_function_def] = STATE(797),
    [sym_preproc_call] = STATE(797),
    [sym_preproc_if_in_field_declaration_list] = STATE(797),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(797),
    [sym_type_definition] = STATE(797),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(797),
    [sym_field_declaration] = STATE(797),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(797),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(797),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(797),
    [sym_operator_cast_declaration] = STATE(797),
    [sym_constructor_or_destructor_definition] = STATE(797),
    [sym_constructor_or_destructor_declaration] = STATE(797),
    [sym_friend_declaration] = STATE(797),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(797),
    [sym_alias_declaration] = STATE(797),
    [sym_static_assert_declaration] = STATE(797),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(797),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2879),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [713] = {
    [ts_builtin_sym_end] = ACTIONS(2464),
    [sym_identifier] = ACTIONS(2462),
    [aux_sym_preproc_include_token1] = ACTIONS(2462),
    [aux_sym_preproc_def_token1] = ACTIONS(2462),
    [aux_sym_preproc_if_token1] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2462),
    [sym_preproc_directive] = ACTIONS(2462),
    [anon_sym_LPAREN2] = ACTIONS(2464),
    [anon_sym_BANG] = ACTIONS(2464),
    [anon_sym_TILDE] = ACTIONS(2464),
    [anon_sym_DASH] = ACTIONS(2462),
    [anon_sym_PLUS] = ACTIONS(2462),
    [anon_sym_STAR] = ACTIONS(2464),
    [anon_sym_AMP_AMP] = ACTIONS(2464),
    [anon_sym_AMP] = ACTIONS(2462),
    [anon_sym___extension__] = ACTIONS(2462),
    [anon_sym_typedef] = ACTIONS(2462),
    [anon_sym_in] = ACTIONS(2462),
    [anon_sym_out] = ACTIONS(2462),
    [anon_sym_inout] = ACTIONS(2462),
    [anon_sym_extern] = ACTIONS(2462),
    [anon_sym___attribute__] = ACTIONS(2462),
    [anon_sym_COLON_COLON] = ACTIONS(2464),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2464),
    [anon_sym___declspec] = ACTIONS(2462),
    [anon_sym___based] = ACTIONS(2462),
    [anon_sym___cdecl] = ACTIONS(2462),
    [anon_sym___clrcall] = ACTIONS(2462),
    [anon_sym___stdcall] = ACTIONS(2462),
    [anon_sym___fastcall] = ACTIONS(2462),
    [anon_sym___thiscall] = ACTIONS(2462),
    [anon_sym___vectorcall] = ACTIONS(2462),
    [anon_sym_LBRACE] = ACTIONS(2464),
    [anon_sym_signed] = ACTIONS(2462),
    [anon_sym_unsigned] = ACTIONS(2462),
    [anon_sym_long] = ACTIONS(2462),
    [anon_sym_short] = ACTIONS(2462),
    [anon_sym_LBRACK] = ACTIONS(2462),
    [anon_sym_static] = ACTIONS(2462),
    [anon_sym_register] = ACTIONS(2462),
    [anon_sym_inline] = ACTIONS(2462),
    [anon_sym___inline] = ACTIONS(2462),
    [anon_sym___inline__] = ACTIONS(2462),
    [anon_sym___forceinline] = ACTIONS(2462),
    [anon_sym_thread_local] = ACTIONS(2462),
    [anon_sym___thread] = ACTIONS(2462),
    [anon_sym_const] = ACTIONS(2462),
    [anon_sym_constexpr] = ACTIONS(2462),
    [anon_sym_volatile] = ACTIONS(2462),
    [anon_sym_restrict] = ACTIONS(2462),
    [anon_sym___restrict__] = ACTIONS(2462),
    [anon_sym__Atomic] = ACTIONS(2462),
    [anon_sym__Noreturn] = ACTIONS(2462),
    [anon_sym_noreturn] = ACTIONS(2462),
    [anon_sym_mutable] = ACTIONS(2462),
    [anon_sym_constinit] = ACTIONS(2462),
    [anon_sym_consteval] = ACTIONS(2462),
    [anon_sym_alignas] = ACTIONS(2462),
    [anon_sym__Alignas] = ACTIONS(2462),
    [sym_primitive_type] = ACTIONS(2462),
    [anon_sym_enum] = ACTIONS(2462),
    [anon_sym_class] = ACTIONS(2462),
    [anon_sym_struct] = ACTIONS(2462),
    [anon_sym_union] = ACTIONS(2462),
    [anon_sym_if] = ACTIONS(2462),
    [anon_sym_switch] = ACTIONS(2462),
    [anon_sym_case] = ACTIONS(2462),
    [anon_sym_default] = ACTIONS(2462),
    [anon_sym_while] = ACTIONS(2462),
    [anon_sym_do] = ACTIONS(2462),
    [anon_sym_for] = ACTIONS(2462),
    [anon_sym_return] = ACTIONS(2462),
    [anon_sym_break] = ACTIONS(2462),
    [anon_sym_continue] = ACTIONS(2462),
    [anon_sym_goto] = ACTIONS(2462),
    [anon_sym_not] = ACTIONS(2462),
    [anon_sym_compl] = ACTIONS(2462),
    [anon_sym_DASH_DASH] = ACTIONS(2464),
    [anon_sym_PLUS_PLUS] = ACTIONS(2464),
    [anon_sym_sizeof] = ACTIONS(2462),
    [anon_sym___alignof__] = ACTIONS(2462),
    [anon_sym___alignof] = ACTIONS(2462),
    [anon_sym__alignof] = ACTIONS(2462),
    [anon_sym_alignof] = ACTIONS(2462),
    [anon_sym__Alignof] = ACTIONS(2462),
    [anon_sym_offsetof] = ACTIONS(2462),
    [anon_sym__Generic] = ACTIONS(2462),
    [anon_sym_asm] = ACTIONS(2462),
    [anon_sym___asm__] = ACTIONS(2462),
    [sym_number_literal] = ACTIONS(2464),
    [anon_sym_L_SQUOTE] = ACTIONS(2464),
    [anon_sym_u_SQUOTE] = ACTIONS(2464),
    [anon_sym_U_SQUOTE] = ACTIONS(2464),
    [anon_sym_u8_SQUOTE] = ACTIONS(2464),
    [anon_sym_SQUOTE] = ACTIONS(2464),
    [anon_sym_L_DQUOTE] = ACTIONS(2464),
    [anon_sym_u_DQUOTE] = ACTIONS(2464),
    [anon_sym_U_DQUOTE] = ACTIONS(2464),
    [anon_sym_u8_DQUOTE] = ACTIONS(2464),
    [anon_sym_DQUOTE] = ACTIONS(2464),
    [sym_true] = ACTIONS(2462),
    [sym_false] = ACTIONS(2462),
    [anon_sym_NULL] = ACTIONS(2462),
    [anon_sym_nullptr] = ACTIONS(2462),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2462),
    [anon_sym_decltype] = ACTIONS(2462),
    [sym_virtual] = ACTIONS(2462),
    [anon_sym_explicit] = ACTIONS(2462),
    [anon_sym_typename] = ACTIONS(2462),
    [anon_sym_template] = ACTIONS(2462),
    [anon_sym_operator] = ACTIONS(2462),
    [anon_sym_try] = ACTIONS(2462),
    [anon_sym_delete] = ACTIONS(2462),
    [anon_sym_throw] = ACTIONS(2462),
    [anon_sym_namespace] = ACTIONS(2462),
    [anon_sym_using] = ACTIONS(2462),
    [anon_sym_static_assert] = ACTIONS(2462),
    [anon_sym_concept] = ACTIONS(2462),
    [anon_sym_co_return] = ACTIONS(2462),
    [anon_sym_co_yield] = ACTIONS(2462),
    [anon_sym_R_DQUOTE] = ACTIONS(2464),
    [anon_sym_LR_DQUOTE] = ACTIONS(2464),
    [anon_sym_uR_DQUOTE] = ACTIONS(2464),
    [anon_sym_UR_DQUOTE] = ACTIONS(2464),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2464),
    [anon_sym_co_await] = ACTIONS(2462),
    [anon_sym_new] = ACTIONS(2462),
    [anon_sym_requires] = ACTIONS(2462),
    [sym_this] = ACTIONS(2462),
    [anon_sym_precise] = ACTIONS(2462),
    [anon_sym_shared] = ACTIONS(2462),
    [anon_sym_groupshared] = ACTIONS(2462),
    [anon_sym_uniform] = ACTIONS(2462),
    [anon_sym_row_major] = ACTIONS(2462),
    [anon_sym_column_major] = ACTIONS(2462),
    [anon_sym_globallycoherent] = ACTIONS(2462),
    [anon_sym_centroid] = ACTIONS(2462),
    [anon_sym_noperspective] = ACTIONS(2462),
    [anon_sym_nointerpolation] = ACTIONS(2462),
    [anon_sym_sample] = ACTIONS(2462),
    [anon_sym_linear] = ACTIONS(2462),
    [anon_sym_snorm] = ACTIONS(2462),
    [anon_sym_unorm] = ACTIONS(2462),
    [anon_sym_point] = ACTIONS(2462),
    [anon_sym_line] = ACTIONS(2462),
    [anon_sym_triangleadj] = ACTIONS(2462),
    [anon_sym_lineadj] = ACTIONS(2462),
    [anon_sym_triangle] = ACTIONS(2462),
  },
  [714] = {
    [ts_builtin_sym_end] = ACTIONS(2530),
    [sym_identifier] = ACTIONS(2528),
    [aux_sym_preproc_include_token1] = ACTIONS(2528),
    [aux_sym_preproc_def_token1] = ACTIONS(2528),
    [aux_sym_preproc_if_token1] = ACTIONS(2528),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2528),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2528),
    [sym_preproc_directive] = ACTIONS(2528),
    [anon_sym_LPAREN2] = ACTIONS(2530),
    [anon_sym_BANG] = ACTIONS(2530),
    [anon_sym_TILDE] = ACTIONS(2530),
    [anon_sym_DASH] = ACTIONS(2528),
    [anon_sym_PLUS] = ACTIONS(2528),
    [anon_sym_STAR] = ACTIONS(2530),
    [anon_sym_AMP_AMP] = ACTIONS(2530),
    [anon_sym_AMP] = ACTIONS(2528),
    [anon_sym___extension__] = ACTIONS(2528),
    [anon_sym_typedef] = ACTIONS(2528),
    [anon_sym_in] = ACTIONS(2528),
    [anon_sym_out] = ACTIONS(2528),
    [anon_sym_inout] = ACTIONS(2528),
    [anon_sym_extern] = ACTIONS(2528),
    [anon_sym___attribute__] = ACTIONS(2528),
    [anon_sym_COLON_COLON] = ACTIONS(2530),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2530),
    [anon_sym___declspec] = ACTIONS(2528),
    [anon_sym___based] = ACTIONS(2528),
    [anon_sym___cdecl] = ACTIONS(2528),
    [anon_sym___clrcall] = ACTIONS(2528),
    [anon_sym___stdcall] = ACTIONS(2528),
    [anon_sym___fastcall] = ACTIONS(2528),
    [anon_sym___thiscall] = ACTIONS(2528),
    [anon_sym___vectorcall] = ACTIONS(2528),
    [anon_sym_LBRACE] = ACTIONS(2530),
    [anon_sym_signed] = ACTIONS(2528),
    [anon_sym_unsigned] = ACTIONS(2528),
    [anon_sym_long] = ACTIONS(2528),
    [anon_sym_short] = ACTIONS(2528),
    [anon_sym_LBRACK] = ACTIONS(2528),
    [anon_sym_static] = ACTIONS(2528),
    [anon_sym_register] = ACTIONS(2528),
    [anon_sym_inline] = ACTIONS(2528),
    [anon_sym___inline] = ACTIONS(2528),
    [anon_sym___inline__] = ACTIONS(2528),
    [anon_sym___forceinline] = ACTIONS(2528),
    [anon_sym_thread_local] = ACTIONS(2528),
    [anon_sym___thread] = ACTIONS(2528),
    [anon_sym_const] = ACTIONS(2528),
    [anon_sym_constexpr] = ACTIONS(2528),
    [anon_sym_volatile] = ACTIONS(2528),
    [anon_sym_restrict] = ACTIONS(2528),
    [anon_sym___restrict__] = ACTIONS(2528),
    [anon_sym__Atomic] = ACTIONS(2528),
    [anon_sym__Noreturn] = ACTIONS(2528),
    [anon_sym_noreturn] = ACTIONS(2528),
    [anon_sym_mutable] = ACTIONS(2528),
    [anon_sym_constinit] = ACTIONS(2528),
    [anon_sym_consteval] = ACTIONS(2528),
    [anon_sym_alignas] = ACTIONS(2528),
    [anon_sym__Alignas] = ACTIONS(2528),
    [sym_primitive_type] = ACTIONS(2528),
    [anon_sym_enum] = ACTIONS(2528),
    [anon_sym_class] = ACTIONS(2528),
    [anon_sym_struct] = ACTIONS(2528),
    [anon_sym_union] = ACTIONS(2528),
    [anon_sym_if] = ACTIONS(2528),
    [anon_sym_switch] = ACTIONS(2528),
    [anon_sym_case] = ACTIONS(2528),
    [anon_sym_default] = ACTIONS(2528),
    [anon_sym_while] = ACTIONS(2528),
    [anon_sym_do] = ACTIONS(2528),
    [anon_sym_for] = ACTIONS(2528),
    [anon_sym_return] = ACTIONS(2528),
    [anon_sym_break] = ACTIONS(2528),
    [anon_sym_continue] = ACTIONS(2528),
    [anon_sym_goto] = ACTIONS(2528),
    [anon_sym_not] = ACTIONS(2528),
    [anon_sym_compl] = ACTIONS(2528),
    [anon_sym_DASH_DASH] = ACTIONS(2530),
    [anon_sym_PLUS_PLUS] = ACTIONS(2530),
    [anon_sym_sizeof] = ACTIONS(2528),
    [anon_sym___alignof__] = ACTIONS(2528),
    [anon_sym___alignof] = ACTIONS(2528),
    [anon_sym__alignof] = ACTIONS(2528),
    [anon_sym_alignof] = ACTIONS(2528),
    [anon_sym__Alignof] = ACTIONS(2528),
    [anon_sym_offsetof] = ACTIONS(2528),
    [anon_sym__Generic] = ACTIONS(2528),
    [anon_sym_asm] = ACTIONS(2528),
    [anon_sym___asm__] = ACTIONS(2528),
    [sym_number_literal] = ACTIONS(2530),
    [anon_sym_L_SQUOTE] = ACTIONS(2530),
    [anon_sym_u_SQUOTE] = ACTIONS(2530),
    [anon_sym_U_SQUOTE] = ACTIONS(2530),
    [anon_sym_u8_SQUOTE] = ACTIONS(2530),
    [anon_sym_SQUOTE] = ACTIONS(2530),
    [anon_sym_L_DQUOTE] = ACTIONS(2530),
    [anon_sym_u_DQUOTE] = ACTIONS(2530),
    [anon_sym_U_DQUOTE] = ACTIONS(2530),
    [anon_sym_u8_DQUOTE] = ACTIONS(2530),
    [anon_sym_DQUOTE] = ACTIONS(2530),
    [sym_true] = ACTIONS(2528),
    [sym_false] = ACTIONS(2528),
    [anon_sym_NULL] = ACTIONS(2528),
    [anon_sym_nullptr] = ACTIONS(2528),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2528),
    [anon_sym_decltype] = ACTIONS(2528),
    [sym_virtual] = ACTIONS(2528),
    [anon_sym_explicit] = ACTIONS(2528),
    [anon_sym_typename] = ACTIONS(2528),
    [anon_sym_template] = ACTIONS(2528),
    [anon_sym_operator] = ACTIONS(2528),
    [anon_sym_try] = ACTIONS(2528),
    [anon_sym_delete] = ACTIONS(2528),
    [anon_sym_throw] = ACTIONS(2528),
    [anon_sym_namespace] = ACTIONS(2528),
    [anon_sym_using] = ACTIONS(2528),
    [anon_sym_static_assert] = ACTIONS(2528),
    [anon_sym_concept] = ACTIONS(2528),
    [anon_sym_co_return] = ACTIONS(2528),
    [anon_sym_co_yield] = ACTIONS(2528),
    [anon_sym_R_DQUOTE] = ACTIONS(2530),
    [anon_sym_LR_DQUOTE] = ACTIONS(2530),
    [anon_sym_uR_DQUOTE] = ACTIONS(2530),
    [anon_sym_UR_DQUOTE] = ACTIONS(2530),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2530),
    [anon_sym_co_await] = ACTIONS(2528),
    [anon_sym_new] = ACTIONS(2528),
    [anon_sym_requires] = ACTIONS(2528),
    [sym_this] = ACTIONS(2528),
    [anon_sym_precise] = ACTIONS(2528),
    [anon_sym_shared] = ACTIONS(2528),
    [anon_sym_groupshared] = ACTIONS(2528),
    [anon_sym_uniform] = ACTIONS(2528),
    [anon_sym_row_major] = ACTIONS(2528),
    [anon_sym_column_major] = ACTIONS(2528),
    [anon_sym_globallycoherent] = ACTIONS(2528),
    [anon_sym_centroid] = ACTIONS(2528),
    [anon_sym_noperspective] = ACTIONS(2528),
    [anon_sym_nointerpolation] = ACTIONS(2528),
    [anon_sym_sample] = ACTIONS(2528),
    [anon_sym_linear] = ACTIONS(2528),
    [anon_sym_snorm] = ACTIONS(2528),
    [anon_sym_unorm] = ACTIONS(2528),
    [anon_sym_point] = ACTIONS(2528),
    [anon_sym_line] = ACTIONS(2528),
    [anon_sym_triangleadj] = ACTIONS(2528),
    [anon_sym_lineadj] = ACTIONS(2528),
    [anon_sym_triangle] = ACTIONS(2528),
  },
  [715] = {
    [ts_builtin_sym_end] = ACTIONS(2555),
    [sym_identifier] = ACTIONS(2553),
    [aux_sym_preproc_include_token1] = ACTIONS(2553),
    [aux_sym_preproc_def_token1] = ACTIONS(2553),
    [aux_sym_preproc_if_token1] = ACTIONS(2553),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2553),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2553),
    [sym_preproc_directive] = ACTIONS(2553),
    [anon_sym_LPAREN2] = ACTIONS(2555),
    [anon_sym_BANG] = ACTIONS(2555),
    [anon_sym_TILDE] = ACTIONS(2555),
    [anon_sym_DASH] = ACTIONS(2553),
    [anon_sym_PLUS] = ACTIONS(2553),
    [anon_sym_STAR] = ACTIONS(2555),
    [anon_sym_AMP_AMP] = ACTIONS(2555),
    [anon_sym_AMP] = ACTIONS(2553),
    [anon_sym___extension__] = ACTIONS(2553),
    [anon_sym_typedef] = ACTIONS(2553),
    [anon_sym_in] = ACTIONS(2553),
    [anon_sym_out] = ACTIONS(2553),
    [anon_sym_inout] = ACTIONS(2553),
    [anon_sym_extern] = ACTIONS(2553),
    [anon_sym___attribute__] = ACTIONS(2553),
    [anon_sym_COLON_COLON] = ACTIONS(2555),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2555),
    [anon_sym___declspec] = ACTIONS(2553),
    [anon_sym___based] = ACTIONS(2553),
    [anon_sym___cdecl] = ACTIONS(2553),
    [anon_sym___clrcall] = ACTIONS(2553),
    [anon_sym___stdcall] = ACTIONS(2553),
    [anon_sym___fastcall] = ACTIONS(2553),
    [anon_sym___thiscall] = ACTIONS(2553),
    [anon_sym___vectorcall] = ACTIONS(2553),
    [anon_sym_LBRACE] = ACTIONS(2555),
    [anon_sym_signed] = ACTIONS(2553),
    [anon_sym_unsigned] = ACTIONS(2553),
    [anon_sym_long] = ACTIONS(2553),
    [anon_sym_short] = ACTIONS(2553),
    [anon_sym_LBRACK] = ACTIONS(2553),
    [anon_sym_static] = ACTIONS(2553),
    [anon_sym_register] = ACTIONS(2553),
    [anon_sym_inline] = ACTIONS(2553),
    [anon_sym___inline] = ACTIONS(2553),
    [anon_sym___inline__] = ACTIONS(2553),
    [anon_sym___forceinline] = ACTIONS(2553),
    [anon_sym_thread_local] = ACTIONS(2553),
    [anon_sym___thread] = ACTIONS(2553),
    [anon_sym_const] = ACTIONS(2553),
    [anon_sym_constexpr] = ACTIONS(2553),
    [anon_sym_volatile] = ACTIONS(2553),
    [anon_sym_restrict] = ACTIONS(2553),
    [anon_sym___restrict__] = ACTIONS(2553),
    [anon_sym__Atomic] = ACTIONS(2553),
    [anon_sym__Noreturn] = ACTIONS(2553),
    [anon_sym_noreturn] = ACTIONS(2553),
    [anon_sym_mutable] = ACTIONS(2553),
    [anon_sym_constinit] = ACTIONS(2553),
    [anon_sym_consteval] = ACTIONS(2553),
    [anon_sym_alignas] = ACTIONS(2553),
    [anon_sym__Alignas] = ACTIONS(2553),
    [sym_primitive_type] = ACTIONS(2553),
    [anon_sym_enum] = ACTIONS(2553),
    [anon_sym_class] = ACTIONS(2553),
    [anon_sym_struct] = ACTIONS(2553),
    [anon_sym_union] = ACTIONS(2553),
    [anon_sym_if] = ACTIONS(2553),
    [anon_sym_switch] = ACTIONS(2553),
    [anon_sym_case] = ACTIONS(2553),
    [anon_sym_default] = ACTIONS(2553),
    [anon_sym_while] = ACTIONS(2553),
    [anon_sym_do] = ACTIONS(2553),
    [anon_sym_for] = ACTIONS(2553),
    [anon_sym_return] = ACTIONS(2553),
    [anon_sym_break] = ACTIONS(2553),
    [anon_sym_continue] = ACTIONS(2553),
    [anon_sym_goto] = ACTIONS(2553),
    [anon_sym_not] = ACTIONS(2553),
    [anon_sym_compl] = ACTIONS(2553),
    [anon_sym_DASH_DASH] = ACTIONS(2555),
    [anon_sym_PLUS_PLUS] = ACTIONS(2555),
    [anon_sym_sizeof] = ACTIONS(2553),
    [anon_sym___alignof__] = ACTIONS(2553),
    [anon_sym___alignof] = ACTIONS(2553),
    [anon_sym__alignof] = ACTIONS(2553),
    [anon_sym_alignof] = ACTIONS(2553),
    [anon_sym__Alignof] = ACTIONS(2553),
    [anon_sym_offsetof] = ACTIONS(2553),
    [anon_sym__Generic] = ACTIONS(2553),
    [anon_sym_asm] = ACTIONS(2553),
    [anon_sym___asm__] = ACTIONS(2553),
    [sym_number_literal] = ACTIONS(2555),
    [anon_sym_L_SQUOTE] = ACTIONS(2555),
    [anon_sym_u_SQUOTE] = ACTIONS(2555),
    [anon_sym_U_SQUOTE] = ACTIONS(2555),
    [anon_sym_u8_SQUOTE] = ACTIONS(2555),
    [anon_sym_SQUOTE] = ACTIONS(2555),
    [anon_sym_L_DQUOTE] = ACTIONS(2555),
    [anon_sym_u_DQUOTE] = ACTIONS(2555),
    [anon_sym_U_DQUOTE] = ACTIONS(2555),
    [anon_sym_u8_DQUOTE] = ACTIONS(2555),
    [anon_sym_DQUOTE] = ACTIONS(2555),
    [sym_true] = ACTIONS(2553),
    [sym_false] = ACTIONS(2553),
    [anon_sym_NULL] = ACTIONS(2553),
    [anon_sym_nullptr] = ACTIONS(2553),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2553),
    [anon_sym_decltype] = ACTIONS(2553),
    [sym_virtual] = ACTIONS(2553),
    [anon_sym_explicit] = ACTIONS(2553),
    [anon_sym_typename] = ACTIONS(2553),
    [anon_sym_template] = ACTIONS(2553),
    [anon_sym_operator] = ACTIONS(2553),
    [anon_sym_try] = ACTIONS(2553),
    [anon_sym_delete] = ACTIONS(2553),
    [anon_sym_throw] = ACTIONS(2553),
    [anon_sym_namespace] = ACTIONS(2553),
    [anon_sym_using] = ACTIONS(2553),
    [anon_sym_static_assert] = ACTIONS(2553),
    [anon_sym_concept] = ACTIONS(2553),
    [anon_sym_co_return] = ACTIONS(2553),
    [anon_sym_co_yield] = ACTIONS(2553),
    [anon_sym_R_DQUOTE] = ACTIONS(2555),
    [anon_sym_LR_DQUOTE] = ACTIONS(2555),
    [anon_sym_uR_DQUOTE] = ACTIONS(2555),
    [anon_sym_UR_DQUOTE] = ACTIONS(2555),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2555),
    [anon_sym_co_await] = ACTIONS(2553),
    [anon_sym_new] = ACTIONS(2553),
    [anon_sym_requires] = ACTIONS(2553),
    [sym_this] = ACTIONS(2553),
    [anon_sym_precise] = ACTIONS(2553),
    [anon_sym_shared] = ACTIONS(2553),
    [anon_sym_groupshared] = ACTIONS(2553),
    [anon_sym_uniform] = ACTIONS(2553),
    [anon_sym_row_major] = ACTIONS(2553),
    [anon_sym_column_major] = ACTIONS(2553),
    [anon_sym_globallycoherent] = ACTIONS(2553),
    [anon_sym_centroid] = ACTIONS(2553),
    [anon_sym_noperspective] = ACTIONS(2553),
    [anon_sym_nointerpolation] = ACTIONS(2553),
    [anon_sym_sample] = ACTIONS(2553),
    [anon_sym_linear] = ACTIONS(2553),
    [anon_sym_snorm] = ACTIONS(2553),
    [anon_sym_unorm] = ACTIONS(2553),
    [anon_sym_point] = ACTIONS(2553),
    [anon_sym_line] = ACTIONS(2553),
    [anon_sym_triangleadj] = ACTIONS(2553),
    [anon_sym_lineadj] = ACTIONS(2553),
    [anon_sym_triangle] = ACTIONS(2553),
  },
  [716] = {
    [ts_builtin_sym_end] = ACTIONS(2526),
    [sym_identifier] = ACTIONS(2524),
    [aux_sym_preproc_include_token1] = ACTIONS(2524),
    [aux_sym_preproc_def_token1] = ACTIONS(2524),
    [aux_sym_preproc_if_token1] = ACTIONS(2524),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2524),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2524),
    [sym_preproc_directive] = ACTIONS(2524),
    [anon_sym_LPAREN2] = ACTIONS(2526),
    [anon_sym_BANG] = ACTIONS(2526),
    [anon_sym_TILDE] = ACTIONS(2526),
    [anon_sym_DASH] = ACTIONS(2524),
    [anon_sym_PLUS] = ACTIONS(2524),
    [anon_sym_STAR] = ACTIONS(2526),
    [anon_sym_AMP_AMP] = ACTIONS(2526),
    [anon_sym_AMP] = ACTIONS(2524),
    [anon_sym___extension__] = ACTIONS(2524),
    [anon_sym_typedef] = ACTIONS(2524),
    [anon_sym_in] = ACTIONS(2524),
    [anon_sym_out] = ACTIONS(2524),
    [anon_sym_inout] = ACTIONS(2524),
    [anon_sym_extern] = ACTIONS(2524),
    [anon_sym___attribute__] = ACTIONS(2524),
    [anon_sym_COLON_COLON] = ACTIONS(2526),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2526),
    [anon_sym___declspec] = ACTIONS(2524),
    [anon_sym___based] = ACTIONS(2524),
    [anon_sym___cdecl] = ACTIONS(2524),
    [anon_sym___clrcall] = ACTIONS(2524),
    [anon_sym___stdcall] = ACTIONS(2524),
    [anon_sym___fastcall] = ACTIONS(2524),
    [anon_sym___thiscall] = ACTIONS(2524),
    [anon_sym___vectorcall] = ACTIONS(2524),
    [anon_sym_LBRACE] = ACTIONS(2526),
    [anon_sym_signed] = ACTIONS(2524),
    [anon_sym_unsigned] = ACTIONS(2524),
    [anon_sym_long] = ACTIONS(2524),
    [anon_sym_short] = ACTIONS(2524),
    [anon_sym_LBRACK] = ACTIONS(2524),
    [anon_sym_static] = ACTIONS(2524),
    [anon_sym_register] = ACTIONS(2524),
    [anon_sym_inline] = ACTIONS(2524),
    [anon_sym___inline] = ACTIONS(2524),
    [anon_sym___inline__] = ACTIONS(2524),
    [anon_sym___forceinline] = ACTIONS(2524),
    [anon_sym_thread_local] = ACTIONS(2524),
    [anon_sym___thread] = ACTIONS(2524),
    [anon_sym_const] = ACTIONS(2524),
    [anon_sym_constexpr] = ACTIONS(2524),
    [anon_sym_volatile] = ACTIONS(2524),
    [anon_sym_restrict] = ACTIONS(2524),
    [anon_sym___restrict__] = ACTIONS(2524),
    [anon_sym__Atomic] = ACTIONS(2524),
    [anon_sym__Noreturn] = ACTIONS(2524),
    [anon_sym_noreturn] = ACTIONS(2524),
    [anon_sym_mutable] = ACTIONS(2524),
    [anon_sym_constinit] = ACTIONS(2524),
    [anon_sym_consteval] = ACTIONS(2524),
    [anon_sym_alignas] = ACTIONS(2524),
    [anon_sym__Alignas] = ACTIONS(2524),
    [sym_primitive_type] = ACTIONS(2524),
    [anon_sym_enum] = ACTIONS(2524),
    [anon_sym_class] = ACTIONS(2524),
    [anon_sym_struct] = ACTIONS(2524),
    [anon_sym_union] = ACTIONS(2524),
    [anon_sym_if] = ACTIONS(2524),
    [anon_sym_switch] = ACTIONS(2524),
    [anon_sym_case] = ACTIONS(2524),
    [anon_sym_default] = ACTIONS(2524),
    [anon_sym_while] = ACTIONS(2524),
    [anon_sym_do] = ACTIONS(2524),
    [anon_sym_for] = ACTIONS(2524),
    [anon_sym_return] = ACTIONS(2524),
    [anon_sym_break] = ACTIONS(2524),
    [anon_sym_continue] = ACTIONS(2524),
    [anon_sym_goto] = ACTIONS(2524),
    [anon_sym_not] = ACTIONS(2524),
    [anon_sym_compl] = ACTIONS(2524),
    [anon_sym_DASH_DASH] = ACTIONS(2526),
    [anon_sym_PLUS_PLUS] = ACTIONS(2526),
    [anon_sym_sizeof] = ACTIONS(2524),
    [anon_sym___alignof__] = ACTIONS(2524),
    [anon_sym___alignof] = ACTIONS(2524),
    [anon_sym__alignof] = ACTIONS(2524),
    [anon_sym_alignof] = ACTIONS(2524),
    [anon_sym__Alignof] = ACTIONS(2524),
    [anon_sym_offsetof] = ACTIONS(2524),
    [anon_sym__Generic] = ACTIONS(2524),
    [anon_sym_asm] = ACTIONS(2524),
    [anon_sym___asm__] = ACTIONS(2524),
    [sym_number_literal] = ACTIONS(2526),
    [anon_sym_L_SQUOTE] = ACTIONS(2526),
    [anon_sym_u_SQUOTE] = ACTIONS(2526),
    [anon_sym_U_SQUOTE] = ACTIONS(2526),
    [anon_sym_u8_SQUOTE] = ACTIONS(2526),
    [anon_sym_SQUOTE] = ACTIONS(2526),
    [anon_sym_L_DQUOTE] = ACTIONS(2526),
    [anon_sym_u_DQUOTE] = ACTIONS(2526),
    [anon_sym_U_DQUOTE] = ACTIONS(2526),
    [anon_sym_u8_DQUOTE] = ACTIONS(2526),
    [anon_sym_DQUOTE] = ACTIONS(2526),
    [sym_true] = ACTIONS(2524),
    [sym_false] = ACTIONS(2524),
    [anon_sym_NULL] = ACTIONS(2524),
    [anon_sym_nullptr] = ACTIONS(2524),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2524),
    [anon_sym_decltype] = ACTIONS(2524),
    [sym_virtual] = ACTIONS(2524),
    [anon_sym_explicit] = ACTIONS(2524),
    [anon_sym_typename] = ACTIONS(2524),
    [anon_sym_template] = ACTIONS(2524),
    [anon_sym_operator] = ACTIONS(2524),
    [anon_sym_try] = ACTIONS(2524),
    [anon_sym_delete] = ACTIONS(2524),
    [anon_sym_throw] = ACTIONS(2524),
    [anon_sym_namespace] = ACTIONS(2524),
    [anon_sym_using] = ACTIONS(2524),
    [anon_sym_static_assert] = ACTIONS(2524),
    [anon_sym_concept] = ACTIONS(2524),
    [anon_sym_co_return] = ACTIONS(2524),
    [anon_sym_co_yield] = ACTIONS(2524),
    [anon_sym_R_DQUOTE] = ACTIONS(2526),
    [anon_sym_LR_DQUOTE] = ACTIONS(2526),
    [anon_sym_uR_DQUOTE] = ACTIONS(2526),
    [anon_sym_UR_DQUOTE] = ACTIONS(2526),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2526),
    [anon_sym_co_await] = ACTIONS(2524),
    [anon_sym_new] = ACTIONS(2524),
    [anon_sym_requires] = ACTIONS(2524),
    [sym_this] = ACTIONS(2524),
    [anon_sym_precise] = ACTIONS(2524),
    [anon_sym_shared] = ACTIONS(2524),
    [anon_sym_groupshared] = ACTIONS(2524),
    [anon_sym_uniform] = ACTIONS(2524),
    [anon_sym_row_major] = ACTIONS(2524),
    [anon_sym_column_major] = ACTIONS(2524),
    [anon_sym_globallycoherent] = ACTIONS(2524),
    [anon_sym_centroid] = ACTIONS(2524),
    [anon_sym_noperspective] = ACTIONS(2524),
    [anon_sym_nointerpolation] = ACTIONS(2524),
    [anon_sym_sample] = ACTIONS(2524),
    [anon_sym_linear] = ACTIONS(2524),
    [anon_sym_snorm] = ACTIONS(2524),
    [anon_sym_unorm] = ACTIONS(2524),
    [anon_sym_point] = ACTIONS(2524),
    [anon_sym_line] = ACTIONS(2524),
    [anon_sym_triangleadj] = ACTIONS(2524),
    [anon_sym_lineadj] = ACTIONS(2524),
    [anon_sym_triangle] = ACTIONS(2524),
  },
  [717] = {
    [ts_builtin_sym_end] = ACTIONS(2504),
    [sym_identifier] = ACTIONS(2502),
    [aux_sym_preproc_include_token1] = ACTIONS(2502),
    [aux_sym_preproc_def_token1] = ACTIONS(2502),
    [aux_sym_preproc_if_token1] = ACTIONS(2502),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2502),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2502),
    [sym_preproc_directive] = ACTIONS(2502),
    [anon_sym_LPAREN2] = ACTIONS(2504),
    [anon_sym_BANG] = ACTIONS(2504),
    [anon_sym_TILDE] = ACTIONS(2504),
    [anon_sym_DASH] = ACTIONS(2502),
    [anon_sym_PLUS] = ACTIONS(2502),
    [anon_sym_STAR] = ACTIONS(2504),
    [anon_sym_AMP_AMP] = ACTIONS(2504),
    [anon_sym_AMP] = ACTIONS(2502),
    [anon_sym___extension__] = ACTIONS(2502),
    [anon_sym_typedef] = ACTIONS(2502),
    [anon_sym_in] = ACTIONS(2502),
    [anon_sym_out] = ACTIONS(2502),
    [anon_sym_inout] = ACTIONS(2502),
    [anon_sym_extern] = ACTIONS(2502),
    [anon_sym___attribute__] = ACTIONS(2502),
    [anon_sym_COLON_COLON] = ACTIONS(2504),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2504),
    [anon_sym___declspec] = ACTIONS(2502),
    [anon_sym___based] = ACTIONS(2502),
    [anon_sym___cdecl] = ACTIONS(2502),
    [anon_sym___clrcall] = ACTIONS(2502),
    [anon_sym___stdcall] = ACTIONS(2502),
    [anon_sym___fastcall] = ACTIONS(2502),
    [anon_sym___thiscall] = ACTIONS(2502),
    [anon_sym___vectorcall] = ACTIONS(2502),
    [anon_sym_LBRACE] = ACTIONS(2504),
    [anon_sym_signed] = ACTIONS(2502),
    [anon_sym_unsigned] = ACTIONS(2502),
    [anon_sym_long] = ACTIONS(2502),
    [anon_sym_short] = ACTIONS(2502),
    [anon_sym_LBRACK] = ACTIONS(2502),
    [anon_sym_static] = ACTIONS(2502),
    [anon_sym_register] = ACTIONS(2502),
    [anon_sym_inline] = ACTIONS(2502),
    [anon_sym___inline] = ACTIONS(2502),
    [anon_sym___inline__] = ACTIONS(2502),
    [anon_sym___forceinline] = ACTIONS(2502),
    [anon_sym_thread_local] = ACTIONS(2502),
    [anon_sym___thread] = ACTIONS(2502),
    [anon_sym_const] = ACTIONS(2502),
    [anon_sym_constexpr] = ACTIONS(2502),
    [anon_sym_volatile] = ACTIONS(2502),
    [anon_sym_restrict] = ACTIONS(2502),
    [anon_sym___restrict__] = ACTIONS(2502),
    [anon_sym__Atomic] = ACTIONS(2502),
    [anon_sym__Noreturn] = ACTIONS(2502),
    [anon_sym_noreturn] = ACTIONS(2502),
    [anon_sym_mutable] = ACTIONS(2502),
    [anon_sym_constinit] = ACTIONS(2502),
    [anon_sym_consteval] = ACTIONS(2502),
    [anon_sym_alignas] = ACTIONS(2502),
    [anon_sym__Alignas] = ACTIONS(2502),
    [sym_primitive_type] = ACTIONS(2502),
    [anon_sym_enum] = ACTIONS(2502),
    [anon_sym_class] = ACTIONS(2502),
    [anon_sym_struct] = ACTIONS(2502),
    [anon_sym_union] = ACTIONS(2502),
    [anon_sym_if] = ACTIONS(2502),
    [anon_sym_switch] = ACTIONS(2502),
    [anon_sym_case] = ACTIONS(2502),
    [anon_sym_default] = ACTIONS(2502),
    [anon_sym_while] = ACTIONS(2502),
    [anon_sym_do] = ACTIONS(2502),
    [anon_sym_for] = ACTIONS(2502),
    [anon_sym_return] = ACTIONS(2502),
    [anon_sym_break] = ACTIONS(2502),
    [anon_sym_continue] = ACTIONS(2502),
    [anon_sym_goto] = ACTIONS(2502),
    [anon_sym_not] = ACTIONS(2502),
    [anon_sym_compl] = ACTIONS(2502),
    [anon_sym_DASH_DASH] = ACTIONS(2504),
    [anon_sym_PLUS_PLUS] = ACTIONS(2504),
    [anon_sym_sizeof] = ACTIONS(2502),
    [anon_sym___alignof__] = ACTIONS(2502),
    [anon_sym___alignof] = ACTIONS(2502),
    [anon_sym__alignof] = ACTIONS(2502),
    [anon_sym_alignof] = ACTIONS(2502),
    [anon_sym__Alignof] = ACTIONS(2502),
    [anon_sym_offsetof] = ACTIONS(2502),
    [anon_sym__Generic] = ACTIONS(2502),
    [anon_sym_asm] = ACTIONS(2502),
    [anon_sym___asm__] = ACTIONS(2502),
    [sym_number_literal] = ACTIONS(2504),
    [anon_sym_L_SQUOTE] = ACTIONS(2504),
    [anon_sym_u_SQUOTE] = ACTIONS(2504),
    [anon_sym_U_SQUOTE] = ACTIONS(2504),
    [anon_sym_u8_SQUOTE] = ACTIONS(2504),
    [anon_sym_SQUOTE] = ACTIONS(2504),
    [anon_sym_L_DQUOTE] = ACTIONS(2504),
    [anon_sym_u_DQUOTE] = ACTIONS(2504),
    [anon_sym_U_DQUOTE] = ACTIONS(2504),
    [anon_sym_u8_DQUOTE] = ACTIONS(2504),
    [anon_sym_DQUOTE] = ACTIONS(2504),
    [sym_true] = ACTIONS(2502),
    [sym_false] = ACTIONS(2502),
    [anon_sym_NULL] = ACTIONS(2502),
    [anon_sym_nullptr] = ACTIONS(2502),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2502),
    [anon_sym_decltype] = ACTIONS(2502),
    [sym_virtual] = ACTIONS(2502),
    [anon_sym_explicit] = ACTIONS(2502),
    [anon_sym_typename] = ACTIONS(2502),
    [anon_sym_template] = ACTIONS(2502),
    [anon_sym_operator] = ACTIONS(2502),
    [anon_sym_try] = ACTIONS(2502),
    [anon_sym_delete] = ACTIONS(2502),
    [anon_sym_throw] = ACTIONS(2502),
    [anon_sym_namespace] = ACTIONS(2502),
    [anon_sym_using] = ACTIONS(2502),
    [anon_sym_static_assert] = ACTIONS(2502),
    [anon_sym_concept] = ACTIONS(2502),
    [anon_sym_co_return] = ACTIONS(2502),
    [anon_sym_co_yield] = ACTIONS(2502),
    [anon_sym_R_DQUOTE] = ACTIONS(2504),
    [anon_sym_LR_DQUOTE] = ACTIONS(2504),
    [anon_sym_uR_DQUOTE] = ACTIONS(2504),
    [anon_sym_UR_DQUOTE] = ACTIONS(2504),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2504),
    [anon_sym_co_await] = ACTIONS(2502),
    [anon_sym_new] = ACTIONS(2502),
    [anon_sym_requires] = ACTIONS(2502),
    [sym_this] = ACTIONS(2502),
    [anon_sym_precise] = ACTIONS(2502),
    [anon_sym_shared] = ACTIONS(2502),
    [anon_sym_groupshared] = ACTIONS(2502),
    [anon_sym_uniform] = ACTIONS(2502),
    [anon_sym_row_major] = ACTIONS(2502),
    [anon_sym_column_major] = ACTIONS(2502),
    [anon_sym_globallycoherent] = ACTIONS(2502),
    [anon_sym_centroid] = ACTIONS(2502),
    [anon_sym_noperspective] = ACTIONS(2502),
    [anon_sym_nointerpolation] = ACTIONS(2502),
    [anon_sym_sample] = ACTIONS(2502),
    [anon_sym_linear] = ACTIONS(2502),
    [anon_sym_snorm] = ACTIONS(2502),
    [anon_sym_unorm] = ACTIONS(2502),
    [anon_sym_point] = ACTIONS(2502),
    [anon_sym_line] = ACTIONS(2502),
    [anon_sym_triangleadj] = ACTIONS(2502),
    [anon_sym_lineadj] = ACTIONS(2502),
    [anon_sym_triangle] = ACTIONS(2502),
  },
  [718] = {
    [ts_builtin_sym_end] = ACTIONS(2373),
    [sym_identifier] = ACTIONS(2371),
    [aux_sym_preproc_include_token1] = ACTIONS(2371),
    [aux_sym_preproc_def_token1] = ACTIONS(2371),
    [aux_sym_preproc_if_token1] = ACTIONS(2371),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2371),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2371),
    [sym_preproc_directive] = ACTIONS(2371),
    [anon_sym_LPAREN2] = ACTIONS(2373),
    [anon_sym_BANG] = ACTIONS(2373),
    [anon_sym_TILDE] = ACTIONS(2373),
    [anon_sym_DASH] = ACTIONS(2371),
    [anon_sym_PLUS] = ACTIONS(2371),
    [anon_sym_STAR] = ACTIONS(2373),
    [anon_sym_AMP_AMP] = ACTIONS(2373),
    [anon_sym_AMP] = ACTIONS(2371),
    [anon_sym___extension__] = ACTIONS(2371),
    [anon_sym_typedef] = ACTIONS(2371),
    [anon_sym_in] = ACTIONS(2371),
    [anon_sym_out] = ACTIONS(2371),
    [anon_sym_inout] = ACTIONS(2371),
    [anon_sym_extern] = ACTIONS(2371),
    [anon_sym___attribute__] = ACTIONS(2371),
    [anon_sym_COLON_COLON] = ACTIONS(2373),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2373),
    [anon_sym___declspec] = ACTIONS(2371),
    [anon_sym___based] = ACTIONS(2371),
    [anon_sym___cdecl] = ACTIONS(2371),
    [anon_sym___clrcall] = ACTIONS(2371),
    [anon_sym___stdcall] = ACTIONS(2371),
    [anon_sym___fastcall] = ACTIONS(2371),
    [anon_sym___thiscall] = ACTIONS(2371),
    [anon_sym___vectorcall] = ACTIONS(2371),
    [anon_sym_LBRACE] = ACTIONS(2373),
    [anon_sym_signed] = ACTIONS(2371),
    [anon_sym_unsigned] = ACTIONS(2371),
    [anon_sym_long] = ACTIONS(2371),
    [anon_sym_short] = ACTIONS(2371),
    [anon_sym_LBRACK] = ACTIONS(2371),
    [anon_sym_static] = ACTIONS(2371),
    [anon_sym_register] = ACTIONS(2371),
    [anon_sym_inline] = ACTIONS(2371),
    [anon_sym___inline] = ACTIONS(2371),
    [anon_sym___inline__] = ACTIONS(2371),
    [anon_sym___forceinline] = ACTIONS(2371),
    [anon_sym_thread_local] = ACTIONS(2371),
    [anon_sym___thread] = ACTIONS(2371),
    [anon_sym_const] = ACTIONS(2371),
    [anon_sym_constexpr] = ACTIONS(2371),
    [anon_sym_volatile] = ACTIONS(2371),
    [anon_sym_restrict] = ACTIONS(2371),
    [anon_sym___restrict__] = ACTIONS(2371),
    [anon_sym__Atomic] = ACTIONS(2371),
    [anon_sym__Noreturn] = ACTIONS(2371),
    [anon_sym_noreturn] = ACTIONS(2371),
    [anon_sym_mutable] = ACTIONS(2371),
    [anon_sym_constinit] = ACTIONS(2371),
    [anon_sym_consteval] = ACTIONS(2371),
    [anon_sym_alignas] = ACTIONS(2371),
    [anon_sym__Alignas] = ACTIONS(2371),
    [sym_primitive_type] = ACTIONS(2371),
    [anon_sym_enum] = ACTIONS(2371),
    [anon_sym_class] = ACTIONS(2371),
    [anon_sym_struct] = ACTIONS(2371),
    [anon_sym_union] = ACTIONS(2371),
    [anon_sym_if] = ACTIONS(2371),
    [anon_sym_switch] = ACTIONS(2371),
    [anon_sym_case] = ACTIONS(2371),
    [anon_sym_default] = ACTIONS(2371),
    [anon_sym_while] = ACTIONS(2371),
    [anon_sym_do] = ACTIONS(2371),
    [anon_sym_for] = ACTIONS(2371),
    [anon_sym_return] = ACTIONS(2371),
    [anon_sym_break] = ACTIONS(2371),
    [anon_sym_continue] = ACTIONS(2371),
    [anon_sym_goto] = ACTIONS(2371),
    [anon_sym_not] = ACTIONS(2371),
    [anon_sym_compl] = ACTIONS(2371),
    [anon_sym_DASH_DASH] = ACTIONS(2373),
    [anon_sym_PLUS_PLUS] = ACTIONS(2373),
    [anon_sym_sizeof] = ACTIONS(2371),
    [anon_sym___alignof__] = ACTIONS(2371),
    [anon_sym___alignof] = ACTIONS(2371),
    [anon_sym__alignof] = ACTIONS(2371),
    [anon_sym_alignof] = ACTIONS(2371),
    [anon_sym__Alignof] = ACTIONS(2371),
    [anon_sym_offsetof] = ACTIONS(2371),
    [anon_sym__Generic] = ACTIONS(2371),
    [anon_sym_asm] = ACTIONS(2371),
    [anon_sym___asm__] = ACTIONS(2371),
    [sym_number_literal] = ACTIONS(2373),
    [anon_sym_L_SQUOTE] = ACTIONS(2373),
    [anon_sym_u_SQUOTE] = ACTIONS(2373),
    [anon_sym_U_SQUOTE] = ACTIONS(2373),
    [anon_sym_u8_SQUOTE] = ACTIONS(2373),
    [anon_sym_SQUOTE] = ACTIONS(2373),
    [anon_sym_L_DQUOTE] = ACTIONS(2373),
    [anon_sym_u_DQUOTE] = ACTIONS(2373),
    [anon_sym_U_DQUOTE] = ACTIONS(2373),
    [anon_sym_u8_DQUOTE] = ACTIONS(2373),
    [anon_sym_DQUOTE] = ACTIONS(2373),
    [sym_true] = ACTIONS(2371),
    [sym_false] = ACTIONS(2371),
    [anon_sym_NULL] = ACTIONS(2371),
    [anon_sym_nullptr] = ACTIONS(2371),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2371),
    [anon_sym_decltype] = ACTIONS(2371),
    [sym_virtual] = ACTIONS(2371),
    [anon_sym_explicit] = ACTIONS(2371),
    [anon_sym_typename] = ACTIONS(2371),
    [anon_sym_template] = ACTIONS(2371),
    [anon_sym_operator] = ACTIONS(2371),
    [anon_sym_try] = ACTIONS(2371),
    [anon_sym_delete] = ACTIONS(2371),
    [anon_sym_throw] = ACTIONS(2371),
    [anon_sym_namespace] = ACTIONS(2371),
    [anon_sym_using] = ACTIONS(2371),
    [anon_sym_static_assert] = ACTIONS(2371),
    [anon_sym_concept] = ACTIONS(2371),
    [anon_sym_co_return] = ACTIONS(2371),
    [anon_sym_co_yield] = ACTIONS(2371),
    [anon_sym_R_DQUOTE] = ACTIONS(2373),
    [anon_sym_LR_DQUOTE] = ACTIONS(2373),
    [anon_sym_uR_DQUOTE] = ACTIONS(2373),
    [anon_sym_UR_DQUOTE] = ACTIONS(2373),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2373),
    [anon_sym_co_await] = ACTIONS(2371),
    [anon_sym_new] = ACTIONS(2371),
    [anon_sym_requires] = ACTIONS(2371),
    [sym_this] = ACTIONS(2371),
    [anon_sym_precise] = ACTIONS(2371),
    [anon_sym_shared] = ACTIONS(2371),
    [anon_sym_groupshared] = ACTIONS(2371),
    [anon_sym_uniform] = ACTIONS(2371),
    [anon_sym_row_major] = ACTIONS(2371),
    [anon_sym_column_major] = ACTIONS(2371),
    [anon_sym_globallycoherent] = ACTIONS(2371),
    [anon_sym_centroid] = ACTIONS(2371),
    [anon_sym_noperspective] = ACTIONS(2371),
    [anon_sym_nointerpolation] = ACTIONS(2371),
    [anon_sym_sample] = ACTIONS(2371),
    [anon_sym_linear] = ACTIONS(2371),
    [anon_sym_snorm] = ACTIONS(2371),
    [anon_sym_unorm] = ACTIONS(2371),
    [anon_sym_point] = ACTIONS(2371),
    [anon_sym_line] = ACTIONS(2371),
    [anon_sym_triangleadj] = ACTIONS(2371),
    [anon_sym_lineadj] = ACTIONS(2371),
    [anon_sym_triangle] = ACTIONS(2371),
  },
  [719] = {
    [sym_preproc_def] = STATE(740),
    [sym_preproc_function_def] = STATE(740),
    [sym_preproc_call] = STATE(740),
    [sym_preproc_if_in_field_declaration_list] = STATE(740),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(740),
    [sym_type_definition] = STATE(740),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(740),
    [sym_field_declaration] = STATE(740),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(740),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(740),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(740),
    [sym_operator_cast_declaration] = STATE(740),
    [sym_constructor_or_destructor_definition] = STATE(740),
    [sym_constructor_or_destructor_declaration] = STATE(740),
    [sym_friend_declaration] = STATE(740),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(740),
    [sym_alias_declaration] = STATE(740),
    [sym_static_assert_declaration] = STATE(740),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(740),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2881),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [720] = {
    [sym_preproc_def] = STATE(770),
    [sym_preproc_function_def] = STATE(770),
    [sym_preproc_call] = STATE(770),
    [sym_preproc_if_in_field_declaration_list] = STATE(770),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(770),
    [sym_type_definition] = STATE(770),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(770),
    [sym_field_declaration] = STATE(770),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(770),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(770),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(770),
    [sym_operator_cast_declaration] = STATE(770),
    [sym_constructor_or_destructor_definition] = STATE(770),
    [sym_constructor_or_destructor_declaration] = STATE(770),
    [sym_friend_declaration] = STATE(770),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(770),
    [sym_alias_declaration] = STATE(770),
    [sym_static_assert_declaration] = STATE(770),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(770),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2883),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [721] = {
    [ts_builtin_sym_end] = ACTIONS(2438),
    [sym_identifier] = ACTIONS(2436),
    [aux_sym_preproc_include_token1] = ACTIONS(2436),
    [aux_sym_preproc_def_token1] = ACTIONS(2436),
    [aux_sym_preproc_if_token1] = ACTIONS(2436),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2436),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2436),
    [sym_preproc_directive] = ACTIONS(2436),
    [anon_sym_LPAREN2] = ACTIONS(2438),
    [anon_sym_BANG] = ACTIONS(2438),
    [anon_sym_TILDE] = ACTIONS(2438),
    [anon_sym_DASH] = ACTIONS(2436),
    [anon_sym_PLUS] = ACTIONS(2436),
    [anon_sym_STAR] = ACTIONS(2438),
    [anon_sym_AMP_AMP] = ACTIONS(2438),
    [anon_sym_AMP] = ACTIONS(2436),
    [anon_sym___extension__] = ACTIONS(2436),
    [anon_sym_typedef] = ACTIONS(2436),
    [anon_sym_in] = ACTIONS(2436),
    [anon_sym_out] = ACTIONS(2436),
    [anon_sym_inout] = ACTIONS(2436),
    [anon_sym_extern] = ACTIONS(2436),
    [anon_sym___attribute__] = ACTIONS(2436),
    [anon_sym_COLON_COLON] = ACTIONS(2438),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2438),
    [anon_sym___declspec] = ACTIONS(2436),
    [anon_sym___based] = ACTIONS(2436),
    [anon_sym___cdecl] = ACTIONS(2436),
    [anon_sym___clrcall] = ACTIONS(2436),
    [anon_sym___stdcall] = ACTIONS(2436),
    [anon_sym___fastcall] = ACTIONS(2436),
    [anon_sym___thiscall] = ACTIONS(2436),
    [anon_sym___vectorcall] = ACTIONS(2436),
    [anon_sym_LBRACE] = ACTIONS(2438),
    [anon_sym_signed] = ACTIONS(2436),
    [anon_sym_unsigned] = ACTIONS(2436),
    [anon_sym_long] = ACTIONS(2436),
    [anon_sym_short] = ACTIONS(2436),
    [anon_sym_LBRACK] = ACTIONS(2436),
    [anon_sym_static] = ACTIONS(2436),
    [anon_sym_register] = ACTIONS(2436),
    [anon_sym_inline] = ACTIONS(2436),
    [anon_sym___inline] = ACTIONS(2436),
    [anon_sym___inline__] = ACTIONS(2436),
    [anon_sym___forceinline] = ACTIONS(2436),
    [anon_sym_thread_local] = ACTIONS(2436),
    [anon_sym___thread] = ACTIONS(2436),
    [anon_sym_const] = ACTIONS(2436),
    [anon_sym_constexpr] = ACTIONS(2436),
    [anon_sym_volatile] = ACTIONS(2436),
    [anon_sym_restrict] = ACTIONS(2436),
    [anon_sym___restrict__] = ACTIONS(2436),
    [anon_sym__Atomic] = ACTIONS(2436),
    [anon_sym__Noreturn] = ACTIONS(2436),
    [anon_sym_noreturn] = ACTIONS(2436),
    [anon_sym_mutable] = ACTIONS(2436),
    [anon_sym_constinit] = ACTIONS(2436),
    [anon_sym_consteval] = ACTIONS(2436),
    [anon_sym_alignas] = ACTIONS(2436),
    [anon_sym__Alignas] = ACTIONS(2436),
    [sym_primitive_type] = ACTIONS(2436),
    [anon_sym_enum] = ACTIONS(2436),
    [anon_sym_class] = ACTIONS(2436),
    [anon_sym_struct] = ACTIONS(2436),
    [anon_sym_union] = ACTIONS(2436),
    [anon_sym_if] = ACTIONS(2436),
    [anon_sym_switch] = ACTIONS(2436),
    [anon_sym_case] = ACTIONS(2436),
    [anon_sym_default] = ACTIONS(2436),
    [anon_sym_while] = ACTIONS(2436),
    [anon_sym_do] = ACTIONS(2436),
    [anon_sym_for] = ACTIONS(2436),
    [anon_sym_return] = ACTIONS(2436),
    [anon_sym_break] = ACTIONS(2436),
    [anon_sym_continue] = ACTIONS(2436),
    [anon_sym_goto] = ACTIONS(2436),
    [anon_sym_not] = ACTIONS(2436),
    [anon_sym_compl] = ACTIONS(2436),
    [anon_sym_DASH_DASH] = ACTIONS(2438),
    [anon_sym_PLUS_PLUS] = ACTIONS(2438),
    [anon_sym_sizeof] = ACTIONS(2436),
    [anon_sym___alignof__] = ACTIONS(2436),
    [anon_sym___alignof] = ACTIONS(2436),
    [anon_sym__alignof] = ACTIONS(2436),
    [anon_sym_alignof] = ACTIONS(2436),
    [anon_sym__Alignof] = ACTIONS(2436),
    [anon_sym_offsetof] = ACTIONS(2436),
    [anon_sym__Generic] = ACTIONS(2436),
    [anon_sym_asm] = ACTIONS(2436),
    [anon_sym___asm__] = ACTIONS(2436),
    [sym_number_literal] = ACTIONS(2438),
    [anon_sym_L_SQUOTE] = ACTIONS(2438),
    [anon_sym_u_SQUOTE] = ACTIONS(2438),
    [anon_sym_U_SQUOTE] = ACTIONS(2438),
    [anon_sym_u8_SQUOTE] = ACTIONS(2438),
    [anon_sym_SQUOTE] = ACTIONS(2438),
    [anon_sym_L_DQUOTE] = ACTIONS(2438),
    [anon_sym_u_DQUOTE] = ACTIONS(2438),
    [anon_sym_U_DQUOTE] = ACTIONS(2438),
    [anon_sym_u8_DQUOTE] = ACTIONS(2438),
    [anon_sym_DQUOTE] = ACTIONS(2438),
    [sym_true] = ACTIONS(2436),
    [sym_false] = ACTIONS(2436),
    [anon_sym_NULL] = ACTIONS(2436),
    [anon_sym_nullptr] = ACTIONS(2436),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2436),
    [anon_sym_decltype] = ACTIONS(2436),
    [sym_virtual] = ACTIONS(2436),
    [anon_sym_explicit] = ACTIONS(2436),
    [anon_sym_typename] = ACTIONS(2436),
    [anon_sym_template] = ACTIONS(2436),
    [anon_sym_operator] = ACTIONS(2436),
    [anon_sym_try] = ACTIONS(2436),
    [anon_sym_delete] = ACTIONS(2436),
    [anon_sym_throw] = ACTIONS(2436),
    [anon_sym_namespace] = ACTIONS(2436),
    [anon_sym_using] = ACTIONS(2436),
    [anon_sym_static_assert] = ACTIONS(2436),
    [anon_sym_concept] = ACTIONS(2436),
    [anon_sym_co_return] = ACTIONS(2436),
    [anon_sym_co_yield] = ACTIONS(2436),
    [anon_sym_R_DQUOTE] = ACTIONS(2438),
    [anon_sym_LR_DQUOTE] = ACTIONS(2438),
    [anon_sym_uR_DQUOTE] = ACTIONS(2438),
    [anon_sym_UR_DQUOTE] = ACTIONS(2438),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2438),
    [anon_sym_co_await] = ACTIONS(2436),
    [anon_sym_new] = ACTIONS(2436),
    [anon_sym_requires] = ACTIONS(2436),
    [sym_this] = ACTIONS(2436),
    [anon_sym_precise] = ACTIONS(2436),
    [anon_sym_shared] = ACTIONS(2436),
    [anon_sym_groupshared] = ACTIONS(2436),
    [anon_sym_uniform] = ACTIONS(2436),
    [anon_sym_row_major] = ACTIONS(2436),
    [anon_sym_column_major] = ACTIONS(2436),
    [anon_sym_globallycoherent] = ACTIONS(2436),
    [anon_sym_centroid] = ACTIONS(2436),
    [anon_sym_noperspective] = ACTIONS(2436),
    [anon_sym_nointerpolation] = ACTIONS(2436),
    [anon_sym_sample] = ACTIONS(2436),
    [anon_sym_linear] = ACTIONS(2436),
    [anon_sym_snorm] = ACTIONS(2436),
    [anon_sym_unorm] = ACTIONS(2436),
    [anon_sym_point] = ACTIONS(2436),
    [anon_sym_line] = ACTIONS(2436),
    [anon_sym_triangleadj] = ACTIONS(2436),
    [anon_sym_lineadj] = ACTIONS(2436),
    [anon_sym_triangle] = ACTIONS(2436),
  },
  [722] = {
    [ts_builtin_sym_end] = ACTIONS(2377),
    [sym_identifier] = ACTIONS(2375),
    [aux_sym_preproc_include_token1] = ACTIONS(2375),
    [aux_sym_preproc_def_token1] = ACTIONS(2375),
    [aux_sym_preproc_if_token1] = ACTIONS(2375),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2375),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2375),
    [sym_preproc_directive] = ACTIONS(2375),
    [anon_sym_LPAREN2] = ACTIONS(2377),
    [anon_sym_BANG] = ACTIONS(2377),
    [anon_sym_TILDE] = ACTIONS(2377),
    [anon_sym_DASH] = ACTIONS(2375),
    [anon_sym_PLUS] = ACTIONS(2375),
    [anon_sym_STAR] = ACTIONS(2377),
    [anon_sym_AMP_AMP] = ACTIONS(2377),
    [anon_sym_AMP] = ACTIONS(2375),
    [anon_sym___extension__] = ACTIONS(2375),
    [anon_sym_typedef] = ACTIONS(2375),
    [anon_sym_in] = ACTIONS(2375),
    [anon_sym_out] = ACTIONS(2375),
    [anon_sym_inout] = ACTIONS(2375),
    [anon_sym_extern] = ACTIONS(2375),
    [anon_sym___attribute__] = ACTIONS(2375),
    [anon_sym_COLON_COLON] = ACTIONS(2377),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2377),
    [anon_sym___declspec] = ACTIONS(2375),
    [anon_sym___based] = ACTIONS(2375),
    [anon_sym___cdecl] = ACTIONS(2375),
    [anon_sym___clrcall] = ACTIONS(2375),
    [anon_sym___stdcall] = ACTIONS(2375),
    [anon_sym___fastcall] = ACTIONS(2375),
    [anon_sym___thiscall] = ACTIONS(2375),
    [anon_sym___vectorcall] = ACTIONS(2375),
    [anon_sym_LBRACE] = ACTIONS(2377),
    [anon_sym_signed] = ACTIONS(2375),
    [anon_sym_unsigned] = ACTIONS(2375),
    [anon_sym_long] = ACTIONS(2375),
    [anon_sym_short] = ACTIONS(2375),
    [anon_sym_LBRACK] = ACTIONS(2375),
    [anon_sym_static] = ACTIONS(2375),
    [anon_sym_register] = ACTIONS(2375),
    [anon_sym_inline] = ACTIONS(2375),
    [anon_sym___inline] = ACTIONS(2375),
    [anon_sym___inline__] = ACTIONS(2375),
    [anon_sym___forceinline] = ACTIONS(2375),
    [anon_sym_thread_local] = ACTIONS(2375),
    [anon_sym___thread] = ACTIONS(2375),
    [anon_sym_const] = ACTIONS(2375),
    [anon_sym_constexpr] = ACTIONS(2375),
    [anon_sym_volatile] = ACTIONS(2375),
    [anon_sym_restrict] = ACTIONS(2375),
    [anon_sym___restrict__] = ACTIONS(2375),
    [anon_sym__Atomic] = ACTIONS(2375),
    [anon_sym__Noreturn] = ACTIONS(2375),
    [anon_sym_noreturn] = ACTIONS(2375),
    [anon_sym_mutable] = ACTIONS(2375),
    [anon_sym_constinit] = ACTIONS(2375),
    [anon_sym_consteval] = ACTIONS(2375),
    [anon_sym_alignas] = ACTIONS(2375),
    [anon_sym__Alignas] = ACTIONS(2375),
    [sym_primitive_type] = ACTIONS(2375),
    [anon_sym_enum] = ACTIONS(2375),
    [anon_sym_class] = ACTIONS(2375),
    [anon_sym_struct] = ACTIONS(2375),
    [anon_sym_union] = ACTIONS(2375),
    [anon_sym_if] = ACTIONS(2375),
    [anon_sym_switch] = ACTIONS(2375),
    [anon_sym_case] = ACTIONS(2375),
    [anon_sym_default] = ACTIONS(2375),
    [anon_sym_while] = ACTIONS(2375),
    [anon_sym_do] = ACTIONS(2375),
    [anon_sym_for] = ACTIONS(2375),
    [anon_sym_return] = ACTIONS(2375),
    [anon_sym_break] = ACTIONS(2375),
    [anon_sym_continue] = ACTIONS(2375),
    [anon_sym_goto] = ACTIONS(2375),
    [anon_sym_not] = ACTIONS(2375),
    [anon_sym_compl] = ACTIONS(2375),
    [anon_sym_DASH_DASH] = ACTIONS(2377),
    [anon_sym_PLUS_PLUS] = ACTIONS(2377),
    [anon_sym_sizeof] = ACTIONS(2375),
    [anon_sym___alignof__] = ACTIONS(2375),
    [anon_sym___alignof] = ACTIONS(2375),
    [anon_sym__alignof] = ACTIONS(2375),
    [anon_sym_alignof] = ACTIONS(2375),
    [anon_sym__Alignof] = ACTIONS(2375),
    [anon_sym_offsetof] = ACTIONS(2375),
    [anon_sym__Generic] = ACTIONS(2375),
    [anon_sym_asm] = ACTIONS(2375),
    [anon_sym___asm__] = ACTIONS(2375),
    [sym_number_literal] = ACTIONS(2377),
    [anon_sym_L_SQUOTE] = ACTIONS(2377),
    [anon_sym_u_SQUOTE] = ACTIONS(2377),
    [anon_sym_U_SQUOTE] = ACTIONS(2377),
    [anon_sym_u8_SQUOTE] = ACTIONS(2377),
    [anon_sym_SQUOTE] = ACTIONS(2377),
    [anon_sym_L_DQUOTE] = ACTIONS(2377),
    [anon_sym_u_DQUOTE] = ACTIONS(2377),
    [anon_sym_U_DQUOTE] = ACTIONS(2377),
    [anon_sym_u8_DQUOTE] = ACTIONS(2377),
    [anon_sym_DQUOTE] = ACTIONS(2377),
    [sym_true] = ACTIONS(2375),
    [sym_false] = ACTIONS(2375),
    [anon_sym_NULL] = ACTIONS(2375),
    [anon_sym_nullptr] = ACTIONS(2375),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2375),
    [anon_sym_decltype] = ACTIONS(2375),
    [sym_virtual] = ACTIONS(2375),
    [anon_sym_explicit] = ACTIONS(2375),
    [anon_sym_typename] = ACTIONS(2375),
    [anon_sym_template] = ACTIONS(2375),
    [anon_sym_operator] = ACTIONS(2375),
    [anon_sym_try] = ACTIONS(2375),
    [anon_sym_delete] = ACTIONS(2375),
    [anon_sym_throw] = ACTIONS(2375),
    [anon_sym_namespace] = ACTIONS(2375),
    [anon_sym_using] = ACTIONS(2375),
    [anon_sym_static_assert] = ACTIONS(2375),
    [anon_sym_concept] = ACTIONS(2375),
    [anon_sym_co_return] = ACTIONS(2375),
    [anon_sym_co_yield] = ACTIONS(2375),
    [anon_sym_R_DQUOTE] = ACTIONS(2377),
    [anon_sym_LR_DQUOTE] = ACTIONS(2377),
    [anon_sym_uR_DQUOTE] = ACTIONS(2377),
    [anon_sym_UR_DQUOTE] = ACTIONS(2377),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2377),
    [anon_sym_co_await] = ACTIONS(2375),
    [anon_sym_new] = ACTIONS(2375),
    [anon_sym_requires] = ACTIONS(2375),
    [sym_this] = ACTIONS(2375),
    [anon_sym_precise] = ACTIONS(2375),
    [anon_sym_shared] = ACTIONS(2375),
    [anon_sym_groupshared] = ACTIONS(2375),
    [anon_sym_uniform] = ACTIONS(2375),
    [anon_sym_row_major] = ACTIONS(2375),
    [anon_sym_column_major] = ACTIONS(2375),
    [anon_sym_globallycoherent] = ACTIONS(2375),
    [anon_sym_centroid] = ACTIONS(2375),
    [anon_sym_noperspective] = ACTIONS(2375),
    [anon_sym_nointerpolation] = ACTIONS(2375),
    [anon_sym_sample] = ACTIONS(2375),
    [anon_sym_linear] = ACTIONS(2375),
    [anon_sym_snorm] = ACTIONS(2375),
    [anon_sym_unorm] = ACTIONS(2375),
    [anon_sym_point] = ACTIONS(2375),
    [anon_sym_line] = ACTIONS(2375),
    [anon_sym_triangleadj] = ACTIONS(2375),
    [anon_sym_lineadj] = ACTIONS(2375),
    [anon_sym_triangle] = ACTIONS(2375),
  },
  [723] = {
    [ts_builtin_sym_end] = ACTIONS(2460),
    [sym_identifier] = ACTIONS(2458),
    [aux_sym_preproc_include_token1] = ACTIONS(2458),
    [aux_sym_preproc_def_token1] = ACTIONS(2458),
    [aux_sym_preproc_if_token1] = ACTIONS(2458),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2458),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2458),
    [sym_preproc_directive] = ACTIONS(2458),
    [anon_sym_LPAREN2] = ACTIONS(2460),
    [anon_sym_BANG] = ACTIONS(2460),
    [anon_sym_TILDE] = ACTIONS(2460),
    [anon_sym_DASH] = ACTIONS(2458),
    [anon_sym_PLUS] = ACTIONS(2458),
    [anon_sym_STAR] = ACTIONS(2460),
    [anon_sym_AMP_AMP] = ACTIONS(2460),
    [anon_sym_AMP] = ACTIONS(2458),
    [anon_sym___extension__] = ACTIONS(2458),
    [anon_sym_typedef] = ACTIONS(2458),
    [anon_sym_in] = ACTIONS(2458),
    [anon_sym_out] = ACTIONS(2458),
    [anon_sym_inout] = ACTIONS(2458),
    [anon_sym_extern] = ACTIONS(2458),
    [anon_sym___attribute__] = ACTIONS(2458),
    [anon_sym_COLON_COLON] = ACTIONS(2460),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2460),
    [anon_sym___declspec] = ACTIONS(2458),
    [anon_sym___based] = ACTIONS(2458),
    [anon_sym___cdecl] = ACTIONS(2458),
    [anon_sym___clrcall] = ACTIONS(2458),
    [anon_sym___stdcall] = ACTIONS(2458),
    [anon_sym___fastcall] = ACTIONS(2458),
    [anon_sym___thiscall] = ACTIONS(2458),
    [anon_sym___vectorcall] = ACTIONS(2458),
    [anon_sym_LBRACE] = ACTIONS(2460),
    [anon_sym_signed] = ACTIONS(2458),
    [anon_sym_unsigned] = ACTIONS(2458),
    [anon_sym_long] = ACTIONS(2458),
    [anon_sym_short] = ACTIONS(2458),
    [anon_sym_LBRACK] = ACTIONS(2458),
    [anon_sym_static] = ACTIONS(2458),
    [anon_sym_register] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(2458),
    [anon_sym___inline] = ACTIONS(2458),
    [anon_sym___inline__] = ACTIONS(2458),
    [anon_sym___forceinline] = ACTIONS(2458),
    [anon_sym_thread_local] = ACTIONS(2458),
    [anon_sym___thread] = ACTIONS(2458),
    [anon_sym_const] = ACTIONS(2458),
    [anon_sym_constexpr] = ACTIONS(2458),
    [anon_sym_volatile] = ACTIONS(2458),
    [anon_sym_restrict] = ACTIONS(2458),
    [anon_sym___restrict__] = ACTIONS(2458),
    [anon_sym__Atomic] = ACTIONS(2458),
    [anon_sym__Noreturn] = ACTIONS(2458),
    [anon_sym_noreturn] = ACTIONS(2458),
    [anon_sym_mutable] = ACTIONS(2458),
    [anon_sym_constinit] = ACTIONS(2458),
    [anon_sym_consteval] = ACTIONS(2458),
    [anon_sym_alignas] = ACTIONS(2458),
    [anon_sym__Alignas] = ACTIONS(2458),
    [sym_primitive_type] = ACTIONS(2458),
    [anon_sym_enum] = ACTIONS(2458),
    [anon_sym_class] = ACTIONS(2458),
    [anon_sym_struct] = ACTIONS(2458),
    [anon_sym_union] = ACTIONS(2458),
    [anon_sym_if] = ACTIONS(2458),
    [anon_sym_switch] = ACTIONS(2458),
    [anon_sym_case] = ACTIONS(2458),
    [anon_sym_default] = ACTIONS(2458),
    [anon_sym_while] = ACTIONS(2458),
    [anon_sym_do] = ACTIONS(2458),
    [anon_sym_for] = ACTIONS(2458),
    [anon_sym_return] = ACTIONS(2458),
    [anon_sym_break] = ACTIONS(2458),
    [anon_sym_continue] = ACTIONS(2458),
    [anon_sym_goto] = ACTIONS(2458),
    [anon_sym_not] = ACTIONS(2458),
    [anon_sym_compl] = ACTIONS(2458),
    [anon_sym_DASH_DASH] = ACTIONS(2460),
    [anon_sym_PLUS_PLUS] = ACTIONS(2460),
    [anon_sym_sizeof] = ACTIONS(2458),
    [anon_sym___alignof__] = ACTIONS(2458),
    [anon_sym___alignof] = ACTIONS(2458),
    [anon_sym__alignof] = ACTIONS(2458),
    [anon_sym_alignof] = ACTIONS(2458),
    [anon_sym__Alignof] = ACTIONS(2458),
    [anon_sym_offsetof] = ACTIONS(2458),
    [anon_sym__Generic] = ACTIONS(2458),
    [anon_sym_asm] = ACTIONS(2458),
    [anon_sym___asm__] = ACTIONS(2458),
    [sym_number_literal] = ACTIONS(2460),
    [anon_sym_L_SQUOTE] = ACTIONS(2460),
    [anon_sym_u_SQUOTE] = ACTIONS(2460),
    [anon_sym_U_SQUOTE] = ACTIONS(2460),
    [anon_sym_u8_SQUOTE] = ACTIONS(2460),
    [anon_sym_SQUOTE] = ACTIONS(2460),
    [anon_sym_L_DQUOTE] = ACTIONS(2460),
    [anon_sym_u_DQUOTE] = ACTIONS(2460),
    [anon_sym_U_DQUOTE] = ACTIONS(2460),
    [anon_sym_u8_DQUOTE] = ACTIONS(2460),
    [anon_sym_DQUOTE] = ACTIONS(2460),
    [sym_true] = ACTIONS(2458),
    [sym_false] = ACTIONS(2458),
    [anon_sym_NULL] = ACTIONS(2458),
    [anon_sym_nullptr] = ACTIONS(2458),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2458),
    [anon_sym_decltype] = ACTIONS(2458),
    [sym_virtual] = ACTIONS(2458),
    [anon_sym_explicit] = ACTIONS(2458),
    [anon_sym_typename] = ACTIONS(2458),
    [anon_sym_template] = ACTIONS(2458),
    [anon_sym_operator] = ACTIONS(2458),
    [anon_sym_try] = ACTIONS(2458),
    [anon_sym_delete] = ACTIONS(2458),
    [anon_sym_throw] = ACTIONS(2458),
    [anon_sym_namespace] = ACTIONS(2458),
    [anon_sym_using] = ACTIONS(2458),
    [anon_sym_static_assert] = ACTIONS(2458),
    [anon_sym_concept] = ACTIONS(2458),
    [anon_sym_co_return] = ACTIONS(2458),
    [anon_sym_co_yield] = ACTIONS(2458),
    [anon_sym_R_DQUOTE] = ACTIONS(2460),
    [anon_sym_LR_DQUOTE] = ACTIONS(2460),
    [anon_sym_uR_DQUOTE] = ACTIONS(2460),
    [anon_sym_UR_DQUOTE] = ACTIONS(2460),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2460),
    [anon_sym_co_await] = ACTIONS(2458),
    [anon_sym_new] = ACTIONS(2458),
    [anon_sym_requires] = ACTIONS(2458),
    [sym_this] = ACTIONS(2458),
    [anon_sym_precise] = ACTIONS(2458),
    [anon_sym_shared] = ACTIONS(2458),
    [anon_sym_groupshared] = ACTIONS(2458),
    [anon_sym_uniform] = ACTIONS(2458),
    [anon_sym_row_major] = ACTIONS(2458),
    [anon_sym_column_major] = ACTIONS(2458),
    [anon_sym_globallycoherent] = ACTIONS(2458),
    [anon_sym_centroid] = ACTIONS(2458),
    [anon_sym_noperspective] = ACTIONS(2458),
    [anon_sym_nointerpolation] = ACTIONS(2458),
    [anon_sym_sample] = ACTIONS(2458),
    [anon_sym_linear] = ACTIONS(2458),
    [anon_sym_snorm] = ACTIONS(2458),
    [anon_sym_unorm] = ACTIONS(2458),
    [anon_sym_point] = ACTIONS(2458),
    [anon_sym_line] = ACTIONS(2458),
    [anon_sym_triangleadj] = ACTIONS(2458),
    [anon_sym_lineadj] = ACTIONS(2458),
    [anon_sym_triangle] = ACTIONS(2458),
  },
  [724] = {
    [ts_builtin_sym_end] = ACTIONS(2381),
    [sym_identifier] = ACTIONS(2379),
    [aux_sym_preproc_include_token1] = ACTIONS(2379),
    [aux_sym_preproc_def_token1] = ACTIONS(2379),
    [aux_sym_preproc_if_token1] = ACTIONS(2379),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2379),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2379),
    [sym_preproc_directive] = ACTIONS(2379),
    [anon_sym_LPAREN2] = ACTIONS(2381),
    [anon_sym_BANG] = ACTIONS(2381),
    [anon_sym_TILDE] = ACTIONS(2381),
    [anon_sym_DASH] = ACTIONS(2379),
    [anon_sym_PLUS] = ACTIONS(2379),
    [anon_sym_STAR] = ACTIONS(2381),
    [anon_sym_AMP_AMP] = ACTIONS(2381),
    [anon_sym_AMP] = ACTIONS(2379),
    [anon_sym___extension__] = ACTIONS(2379),
    [anon_sym_typedef] = ACTIONS(2379),
    [anon_sym_in] = ACTIONS(2379),
    [anon_sym_out] = ACTIONS(2379),
    [anon_sym_inout] = ACTIONS(2379),
    [anon_sym_extern] = ACTIONS(2379),
    [anon_sym___attribute__] = ACTIONS(2379),
    [anon_sym_COLON_COLON] = ACTIONS(2381),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2381),
    [anon_sym___declspec] = ACTIONS(2379),
    [anon_sym___based] = ACTIONS(2379),
    [anon_sym___cdecl] = ACTIONS(2379),
    [anon_sym___clrcall] = ACTIONS(2379),
    [anon_sym___stdcall] = ACTIONS(2379),
    [anon_sym___fastcall] = ACTIONS(2379),
    [anon_sym___thiscall] = ACTIONS(2379),
    [anon_sym___vectorcall] = ACTIONS(2379),
    [anon_sym_LBRACE] = ACTIONS(2381),
    [anon_sym_signed] = ACTIONS(2379),
    [anon_sym_unsigned] = ACTIONS(2379),
    [anon_sym_long] = ACTIONS(2379),
    [anon_sym_short] = ACTIONS(2379),
    [anon_sym_LBRACK] = ACTIONS(2379),
    [anon_sym_static] = ACTIONS(2379),
    [anon_sym_register] = ACTIONS(2379),
    [anon_sym_inline] = ACTIONS(2379),
    [anon_sym___inline] = ACTIONS(2379),
    [anon_sym___inline__] = ACTIONS(2379),
    [anon_sym___forceinline] = ACTIONS(2379),
    [anon_sym_thread_local] = ACTIONS(2379),
    [anon_sym___thread] = ACTIONS(2379),
    [anon_sym_const] = ACTIONS(2379),
    [anon_sym_constexpr] = ACTIONS(2379),
    [anon_sym_volatile] = ACTIONS(2379),
    [anon_sym_restrict] = ACTIONS(2379),
    [anon_sym___restrict__] = ACTIONS(2379),
    [anon_sym__Atomic] = ACTIONS(2379),
    [anon_sym__Noreturn] = ACTIONS(2379),
    [anon_sym_noreturn] = ACTIONS(2379),
    [anon_sym_mutable] = ACTIONS(2379),
    [anon_sym_constinit] = ACTIONS(2379),
    [anon_sym_consteval] = ACTIONS(2379),
    [anon_sym_alignas] = ACTIONS(2379),
    [anon_sym__Alignas] = ACTIONS(2379),
    [sym_primitive_type] = ACTIONS(2379),
    [anon_sym_enum] = ACTIONS(2379),
    [anon_sym_class] = ACTIONS(2379),
    [anon_sym_struct] = ACTIONS(2379),
    [anon_sym_union] = ACTIONS(2379),
    [anon_sym_if] = ACTIONS(2379),
    [anon_sym_switch] = ACTIONS(2379),
    [anon_sym_case] = ACTIONS(2379),
    [anon_sym_default] = ACTIONS(2379),
    [anon_sym_while] = ACTIONS(2379),
    [anon_sym_do] = ACTIONS(2379),
    [anon_sym_for] = ACTIONS(2379),
    [anon_sym_return] = ACTIONS(2379),
    [anon_sym_break] = ACTIONS(2379),
    [anon_sym_continue] = ACTIONS(2379),
    [anon_sym_goto] = ACTIONS(2379),
    [anon_sym_not] = ACTIONS(2379),
    [anon_sym_compl] = ACTIONS(2379),
    [anon_sym_DASH_DASH] = ACTIONS(2381),
    [anon_sym_PLUS_PLUS] = ACTIONS(2381),
    [anon_sym_sizeof] = ACTIONS(2379),
    [anon_sym___alignof__] = ACTIONS(2379),
    [anon_sym___alignof] = ACTIONS(2379),
    [anon_sym__alignof] = ACTIONS(2379),
    [anon_sym_alignof] = ACTIONS(2379),
    [anon_sym__Alignof] = ACTIONS(2379),
    [anon_sym_offsetof] = ACTIONS(2379),
    [anon_sym__Generic] = ACTIONS(2379),
    [anon_sym_asm] = ACTIONS(2379),
    [anon_sym___asm__] = ACTIONS(2379),
    [sym_number_literal] = ACTIONS(2381),
    [anon_sym_L_SQUOTE] = ACTIONS(2381),
    [anon_sym_u_SQUOTE] = ACTIONS(2381),
    [anon_sym_U_SQUOTE] = ACTIONS(2381),
    [anon_sym_u8_SQUOTE] = ACTIONS(2381),
    [anon_sym_SQUOTE] = ACTIONS(2381),
    [anon_sym_L_DQUOTE] = ACTIONS(2381),
    [anon_sym_u_DQUOTE] = ACTIONS(2381),
    [anon_sym_U_DQUOTE] = ACTIONS(2381),
    [anon_sym_u8_DQUOTE] = ACTIONS(2381),
    [anon_sym_DQUOTE] = ACTIONS(2381),
    [sym_true] = ACTIONS(2379),
    [sym_false] = ACTIONS(2379),
    [anon_sym_NULL] = ACTIONS(2379),
    [anon_sym_nullptr] = ACTIONS(2379),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2379),
    [anon_sym_decltype] = ACTIONS(2379),
    [sym_virtual] = ACTIONS(2379),
    [anon_sym_explicit] = ACTIONS(2379),
    [anon_sym_typename] = ACTIONS(2379),
    [anon_sym_template] = ACTIONS(2379),
    [anon_sym_operator] = ACTIONS(2379),
    [anon_sym_try] = ACTIONS(2379),
    [anon_sym_delete] = ACTIONS(2379),
    [anon_sym_throw] = ACTIONS(2379),
    [anon_sym_namespace] = ACTIONS(2379),
    [anon_sym_using] = ACTIONS(2379),
    [anon_sym_static_assert] = ACTIONS(2379),
    [anon_sym_concept] = ACTIONS(2379),
    [anon_sym_co_return] = ACTIONS(2379),
    [anon_sym_co_yield] = ACTIONS(2379),
    [anon_sym_R_DQUOTE] = ACTIONS(2381),
    [anon_sym_LR_DQUOTE] = ACTIONS(2381),
    [anon_sym_uR_DQUOTE] = ACTIONS(2381),
    [anon_sym_UR_DQUOTE] = ACTIONS(2381),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2381),
    [anon_sym_co_await] = ACTIONS(2379),
    [anon_sym_new] = ACTIONS(2379),
    [anon_sym_requires] = ACTIONS(2379),
    [sym_this] = ACTIONS(2379),
    [anon_sym_precise] = ACTIONS(2379),
    [anon_sym_shared] = ACTIONS(2379),
    [anon_sym_groupshared] = ACTIONS(2379),
    [anon_sym_uniform] = ACTIONS(2379),
    [anon_sym_row_major] = ACTIONS(2379),
    [anon_sym_column_major] = ACTIONS(2379),
    [anon_sym_globallycoherent] = ACTIONS(2379),
    [anon_sym_centroid] = ACTIONS(2379),
    [anon_sym_noperspective] = ACTIONS(2379),
    [anon_sym_nointerpolation] = ACTIONS(2379),
    [anon_sym_sample] = ACTIONS(2379),
    [anon_sym_linear] = ACTIONS(2379),
    [anon_sym_snorm] = ACTIONS(2379),
    [anon_sym_unorm] = ACTIONS(2379),
    [anon_sym_point] = ACTIONS(2379),
    [anon_sym_line] = ACTIONS(2379),
    [anon_sym_triangleadj] = ACTIONS(2379),
    [anon_sym_lineadj] = ACTIONS(2379),
    [anon_sym_triangle] = ACTIONS(2379),
  },
  [725] = {
    [ts_builtin_sym_end] = ACTIONS(2496),
    [sym_identifier] = ACTIONS(2494),
    [aux_sym_preproc_include_token1] = ACTIONS(2494),
    [aux_sym_preproc_def_token1] = ACTIONS(2494),
    [aux_sym_preproc_if_token1] = ACTIONS(2494),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2494),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2494),
    [sym_preproc_directive] = ACTIONS(2494),
    [anon_sym_LPAREN2] = ACTIONS(2496),
    [anon_sym_BANG] = ACTIONS(2496),
    [anon_sym_TILDE] = ACTIONS(2496),
    [anon_sym_DASH] = ACTIONS(2494),
    [anon_sym_PLUS] = ACTIONS(2494),
    [anon_sym_STAR] = ACTIONS(2496),
    [anon_sym_AMP_AMP] = ACTIONS(2496),
    [anon_sym_AMP] = ACTIONS(2494),
    [anon_sym___extension__] = ACTIONS(2494),
    [anon_sym_typedef] = ACTIONS(2494),
    [anon_sym_in] = ACTIONS(2494),
    [anon_sym_out] = ACTIONS(2494),
    [anon_sym_inout] = ACTIONS(2494),
    [anon_sym_extern] = ACTIONS(2494),
    [anon_sym___attribute__] = ACTIONS(2494),
    [anon_sym_COLON_COLON] = ACTIONS(2496),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2496),
    [anon_sym___declspec] = ACTIONS(2494),
    [anon_sym___based] = ACTIONS(2494),
    [anon_sym___cdecl] = ACTIONS(2494),
    [anon_sym___clrcall] = ACTIONS(2494),
    [anon_sym___stdcall] = ACTIONS(2494),
    [anon_sym___fastcall] = ACTIONS(2494),
    [anon_sym___thiscall] = ACTIONS(2494),
    [anon_sym___vectorcall] = ACTIONS(2494),
    [anon_sym_LBRACE] = ACTIONS(2496),
    [anon_sym_signed] = ACTIONS(2494),
    [anon_sym_unsigned] = ACTIONS(2494),
    [anon_sym_long] = ACTIONS(2494),
    [anon_sym_short] = ACTIONS(2494),
    [anon_sym_LBRACK] = ACTIONS(2494),
    [anon_sym_static] = ACTIONS(2494),
    [anon_sym_register] = ACTIONS(2494),
    [anon_sym_inline] = ACTIONS(2494),
    [anon_sym___inline] = ACTIONS(2494),
    [anon_sym___inline__] = ACTIONS(2494),
    [anon_sym___forceinline] = ACTIONS(2494),
    [anon_sym_thread_local] = ACTIONS(2494),
    [anon_sym___thread] = ACTIONS(2494),
    [anon_sym_const] = ACTIONS(2494),
    [anon_sym_constexpr] = ACTIONS(2494),
    [anon_sym_volatile] = ACTIONS(2494),
    [anon_sym_restrict] = ACTIONS(2494),
    [anon_sym___restrict__] = ACTIONS(2494),
    [anon_sym__Atomic] = ACTIONS(2494),
    [anon_sym__Noreturn] = ACTIONS(2494),
    [anon_sym_noreturn] = ACTIONS(2494),
    [anon_sym_mutable] = ACTIONS(2494),
    [anon_sym_constinit] = ACTIONS(2494),
    [anon_sym_consteval] = ACTIONS(2494),
    [anon_sym_alignas] = ACTIONS(2494),
    [anon_sym__Alignas] = ACTIONS(2494),
    [sym_primitive_type] = ACTIONS(2494),
    [anon_sym_enum] = ACTIONS(2494),
    [anon_sym_class] = ACTIONS(2494),
    [anon_sym_struct] = ACTIONS(2494),
    [anon_sym_union] = ACTIONS(2494),
    [anon_sym_if] = ACTIONS(2494),
    [anon_sym_switch] = ACTIONS(2494),
    [anon_sym_case] = ACTIONS(2494),
    [anon_sym_default] = ACTIONS(2494),
    [anon_sym_while] = ACTIONS(2494),
    [anon_sym_do] = ACTIONS(2494),
    [anon_sym_for] = ACTIONS(2494),
    [anon_sym_return] = ACTIONS(2494),
    [anon_sym_break] = ACTIONS(2494),
    [anon_sym_continue] = ACTIONS(2494),
    [anon_sym_goto] = ACTIONS(2494),
    [anon_sym_not] = ACTIONS(2494),
    [anon_sym_compl] = ACTIONS(2494),
    [anon_sym_DASH_DASH] = ACTIONS(2496),
    [anon_sym_PLUS_PLUS] = ACTIONS(2496),
    [anon_sym_sizeof] = ACTIONS(2494),
    [anon_sym___alignof__] = ACTIONS(2494),
    [anon_sym___alignof] = ACTIONS(2494),
    [anon_sym__alignof] = ACTIONS(2494),
    [anon_sym_alignof] = ACTIONS(2494),
    [anon_sym__Alignof] = ACTIONS(2494),
    [anon_sym_offsetof] = ACTIONS(2494),
    [anon_sym__Generic] = ACTIONS(2494),
    [anon_sym_asm] = ACTIONS(2494),
    [anon_sym___asm__] = ACTIONS(2494),
    [sym_number_literal] = ACTIONS(2496),
    [anon_sym_L_SQUOTE] = ACTIONS(2496),
    [anon_sym_u_SQUOTE] = ACTIONS(2496),
    [anon_sym_U_SQUOTE] = ACTIONS(2496),
    [anon_sym_u8_SQUOTE] = ACTIONS(2496),
    [anon_sym_SQUOTE] = ACTIONS(2496),
    [anon_sym_L_DQUOTE] = ACTIONS(2496),
    [anon_sym_u_DQUOTE] = ACTIONS(2496),
    [anon_sym_U_DQUOTE] = ACTIONS(2496),
    [anon_sym_u8_DQUOTE] = ACTIONS(2496),
    [anon_sym_DQUOTE] = ACTIONS(2496),
    [sym_true] = ACTIONS(2494),
    [sym_false] = ACTIONS(2494),
    [anon_sym_NULL] = ACTIONS(2494),
    [anon_sym_nullptr] = ACTIONS(2494),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2494),
    [anon_sym_decltype] = ACTIONS(2494),
    [sym_virtual] = ACTIONS(2494),
    [anon_sym_explicit] = ACTIONS(2494),
    [anon_sym_typename] = ACTIONS(2494),
    [anon_sym_template] = ACTIONS(2494),
    [anon_sym_operator] = ACTIONS(2494),
    [anon_sym_try] = ACTIONS(2494),
    [anon_sym_delete] = ACTIONS(2494),
    [anon_sym_throw] = ACTIONS(2494),
    [anon_sym_namespace] = ACTIONS(2494),
    [anon_sym_using] = ACTIONS(2494),
    [anon_sym_static_assert] = ACTIONS(2494),
    [anon_sym_concept] = ACTIONS(2494),
    [anon_sym_co_return] = ACTIONS(2494),
    [anon_sym_co_yield] = ACTIONS(2494),
    [anon_sym_R_DQUOTE] = ACTIONS(2496),
    [anon_sym_LR_DQUOTE] = ACTIONS(2496),
    [anon_sym_uR_DQUOTE] = ACTIONS(2496),
    [anon_sym_UR_DQUOTE] = ACTIONS(2496),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2496),
    [anon_sym_co_await] = ACTIONS(2494),
    [anon_sym_new] = ACTIONS(2494),
    [anon_sym_requires] = ACTIONS(2494),
    [sym_this] = ACTIONS(2494),
    [anon_sym_precise] = ACTIONS(2494),
    [anon_sym_shared] = ACTIONS(2494),
    [anon_sym_groupshared] = ACTIONS(2494),
    [anon_sym_uniform] = ACTIONS(2494),
    [anon_sym_row_major] = ACTIONS(2494),
    [anon_sym_column_major] = ACTIONS(2494),
    [anon_sym_globallycoherent] = ACTIONS(2494),
    [anon_sym_centroid] = ACTIONS(2494),
    [anon_sym_noperspective] = ACTIONS(2494),
    [anon_sym_nointerpolation] = ACTIONS(2494),
    [anon_sym_sample] = ACTIONS(2494),
    [anon_sym_linear] = ACTIONS(2494),
    [anon_sym_snorm] = ACTIONS(2494),
    [anon_sym_unorm] = ACTIONS(2494),
    [anon_sym_point] = ACTIONS(2494),
    [anon_sym_line] = ACTIONS(2494),
    [anon_sym_triangleadj] = ACTIONS(2494),
    [anon_sym_lineadj] = ACTIONS(2494),
    [anon_sym_triangle] = ACTIONS(2494),
  },
  [726] = {
    [ts_builtin_sym_end] = ACTIONS(2472),
    [sym_identifier] = ACTIONS(2470),
    [aux_sym_preproc_include_token1] = ACTIONS(2470),
    [aux_sym_preproc_def_token1] = ACTIONS(2470),
    [aux_sym_preproc_if_token1] = ACTIONS(2470),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2470),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2470),
    [sym_preproc_directive] = ACTIONS(2470),
    [anon_sym_LPAREN2] = ACTIONS(2472),
    [anon_sym_BANG] = ACTIONS(2472),
    [anon_sym_TILDE] = ACTIONS(2472),
    [anon_sym_DASH] = ACTIONS(2470),
    [anon_sym_PLUS] = ACTIONS(2470),
    [anon_sym_STAR] = ACTIONS(2472),
    [anon_sym_AMP_AMP] = ACTIONS(2472),
    [anon_sym_AMP] = ACTIONS(2470),
    [anon_sym___extension__] = ACTIONS(2470),
    [anon_sym_typedef] = ACTIONS(2470),
    [anon_sym_in] = ACTIONS(2470),
    [anon_sym_out] = ACTIONS(2470),
    [anon_sym_inout] = ACTIONS(2470),
    [anon_sym_extern] = ACTIONS(2470),
    [anon_sym___attribute__] = ACTIONS(2470),
    [anon_sym_COLON_COLON] = ACTIONS(2472),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2472),
    [anon_sym___declspec] = ACTIONS(2470),
    [anon_sym___based] = ACTIONS(2470),
    [anon_sym___cdecl] = ACTIONS(2470),
    [anon_sym___clrcall] = ACTIONS(2470),
    [anon_sym___stdcall] = ACTIONS(2470),
    [anon_sym___fastcall] = ACTIONS(2470),
    [anon_sym___thiscall] = ACTIONS(2470),
    [anon_sym___vectorcall] = ACTIONS(2470),
    [anon_sym_LBRACE] = ACTIONS(2472),
    [anon_sym_signed] = ACTIONS(2470),
    [anon_sym_unsigned] = ACTIONS(2470),
    [anon_sym_long] = ACTIONS(2470),
    [anon_sym_short] = ACTIONS(2470),
    [anon_sym_LBRACK] = ACTIONS(2470),
    [anon_sym_static] = ACTIONS(2470),
    [anon_sym_register] = ACTIONS(2470),
    [anon_sym_inline] = ACTIONS(2470),
    [anon_sym___inline] = ACTIONS(2470),
    [anon_sym___inline__] = ACTIONS(2470),
    [anon_sym___forceinline] = ACTIONS(2470),
    [anon_sym_thread_local] = ACTIONS(2470),
    [anon_sym___thread] = ACTIONS(2470),
    [anon_sym_const] = ACTIONS(2470),
    [anon_sym_constexpr] = ACTIONS(2470),
    [anon_sym_volatile] = ACTIONS(2470),
    [anon_sym_restrict] = ACTIONS(2470),
    [anon_sym___restrict__] = ACTIONS(2470),
    [anon_sym__Atomic] = ACTIONS(2470),
    [anon_sym__Noreturn] = ACTIONS(2470),
    [anon_sym_noreturn] = ACTIONS(2470),
    [anon_sym_mutable] = ACTIONS(2470),
    [anon_sym_constinit] = ACTIONS(2470),
    [anon_sym_consteval] = ACTIONS(2470),
    [anon_sym_alignas] = ACTIONS(2470),
    [anon_sym__Alignas] = ACTIONS(2470),
    [sym_primitive_type] = ACTIONS(2470),
    [anon_sym_enum] = ACTIONS(2470),
    [anon_sym_class] = ACTIONS(2470),
    [anon_sym_struct] = ACTIONS(2470),
    [anon_sym_union] = ACTIONS(2470),
    [anon_sym_if] = ACTIONS(2470),
    [anon_sym_switch] = ACTIONS(2470),
    [anon_sym_case] = ACTIONS(2470),
    [anon_sym_default] = ACTIONS(2470),
    [anon_sym_while] = ACTIONS(2470),
    [anon_sym_do] = ACTIONS(2470),
    [anon_sym_for] = ACTIONS(2470),
    [anon_sym_return] = ACTIONS(2470),
    [anon_sym_break] = ACTIONS(2470),
    [anon_sym_continue] = ACTIONS(2470),
    [anon_sym_goto] = ACTIONS(2470),
    [anon_sym_not] = ACTIONS(2470),
    [anon_sym_compl] = ACTIONS(2470),
    [anon_sym_DASH_DASH] = ACTIONS(2472),
    [anon_sym_PLUS_PLUS] = ACTIONS(2472),
    [anon_sym_sizeof] = ACTIONS(2470),
    [anon_sym___alignof__] = ACTIONS(2470),
    [anon_sym___alignof] = ACTIONS(2470),
    [anon_sym__alignof] = ACTIONS(2470),
    [anon_sym_alignof] = ACTIONS(2470),
    [anon_sym__Alignof] = ACTIONS(2470),
    [anon_sym_offsetof] = ACTIONS(2470),
    [anon_sym__Generic] = ACTIONS(2470),
    [anon_sym_asm] = ACTIONS(2470),
    [anon_sym___asm__] = ACTIONS(2470),
    [sym_number_literal] = ACTIONS(2472),
    [anon_sym_L_SQUOTE] = ACTIONS(2472),
    [anon_sym_u_SQUOTE] = ACTIONS(2472),
    [anon_sym_U_SQUOTE] = ACTIONS(2472),
    [anon_sym_u8_SQUOTE] = ACTIONS(2472),
    [anon_sym_SQUOTE] = ACTIONS(2472),
    [anon_sym_L_DQUOTE] = ACTIONS(2472),
    [anon_sym_u_DQUOTE] = ACTIONS(2472),
    [anon_sym_U_DQUOTE] = ACTIONS(2472),
    [anon_sym_u8_DQUOTE] = ACTIONS(2472),
    [anon_sym_DQUOTE] = ACTIONS(2472),
    [sym_true] = ACTIONS(2470),
    [sym_false] = ACTIONS(2470),
    [anon_sym_NULL] = ACTIONS(2470),
    [anon_sym_nullptr] = ACTIONS(2470),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2470),
    [anon_sym_decltype] = ACTIONS(2470),
    [sym_virtual] = ACTIONS(2470),
    [anon_sym_explicit] = ACTIONS(2470),
    [anon_sym_typename] = ACTIONS(2470),
    [anon_sym_template] = ACTIONS(2470),
    [anon_sym_operator] = ACTIONS(2470),
    [anon_sym_try] = ACTIONS(2470),
    [anon_sym_delete] = ACTIONS(2470),
    [anon_sym_throw] = ACTIONS(2470),
    [anon_sym_namespace] = ACTIONS(2470),
    [anon_sym_using] = ACTIONS(2470),
    [anon_sym_static_assert] = ACTIONS(2470),
    [anon_sym_concept] = ACTIONS(2470),
    [anon_sym_co_return] = ACTIONS(2470),
    [anon_sym_co_yield] = ACTIONS(2470),
    [anon_sym_R_DQUOTE] = ACTIONS(2472),
    [anon_sym_LR_DQUOTE] = ACTIONS(2472),
    [anon_sym_uR_DQUOTE] = ACTIONS(2472),
    [anon_sym_UR_DQUOTE] = ACTIONS(2472),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2472),
    [anon_sym_co_await] = ACTIONS(2470),
    [anon_sym_new] = ACTIONS(2470),
    [anon_sym_requires] = ACTIONS(2470),
    [sym_this] = ACTIONS(2470),
    [anon_sym_precise] = ACTIONS(2470),
    [anon_sym_shared] = ACTIONS(2470),
    [anon_sym_groupshared] = ACTIONS(2470),
    [anon_sym_uniform] = ACTIONS(2470),
    [anon_sym_row_major] = ACTIONS(2470),
    [anon_sym_column_major] = ACTIONS(2470),
    [anon_sym_globallycoherent] = ACTIONS(2470),
    [anon_sym_centroid] = ACTIONS(2470),
    [anon_sym_noperspective] = ACTIONS(2470),
    [anon_sym_nointerpolation] = ACTIONS(2470),
    [anon_sym_sample] = ACTIONS(2470),
    [anon_sym_linear] = ACTIONS(2470),
    [anon_sym_snorm] = ACTIONS(2470),
    [anon_sym_unorm] = ACTIONS(2470),
    [anon_sym_point] = ACTIONS(2470),
    [anon_sym_line] = ACTIONS(2470),
    [anon_sym_triangleadj] = ACTIONS(2470),
    [anon_sym_lineadj] = ACTIONS(2470),
    [anon_sym_triangle] = ACTIONS(2470),
  },
  [727] = {
    [sym_preproc_def] = STATE(735),
    [sym_preproc_function_def] = STATE(735),
    [sym_preproc_call] = STATE(735),
    [sym_preproc_if_in_field_declaration_list] = STATE(735),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(735),
    [sym_type_definition] = STATE(735),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(735),
    [sym_field_declaration] = STATE(735),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(735),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(735),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(735),
    [sym_operator_cast_declaration] = STATE(735),
    [sym_constructor_or_destructor_definition] = STATE(735),
    [sym_constructor_or_destructor_declaration] = STATE(735),
    [sym_friend_declaration] = STATE(735),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(735),
    [sym_alias_declaration] = STATE(735),
    [sym_static_assert_declaration] = STATE(735),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(735),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2885),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [728] = {
    [ts_builtin_sym_end] = ACTIONS(2492),
    [sym_identifier] = ACTIONS(2490),
    [aux_sym_preproc_include_token1] = ACTIONS(2490),
    [aux_sym_preproc_def_token1] = ACTIONS(2490),
    [aux_sym_preproc_if_token1] = ACTIONS(2490),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2490),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2490),
    [sym_preproc_directive] = ACTIONS(2490),
    [anon_sym_LPAREN2] = ACTIONS(2492),
    [anon_sym_BANG] = ACTIONS(2492),
    [anon_sym_TILDE] = ACTIONS(2492),
    [anon_sym_DASH] = ACTIONS(2490),
    [anon_sym_PLUS] = ACTIONS(2490),
    [anon_sym_STAR] = ACTIONS(2492),
    [anon_sym_AMP_AMP] = ACTIONS(2492),
    [anon_sym_AMP] = ACTIONS(2490),
    [anon_sym___extension__] = ACTIONS(2490),
    [anon_sym_typedef] = ACTIONS(2490),
    [anon_sym_in] = ACTIONS(2490),
    [anon_sym_out] = ACTIONS(2490),
    [anon_sym_inout] = ACTIONS(2490),
    [anon_sym_extern] = ACTIONS(2490),
    [anon_sym___attribute__] = ACTIONS(2490),
    [anon_sym_COLON_COLON] = ACTIONS(2492),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2492),
    [anon_sym___declspec] = ACTIONS(2490),
    [anon_sym___based] = ACTIONS(2490),
    [anon_sym___cdecl] = ACTIONS(2490),
    [anon_sym___clrcall] = ACTIONS(2490),
    [anon_sym___stdcall] = ACTIONS(2490),
    [anon_sym___fastcall] = ACTIONS(2490),
    [anon_sym___thiscall] = ACTIONS(2490),
    [anon_sym___vectorcall] = ACTIONS(2490),
    [anon_sym_LBRACE] = ACTIONS(2492),
    [anon_sym_signed] = ACTIONS(2490),
    [anon_sym_unsigned] = ACTIONS(2490),
    [anon_sym_long] = ACTIONS(2490),
    [anon_sym_short] = ACTIONS(2490),
    [anon_sym_LBRACK] = ACTIONS(2490),
    [anon_sym_static] = ACTIONS(2490),
    [anon_sym_register] = ACTIONS(2490),
    [anon_sym_inline] = ACTIONS(2490),
    [anon_sym___inline] = ACTIONS(2490),
    [anon_sym___inline__] = ACTIONS(2490),
    [anon_sym___forceinline] = ACTIONS(2490),
    [anon_sym_thread_local] = ACTIONS(2490),
    [anon_sym___thread] = ACTIONS(2490),
    [anon_sym_const] = ACTIONS(2490),
    [anon_sym_constexpr] = ACTIONS(2490),
    [anon_sym_volatile] = ACTIONS(2490),
    [anon_sym_restrict] = ACTIONS(2490),
    [anon_sym___restrict__] = ACTIONS(2490),
    [anon_sym__Atomic] = ACTIONS(2490),
    [anon_sym__Noreturn] = ACTIONS(2490),
    [anon_sym_noreturn] = ACTIONS(2490),
    [anon_sym_mutable] = ACTIONS(2490),
    [anon_sym_constinit] = ACTIONS(2490),
    [anon_sym_consteval] = ACTIONS(2490),
    [anon_sym_alignas] = ACTIONS(2490),
    [anon_sym__Alignas] = ACTIONS(2490),
    [sym_primitive_type] = ACTIONS(2490),
    [anon_sym_enum] = ACTIONS(2490),
    [anon_sym_class] = ACTIONS(2490),
    [anon_sym_struct] = ACTIONS(2490),
    [anon_sym_union] = ACTIONS(2490),
    [anon_sym_if] = ACTIONS(2490),
    [anon_sym_switch] = ACTIONS(2490),
    [anon_sym_case] = ACTIONS(2490),
    [anon_sym_default] = ACTIONS(2490),
    [anon_sym_while] = ACTIONS(2490),
    [anon_sym_do] = ACTIONS(2490),
    [anon_sym_for] = ACTIONS(2490),
    [anon_sym_return] = ACTIONS(2490),
    [anon_sym_break] = ACTIONS(2490),
    [anon_sym_continue] = ACTIONS(2490),
    [anon_sym_goto] = ACTIONS(2490),
    [anon_sym_not] = ACTIONS(2490),
    [anon_sym_compl] = ACTIONS(2490),
    [anon_sym_DASH_DASH] = ACTIONS(2492),
    [anon_sym_PLUS_PLUS] = ACTIONS(2492),
    [anon_sym_sizeof] = ACTIONS(2490),
    [anon_sym___alignof__] = ACTIONS(2490),
    [anon_sym___alignof] = ACTIONS(2490),
    [anon_sym__alignof] = ACTIONS(2490),
    [anon_sym_alignof] = ACTIONS(2490),
    [anon_sym__Alignof] = ACTIONS(2490),
    [anon_sym_offsetof] = ACTIONS(2490),
    [anon_sym__Generic] = ACTIONS(2490),
    [anon_sym_asm] = ACTIONS(2490),
    [anon_sym___asm__] = ACTIONS(2490),
    [sym_number_literal] = ACTIONS(2492),
    [anon_sym_L_SQUOTE] = ACTIONS(2492),
    [anon_sym_u_SQUOTE] = ACTIONS(2492),
    [anon_sym_U_SQUOTE] = ACTIONS(2492),
    [anon_sym_u8_SQUOTE] = ACTIONS(2492),
    [anon_sym_SQUOTE] = ACTIONS(2492),
    [anon_sym_L_DQUOTE] = ACTIONS(2492),
    [anon_sym_u_DQUOTE] = ACTIONS(2492),
    [anon_sym_U_DQUOTE] = ACTIONS(2492),
    [anon_sym_u8_DQUOTE] = ACTIONS(2492),
    [anon_sym_DQUOTE] = ACTIONS(2492),
    [sym_true] = ACTIONS(2490),
    [sym_false] = ACTIONS(2490),
    [anon_sym_NULL] = ACTIONS(2490),
    [anon_sym_nullptr] = ACTIONS(2490),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2490),
    [anon_sym_decltype] = ACTIONS(2490),
    [sym_virtual] = ACTIONS(2490),
    [anon_sym_explicit] = ACTIONS(2490),
    [anon_sym_typename] = ACTIONS(2490),
    [anon_sym_template] = ACTIONS(2490),
    [anon_sym_operator] = ACTIONS(2490),
    [anon_sym_try] = ACTIONS(2490),
    [anon_sym_delete] = ACTIONS(2490),
    [anon_sym_throw] = ACTIONS(2490),
    [anon_sym_namespace] = ACTIONS(2490),
    [anon_sym_using] = ACTIONS(2490),
    [anon_sym_static_assert] = ACTIONS(2490),
    [anon_sym_concept] = ACTIONS(2490),
    [anon_sym_co_return] = ACTIONS(2490),
    [anon_sym_co_yield] = ACTIONS(2490),
    [anon_sym_R_DQUOTE] = ACTIONS(2492),
    [anon_sym_LR_DQUOTE] = ACTIONS(2492),
    [anon_sym_uR_DQUOTE] = ACTIONS(2492),
    [anon_sym_UR_DQUOTE] = ACTIONS(2492),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2492),
    [anon_sym_co_await] = ACTIONS(2490),
    [anon_sym_new] = ACTIONS(2490),
    [anon_sym_requires] = ACTIONS(2490),
    [sym_this] = ACTIONS(2490),
    [anon_sym_precise] = ACTIONS(2490),
    [anon_sym_shared] = ACTIONS(2490),
    [anon_sym_groupshared] = ACTIONS(2490),
    [anon_sym_uniform] = ACTIONS(2490),
    [anon_sym_row_major] = ACTIONS(2490),
    [anon_sym_column_major] = ACTIONS(2490),
    [anon_sym_globallycoherent] = ACTIONS(2490),
    [anon_sym_centroid] = ACTIONS(2490),
    [anon_sym_noperspective] = ACTIONS(2490),
    [anon_sym_nointerpolation] = ACTIONS(2490),
    [anon_sym_sample] = ACTIONS(2490),
    [anon_sym_linear] = ACTIONS(2490),
    [anon_sym_snorm] = ACTIONS(2490),
    [anon_sym_unorm] = ACTIONS(2490),
    [anon_sym_point] = ACTIONS(2490),
    [anon_sym_line] = ACTIONS(2490),
    [anon_sym_triangleadj] = ACTIONS(2490),
    [anon_sym_lineadj] = ACTIONS(2490),
    [anon_sym_triangle] = ACTIONS(2490),
  },
  [729] = {
    [ts_builtin_sym_end] = ACTIONS(2500),
    [sym_identifier] = ACTIONS(2498),
    [aux_sym_preproc_include_token1] = ACTIONS(2498),
    [aux_sym_preproc_def_token1] = ACTIONS(2498),
    [aux_sym_preproc_if_token1] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2498),
    [sym_preproc_directive] = ACTIONS(2498),
    [anon_sym_LPAREN2] = ACTIONS(2500),
    [anon_sym_BANG] = ACTIONS(2500),
    [anon_sym_TILDE] = ACTIONS(2500),
    [anon_sym_DASH] = ACTIONS(2498),
    [anon_sym_PLUS] = ACTIONS(2498),
    [anon_sym_STAR] = ACTIONS(2500),
    [anon_sym_AMP_AMP] = ACTIONS(2500),
    [anon_sym_AMP] = ACTIONS(2498),
    [anon_sym___extension__] = ACTIONS(2498),
    [anon_sym_typedef] = ACTIONS(2498),
    [anon_sym_in] = ACTIONS(2498),
    [anon_sym_out] = ACTIONS(2498),
    [anon_sym_inout] = ACTIONS(2498),
    [anon_sym_extern] = ACTIONS(2498),
    [anon_sym___attribute__] = ACTIONS(2498),
    [anon_sym_COLON_COLON] = ACTIONS(2500),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2500),
    [anon_sym___declspec] = ACTIONS(2498),
    [anon_sym___based] = ACTIONS(2498),
    [anon_sym___cdecl] = ACTIONS(2498),
    [anon_sym___clrcall] = ACTIONS(2498),
    [anon_sym___stdcall] = ACTIONS(2498),
    [anon_sym___fastcall] = ACTIONS(2498),
    [anon_sym___thiscall] = ACTIONS(2498),
    [anon_sym___vectorcall] = ACTIONS(2498),
    [anon_sym_LBRACE] = ACTIONS(2500),
    [anon_sym_signed] = ACTIONS(2498),
    [anon_sym_unsigned] = ACTIONS(2498),
    [anon_sym_long] = ACTIONS(2498),
    [anon_sym_short] = ACTIONS(2498),
    [anon_sym_LBRACK] = ACTIONS(2498),
    [anon_sym_static] = ACTIONS(2498),
    [anon_sym_register] = ACTIONS(2498),
    [anon_sym_inline] = ACTIONS(2498),
    [anon_sym___inline] = ACTIONS(2498),
    [anon_sym___inline__] = ACTIONS(2498),
    [anon_sym___forceinline] = ACTIONS(2498),
    [anon_sym_thread_local] = ACTIONS(2498),
    [anon_sym___thread] = ACTIONS(2498),
    [anon_sym_const] = ACTIONS(2498),
    [anon_sym_constexpr] = ACTIONS(2498),
    [anon_sym_volatile] = ACTIONS(2498),
    [anon_sym_restrict] = ACTIONS(2498),
    [anon_sym___restrict__] = ACTIONS(2498),
    [anon_sym__Atomic] = ACTIONS(2498),
    [anon_sym__Noreturn] = ACTIONS(2498),
    [anon_sym_noreturn] = ACTIONS(2498),
    [anon_sym_mutable] = ACTIONS(2498),
    [anon_sym_constinit] = ACTIONS(2498),
    [anon_sym_consteval] = ACTIONS(2498),
    [anon_sym_alignas] = ACTIONS(2498),
    [anon_sym__Alignas] = ACTIONS(2498),
    [sym_primitive_type] = ACTIONS(2498),
    [anon_sym_enum] = ACTIONS(2498),
    [anon_sym_class] = ACTIONS(2498),
    [anon_sym_struct] = ACTIONS(2498),
    [anon_sym_union] = ACTIONS(2498),
    [anon_sym_if] = ACTIONS(2498),
    [anon_sym_switch] = ACTIONS(2498),
    [anon_sym_case] = ACTIONS(2498),
    [anon_sym_default] = ACTIONS(2498),
    [anon_sym_while] = ACTIONS(2498),
    [anon_sym_do] = ACTIONS(2498),
    [anon_sym_for] = ACTIONS(2498),
    [anon_sym_return] = ACTIONS(2498),
    [anon_sym_break] = ACTIONS(2498),
    [anon_sym_continue] = ACTIONS(2498),
    [anon_sym_goto] = ACTIONS(2498),
    [anon_sym_not] = ACTIONS(2498),
    [anon_sym_compl] = ACTIONS(2498),
    [anon_sym_DASH_DASH] = ACTIONS(2500),
    [anon_sym_PLUS_PLUS] = ACTIONS(2500),
    [anon_sym_sizeof] = ACTIONS(2498),
    [anon_sym___alignof__] = ACTIONS(2498),
    [anon_sym___alignof] = ACTIONS(2498),
    [anon_sym__alignof] = ACTIONS(2498),
    [anon_sym_alignof] = ACTIONS(2498),
    [anon_sym__Alignof] = ACTIONS(2498),
    [anon_sym_offsetof] = ACTIONS(2498),
    [anon_sym__Generic] = ACTIONS(2498),
    [anon_sym_asm] = ACTIONS(2498),
    [anon_sym___asm__] = ACTIONS(2498),
    [sym_number_literal] = ACTIONS(2500),
    [anon_sym_L_SQUOTE] = ACTIONS(2500),
    [anon_sym_u_SQUOTE] = ACTIONS(2500),
    [anon_sym_U_SQUOTE] = ACTIONS(2500),
    [anon_sym_u8_SQUOTE] = ACTIONS(2500),
    [anon_sym_SQUOTE] = ACTIONS(2500),
    [anon_sym_L_DQUOTE] = ACTIONS(2500),
    [anon_sym_u_DQUOTE] = ACTIONS(2500),
    [anon_sym_U_DQUOTE] = ACTIONS(2500),
    [anon_sym_u8_DQUOTE] = ACTIONS(2500),
    [anon_sym_DQUOTE] = ACTIONS(2500),
    [sym_true] = ACTIONS(2498),
    [sym_false] = ACTIONS(2498),
    [anon_sym_NULL] = ACTIONS(2498),
    [anon_sym_nullptr] = ACTIONS(2498),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2498),
    [anon_sym_decltype] = ACTIONS(2498),
    [sym_virtual] = ACTIONS(2498),
    [anon_sym_explicit] = ACTIONS(2498),
    [anon_sym_typename] = ACTIONS(2498),
    [anon_sym_template] = ACTIONS(2498),
    [anon_sym_operator] = ACTIONS(2498),
    [anon_sym_try] = ACTIONS(2498),
    [anon_sym_delete] = ACTIONS(2498),
    [anon_sym_throw] = ACTIONS(2498),
    [anon_sym_namespace] = ACTIONS(2498),
    [anon_sym_using] = ACTIONS(2498),
    [anon_sym_static_assert] = ACTIONS(2498),
    [anon_sym_concept] = ACTIONS(2498),
    [anon_sym_co_return] = ACTIONS(2498),
    [anon_sym_co_yield] = ACTIONS(2498),
    [anon_sym_R_DQUOTE] = ACTIONS(2500),
    [anon_sym_LR_DQUOTE] = ACTIONS(2500),
    [anon_sym_uR_DQUOTE] = ACTIONS(2500),
    [anon_sym_UR_DQUOTE] = ACTIONS(2500),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2500),
    [anon_sym_co_await] = ACTIONS(2498),
    [anon_sym_new] = ACTIONS(2498),
    [anon_sym_requires] = ACTIONS(2498),
    [sym_this] = ACTIONS(2498),
    [anon_sym_precise] = ACTIONS(2498),
    [anon_sym_shared] = ACTIONS(2498),
    [anon_sym_groupshared] = ACTIONS(2498),
    [anon_sym_uniform] = ACTIONS(2498),
    [anon_sym_row_major] = ACTIONS(2498),
    [anon_sym_column_major] = ACTIONS(2498),
    [anon_sym_globallycoherent] = ACTIONS(2498),
    [anon_sym_centroid] = ACTIONS(2498),
    [anon_sym_noperspective] = ACTIONS(2498),
    [anon_sym_nointerpolation] = ACTIONS(2498),
    [anon_sym_sample] = ACTIONS(2498),
    [anon_sym_linear] = ACTIONS(2498),
    [anon_sym_snorm] = ACTIONS(2498),
    [anon_sym_unorm] = ACTIONS(2498),
    [anon_sym_point] = ACTIONS(2498),
    [anon_sym_line] = ACTIONS(2498),
    [anon_sym_triangleadj] = ACTIONS(2498),
    [anon_sym_lineadj] = ACTIONS(2498),
    [anon_sym_triangle] = ACTIONS(2498),
  },
  [730] = {
    [ts_builtin_sym_end] = ACTIONS(2338),
    [sym_identifier] = ACTIONS(2336),
    [aux_sym_preproc_include_token1] = ACTIONS(2336),
    [aux_sym_preproc_def_token1] = ACTIONS(2336),
    [aux_sym_preproc_if_token1] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2336),
    [sym_preproc_directive] = ACTIONS(2336),
    [anon_sym_LPAREN2] = ACTIONS(2338),
    [anon_sym_BANG] = ACTIONS(2338),
    [anon_sym_TILDE] = ACTIONS(2338),
    [anon_sym_DASH] = ACTIONS(2336),
    [anon_sym_PLUS] = ACTIONS(2336),
    [anon_sym_STAR] = ACTIONS(2338),
    [anon_sym_AMP_AMP] = ACTIONS(2338),
    [anon_sym_AMP] = ACTIONS(2336),
    [anon_sym___extension__] = ACTIONS(2336),
    [anon_sym_typedef] = ACTIONS(2336),
    [anon_sym_in] = ACTIONS(2336),
    [anon_sym_out] = ACTIONS(2336),
    [anon_sym_inout] = ACTIONS(2336),
    [anon_sym_extern] = ACTIONS(2336),
    [anon_sym___attribute__] = ACTIONS(2336),
    [anon_sym_COLON_COLON] = ACTIONS(2338),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2338),
    [anon_sym___declspec] = ACTIONS(2336),
    [anon_sym___based] = ACTIONS(2336),
    [anon_sym___cdecl] = ACTIONS(2336),
    [anon_sym___clrcall] = ACTIONS(2336),
    [anon_sym___stdcall] = ACTIONS(2336),
    [anon_sym___fastcall] = ACTIONS(2336),
    [anon_sym___thiscall] = ACTIONS(2336),
    [anon_sym___vectorcall] = ACTIONS(2336),
    [anon_sym_LBRACE] = ACTIONS(2338),
    [anon_sym_signed] = ACTIONS(2336),
    [anon_sym_unsigned] = ACTIONS(2336),
    [anon_sym_long] = ACTIONS(2336),
    [anon_sym_short] = ACTIONS(2336),
    [anon_sym_LBRACK] = ACTIONS(2336),
    [anon_sym_static] = ACTIONS(2336),
    [anon_sym_register] = ACTIONS(2336),
    [anon_sym_inline] = ACTIONS(2336),
    [anon_sym___inline] = ACTIONS(2336),
    [anon_sym___inline__] = ACTIONS(2336),
    [anon_sym___forceinline] = ACTIONS(2336),
    [anon_sym_thread_local] = ACTIONS(2336),
    [anon_sym___thread] = ACTIONS(2336),
    [anon_sym_const] = ACTIONS(2336),
    [anon_sym_constexpr] = ACTIONS(2336),
    [anon_sym_volatile] = ACTIONS(2336),
    [anon_sym_restrict] = ACTIONS(2336),
    [anon_sym___restrict__] = ACTIONS(2336),
    [anon_sym__Atomic] = ACTIONS(2336),
    [anon_sym__Noreturn] = ACTIONS(2336),
    [anon_sym_noreturn] = ACTIONS(2336),
    [anon_sym_mutable] = ACTIONS(2336),
    [anon_sym_constinit] = ACTIONS(2336),
    [anon_sym_consteval] = ACTIONS(2336),
    [anon_sym_alignas] = ACTIONS(2336),
    [anon_sym__Alignas] = ACTIONS(2336),
    [sym_primitive_type] = ACTIONS(2336),
    [anon_sym_enum] = ACTIONS(2336),
    [anon_sym_class] = ACTIONS(2336),
    [anon_sym_struct] = ACTIONS(2336),
    [anon_sym_union] = ACTIONS(2336),
    [anon_sym_if] = ACTIONS(2336),
    [anon_sym_switch] = ACTIONS(2336),
    [anon_sym_case] = ACTIONS(2336),
    [anon_sym_default] = ACTIONS(2336),
    [anon_sym_while] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(2336),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_return] = ACTIONS(2336),
    [anon_sym_break] = ACTIONS(2336),
    [anon_sym_continue] = ACTIONS(2336),
    [anon_sym_goto] = ACTIONS(2336),
    [anon_sym_not] = ACTIONS(2336),
    [anon_sym_compl] = ACTIONS(2336),
    [anon_sym_DASH_DASH] = ACTIONS(2338),
    [anon_sym_PLUS_PLUS] = ACTIONS(2338),
    [anon_sym_sizeof] = ACTIONS(2336),
    [anon_sym___alignof__] = ACTIONS(2336),
    [anon_sym___alignof] = ACTIONS(2336),
    [anon_sym__alignof] = ACTIONS(2336),
    [anon_sym_alignof] = ACTIONS(2336),
    [anon_sym__Alignof] = ACTIONS(2336),
    [anon_sym_offsetof] = ACTIONS(2336),
    [anon_sym__Generic] = ACTIONS(2336),
    [anon_sym_asm] = ACTIONS(2336),
    [anon_sym___asm__] = ACTIONS(2336),
    [sym_number_literal] = ACTIONS(2338),
    [anon_sym_L_SQUOTE] = ACTIONS(2338),
    [anon_sym_u_SQUOTE] = ACTIONS(2338),
    [anon_sym_U_SQUOTE] = ACTIONS(2338),
    [anon_sym_u8_SQUOTE] = ACTIONS(2338),
    [anon_sym_SQUOTE] = ACTIONS(2338),
    [anon_sym_L_DQUOTE] = ACTIONS(2338),
    [anon_sym_u_DQUOTE] = ACTIONS(2338),
    [anon_sym_U_DQUOTE] = ACTIONS(2338),
    [anon_sym_u8_DQUOTE] = ACTIONS(2338),
    [anon_sym_DQUOTE] = ACTIONS(2338),
    [sym_true] = ACTIONS(2336),
    [sym_false] = ACTIONS(2336),
    [anon_sym_NULL] = ACTIONS(2336),
    [anon_sym_nullptr] = ACTIONS(2336),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2336),
    [anon_sym_decltype] = ACTIONS(2336),
    [sym_virtual] = ACTIONS(2336),
    [anon_sym_explicit] = ACTIONS(2336),
    [anon_sym_typename] = ACTIONS(2336),
    [anon_sym_template] = ACTIONS(2336),
    [anon_sym_operator] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2336),
    [anon_sym_delete] = ACTIONS(2336),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_namespace] = ACTIONS(2336),
    [anon_sym_using] = ACTIONS(2336),
    [anon_sym_static_assert] = ACTIONS(2336),
    [anon_sym_concept] = ACTIONS(2336),
    [anon_sym_co_return] = ACTIONS(2336),
    [anon_sym_co_yield] = ACTIONS(2336),
    [anon_sym_R_DQUOTE] = ACTIONS(2338),
    [anon_sym_LR_DQUOTE] = ACTIONS(2338),
    [anon_sym_uR_DQUOTE] = ACTIONS(2338),
    [anon_sym_UR_DQUOTE] = ACTIONS(2338),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2338),
    [anon_sym_co_await] = ACTIONS(2336),
    [anon_sym_new] = ACTIONS(2336),
    [anon_sym_requires] = ACTIONS(2336),
    [sym_this] = ACTIONS(2336),
    [anon_sym_precise] = ACTIONS(2336),
    [anon_sym_shared] = ACTIONS(2336),
    [anon_sym_groupshared] = ACTIONS(2336),
    [anon_sym_uniform] = ACTIONS(2336),
    [anon_sym_row_major] = ACTIONS(2336),
    [anon_sym_column_major] = ACTIONS(2336),
    [anon_sym_globallycoherent] = ACTIONS(2336),
    [anon_sym_centroid] = ACTIONS(2336),
    [anon_sym_noperspective] = ACTIONS(2336),
    [anon_sym_nointerpolation] = ACTIONS(2336),
    [anon_sym_sample] = ACTIONS(2336),
    [anon_sym_linear] = ACTIONS(2336),
    [anon_sym_snorm] = ACTIONS(2336),
    [anon_sym_unorm] = ACTIONS(2336),
    [anon_sym_point] = ACTIONS(2336),
    [anon_sym_line] = ACTIONS(2336),
    [anon_sym_triangleadj] = ACTIONS(2336),
    [anon_sym_lineadj] = ACTIONS(2336),
    [anon_sym_triangle] = ACTIONS(2336),
  },
  [731] = {
    [ts_builtin_sym_end] = ACTIONS(2468),
    [sym_identifier] = ACTIONS(2466),
    [aux_sym_preproc_include_token1] = ACTIONS(2466),
    [aux_sym_preproc_def_token1] = ACTIONS(2466),
    [aux_sym_preproc_if_token1] = ACTIONS(2466),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2466),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2466),
    [sym_preproc_directive] = ACTIONS(2466),
    [anon_sym_LPAREN2] = ACTIONS(2468),
    [anon_sym_BANG] = ACTIONS(2468),
    [anon_sym_TILDE] = ACTIONS(2468),
    [anon_sym_DASH] = ACTIONS(2466),
    [anon_sym_PLUS] = ACTIONS(2466),
    [anon_sym_STAR] = ACTIONS(2468),
    [anon_sym_AMP_AMP] = ACTIONS(2468),
    [anon_sym_AMP] = ACTIONS(2466),
    [anon_sym___extension__] = ACTIONS(2466),
    [anon_sym_typedef] = ACTIONS(2466),
    [anon_sym_in] = ACTIONS(2466),
    [anon_sym_out] = ACTIONS(2466),
    [anon_sym_inout] = ACTIONS(2466),
    [anon_sym_extern] = ACTIONS(2466),
    [anon_sym___attribute__] = ACTIONS(2466),
    [anon_sym_COLON_COLON] = ACTIONS(2468),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2468),
    [anon_sym___declspec] = ACTIONS(2466),
    [anon_sym___based] = ACTIONS(2466),
    [anon_sym___cdecl] = ACTIONS(2466),
    [anon_sym___clrcall] = ACTIONS(2466),
    [anon_sym___stdcall] = ACTIONS(2466),
    [anon_sym___fastcall] = ACTIONS(2466),
    [anon_sym___thiscall] = ACTIONS(2466),
    [anon_sym___vectorcall] = ACTIONS(2466),
    [anon_sym_LBRACE] = ACTIONS(2468),
    [anon_sym_signed] = ACTIONS(2466),
    [anon_sym_unsigned] = ACTIONS(2466),
    [anon_sym_long] = ACTIONS(2466),
    [anon_sym_short] = ACTIONS(2466),
    [anon_sym_LBRACK] = ACTIONS(2466),
    [anon_sym_static] = ACTIONS(2466),
    [anon_sym_register] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2466),
    [anon_sym___inline] = ACTIONS(2466),
    [anon_sym___inline__] = ACTIONS(2466),
    [anon_sym___forceinline] = ACTIONS(2466),
    [anon_sym_thread_local] = ACTIONS(2466),
    [anon_sym___thread] = ACTIONS(2466),
    [anon_sym_const] = ACTIONS(2466),
    [anon_sym_constexpr] = ACTIONS(2466),
    [anon_sym_volatile] = ACTIONS(2466),
    [anon_sym_restrict] = ACTIONS(2466),
    [anon_sym___restrict__] = ACTIONS(2466),
    [anon_sym__Atomic] = ACTIONS(2466),
    [anon_sym__Noreturn] = ACTIONS(2466),
    [anon_sym_noreturn] = ACTIONS(2466),
    [anon_sym_mutable] = ACTIONS(2466),
    [anon_sym_constinit] = ACTIONS(2466),
    [anon_sym_consteval] = ACTIONS(2466),
    [anon_sym_alignas] = ACTIONS(2466),
    [anon_sym__Alignas] = ACTIONS(2466),
    [sym_primitive_type] = ACTIONS(2466),
    [anon_sym_enum] = ACTIONS(2466),
    [anon_sym_class] = ACTIONS(2466),
    [anon_sym_struct] = ACTIONS(2466),
    [anon_sym_union] = ACTIONS(2466),
    [anon_sym_if] = ACTIONS(2466),
    [anon_sym_switch] = ACTIONS(2466),
    [anon_sym_case] = ACTIONS(2466),
    [anon_sym_default] = ACTIONS(2466),
    [anon_sym_while] = ACTIONS(2466),
    [anon_sym_do] = ACTIONS(2466),
    [anon_sym_for] = ACTIONS(2466),
    [anon_sym_return] = ACTIONS(2466),
    [anon_sym_break] = ACTIONS(2466),
    [anon_sym_continue] = ACTIONS(2466),
    [anon_sym_goto] = ACTIONS(2466),
    [anon_sym_not] = ACTIONS(2466),
    [anon_sym_compl] = ACTIONS(2466),
    [anon_sym_DASH_DASH] = ACTIONS(2468),
    [anon_sym_PLUS_PLUS] = ACTIONS(2468),
    [anon_sym_sizeof] = ACTIONS(2466),
    [anon_sym___alignof__] = ACTIONS(2466),
    [anon_sym___alignof] = ACTIONS(2466),
    [anon_sym__alignof] = ACTIONS(2466),
    [anon_sym_alignof] = ACTIONS(2466),
    [anon_sym__Alignof] = ACTIONS(2466),
    [anon_sym_offsetof] = ACTIONS(2466),
    [anon_sym__Generic] = ACTIONS(2466),
    [anon_sym_asm] = ACTIONS(2466),
    [anon_sym___asm__] = ACTIONS(2466),
    [sym_number_literal] = ACTIONS(2468),
    [anon_sym_L_SQUOTE] = ACTIONS(2468),
    [anon_sym_u_SQUOTE] = ACTIONS(2468),
    [anon_sym_U_SQUOTE] = ACTIONS(2468),
    [anon_sym_u8_SQUOTE] = ACTIONS(2468),
    [anon_sym_SQUOTE] = ACTIONS(2468),
    [anon_sym_L_DQUOTE] = ACTIONS(2468),
    [anon_sym_u_DQUOTE] = ACTIONS(2468),
    [anon_sym_U_DQUOTE] = ACTIONS(2468),
    [anon_sym_u8_DQUOTE] = ACTIONS(2468),
    [anon_sym_DQUOTE] = ACTIONS(2468),
    [sym_true] = ACTIONS(2466),
    [sym_false] = ACTIONS(2466),
    [anon_sym_NULL] = ACTIONS(2466),
    [anon_sym_nullptr] = ACTIONS(2466),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2466),
    [anon_sym_decltype] = ACTIONS(2466),
    [sym_virtual] = ACTIONS(2466),
    [anon_sym_explicit] = ACTIONS(2466),
    [anon_sym_typename] = ACTIONS(2466),
    [anon_sym_template] = ACTIONS(2466),
    [anon_sym_operator] = ACTIONS(2466),
    [anon_sym_try] = ACTIONS(2466),
    [anon_sym_delete] = ACTIONS(2466),
    [anon_sym_throw] = ACTIONS(2466),
    [anon_sym_namespace] = ACTIONS(2466),
    [anon_sym_using] = ACTIONS(2466),
    [anon_sym_static_assert] = ACTIONS(2466),
    [anon_sym_concept] = ACTIONS(2466),
    [anon_sym_co_return] = ACTIONS(2466),
    [anon_sym_co_yield] = ACTIONS(2466),
    [anon_sym_R_DQUOTE] = ACTIONS(2468),
    [anon_sym_LR_DQUOTE] = ACTIONS(2468),
    [anon_sym_uR_DQUOTE] = ACTIONS(2468),
    [anon_sym_UR_DQUOTE] = ACTIONS(2468),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2468),
    [anon_sym_co_await] = ACTIONS(2466),
    [anon_sym_new] = ACTIONS(2466),
    [anon_sym_requires] = ACTIONS(2466),
    [sym_this] = ACTIONS(2466),
    [anon_sym_precise] = ACTIONS(2466),
    [anon_sym_shared] = ACTIONS(2466),
    [anon_sym_groupshared] = ACTIONS(2466),
    [anon_sym_uniform] = ACTIONS(2466),
    [anon_sym_row_major] = ACTIONS(2466),
    [anon_sym_column_major] = ACTIONS(2466),
    [anon_sym_globallycoherent] = ACTIONS(2466),
    [anon_sym_centroid] = ACTIONS(2466),
    [anon_sym_noperspective] = ACTIONS(2466),
    [anon_sym_nointerpolation] = ACTIONS(2466),
    [anon_sym_sample] = ACTIONS(2466),
    [anon_sym_linear] = ACTIONS(2466),
    [anon_sym_snorm] = ACTIONS(2466),
    [anon_sym_unorm] = ACTIONS(2466),
    [anon_sym_point] = ACTIONS(2466),
    [anon_sym_line] = ACTIONS(2466),
    [anon_sym_triangleadj] = ACTIONS(2466),
    [anon_sym_lineadj] = ACTIONS(2466),
    [anon_sym_triangle] = ACTIONS(2466),
  },
  [732] = {
    [ts_builtin_sym_end] = ACTIONS(2326),
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_include_token1] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_BANG] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_DASH] = ACTIONS(2324),
    [anon_sym_PLUS] = ACTIONS(2324),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym___cdecl] = ACTIONS(2324),
    [anon_sym___clrcall] = ACTIONS(2324),
    [anon_sym___stdcall] = ACTIONS(2324),
    [anon_sym___fastcall] = ACTIONS(2324),
    [anon_sym___thiscall] = ACTIONS(2324),
    [anon_sym___vectorcall] = ACTIONS(2324),
    [anon_sym_LBRACE] = ACTIONS(2326),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [anon_sym_if] = ACTIONS(2324),
    [anon_sym_switch] = ACTIONS(2324),
    [anon_sym_case] = ACTIONS(2324),
    [anon_sym_default] = ACTIONS(2324),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_do] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2324),
    [anon_sym_return] = ACTIONS(2324),
    [anon_sym_break] = ACTIONS(2324),
    [anon_sym_continue] = ACTIONS(2324),
    [anon_sym_goto] = ACTIONS(2324),
    [anon_sym_not] = ACTIONS(2324),
    [anon_sym_compl] = ACTIONS(2324),
    [anon_sym_DASH_DASH] = ACTIONS(2326),
    [anon_sym_PLUS_PLUS] = ACTIONS(2326),
    [anon_sym_sizeof] = ACTIONS(2324),
    [anon_sym___alignof__] = ACTIONS(2324),
    [anon_sym___alignof] = ACTIONS(2324),
    [anon_sym__alignof] = ACTIONS(2324),
    [anon_sym_alignof] = ACTIONS(2324),
    [anon_sym__Alignof] = ACTIONS(2324),
    [anon_sym_offsetof] = ACTIONS(2324),
    [anon_sym__Generic] = ACTIONS(2324),
    [anon_sym_asm] = ACTIONS(2324),
    [anon_sym___asm__] = ACTIONS(2324),
    [sym_number_literal] = ACTIONS(2326),
    [anon_sym_L_SQUOTE] = ACTIONS(2326),
    [anon_sym_u_SQUOTE] = ACTIONS(2326),
    [anon_sym_U_SQUOTE] = ACTIONS(2326),
    [anon_sym_u8_SQUOTE] = ACTIONS(2326),
    [anon_sym_SQUOTE] = ACTIONS(2326),
    [anon_sym_L_DQUOTE] = ACTIONS(2326),
    [anon_sym_u_DQUOTE] = ACTIONS(2326),
    [anon_sym_U_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8_DQUOTE] = ACTIONS(2326),
    [anon_sym_DQUOTE] = ACTIONS(2326),
    [sym_true] = ACTIONS(2324),
    [sym_false] = ACTIONS(2324),
    [anon_sym_NULL] = ACTIONS(2324),
    [anon_sym_nullptr] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_try] = ACTIONS(2324),
    [anon_sym_delete] = ACTIONS(2324),
    [anon_sym_throw] = ACTIONS(2324),
    [anon_sym_namespace] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_concept] = ACTIONS(2324),
    [anon_sym_co_return] = ACTIONS(2324),
    [anon_sym_co_yield] = ACTIONS(2324),
    [anon_sym_R_DQUOTE] = ACTIONS(2326),
    [anon_sym_LR_DQUOTE] = ACTIONS(2326),
    [anon_sym_uR_DQUOTE] = ACTIONS(2326),
    [anon_sym_UR_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2326),
    [anon_sym_co_await] = ACTIONS(2324),
    [anon_sym_new] = ACTIONS(2324),
    [anon_sym_requires] = ACTIONS(2324),
    [sym_this] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
  },
  [733] = {
    [ts_builtin_sym_end] = ACTIONS(2338),
    [sym_identifier] = ACTIONS(2336),
    [aux_sym_preproc_include_token1] = ACTIONS(2336),
    [aux_sym_preproc_def_token1] = ACTIONS(2336),
    [aux_sym_preproc_if_token1] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2336),
    [sym_preproc_directive] = ACTIONS(2336),
    [anon_sym_LPAREN2] = ACTIONS(2338),
    [anon_sym_BANG] = ACTIONS(2338),
    [anon_sym_TILDE] = ACTIONS(2338),
    [anon_sym_DASH] = ACTIONS(2336),
    [anon_sym_PLUS] = ACTIONS(2336),
    [anon_sym_STAR] = ACTIONS(2338),
    [anon_sym_AMP_AMP] = ACTIONS(2338),
    [anon_sym_AMP] = ACTIONS(2336),
    [anon_sym___extension__] = ACTIONS(2336),
    [anon_sym_typedef] = ACTIONS(2336),
    [anon_sym_in] = ACTIONS(2336),
    [anon_sym_out] = ACTIONS(2336),
    [anon_sym_inout] = ACTIONS(2336),
    [anon_sym_extern] = ACTIONS(2336),
    [anon_sym___attribute__] = ACTIONS(2336),
    [anon_sym_COLON_COLON] = ACTIONS(2338),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2338),
    [anon_sym___declspec] = ACTIONS(2336),
    [anon_sym___based] = ACTIONS(2336),
    [anon_sym___cdecl] = ACTIONS(2336),
    [anon_sym___clrcall] = ACTIONS(2336),
    [anon_sym___stdcall] = ACTIONS(2336),
    [anon_sym___fastcall] = ACTIONS(2336),
    [anon_sym___thiscall] = ACTIONS(2336),
    [anon_sym___vectorcall] = ACTIONS(2336),
    [anon_sym_LBRACE] = ACTIONS(2338),
    [anon_sym_signed] = ACTIONS(2336),
    [anon_sym_unsigned] = ACTIONS(2336),
    [anon_sym_long] = ACTIONS(2336),
    [anon_sym_short] = ACTIONS(2336),
    [anon_sym_LBRACK] = ACTIONS(2336),
    [anon_sym_static] = ACTIONS(2336),
    [anon_sym_register] = ACTIONS(2336),
    [anon_sym_inline] = ACTIONS(2336),
    [anon_sym___inline] = ACTIONS(2336),
    [anon_sym___inline__] = ACTIONS(2336),
    [anon_sym___forceinline] = ACTIONS(2336),
    [anon_sym_thread_local] = ACTIONS(2336),
    [anon_sym___thread] = ACTIONS(2336),
    [anon_sym_const] = ACTIONS(2336),
    [anon_sym_constexpr] = ACTIONS(2336),
    [anon_sym_volatile] = ACTIONS(2336),
    [anon_sym_restrict] = ACTIONS(2336),
    [anon_sym___restrict__] = ACTIONS(2336),
    [anon_sym__Atomic] = ACTIONS(2336),
    [anon_sym__Noreturn] = ACTIONS(2336),
    [anon_sym_noreturn] = ACTIONS(2336),
    [anon_sym_mutable] = ACTIONS(2336),
    [anon_sym_constinit] = ACTIONS(2336),
    [anon_sym_consteval] = ACTIONS(2336),
    [anon_sym_alignas] = ACTIONS(2336),
    [anon_sym__Alignas] = ACTIONS(2336),
    [sym_primitive_type] = ACTIONS(2336),
    [anon_sym_enum] = ACTIONS(2336),
    [anon_sym_class] = ACTIONS(2336),
    [anon_sym_struct] = ACTIONS(2336),
    [anon_sym_union] = ACTIONS(2336),
    [anon_sym_if] = ACTIONS(2336),
    [anon_sym_switch] = ACTIONS(2336),
    [anon_sym_case] = ACTIONS(2336),
    [anon_sym_default] = ACTIONS(2336),
    [anon_sym_while] = ACTIONS(2336),
    [anon_sym_do] = ACTIONS(2336),
    [anon_sym_for] = ACTIONS(2336),
    [anon_sym_return] = ACTIONS(2336),
    [anon_sym_break] = ACTIONS(2336),
    [anon_sym_continue] = ACTIONS(2336),
    [anon_sym_goto] = ACTIONS(2336),
    [anon_sym_not] = ACTIONS(2336),
    [anon_sym_compl] = ACTIONS(2336),
    [anon_sym_DASH_DASH] = ACTIONS(2338),
    [anon_sym_PLUS_PLUS] = ACTIONS(2338),
    [anon_sym_sizeof] = ACTIONS(2336),
    [anon_sym___alignof__] = ACTIONS(2336),
    [anon_sym___alignof] = ACTIONS(2336),
    [anon_sym__alignof] = ACTIONS(2336),
    [anon_sym_alignof] = ACTIONS(2336),
    [anon_sym__Alignof] = ACTIONS(2336),
    [anon_sym_offsetof] = ACTIONS(2336),
    [anon_sym__Generic] = ACTIONS(2336),
    [anon_sym_asm] = ACTIONS(2336),
    [anon_sym___asm__] = ACTIONS(2336),
    [sym_number_literal] = ACTIONS(2338),
    [anon_sym_L_SQUOTE] = ACTIONS(2338),
    [anon_sym_u_SQUOTE] = ACTIONS(2338),
    [anon_sym_U_SQUOTE] = ACTIONS(2338),
    [anon_sym_u8_SQUOTE] = ACTIONS(2338),
    [anon_sym_SQUOTE] = ACTIONS(2338),
    [anon_sym_L_DQUOTE] = ACTIONS(2338),
    [anon_sym_u_DQUOTE] = ACTIONS(2338),
    [anon_sym_U_DQUOTE] = ACTIONS(2338),
    [anon_sym_u8_DQUOTE] = ACTIONS(2338),
    [anon_sym_DQUOTE] = ACTIONS(2338),
    [sym_true] = ACTIONS(2336),
    [sym_false] = ACTIONS(2336),
    [anon_sym_NULL] = ACTIONS(2336),
    [anon_sym_nullptr] = ACTIONS(2336),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2336),
    [anon_sym_decltype] = ACTIONS(2336),
    [sym_virtual] = ACTIONS(2336),
    [anon_sym_explicit] = ACTIONS(2336),
    [anon_sym_typename] = ACTIONS(2336),
    [anon_sym_template] = ACTIONS(2336),
    [anon_sym_operator] = ACTIONS(2336),
    [anon_sym_try] = ACTIONS(2336),
    [anon_sym_delete] = ACTIONS(2336),
    [anon_sym_throw] = ACTIONS(2336),
    [anon_sym_namespace] = ACTIONS(2336),
    [anon_sym_using] = ACTIONS(2336),
    [anon_sym_static_assert] = ACTIONS(2336),
    [anon_sym_concept] = ACTIONS(2336),
    [anon_sym_co_return] = ACTIONS(2336),
    [anon_sym_co_yield] = ACTIONS(2336),
    [anon_sym_R_DQUOTE] = ACTIONS(2338),
    [anon_sym_LR_DQUOTE] = ACTIONS(2338),
    [anon_sym_uR_DQUOTE] = ACTIONS(2338),
    [anon_sym_UR_DQUOTE] = ACTIONS(2338),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2338),
    [anon_sym_co_await] = ACTIONS(2336),
    [anon_sym_new] = ACTIONS(2336),
    [anon_sym_requires] = ACTIONS(2336),
    [sym_this] = ACTIONS(2336),
    [anon_sym_precise] = ACTIONS(2336),
    [anon_sym_shared] = ACTIONS(2336),
    [anon_sym_groupshared] = ACTIONS(2336),
    [anon_sym_uniform] = ACTIONS(2336),
    [anon_sym_row_major] = ACTIONS(2336),
    [anon_sym_column_major] = ACTIONS(2336),
    [anon_sym_globallycoherent] = ACTIONS(2336),
    [anon_sym_centroid] = ACTIONS(2336),
    [anon_sym_noperspective] = ACTIONS(2336),
    [anon_sym_nointerpolation] = ACTIONS(2336),
    [anon_sym_sample] = ACTIONS(2336),
    [anon_sym_linear] = ACTIONS(2336),
    [anon_sym_snorm] = ACTIONS(2336),
    [anon_sym_unorm] = ACTIONS(2336),
    [anon_sym_point] = ACTIONS(2336),
    [anon_sym_line] = ACTIONS(2336),
    [anon_sym_triangleadj] = ACTIONS(2336),
    [anon_sym_lineadj] = ACTIONS(2336),
    [anon_sym_triangle] = ACTIONS(2336),
  },
  [734] = {
    [sym_preproc_def] = STATE(745),
    [sym_preproc_function_def] = STATE(745),
    [sym_preproc_call] = STATE(745),
    [sym_preproc_if_in_field_declaration_list] = STATE(745),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(745),
    [sym_type_definition] = STATE(745),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(745),
    [sym_field_declaration] = STATE(745),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(745),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(745),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(745),
    [sym_operator_cast_declaration] = STATE(745),
    [sym_constructor_or_destructor_definition] = STATE(745),
    [sym_constructor_or_destructor_declaration] = STATE(745),
    [sym_friend_declaration] = STATE(745),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(745),
    [sym_alias_declaration] = STATE(745),
    [sym_static_assert_declaration] = STATE(745),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(745),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2887),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [735] = {
    [sym_preproc_def] = STATE(797),
    [sym_preproc_function_def] = STATE(797),
    [sym_preproc_call] = STATE(797),
    [sym_preproc_if_in_field_declaration_list] = STATE(797),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(797),
    [sym_type_definition] = STATE(797),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(797),
    [sym_field_declaration] = STATE(797),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(797),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(797),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(797),
    [sym_operator_cast_declaration] = STATE(797),
    [sym_constructor_or_destructor_definition] = STATE(797),
    [sym_constructor_or_destructor_declaration] = STATE(797),
    [sym_friend_declaration] = STATE(797),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(797),
    [sym_alias_declaration] = STATE(797),
    [sym_static_assert_declaration] = STATE(797),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(797),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2889),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [736] = {
    [ts_builtin_sym_end] = ACTIONS(2579),
    [sym_identifier] = ACTIONS(2577),
    [aux_sym_preproc_include_token1] = ACTIONS(2577),
    [aux_sym_preproc_def_token1] = ACTIONS(2577),
    [aux_sym_preproc_if_token1] = ACTIONS(2577),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2577),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2577),
    [sym_preproc_directive] = ACTIONS(2577),
    [anon_sym_LPAREN2] = ACTIONS(2579),
    [anon_sym_BANG] = ACTIONS(2579),
    [anon_sym_TILDE] = ACTIONS(2579),
    [anon_sym_DASH] = ACTIONS(2577),
    [anon_sym_PLUS] = ACTIONS(2577),
    [anon_sym_STAR] = ACTIONS(2579),
    [anon_sym_AMP_AMP] = ACTIONS(2579),
    [anon_sym_AMP] = ACTIONS(2577),
    [anon_sym___extension__] = ACTIONS(2577),
    [anon_sym_typedef] = ACTIONS(2577),
    [anon_sym_in] = ACTIONS(2577),
    [anon_sym_out] = ACTIONS(2577),
    [anon_sym_inout] = ACTIONS(2577),
    [anon_sym_extern] = ACTIONS(2577),
    [anon_sym___attribute__] = ACTIONS(2577),
    [anon_sym_COLON_COLON] = ACTIONS(2579),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2579),
    [anon_sym___declspec] = ACTIONS(2577),
    [anon_sym___based] = ACTIONS(2577),
    [anon_sym___cdecl] = ACTIONS(2577),
    [anon_sym___clrcall] = ACTIONS(2577),
    [anon_sym___stdcall] = ACTIONS(2577),
    [anon_sym___fastcall] = ACTIONS(2577),
    [anon_sym___thiscall] = ACTIONS(2577),
    [anon_sym___vectorcall] = ACTIONS(2577),
    [anon_sym_LBRACE] = ACTIONS(2579),
    [anon_sym_signed] = ACTIONS(2577),
    [anon_sym_unsigned] = ACTIONS(2577),
    [anon_sym_long] = ACTIONS(2577),
    [anon_sym_short] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2577),
    [anon_sym_static] = ACTIONS(2577),
    [anon_sym_register] = ACTIONS(2577),
    [anon_sym_inline] = ACTIONS(2577),
    [anon_sym___inline] = ACTIONS(2577),
    [anon_sym___inline__] = ACTIONS(2577),
    [anon_sym___forceinline] = ACTIONS(2577),
    [anon_sym_thread_local] = ACTIONS(2577),
    [anon_sym___thread] = ACTIONS(2577),
    [anon_sym_const] = ACTIONS(2577),
    [anon_sym_constexpr] = ACTIONS(2577),
    [anon_sym_volatile] = ACTIONS(2577),
    [anon_sym_restrict] = ACTIONS(2577),
    [anon_sym___restrict__] = ACTIONS(2577),
    [anon_sym__Atomic] = ACTIONS(2577),
    [anon_sym__Noreturn] = ACTIONS(2577),
    [anon_sym_noreturn] = ACTIONS(2577),
    [anon_sym_mutable] = ACTIONS(2577),
    [anon_sym_constinit] = ACTIONS(2577),
    [anon_sym_consteval] = ACTIONS(2577),
    [anon_sym_alignas] = ACTIONS(2577),
    [anon_sym__Alignas] = ACTIONS(2577),
    [sym_primitive_type] = ACTIONS(2577),
    [anon_sym_enum] = ACTIONS(2577),
    [anon_sym_class] = ACTIONS(2577),
    [anon_sym_struct] = ACTIONS(2577),
    [anon_sym_union] = ACTIONS(2577),
    [anon_sym_if] = ACTIONS(2577),
    [anon_sym_switch] = ACTIONS(2577),
    [anon_sym_case] = ACTIONS(2577),
    [anon_sym_default] = ACTIONS(2577),
    [anon_sym_while] = ACTIONS(2577),
    [anon_sym_do] = ACTIONS(2577),
    [anon_sym_for] = ACTIONS(2577),
    [anon_sym_return] = ACTIONS(2577),
    [anon_sym_break] = ACTIONS(2577),
    [anon_sym_continue] = ACTIONS(2577),
    [anon_sym_goto] = ACTIONS(2577),
    [anon_sym_not] = ACTIONS(2577),
    [anon_sym_compl] = ACTIONS(2577),
    [anon_sym_DASH_DASH] = ACTIONS(2579),
    [anon_sym_PLUS_PLUS] = ACTIONS(2579),
    [anon_sym_sizeof] = ACTIONS(2577),
    [anon_sym___alignof__] = ACTIONS(2577),
    [anon_sym___alignof] = ACTIONS(2577),
    [anon_sym__alignof] = ACTIONS(2577),
    [anon_sym_alignof] = ACTIONS(2577),
    [anon_sym__Alignof] = ACTIONS(2577),
    [anon_sym_offsetof] = ACTIONS(2577),
    [anon_sym__Generic] = ACTIONS(2577),
    [anon_sym_asm] = ACTIONS(2577),
    [anon_sym___asm__] = ACTIONS(2577),
    [sym_number_literal] = ACTIONS(2579),
    [anon_sym_L_SQUOTE] = ACTIONS(2579),
    [anon_sym_u_SQUOTE] = ACTIONS(2579),
    [anon_sym_U_SQUOTE] = ACTIONS(2579),
    [anon_sym_u8_SQUOTE] = ACTIONS(2579),
    [anon_sym_SQUOTE] = ACTIONS(2579),
    [anon_sym_L_DQUOTE] = ACTIONS(2579),
    [anon_sym_u_DQUOTE] = ACTIONS(2579),
    [anon_sym_U_DQUOTE] = ACTIONS(2579),
    [anon_sym_u8_DQUOTE] = ACTIONS(2579),
    [anon_sym_DQUOTE] = ACTIONS(2579),
    [sym_true] = ACTIONS(2577),
    [sym_false] = ACTIONS(2577),
    [anon_sym_NULL] = ACTIONS(2577),
    [anon_sym_nullptr] = ACTIONS(2577),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2577),
    [anon_sym_decltype] = ACTIONS(2577),
    [sym_virtual] = ACTIONS(2577),
    [anon_sym_explicit] = ACTIONS(2577),
    [anon_sym_typename] = ACTIONS(2577),
    [anon_sym_template] = ACTIONS(2577),
    [anon_sym_operator] = ACTIONS(2577),
    [anon_sym_try] = ACTIONS(2577),
    [anon_sym_delete] = ACTIONS(2577),
    [anon_sym_throw] = ACTIONS(2577),
    [anon_sym_namespace] = ACTIONS(2577),
    [anon_sym_using] = ACTIONS(2577),
    [anon_sym_static_assert] = ACTIONS(2577),
    [anon_sym_concept] = ACTIONS(2577),
    [anon_sym_co_return] = ACTIONS(2577),
    [anon_sym_co_yield] = ACTIONS(2577),
    [anon_sym_R_DQUOTE] = ACTIONS(2579),
    [anon_sym_LR_DQUOTE] = ACTIONS(2579),
    [anon_sym_uR_DQUOTE] = ACTIONS(2579),
    [anon_sym_UR_DQUOTE] = ACTIONS(2579),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2579),
    [anon_sym_co_await] = ACTIONS(2577),
    [anon_sym_new] = ACTIONS(2577),
    [anon_sym_requires] = ACTIONS(2577),
    [sym_this] = ACTIONS(2577),
    [anon_sym_precise] = ACTIONS(2577),
    [anon_sym_shared] = ACTIONS(2577),
    [anon_sym_groupshared] = ACTIONS(2577),
    [anon_sym_uniform] = ACTIONS(2577),
    [anon_sym_row_major] = ACTIONS(2577),
    [anon_sym_column_major] = ACTIONS(2577),
    [anon_sym_globallycoherent] = ACTIONS(2577),
    [anon_sym_centroid] = ACTIONS(2577),
    [anon_sym_noperspective] = ACTIONS(2577),
    [anon_sym_nointerpolation] = ACTIONS(2577),
    [anon_sym_sample] = ACTIONS(2577),
    [anon_sym_linear] = ACTIONS(2577),
    [anon_sym_snorm] = ACTIONS(2577),
    [anon_sym_unorm] = ACTIONS(2577),
    [anon_sym_point] = ACTIONS(2577),
    [anon_sym_line] = ACTIONS(2577),
    [anon_sym_triangleadj] = ACTIONS(2577),
    [anon_sym_lineadj] = ACTIONS(2577),
    [anon_sym_triangle] = ACTIONS(2577),
  },
  [737] = {
    [sym_preproc_def] = STATE(710),
    [sym_preproc_function_def] = STATE(710),
    [sym_preproc_call] = STATE(710),
    [sym_preproc_if_in_field_declaration_list] = STATE(710),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(710),
    [sym_type_definition] = STATE(710),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(710),
    [sym_field_declaration] = STATE(710),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(710),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(710),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(710),
    [sym_operator_cast_declaration] = STATE(710),
    [sym_constructor_or_destructor_definition] = STATE(710),
    [sym_constructor_or_destructor_declaration] = STATE(710),
    [sym_friend_declaration] = STATE(710),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(710),
    [sym_alias_declaration] = STATE(710),
    [sym_static_assert_declaration] = STATE(710),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(710),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2891),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [738] = {
    [ts_builtin_sym_end] = ACTIONS(2563),
    [sym_identifier] = ACTIONS(2561),
    [aux_sym_preproc_include_token1] = ACTIONS(2561),
    [aux_sym_preproc_def_token1] = ACTIONS(2561),
    [aux_sym_preproc_if_token1] = ACTIONS(2561),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2561),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2561),
    [sym_preproc_directive] = ACTIONS(2561),
    [anon_sym_LPAREN2] = ACTIONS(2563),
    [anon_sym_BANG] = ACTIONS(2563),
    [anon_sym_TILDE] = ACTIONS(2563),
    [anon_sym_DASH] = ACTIONS(2561),
    [anon_sym_PLUS] = ACTIONS(2561),
    [anon_sym_STAR] = ACTIONS(2563),
    [anon_sym_AMP_AMP] = ACTIONS(2563),
    [anon_sym_AMP] = ACTIONS(2561),
    [anon_sym___extension__] = ACTIONS(2561),
    [anon_sym_typedef] = ACTIONS(2561),
    [anon_sym_in] = ACTIONS(2561),
    [anon_sym_out] = ACTIONS(2561),
    [anon_sym_inout] = ACTIONS(2561),
    [anon_sym_extern] = ACTIONS(2561),
    [anon_sym___attribute__] = ACTIONS(2561),
    [anon_sym_COLON_COLON] = ACTIONS(2563),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2563),
    [anon_sym___declspec] = ACTIONS(2561),
    [anon_sym___based] = ACTIONS(2561),
    [anon_sym___cdecl] = ACTIONS(2561),
    [anon_sym___clrcall] = ACTIONS(2561),
    [anon_sym___stdcall] = ACTIONS(2561),
    [anon_sym___fastcall] = ACTIONS(2561),
    [anon_sym___thiscall] = ACTIONS(2561),
    [anon_sym___vectorcall] = ACTIONS(2561),
    [anon_sym_LBRACE] = ACTIONS(2563),
    [anon_sym_signed] = ACTIONS(2561),
    [anon_sym_unsigned] = ACTIONS(2561),
    [anon_sym_long] = ACTIONS(2561),
    [anon_sym_short] = ACTIONS(2561),
    [anon_sym_LBRACK] = ACTIONS(2561),
    [anon_sym_static] = ACTIONS(2561),
    [anon_sym_register] = ACTIONS(2561),
    [anon_sym_inline] = ACTIONS(2561),
    [anon_sym___inline] = ACTIONS(2561),
    [anon_sym___inline__] = ACTIONS(2561),
    [anon_sym___forceinline] = ACTIONS(2561),
    [anon_sym_thread_local] = ACTIONS(2561),
    [anon_sym___thread] = ACTIONS(2561),
    [anon_sym_const] = ACTIONS(2561),
    [anon_sym_constexpr] = ACTIONS(2561),
    [anon_sym_volatile] = ACTIONS(2561),
    [anon_sym_restrict] = ACTIONS(2561),
    [anon_sym___restrict__] = ACTIONS(2561),
    [anon_sym__Atomic] = ACTIONS(2561),
    [anon_sym__Noreturn] = ACTIONS(2561),
    [anon_sym_noreturn] = ACTIONS(2561),
    [anon_sym_mutable] = ACTIONS(2561),
    [anon_sym_constinit] = ACTIONS(2561),
    [anon_sym_consteval] = ACTIONS(2561),
    [anon_sym_alignas] = ACTIONS(2561),
    [anon_sym__Alignas] = ACTIONS(2561),
    [sym_primitive_type] = ACTIONS(2561),
    [anon_sym_enum] = ACTIONS(2561),
    [anon_sym_class] = ACTIONS(2561),
    [anon_sym_struct] = ACTIONS(2561),
    [anon_sym_union] = ACTIONS(2561),
    [anon_sym_if] = ACTIONS(2561),
    [anon_sym_switch] = ACTIONS(2561),
    [anon_sym_case] = ACTIONS(2561),
    [anon_sym_default] = ACTIONS(2561),
    [anon_sym_while] = ACTIONS(2561),
    [anon_sym_do] = ACTIONS(2561),
    [anon_sym_for] = ACTIONS(2561),
    [anon_sym_return] = ACTIONS(2561),
    [anon_sym_break] = ACTIONS(2561),
    [anon_sym_continue] = ACTIONS(2561),
    [anon_sym_goto] = ACTIONS(2561),
    [anon_sym_not] = ACTIONS(2561),
    [anon_sym_compl] = ACTIONS(2561),
    [anon_sym_DASH_DASH] = ACTIONS(2563),
    [anon_sym_PLUS_PLUS] = ACTIONS(2563),
    [anon_sym_sizeof] = ACTIONS(2561),
    [anon_sym___alignof__] = ACTIONS(2561),
    [anon_sym___alignof] = ACTIONS(2561),
    [anon_sym__alignof] = ACTIONS(2561),
    [anon_sym_alignof] = ACTIONS(2561),
    [anon_sym__Alignof] = ACTIONS(2561),
    [anon_sym_offsetof] = ACTIONS(2561),
    [anon_sym__Generic] = ACTIONS(2561),
    [anon_sym_asm] = ACTIONS(2561),
    [anon_sym___asm__] = ACTIONS(2561),
    [sym_number_literal] = ACTIONS(2563),
    [anon_sym_L_SQUOTE] = ACTIONS(2563),
    [anon_sym_u_SQUOTE] = ACTIONS(2563),
    [anon_sym_U_SQUOTE] = ACTIONS(2563),
    [anon_sym_u8_SQUOTE] = ACTIONS(2563),
    [anon_sym_SQUOTE] = ACTIONS(2563),
    [anon_sym_L_DQUOTE] = ACTIONS(2563),
    [anon_sym_u_DQUOTE] = ACTIONS(2563),
    [anon_sym_U_DQUOTE] = ACTIONS(2563),
    [anon_sym_u8_DQUOTE] = ACTIONS(2563),
    [anon_sym_DQUOTE] = ACTIONS(2563),
    [sym_true] = ACTIONS(2561),
    [sym_false] = ACTIONS(2561),
    [anon_sym_NULL] = ACTIONS(2561),
    [anon_sym_nullptr] = ACTIONS(2561),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2561),
    [anon_sym_decltype] = ACTIONS(2561),
    [sym_virtual] = ACTIONS(2561),
    [anon_sym_explicit] = ACTIONS(2561),
    [anon_sym_typename] = ACTIONS(2561),
    [anon_sym_template] = ACTIONS(2561),
    [anon_sym_operator] = ACTIONS(2561),
    [anon_sym_try] = ACTIONS(2561),
    [anon_sym_delete] = ACTIONS(2561),
    [anon_sym_throw] = ACTIONS(2561),
    [anon_sym_namespace] = ACTIONS(2561),
    [anon_sym_using] = ACTIONS(2561),
    [anon_sym_static_assert] = ACTIONS(2561),
    [anon_sym_concept] = ACTIONS(2561),
    [anon_sym_co_return] = ACTIONS(2561),
    [anon_sym_co_yield] = ACTIONS(2561),
    [anon_sym_R_DQUOTE] = ACTIONS(2563),
    [anon_sym_LR_DQUOTE] = ACTIONS(2563),
    [anon_sym_uR_DQUOTE] = ACTIONS(2563),
    [anon_sym_UR_DQUOTE] = ACTIONS(2563),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2563),
    [anon_sym_co_await] = ACTIONS(2561),
    [anon_sym_new] = ACTIONS(2561),
    [anon_sym_requires] = ACTIONS(2561),
    [sym_this] = ACTIONS(2561),
    [anon_sym_precise] = ACTIONS(2561),
    [anon_sym_shared] = ACTIONS(2561),
    [anon_sym_groupshared] = ACTIONS(2561),
    [anon_sym_uniform] = ACTIONS(2561),
    [anon_sym_row_major] = ACTIONS(2561),
    [anon_sym_column_major] = ACTIONS(2561),
    [anon_sym_globallycoherent] = ACTIONS(2561),
    [anon_sym_centroid] = ACTIONS(2561),
    [anon_sym_noperspective] = ACTIONS(2561),
    [anon_sym_nointerpolation] = ACTIONS(2561),
    [anon_sym_sample] = ACTIONS(2561),
    [anon_sym_linear] = ACTIONS(2561),
    [anon_sym_snorm] = ACTIONS(2561),
    [anon_sym_unorm] = ACTIONS(2561),
    [anon_sym_point] = ACTIONS(2561),
    [anon_sym_line] = ACTIONS(2561),
    [anon_sym_triangleadj] = ACTIONS(2561),
    [anon_sym_lineadj] = ACTIONS(2561),
    [anon_sym_triangle] = ACTIONS(2561),
  },
  [739] = {
    [ts_builtin_sym_end] = ACTIONS(2410),
    [sym_identifier] = ACTIONS(2408),
    [aux_sym_preproc_include_token1] = ACTIONS(2408),
    [aux_sym_preproc_def_token1] = ACTIONS(2408),
    [aux_sym_preproc_if_token1] = ACTIONS(2408),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2408),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2408),
    [sym_preproc_directive] = ACTIONS(2408),
    [anon_sym_LPAREN2] = ACTIONS(2410),
    [anon_sym_BANG] = ACTIONS(2410),
    [anon_sym_TILDE] = ACTIONS(2410),
    [anon_sym_DASH] = ACTIONS(2408),
    [anon_sym_PLUS] = ACTIONS(2408),
    [anon_sym_STAR] = ACTIONS(2410),
    [anon_sym_AMP_AMP] = ACTIONS(2410),
    [anon_sym_AMP] = ACTIONS(2408),
    [anon_sym___extension__] = ACTIONS(2408),
    [anon_sym_typedef] = ACTIONS(2408),
    [anon_sym_in] = ACTIONS(2408),
    [anon_sym_out] = ACTIONS(2408),
    [anon_sym_inout] = ACTIONS(2408),
    [anon_sym_extern] = ACTIONS(2408),
    [anon_sym___attribute__] = ACTIONS(2408),
    [anon_sym_COLON_COLON] = ACTIONS(2410),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2410),
    [anon_sym___declspec] = ACTIONS(2408),
    [anon_sym___based] = ACTIONS(2408),
    [anon_sym___cdecl] = ACTIONS(2408),
    [anon_sym___clrcall] = ACTIONS(2408),
    [anon_sym___stdcall] = ACTIONS(2408),
    [anon_sym___fastcall] = ACTIONS(2408),
    [anon_sym___thiscall] = ACTIONS(2408),
    [anon_sym___vectorcall] = ACTIONS(2408),
    [anon_sym_LBRACE] = ACTIONS(2410),
    [anon_sym_signed] = ACTIONS(2408),
    [anon_sym_unsigned] = ACTIONS(2408),
    [anon_sym_long] = ACTIONS(2408),
    [anon_sym_short] = ACTIONS(2408),
    [anon_sym_LBRACK] = ACTIONS(2408),
    [anon_sym_static] = ACTIONS(2408),
    [anon_sym_register] = ACTIONS(2408),
    [anon_sym_inline] = ACTIONS(2408),
    [anon_sym___inline] = ACTIONS(2408),
    [anon_sym___inline__] = ACTIONS(2408),
    [anon_sym___forceinline] = ACTIONS(2408),
    [anon_sym_thread_local] = ACTIONS(2408),
    [anon_sym___thread] = ACTIONS(2408),
    [anon_sym_const] = ACTIONS(2408),
    [anon_sym_constexpr] = ACTIONS(2408),
    [anon_sym_volatile] = ACTIONS(2408),
    [anon_sym_restrict] = ACTIONS(2408),
    [anon_sym___restrict__] = ACTIONS(2408),
    [anon_sym__Atomic] = ACTIONS(2408),
    [anon_sym__Noreturn] = ACTIONS(2408),
    [anon_sym_noreturn] = ACTIONS(2408),
    [anon_sym_mutable] = ACTIONS(2408),
    [anon_sym_constinit] = ACTIONS(2408),
    [anon_sym_consteval] = ACTIONS(2408),
    [anon_sym_alignas] = ACTIONS(2408),
    [anon_sym__Alignas] = ACTIONS(2408),
    [sym_primitive_type] = ACTIONS(2408),
    [anon_sym_enum] = ACTIONS(2408),
    [anon_sym_class] = ACTIONS(2408),
    [anon_sym_struct] = ACTIONS(2408),
    [anon_sym_union] = ACTIONS(2408),
    [anon_sym_if] = ACTIONS(2408),
    [anon_sym_switch] = ACTIONS(2408),
    [anon_sym_case] = ACTIONS(2408),
    [anon_sym_default] = ACTIONS(2408),
    [anon_sym_while] = ACTIONS(2408),
    [anon_sym_do] = ACTIONS(2408),
    [anon_sym_for] = ACTIONS(2408),
    [anon_sym_return] = ACTIONS(2408),
    [anon_sym_break] = ACTIONS(2408),
    [anon_sym_continue] = ACTIONS(2408),
    [anon_sym_goto] = ACTIONS(2408),
    [anon_sym_not] = ACTIONS(2408),
    [anon_sym_compl] = ACTIONS(2408),
    [anon_sym_DASH_DASH] = ACTIONS(2410),
    [anon_sym_PLUS_PLUS] = ACTIONS(2410),
    [anon_sym_sizeof] = ACTIONS(2408),
    [anon_sym___alignof__] = ACTIONS(2408),
    [anon_sym___alignof] = ACTIONS(2408),
    [anon_sym__alignof] = ACTIONS(2408),
    [anon_sym_alignof] = ACTIONS(2408),
    [anon_sym__Alignof] = ACTIONS(2408),
    [anon_sym_offsetof] = ACTIONS(2408),
    [anon_sym__Generic] = ACTIONS(2408),
    [anon_sym_asm] = ACTIONS(2408),
    [anon_sym___asm__] = ACTIONS(2408),
    [sym_number_literal] = ACTIONS(2410),
    [anon_sym_L_SQUOTE] = ACTIONS(2410),
    [anon_sym_u_SQUOTE] = ACTIONS(2410),
    [anon_sym_U_SQUOTE] = ACTIONS(2410),
    [anon_sym_u8_SQUOTE] = ACTIONS(2410),
    [anon_sym_SQUOTE] = ACTIONS(2410),
    [anon_sym_L_DQUOTE] = ACTIONS(2410),
    [anon_sym_u_DQUOTE] = ACTIONS(2410),
    [anon_sym_U_DQUOTE] = ACTIONS(2410),
    [anon_sym_u8_DQUOTE] = ACTIONS(2410),
    [anon_sym_DQUOTE] = ACTIONS(2410),
    [sym_true] = ACTIONS(2408),
    [sym_false] = ACTIONS(2408),
    [anon_sym_NULL] = ACTIONS(2408),
    [anon_sym_nullptr] = ACTIONS(2408),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2408),
    [anon_sym_decltype] = ACTIONS(2408),
    [sym_virtual] = ACTIONS(2408),
    [anon_sym_explicit] = ACTIONS(2408),
    [anon_sym_typename] = ACTIONS(2408),
    [anon_sym_template] = ACTIONS(2408),
    [anon_sym_operator] = ACTIONS(2408),
    [anon_sym_try] = ACTIONS(2408),
    [anon_sym_delete] = ACTIONS(2408),
    [anon_sym_throw] = ACTIONS(2408),
    [anon_sym_namespace] = ACTIONS(2408),
    [anon_sym_using] = ACTIONS(2408),
    [anon_sym_static_assert] = ACTIONS(2408),
    [anon_sym_concept] = ACTIONS(2408),
    [anon_sym_co_return] = ACTIONS(2408),
    [anon_sym_co_yield] = ACTIONS(2408),
    [anon_sym_R_DQUOTE] = ACTIONS(2410),
    [anon_sym_LR_DQUOTE] = ACTIONS(2410),
    [anon_sym_uR_DQUOTE] = ACTIONS(2410),
    [anon_sym_UR_DQUOTE] = ACTIONS(2410),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2410),
    [anon_sym_co_await] = ACTIONS(2408),
    [anon_sym_new] = ACTIONS(2408),
    [anon_sym_requires] = ACTIONS(2408),
    [sym_this] = ACTIONS(2408),
    [anon_sym_precise] = ACTIONS(2408),
    [anon_sym_shared] = ACTIONS(2408),
    [anon_sym_groupshared] = ACTIONS(2408),
    [anon_sym_uniform] = ACTIONS(2408),
    [anon_sym_row_major] = ACTIONS(2408),
    [anon_sym_column_major] = ACTIONS(2408),
    [anon_sym_globallycoherent] = ACTIONS(2408),
    [anon_sym_centroid] = ACTIONS(2408),
    [anon_sym_noperspective] = ACTIONS(2408),
    [anon_sym_nointerpolation] = ACTIONS(2408),
    [anon_sym_sample] = ACTIONS(2408),
    [anon_sym_linear] = ACTIONS(2408),
    [anon_sym_snorm] = ACTIONS(2408),
    [anon_sym_unorm] = ACTIONS(2408),
    [anon_sym_point] = ACTIONS(2408),
    [anon_sym_line] = ACTIONS(2408),
    [anon_sym_triangleadj] = ACTIONS(2408),
    [anon_sym_lineadj] = ACTIONS(2408),
    [anon_sym_triangle] = ACTIONS(2408),
  },
  [740] = {
    [sym_preproc_def] = STATE(797),
    [sym_preproc_function_def] = STATE(797),
    [sym_preproc_call] = STATE(797),
    [sym_preproc_if_in_field_declaration_list] = STATE(797),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(797),
    [sym_type_definition] = STATE(797),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(797),
    [sym_field_declaration] = STATE(797),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(797),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(797),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(797),
    [sym_operator_cast_declaration] = STATE(797),
    [sym_constructor_or_destructor_definition] = STATE(797),
    [sym_constructor_or_destructor_declaration] = STATE(797),
    [sym_friend_declaration] = STATE(797),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(797),
    [sym_alias_declaration] = STATE(797),
    [sym_static_assert_declaration] = STATE(797),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(797),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2893),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [741] = {
    [ts_builtin_sym_end] = ACTIONS(2391),
    [sym_identifier] = ACTIONS(2389),
    [aux_sym_preproc_include_token1] = ACTIONS(2389),
    [aux_sym_preproc_def_token1] = ACTIONS(2389),
    [aux_sym_preproc_if_token1] = ACTIONS(2389),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2389),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2389),
    [sym_preproc_directive] = ACTIONS(2389),
    [anon_sym_LPAREN2] = ACTIONS(2391),
    [anon_sym_BANG] = ACTIONS(2391),
    [anon_sym_TILDE] = ACTIONS(2391),
    [anon_sym_DASH] = ACTIONS(2389),
    [anon_sym_PLUS] = ACTIONS(2389),
    [anon_sym_STAR] = ACTIONS(2391),
    [anon_sym_AMP_AMP] = ACTIONS(2391),
    [anon_sym_AMP] = ACTIONS(2389),
    [anon_sym___extension__] = ACTIONS(2389),
    [anon_sym_typedef] = ACTIONS(2389),
    [anon_sym_in] = ACTIONS(2389),
    [anon_sym_out] = ACTIONS(2389),
    [anon_sym_inout] = ACTIONS(2389),
    [anon_sym_extern] = ACTIONS(2389),
    [anon_sym___attribute__] = ACTIONS(2389),
    [anon_sym_COLON_COLON] = ACTIONS(2391),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2391),
    [anon_sym___declspec] = ACTIONS(2389),
    [anon_sym___based] = ACTIONS(2389),
    [anon_sym___cdecl] = ACTIONS(2389),
    [anon_sym___clrcall] = ACTIONS(2389),
    [anon_sym___stdcall] = ACTIONS(2389),
    [anon_sym___fastcall] = ACTIONS(2389),
    [anon_sym___thiscall] = ACTIONS(2389),
    [anon_sym___vectorcall] = ACTIONS(2389),
    [anon_sym_LBRACE] = ACTIONS(2391),
    [anon_sym_signed] = ACTIONS(2389),
    [anon_sym_unsigned] = ACTIONS(2389),
    [anon_sym_long] = ACTIONS(2389),
    [anon_sym_short] = ACTIONS(2389),
    [anon_sym_LBRACK] = ACTIONS(2389),
    [anon_sym_static] = ACTIONS(2389),
    [anon_sym_register] = ACTIONS(2389),
    [anon_sym_inline] = ACTIONS(2389),
    [anon_sym___inline] = ACTIONS(2389),
    [anon_sym___inline__] = ACTIONS(2389),
    [anon_sym___forceinline] = ACTIONS(2389),
    [anon_sym_thread_local] = ACTIONS(2389),
    [anon_sym___thread] = ACTIONS(2389),
    [anon_sym_const] = ACTIONS(2389),
    [anon_sym_constexpr] = ACTIONS(2389),
    [anon_sym_volatile] = ACTIONS(2389),
    [anon_sym_restrict] = ACTIONS(2389),
    [anon_sym___restrict__] = ACTIONS(2389),
    [anon_sym__Atomic] = ACTIONS(2389),
    [anon_sym__Noreturn] = ACTIONS(2389),
    [anon_sym_noreturn] = ACTIONS(2389),
    [anon_sym_mutable] = ACTIONS(2389),
    [anon_sym_constinit] = ACTIONS(2389),
    [anon_sym_consteval] = ACTIONS(2389),
    [anon_sym_alignas] = ACTIONS(2389),
    [anon_sym__Alignas] = ACTIONS(2389),
    [sym_primitive_type] = ACTIONS(2389),
    [anon_sym_enum] = ACTIONS(2389),
    [anon_sym_class] = ACTIONS(2389),
    [anon_sym_struct] = ACTIONS(2389),
    [anon_sym_union] = ACTIONS(2389),
    [anon_sym_if] = ACTIONS(2389),
    [anon_sym_switch] = ACTIONS(2389),
    [anon_sym_case] = ACTIONS(2389),
    [anon_sym_default] = ACTIONS(2389),
    [anon_sym_while] = ACTIONS(2389),
    [anon_sym_do] = ACTIONS(2389),
    [anon_sym_for] = ACTIONS(2389),
    [anon_sym_return] = ACTIONS(2389),
    [anon_sym_break] = ACTIONS(2389),
    [anon_sym_continue] = ACTIONS(2389),
    [anon_sym_goto] = ACTIONS(2389),
    [anon_sym_not] = ACTIONS(2389),
    [anon_sym_compl] = ACTIONS(2389),
    [anon_sym_DASH_DASH] = ACTIONS(2391),
    [anon_sym_PLUS_PLUS] = ACTIONS(2391),
    [anon_sym_sizeof] = ACTIONS(2389),
    [anon_sym___alignof__] = ACTIONS(2389),
    [anon_sym___alignof] = ACTIONS(2389),
    [anon_sym__alignof] = ACTIONS(2389),
    [anon_sym_alignof] = ACTIONS(2389),
    [anon_sym__Alignof] = ACTIONS(2389),
    [anon_sym_offsetof] = ACTIONS(2389),
    [anon_sym__Generic] = ACTIONS(2389),
    [anon_sym_asm] = ACTIONS(2389),
    [anon_sym___asm__] = ACTIONS(2389),
    [sym_number_literal] = ACTIONS(2391),
    [anon_sym_L_SQUOTE] = ACTIONS(2391),
    [anon_sym_u_SQUOTE] = ACTIONS(2391),
    [anon_sym_U_SQUOTE] = ACTIONS(2391),
    [anon_sym_u8_SQUOTE] = ACTIONS(2391),
    [anon_sym_SQUOTE] = ACTIONS(2391),
    [anon_sym_L_DQUOTE] = ACTIONS(2391),
    [anon_sym_u_DQUOTE] = ACTIONS(2391),
    [anon_sym_U_DQUOTE] = ACTIONS(2391),
    [anon_sym_u8_DQUOTE] = ACTIONS(2391),
    [anon_sym_DQUOTE] = ACTIONS(2391),
    [sym_true] = ACTIONS(2389),
    [sym_false] = ACTIONS(2389),
    [anon_sym_NULL] = ACTIONS(2389),
    [anon_sym_nullptr] = ACTIONS(2389),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2389),
    [anon_sym_decltype] = ACTIONS(2389),
    [sym_virtual] = ACTIONS(2389),
    [anon_sym_explicit] = ACTIONS(2389),
    [anon_sym_typename] = ACTIONS(2389),
    [anon_sym_template] = ACTIONS(2389),
    [anon_sym_operator] = ACTIONS(2389),
    [anon_sym_try] = ACTIONS(2389),
    [anon_sym_delete] = ACTIONS(2389),
    [anon_sym_throw] = ACTIONS(2389),
    [anon_sym_namespace] = ACTIONS(2389),
    [anon_sym_using] = ACTIONS(2389),
    [anon_sym_static_assert] = ACTIONS(2389),
    [anon_sym_concept] = ACTIONS(2389),
    [anon_sym_co_return] = ACTIONS(2389),
    [anon_sym_co_yield] = ACTIONS(2389),
    [anon_sym_R_DQUOTE] = ACTIONS(2391),
    [anon_sym_LR_DQUOTE] = ACTIONS(2391),
    [anon_sym_uR_DQUOTE] = ACTIONS(2391),
    [anon_sym_UR_DQUOTE] = ACTIONS(2391),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2391),
    [anon_sym_co_await] = ACTIONS(2389),
    [anon_sym_new] = ACTIONS(2389),
    [anon_sym_requires] = ACTIONS(2389),
    [sym_this] = ACTIONS(2389),
    [anon_sym_precise] = ACTIONS(2389),
    [anon_sym_shared] = ACTIONS(2389),
    [anon_sym_groupshared] = ACTIONS(2389),
    [anon_sym_uniform] = ACTIONS(2389),
    [anon_sym_row_major] = ACTIONS(2389),
    [anon_sym_column_major] = ACTIONS(2389),
    [anon_sym_globallycoherent] = ACTIONS(2389),
    [anon_sym_centroid] = ACTIONS(2389),
    [anon_sym_noperspective] = ACTIONS(2389),
    [anon_sym_nointerpolation] = ACTIONS(2389),
    [anon_sym_sample] = ACTIONS(2389),
    [anon_sym_linear] = ACTIONS(2389),
    [anon_sym_snorm] = ACTIONS(2389),
    [anon_sym_unorm] = ACTIONS(2389),
    [anon_sym_point] = ACTIONS(2389),
    [anon_sym_line] = ACTIONS(2389),
    [anon_sym_triangleadj] = ACTIONS(2389),
    [anon_sym_lineadj] = ACTIONS(2389),
    [anon_sym_triangle] = ACTIONS(2389),
  },
  [742] = {
    [ts_builtin_sym_end] = ACTIONS(2895),
    [sym_identifier] = ACTIONS(2897),
    [aux_sym_preproc_include_token1] = ACTIONS(2897),
    [aux_sym_preproc_def_token1] = ACTIONS(2897),
    [aux_sym_preproc_if_token1] = ACTIONS(2897),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2897),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2897),
    [sym_preproc_directive] = ACTIONS(2897),
    [anon_sym_LPAREN2] = ACTIONS(2895),
    [anon_sym_BANG] = ACTIONS(2895),
    [anon_sym_TILDE] = ACTIONS(2895),
    [anon_sym_DASH] = ACTIONS(2897),
    [anon_sym_PLUS] = ACTIONS(2897),
    [anon_sym_STAR] = ACTIONS(2895),
    [anon_sym_AMP_AMP] = ACTIONS(2895),
    [anon_sym_AMP] = ACTIONS(2897),
    [anon_sym___extension__] = ACTIONS(2897),
    [anon_sym_typedef] = ACTIONS(2897),
    [anon_sym_in] = ACTIONS(2897),
    [anon_sym_out] = ACTIONS(2897),
    [anon_sym_inout] = ACTIONS(2897),
    [anon_sym_extern] = ACTIONS(2897),
    [anon_sym___attribute__] = ACTIONS(2897),
    [anon_sym_COLON_COLON] = ACTIONS(2895),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2895),
    [anon_sym___declspec] = ACTIONS(2897),
    [anon_sym___based] = ACTIONS(2897),
    [anon_sym___cdecl] = ACTIONS(2897),
    [anon_sym___clrcall] = ACTIONS(2897),
    [anon_sym___stdcall] = ACTIONS(2897),
    [anon_sym___fastcall] = ACTIONS(2897),
    [anon_sym___thiscall] = ACTIONS(2897),
    [anon_sym___vectorcall] = ACTIONS(2897),
    [anon_sym_LBRACE] = ACTIONS(2895),
    [anon_sym_signed] = ACTIONS(2897),
    [anon_sym_unsigned] = ACTIONS(2897),
    [anon_sym_long] = ACTIONS(2897),
    [anon_sym_short] = ACTIONS(2897),
    [anon_sym_LBRACK] = ACTIONS(2897),
    [anon_sym_static] = ACTIONS(2897),
    [anon_sym_register] = ACTIONS(2897),
    [anon_sym_inline] = ACTIONS(2897),
    [anon_sym___inline] = ACTIONS(2897),
    [anon_sym___inline__] = ACTIONS(2897),
    [anon_sym___forceinline] = ACTIONS(2897),
    [anon_sym_thread_local] = ACTIONS(2897),
    [anon_sym___thread] = ACTIONS(2897),
    [anon_sym_const] = ACTIONS(2897),
    [anon_sym_constexpr] = ACTIONS(2897),
    [anon_sym_volatile] = ACTIONS(2897),
    [anon_sym_restrict] = ACTIONS(2897),
    [anon_sym___restrict__] = ACTIONS(2897),
    [anon_sym__Atomic] = ACTIONS(2897),
    [anon_sym__Noreturn] = ACTIONS(2897),
    [anon_sym_noreturn] = ACTIONS(2897),
    [anon_sym_mutable] = ACTIONS(2897),
    [anon_sym_constinit] = ACTIONS(2897),
    [anon_sym_consteval] = ACTIONS(2897),
    [anon_sym_alignas] = ACTIONS(2897),
    [anon_sym__Alignas] = ACTIONS(2897),
    [sym_primitive_type] = ACTIONS(2897),
    [anon_sym_enum] = ACTIONS(2897),
    [anon_sym_class] = ACTIONS(2897),
    [anon_sym_struct] = ACTIONS(2897),
    [anon_sym_union] = ACTIONS(2897),
    [anon_sym_if] = ACTIONS(2897),
    [anon_sym_switch] = ACTIONS(2897),
    [anon_sym_case] = ACTIONS(2897),
    [anon_sym_default] = ACTIONS(2897),
    [anon_sym_while] = ACTIONS(2897),
    [anon_sym_do] = ACTIONS(2897),
    [anon_sym_for] = ACTIONS(2897),
    [anon_sym_return] = ACTIONS(2897),
    [anon_sym_break] = ACTIONS(2897),
    [anon_sym_continue] = ACTIONS(2897),
    [anon_sym_goto] = ACTIONS(2897),
    [anon_sym_not] = ACTIONS(2897),
    [anon_sym_compl] = ACTIONS(2897),
    [anon_sym_DASH_DASH] = ACTIONS(2895),
    [anon_sym_PLUS_PLUS] = ACTIONS(2895),
    [anon_sym_sizeof] = ACTIONS(2897),
    [anon_sym___alignof__] = ACTIONS(2897),
    [anon_sym___alignof] = ACTIONS(2897),
    [anon_sym__alignof] = ACTIONS(2897),
    [anon_sym_alignof] = ACTIONS(2897),
    [anon_sym__Alignof] = ACTIONS(2897),
    [anon_sym_offsetof] = ACTIONS(2897),
    [anon_sym__Generic] = ACTIONS(2897),
    [anon_sym_asm] = ACTIONS(2897),
    [anon_sym___asm__] = ACTIONS(2897),
    [sym_number_literal] = ACTIONS(2895),
    [anon_sym_L_SQUOTE] = ACTIONS(2895),
    [anon_sym_u_SQUOTE] = ACTIONS(2895),
    [anon_sym_U_SQUOTE] = ACTIONS(2895),
    [anon_sym_u8_SQUOTE] = ACTIONS(2895),
    [anon_sym_SQUOTE] = ACTIONS(2895),
    [anon_sym_L_DQUOTE] = ACTIONS(2895),
    [anon_sym_u_DQUOTE] = ACTIONS(2895),
    [anon_sym_U_DQUOTE] = ACTIONS(2895),
    [anon_sym_u8_DQUOTE] = ACTIONS(2895),
    [anon_sym_DQUOTE] = ACTIONS(2895),
    [sym_true] = ACTIONS(2897),
    [sym_false] = ACTIONS(2897),
    [anon_sym_NULL] = ACTIONS(2897),
    [anon_sym_nullptr] = ACTIONS(2897),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2897),
    [anon_sym_decltype] = ACTIONS(2897),
    [sym_virtual] = ACTIONS(2897),
    [anon_sym_explicit] = ACTIONS(2897),
    [anon_sym_typename] = ACTIONS(2897),
    [anon_sym_template] = ACTIONS(2897),
    [anon_sym_operator] = ACTIONS(2897),
    [anon_sym_try] = ACTIONS(2897),
    [anon_sym_delete] = ACTIONS(2897),
    [anon_sym_throw] = ACTIONS(2897),
    [anon_sym_namespace] = ACTIONS(2897),
    [anon_sym_using] = ACTIONS(2897),
    [anon_sym_static_assert] = ACTIONS(2897),
    [anon_sym_concept] = ACTIONS(2897),
    [anon_sym_co_return] = ACTIONS(2897),
    [anon_sym_co_yield] = ACTIONS(2897),
    [anon_sym_R_DQUOTE] = ACTIONS(2895),
    [anon_sym_LR_DQUOTE] = ACTIONS(2895),
    [anon_sym_uR_DQUOTE] = ACTIONS(2895),
    [anon_sym_UR_DQUOTE] = ACTIONS(2895),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2895),
    [anon_sym_co_await] = ACTIONS(2897),
    [anon_sym_new] = ACTIONS(2897),
    [anon_sym_requires] = ACTIONS(2897),
    [sym_this] = ACTIONS(2897),
    [anon_sym_precise] = ACTIONS(2897),
    [anon_sym_shared] = ACTIONS(2897),
    [anon_sym_groupshared] = ACTIONS(2897),
    [anon_sym_uniform] = ACTIONS(2897),
    [anon_sym_row_major] = ACTIONS(2897),
    [anon_sym_column_major] = ACTIONS(2897),
    [anon_sym_globallycoherent] = ACTIONS(2897),
    [anon_sym_centroid] = ACTIONS(2897),
    [anon_sym_noperspective] = ACTIONS(2897),
    [anon_sym_nointerpolation] = ACTIONS(2897),
    [anon_sym_sample] = ACTIONS(2897),
    [anon_sym_linear] = ACTIONS(2897),
    [anon_sym_snorm] = ACTIONS(2897),
    [anon_sym_unorm] = ACTIONS(2897),
    [anon_sym_point] = ACTIONS(2897),
    [anon_sym_line] = ACTIONS(2897),
    [anon_sym_triangleadj] = ACTIONS(2897),
    [anon_sym_lineadj] = ACTIONS(2897),
    [anon_sym_triangle] = ACTIONS(2897),
  },
  [743] = {
    [ts_builtin_sym_end] = ACTIONS(2476),
    [sym_identifier] = ACTIONS(2474),
    [aux_sym_preproc_include_token1] = ACTIONS(2474),
    [aux_sym_preproc_def_token1] = ACTIONS(2474),
    [aux_sym_preproc_if_token1] = ACTIONS(2474),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2474),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2474),
    [sym_preproc_directive] = ACTIONS(2474),
    [anon_sym_LPAREN2] = ACTIONS(2476),
    [anon_sym_BANG] = ACTIONS(2476),
    [anon_sym_TILDE] = ACTIONS(2476),
    [anon_sym_DASH] = ACTIONS(2474),
    [anon_sym_PLUS] = ACTIONS(2474),
    [anon_sym_STAR] = ACTIONS(2476),
    [anon_sym_AMP_AMP] = ACTIONS(2476),
    [anon_sym_AMP] = ACTIONS(2474),
    [anon_sym___extension__] = ACTIONS(2474),
    [anon_sym_typedef] = ACTIONS(2474),
    [anon_sym_in] = ACTIONS(2474),
    [anon_sym_out] = ACTIONS(2474),
    [anon_sym_inout] = ACTIONS(2474),
    [anon_sym_extern] = ACTIONS(2474),
    [anon_sym___attribute__] = ACTIONS(2474),
    [anon_sym_COLON_COLON] = ACTIONS(2476),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2476),
    [anon_sym___declspec] = ACTIONS(2474),
    [anon_sym___based] = ACTIONS(2474),
    [anon_sym___cdecl] = ACTIONS(2474),
    [anon_sym___clrcall] = ACTIONS(2474),
    [anon_sym___stdcall] = ACTIONS(2474),
    [anon_sym___fastcall] = ACTIONS(2474),
    [anon_sym___thiscall] = ACTIONS(2474),
    [anon_sym___vectorcall] = ACTIONS(2474),
    [anon_sym_LBRACE] = ACTIONS(2476),
    [anon_sym_signed] = ACTIONS(2474),
    [anon_sym_unsigned] = ACTIONS(2474),
    [anon_sym_long] = ACTIONS(2474),
    [anon_sym_short] = ACTIONS(2474),
    [anon_sym_LBRACK] = ACTIONS(2474),
    [anon_sym_static] = ACTIONS(2474),
    [anon_sym_register] = ACTIONS(2474),
    [anon_sym_inline] = ACTIONS(2474),
    [anon_sym___inline] = ACTIONS(2474),
    [anon_sym___inline__] = ACTIONS(2474),
    [anon_sym___forceinline] = ACTIONS(2474),
    [anon_sym_thread_local] = ACTIONS(2474),
    [anon_sym___thread] = ACTIONS(2474),
    [anon_sym_const] = ACTIONS(2474),
    [anon_sym_constexpr] = ACTIONS(2474),
    [anon_sym_volatile] = ACTIONS(2474),
    [anon_sym_restrict] = ACTIONS(2474),
    [anon_sym___restrict__] = ACTIONS(2474),
    [anon_sym__Atomic] = ACTIONS(2474),
    [anon_sym__Noreturn] = ACTIONS(2474),
    [anon_sym_noreturn] = ACTIONS(2474),
    [anon_sym_mutable] = ACTIONS(2474),
    [anon_sym_constinit] = ACTIONS(2474),
    [anon_sym_consteval] = ACTIONS(2474),
    [anon_sym_alignas] = ACTIONS(2474),
    [anon_sym__Alignas] = ACTIONS(2474),
    [sym_primitive_type] = ACTIONS(2474),
    [anon_sym_enum] = ACTIONS(2474),
    [anon_sym_class] = ACTIONS(2474),
    [anon_sym_struct] = ACTIONS(2474),
    [anon_sym_union] = ACTIONS(2474),
    [anon_sym_if] = ACTIONS(2474),
    [anon_sym_switch] = ACTIONS(2474),
    [anon_sym_case] = ACTIONS(2474),
    [anon_sym_default] = ACTIONS(2474),
    [anon_sym_while] = ACTIONS(2474),
    [anon_sym_do] = ACTIONS(2474),
    [anon_sym_for] = ACTIONS(2474),
    [anon_sym_return] = ACTIONS(2474),
    [anon_sym_break] = ACTIONS(2474),
    [anon_sym_continue] = ACTIONS(2474),
    [anon_sym_goto] = ACTIONS(2474),
    [anon_sym_not] = ACTIONS(2474),
    [anon_sym_compl] = ACTIONS(2474),
    [anon_sym_DASH_DASH] = ACTIONS(2476),
    [anon_sym_PLUS_PLUS] = ACTIONS(2476),
    [anon_sym_sizeof] = ACTIONS(2474),
    [anon_sym___alignof__] = ACTIONS(2474),
    [anon_sym___alignof] = ACTIONS(2474),
    [anon_sym__alignof] = ACTIONS(2474),
    [anon_sym_alignof] = ACTIONS(2474),
    [anon_sym__Alignof] = ACTIONS(2474),
    [anon_sym_offsetof] = ACTIONS(2474),
    [anon_sym__Generic] = ACTIONS(2474),
    [anon_sym_asm] = ACTIONS(2474),
    [anon_sym___asm__] = ACTIONS(2474),
    [sym_number_literal] = ACTIONS(2476),
    [anon_sym_L_SQUOTE] = ACTIONS(2476),
    [anon_sym_u_SQUOTE] = ACTIONS(2476),
    [anon_sym_U_SQUOTE] = ACTIONS(2476),
    [anon_sym_u8_SQUOTE] = ACTIONS(2476),
    [anon_sym_SQUOTE] = ACTIONS(2476),
    [anon_sym_L_DQUOTE] = ACTIONS(2476),
    [anon_sym_u_DQUOTE] = ACTIONS(2476),
    [anon_sym_U_DQUOTE] = ACTIONS(2476),
    [anon_sym_u8_DQUOTE] = ACTIONS(2476),
    [anon_sym_DQUOTE] = ACTIONS(2476),
    [sym_true] = ACTIONS(2474),
    [sym_false] = ACTIONS(2474),
    [anon_sym_NULL] = ACTIONS(2474),
    [anon_sym_nullptr] = ACTIONS(2474),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2474),
    [anon_sym_decltype] = ACTIONS(2474),
    [sym_virtual] = ACTIONS(2474),
    [anon_sym_explicit] = ACTIONS(2474),
    [anon_sym_typename] = ACTIONS(2474),
    [anon_sym_template] = ACTIONS(2474),
    [anon_sym_operator] = ACTIONS(2474),
    [anon_sym_try] = ACTIONS(2474),
    [anon_sym_delete] = ACTIONS(2474),
    [anon_sym_throw] = ACTIONS(2474),
    [anon_sym_namespace] = ACTIONS(2474),
    [anon_sym_using] = ACTIONS(2474),
    [anon_sym_static_assert] = ACTIONS(2474),
    [anon_sym_concept] = ACTIONS(2474),
    [anon_sym_co_return] = ACTIONS(2474),
    [anon_sym_co_yield] = ACTIONS(2474),
    [anon_sym_R_DQUOTE] = ACTIONS(2476),
    [anon_sym_LR_DQUOTE] = ACTIONS(2476),
    [anon_sym_uR_DQUOTE] = ACTIONS(2476),
    [anon_sym_UR_DQUOTE] = ACTIONS(2476),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2476),
    [anon_sym_co_await] = ACTIONS(2474),
    [anon_sym_new] = ACTIONS(2474),
    [anon_sym_requires] = ACTIONS(2474),
    [sym_this] = ACTIONS(2474),
    [anon_sym_precise] = ACTIONS(2474),
    [anon_sym_shared] = ACTIONS(2474),
    [anon_sym_groupshared] = ACTIONS(2474),
    [anon_sym_uniform] = ACTIONS(2474),
    [anon_sym_row_major] = ACTIONS(2474),
    [anon_sym_column_major] = ACTIONS(2474),
    [anon_sym_globallycoherent] = ACTIONS(2474),
    [anon_sym_centroid] = ACTIONS(2474),
    [anon_sym_noperspective] = ACTIONS(2474),
    [anon_sym_nointerpolation] = ACTIONS(2474),
    [anon_sym_sample] = ACTIONS(2474),
    [anon_sym_linear] = ACTIONS(2474),
    [anon_sym_snorm] = ACTIONS(2474),
    [anon_sym_unorm] = ACTIONS(2474),
    [anon_sym_point] = ACTIONS(2474),
    [anon_sym_line] = ACTIONS(2474),
    [anon_sym_triangleadj] = ACTIONS(2474),
    [anon_sym_lineadj] = ACTIONS(2474),
    [anon_sym_triangle] = ACTIONS(2474),
  },
  [744] = {
    [sym_preproc_def] = STATE(744),
    [sym_preproc_function_def] = STATE(744),
    [sym_preproc_call] = STATE(744),
    [sym_preproc_if_in_field_declaration_list] = STATE(744),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(744),
    [sym_type_definition] = STATE(744),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5542),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6069),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(744),
    [sym_field_declaration] = STATE(744),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1829),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(744),
    [sym_operator_cast] = STATE(6635),
    [sym_inline_method_definition] = STATE(744),
    [sym__constructor_specifiers] = STATE(1829),
    [sym_operator_cast_definition] = STATE(744),
    [sym_operator_cast_declaration] = STATE(744),
    [sym_constructor_or_destructor_definition] = STATE(744),
    [sym_constructor_or_destructor_declaration] = STATE(744),
    [sym_friend_declaration] = STATE(744),
    [sym_access_specifier] = STATE(8203),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(744),
    [sym_alias_declaration] = STATE(744),
    [sym_static_assert_declaration] = STATE(744),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6635),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(744),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1829),
    [sym_identifier] = ACTIONS(2728),
    [aux_sym_preproc_def_token1] = ACTIONS(2899),
    [aux_sym_preproc_if_token1] = ACTIONS(2902),
    [aux_sym_preproc_if_token2] = ACTIONS(2737),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2905),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2905),
    [sym_preproc_directive] = ACTIONS(2908),
    [anon_sym_LPAREN2] = ACTIONS(2745),
    [anon_sym_TILDE] = ACTIONS(2748),
    [anon_sym_STAR] = ACTIONS(2751),
    [anon_sym_AMP_AMP] = ACTIONS(2754),
    [anon_sym_AMP] = ACTIONS(2757),
    [anon_sym___extension__] = ACTIONS(2911),
    [anon_sym_typedef] = ACTIONS(2914),
    [anon_sym_in] = ACTIONS(2766),
    [anon_sym_out] = ACTIONS(2766),
    [anon_sym_inout] = ACTIONS(2766),
    [anon_sym_extern] = ACTIONS(2769),
    [anon_sym___attribute__] = ACTIONS(2772),
    [anon_sym_COLON_COLON] = ACTIONS(2775),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2778),
    [anon_sym___declspec] = ACTIONS(2781),
    [anon_sym___based] = ACTIONS(2784),
    [anon_sym_signed] = ACTIONS(2787),
    [anon_sym_unsigned] = ACTIONS(2787),
    [anon_sym_long] = ACTIONS(2787),
    [anon_sym_short] = ACTIONS(2787),
    [anon_sym_LBRACK] = ACTIONS(2790),
    [anon_sym_static] = ACTIONS(2769),
    [anon_sym_register] = ACTIONS(2769),
    [anon_sym_inline] = ACTIONS(2769),
    [anon_sym___inline] = ACTIONS(2769),
    [anon_sym___inline__] = ACTIONS(2769),
    [anon_sym___forceinline] = ACTIONS(2769),
    [anon_sym_thread_local] = ACTIONS(2769),
    [anon_sym___thread] = ACTIONS(2769),
    [anon_sym_const] = ACTIONS(2793),
    [anon_sym_constexpr] = ACTIONS(2793),
    [anon_sym_volatile] = ACTIONS(2793),
    [anon_sym_restrict] = ACTIONS(2793),
    [anon_sym___restrict__] = ACTIONS(2793),
    [anon_sym__Atomic] = ACTIONS(2793),
    [anon_sym__Noreturn] = ACTIONS(2793),
    [anon_sym_noreturn] = ACTIONS(2793),
    [anon_sym_mutable] = ACTIONS(2793),
    [anon_sym_constinit] = ACTIONS(2793),
    [anon_sym_consteval] = ACTIONS(2793),
    [anon_sym_alignas] = ACTIONS(2796),
    [anon_sym__Alignas] = ACTIONS(2796),
    [sym_primitive_type] = ACTIONS(2799),
    [anon_sym_enum] = ACTIONS(2802),
    [anon_sym_class] = ACTIONS(2805),
    [anon_sym_struct] = ACTIONS(2808),
    [anon_sym_union] = ACTIONS(2811),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2814),
    [anon_sym_decltype] = ACTIONS(2817),
    [sym_virtual] = ACTIONS(2766),
    [anon_sym_explicit] = ACTIONS(2820),
    [anon_sym_typename] = ACTIONS(2823),
    [anon_sym_template] = ACTIONS(2917),
    [anon_sym_operator] = ACTIONS(2829),
    [anon_sym_friend] = ACTIONS(2920),
    [anon_sym_public] = ACTIONS(2835),
    [anon_sym_private] = ACTIONS(2835),
    [anon_sym_protected] = ACTIONS(2835),
    [anon_sym_using] = ACTIONS(2923),
    [anon_sym_static_assert] = ACTIONS(2926),
    [anon_sym_precise] = ACTIONS(2844),
    [anon_sym_shared] = ACTIONS(2844),
    [anon_sym_groupshared] = ACTIONS(2844),
    [anon_sym_uniform] = ACTIONS(2844),
    [anon_sym_row_major] = ACTIONS(2844),
    [anon_sym_column_major] = ACTIONS(2844),
    [anon_sym_globallycoherent] = ACTIONS(2844),
    [anon_sym_centroid] = ACTIONS(2844),
    [anon_sym_noperspective] = ACTIONS(2844),
    [anon_sym_nointerpolation] = ACTIONS(2844),
    [anon_sym_sample] = ACTIONS(2844),
    [anon_sym_linear] = ACTIONS(2844),
    [anon_sym_snorm] = ACTIONS(2844),
    [anon_sym_unorm] = ACTIONS(2844),
    [anon_sym_point] = ACTIONS(2844),
    [anon_sym_line] = ACTIONS(2844),
    [anon_sym_triangleadj] = ACTIONS(2844),
    [anon_sym_lineadj] = ACTIONS(2844),
    [anon_sym_triangle] = ACTIONS(2844),
  },
  [745] = {
    [sym_preproc_def] = STATE(797),
    [sym_preproc_function_def] = STATE(797),
    [sym_preproc_call] = STATE(797),
    [sym_preproc_if_in_field_declaration_list] = STATE(797),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(797),
    [sym_type_definition] = STATE(797),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(797),
    [sym_field_declaration] = STATE(797),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(797),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(797),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(797),
    [sym_operator_cast_declaration] = STATE(797),
    [sym_constructor_or_destructor_definition] = STATE(797),
    [sym_constructor_or_destructor_declaration] = STATE(797),
    [sym_friend_declaration] = STATE(797),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(797),
    [sym_alias_declaration] = STATE(797),
    [sym_static_assert_declaration] = STATE(797),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(797),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2929),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [746] = {
    [ts_builtin_sym_end] = ACTIONS(2480),
    [sym_identifier] = ACTIONS(2478),
    [aux_sym_preproc_include_token1] = ACTIONS(2478),
    [aux_sym_preproc_def_token1] = ACTIONS(2478),
    [aux_sym_preproc_if_token1] = ACTIONS(2478),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2478),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2478),
    [sym_preproc_directive] = ACTIONS(2478),
    [anon_sym_LPAREN2] = ACTIONS(2480),
    [anon_sym_BANG] = ACTIONS(2480),
    [anon_sym_TILDE] = ACTIONS(2480),
    [anon_sym_DASH] = ACTIONS(2478),
    [anon_sym_PLUS] = ACTIONS(2478),
    [anon_sym_STAR] = ACTIONS(2480),
    [anon_sym_AMP_AMP] = ACTIONS(2480),
    [anon_sym_AMP] = ACTIONS(2478),
    [anon_sym___extension__] = ACTIONS(2478),
    [anon_sym_typedef] = ACTIONS(2478),
    [anon_sym_in] = ACTIONS(2478),
    [anon_sym_out] = ACTIONS(2478),
    [anon_sym_inout] = ACTIONS(2478),
    [anon_sym_extern] = ACTIONS(2478),
    [anon_sym___attribute__] = ACTIONS(2478),
    [anon_sym_COLON_COLON] = ACTIONS(2480),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2480),
    [anon_sym___declspec] = ACTIONS(2478),
    [anon_sym___based] = ACTIONS(2478),
    [anon_sym___cdecl] = ACTIONS(2478),
    [anon_sym___clrcall] = ACTIONS(2478),
    [anon_sym___stdcall] = ACTIONS(2478),
    [anon_sym___fastcall] = ACTIONS(2478),
    [anon_sym___thiscall] = ACTIONS(2478),
    [anon_sym___vectorcall] = ACTIONS(2478),
    [anon_sym_LBRACE] = ACTIONS(2480),
    [anon_sym_signed] = ACTIONS(2478),
    [anon_sym_unsigned] = ACTIONS(2478),
    [anon_sym_long] = ACTIONS(2478),
    [anon_sym_short] = ACTIONS(2478),
    [anon_sym_LBRACK] = ACTIONS(2478),
    [anon_sym_static] = ACTIONS(2478),
    [anon_sym_register] = ACTIONS(2478),
    [anon_sym_inline] = ACTIONS(2478),
    [anon_sym___inline] = ACTIONS(2478),
    [anon_sym___inline__] = ACTIONS(2478),
    [anon_sym___forceinline] = ACTIONS(2478),
    [anon_sym_thread_local] = ACTIONS(2478),
    [anon_sym___thread] = ACTIONS(2478),
    [anon_sym_const] = ACTIONS(2478),
    [anon_sym_constexpr] = ACTIONS(2478),
    [anon_sym_volatile] = ACTIONS(2478),
    [anon_sym_restrict] = ACTIONS(2478),
    [anon_sym___restrict__] = ACTIONS(2478),
    [anon_sym__Atomic] = ACTIONS(2478),
    [anon_sym__Noreturn] = ACTIONS(2478),
    [anon_sym_noreturn] = ACTIONS(2478),
    [anon_sym_mutable] = ACTIONS(2478),
    [anon_sym_constinit] = ACTIONS(2478),
    [anon_sym_consteval] = ACTIONS(2478),
    [anon_sym_alignas] = ACTIONS(2478),
    [anon_sym__Alignas] = ACTIONS(2478),
    [sym_primitive_type] = ACTIONS(2478),
    [anon_sym_enum] = ACTIONS(2478),
    [anon_sym_class] = ACTIONS(2478),
    [anon_sym_struct] = ACTIONS(2478),
    [anon_sym_union] = ACTIONS(2478),
    [anon_sym_if] = ACTIONS(2478),
    [anon_sym_switch] = ACTIONS(2478),
    [anon_sym_case] = ACTIONS(2478),
    [anon_sym_default] = ACTIONS(2478),
    [anon_sym_while] = ACTIONS(2478),
    [anon_sym_do] = ACTIONS(2478),
    [anon_sym_for] = ACTIONS(2478),
    [anon_sym_return] = ACTIONS(2478),
    [anon_sym_break] = ACTIONS(2478),
    [anon_sym_continue] = ACTIONS(2478),
    [anon_sym_goto] = ACTIONS(2478),
    [anon_sym_not] = ACTIONS(2478),
    [anon_sym_compl] = ACTIONS(2478),
    [anon_sym_DASH_DASH] = ACTIONS(2480),
    [anon_sym_PLUS_PLUS] = ACTIONS(2480),
    [anon_sym_sizeof] = ACTIONS(2478),
    [anon_sym___alignof__] = ACTIONS(2478),
    [anon_sym___alignof] = ACTIONS(2478),
    [anon_sym__alignof] = ACTIONS(2478),
    [anon_sym_alignof] = ACTIONS(2478),
    [anon_sym__Alignof] = ACTIONS(2478),
    [anon_sym_offsetof] = ACTIONS(2478),
    [anon_sym__Generic] = ACTIONS(2478),
    [anon_sym_asm] = ACTIONS(2478),
    [anon_sym___asm__] = ACTIONS(2478),
    [sym_number_literal] = ACTIONS(2480),
    [anon_sym_L_SQUOTE] = ACTIONS(2480),
    [anon_sym_u_SQUOTE] = ACTIONS(2480),
    [anon_sym_U_SQUOTE] = ACTIONS(2480),
    [anon_sym_u8_SQUOTE] = ACTIONS(2480),
    [anon_sym_SQUOTE] = ACTIONS(2480),
    [anon_sym_L_DQUOTE] = ACTIONS(2480),
    [anon_sym_u_DQUOTE] = ACTIONS(2480),
    [anon_sym_U_DQUOTE] = ACTIONS(2480),
    [anon_sym_u8_DQUOTE] = ACTIONS(2480),
    [anon_sym_DQUOTE] = ACTIONS(2480),
    [sym_true] = ACTIONS(2478),
    [sym_false] = ACTIONS(2478),
    [anon_sym_NULL] = ACTIONS(2478),
    [anon_sym_nullptr] = ACTIONS(2478),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2478),
    [anon_sym_decltype] = ACTIONS(2478),
    [sym_virtual] = ACTIONS(2478),
    [anon_sym_explicit] = ACTIONS(2478),
    [anon_sym_typename] = ACTIONS(2478),
    [anon_sym_template] = ACTIONS(2478),
    [anon_sym_operator] = ACTIONS(2478),
    [anon_sym_try] = ACTIONS(2478),
    [anon_sym_delete] = ACTIONS(2478),
    [anon_sym_throw] = ACTIONS(2478),
    [anon_sym_namespace] = ACTIONS(2478),
    [anon_sym_using] = ACTIONS(2478),
    [anon_sym_static_assert] = ACTIONS(2478),
    [anon_sym_concept] = ACTIONS(2478),
    [anon_sym_co_return] = ACTIONS(2478),
    [anon_sym_co_yield] = ACTIONS(2478),
    [anon_sym_R_DQUOTE] = ACTIONS(2480),
    [anon_sym_LR_DQUOTE] = ACTIONS(2480),
    [anon_sym_uR_DQUOTE] = ACTIONS(2480),
    [anon_sym_UR_DQUOTE] = ACTIONS(2480),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2480),
    [anon_sym_co_await] = ACTIONS(2478),
    [anon_sym_new] = ACTIONS(2478),
    [anon_sym_requires] = ACTIONS(2478),
    [sym_this] = ACTIONS(2478),
    [anon_sym_precise] = ACTIONS(2478),
    [anon_sym_shared] = ACTIONS(2478),
    [anon_sym_groupshared] = ACTIONS(2478),
    [anon_sym_uniform] = ACTIONS(2478),
    [anon_sym_row_major] = ACTIONS(2478),
    [anon_sym_column_major] = ACTIONS(2478),
    [anon_sym_globallycoherent] = ACTIONS(2478),
    [anon_sym_centroid] = ACTIONS(2478),
    [anon_sym_noperspective] = ACTIONS(2478),
    [anon_sym_nointerpolation] = ACTIONS(2478),
    [anon_sym_sample] = ACTIONS(2478),
    [anon_sym_linear] = ACTIONS(2478),
    [anon_sym_snorm] = ACTIONS(2478),
    [anon_sym_unorm] = ACTIONS(2478),
    [anon_sym_point] = ACTIONS(2478),
    [anon_sym_line] = ACTIONS(2478),
    [anon_sym_triangleadj] = ACTIONS(2478),
    [anon_sym_lineadj] = ACTIONS(2478),
    [anon_sym_triangle] = ACTIONS(2478),
  },
  [747] = {
    [sym_preproc_def] = STATE(762),
    [sym_preproc_function_def] = STATE(762),
    [sym_preproc_call] = STATE(762),
    [sym_preproc_if_in_field_declaration_list] = STATE(762),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(762),
    [sym_type_definition] = STATE(762),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5542),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6069),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(762),
    [sym_field_declaration] = STATE(762),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1829),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(762),
    [sym_operator_cast] = STATE(6635),
    [sym_inline_method_definition] = STATE(762),
    [sym__constructor_specifiers] = STATE(1829),
    [sym_operator_cast_definition] = STATE(762),
    [sym_operator_cast_declaration] = STATE(762),
    [sym_constructor_or_destructor_definition] = STATE(762),
    [sym_constructor_or_destructor_declaration] = STATE(762),
    [sym_friend_declaration] = STATE(762),
    [sym_access_specifier] = STATE(8203),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(762),
    [sym_alias_declaration] = STATE(762),
    [sym_static_assert_declaration] = STATE(762),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6635),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(762),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1829),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2931),
    [aux_sym_preproc_if_token1] = ACTIONS(2933),
    [aux_sym_preproc_if_token2] = ACTIONS(2935),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2937),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2937),
    [sym_preproc_directive] = ACTIONS(2939),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2941),
    [anon_sym_typedef] = ACTIONS(2943),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2945),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2947),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2949),
    [anon_sym_static_assert] = ACTIONS(2951),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [748] = {
    [sym_preproc_def] = STATE(797),
    [sym_preproc_function_def] = STATE(797),
    [sym_preproc_call] = STATE(797),
    [sym_preproc_if_in_field_declaration_list] = STATE(797),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(797),
    [sym_type_definition] = STATE(797),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(797),
    [sym_field_declaration] = STATE(797),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(797),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(797),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(797),
    [sym_operator_cast_declaration] = STATE(797),
    [sym_constructor_or_destructor_definition] = STATE(797),
    [sym_constructor_or_destructor_declaration] = STATE(797),
    [sym_friend_declaration] = STATE(797),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(797),
    [sym_alias_declaration] = STATE(797),
    [sym_static_assert_declaration] = STATE(797),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(797),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2953),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [749] = {
    [ts_builtin_sym_end] = ACTIONS(2298),
    [sym_identifier] = ACTIONS(2296),
    [aux_sym_preproc_include_token1] = ACTIONS(2296),
    [aux_sym_preproc_def_token1] = ACTIONS(2296),
    [aux_sym_preproc_if_token1] = ACTIONS(2296),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2296),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2296),
    [sym_preproc_directive] = ACTIONS(2296),
    [anon_sym_LPAREN2] = ACTIONS(2298),
    [anon_sym_BANG] = ACTIONS(2298),
    [anon_sym_TILDE] = ACTIONS(2298),
    [anon_sym_DASH] = ACTIONS(2296),
    [anon_sym_PLUS] = ACTIONS(2296),
    [anon_sym_STAR] = ACTIONS(2298),
    [anon_sym_AMP_AMP] = ACTIONS(2298),
    [anon_sym_AMP] = ACTIONS(2296),
    [anon_sym___extension__] = ACTIONS(2296),
    [anon_sym_typedef] = ACTIONS(2296),
    [anon_sym_in] = ACTIONS(2296),
    [anon_sym_out] = ACTIONS(2296),
    [anon_sym_inout] = ACTIONS(2296),
    [anon_sym_extern] = ACTIONS(2296),
    [anon_sym___attribute__] = ACTIONS(2296),
    [anon_sym_COLON_COLON] = ACTIONS(2298),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2298),
    [anon_sym___declspec] = ACTIONS(2296),
    [anon_sym___based] = ACTIONS(2296),
    [anon_sym___cdecl] = ACTIONS(2296),
    [anon_sym___clrcall] = ACTIONS(2296),
    [anon_sym___stdcall] = ACTIONS(2296),
    [anon_sym___fastcall] = ACTIONS(2296),
    [anon_sym___thiscall] = ACTIONS(2296),
    [anon_sym___vectorcall] = ACTIONS(2296),
    [anon_sym_LBRACE] = ACTIONS(2298),
    [anon_sym_signed] = ACTIONS(2296),
    [anon_sym_unsigned] = ACTIONS(2296),
    [anon_sym_long] = ACTIONS(2296),
    [anon_sym_short] = ACTIONS(2296),
    [anon_sym_LBRACK] = ACTIONS(2296),
    [anon_sym_static] = ACTIONS(2296),
    [anon_sym_register] = ACTIONS(2296),
    [anon_sym_inline] = ACTIONS(2296),
    [anon_sym___inline] = ACTIONS(2296),
    [anon_sym___inline__] = ACTIONS(2296),
    [anon_sym___forceinline] = ACTIONS(2296),
    [anon_sym_thread_local] = ACTIONS(2296),
    [anon_sym___thread] = ACTIONS(2296),
    [anon_sym_const] = ACTIONS(2296),
    [anon_sym_constexpr] = ACTIONS(2296),
    [anon_sym_volatile] = ACTIONS(2296),
    [anon_sym_restrict] = ACTIONS(2296),
    [anon_sym___restrict__] = ACTIONS(2296),
    [anon_sym__Atomic] = ACTIONS(2296),
    [anon_sym__Noreturn] = ACTIONS(2296),
    [anon_sym_noreturn] = ACTIONS(2296),
    [anon_sym_mutable] = ACTIONS(2296),
    [anon_sym_constinit] = ACTIONS(2296),
    [anon_sym_consteval] = ACTIONS(2296),
    [anon_sym_alignas] = ACTIONS(2296),
    [anon_sym__Alignas] = ACTIONS(2296),
    [sym_primitive_type] = ACTIONS(2296),
    [anon_sym_enum] = ACTIONS(2296),
    [anon_sym_class] = ACTIONS(2296),
    [anon_sym_struct] = ACTIONS(2296),
    [anon_sym_union] = ACTIONS(2296),
    [anon_sym_if] = ACTIONS(2296),
    [anon_sym_switch] = ACTIONS(2296),
    [anon_sym_case] = ACTIONS(2296),
    [anon_sym_default] = ACTIONS(2296),
    [anon_sym_while] = ACTIONS(2296),
    [anon_sym_do] = ACTIONS(2296),
    [anon_sym_for] = ACTIONS(2296),
    [anon_sym_return] = ACTIONS(2296),
    [anon_sym_break] = ACTIONS(2296),
    [anon_sym_continue] = ACTIONS(2296),
    [anon_sym_goto] = ACTIONS(2296),
    [anon_sym_not] = ACTIONS(2296),
    [anon_sym_compl] = ACTIONS(2296),
    [anon_sym_DASH_DASH] = ACTIONS(2298),
    [anon_sym_PLUS_PLUS] = ACTIONS(2298),
    [anon_sym_sizeof] = ACTIONS(2296),
    [anon_sym___alignof__] = ACTIONS(2296),
    [anon_sym___alignof] = ACTIONS(2296),
    [anon_sym__alignof] = ACTIONS(2296),
    [anon_sym_alignof] = ACTIONS(2296),
    [anon_sym__Alignof] = ACTIONS(2296),
    [anon_sym_offsetof] = ACTIONS(2296),
    [anon_sym__Generic] = ACTIONS(2296),
    [anon_sym_asm] = ACTIONS(2296),
    [anon_sym___asm__] = ACTIONS(2296),
    [sym_number_literal] = ACTIONS(2298),
    [anon_sym_L_SQUOTE] = ACTIONS(2298),
    [anon_sym_u_SQUOTE] = ACTIONS(2298),
    [anon_sym_U_SQUOTE] = ACTIONS(2298),
    [anon_sym_u8_SQUOTE] = ACTIONS(2298),
    [anon_sym_SQUOTE] = ACTIONS(2298),
    [anon_sym_L_DQUOTE] = ACTIONS(2298),
    [anon_sym_u_DQUOTE] = ACTIONS(2298),
    [anon_sym_U_DQUOTE] = ACTIONS(2298),
    [anon_sym_u8_DQUOTE] = ACTIONS(2298),
    [anon_sym_DQUOTE] = ACTIONS(2298),
    [sym_true] = ACTIONS(2296),
    [sym_false] = ACTIONS(2296),
    [anon_sym_NULL] = ACTIONS(2296),
    [anon_sym_nullptr] = ACTIONS(2296),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2296),
    [anon_sym_decltype] = ACTIONS(2296),
    [sym_virtual] = ACTIONS(2296),
    [anon_sym_explicit] = ACTIONS(2296),
    [anon_sym_typename] = ACTIONS(2296),
    [anon_sym_template] = ACTIONS(2296),
    [anon_sym_operator] = ACTIONS(2296),
    [anon_sym_try] = ACTIONS(2296),
    [anon_sym_delete] = ACTIONS(2296),
    [anon_sym_throw] = ACTIONS(2296),
    [anon_sym_namespace] = ACTIONS(2296),
    [anon_sym_using] = ACTIONS(2296),
    [anon_sym_static_assert] = ACTIONS(2296),
    [anon_sym_concept] = ACTIONS(2296),
    [anon_sym_co_return] = ACTIONS(2296),
    [anon_sym_co_yield] = ACTIONS(2296),
    [anon_sym_R_DQUOTE] = ACTIONS(2298),
    [anon_sym_LR_DQUOTE] = ACTIONS(2298),
    [anon_sym_uR_DQUOTE] = ACTIONS(2298),
    [anon_sym_UR_DQUOTE] = ACTIONS(2298),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2298),
    [anon_sym_co_await] = ACTIONS(2296),
    [anon_sym_new] = ACTIONS(2296),
    [anon_sym_requires] = ACTIONS(2296),
    [sym_this] = ACTIONS(2296),
    [anon_sym_precise] = ACTIONS(2296),
    [anon_sym_shared] = ACTIONS(2296),
    [anon_sym_groupshared] = ACTIONS(2296),
    [anon_sym_uniform] = ACTIONS(2296),
    [anon_sym_row_major] = ACTIONS(2296),
    [anon_sym_column_major] = ACTIONS(2296),
    [anon_sym_globallycoherent] = ACTIONS(2296),
    [anon_sym_centroid] = ACTIONS(2296),
    [anon_sym_noperspective] = ACTIONS(2296),
    [anon_sym_nointerpolation] = ACTIONS(2296),
    [anon_sym_sample] = ACTIONS(2296),
    [anon_sym_linear] = ACTIONS(2296),
    [anon_sym_snorm] = ACTIONS(2296),
    [anon_sym_unorm] = ACTIONS(2296),
    [anon_sym_point] = ACTIONS(2296),
    [anon_sym_line] = ACTIONS(2296),
    [anon_sym_triangleadj] = ACTIONS(2296),
    [anon_sym_lineadj] = ACTIONS(2296),
    [anon_sym_triangle] = ACTIONS(2296),
  },
  [750] = {
    [ts_builtin_sym_end] = ACTIONS(2334),
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_include_token1] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_BANG] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_DASH] = ACTIONS(2332),
    [anon_sym_PLUS] = ACTIONS(2332),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym___cdecl] = ACTIONS(2332),
    [anon_sym___clrcall] = ACTIONS(2332),
    [anon_sym___stdcall] = ACTIONS(2332),
    [anon_sym___fastcall] = ACTIONS(2332),
    [anon_sym___thiscall] = ACTIONS(2332),
    [anon_sym___vectorcall] = ACTIONS(2332),
    [anon_sym_LBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_switch] = ACTIONS(2332),
    [anon_sym_case] = ACTIONS(2332),
    [anon_sym_default] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2332),
    [anon_sym_do] = ACTIONS(2332),
    [anon_sym_for] = ACTIONS(2332),
    [anon_sym_return] = ACTIONS(2332),
    [anon_sym_break] = ACTIONS(2332),
    [anon_sym_continue] = ACTIONS(2332),
    [anon_sym_goto] = ACTIONS(2332),
    [anon_sym_not] = ACTIONS(2332),
    [anon_sym_compl] = ACTIONS(2332),
    [anon_sym_DASH_DASH] = ACTIONS(2334),
    [anon_sym_PLUS_PLUS] = ACTIONS(2334),
    [anon_sym_sizeof] = ACTIONS(2332),
    [anon_sym___alignof__] = ACTIONS(2332),
    [anon_sym___alignof] = ACTIONS(2332),
    [anon_sym__alignof] = ACTIONS(2332),
    [anon_sym_alignof] = ACTIONS(2332),
    [anon_sym__Alignof] = ACTIONS(2332),
    [anon_sym_offsetof] = ACTIONS(2332),
    [anon_sym__Generic] = ACTIONS(2332),
    [anon_sym_asm] = ACTIONS(2332),
    [anon_sym___asm__] = ACTIONS(2332),
    [sym_number_literal] = ACTIONS(2334),
    [anon_sym_L_SQUOTE] = ACTIONS(2334),
    [anon_sym_u_SQUOTE] = ACTIONS(2334),
    [anon_sym_U_SQUOTE] = ACTIONS(2334),
    [anon_sym_u8_SQUOTE] = ACTIONS(2334),
    [anon_sym_SQUOTE] = ACTIONS(2334),
    [anon_sym_L_DQUOTE] = ACTIONS(2334),
    [anon_sym_u_DQUOTE] = ACTIONS(2334),
    [anon_sym_U_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8_DQUOTE] = ACTIONS(2334),
    [anon_sym_DQUOTE] = ACTIONS(2334),
    [sym_true] = ACTIONS(2332),
    [sym_false] = ACTIONS(2332),
    [anon_sym_NULL] = ACTIONS(2332),
    [anon_sym_nullptr] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_try] = ACTIONS(2332),
    [anon_sym_delete] = ACTIONS(2332),
    [anon_sym_throw] = ACTIONS(2332),
    [anon_sym_namespace] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_concept] = ACTIONS(2332),
    [anon_sym_co_return] = ACTIONS(2332),
    [anon_sym_co_yield] = ACTIONS(2332),
    [anon_sym_R_DQUOTE] = ACTIONS(2334),
    [anon_sym_LR_DQUOTE] = ACTIONS(2334),
    [anon_sym_uR_DQUOTE] = ACTIONS(2334),
    [anon_sym_UR_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2334),
    [anon_sym_co_await] = ACTIONS(2332),
    [anon_sym_new] = ACTIONS(2332),
    [anon_sym_requires] = ACTIONS(2332),
    [sym_this] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
  },
  [751] = {
    [ts_builtin_sym_end] = ACTIONS(2334),
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_include_token1] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_BANG] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_DASH] = ACTIONS(2332),
    [anon_sym_PLUS] = ACTIONS(2332),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym___cdecl] = ACTIONS(2332),
    [anon_sym___clrcall] = ACTIONS(2332),
    [anon_sym___stdcall] = ACTIONS(2332),
    [anon_sym___fastcall] = ACTIONS(2332),
    [anon_sym___thiscall] = ACTIONS(2332),
    [anon_sym___vectorcall] = ACTIONS(2332),
    [anon_sym_LBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_switch] = ACTIONS(2332),
    [anon_sym_case] = ACTIONS(2332),
    [anon_sym_default] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2332),
    [anon_sym_do] = ACTIONS(2332),
    [anon_sym_for] = ACTIONS(2332),
    [anon_sym_return] = ACTIONS(2332),
    [anon_sym_break] = ACTIONS(2332),
    [anon_sym_continue] = ACTIONS(2332),
    [anon_sym_goto] = ACTIONS(2332),
    [anon_sym_not] = ACTIONS(2332),
    [anon_sym_compl] = ACTIONS(2332),
    [anon_sym_DASH_DASH] = ACTIONS(2334),
    [anon_sym_PLUS_PLUS] = ACTIONS(2334),
    [anon_sym_sizeof] = ACTIONS(2332),
    [anon_sym___alignof__] = ACTIONS(2332),
    [anon_sym___alignof] = ACTIONS(2332),
    [anon_sym__alignof] = ACTIONS(2332),
    [anon_sym_alignof] = ACTIONS(2332),
    [anon_sym__Alignof] = ACTIONS(2332),
    [anon_sym_offsetof] = ACTIONS(2332),
    [anon_sym__Generic] = ACTIONS(2332),
    [anon_sym_asm] = ACTIONS(2332),
    [anon_sym___asm__] = ACTIONS(2332),
    [sym_number_literal] = ACTIONS(2334),
    [anon_sym_L_SQUOTE] = ACTIONS(2334),
    [anon_sym_u_SQUOTE] = ACTIONS(2334),
    [anon_sym_U_SQUOTE] = ACTIONS(2334),
    [anon_sym_u8_SQUOTE] = ACTIONS(2334),
    [anon_sym_SQUOTE] = ACTIONS(2334),
    [anon_sym_L_DQUOTE] = ACTIONS(2334),
    [anon_sym_u_DQUOTE] = ACTIONS(2334),
    [anon_sym_U_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8_DQUOTE] = ACTIONS(2334),
    [anon_sym_DQUOTE] = ACTIONS(2334),
    [sym_true] = ACTIONS(2332),
    [sym_false] = ACTIONS(2332),
    [anon_sym_NULL] = ACTIONS(2332),
    [anon_sym_nullptr] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_try] = ACTIONS(2332),
    [anon_sym_delete] = ACTIONS(2332),
    [anon_sym_throw] = ACTIONS(2332),
    [anon_sym_namespace] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_concept] = ACTIONS(2332),
    [anon_sym_co_return] = ACTIONS(2332),
    [anon_sym_co_yield] = ACTIONS(2332),
    [anon_sym_R_DQUOTE] = ACTIONS(2334),
    [anon_sym_LR_DQUOTE] = ACTIONS(2334),
    [anon_sym_uR_DQUOTE] = ACTIONS(2334),
    [anon_sym_UR_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2334),
    [anon_sym_co_await] = ACTIONS(2332),
    [anon_sym_new] = ACTIONS(2332),
    [anon_sym_requires] = ACTIONS(2332),
    [sym_this] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
  },
  [752] = {
    [ts_builtin_sym_end] = ACTIONS(2326),
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_include_token1] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_BANG] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_DASH] = ACTIONS(2324),
    [anon_sym_PLUS] = ACTIONS(2324),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym___cdecl] = ACTIONS(2324),
    [anon_sym___clrcall] = ACTIONS(2324),
    [anon_sym___stdcall] = ACTIONS(2324),
    [anon_sym___fastcall] = ACTIONS(2324),
    [anon_sym___thiscall] = ACTIONS(2324),
    [anon_sym___vectorcall] = ACTIONS(2324),
    [anon_sym_LBRACE] = ACTIONS(2326),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [anon_sym_if] = ACTIONS(2324),
    [anon_sym_switch] = ACTIONS(2324),
    [anon_sym_case] = ACTIONS(2324),
    [anon_sym_default] = ACTIONS(2324),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_do] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2324),
    [anon_sym_return] = ACTIONS(2324),
    [anon_sym_break] = ACTIONS(2324),
    [anon_sym_continue] = ACTIONS(2324),
    [anon_sym_goto] = ACTIONS(2324),
    [anon_sym_not] = ACTIONS(2324),
    [anon_sym_compl] = ACTIONS(2324),
    [anon_sym_DASH_DASH] = ACTIONS(2326),
    [anon_sym_PLUS_PLUS] = ACTIONS(2326),
    [anon_sym_sizeof] = ACTIONS(2324),
    [anon_sym___alignof__] = ACTIONS(2324),
    [anon_sym___alignof] = ACTIONS(2324),
    [anon_sym__alignof] = ACTIONS(2324),
    [anon_sym_alignof] = ACTIONS(2324),
    [anon_sym__Alignof] = ACTIONS(2324),
    [anon_sym_offsetof] = ACTIONS(2324),
    [anon_sym__Generic] = ACTIONS(2324),
    [anon_sym_asm] = ACTIONS(2324),
    [anon_sym___asm__] = ACTIONS(2324),
    [sym_number_literal] = ACTIONS(2326),
    [anon_sym_L_SQUOTE] = ACTIONS(2326),
    [anon_sym_u_SQUOTE] = ACTIONS(2326),
    [anon_sym_U_SQUOTE] = ACTIONS(2326),
    [anon_sym_u8_SQUOTE] = ACTIONS(2326),
    [anon_sym_SQUOTE] = ACTIONS(2326),
    [anon_sym_L_DQUOTE] = ACTIONS(2326),
    [anon_sym_u_DQUOTE] = ACTIONS(2326),
    [anon_sym_U_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8_DQUOTE] = ACTIONS(2326),
    [anon_sym_DQUOTE] = ACTIONS(2326),
    [sym_true] = ACTIONS(2324),
    [sym_false] = ACTIONS(2324),
    [anon_sym_NULL] = ACTIONS(2324),
    [anon_sym_nullptr] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_try] = ACTIONS(2324),
    [anon_sym_delete] = ACTIONS(2324),
    [anon_sym_throw] = ACTIONS(2324),
    [anon_sym_namespace] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_concept] = ACTIONS(2324),
    [anon_sym_co_return] = ACTIONS(2324),
    [anon_sym_co_yield] = ACTIONS(2324),
    [anon_sym_R_DQUOTE] = ACTIONS(2326),
    [anon_sym_LR_DQUOTE] = ACTIONS(2326),
    [anon_sym_uR_DQUOTE] = ACTIONS(2326),
    [anon_sym_UR_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2326),
    [anon_sym_co_await] = ACTIONS(2324),
    [anon_sym_new] = ACTIONS(2324),
    [anon_sym_requires] = ACTIONS(2324),
    [sym_this] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
  },
  [753] = {
    [ts_builtin_sym_end] = ACTIONS(2456),
    [sym_identifier] = ACTIONS(2454),
    [aux_sym_preproc_include_token1] = ACTIONS(2454),
    [aux_sym_preproc_def_token1] = ACTIONS(2454),
    [aux_sym_preproc_if_token1] = ACTIONS(2454),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2454),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2454),
    [sym_preproc_directive] = ACTIONS(2454),
    [anon_sym_LPAREN2] = ACTIONS(2456),
    [anon_sym_BANG] = ACTIONS(2456),
    [anon_sym_TILDE] = ACTIONS(2456),
    [anon_sym_DASH] = ACTIONS(2454),
    [anon_sym_PLUS] = ACTIONS(2454),
    [anon_sym_STAR] = ACTIONS(2456),
    [anon_sym_AMP_AMP] = ACTIONS(2456),
    [anon_sym_AMP] = ACTIONS(2454),
    [anon_sym___extension__] = ACTIONS(2454),
    [anon_sym_typedef] = ACTIONS(2454),
    [anon_sym_in] = ACTIONS(2454),
    [anon_sym_out] = ACTIONS(2454),
    [anon_sym_inout] = ACTIONS(2454),
    [anon_sym_extern] = ACTIONS(2454),
    [anon_sym___attribute__] = ACTIONS(2454),
    [anon_sym_COLON_COLON] = ACTIONS(2456),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2456),
    [anon_sym___declspec] = ACTIONS(2454),
    [anon_sym___based] = ACTIONS(2454),
    [anon_sym___cdecl] = ACTIONS(2454),
    [anon_sym___clrcall] = ACTIONS(2454),
    [anon_sym___stdcall] = ACTIONS(2454),
    [anon_sym___fastcall] = ACTIONS(2454),
    [anon_sym___thiscall] = ACTIONS(2454),
    [anon_sym___vectorcall] = ACTIONS(2454),
    [anon_sym_LBRACE] = ACTIONS(2456),
    [anon_sym_signed] = ACTIONS(2454),
    [anon_sym_unsigned] = ACTIONS(2454),
    [anon_sym_long] = ACTIONS(2454),
    [anon_sym_short] = ACTIONS(2454),
    [anon_sym_LBRACK] = ACTIONS(2454),
    [anon_sym_static] = ACTIONS(2454),
    [anon_sym_register] = ACTIONS(2454),
    [anon_sym_inline] = ACTIONS(2454),
    [anon_sym___inline] = ACTIONS(2454),
    [anon_sym___inline__] = ACTIONS(2454),
    [anon_sym___forceinline] = ACTIONS(2454),
    [anon_sym_thread_local] = ACTIONS(2454),
    [anon_sym___thread] = ACTIONS(2454),
    [anon_sym_const] = ACTIONS(2454),
    [anon_sym_constexpr] = ACTIONS(2454),
    [anon_sym_volatile] = ACTIONS(2454),
    [anon_sym_restrict] = ACTIONS(2454),
    [anon_sym___restrict__] = ACTIONS(2454),
    [anon_sym__Atomic] = ACTIONS(2454),
    [anon_sym__Noreturn] = ACTIONS(2454),
    [anon_sym_noreturn] = ACTIONS(2454),
    [anon_sym_mutable] = ACTIONS(2454),
    [anon_sym_constinit] = ACTIONS(2454),
    [anon_sym_consteval] = ACTIONS(2454),
    [anon_sym_alignas] = ACTIONS(2454),
    [anon_sym__Alignas] = ACTIONS(2454),
    [sym_primitive_type] = ACTIONS(2454),
    [anon_sym_enum] = ACTIONS(2454),
    [anon_sym_class] = ACTIONS(2454),
    [anon_sym_struct] = ACTIONS(2454),
    [anon_sym_union] = ACTIONS(2454),
    [anon_sym_if] = ACTIONS(2454),
    [anon_sym_switch] = ACTIONS(2454),
    [anon_sym_case] = ACTIONS(2454),
    [anon_sym_default] = ACTIONS(2454),
    [anon_sym_while] = ACTIONS(2454),
    [anon_sym_do] = ACTIONS(2454),
    [anon_sym_for] = ACTIONS(2454),
    [anon_sym_return] = ACTIONS(2454),
    [anon_sym_break] = ACTIONS(2454),
    [anon_sym_continue] = ACTIONS(2454),
    [anon_sym_goto] = ACTIONS(2454),
    [anon_sym_not] = ACTIONS(2454),
    [anon_sym_compl] = ACTIONS(2454),
    [anon_sym_DASH_DASH] = ACTIONS(2456),
    [anon_sym_PLUS_PLUS] = ACTIONS(2456),
    [anon_sym_sizeof] = ACTIONS(2454),
    [anon_sym___alignof__] = ACTIONS(2454),
    [anon_sym___alignof] = ACTIONS(2454),
    [anon_sym__alignof] = ACTIONS(2454),
    [anon_sym_alignof] = ACTIONS(2454),
    [anon_sym__Alignof] = ACTIONS(2454),
    [anon_sym_offsetof] = ACTIONS(2454),
    [anon_sym__Generic] = ACTIONS(2454),
    [anon_sym_asm] = ACTIONS(2454),
    [anon_sym___asm__] = ACTIONS(2454),
    [sym_number_literal] = ACTIONS(2456),
    [anon_sym_L_SQUOTE] = ACTIONS(2456),
    [anon_sym_u_SQUOTE] = ACTIONS(2456),
    [anon_sym_U_SQUOTE] = ACTIONS(2456),
    [anon_sym_u8_SQUOTE] = ACTIONS(2456),
    [anon_sym_SQUOTE] = ACTIONS(2456),
    [anon_sym_L_DQUOTE] = ACTIONS(2456),
    [anon_sym_u_DQUOTE] = ACTIONS(2456),
    [anon_sym_U_DQUOTE] = ACTIONS(2456),
    [anon_sym_u8_DQUOTE] = ACTIONS(2456),
    [anon_sym_DQUOTE] = ACTIONS(2456),
    [sym_true] = ACTIONS(2454),
    [sym_false] = ACTIONS(2454),
    [anon_sym_NULL] = ACTIONS(2454),
    [anon_sym_nullptr] = ACTIONS(2454),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2454),
    [anon_sym_decltype] = ACTIONS(2454),
    [sym_virtual] = ACTIONS(2454),
    [anon_sym_explicit] = ACTIONS(2454),
    [anon_sym_typename] = ACTIONS(2454),
    [anon_sym_template] = ACTIONS(2454),
    [anon_sym_operator] = ACTIONS(2454),
    [anon_sym_try] = ACTIONS(2454),
    [anon_sym_delete] = ACTIONS(2454),
    [anon_sym_throw] = ACTIONS(2454),
    [anon_sym_namespace] = ACTIONS(2454),
    [anon_sym_using] = ACTIONS(2454),
    [anon_sym_static_assert] = ACTIONS(2454),
    [anon_sym_concept] = ACTIONS(2454),
    [anon_sym_co_return] = ACTIONS(2454),
    [anon_sym_co_yield] = ACTIONS(2454),
    [anon_sym_R_DQUOTE] = ACTIONS(2456),
    [anon_sym_LR_DQUOTE] = ACTIONS(2456),
    [anon_sym_uR_DQUOTE] = ACTIONS(2456),
    [anon_sym_UR_DQUOTE] = ACTIONS(2456),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2456),
    [anon_sym_co_await] = ACTIONS(2454),
    [anon_sym_new] = ACTIONS(2454),
    [anon_sym_requires] = ACTIONS(2454),
    [sym_this] = ACTIONS(2454),
    [anon_sym_precise] = ACTIONS(2454),
    [anon_sym_shared] = ACTIONS(2454),
    [anon_sym_groupshared] = ACTIONS(2454),
    [anon_sym_uniform] = ACTIONS(2454),
    [anon_sym_row_major] = ACTIONS(2454),
    [anon_sym_column_major] = ACTIONS(2454),
    [anon_sym_globallycoherent] = ACTIONS(2454),
    [anon_sym_centroid] = ACTIONS(2454),
    [anon_sym_noperspective] = ACTIONS(2454),
    [anon_sym_nointerpolation] = ACTIONS(2454),
    [anon_sym_sample] = ACTIONS(2454),
    [anon_sym_linear] = ACTIONS(2454),
    [anon_sym_snorm] = ACTIONS(2454),
    [anon_sym_unorm] = ACTIONS(2454),
    [anon_sym_point] = ACTIONS(2454),
    [anon_sym_line] = ACTIONS(2454),
    [anon_sym_triangleadj] = ACTIONS(2454),
    [anon_sym_lineadj] = ACTIONS(2454),
    [anon_sym_triangle] = ACTIONS(2454),
  },
  [754] = {
    [ts_builtin_sym_end] = ACTIONS(2522),
    [sym_identifier] = ACTIONS(2520),
    [aux_sym_preproc_include_token1] = ACTIONS(2520),
    [aux_sym_preproc_def_token1] = ACTIONS(2520),
    [aux_sym_preproc_if_token1] = ACTIONS(2520),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2520),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2520),
    [sym_preproc_directive] = ACTIONS(2520),
    [anon_sym_LPAREN2] = ACTIONS(2522),
    [anon_sym_BANG] = ACTIONS(2522),
    [anon_sym_TILDE] = ACTIONS(2522),
    [anon_sym_DASH] = ACTIONS(2520),
    [anon_sym_PLUS] = ACTIONS(2520),
    [anon_sym_STAR] = ACTIONS(2522),
    [anon_sym_AMP_AMP] = ACTIONS(2522),
    [anon_sym_AMP] = ACTIONS(2520),
    [anon_sym___extension__] = ACTIONS(2520),
    [anon_sym_typedef] = ACTIONS(2520),
    [anon_sym_in] = ACTIONS(2520),
    [anon_sym_out] = ACTIONS(2520),
    [anon_sym_inout] = ACTIONS(2520),
    [anon_sym_extern] = ACTIONS(2520),
    [anon_sym___attribute__] = ACTIONS(2520),
    [anon_sym_COLON_COLON] = ACTIONS(2522),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2522),
    [anon_sym___declspec] = ACTIONS(2520),
    [anon_sym___based] = ACTIONS(2520),
    [anon_sym___cdecl] = ACTIONS(2520),
    [anon_sym___clrcall] = ACTIONS(2520),
    [anon_sym___stdcall] = ACTIONS(2520),
    [anon_sym___fastcall] = ACTIONS(2520),
    [anon_sym___thiscall] = ACTIONS(2520),
    [anon_sym___vectorcall] = ACTIONS(2520),
    [anon_sym_LBRACE] = ACTIONS(2522),
    [anon_sym_signed] = ACTIONS(2520),
    [anon_sym_unsigned] = ACTIONS(2520),
    [anon_sym_long] = ACTIONS(2520),
    [anon_sym_short] = ACTIONS(2520),
    [anon_sym_LBRACK] = ACTIONS(2520),
    [anon_sym_static] = ACTIONS(2520),
    [anon_sym_register] = ACTIONS(2520),
    [anon_sym_inline] = ACTIONS(2520),
    [anon_sym___inline] = ACTIONS(2520),
    [anon_sym___inline__] = ACTIONS(2520),
    [anon_sym___forceinline] = ACTIONS(2520),
    [anon_sym_thread_local] = ACTIONS(2520),
    [anon_sym___thread] = ACTIONS(2520),
    [anon_sym_const] = ACTIONS(2520),
    [anon_sym_constexpr] = ACTIONS(2520),
    [anon_sym_volatile] = ACTIONS(2520),
    [anon_sym_restrict] = ACTIONS(2520),
    [anon_sym___restrict__] = ACTIONS(2520),
    [anon_sym__Atomic] = ACTIONS(2520),
    [anon_sym__Noreturn] = ACTIONS(2520),
    [anon_sym_noreturn] = ACTIONS(2520),
    [anon_sym_mutable] = ACTIONS(2520),
    [anon_sym_constinit] = ACTIONS(2520),
    [anon_sym_consteval] = ACTIONS(2520),
    [anon_sym_alignas] = ACTIONS(2520),
    [anon_sym__Alignas] = ACTIONS(2520),
    [sym_primitive_type] = ACTIONS(2520),
    [anon_sym_enum] = ACTIONS(2520),
    [anon_sym_class] = ACTIONS(2520),
    [anon_sym_struct] = ACTIONS(2520),
    [anon_sym_union] = ACTIONS(2520),
    [anon_sym_if] = ACTIONS(2520),
    [anon_sym_switch] = ACTIONS(2520),
    [anon_sym_case] = ACTIONS(2520),
    [anon_sym_default] = ACTIONS(2520),
    [anon_sym_while] = ACTIONS(2520),
    [anon_sym_do] = ACTIONS(2520),
    [anon_sym_for] = ACTIONS(2520),
    [anon_sym_return] = ACTIONS(2520),
    [anon_sym_break] = ACTIONS(2520),
    [anon_sym_continue] = ACTIONS(2520),
    [anon_sym_goto] = ACTIONS(2520),
    [anon_sym_not] = ACTIONS(2520),
    [anon_sym_compl] = ACTIONS(2520),
    [anon_sym_DASH_DASH] = ACTIONS(2522),
    [anon_sym_PLUS_PLUS] = ACTIONS(2522),
    [anon_sym_sizeof] = ACTIONS(2520),
    [anon_sym___alignof__] = ACTIONS(2520),
    [anon_sym___alignof] = ACTIONS(2520),
    [anon_sym__alignof] = ACTIONS(2520),
    [anon_sym_alignof] = ACTIONS(2520),
    [anon_sym__Alignof] = ACTIONS(2520),
    [anon_sym_offsetof] = ACTIONS(2520),
    [anon_sym__Generic] = ACTIONS(2520),
    [anon_sym_asm] = ACTIONS(2520),
    [anon_sym___asm__] = ACTIONS(2520),
    [sym_number_literal] = ACTIONS(2522),
    [anon_sym_L_SQUOTE] = ACTIONS(2522),
    [anon_sym_u_SQUOTE] = ACTIONS(2522),
    [anon_sym_U_SQUOTE] = ACTIONS(2522),
    [anon_sym_u8_SQUOTE] = ACTIONS(2522),
    [anon_sym_SQUOTE] = ACTIONS(2522),
    [anon_sym_L_DQUOTE] = ACTIONS(2522),
    [anon_sym_u_DQUOTE] = ACTIONS(2522),
    [anon_sym_U_DQUOTE] = ACTIONS(2522),
    [anon_sym_u8_DQUOTE] = ACTIONS(2522),
    [anon_sym_DQUOTE] = ACTIONS(2522),
    [sym_true] = ACTIONS(2520),
    [sym_false] = ACTIONS(2520),
    [anon_sym_NULL] = ACTIONS(2520),
    [anon_sym_nullptr] = ACTIONS(2520),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2520),
    [anon_sym_decltype] = ACTIONS(2520),
    [sym_virtual] = ACTIONS(2520),
    [anon_sym_explicit] = ACTIONS(2520),
    [anon_sym_typename] = ACTIONS(2520),
    [anon_sym_template] = ACTIONS(2520),
    [anon_sym_operator] = ACTIONS(2520),
    [anon_sym_try] = ACTIONS(2520),
    [anon_sym_delete] = ACTIONS(2520),
    [anon_sym_throw] = ACTIONS(2520),
    [anon_sym_namespace] = ACTIONS(2520),
    [anon_sym_using] = ACTIONS(2520),
    [anon_sym_static_assert] = ACTIONS(2520),
    [anon_sym_concept] = ACTIONS(2520),
    [anon_sym_co_return] = ACTIONS(2520),
    [anon_sym_co_yield] = ACTIONS(2520),
    [anon_sym_R_DQUOTE] = ACTIONS(2522),
    [anon_sym_LR_DQUOTE] = ACTIONS(2522),
    [anon_sym_uR_DQUOTE] = ACTIONS(2522),
    [anon_sym_UR_DQUOTE] = ACTIONS(2522),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2522),
    [anon_sym_co_await] = ACTIONS(2520),
    [anon_sym_new] = ACTIONS(2520),
    [anon_sym_requires] = ACTIONS(2520),
    [sym_this] = ACTIONS(2520),
    [anon_sym_precise] = ACTIONS(2520),
    [anon_sym_shared] = ACTIONS(2520),
    [anon_sym_groupshared] = ACTIONS(2520),
    [anon_sym_uniform] = ACTIONS(2520),
    [anon_sym_row_major] = ACTIONS(2520),
    [anon_sym_column_major] = ACTIONS(2520),
    [anon_sym_globallycoherent] = ACTIONS(2520),
    [anon_sym_centroid] = ACTIONS(2520),
    [anon_sym_noperspective] = ACTIONS(2520),
    [anon_sym_nointerpolation] = ACTIONS(2520),
    [anon_sym_sample] = ACTIONS(2520),
    [anon_sym_linear] = ACTIONS(2520),
    [anon_sym_snorm] = ACTIONS(2520),
    [anon_sym_unorm] = ACTIONS(2520),
    [anon_sym_point] = ACTIONS(2520),
    [anon_sym_line] = ACTIONS(2520),
    [anon_sym_triangleadj] = ACTIONS(2520),
    [anon_sym_lineadj] = ACTIONS(2520),
    [anon_sym_triangle] = ACTIONS(2520),
  },
  [755] = {
    [ts_builtin_sym_end] = ACTIONS(2395),
    [sym_identifier] = ACTIONS(2393),
    [aux_sym_preproc_include_token1] = ACTIONS(2393),
    [aux_sym_preproc_def_token1] = ACTIONS(2393),
    [aux_sym_preproc_if_token1] = ACTIONS(2393),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2393),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2393),
    [sym_preproc_directive] = ACTIONS(2393),
    [anon_sym_LPAREN2] = ACTIONS(2395),
    [anon_sym_BANG] = ACTIONS(2395),
    [anon_sym_TILDE] = ACTIONS(2395),
    [anon_sym_DASH] = ACTIONS(2393),
    [anon_sym_PLUS] = ACTIONS(2393),
    [anon_sym_STAR] = ACTIONS(2395),
    [anon_sym_AMP_AMP] = ACTIONS(2395),
    [anon_sym_AMP] = ACTIONS(2393),
    [anon_sym___extension__] = ACTIONS(2393),
    [anon_sym_typedef] = ACTIONS(2393),
    [anon_sym_in] = ACTIONS(2393),
    [anon_sym_out] = ACTIONS(2393),
    [anon_sym_inout] = ACTIONS(2393),
    [anon_sym_extern] = ACTIONS(2393),
    [anon_sym___attribute__] = ACTIONS(2393),
    [anon_sym_COLON_COLON] = ACTIONS(2395),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2395),
    [anon_sym___declspec] = ACTIONS(2393),
    [anon_sym___based] = ACTIONS(2393),
    [anon_sym___cdecl] = ACTIONS(2393),
    [anon_sym___clrcall] = ACTIONS(2393),
    [anon_sym___stdcall] = ACTIONS(2393),
    [anon_sym___fastcall] = ACTIONS(2393),
    [anon_sym___thiscall] = ACTIONS(2393),
    [anon_sym___vectorcall] = ACTIONS(2393),
    [anon_sym_LBRACE] = ACTIONS(2395),
    [anon_sym_signed] = ACTIONS(2393),
    [anon_sym_unsigned] = ACTIONS(2393),
    [anon_sym_long] = ACTIONS(2393),
    [anon_sym_short] = ACTIONS(2393),
    [anon_sym_LBRACK] = ACTIONS(2393),
    [anon_sym_static] = ACTIONS(2393),
    [anon_sym_register] = ACTIONS(2393),
    [anon_sym_inline] = ACTIONS(2393),
    [anon_sym___inline] = ACTIONS(2393),
    [anon_sym___inline__] = ACTIONS(2393),
    [anon_sym___forceinline] = ACTIONS(2393),
    [anon_sym_thread_local] = ACTIONS(2393),
    [anon_sym___thread] = ACTIONS(2393),
    [anon_sym_const] = ACTIONS(2393),
    [anon_sym_constexpr] = ACTIONS(2393),
    [anon_sym_volatile] = ACTIONS(2393),
    [anon_sym_restrict] = ACTIONS(2393),
    [anon_sym___restrict__] = ACTIONS(2393),
    [anon_sym__Atomic] = ACTIONS(2393),
    [anon_sym__Noreturn] = ACTIONS(2393),
    [anon_sym_noreturn] = ACTIONS(2393),
    [anon_sym_mutable] = ACTIONS(2393),
    [anon_sym_constinit] = ACTIONS(2393),
    [anon_sym_consteval] = ACTIONS(2393),
    [anon_sym_alignas] = ACTIONS(2393),
    [anon_sym__Alignas] = ACTIONS(2393),
    [sym_primitive_type] = ACTIONS(2393),
    [anon_sym_enum] = ACTIONS(2393),
    [anon_sym_class] = ACTIONS(2393),
    [anon_sym_struct] = ACTIONS(2393),
    [anon_sym_union] = ACTIONS(2393),
    [anon_sym_if] = ACTIONS(2393),
    [anon_sym_switch] = ACTIONS(2393),
    [anon_sym_case] = ACTIONS(2393),
    [anon_sym_default] = ACTIONS(2393),
    [anon_sym_while] = ACTIONS(2393),
    [anon_sym_do] = ACTIONS(2393),
    [anon_sym_for] = ACTIONS(2393),
    [anon_sym_return] = ACTIONS(2393),
    [anon_sym_break] = ACTIONS(2393),
    [anon_sym_continue] = ACTIONS(2393),
    [anon_sym_goto] = ACTIONS(2393),
    [anon_sym_not] = ACTIONS(2393),
    [anon_sym_compl] = ACTIONS(2393),
    [anon_sym_DASH_DASH] = ACTIONS(2395),
    [anon_sym_PLUS_PLUS] = ACTIONS(2395),
    [anon_sym_sizeof] = ACTIONS(2393),
    [anon_sym___alignof__] = ACTIONS(2393),
    [anon_sym___alignof] = ACTIONS(2393),
    [anon_sym__alignof] = ACTIONS(2393),
    [anon_sym_alignof] = ACTIONS(2393),
    [anon_sym__Alignof] = ACTIONS(2393),
    [anon_sym_offsetof] = ACTIONS(2393),
    [anon_sym__Generic] = ACTIONS(2393),
    [anon_sym_asm] = ACTIONS(2393),
    [anon_sym___asm__] = ACTIONS(2393),
    [sym_number_literal] = ACTIONS(2395),
    [anon_sym_L_SQUOTE] = ACTIONS(2395),
    [anon_sym_u_SQUOTE] = ACTIONS(2395),
    [anon_sym_U_SQUOTE] = ACTIONS(2395),
    [anon_sym_u8_SQUOTE] = ACTIONS(2395),
    [anon_sym_SQUOTE] = ACTIONS(2395),
    [anon_sym_L_DQUOTE] = ACTIONS(2395),
    [anon_sym_u_DQUOTE] = ACTIONS(2395),
    [anon_sym_U_DQUOTE] = ACTIONS(2395),
    [anon_sym_u8_DQUOTE] = ACTIONS(2395),
    [anon_sym_DQUOTE] = ACTIONS(2395),
    [sym_true] = ACTIONS(2393),
    [sym_false] = ACTIONS(2393),
    [anon_sym_NULL] = ACTIONS(2393),
    [anon_sym_nullptr] = ACTIONS(2393),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2393),
    [anon_sym_decltype] = ACTIONS(2393),
    [sym_virtual] = ACTIONS(2393),
    [anon_sym_explicit] = ACTIONS(2393),
    [anon_sym_typename] = ACTIONS(2393),
    [anon_sym_template] = ACTIONS(2393),
    [anon_sym_operator] = ACTIONS(2393),
    [anon_sym_try] = ACTIONS(2393),
    [anon_sym_delete] = ACTIONS(2393),
    [anon_sym_throw] = ACTIONS(2393),
    [anon_sym_namespace] = ACTIONS(2393),
    [anon_sym_using] = ACTIONS(2393),
    [anon_sym_static_assert] = ACTIONS(2393),
    [anon_sym_concept] = ACTIONS(2393),
    [anon_sym_co_return] = ACTIONS(2393),
    [anon_sym_co_yield] = ACTIONS(2393),
    [anon_sym_R_DQUOTE] = ACTIONS(2395),
    [anon_sym_LR_DQUOTE] = ACTIONS(2395),
    [anon_sym_uR_DQUOTE] = ACTIONS(2395),
    [anon_sym_UR_DQUOTE] = ACTIONS(2395),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2395),
    [anon_sym_co_await] = ACTIONS(2393),
    [anon_sym_new] = ACTIONS(2393),
    [anon_sym_requires] = ACTIONS(2393),
    [sym_this] = ACTIONS(2393),
    [anon_sym_precise] = ACTIONS(2393),
    [anon_sym_shared] = ACTIONS(2393),
    [anon_sym_groupshared] = ACTIONS(2393),
    [anon_sym_uniform] = ACTIONS(2393),
    [anon_sym_row_major] = ACTIONS(2393),
    [anon_sym_column_major] = ACTIONS(2393),
    [anon_sym_globallycoherent] = ACTIONS(2393),
    [anon_sym_centroid] = ACTIONS(2393),
    [anon_sym_noperspective] = ACTIONS(2393),
    [anon_sym_nointerpolation] = ACTIONS(2393),
    [anon_sym_sample] = ACTIONS(2393),
    [anon_sym_linear] = ACTIONS(2393),
    [anon_sym_snorm] = ACTIONS(2393),
    [anon_sym_unorm] = ACTIONS(2393),
    [anon_sym_point] = ACTIONS(2393),
    [anon_sym_line] = ACTIONS(2393),
    [anon_sym_triangleadj] = ACTIONS(2393),
    [anon_sym_lineadj] = ACTIONS(2393),
    [anon_sym_triangle] = ACTIONS(2393),
  },
  [756] = {
    [ts_builtin_sym_end] = ACTIONS(2575),
    [sym_identifier] = ACTIONS(2573),
    [aux_sym_preproc_include_token1] = ACTIONS(2573),
    [aux_sym_preproc_def_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2573),
    [sym_preproc_directive] = ACTIONS(2573),
    [anon_sym_LPAREN2] = ACTIONS(2575),
    [anon_sym_BANG] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(2575),
    [anon_sym_DASH] = ACTIONS(2573),
    [anon_sym_PLUS] = ACTIONS(2573),
    [anon_sym_STAR] = ACTIONS(2575),
    [anon_sym_AMP_AMP] = ACTIONS(2575),
    [anon_sym_AMP] = ACTIONS(2573),
    [anon_sym___extension__] = ACTIONS(2573),
    [anon_sym_typedef] = ACTIONS(2573),
    [anon_sym_in] = ACTIONS(2573),
    [anon_sym_out] = ACTIONS(2573),
    [anon_sym_inout] = ACTIONS(2573),
    [anon_sym_extern] = ACTIONS(2573),
    [anon_sym___attribute__] = ACTIONS(2573),
    [anon_sym_COLON_COLON] = ACTIONS(2575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2575),
    [anon_sym___declspec] = ACTIONS(2573),
    [anon_sym___based] = ACTIONS(2573),
    [anon_sym___cdecl] = ACTIONS(2573),
    [anon_sym___clrcall] = ACTIONS(2573),
    [anon_sym___stdcall] = ACTIONS(2573),
    [anon_sym___fastcall] = ACTIONS(2573),
    [anon_sym___thiscall] = ACTIONS(2573),
    [anon_sym___vectorcall] = ACTIONS(2573),
    [anon_sym_LBRACE] = ACTIONS(2575),
    [anon_sym_signed] = ACTIONS(2573),
    [anon_sym_unsigned] = ACTIONS(2573),
    [anon_sym_long] = ACTIONS(2573),
    [anon_sym_short] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2573),
    [anon_sym_static] = ACTIONS(2573),
    [anon_sym_register] = ACTIONS(2573),
    [anon_sym_inline] = ACTIONS(2573),
    [anon_sym___inline] = ACTIONS(2573),
    [anon_sym___inline__] = ACTIONS(2573),
    [anon_sym___forceinline] = ACTIONS(2573),
    [anon_sym_thread_local] = ACTIONS(2573),
    [anon_sym___thread] = ACTIONS(2573),
    [anon_sym_const] = ACTIONS(2573),
    [anon_sym_constexpr] = ACTIONS(2573),
    [anon_sym_volatile] = ACTIONS(2573),
    [anon_sym_restrict] = ACTIONS(2573),
    [anon_sym___restrict__] = ACTIONS(2573),
    [anon_sym__Atomic] = ACTIONS(2573),
    [anon_sym__Noreturn] = ACTIONS(2573),
    [anon_sym_noreturn] = ACTIONS(2573),
    [anon_sym_mutable] = ACTIONS(2573),
    [anon_sym_constinit] = ACTIONS(2573),
    [anon_sym_consteval] = ACTIONS(2573),
    [anon_sym_alignas] = ACTIONS(2573),
    [anon_sym__Alignas] = ACTIONS(2573),
    [sym_primitive_type] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_class] = ACTIONS(2573),
    [anon_sym_struct] = ACTIONS(2573),
    [anon_sym_union] = ACTIONS(2573),
    [anon_sym_if] = ACTIONS(2573),
    [anon_sym_switch] = ACTIONS(2573),
    [anon_sym_case] = ACTIONS(2573),
    [anon_sym_default] = ACTIONS(2573),
    [anon_sym_while] = ACTIONS(2573),
    [anon_sym_do] = ACTIONS(2573),
    [anon_sym_for] = ACTIONS(2573),
    [anon_sym_return] = ACTIONS(2573),
    [anon_sym_break] = ACTIONS(2573),
    [anon_sym_continue] = ACTIONS(2573),
    [anon_sym_goto] = ACTIONS(2573),
    [anon_sym_not] = ACTIONS(2573),
    [anon_sym_compl] = ACTIONS(2573),
    [anon_sym_DASH_DASH] = ACTIONS(2575),
    [anon_sym_PLUS_PLUS] = ACTIONS(2575),
    [anon_sym_sizeof] = ACTIONS(2573),
    [anon_sym___alignof__] = ACTIONS(2573),
    [anon_sym___alignof] = ACTIONS(2573),
    [anon_sym__alignof] = ACTIONS(2573),
    [anon_sym_alignof] = ACTIONS(2573),
    [anon_sym__Alignof] = ACTIONS(2573),
    [anon_sym_offsetof] = ACTIONS(2573),
    [anon_sym__Generic] = ACTIONS(2573),
    [anon_sym_asm] = ACTIONS(2573),
    [anon_sym___asm__] = ACTIONS(2573),
    [sym_number_literal] = ACTIONS(2575),
    [anon_sym_L_SQUOTE] = ACTIONS(2575),
    [anon_sym_u_SQUOTE] = ACTIONS(2575),
    [anon_sym_U_SQUOTE] = ACTIONS(2575),
    [anon_sym_u8_SQUOTE] = ACTIONS(2575),
    [anon_sym_SQUOTE] = ACTIONS(2575),
    [anon_sym_L_DQUOTE] = ACTIONS(2575),
    [anon_sym_u_DQUOTE] = ACTIONS(2575),
    [anon_sym_U_DQUOTE] = ACTIONS(2575),
    [anon_sym_u8_DQUOTE] = ACTIONS(2575),
    [anon_sym_DQUOTE] = ACTIONS(2575),
    [sym_true] = ACTIONS(2573),
    [sym_false] = ACTIONS(2573),
    [anon_sym_NULL] = ACTIONS(2573),
    [anon_sym_nullptr] = ACTIONS(2573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2573),
    [anon_sym_decltype] = ACTIONS(2573),
    [sym_virtual] = ACTIONS(2573),
    [anon_sym_explicit] = ACTIONS(2573),
    [anon_sym_typename] = ACTIONS(2573),
    [anon_sym_template] = ACTIONS(2573),
    [anon_sym_operator] = ACTIONS(2573),
    [anon_sym_try] = ACTIONS(2573),
    [anon_sym_delete] = ACTIONS(2573),
    [anon_sym_throw] = ACTIONS(2573),
    [anon_sym_namespace] = ACTIONS(2573),
    [anon_sym_using] = ACTIONS(2573),
    [anon_sym_static_assert] = ACTIONS(2573),
    [anon_sym_concept] = ACTIONS(2573),
    [anon_sym_co_return] = ACTIONS(2573),
    [anon_sym_co_yield] = ACTIONS(2573),
    [anon_sym_R_DQUOTE] = ACTIONS(2575),
    [anon_sym_LR_DQUOTE] = ACTIONS(2575),
    [anon_sym_uR_DQUOTE] = ACTIONS(2575),
    [anon_sym_UR_DQUOTE] = ACTIONS(2575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2575),
    [anon_sym_co_await] = ACTIONS(2573),
    [anon_sym_new] = ACTIONS(2573),
    [anon_sym_requires] = ACTIONS(2573),
    [sym_this] = ACTIONS(2573),
    [anon_sym_precise] = ACTIONS(2573),
    [anon_sym_shared] = ACTIONS(2573),
    [anon_sym_groupshared] = ACTIONS(2573),
    [anon_sym_uniform] = ACTIONS(2573),
    [anon_sym_row_major] = ACTIONS(2573),
    [anon_sym_column_major] = ACTIONS(2573),
    [anon_sym_globallycoherent] = ACTIONS(2573),
    [anon_sym_centroid] = ACTIONS(2573),
    [anon_sym_noperspective] = ACTIONS(2573),
    [anon_sym_nointerpolation] = ACTIONS(2573),
    [anon_sym_sample] = ACTIONS(2573),
    [anon_sym_linear] = ACTIONS(2573),
    [anon_sym_snorm] = ACTIONS(2573),
    [anon_sym_unorm] = ACTIONS(2573),
    [anon_sym_point] = ACTIONS(2573),
    [anon_sym_line] = ACTIONS(2573),
    [anon_sym_triangleadj] = ACTIONS(2573),
    [anon_sym_lineadj] = ACTIONS(2573),
    [anon_sym_triangle] = ACTIONS(2573),
  },
  [757] = {
    [ts_builtin_sym_end] = ACTIONS(2955),
    [sym_identifier] = ACTIONS(2958),
    [aux_sym_preproc_include_token1] = ACTIONS(2958),
    [aux_sym_preproc_def_token1] = ACTIONS(2958),
    [aux_sym_preproc_if_token1] = ACTIONS(2958),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2958),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2958),
    [sym_preproc_directive] = ACTIONS(2958),
    [anon_sym_LPAREN2] = ACTIONS(2955),
    [anon_sym_BANG] = ACTIONS(2955),
    [anon_sym_TILDE] = ACTIONS(2955),
    [anon_sym_DASH] = ACTIONS(2958),
    [anon_sym_PLUS] = ACTIONS(2958),
    [anon_sym_STAR] = ACTIONS(2955),
    [anon_sym_AMP_AMP] = ACTIONS(2955),
    [anon_sym_AMP] = ACTIONS(2958),
    [anon_sym___extension__] = ACTIONS(2958),
    [anon_sym_typedef] = ACTIONS(2958),
    [anon_sym_in] = ACTIONS(2958),
    [anon_sym_out] = ACTIONS(2958),
    [anon_sym_inout] = ACTIONS(2958),
    [anon_sym_extern] = ACTIONS(2958),
    [anon_sym___attribute__] = ACTIONS(2958),
    [anon_sym_COLON_COLON] = ACTIONS(2955),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2955),
    [anon_sym___declspec] = ACTIONS(2958),
    [anon_sym___based] = ACTIONS(2958),
    [anon_sym___cdecl] = ACTIONS(2958),
    [anon_sym___clrcall] = ACTIONS(2958),
    [anon_sym___stdcall] = ACTIONS(2958),
    [anon_sym___fastcall] = ACTIONS(2958),
    [anon_sym___thiscall] = ACTIONS(2958),
    [anon_sym___vectorcall] = ACTIONS(2958),
    [anon_sym_LBRACE] = ACTIONS(2955),
    [anon_sym_signed] = ACTIONS(2958),
    [anon_sym_unsigned] = ACTIONS(2958),
    [anon_sym_long] = ACTIONS(2958),
    [anon_sym_short] = ACTIONS(2958),
    [anon_sym_LBRACK] = ACTIONS(2958),
    [anon_sym_static] = ACTIONS(2958),
    [anon_sym_register] = ACTIONS(2958),
    [anon_sym_inline] = ACTIONS(2958),
    [anon_sym___inline] = ACTIONS(2958),
    [anon_sym___inline__] = ACTIONS(2958),
    [anon_sym___forceinline] = ACTIONS(2958),
    [anon_sym_thread_local] = ACTIONS(2958),
    [anon_sym___thread] = ACTIONS(2958),
    [anon_sym_const] = ACTIONS(2958),
    [anon_sym_constexpr] = ACTIONS(2958),
    [anon_sym_volatile] = ACTIONS(2958),
    [anon_sym_restrict] = ACTIONS(2958),
    [anon_sym___restrict__] = ACTIONS(2958),
    [anon_sym__Atomic] = ACTIONS(2958),
    [anon_sym__Noreturn] = ACTIONS(2958),
    [anon_sym_noreturn] = ACTIONS(2958),
    [anon_sym_mutable] = ACTIONS(2958),
    [anon_sym_constinit] = ACTIONS(2958),
    [anon_sym_consteval] = ACTIONS(2958),
    [anon_sym_alignas] = ACTIONS(2958),
    [anon_sym__Alignas] = ACTIONS(2958),
    [sym_primitive_type] = ACTIONS(2958),
    [anon_sym_enum] = ACTIONS(2958),
    [anon_sym_class] = ACTIONS(2958),
    [anon_sym_struct] = ACTIONS(2958),
    [anon_sym_union] = ACTIONS(2958),
    [anon_sym_if] = ACTIONS(2958),
    [anon_sym_switch] = ACTIONS(2958),
    [anon_sym_case] = ACTIONS(2958),
    [anon_sym_default] = ACTIONS(2958),
    [anon_sym_while] = ACTIONS(2958),
    [anon_sym_do] = ACTIONS(2958),
    [anon_sym_for] = ACTIONS(2958),
    [anon_sym_return] = ACTIONS(2958),
    [anon_sym_break] = ACTIONS(2958),
    [anon_sym_continue] = ACTIONS(2958),
    [anon_sym_goto] = ACTIONS(2958),
    [anon_sym_not] = ACTIONS(2958),
    [anon_sym_compl] = ACTIONS(2958),
    [anon_sym_DASH_DASH] = ACTIONS(2955),
    [anon_sym_PLUS_PLUS] = ACTIONS(2955),
    [anon_sym_sizeof] = ACTIONS(2958),
    [anon_sym___alignof__] = ACTIONS(2958),
    [anon_sym___alignof] = ACTIONS(2958),
    [anon_sym__alignof] = ACTIONS(2958),
    [anon_sym_alignof] = ACTIONS(2958),
    [anon_sym__Alignof] = ACTIONS(2958),
    [anon_sym_offsetof] = ACTIONS(2958),
    [anon_sym__Generic] = ACTIONS(2958),
    [anon_sym_asm] = ACTIONS(2958),
    [anon_sym___asm__] = ACTIONS(2958),
    [sym_number_literal] = ACTIONS(2955),
    [anon_sym_L_SQUOTE] = ACTIONS(2955),
    [anon_sym_u_SQUOTE] = ACTIONS(2955),
    [anon_sym_U_SQUOTE] = ACTIONS(2955),
    [anon_sym_u8_SQUOTE] = ACTIONS(2955),
    [anon_sym_SQUOTE] = ACTIONS(2955),
    [anon_sym_L_DQUOTE] = ACTIONS(2955),
    [anon_sym_u_DQUOTE] = ACTIONS(2955),
    [anon_sym_U_DQUOTE] = ACTIONS(2955),
    [anon_sym_u8_DQUOTE] = ACTIONS(2955),
    [anon_sym_DQUOTE] = ACTIONS(2955),
    [sym_true] = ACTIONS(2958),
    [sym_false] = ACTIONS(2958),
    [anon_sym_NULL] = ACTIONS(2958),
    [anon_sym_nullptr] = ACTIONS(2958),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2958),
    [anon_sym_decltype] = ACTIONS(2958),
    [sym_virtual] = ACTIONS(2958),
    [anon_sym_explicit] = ACTIONS(2958),
    [anon_sym_typename] = ACTIONS(2958),
    [anon_sym_template] = ACTIONS(2958),
    [anon_sym_operator] = ACTIONS(2958),
    [anon_sym_try] = ACTIONS(2958),
    [anon_sym_delete] = ACTIONS(2958),
    [anon_sym_throw] = ACTIONS(2958),
    [anon_sym_namespace] = ACTIONS(2958),
    [anon_sym_using] = ACTIONS(2958),
    [anon_sym_static_assert] = ACTIONS(2958),
    [anon_sym_concept] = ACTIONS(2958),
    [anon_sym_co_return] = ACTIONS(2958),
    [anon_sym_co_yield] = ACTIONS(2958),
    [anon_sym_R_DQUOTE] = ACTIONS(2955),
    [anon_sym_LR_DQUOTE] = ACTIONS(2955),
    [anon_sym_uR_DQUOTE] = ACTIONS(2955),
    [anon_sym_UR_DQUOTE] = ACTIONS(2955),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2955),
    [anon_sym_co_await] = ACTIONS(2958),
    [anon_sym_new] = ACTIONS(2958),
    [anon_sym_requires] = ACTIONS(2958),
    [sym_this] = ACTIONS(2958),
    [anon_sym_precise] = ACTIONS(2958),
    [anon_sym_shared] = ACTIONS(2958),
    [anon_sym_groupshared] = ACTIONS(2958),
    [anon_sym_uniform] = ACTIONS(2958),
    [anon_sym_row_major] = ACTIONS(2958),
    [anon_sym_column_major] = ACTIONS(2958),
    [anon_sym_globallycoherent] = ACTIONS(2958),
    [anon_sym_centroid] = ACTIONS(2958),
    [anon_sym_noperspective] = ACTIONS(2958),
    [anon_sym_nointerpolation] = ACTIONS(2958),
    [anon_sym_sample] = ACTIONS(2958),
    [anon_sym_linear] = ACTIONS(2958),
    [anon_sym_snorm] = ACTIONS(2958),
    [anon_sym_unorm] = ACTIONS(2958),
    [anon_sym_point] = ACTIONS(2958),
    [anon_sym_line] = ACTIONS(2958),
    [anon_sym_triangleadj] = ACTIONS(2958),
    [anon_sym_lineadj] = ACTIONS(2958),
    [anon_sym_triangle] = ACTIONS(2958),
  },
  [758] = {
    [ts_builtin_sym_end] = ACTIONS(2512),
    [sym_identifier] = ACTIONS(2510),
    [aux_sym_preproc_include_token1] = ACTIONS(2510),
    [aux_sym_preproc_def_token1] = ACTIONS(2510),
    [aux_sym_preproc_if_token1] = ACTIONS(2510),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2510),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2510),
    [sym_preproc_directive] = ACTIONS(2510),
    [anon_sym_LPAREN2] = ACTIONS(2512),
    [anon_sym_BANG] = ACTIONS(2512),
    [anon_sym_TILDE] = ACTIONS(2512),
    [anon_sym_DASH] = ACTIONS(2510),
    [anon_sym_PLUS] = ACTIONS(2510),
    [anon_sym_STAR] = ACTIONS(2512),
    [anon_sym_AMP_AMP] = ACTIONS(2512),
    [anon_sym_AMP] = ACTIONS(2510),
    [anon_sym___extension__] = ACTIONS(2510),
    [anon_sym_typedef] = ACTIONS(2510),
    [anon_sym_in] = ACTIONS(2510),
    [anon_sym_out] = ACTIONS(2510),
    [anon_sym_inout] = ACTIONS(2510),
    [anon_sym_extern] = ACTIONS(2510),
    [anon_sym___attribute__] = ACTIONS(2510),
    [anon_sym_COLON_COLON] = ACTIONS(2512),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2512),
    [anon_sym___declspec] = ACTIONS(2510),
    [anon_sym___based] = ACTIONS(2510),
    [anon_sym___cdecl] = ACTIONS(2510),
    [anon_sym___clrcall] = ACTIONS(2510),
    [anon_sym___stdcall] = ACTIONS(2510),
    [anon_sym___fastcall] = ACTIONS(2510),
    [anon_sym___thiscall] = ACTIONS(2510),
    [anon_sym___vectorcall] = ACTIONS(2510),
    [anon_sym_LBRACE] = ACTIONS(2512),
    [anon_sym_signed] = ACTIONS(2510),
    [anon_sym_unsigned] = ACTIONS(2510),
    [anon_sym_long] = ACTIONS(2510),
    [anon_sym_short] = ACTIONS(2510),
    [anon_sym_LBRACK] = ACTIONS(2510),
    [anon_sym_static] = ACTIONS(2510),
    [anon_sym_register] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(2510),
    [anon_sym___inline] = ACTIONS(2510),
    [anon_sym___inline__] = ACTIONS(2510),
    [anon_sym___forceinline] = ACTIONS(2510),
    [anon_sym_thread_local] = ACTIONS(2510),
    [anon_sym___thread] = ACTIONS(2510),
    [anon_sym_const] = ACTIONS(2510),
    [anon_sym_constexpr] = ACTIONS(2510),
    [anon_sym_volatile] = ACTIONS(2510),
    [anon_sym_restrict] = ACTIONS(2510),
    [anon_sym___restrict__] = ACTIONS(2510),
    [anon_sym__Atomic] = ACTIONS(2510),
    [anon_sym__Noreturn] = ACTIONS(2510),
    [anon_sym_noreturn] = ACTIONS(2510),
    [anon_sym_mutable] = ACTIONS(2510),
    [anon_sym_constinit] = ACTIONS(2510),
    [anon_sym_consteval] = ACTIONS(2510),
    [anon_sym_alignas] = ACTIONS(2510),
    [anon_sym__Alignas] = ACTIONS(2510),
    [sym_primitive_type] = ACTIONS(2510),
    [anon_sym_enum] = ACTIONS(2510),
    [anon_sym_class] = ACTIONS(2510),
    [anon_sym_struct] = ACTIONS(2510),
    [anon_sym_union] = ACTIONS(2510),
    [anon_sym_if] = ACTIONS(2510),
    [anon_sym_switch] = ACTIONS(2510),
    [anon_sym_case] = ACTIONS(2510),
    [anon_sym_default] = ACTIONS(2510),
    [anon_sym_while] = ACTIONS(2510),
    [anon_sym_do] = ACTIONS(2510),
    [anon_sym_for] = ACTIONS(2510),
    [anon_sym_return] = ACTIONS(2510),
    [anon_sym_break] = ACTIONS(2510),
    [anon_sym_continue] = ACTIONS(2510),
    [anon_sym_goto] = ACTIONS(2510),
    [anon_sym_not] = ACTIONS(2510),
    [anon_sym_compl] = ACTIONS(2510),
    [anon_sym_DASH_DASH] = ACTIONS(2512),
    [anon_sym_PLUS_PLUS] = ACTIONS(2512),
    [anon_sym_sizeof] = ACTIONS(2510),
    [anon_sym___alignof__] = ACTIONS(2510),
    [anon_sym___alignof] = ACTIONS(2510),
    [anon_sym__alignof] = ACTIONS(2510),
    [anon_sym_alignof] = ACTIONS(2510),
    [anon_sym__Alignof] = ACTIONS(2510),
    [anon_sym_offsetof] = ACTIONS(2510),
    [anon_sym__Generic] = ACTIONS(2510),
    [anon_sym_asm] = ACTIONS(2510),
    [anon_sym___asm__] = ACTIONS(2510),
    [sym_number_literal] = ACTIONS(2512),
    [anon_sym_L_SQUOTE] = ACTIONS(2512),
    [anon_sym_u_SQUOTE] = ACTIONS(2512),
    [anon_sym_U_SQUOTE] = ACTIONS(2512),
    [anon_sym_u8_SQUOTE] = ACTIONS(2512),
    [anon_sym_SQUOTE] = ACTIONS(2512),
    [anon_sym_L_DQUOTE] = ACTIONS(2512),
    [anon_sym_u_DQUOTE] = ACTIONS(2512),
    [anon_sym_U_DQUOTE] = ACTIONS(2512),
    [anon_sym_u8_DQUOTE] = ACTIONS(2512),
    [anon_sym_DQUOTE] = ACTIONS(2512),
    [sym_true] = ACTIONS(2510),
    [sym_false] = ACTIONS(2510),
    [anon_sym_NULL] = ACTIONS(2510),
    [anon_sym_nullptr] = ACTIONS(2510),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2510),
    [anon_sym_decltype] = ACTIONS(2510),
    [sym_virtual] = ACTIONS(2510),
    [anon_sym_explicit] = ACTIONS(2510),
    [anon_sym_typename] = ACTIONS(2510),
    [anon_sym_template] = ACTIONS(2510),
    [anon_sym_operator] = ACTIONS(2510),
    [anon_sym_try] = ACTIONS(2510),
    [anon_sym_delete] = ACTIONS(2510),
    [anon_sym_throw] = ACTIONS(2510),
    [anon_sym_namespace] = ACTIONS(2510),
    [anon_sym_using] = ACTIONS(2510),
    [anon_sym_static_assert] = ACTIONS(2510),
    [anon_sym_concept] = ACTIONS(2510),
    [anon_sym_co_return] = ACTIONS(2510),
    [anon_sym_co_yield] = ACTIONS(2510),
    [anon_sym_R_DQUOTE] = ACTIONS(2512),
    [anon_sym_LR_DQUOTE] = ACTIONS(2512),
    [anon_sym_uR_DQUOTE] = ACTIONS(2512),
    [anon_sym_UR_DQUOTE] = ACTIONS(2512),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2512),
    [anon_sym_co_await] = ACTIONS(2510),
    [anon_sym_new] = ACTIONS(2510),
    [anon_sym_requires] = ACTIONS(2510),
    [sym_this] = ACTIONS(2510),
    [anon_sym_precise] = ACTIONS(2510),
    [anon_sym_shared] = ACTIONS(2510),
    [anon_sym_groupshared] = ACTIONS(2510),
    [anon_sym_uniform] = ACTIONS(2510),
    [anon_sym_row_major] = ACTIONS(2510),
    [anon_sym_column_major] = ACTIONS(2510),
    [anon_sym_globallycoherent] = ACTIONS(2510),
    [anon_sym_centroid] = ACTIONS(2510),
    [anon_sym_noperspective] = ACTIONS(2510),
    [anon_sym_nointerpolation] = ACTIONS(2510),
    [anon_sym_sample] = ACTIONS(2510),
    [anon_sym_linear] = ACTIONS(2510),
    [anon_sym_snorm] = ACTIONS(2510),
    [anon_sym_unorm] = ACTIONS(2510),
    [anon_sym_point] = ACTIONS(2510),
    [anon_sym_line] = ACTIONS(2510),
    [anon_sym_triangleadj] = ACTIONS(2510),
    [anon_sym_lineadj] = ACTIONS(2510),
    [anon_sym_triangle] = ACTIONS(2510),
  },
  [759] = {
    [sym_preproc_def] = STATE(712),
    [sym_preproc_function_def] = STATE(712),
    [sym_preproc_call] = STATE(712),
    [sym_preproc_if_in_field_declaration_list] = STATE(712),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(712),
    [sym_type_definition] = STATE(712),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(712),
    [sym_field_declaration] = STATE(712),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(712),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(712),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(712),
    [sym_operator_cast_declaration] = STATE(712),
    [sym_constructor_or_destructor_definition] = STATE(712),
    [sym_constructor_or_destructor_declaration] = STATE(712),
    [sym_friend_declaration] = STATE(712),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(712),
    [sym_alias_declaration] = STATE(712),
    [sym_static_assert_declaration] = STATE(712),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(712),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2961),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [760] = {
    [ts_builtin_sym_end] = ACTIONS(2508),
    [sym_identifier] = ACTIONS(2506),
    [aux_sym_preproc_include_token1] = ACTIONS(2506),
    [aux_sym_preproc_def_token1] = ACTIONS(2506),
    [aux_sym_preproc_if_token1] = ACTIONS(2506),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2506),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2506),
    [sym_preproc_directive] = ACTIONS(2506),
    [anon_sym_LPAREN2] = ACTIONS(2508),
    [anon_sym_BANG] = ACTIONS(2508),
    [anon_sym_TILDE] = ACTIONS(2508),
    [anon_sym_DASH] = ACTIONS(2506),
    [anon_sym_PLUS] = ACTIONS(2506),
    [anon_sym_STAR] = ACTIONS(2508),
    [anon_sym_AMP_AMP] = ACTIONS(2508),
    [anon_sym_AMP] = ACTIONS(2506),
    [anon_sym___extension__] = ACTIONS(2506),
    [anon_sym_typedef] = ACTIONS(2506),
    [anon_sym_in] = ACTIONS(2506),
    [anon_sym_out] = ACTIONS(2506),
    [anon_sym_inout] = ACTIONS(2506),
    [anon_sym_extern] = ACTIONS(2506),
    [anon_sym___attribute__] = ACTIONS(2506),
    [anon_sym_COLON_COLON] = ACTIONS(2508),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2508),
    [anon_sym___declspec] = ACTIONS(2506),
    [anon_sym___based] = ACTIONS(2506),
    [anon_sym___cdecl] = ACTIONS(2506),
    [anon_sym___clrcall] = ACTIONS(2506),
    [anon_sym___stdcall] = ACTIONS(2506),
    [anon_sym___fastcall] = ACTIONS(2506),
    [anon_sym___thiscall] = ACTIONS(2506),
    [anon_sym___vectorcall] = ACTIONS(2506),
    [anon_sym_LBRACE] = ACTIONS(2508),
    [anon_sym_signed] = ACTIONS(2506),
    [anon_sym_unsigned] = ACTIONS(2506),
    [anon_sym_long] = ACTIONS(2506),
    [anon_sym_short] = ACTIONS(2506),
    [anon_sym_LBRACK] = ACTIONS(2506),
    [anon_sym_static] = ACTIONS(2506),
    [anon_sym_register] = ACTIONS(2506),
    [anon_sym_inline] = ACTIONS(2506),
    [anon_sym___inline] = ACTIONS(2506),
    [anon_sym___inline__] = ACTIONS(2506),
    [anon_sym___forceinline] = ACTIONS(2506),
    [anon_sym_thread_local] = ACTIONS(2506),
    [anon_sym___thread] = ACTIONS(2506),
    [anon_sym_const] = ACTIONS(2506),
    [anon_sym_constexpr] = ACTIONS(2506),
    [anon_sym_volatile] = ACTIONS(2506),
    [anon_sym_restrict] = ACTIONS(2506),
    [anon_sym___restrict__] = ACTIONS(2506),
    [anon_sym__Atomic] = ACTIONS(2506),
    [anon_sym__Noreturn] = ACTIONS(2506),
    [anon_sym_noreturn] = ACTIONS(2506),
    [anon_sym_mutable] = ACTIONS(2506),
    [anon_sym_constinit] = ACTIONS(2506),
    [anon_sym_consteval] = ACTIONS(2506),
    [anon_sym_alignas] = ACTIONS(2506),
    [anon_sym__Alignas] = ACTIONS(2506),
    [sym_primitive_type] = ACTIONS(2506),
    [anon_sym_enum] = ACTIONS(2506),
    [anon_sym_class] = ACTIONS(2506),
    [anon_sym_struct] = ACTIONS(2506),
    [anon_sym_union] = ACTIONS(2506),
    [anon_sym_if] = ACTIONS(2506),
    [anon_sym_switch] = ACTIONS(2506),
    [anon_sym_case] = ACTIONS(2506),
    [anon_sym_default] = ACTIONS(2506),
    [anon_sym_while] = ACTIONS(2506),
    [anon_sym_do] = ACTIONS(2506),
    [anon_sym_for] = ACTIONS(2506),
    [anon_sym_return] = ACTIONS(2506),
    [anon_sym_break] = ACTIONS(2506),
    [anon_sym_continue] = ACTIONS(2506),
    [anon_sym_goto] = ACTIONS(2506),
    [anon_sym_not] = ACTIONS(2506),
    [anon_sym_compl] = ACTIONS(2506),
    [anon_sym_DASH_DASH] = ACTIONS(2508),
    [anon_sym_PLUS_PLUS] = ACTIONS(2508),
    [anon_sym_sizeof] = ACTIONS(2506),
    [anon_sym___alignof__] = ACTIONS(2506),
    [anon_sym___alignof] = ACTIONS(2506),
    [anon_sym__alignof] = ACTIONS(2506),
    [anon_sym_alignof] = ACTIONS(2506),
    [anon_sym__Alignof] = ACTIONS(2506),
    [anon_sym_offsetof] = ACTIONS(2506),
    [anon_sym__Generic] = ACTIONS(2506),
    [anon_sym_asm] = ACTIONS(2506),
    [anon_sym___asm__] = ACTIONS(2506),
    [sym_number_literal] = ACTIONS(2508),
    [anon_sym_L_SQUOTE] = ACTIONS(2508),
    [anon_sym_u_SQUOTE] = ACTIONS(2508),
    [anon_sym_U_SQUOTE] = ACTIONS(2508),
    [anon_sym_u8_SQUOTE] = ACTIONS(2508),
    [anon_sym_SQUOTE] = ACTIONS(2508),
    [anon_sym_L_DQUOTE] = ACTIONS(2508),
    [anon_sym_u_DQUOTE] = ACTIONS(2508),
    [anon_sym_U_DQUOTE] = ACTIONS(2508),
    [anon_sym_u8_DQUOTE] = ACTIONS(2508),
    [anon_sym_DQUOTE] = ACTIONS(2508),
    [sym_true] = ACTIONS(2506),
    [sym_false] = ACTIONS(2506),
    [anon_sym_NULL] = ACTIONS(2506),
    [anon_sym_nullptr] = ACTIONS(2506),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2506),
    [anon_sym_decltype] = ACTIONS(2506),
    [sym_virtual] = ACTIONS(2506),
    [anon_sym_explicit] = ACTIONS(2506),
    [anon_sym_typename] = ACTIONS(2506),
    [anon_sym_template] = ACTIONS(2506),
    [anon_sym_operator] = ACTIONS(2506),
    [anon_sym_try] = ACTIONS(2506),
    [anon_sym_delete] = ACTIONS(2506),
    [anon_sym_throw] = ACTIONS(2506),
    [anon_sym_namespace] = ACTIONS(2506),
    [anon_sym_using] = ACTIONS(2506),
    [anon_sym_static_assert] = ACTIONS(2506),
    [anon_sym_concept] = ACTIONS(2506),
    [anon_sym_co_return] = ACTIONS(2506),
    [anon_sym_co_yield] = ACTIONS(2506),
    [anon_sym_R_DQUOTE] = ACTIONS(2508),
    [anon_sym_LR_DQUOTE] = ACTIONS(2508),
    [anon_sym_uR_DQUOTE] = ACTIONS(2508),
    [anon_sym_UR_DQUOTE] = ACTIONS(2508),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2508),
    [anon_sym_co_await] = ACTIONS(2506),
    [anon_sym_new] = ACTIONS(2506),
    [anon_sym_requires] = ACTIONS(2506),
    [sym_this] = ACTIONS(2506),
    [anon_sym_precise] = ACTIONS(2506),
    [anon_sym_shared] = ACTIONS(2506),
    [anon_sym_groupshared] = ACTIONS(2506),
    [anon_sym_uniform] = ACTIONS(2506),
    [anon_sym_row_major] = ACTIONS(2506),
    [anon_sym_column_major] = ACTIONS(2506),
    [anon_sym_globallycoherent] = ACTIONS(2506),
    [anon_sym_centroid] = ACTIONS(2506),
    [anon_sym_noperspective] = ACTIONS(2506),
    [anon_sym_nointerpolation] = ACTIONS(2506),
    [anon_sym_sample] = ACTIONS(2506),
    [anon_sym_linear] = ACTIONS(2506),
    [anon_sym_snorm] = ACTIONS(2506),
    [anon_sym_unorm] = ACTIONS(2506),
    [anon_sym_point] = ACTIONS(2506),
    [anon_sym_line] = ACTIONS(2506),
    [anon_sym_triangleadj] = ACTIONS(2506),
    [anon_sym_lineadj] = ACTIONS(2506),
    [anon_sym_triangle] = ACTIONS(2506),
  },
  [761] = {
    [sym_preproc_def] = STATE(766),
    [sym_preproc_function_def] = STATE(766),
    [sym_preproc_call] = STATE(766),
    [sym_preproc_if_in_field_declaration_list] = STATE(766),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(766),
    [sym_type_definition] = STATE(766),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(766),
    [sym_field_declaration] = STATE(766),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(766),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(766),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(766),
    [sym_operator_cast_declaration] = STATE(766),
    [sym_constructor_or_destructor_definition] = STATE(766),
    [sym_constructor_or_destructor_declaration] = STATE(766),
    [sym_friend_declaration] = STATE(766),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(766),
    [sym_alias_declaration] = STATE(766),
    [sym_static_assert_declaration] = STATE(766),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(766),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2963),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [762] = {
    [sym_preproc_def] = STATE(744),
    [sym_preproc_function_def] = STATE(744),
    [sym_preproc_call] = STATE(744),
    [sym_preproc_if_in_field_declaration_list] = STATE(744),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(744),
    [sym_type_definition] = STATE(744),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5542),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6069),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(744),
    [sym_field_declaration] = STATE(744),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1829),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(744),
    [sym_operator_cast] = STATE(6635),
    [sym_inline_method_definition] = STATE(744),
    [sym__constructor_specifiers] = STATE(1829),
    [sym_operator_cast_definition] = STATE(744),
    [sym_operator_cast_declaration] = STATE(744),
    [sym_constructor_or_destructor_definition] = STATE(744),
    [sym_constructor_or_destructor_declaration] = STATE(744),
    [sym_friend_declaration] = STATE(744),
    [sym_access_specifier] = STATE(8203),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(744),
    [sym_alias_declaration] = STATE(744),
    [sym_static_assert_declaration] = STATE(744),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6635),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(744),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1829),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2931),
    [aux_sym_preproc_if_token1] = ACTIONS(2933),
    [aux_sym_preproc_if_token2] = ACTIONS(2965),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2937),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2937),
    [sym_preproc_directive] = ACTIONS(2939),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2941),
    [anon_sym_typedef] = ACTIONS(2943),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2945),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2947),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2949),
    [anon_sym_static_assert] = ACTIONS(2951),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [763] = {
    [sym_preproc_def] = STATE(797),
    [sym_preproc_function_def] = STATE(797),
    [sym_preproc_call] = STATE(797),
    [sym_preproc_if_in_field_declaration_list] = STATE(797),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(797),
    [sym_type_definition] = STATE(797),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(797),
    [sym_field_declaration] = STATE(797),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(797),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(797),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(797),
    [sym_operator_cast_declaration] = STATE(797),
    [sym_constructor_or_destructor_definition] = STATE(797),
    [sym_constructor_or_destructor_declaration] = STATE(797),
    [sym_friend_declaration] = STATE(797),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(797),
    [sym_alias_declaration] = STATE(797),
    [sym_static_assert_declaration] = STATE(797),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(797),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2967),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [764] = {
    [ts_builtin_sym_end] = ACTIONS(2418),
    [sym_identifier] = ACTIONS(2416),
    [aux_sym_preproc_include_token1] = ACTIONS(2416),
    [aux_sym_preproc_def_token1] = ACTIONS(2416),
    [aux_sym_preproc_if_token1] = ACTIONS(2416),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2416),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2416),
    [sym_preproc_directive] = ACTIONS(2416),
    [anon_sym_LPAREN2] = ACTIONS(2418),
    [anon_sym_BANG] = ACTIONS(2418),
    [anon_sym_TILDE] = ACTIONS(2418),
    [anon_sym_DASH] = ACTIONS(2416),
    [anon_sym_PLUS] = ACTIONS(2416),
    [anon_sym_STAR] = ACTIONS(2418),
    [anon_sym_AMP_AMP] = ACTIONS(2418),
    [anon_sym_AMP] = ACTIONS(2416),
    [anon_sym___extension__] = ACTIONS(2416),
    [anon_sym_typedef] = ACTIONS(2416),
    [anon_sym_in] = ACTIONS(2416),
    [anon_sym_out] = ACTIONS(2416),
    [anon_sym_inout] = ACTIONS(2416),
    [anon_sym_extern] = ACTIONS(2416),
    [anon_sym___attribute__] = ACTIONS(2416),
    [anon_sym_COLON_COLON] = ACTIONS(2418),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2418),
    [anon_sym___declspec] = ACTIONS(2416),
    [anon_sym___based] = ACTIONS(2416),
    [anon_sym___cdecl] = ACTIONS(2416),
    [anon_sym___clrcall] = ACTIONS(2416),
    [anon_sym___stdcall] = ACTIONS(2416),
    [anon_sym___fastcall] = ACTIONS(2416),
    [anon_sym___thiscall] = ACTIONS(2416),
    [anon_sym___vectorcall] = ACTIONS(2416),
    [anon_sym_LBRACE] = ACTIONS(2418),
    [anon_sym_signed] = ACTIONS(2416),
    [anon_sym_unsigned] = ACTIONS(2416),
    [anon_sym_long] = ACTIONS(2416),
    [anon_sym_short] = ACTIONS(2416),
    [anon_sym_LBRACK] = ACTIONS(2416),
    [anon_sym_static] = ACTIONS(2416),
    [anon_sym_register] = ACTIONS(2416),
    [anon_sym_inline] = ACTIONS(2416),
    [anon_sym___inline] = ACTIONS(2416),
    [anon_sym___inline__] = ACTIONS(2416),
    [anon_sym___forceinline] = ACTIONS(2416),
    [anon_sym_thread_local] = ACTIONS(2416),
    [anon_sym___thread] = ACTIONS(2416),
    [anon_sym_const] = ACTIONS(2416),
    [anon_sym_constexpr] = ACTIONS(2416),
    [anon_sym_volatile] = ACTIONS(2416),
    [anon_sym_restrict] = ACTIONS(2416),
    [anon_sym___restrict__] = ACTIONS(2416),
    [anon_sym__Atomic] = ACTIONS(2416),
    [anon_sym__Noreturn] = ACTIONS(2416),
    [anon_sym_noreturn] = ACTIONS(2416),
    [anon_sym_mutable] = ACTIONS(2416),
    [anon_sym_constinit] = ACTIONS(2416),
    [anon_sym_consteval] = ACTIONS(2416),
    [anon_sym_alignas] = ACTIONS(2416),
    [anon_sym__Alignas] = ACTIONS(2416),
    [sym_primitive_type] = ACTIONS(2416),
    [anon_sym_enum] = ACTIONS(2416),
    [anon_sym_class] = ACTIONS(2416),
    [anon_sym_struct] = ACTIONS(2416),
    [anon_sym_union] = ACTIONS(2416),
    [anon_sym_if] = ACTIONS(2416),
    [anon_sym_switch] = ACTIONS(2416),
    [anon_sym_case] = ACTIONS(2416),
    [anon_sym_default] = ACTIONS(2416),
    [anon_sym_while] = ACTIONS(2416),
    [anon_sym_do] = ACTIONS(2416),
    [anon_sym_for] = ACTIONS(2416),
    [anon_sym_return] = ACTIONS(2416),
    [anon_sym_break] = ACTIONS(2416),
    [anon_sym_continue] = ACTIONS(2416),
    [anon_sym_goto] = ACTIONS(2416),
    [anon_sym_not] = ACTIONS(2416),
    [anon_sym_compl] = ACTIONS(2416),
    [anon_sym_DASH_DASH] = ACTIONS(2418),
    [anon_sym_PLUS_PLUS] = ACTIONS(2418),
    [anon_sym_sizeof] = ACTIONS(2416),
    [anon_sym___alignof__] = ACTIONS(2416),
    [anon_sym___alignof] = ACTIONS(2416),
    [anon_sym__alignof] = ACTIONS(2416),
    [anon_sym_alignof] = ACTIONS(2416),
    [anon_sym__Alignof] = ACTIONS(2416),
    [anon_sym_offsetof] = ACTIONS(2416),
    [anon_sym__Generic] = ACTIONS(2416),
    [anon_sym_asm] = ACTIONS(2416),
    [anon_sym___asm__] = ACTIONS(2416),
    [sym_number_literal] = ACTIONS(2418),
    [anon_sym_L_SQUOTE] = ACTIONS(2418),
    [anon_sym_u_SQUOTE] = ACTIONS(2418),
    [anon_sym_U_SQUOTE] = ACTIONS(2418),
    [anon_sym_u8_SQUOTE] = ACTIONS(2418),
    [anon_sym_SQUOTE] = ACTIONS(2418),
    [anon_sym_L_DQUOTE] = ACTIONS(2418),
    [anon_sym_u_DQUOTE] = ACTIONS(2418),
    [anon_sym_U_DQUOTE] = ACTIONS(2418),
    [anon_sym_u8_DQUOTE] = ACTIONS(2418),
    [anon_sym_DQUOTE] = ACTIONS(2418),
    [sym_true] = ACTIONS(2416),
    [sym_false] = ACTIONS(2416),
    [anon_sym_NULL] = ACTIONS(2416),
    [anon_sym_nullptr] = ACTIONS(2416),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2416),
    [anon_sym_decltype] = ACTIONS(2416),
    [sym_virtual] = ACTIONS(2416),
    [anon_sym_explicit] = ACTIONS(2416),
    [anon_sym_typename] = ACTIONS(2416),
    [anon_sym_template] = ACTIONS(2416),
    [anon_sym_operator] = ACTIONS(2416),
    [anon_sym_try] = ACTIONS(2416),
    [anon_sym_delete] = ACTIONS(2416),
    [anon_sym_throw] = ACTIONS(2416),
    [anon_sym_namespace] = ACTIONS(2416),
    [anon_sym_using] = ACTIONS(2416),
    [anon_sym_static_assert] = ACTIONS(2416),
    [anon_sym_concept] = ACTIONS(2416),
    [anon_sym_co_return] = ACTIONS(2416),
    [anon_sym_co_yield] = ACTIONS(2416),
    [anon_sym_R_DQUOTE] = ACTIONS(2418),
    [anon_sym_LR_DQUOTE] = ACTIONS(2418),
    [anon_sym_uR_DQUOTE] = ACTIONS(2418),
    [anon_sym_UR_DQUOTE] = ACTIONS(2418),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2418),
    [anon_sym_co_await] = ACTIONS(2416),
    [anon_sym_new] = ACTIONS(2416),
    [anon_sym_requires] = ACTIONS(2416),
    [sym_this] = ACTIONS(2416),
    [anon_sym_precise] = ACTIONS(2416),
    [anon_sym_shared] = ACTIONS(2416),
    [anon_sym_groupshared] = ACTIONS(2416),
    [anon_sym_uniform] = ACTIONS(2416),
    [anon_sym_row_major] = ACTIONS(2416),
    [anon_sym_column_major] = ACTIONS(2416),
    [anon_sym_globallycoherent] = ACTIONS(2416),
    [anon_sym_centroid] = ACTIONS(2416),
    [anon_sym_noperspective] = ACTIONS(2416),
    [anon_sym_nointerpolation] = ACTIONS(2416),
    [anon_sym_sample] = ACTIONS(2416),
    [anon_sym_linear] = ACTIONS(2416),
    [anon_sym_snorm] = ACTIONS(2416),
    [anon_sym_unorm] = ACTIONS(2416),
    [anon_sym_point] = ACTIONS(2416),
    [anon_sym_line] = ACTIONS(2416),
    [anon_sym_triangleadj] = ACTIONS(2416),
    [anon_sym_lineadj] = ACTIONS(2416),
    [anon_sym_triangle] = ACTIONS(2416),
  },
  [765] = {
    [ts_builtin_sym_end] = ACTIONS(2518),
    [sym_identifier] = ACTIONS(2516),
    [aux_sym_preproc_include_token1] = ACTIONS(2516),
    [aux_sym_preproc_def_token1] = ACTIONS(2516),
    [aux_sym_preproc_if_token1] = ACTIONS(2516),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2516),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2516),
    [sym_preproc_directive] = ACTIONS(2516),
    [anon_sym_LPAREN2] = ACTIONS(2518),
    [anon_sym_BANG] = ACTIONS(2518),
    [anon_sym_TILDE] = ACTIONS(2518),
    [anon_sym_DASH] = ACTIONS(2516),
    [anon_sym_PLUS] = ACTIONS(2516),
    [anon_sym_STAR] = ACTIONS(2518),
    [anon_sym_AMP_AMP] = ACTIONS(2518),
    [anon_sym_AMP] = ACTIONS(2516),
    [anon_sym___extension__] = ACTIONS(2516),
    [anon_sym_typedef] = ACTIONS(2516),
    [anon_sym_in] = ACTIONS(2516),
    [anon_sym_out] = ACTIONS(2516),
    [anon_sym_inout] = ACTIONS(2516),
    [anon_sym_extern] = ACTIONS(2516),
    [anon_sym___attribute__] = ACTIONS(2516),
    [anon_sym_COLON_COLON] = ACTIONS(2518),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2518),
    [anon_sym___declspec] = ACTIONS(2516),
    [anon_sym___based] = ACTIONS(2516),
    [anon_sym___cdecl] = ACTIONS(2516),
    [anon_sym___clrcall] = ACTIONS(2516),
    [anon_sym___stdcall] = ACTIONS(2516),
    [anon_sym___fastcall] = ACTIONS(2516),
    [anon_sym___thiscall] = ACTIONS(2516),
    [anon_sym___vectorcall] = ACTIONS(2516),
    [anon_sym_LBRACE] = ACTIONS(2518),
    [anon_sym_signed] = ACTIONS(2516),
    [anon_sym_unsigned] = ACTIONS(2516),
    [anon_sym_long] = ACTIONS(2516),
    [anon_sym_short] = ACTIONS(2516),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_static] = ACTIONS(2516),
    [anon_sym_register] = ACTIONS(2516),
    [anon_sym_inline] = ACTIONS(2516),
    [anon_sym___inline] = ACTIONS(2516),
    [anon_sym___inline__] = ACTIONS(2516),
    [anon_sym___forceinline] = ACTIONS(2516),
    [anon_sym_thread_local] = ACTIONS(2516),
    [anon_sym___thread] = ACTIONS(2516),
    [anon_sym_const] = ACTIONS(2516),
    [anon_sym_constexpr] = ACTIONS(2516),
    [anon_sym_volatile] = ACTIONS(2516),
    [anon_sym_restrict] = ACTIONS(2516),
    [anon_sym___restrict__] = ACTIONS(2516),
    [anon_sym__Atomic] = ACTIONS(2516),
    [anon_sym__Noreturn] = ACTIONS(2516),
    [anon_sym_noreturn] = ACTIONS(2516),
    [anon_sym_mutable] = ACTIONS(2516),
    [anon_sym_constinit] = ACTIONS(2516),
    [anon_sym_consteval] = ACTIONS(2516),
    [anon_sym_alignas] = ACTIONS(2516),
    [anon_sym__Alignas] = ACTIONS(2516),
    [sym_primitive_type] = ACTIONS(2516),
    [anon_sym_enum] = ACTIONS(2516),
    [anon_sym_class] = ACTIONS(2516),
    [anon_sym_struct] = ACTIONS(2516),
    [anon_sym_union] = ACTIONS(2516),
    [anon_sym_if] = ACTIONS(2516),
    [anon_sym_switch] = ACTIONS(2516),
    [anon_sym_case] = ACTIONS(2516),
    [anon_sym_default] = ACTIONS(2516),
    [anon_sym_while] = ACTIONS(2516),
    [anon_sym_do] = ACTIONS(2516),
    [anon_sym_for] = ACTIONS(2516),
    [anon_sym_return] = ACTIONS(2516),
    [anon_sym_break] = ACTIONS(2516),
    [anon_sym_continue] = ACTIONS(2516),
    [anon_sym_goto] = ACTIONS(2516),
    [anon_sym_not] = ACTIONS(2516),
    [anon_sym_compl] = ACTIONS(2516),
    [anon_sym_DASH_DASH] = ACTIONS(2518),
    [anon_sym_PLUS_PLUS] = ACTIONS(2518),
    [anon_sym_sizeof] = ACTIONS(2516),
    [anon_sym___alignof__] = ACTIONS(2516),
    [anon_sym___alignof] = ACTIONS(2516),
    [anon_sym__alignof] = ACTIONS(2516),
    [anon_sym_alignof] = ACTIONS(2516),
    [anon_sym__Alignof] = ACTIONS(2516),
    [anon_sym_offsetof] = ACTIONS(2516),
    [anon_sym__Generic] = ACTIONS(2516),
    [anon_sym_asm] = ACTIONS(2516),
    [anon_sym___asm__] = ACTIONS(2516),
    [sym_number_literal] = ACTIONS(2518),
    [anon_sym_L_SQUOTE] = ACTIONS(2518),
    [anon_sym_u_SQUOTE] = ACTIONS(2518),
    [anon_sym_U_SQUOTE] = ACTIONS(2518),
    [anon_sym_u8_SQUOTE] = ACTIONS(2518),
    [anon_sym_SQUOTE] = ACTIONS(2518),
    [anon_sym_L_DQUOTE] = ACTIONS(2518),
    [anon_sym_u_DQUOTE] = ACTIONS(2518),
    [anon_sym_U_DQUOTE] = ACTIONS(2518),
    [anon_sym_u8_DQUOTE] = ACTIONS(2518),
    [anon_sym_DQUOTE] = ACTIONS(2518),
    [sym_true] = ACTIONS(2516),
    [sym_false] = ACTIONS(2516),
    [anon_sym_NULL] = ACTIONS(2516),
    [anon_sym_nullptr] = ACTIONS(2516),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2516),
    [anon_sym_decltype] = ACTIONS(2516),
    [sym_virtual] = ACTIONS(2516),
    [anon_sym_explicit] = ACTIONS(2516),
    [anon_sym_typename] = ACTIONS(2516),
    [anon_sym_template] = ACTIONS(2516),
    [anon_sym_operator] = ACTIONS(2516),
    [anon_sym_try] = ACTIONS(2516),
    [anon_sym_delete] = ACTIONS(2516),
    [anon_sym_throw] = ACTIONS(2516),
    [anon_sym_namespace] = ACTIONS(2516),
    [anon_sym_using] = ACTIONS(2516),
    [anon_sym_static_assert] = ACTIONS(2516),
    [anon_sym_concept] = ACTIONS(2516),
    [anon_sym_co_return] = ACTIONS(2516),
    [anon_sym_co_yield] = ACTIONS(2516),
    [anon_sym_R_DQUOTE] = ACTIONS(2518),
    [anon_sym_LR_DQUOTE] = ACTIONS(2518),
    [anon_sym_uR_DQUOTE] = ACTIONS(2518),
    [anon_sym_UR_DQUOTE] = ACTIONS(2518),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2518),
    [anon_sym_co_await] = ACTIONS(2516),
    [anon_sym_new] = ACTIONS(2516),
    [anon_sym_requires] = ACTIONS(2516),
    [sym_this] = ACTIONS(2516),
    [anon_sym_precise] = ACTIONS(2516),
    [anon_sym_shared] = ACTIONS(2516),
    [anon_sym_groupshared] = ACTIONS(2516),
    [anon_sym_uniform] = ACTIONS(2516),
    [anon_sym_row_major] = ACTIONS(2516),
    [anon_sym_column_major] = ACTIONS(2516),
    [anon_sym_globallycoherent] = ACTIONS(2516),
    [anon_sym_centroid] = ACTIONS(2516),
    [anon_sym_noperspective] = ACTIONS(2516),
    [anon_sym_nointerpolation] = ACTIONS(2516),
    [anon_sym_sample] = ACTIONS(2516),
    [anon_sym_linear] = ACTIONS(2516),
    [anon_sym_snorm] = ACTIONS(2516),
    [anon_sym_unorm] = ACTIONS(2516),
    [anon_sym_point] = ACTIONS(2516),
    [anon_sym_line] = ACTIONS(2516),
    [anon_sym_triangleadj] = ACTIONS(2516),
    [anon_sym_lineadj] = ACTIONS(2516),
    [anon_sym_triangle] = ACTIONS(2516),
  },
  [766] = {
    [sym_preproc_def] = STATE(797),
    [sym_preproc_function_def] = STATE(797),
    [sym_preproc_call] = STATE(797),
    [sym_preproc_if_in_field_declaration_list] = STATE(797),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(797),
    [sym_type_definition] = STATE(797),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(797),
    [sym_field_declaration] = STATE(797),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(797),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(797),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(797),
    [sym_operator_cast_declaration] = STATE(797),
    [sym_constructor_or_destructor_definition] = STATE(797),
    [sym_constructor_or_destructor_declaration] = STATE(797),
    [sym_friend_declaration] = STATE(797),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(797),
    [sym_alias_declaration] = STATE(797),
    [sym_static_assert_declaration] = STATE(797),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(797),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2969),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [767] = {
    [ts_builtin_sym_end] = ACTIONS(2318),
    [sym_identifier] = ACTIONS(2316),
    [aux_sym_preproc_include_token1] = ACTIONS(2316),
    [aux_sym_preproc_def_token1] = ACTIONS(2316),
    [aux_sym_preproc_if_token1] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2316),
    [sym_preproc_directive] = ACTIONS(2316),
    [anon_sym_LPAREN2] = ACTIONS(2318),
    [anon_sym_BANG] = ACTIONS(2318),
    [anon_sym_TILDE] = ACTIONS(2318),
    [anon_sym_DASH] = ACTIONS(2316),
    [anon_sym_PLUS] = ACTIONS(2316),
    [anon_sym_STAR] = ACTIONS(2318),
    [anon_sym_AMP_AMP] = ACTIONS(2318),
    [anon_sym_AMP] = ACTIONS(2316),
    [anon_sym___extension__] = ACTIONS(2316),
    [anon_sym_typedef] = ACTIONS(2316),
    [anon_sym_in] = ACTIONS(2316),
    [anon_sym_out] = ACTIONS(2316),
    [anon_sym_inout] = ACTIONS(2316),
    [anon_sym_extern] = ACTIONS(2316),
    [anon_sym___attribute__] = ACTIONS(2316),
    [anon_sym_COLON_COLON] = ACTIONS(2318),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2318),
    [anon_sym___declspec] = ACTIONS(2316),
    [anon_sym___based] = ACTIONS(2316),
    [anon_sym___cdecl] = ACTIONS(2316),
    [anon_sym___clrcall] = ACTIONS(2316),
    [anon_sym___stdcall] = ACTIONS(2316),
    [anon_sym___fastcall] = ACTIONS(2316),
    [anon_sym___thiscall] = ACTIONS(2316),
    [anon_sym___vectorcall] = ACTIONS(2316),
    [anon_sym_LBRACE] = ACTIONS(2318),
    [anon_sym_signed] = ACTIONS(2316),
    [anon_sym_unsigned] = ACTIONS(2316),
    [anon_sym_long] = ACTIONS(2316),
    [anon_sym_short] = ACTIONS(2316),
    [anon_sym_LBRACK] = ACTIONS(2316),
    [anon_sym_static] = ACTIONS(2316),
    [anon_sym_register] = ACTIONS(2316),
    [anon_sym_inline] = ACTIONS(2316),
    [anon_sym___inline] = ACTIONS(2316),
    [anon_sym___inline__] = ACTIONS(2316),
    [anon_sym___forceinline] = ACTIONS(2316),
    [anon_sym_thread_local] = ACTIONS(2316),
    [anon_sym___thread] = ACTIONS(2316),
    [anon_sym_const] = ACTIONS(2316),
    [anon_sym_constexpr] = ACTIONS(2316),
    [anon_sym_volatile] = ACTIONS(2316),
    [anon_sym_restrict] = ACTIONS(2316),
    [anon_sym___restrict__] = ACTIONS(2316),
    [anon_sym__Atomic] = ACTIONS(2316),
    [anon_sym__Noreturn] = ACTIONS(2316),
    [anon_sym_noreturn] = ACTIONS(2316),
    [anon_sym_mutable] = ACTIONS(2316),
    [anon_sym_constinit] = ACTIONS(2316),
    [anon_sym_consteval] = ACTIONS(2316),
    [anon_sym_alignas] = ACTIONS(2316),
    [anon_sym__Alignas] = ACTIONS(2316),
    [sym_primitive_type] = ACTIONS(2316),
    [anon_sym_enum] = ACTIONS(2316),
    [anon_sym_class] = ACTIONS(2316),
    [anon_sym_struct] = ACTIONS(2316),
    [anon_sym_union] = ACTIONS(2316),
    [anon_sym_if] = ACTIONS(2316),
    [anon_sym_switch] = ACTIONS(2316),
    [anon_sym_case] = ACTIONS(2316),
    [anon_sym_default] = ACTIONS(2316),
    [anon_sym_while] = ACTIONS(2316),
    [anon_sym_do] = ACTIONS(2316),
    [anon_sym_for] = ACTIONS(2316),
    [anon_sym_return] = ACTIONS(2316),
    [anon_sym_break] = ACTIONS(2316),
    [anon_sym_continue] = ACTIONS(2316),
    [anon_sym_goto] = ACTIONS(2316),
    [anon_sym_not] = ACTIONS(2316),
    [anon_sym_compl] = ACTIONS(2316),
    [anon_sym_DASH_DASH] = ACTIONS(2318),
    [anon_sym_PLUS_PLUS] = ACTIONS(2318),
    [anon_sym_sizeof] = ACTIONS(2316),
    [anon_sym___alignof__] = ACTIONS(2316),
    [anon_sym___alignof] = ACTIONS(2316),
    [anon_sym__alignof] = ACTIONS(2316),
    [anon_sym_alignof] = ACTIONS(2316),
    [anon_sym__Alignof] = ACTIONS(2316),
    [anon_sym_offsetof] = ACTIONS(2316),
    [anon_sym__Generic] = ACTIONS(2316),
    [anon_sym_asm] = ACTIONS(2316),
    [anon_sym___asm__] = ACTIONS(2316),
    [sym_number_literal] = ACTIONS(2318),
    [anon_sym_L_SQUOTE] = ACTIONS(2318),
    [anon_sym_u_SQUOTE] = ACTIONS(2318),
    [anon_sym_U_SQUOTE] = ACTIONS(2318),
    [anon_sym_u8_SQUOTE] = ACTIONS(2318),
    [anon_sym_SQUOTE] = ACTIONS(2318),
    [anon_sym_L_DQUOTE] = ACTIONS(2318),
    [anon_sym_u_DQUOTE] = ACTIONS(2318),
    [anon_sym_U_DQUOTE] = ACTIONS(2318),
    [anon_sym_u8_DQUOTE] = ACTIONS(2318),
    [anon_sym_DQUOTE] = ACTIONS(2318),
    [sym_true] = ACTIONS(2316),
    [sym_false] = ACTIONS(2316),
    [anon_sym_NULL] = ACTIONS(2316),
    [anon_sym_nullptr] = ACTIONS(2316),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2316),
    [anon_sym_decltype] = ACTIONS(2316),
    [sym_virtual] = ACTIONS(2316),
    [anon_sym_explicit] = ACTIONS(2316),
    [anon_sym_typename] = ACTIONS(2316),
    [anon_sym_template] = ACTIONS(2316),
    [anon_sym_operator] = ACTIONS(2316),
    [anon_sym_try] = ACTIONS(2316),
    [anon_sym_delete] = ACTIONS(2316),
    [anon_sym_throw] = ACTIONS(2316),
    [anon_sym_namespace] = ACTIONS(2316),
    [anon_sym_using] = ACTIONS(2316),
    [anon_sym_static_assert] = ACTIONS(2316),
    [anon_sym_concept] = ACTIONS(2316),
    [anon_sym_co_return] = ACTIONS(2316),
    [anon_sym_co_yield] = ACTIONS(2316),
    [anon_sym_R_DQUOTE] = ACTIONS(2318),
    [anon_sym_LR_DQUOTE] = ACTIONS(2318),
    [anon_sym_uR_DQUOTE] = ACTIONS(2318),
    [anon_sym_UR_DQUOTE] = ACTIONS(2318),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2318),
    [anon_sym_co_await] = ACTIONS(2316),
    [anon_sym_new] = ACTIONS(2316),
    [anon_sym_requires] = ACTIONS(2316),
    [sym_this] = ACTIONS(2316),
    [anon_sym_precise] = ACTIONS(2316),
    [anon_sym_shared] = ACTIONS(2316),
    [anon_sym_groupshared] = ACTIONS(2316),
    [anon_sym_uniform] = ACTIONS(2316),
    [anon_sym_row_major] = ACTIONS(2316),
    [anon_sym_column_major] = ACTIONS(2316),
    [anon_sym_globallycoherent] = ACTIONS(2316),
    [anon_sym_centroid] = ACTIONS(2316),
    [anon_sym_noperspective] = ACTIONS(2316),
    [anon_sym_nointerpolation] = ACTIONS(2316),
    [anon_sym_sample] = ACTIONS(2316),
    [anon_sym_linear] = ACTIONS(2316),
    [anon_sym_snorm] = ACTIONS(2316),
    [anon_sym_unorm] = ACTIONS(2316),
    [anon_sym_point] = ACTIONS(2316),
    [anon_sym_line] = ACTIONS(2316),
    [anon_sym_triangleadj] = ACTIONS(2316),
    [anon_sym_lineadj] = ACTIONS(2316),
    [anon_sym_triangle] = ACTIONS(2316),
  },
  [768] = {
    [ts_builtin_sym_end] = ACTIONS(2551),
    [sym_identifier] = ACTIONS(2549),
    [aux_sym_preproc_include_token1] = ACTIONS(2549),
    [aux_sym_preproc_def_token1] = ACTIONS(2549),
    [aux_sym_preproc_if_token1] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2549),
    [sym_preproc_directive] = ACTIONS(2549),
    [anon_sym_LPAREN2] = ACTIONS(2551),
    [anon_sym_BANG] = ACTIONS(2551),
    [anon_sym_TILDE] = ACTIONS(2551),
    [anon_sym_DASH] = ACTIONS(2549),
    [anon_sym_PLUS] = ACTIONS(2549),
    [anon_sym_STAR] = ACTIONS(2551),
    [anon_sym_AMP_AMP] = ACTIONS(2551),
    [anon_sym_AMP] = ACTIONS(2549),
    [anon_sym___extension__] = ACTIONS(2549),
    [anon_sym_typedef] = ACTIONS(2549),
    [anon_sym_in] = ACTIONS(2549),
    [anon_sym_out] = ACTIONS(2549),
    [anon_sym_inout] = ACTIONS(2549),
    [anon_sym_extern] = ACTIONS(2549),
    [anon_sym___attribute__] = ACTIONS(2549),
    [anon_sym_COLON_COLON] = ACTIONS(2551),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2551),
    [anon_sym___declspec] = ACTIONS(2549),
    [anon_sym___based] = ACTIONS(2549),
    [anon_sym___cdecl] = ACTIONS(2549),
    [anon_sym___clrcall] = ACTIONS(2549),
    [anon_sym___stdcall] = ACTIONS(2549),
    [anon_sym___fastcall] = ACTIONS(2549),
    [anon_sym___thiscall] = ACTIONS(2549),
    [anon_sym___vectorcall] = ACTIONS(2549),
    [anon_sym_LBRACE] = ACTIONS(2551),
    [anon_sym_signed] = ACTIONS(2549),
    [anon_sym_unsigned] = ACTIONS(2549),
    [anon_sym_long] = ACTIONS(2549),
    [anon_sym_short] = ACTIONS(2549),
    [anon_sym_LBRACK] = ACTIONS(2549),
    [anon_sym_static] = ACTIONS(2549),
    [anon_sym_register] = ACTIONS(2549),
    [anon_sym_inline] = ACTIONS(2549),
    [anon_sym___inline] = ACTIONS(2549),
    [anon_sym___inline__] = ACTIONS(2549),
    [anon_sym___forceinline] = ACTIONS(2549),
    [anon_sym_thread_local] = ACTIONS(2549),
    [anon_sym___thread] = ACTIONS(2549),
    [anon_sym_const] = ACTIONS(2549),
    [anon_sym_constexpr] = ACTIONS(2549),
    [anon_sym_volatile] = ACTIONS(2549),
    [anon_sym_restrict] = ACTIONS(2549),
    [anon_sym___restrict__] = ACTIONS(2549),
    [anon_sym__Atomic] = ACTIONS(2549),
    [anon_sym__Noreturn] = ACTIONS(2549),
    [anon_sym_noreturn] = ACTIONS(2549),
    [anon_sym_mutable] = ACTIONS(2549),
    [anon_sym_constinit] = ACTIONS(2549),
    [anon_sym_consteval] = ACTIONS(2549),
    [anon_sym_alignas] = ACTIONS(2549),
    [anon_sym__Alignas] = ACTIONS(2549),
    [sym_primitive_type] = ACTIONS(2549),
    [anon_sym_enum] = ACTIONS(2549),
    [anon_sym_class] = ACTIONS(2549),
    [anon_sym_struct] = ACTIONS(2549),
    [anon_sym_union] = ACTIONS(2549),
    [anon_sym_if] = ACTIONS(2549),
    [anon_sym_switch] = ACTIONS(2549),
    [anon_sym_case] = ACTIONS(2549),
    [anon_sym_default] = ACTIONS(2549),
    [anon_sym_while] = ACTIONS(2549),
    [anon_sym_do] = ACTIONS(2549),
    [anon_sym_for] = ACTIONS(2549),
    [anon_sym_return] = ACTIONS(2549),
    [anon_sym_break] = ACTIONS(2549),
    [anon_sym_continue] = ACTIONS(2549),
    [anon_sym_goto] = ACTIONS(2549),
    [anon_sym_not] = ACTIONS(2549),
    [anon_sym_compl] = ACTIONS(2549),
    [anon_sym_DASH_DASH] = ACTIONS(2551),
    [anon_sym_PLUS_PLUS] = ACTIONS(2551),
    [anon_sym_sizeof] = ACTIONS(2549),
    [anon_sym___alignof__] = ACTIONS(2549),
    [anon_sym___alignof] = ACTIONS(2549),
    [anon_sym__alignof] = ACTIONS(2549),
    [anon_sym_alignof] = ACTIONS(2549),
    [anon_sym__Alignof] = ACTIONS(2549),
    [anon_sym_offsetof] = ACTIONS(2549),
    [anon_sym__Generic] = ACTIONS(2549),
    [anon_sym_asm] = ACTIONS(2549),
    [anon_sym___asm__] = ACTIONS(2549),
    [sym_number_literal] = ACTIONS(2551),
    [anon_sym_L_SQUOTE] = ACTIONS(2551),
    [anon_sym_u_SQUOTE] = ACTIONS(2551),
    [anon_sym_U_SQUOTE] = ACTIONS(2551),
    [anon_sym_u8_SQUOTE] = ACTIONS(2551),
    [anon_sym_SQUOTE] = ACTIONS(2551),
    [anon_sym_L_DQUOTE] = ACTIONS(2551),
    [anon_sym_u_DQUOTE] = ACTIONS(2551),
    [anon_sym_U_DQUOTE] = ACTIONS(2551),
    [anon_sym_u8_DQUOTE] = ACTIONS(2551),
    [anon_sym_DQUOTE] = ACTIONS(2551),
    [sym_true] = ACTIONS(2549),
    [sym_false] = ACTIONS(2549),
    [anon_sym_NULL] = ACTIONS(2549),
    [anon_sym_nullptr] = ACTIONS(2549),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2549),
    [anon_sym_decltype] = ACTIONS(2549),
    [sym_virtual] = ACTIONS(2549),
    [anon_sym_explicit] = ACTIONS(2549),
    [anon_sym_typename] = ACTIONS(2549),
    [anon_sym_template] = ACTIONS(2549),
    [anon_sym_operator] = ACTIONS(2549),
    [anon_sym_try] = ACTIONS(2549),
    [anon_sym_delete] = ACTIONS(2549),
    [anon_sym_throw] = ACTIONS(2549),
    [anon_sym_namespace] = ACTIONS(2549),
    [anon_sym_using] = ACTIONS(2549),
    [anon_sym_static_assert] = ACTIONS(2549),
    [anon_sym_concept] = ACTIONS(2549),
    [anon_sym_co_return] = ACTIONS(2549),
    [anon_sym_co_yield] = ACTIONS(2549),
    [anon_sym_R_DQUOTE] = ACTIONS(2551),
    [anon_sym_LR_DQUOTE] = ACTIONS(2551),
    [anon_sym_uR_DQUOTE] = ACTIONS(2551),
    [anon_sym_UR_DQUOTE] = ACTIONS(2551),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2551),
    [anon_sym_co_await] = ACTIONS(2549),
    [anon_sym_new] = ACTIONS(2549),
    [anon_sym_requires] = ACTIONS(2549),
    [sym_this] = ACTIONS(2549),
    [anon_sym_precise] = ACTIONS(2549),
    [anon_sym_shared] = ACTIONS(2549),
    [anon_sym_groupshared] = ACTIONS(2549),
    [anon_sym_uniform] = ACTIONS(2549),
    [anon_sym_row_major] = ACTIONS(2549),
    [anon_sym_column_major] = ACTIONS(2549),
    [anon_sym_globallycoherent] = ACTIONS(2549),
    [anon_sym_centroid] = ACTIONS(2549),
    [anon_sym_noperspective] = ACTIONS(2549),
    [anon_sym_nointerpolation] = ACTIONS(2549),
    [anon_sym_sample] = ACTIONS(2549),
    [anon_sym_linear] = ACTIONS(2549),
    [anon_sym_snorm] = ACTIONS(2549),
    [anon_sym_unorm] = ACTIONS(2549),
    [anon_sym_point] = ACTIONS(2549),
    [anon_sym_line] = ACTIONS(2549),
    [anon_sym_triangleadj] = ACTIONS(2549),
    [anon_sym_lineadj] = ACTIONS(2549),
    [anon_sym_triangle] = ACTIONS(2549),
  },
  [769] = {
    [sym_preproc_def] = STATE(771),
    [sym_preproc_function_def] = STATE(771),
    [sym_preproc_call] = STATE(771),
    [sym_preproc_if_in_field_declaration_list] = STATE(771),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(771),
    [sym_type_definition] = STATE(771),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(771),
    [sym_field_declaration] = STATE(771),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(771),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(771),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(771),
    [sym_operator_cast_declaration] = STATE(771),
    [sym_constructor_or_destructor_definition] = STATE(771),
    [sym_constructor_or_destructor_declaration] = STATE(771),
    [sym_friend_declaration] = STATE(771),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(771),
    [sym_alias_declaration] = STATE(771),
    [sym_static_assert_declaration] = STATE(771),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(771),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2971),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [770] = {
    [sym_preproc_def] = STATE(797),
    [sym_preproc_function_def] = STATE(797),
    [sym_preproc_call] = STATE(797),
    [sym_preproc_if_in_field_declaration_list] = STATE(797),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(797),
    [sym_type_definition] = STATE(797),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(797),
    [sym_field_declaration] = STATE(797),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(797),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(797),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(797),
    [sym_operator_cast_declaration] = STATE(797),
    [sym_constructor_or_destructor_definition] = STATE(797),
    [sym_constructor_or_destructor_declaration] = STATE(797),
    [sym_friend_declaration] = STATE(797),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(797),
    [sym_alias_declaration] = STATE(797),
    [sym_static_assert_declaration] = STATE(797),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(797),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2973),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [771] = {
    [sym_preproc_def] = STATE(797),
    [sym_preproc_function_def] = STATE(797),
    [sym_preproc_call] = STATE(797),
    [sym_preproc_if_in_field_declaration_list] = STATE(797),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(797),
    [sym_type_definition] = STATE(797),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(797),
    [sym_field_declaration] = STATE(797),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(797),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(797),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(797),
    [sym_operator_cast_declaration] = STATE(797),
    [sym_constructor_or_destructor_definition] = STATE(797),
    [sym_constructor_or_destructor_declaration] = STATE(797),
    [sym_friend_declaration] = STATE(797),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(797),
    [sym_alias_declaration] = STATE(797),
    [sym_static_assert_declaration] = STATE(797),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(797),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2975),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [772] = {
    [sym_preproc_def] = STATE(774),
    [sym_preproc_function_def] = STATE(774),
    [sym_preproc_call] = STATE(774),
    [sym_preproc_if_in_field_declaration_list] = STATE(774),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(774),
    [sym_type_definition] = STATE(774),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(774),
    [sym_field_declaration] = STATE(774),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(774),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(774),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(774),
    [sym_operator_cast_declaration] = STATE(774),
    [sym_constructor_or_destructor_definition] = STATE(774),
    [sym_constructor_or_destructor_declaration] = STATE(774),
    [sym_friend_declaration] = STATE(774),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(774),
    [sym_alias_declaration] = STATE(774),
    [sym_static_assert_declaration] = STATE(774),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(774),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2977),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [773] = {
    [sym_preproc_def] = STATE(763),
    [sym_preproc_function_def] = STATE(763),
    [sym_preproc_call] = STATE(763),
    [sym_preproc_if_in_field_declaration_list] = STATE(763),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(763),
    [sym_type_definition] = STATE(763),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(763),
    [sym_field_declaration] = STATE(763),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(763),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(763),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(763),
    [sym_operator_cast_declaration] = STATE(763),
    [sym_constructor_or_destructor_definition] = STATE(763),
    [sym_constructor_or_destructor_declaration] = STATE(763),
    [sym_friend_declaration] = STATE(763),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(763),
    [sym_alias_declaration] = STATE(763),
    [sym_static_assert_declaration] = STATE(763),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(763),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2979),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [774] = {
    [sym_preproc_def] = STATE(797),
    [sym_preproc_function_def] = STATE(797),
    [sym_preproc_call] = STATE(797),
    [sym_preproc_if_in_field_declaration_list] = STATE(797),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(797),
    [sym_type_definition] = STATE(797),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(797),
    [sym_field_declaration] = STATE(797),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(797),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(797),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(797),
    [sym_operator_cast_declaration] = STATE(797),
    [sym_constructor_or_destructor_definition] = STATE(797),
    [sym_constructor_or_destructor_declaration] = STATE(797),
    [sym_friend_declaration] = STATE(797),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(797),
    [sym_alias_declaration] = STATE(797),
    [sym_static_assert_declaration] = STATE(797),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(797),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2981),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [775] = {
    [sym_preproc_def] = STATE(780),
    [sym_preproc_function_def] = STATE(780),
    [sym_preproc_call] = STATE(780),
    [sym_preproc_if_in_field_declaration_list] = STATE(780),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(780),
    [sym_type_definition] = STATE(780),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(780),
    [sym_field_declaration] = STATE(780),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(780),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(780),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(780),
    [sym_operator_cast_declaration] = STATE(780),
    [sym_constructor_or_destructor_definition] = STATE(780),
    [sym_constructor_or_destructor_declaration] = STATE(780),
    [sym_friend_declaration] = STATE(780),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(780),
    [sym_alias_declaration] = STATE(780),
    [sym_static_assert_declaration] = STATE(780),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(780),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2983),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [776] = {
    [ts_builtin_sym_end] = ACTIONS(2571),
    [sym_identifier] = ACTIONS(2569),
    [aux_sym_preproc_include_token1] = ACTIONS(2569),
    [aux_sym_preproc_def_token1] = ACTIONS(2569),
    [aux_sym_preproc_if_token1] = ACTIONS(2569),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2569),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2569),
    [sym_preproc_directive] = ACTIONS(2569),
    [anon_sym_LPAREN2] = ACTIONS(2571),
    [anon_sym_BANG] = ACTIONS(2571),
    [anon_sym_TILDE] = ACTIONS(2571),
    [anon_sym_DASH] = ACTIONS(2569),
    [anon_sym_PLUS] = ACTIONS(2569),
    [anon_sym_STAR] = ACTIONS(2571),
    [anon_sym_AMP_AMP] = ACTIONS(2571),
    [anon_sym_AMP] = ACTIONS(2569),
    [anon_sym___extension__] = ACTIONS(2569),
    [anon_sym_typedef] = ACTIONS(2569),
    [anon_sym_in] = ACTIONS(2569),
    [anon_sym_out] = ACTIONS(2569),
    [anon_sym_inout] = ACTIONS(2569),
    [anon_sym_extern] = ACTIONS(2569),
    [anon_sym___attribute__] = ACTIONS(2569),
    [anon_sym_COLON_COLON] = ACTIONS(2571),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2571),
    [anon_sym___declspec] = ACTIONS(2569),
    [anon_sym___based] = ACTIONS(2569),
    [anon_sym___cdecl] = ACTIONS(2569),
    [anon_sym___clrcall] = ACTIONS(2569),
    [anon_sym___stdcall] = ACTIONS(2569),
    [anon_sym___fastcall] = ACTIONS(2569),
    [anon_sym___thiscall] = ACTIONS(2569),
    [anon_sym___vectorcall] = ACTIONS(2569),
    [anon_sym_LBRACE] = ACTIONS(2571),
    [anon_sym_signed] = ACTIONS(2569),
    [anon_sym_unsigned] = ACTIONS(2569),
    [anon_sym_long] = ACTIONS(2569),
    [anon_sym_short] = ACTIONS(2569),
    [anon_sym_LBRACK] = ACTIONS(2569),
    [anon_sym_static] = ACTIONS(2569),
    [anon_sym_register] = ACTIONS(2569),
    [anon_sym_inline] = ACTIONS(2569),
    [anon_sym___inline] = ACTIONS(2569),
    [anon_sym___inline__] = ACTIONS(2569),
    [anon_sym___forceinline] = ACTIONS(2569),
    [anon_sym_thread_local] = ACTIONS(2569),
    [anon_sym___thread] = ACTIONS(2569),
    [anon_sym_const] = ACTIONS(2569),
    [anon_sym_constexpr] = ACTIONS(2569),
    [anon_sym_volatile] = ACTIONS(2569),
    [anon_sym_restrict] = ACTIONS(2569),
    [anon_sym___restrict__] = ACTIONS(2569),
    [anon_sym__Atomic] = ACTIONS(2569),
    [anon_sym__Noreturn] = ACTIONS(2569),
    [anon_sym_noreturn] = ACTIONS(2569),
    [anon_sym_mutable] = ACTIONS(2569),
    [anon_sym_constinit] = ACTIONS(2569),
    [anon_sym_consteval] = ACTIONS(2569),
    [anon_sym_alignas] = ACTIONS(2569),
    [anon_sym__Alignas] = ACTIONS(2569),
    [sym_primitive_type] = ACTIONS(2569),
    [anon_sym_enum] = ACTIONS(2569),
    [anon_sym_class] = ACTIONS(2569),
    [anon_sym_struct] = ACTIONS(2569),
    [anon_sym_union] = ACTIONS(2569),
    [anon_sym_if] = ACTIONS(2569),
    [anon_sym_switch] = ACTIONS(2569),
    [anon_sym_case] = ACTIONS(2569),
    [anon_sym_default] = ACTIONS(2569),
    [anon_sym_while] = ACTIONS(2569),
    [anon_sym_do] = ACTIONS(2569),
    [anon_sym_for] = ACTIONS(2569),
    [anon_sym_return] = ACTIONS(2569),
    [anon_sym_break] = ACTIONS(2569),
    [anon_sym_continue] = ACTIONS(2569),
    [anon_sym_goto] = ACTIONS(2569),
    [anon_sym_not] = ACTIONS(2569),
    [anon_sym_compl] = ACTIONS(2569),
    [anon_sym_DASH_DASH] = ACTIONS(2571),
    [anon_sym_PLUS_PLUS] = ACTIONS(2571),
    [anon_sym_sizeof] = ACTIONS(2569),
    [anon_sym___alignof__] = ACTIONS(2569),
    [anon_sym___alignof] = ACTIONS(2569),
    [anon_sym__alignof] = ACTIONS(2569),
    [anon_sym_alignof] = ACTIONS(2569),
    [anon_sym__Alignof] = ACTIONS(2569),
    [anon_sym_offsetof] = ACTIONS(2569),
    [anon_sym__Generic] = ACTIONS(2569),
    [anon_sym_asm] = ACTIONS(2569),
    [anon_sym___asm__] = ACTIONS(2569),
    [sym_number_literal] = ACTIONS(2571),
    [anon_sym_L_SQUOTE] = ACTIONS(2571),
    [anon_sym_u_SQUOTE] = ACTIONS(2571),
    [anon_sym_U_SQUOTE] = ACTIONS(2571),
    [anon_sym_u8_SQUOTE] = ACTIONS(2571),
    [anon_sym_SQUOTE] = ACTIONS(2571),
    [anon_sym_L_DQUOTE] = ACTIONS(2571),
    [anon_sym_u_DQUOTE] = ACTIONS(2571),
    [anon_sym_U_DQUOTE] = ACTIONS(2571),
    [anon_sym_u8_DQUOTE] = ACTIONS(2571),
    [anon_sym_DQUOTE] = ACTIONS(2571),
    [sym_true] = ACTIONS(2569),
    [sym_false] = ACTIONS(2569),
    [anon_sym_NULL] = ACTIONS(2569),
    [anon_sym_nullptr] = ACTIONS(2569),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2569),
    [anon_sym_decltype] = ACTIONS(2569),
    [sym_virtual] = ACTIONS(2569),
    [anon_sym_explicit] = ACTIONS(2569),
    [anon_sym_typename] = ACTIONS(2569),
    [anon_sym_template] = ACTIONS(2569),
    [anon_sym_operator] = ACTIONS(2569),
    [anon_sym_try] = ACTIONS(2569),
    [anon_sym_delete] = ACTIONS(2569),
    [anon_sym_throw] = ACTIONS(2569),
    [anon_sym_namespace] = ACTIONS(2569),
    [anon_sym_using] = ACTIONS(2569),
    [anon_sym_static_assert] = ACTIONS(2569),
    [anon_sym_concept] = ACTIONS(2569),
    [anon_sym_co_return] = ACTIONS(2569),
    [anon_sym_co_yield] = ACTIONS(2569),
    [anon_sym_R_DQUOTE] = ACTIONS(2571),
    [anon_sym_LR_DQUOTE] = ACTIONS(2571),
    [anon_sym_uR_DQUOTE] = ACTIONS(2571),
    [anon_sym_UR_DQUOTE] = ACTIONS(2571),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2571),
    [anon_sym_co_await] = ACTIONS(2569),
    [anon_sym_new] = ACTIONS(2569),
    [anon_sym_requires] = ACTIONS(2569),
    [sym_this] = ACTIONS(2569),
    [anon_sym_precise] = ACTIONS(2569),
    [anon_sym_shared] = ACTIONS(2569),
    [anon_sym_groupshared] = ACTIONS(2569),
    [anon_sym_uniform] = ACTIONS(2569),
    [anon_sym_row_major] = ACTIONS(2569),
    [anon_sym_column_major] = ACTIONS(2569),
    [anon_sym_globallycoherent] = ACTIONS(2569),
    [anon_sym_centroid] = ACTIONS(2569),
    [anon_sym_noperspective] = ACTIONS(2569),
    [anon_sym_nointerpolation] = ACTIONS(2569),
    [anon_sym_sample] = ACTIONS(2569),
    [anon_sym_linear] = ACTIONS(2569),
    [anon_sym_snorm] = ACTIONS(2569),
    [anon_sym_unorm] = ACTIONS(2569),
    [anon_sym_point] = ACTIONS(2569),
    [anon_sym_line] = ACTIONS(2569),
    [anon_sym_triangleadj] = ACTIONS(2569),
    [anon_sym_lineadj] = ACTIONS(2569),
    [anon_sym_triangle] = ACTIONS(2569),
  },
  [777] = {
    [ts_builtin_sym_end] = ACTIONS(2426),
    [sym_identifier] = ACTIONS(2424),
    [aux_sym_preproc_include_token1] = ACTIONS(2424),
    [aux_sym_preproc_def_token1] = ACTIONS(2424),
    [aux_sym_preproc_if_token1] = ACTIONS(2424),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2424),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2424),
    [sym_preproc_directive] = ACTIONS(2424),
    [anon_sym_LPAREN2] = ACTIONS(2426),
    [anon_sym_BANG] = ACTIONS(2426),
    [anon_sym_TILDE] = ACTIONS(2426),
    [anon_sym_DASH] = ACTIONS(2424),
    [anon_sym_PLUS] = ACTIONS(2424),
    [anon_sym_STAR] = ACTIONS(2426),
    [anon_sym_AMP_AMP] = ACTIONS(2426),
    [anon_sym_AMP] = ACTIONS(2424),
    [anon_sym___extension__] = ACTIONS(2424),
    [anon_sym_typedef] = ACTIONS(2424),
    [anon_sym_in] = ACTIONS(2424),
    [anon_sym_out] = ACTIONS(2424),
    [anon_sym_inout] = ACTIONS(2424),
    [anon_sym_extern] = ACTIONS(2424),
    [anon_sym___attribute__] = ACTIONS(2424),
    [anon_sym_COLON_COLON] = ACTIONS(2426),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2426),
    [anon_sym___declspec] = ACTIONS(2424),
    [anon_sym___based] = ACTIONS(2424),
    [anon_sym___cdecl] = ACTIONS(2424),
    [anon_sym___clrcall] = ACTIONS(2424),
    [anon_sym___stdcall] = ACTIONS(2424),
    [anon_sym___fastcall] = ACTIONS(2424),
    [anon_sym___thiscall] = ACTIONS(2424),
    [anon_sym___vectorcall] = ACTIONS(2424),
    [anon_sym_LBRACE] = ACTIONS(2426),
    [anon_sym_signed] = ACTIONS(2424),
    [anon_sym_unsigned] = ACTIONS(2424),
    [anon_sym_long] = ACTIONS(2424),
    [anon_sym_short] = ACTIONS(2424),
    [anon_sym_LBRACK] = ACTIONS(2424),
    [anon_sym_static] = ACTIONS(2424),
    [anon_sym_register] = ACTIONS(2424),
    [anon_sym_inline] = ACTIONS(2424),
    [anon_sym___inline] = ACTIONS(2424),
    [anon_sym___inline__] = ACTIONS(2424),
    [anon_sym___forceinline] = ACTIONS(2424),
    [anon_sym_thread_local] = ACTIONS(2424),
    [anon_sym___thread] = ACTIONS(2424),
    [anon_sym_const] = ACTIONS(2424),
    [anon_sym_constexpr] = ACTIONS(2424),
    [anon_sym_volatile] = ACTIONS(2424),
    [anon_sym_restrict] = ACTIONS(2424),
    [anon_sym___restrict__] = ACTIONS(2424),
    [anon_sym__Atomic] = ACTIONS(2424),
    [anon_sym__Noreturn] = ACTIONS(2424),
    [anon_sym_noreturn] = ACTIONS(2424),
    [anon_sym_mutable] = ACTIONS(2424),
    [anon_sym_constinit] = ACTIONS(2424),
    [anon_sym_consteval] = ACTIONS(2424),
    [anon_sym_alignas] = ACTIONS(2424),
    [anon_sym__Alignas] = ACTIONS(2424),
    [sym_primitive_type] = ACTIONS(2424),
    [anon_sym_enum] = ACTIONS(2424),
    [anon_sym_class] = ACTIONS(2424),
    [anon_sym_struct] = ACTIONS(2424),
    [anon_sym_union] = ACTIONS(2424),
    [anon_sym_if] = ACTIONS(2424),
    [anon_sym_switch] = ACTIONS(2424),
    [anon_sym_case] = ACTIONS(2424),
    [anon_sym_default] = ACTIONS(2424),
    [anon_sym_while] = ACTIONS(2424),
    [anon_sym_do] = ACTIONS(2424),
    [anon_sym_for] = ACTIONS(2424),
    [anon_sym_return] = ACTIONS(2424),
    [anon_sym_break] = ACTIONS(2424),
    [anon_sym_continue] = ACTIONS(2424),
    [anon_sym_goto] = ACTIONS(2424),
    [anon_sym_not] = ACTIONS(2424),
    [anon_sym_compl] = ACTIONS(2424),
    [anon_sym_DASH_DASH] = ACTIONS(2426),
    [anon_sym_PLUS_PLUS] = ACTIONS(2426),
    [anon_sym_sizeof] = ACTIONS(2424),
    [anon_sym___alignof__] = ACTIONS(2424),
    [anon_sym___alignof] = ACTIONS(2424),
    [anon_sym__alignof] = ACTIONS(2424),
    [anon_sym_alignof] = ACTIONS(2424),
    [anon_sym__Alignof] = ACTIONS(2424),
    [anon_sym_offsetof] = ACTIONS(2424),
    [anon_sym__Generic] = ACTIONS(2424),
    [anon_sym_asm] = ACTIONS(2424),
    [anon_sym___asm__] = ACTIONS(2424),
    [sym_number_literal] = ACTIONS(2426),
    [anon_sym_L_SQUOTE] = ACTIONS(2426),
    [anon_sym_u_SQUOTE] = ACTIONS(2426),
    [anon_sym_U_SQUOTE] = ACTIONS(2426),
    [anon_sym_u8_SQUOTE] = ACTIONS(2426),
    [anon_sym_SQUOTE] = ACTIONS(2426),
    [anon_sym_L_DQUOTE] = ACTIONS(2426),
    [anon_sym_u_DQUOTE] = ACTIONS(2426),
    [anon_sym_U_DQUOTE] = ACTIONS(2426),
    [anon_sym_u8_DQUOTE] = ACTIONS(2426),
    [anon_sym_DQUOTE] = ACTIONS(2426),
    [sym_true] = ACTIONS(2424),
    [sym_false] = ACTIONS(2424),
    [anon_sym_NULL] = ACTIONS(2424),
    [anon_sym_nullptr] = ACTIONS(2424),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2424),
    [anon_sym_decltype] = ACTIONS(2424),
    [sym_virtual] = ACTIONS(2424),
    [anon_sym_explicit] = ACTIONS(2424),
    [anon_sym_typename] = ACTIONS(2424),
    [anon_sym_template] = ACTIONS(2424),
    [anon_sym_operator] = ACTIONS(2424),
    [anon_sym_try] = ACTIONS(2424),
    [anon_sym_delete] = ACTIONS(2424),
    [anon_sym_throw] = ACTIONS(2424),
    [anon_sym_namespace] = ACTIONS(2424),
    [anon_sym_using] = ACTIONS(2424),
    [anon_sym_static_assert] = ACTIONS(2424),
    [anon_sym_concept] = ACTIONS(2424),
    [anon_sym_co_return] = ACTIONS(2424),
    [anon_sym_co_yield] = ACTIONS(2424),
    [anon_sym_R_DQUOTE] = ACTIONS(2426),
    [anon_sym_LR_DQUOTE] = ACTIONS(2426),
    [anon_sym_uR_DQUOTE] = ACTIONS(2426),
    [anon_sym_UR_DQUOTE] = ACTIONS(2426),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2426),
    [anon_sym_co_await] = ACTIONS(2424),
    [anon_sym_new] = ACTIONS(2424),
    [anon_sym_requires] = ACTIONS(2424),
    [sym_this] = ACTIONS(2424),
    [anon_sym_precise] = ACTIONS(2424),
    [anon_sym_shared] = ACTIONS(2424),
    [anon_sym_groupshared] = ACTIONS(2424),
    [anon_sym_uniform] = ACTIONS(2424),
    [anon_sym_row_major] = ACTIONS(2424),
    [anon_sym_column_major] = ACTIONS(2424),
    [anon_sym_globallycoherent] = ACTIONS(2424),
    [anon_sym_centroid] = ACTIONS(2424),
    [anon_sym_noperspective] = ACTIONS(2424),
    [anon_sym_nointerpolation] = ACTIONS(2424),
    [anon_sym_sample] = ACTIONS(2424),
    [anon_sym_linear] = ACTIONS(2424),
    [anon_sym_snorm] = ACTIONS(2424),
    [anon_sym_unorm] = ACTIONS(2424),
    [anon_sym_point] = ACTIONS(2424),
    [anon_sym_line] = ACTIONS(2424),
    [anon_sym_triangleadj] = ACTIONS(2424),
    [anon_sym_lineadj] = ACTIONS(2424),
    [anon_sym_triangle] = ACTIONS(2424),
  },
  [778] = {
    [ts_builtin_sym_end] = ACTIONS(2542),
    [sym_identifier] = ACTIONS(2540),
    [aux_sym_preproc_include_token1] = ACTIONS(2540),
    [aux_sym_preproc_def_token1] = ACTIONS(2540),
    [aux_sym_preproc_if_token1] = ACTIONS(2540),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2540),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2540),
    [sym_preproc_directive] = ACTIONS(2540),
    [anon_sym_LPAREN2] = ACTIONS(2542),
    [anon_sym_BANG] = ACTIONS(2542),
    [anon_sym_TILDE] = ACTIONS(2542),
    [anon_sym_DASH] = ACTIONS(2540),
    [anon_sym_PLUS] = ACTIONS(2540),
    [anon_sym_STAR] = ACTIONS(2542),
    [anon_sym_AMP_AMP] = ACTIONS(2542),
    [anon_sym_AMP] = ACTIONS(2540),
    [anon_sym___extension__] = ACTIONS(2540),
    [anon_sym_typedef] = ACTIONS(2540),
    [anon_sym_in] = ACTIONS(2540),
    [anon_sym_out] = ACTIONS(2540),
    [anon_sym_inout] = ACTIONS(2540),
    [anon_sym_extern] = ACTIONS(2540),
    [anon_sym___attribute__] = ACTIONS(2540),
    [anon_sym_COLON_COLON] = ACTIONS(2542),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2542),
    [anon_sym___declspec] = ACTIONS(2540),
    [anon_sym___based] = ACTIONS(2540),
    [anon_sym___cdecl] = ACTIONS(2540),
    [anon_sym___clrcall] = ACTIONS(2540),
    [anon_sym___stdcall] = ACTIONS(2540),
    [anon_sym___fastcall] = ACTIONS(2540),
    [anon_sym___thiscall] = ACTIONS(2540),
    [anon_sym___vectorcall] = ACTIONS(2540),
    [anon_sym_LBRACE] = ACTIONS(2542),
    [anon_sym_signed] = ACTIONS(2540),
    [anon_sym_unsigned] = ACTIONS(2540),
    [anon_sym_long] = ACTIONS(2540),
    [anon_sym_short] = ACTIONS(2540),
    [anon_sym_LBRACK] = ACTIONS(2540),
    [anon_sym_static] = ACTIONS(2540),
    [anon_sym_register] = ACTIONS(2540),
    [anon_sym_inline] = ACTIONS(2540),
    [anon_sym___inline] = ACTIONS(2540),
    [anon_sym___inline__] = ACTIONS(2540),
    [anon_sym___forceinline] = ACTIONS(2540),
    [anon_sym_thread_local] = ACTIONS(2540),
    [anon_sym___thread] = ACTIONS(2540),
    [anon_sym_const] = ACTIONS(2540),
    [anon_sym_constexpr] = ACTIONS(2540),
    [anon_sym_volatile] = ACTIONS(2540),
    [anon_sym_restrict] = ACTIONS(2540),
    [anon_sym___restrict__] = ACTIONS(2540),
    [anon_sym__Atomic] = ACTIONS(2540),
    [anon_sym__Noreturn] = ACTIONS(2540),
    [anon_sym_noreturn] = ACTIONS(2540),
    [anon_sym_mutable] = ACTIONS(2540),
    [anon_sym_constinit] = ACTIONS(2540),
    [anon_sym_consteval] = ACTIONS(2540),
    [anon_sym_alignas] = ACTIONS(2540),
    [anon_sym__Alignas] = ACTIONS(2540),
    [sym_primitive_type] = ACTIONS(2540),
    [anon_sym_enum] = ACTIONS(2540),
    [anon_sym_class] = ACTIONS(2540),
    [anon_sym_struct] = ACTIONS(2540),
    [anon_sym_union] = ACTIONS(2540),
    [anon_sym_if] = ACTIONS(2540),
    [anon_sym_switch] = ACTIONS(2540),
    [anon_sym_case] = ACTIONS(2540),
    [anon_sym_default] = ACTIONS(2540),
    [anon_sym_while] = ACTIONS(2540),
    [anon_sym_do] = ACTIONS(2540),
    [anon_sym_for] = ACTIONS(2540),
    [anon_sym_return] = ACTIONS(2540),
    [anon_sym_break] = ACTIONS(2540),
    [anon_sym_continue] = ACTIONS(2540),
    [anon_sym_goto] = ACTIONS(2540),
    [anon_sym_not] = ACTIONS(2540),
    [anon_sym_compl] = ACTIONS(2540),
    [anon_sym_DASH_DASH] = ACTIONS(2542),
    [anon_sym_PLUS_PLUS] = ACTIONS(2542),
    [anon_sym_sizeof] = ACTIONS(2540),
    [anon_sym___alignof__] = ACTIONS(2540),
    [anon_sym___alignof] = ACTIONS(2540),
    [anon_sym__alignof] = ACTIONS(2540),
    [anon_sym_alignof] = ACTIONS(2540),
    [anon_sym__Alignof] = ACTIONS(2540),
    [anon_sym_offsetof] = ACTIONS(2540),
    [anon_sym__Generic] = ACTIONS(2540),
    [anon_sym_asm] = ACTIONS(2540),
    [anon_sym___asm__] = ACTIONS(2540),
    [sym_number_literal] = ACTIONS(2542),
    [anon_sym_L_SQUOTE] = ACTIONS(2542),
    [anon_sym_u_SQUOTE] = ACTIONS(2542),
    [anon_sym_U_SQUOTE] = ACTIONS(2542),
    [anon_sym_u8_SQUOTE] = ACTIONS(2542),
    [anon_sym_SQUOTE] = ACTIONS(2542),
    [anon_sym_L_DQUOTE] = ACTIONS(2542),
    [anon_sym_u_DQUOTE] = ACTIONS(2542),
    [anon_sym_U_DQUOTE] = ACTIONS(2542),
    [anon_sym_u8_DQUOTE] = ACTIONS(2542),
    [anon_sym_DQUOTE] = ACTIONS(2542),
    [sym_true] = ACTIONS(2540),
    [sym_false] = ACTIONS(2540),
    [anon_sym_NULL] = ACTIONS(2540),
    [anon_sym_nullptr] = ACTIONS(2540),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2540),
    [anon_sym_decltype] = ACTIONS(2540),
    [sym_virtual] = ACTIONS(2540),
    [anon_sym_explicit] = ACTIONS(2540),
    [anon_sym_typename] = ACTIONS(2540),
    [anon_sym_template] = ACTIONS(2540),
    [anon_sym_operator] = ACTIONS(2540),
    [anon_sym_try] = ACTIONS(2540),
    [anon_sym_delete] = ACTIONS(2540),
    [anon_sym_throw] = ACTIONS(2540),
    [anon_sym_namespace] = ACTIONS(2540),
    [anon_sym_using] = ACTIONS(2540),
    [anon_sym_static_assert] = ACTIONS(2540),
    [anon_sym_concept] = ACTIONS(2540),
    [anon_sym_co_return] = ACTIONS(2540),
    [anon_sym_co_yield] = ACTIONS(2540),
    [anon_sym_R_DQUOTE] = ACTIONS(2542),
    [anon_sym_LR_DQUOTE] = ACTIONS(2542),
    [anon_sym_uR_DQUOTE] = ACTIONS(2542),
    [anon_sym_UR_DQUOTE] = ACTIONS(2542),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2542),
    [anon_sym_co_await] = ACTIONS(2540),
    [anon_sym_new] = ACTIONS(2540),
    [anon_sym_requires] = ACTIONS(2540),
    [sym_this] = ACTIONS(2540),
    [anon_sym_precise] = ACTIONS(2540),
    [anon_sym_shared] = ACTIONS(2540),
    [anon_sym_groupshared] = ACTIONS(2540),
    [anon_sym_uniform] = ACTIONS(2540),
    [anon_sym_row_major] = ACTIONS(2540),
    [anon_sym_column_major] = ACTIONS(2540),
    [anon_sym_globallycoherent] = ACTIONS(2540),
    [anon_sym_centroid] = ACTIONS(2540),
    [anon_sym_noperspective] = ACTIONS(2540),
    [anon_sym_nointerpolation] = ACTIONS(2540),
    [anon_sym_sample] = ACTIONS(2540),
    [anon_sym_linear] = ACTIONS(2540),
    [anon_sym_snorm] = ACTIONS(2540),
    [anon_sym_unorm] = ACTIONS(2540),
    [anon_sym_point] = ACTIONS(2540),
    [anon_sym_line] = ACTIONS(2540),
    [anon_sym_triangleadj] = ACTIONS(2540),
    [anon_sym_lineadj] = ACTIONS(2540),
    [anon_sym_triangle] = ACTIONS(2540),
  },
  [779] = {
    [ts_builtin_sym_end] = ACTIONS(2484),
    [sym_identifier] = ACTIONS(2482),
    [aux_sym_preproc_include_token1] = ACTIONS(2482),
    [aux_sym_preproc_def_token1] = ACTIONS(2482),
    [aux_sym_preproc_if_token1] = ACTIONS(2482),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2482),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2482),
    [sym_preproc_directive] = ACTIONS(2482),
    [anon_sym_LPAREN2] = ACTIONS(2484),
    [anon_sym_BANG] = ACTIONS(2484),
    [anon_sym_TILDE] = ACTIONS(2484),
    [anon_sym_DASH] = ACTIONS(2482),
    [anon_sym_PLUS] = ACTIONS(2482),
    [anon_sym_STAR] = ACTIONS(2484),
    [anon_sym_AMP_AMP] = ACTIONS(2484),
    [anon_sym_AMP] = ACTIONS(2482),
    [anon_sym___extension__] = ACTIONS(2482),
    [anon_sym_typedef] = ACTIONS(2482),
    [anon_sym_in] = ACTIONS(2482),
    [anon_sym_out] = ACTIONS(2482),
    [anon_sym_inout] = ACTIONS(2482),
    [anon_sym_extern] = ACTIONS(2482),
    [anon_sym___attribute__] = ACTIONS(2482),
    [anon_sym_COLON_COLON] = ACTIONS(2484),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2484),
    [anon_sym___declspec] = ACTIONS(2482),
    [anon_sym___based] = ACTIONS(2482),
    [anon_sym___cdecl] = ACTIONS(2482),
    [anon_sym___clrcall] = ACTIONS(2482),
    [anon_sym___stdcall] = ACTIONS(2482),
    [anon_sym___fastcall] = ACTIONS(2482),
    [anon_sym___thiscall] = ACTIONS(2482),
    [anon_sym___vectorcall] = ACTIONS(2482),
    [anon_sym_LBRACE] = ACTIONS(2484),
    [anon_sym_signed] = ACTIONS(2482),
    [anon_sym_unsigned] = ACTIONS(2482),
    [anon_sym_long] = ACTIONS(2482),
    [anon_sym_short] = ACTIONS(2482),
    [anon_sym_LBRACK] = ACTIONS(2482),
    [anon_sym_static] = ACTIONS(2482),
    [anon_sym_register] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(2482),
    [anon_sym___inline] = ACTIONS(2482),
    [anon_sym___inline__] = ACTIONS(2482),
    [anon_sym___forceinline] = ACTIONS(2482),
    [anon_sym_thread_local] = ACTIONS(2482),
    [anon_sym___thread] = ACTIONS(2482),
    [anon_sym_const] = ACTIONS(2482),
    [anon_sym_constexpr] = ACTIONS(2482),
    [anon_sym_volatile] = ACTIONS(2482),
    [anon_sym_restrict] = ACTIONS(2482),
    [anon_sym___restrict__] = ACTIONS(2482),
    [anon_sym__Atomic] = ACTIONS(2482),
    [anon_sym__Noreturn] = ACTIONS(2482),
    [anon_sym_noreturn] = ACTIONS(2482),
    [anon_sym_mutable] = ACTIONS(2482),
    [anon_sym_constinit] = ACTIONS(2482),
    [anon_sym_consteval] = ACTIONS(2482),
    [anon_sym_alignas] = ACTIONS(2482),
    [anon_sym__Alignas] = ACTIONS(2482),
    [sym_primitive_type] = ACTIONS(2482),
    [anon_sym_enum] = ACTIONS(2482),
    [anon_sym_class] = ACTIONS(2482),
    [anon_sym_struct] = ACTIONS(2482),
    [anon_sym_union] = ACTIONS(2482),
    [anon_sym_if] = ACTIONS(2482),
    [anon_sym_switch] = ACTIONS(2482),
    [anon_sym_case] = ACTIONS(2482),
    [anon_sym_default] = ACTIONS(2482),
    [anon_sym_while] = ACTIONS(2482),
    [anon_sym_do] = ACTIONS(2482),
    [anon_sym_for] = ACTIONS(2482),
    [anon_sym_return] = ACTIONS(2482),
    [anon_sym_break] = ACTIONS(2482),
    [anon_sym_continue] = ACTIONS(2482),
    [anon_sym_goto] = ACTIONS(2482),
    [anon_sym_not] = ACTIONS(2482),
    [anon_sym_compl] = ACTIONS(2482),
    [anon_sym_DASH_DASH] = ACTIONS(2484),
    [anon_sym_PLUS_PLUS] = ACTIONS(2484),
    [anon_sym_sizeof] = ACTIONS(2482),
    [anon_sym___alignof__] = ACTIONS(2482),
    [anon_sym___alignof] = ACTIONS(2482),
    [anon_sym__alignof] = ACTIONS(2482),
    [anon_sym_alignof] = ACTIONS(2482),
    [anon_sym__Alignof] = ACTIONS(2482),
    [anon_sym_offsetof] = ACTIONS(2482),
    [anon_sym__Generic] = ACTIONS(2482),
    [anon_sym_asm] = ACTIONS(2482),
    [anon_sym___asm__] = ACTIONS(2482),
    [sym_number_literal] = ACTIONS(2484),
    [anon_sym_L_SQUOTE] = ACTIONS(2484),
    [anon_sym_u_SQUOTE] = ACTIONS(2484),
    [anon_sym_U_SQUOTE] = ACTIONS(2484),
    [anon_sym_u8_SQUOTE] = ACTIONS(2484),
    [anon_sym_SQUOTE] = ACTIONS(2484),
    [anon_sym_L_DQUOTE] = ACTIONS(2484),
    [anon_sym_u_DQUOTE] = ACTIONS(2484),
    [anon_sym_U_DQUOTE] = ACTIONS(2484),
    [anon_sym_u8_DQUOTE] = ACTIONS(2484),
    [anon_sym_DQUOTE] = ACTIONS(2484),
    [sym_true] = ACTIONS(2482),
    [sym_false] = ACTIONS(2482),
    [anon_sym_NULL] = ACTIONS(2482),
    [anon_sym_nullptr] = ACTIONS(2482),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2482),
    [anon_sym_decltype] = ACTIONS(2482),
    [sym_virtual] = ACTIONS(2482),
    [anon_sym_explicit] = ACTIONS(2482),
    [anon_sym_typename] = ACTIONS(2482),
    [anon_sym_template] = ACTIONS(2482),
    [anon_sym_operator] = ACTIONS(2482),
    [anon_sym_try] = ACTIONS(2482),
    [anon_sym_delete] = ACTIONS(2482),
    [anon_sym_throw] = ACTIONS(2482),
    [anon_sym_namespace] = ACTIONS(2482),
    [anon_sym_using] = ACTIONS(2482),
    [anon_sym_static_assert] = ACTIONS(2482),
    [anon_sym_concept] = ACTIONS(2482),
    [anon_sym_co_return] = ACTIONS(2482),
    [anon_sym_co_yield] = ACTIONS(2482),
    [anon_sym_R_DQUOTE] = ACTIONS(2484),
    [anon_sym_LR_DQUOTE] = ACTIONS(2484),
    [anon_sym_uR_DQUOTE] = ACTIONS(2484),
    [anon_sym_UR_DQUOTE] = ACTIONS(2484),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2484),
    [anon_sym_co_await] = ACTIONS(2482),
    [anon_sym_new] = ACTIONS(2482),
    [anon_sym_requires] = ACTIONS(2482),
    [sym_this] = ACTIONS(2482),
    [anon_sym_precise] = ACTIONS(2482),
    [anon_sym_shared] = ACTIONS(2482),
    [anon_sym_groupshared] = ACTIONS(2482),
    [anon_sym_uniform] = ACTIONS(2482),
    [anon_sym_row_major] = ACTIONS(2482),
    [anon_sym_column_major] = ACTIONS(2482),
    [anon_sym_globallycoherent] = ACTIONS(2482),
    [anon_sym_centroid] = ACTIONS(2482),
    [anon_sym_noperspective] = ACTIONS(2482),
    [anon_sym_nointerpolation] = ACTIONS(2482),
    [anon_sym_sample] = ACTIONS(2482),
    [anon_sym_linear] = ACTIONS(2482),
    [anon_sym_snorm] = ACTIONS(2482),
    [anon_sym_unorm] = ACTIONS(2482),
    [anon_sym_point] = ACTIONS(2482),
    [anon_sym_line] = ACTIONS(2482),
    [anon_sym_triangleadj] = ACTIONS(2482),
    [anon_sym_lineadj] = ACTIONS(2482),
    [anon_sym_triangle] = ACTIONS(2482),
  },
  [780] = {
    [sym_preproc_def] = STATE(797),
    [sym_preproc_function_def] = STATE(797),
    [sym_preproc_call] = STATE(797),
    [sym_preproc_if_in_field_declaration_list] = STATE(797),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(797),
    [sym_type_definition] = STATE(797),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(797),
    [sym_field_declaration] = STATE(797),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(797),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(797),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(797),
    [sym_operator_cast_declaration] = STATE(797),
    [sym_constructor_or_destructor_definition] = STATE(797),
    [sym_constructor_or_destructor_declaration] = STATE(797),
    [sym_friend_declaration] = STATE(797),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(797),
    [sym_alias_declaration] = STATE(797),
    [sym_static_assert_declaration] = STATE(797),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(797),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2985),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [781] = {
    [ts_builtin_sym_end] = ACTIONS(2330),
    [sym_identifier] = ACTIONS(2328),
    [aux_sym_preproc_include_token1] = ACTIONS(2328),
    [aux_sym_preproc_def_token1] = ACTIONS(2328),
    [aux_sym_preproc_if_token1] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2328),
    [sym_preproc_directive] = ACTIONS(2328),
    [anon_sym_LPAREN2] = ACTIONS(2330),
    [anon_sym_BANG] = ACTIONS(2330),
    [anon_sym_TILDE] = ACTIONS(2330),
    [anon_sym_DASH] = ACTIONS(2328),
    [anon_sym_PLUS] = ACTIONS(2328),
    [anon_sym_STAR] = ACTIONS(2330),
    [anon_sym_AMP_AMP] = ACTIONS(2330),
    [anon_sym_AMP] = ACTIONS(2328),
    [anon_sym___extension__] = ACTIONS(2328),
    [anon_sym_typedef] = ACTIONS(2328),
    [anon_sym_in] = ACTIONS(2328),
    [anon_sym_out] = ACTIONS(2328),
    [anon_sym_inout] = ACTIONS(2328),
    [anon_sym_extern] = ACTIONS(2328),
    [anon_sym___attribute__] = ACTIONS(2328),
    [anon_sym_COLON_COLON] = ACTIONS(2330),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2330),
    [anon_sym___declspec] = ACTIONS(2328),
    [anon_sym___based] = ACTIONS(2328),
    [anon_sym___cdecl] = ACTIONS(2328),
    [anon_sym___clrcall] = ACTIONS(2328),
    [anon_sym___stdcall] = ACTIONS(2328),
    [anon_sym___fastcall] = ACTIONS(2328),
    [anon_sym___thiscall] = ACTIONS(2328),
    [anon_sym___vectorcall] = ACTIONS(2328),
    [anon_sym_LBRACE] = ACTIONS(2330),
    [anon_sym_signed] = ACTIONS(2328),
    [anon_sym_unsigned] = ACTIONS(2328),
    [anon_sym_long] = ACTIONS(2328),
    [anon_sym_short] = ACTIONS(2328),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_static] = ACTIONS(2328),
    [anon_sym_register] = ACTIONS(2328),
    [anon_sym_inline] = ACTIONS(2328),
    [anon_sym___inline] = ACTIONS(2328),
    [anon_sym___inline__] = ACTIONS(2328),
    [anon_sym___forceinline] = ACTIONS(2328),
    [anon_sym_thread_local] = ACTIONS(2328),
    [anon_sym___thread] = ACTIONS(2328),
    [anon_sym_const] = ACTIONS(2328),
    [anon_sym_constexpr] = ACTIONS(2328),
    [anon_sym_volatile] = ACTIONS(2328),
    [anon_sym_restrict] = ACTIONS(2328),
    [anon_sym___restrict__] = ACTIONS(2328),
    [anon_sym__Atomic] = ACTIONS(2328),
    [anon_sym__Noreturn] = ACTIONS(2328),
    [anon_sym_noreturn] = ACTIONS(2328),
    [anon_sym_mutable] = ACTIONS(2328),
    [anon_sym_constinit] = ACTIONS(2328),
    [anon_sym_consteval] = ACTIONS(2328),
    [anon_sym_alignas] = ACTIONS(2328),
    [anon_sym__Alignas] = ACTIONS(2328),
    [sym_primitive_type] = ACTIONS(2328),
    [anon_sym_enum] = ACTIONS(2328),
    [anon_sym_class] = ACTIONS(2328),
    [anon_sym_struct] = ACTIONS(2328),
    [anon_sym_union] = ACTIONS(2328),
    [anon_sym_if] = ACTIONS(2328),
    [anon_sym_switch] = ACTIONS(2328),
    [anon_sym_case] = ACTIONS(2328),
    [anon_sym_default] = ACTIONS(2328),
    [anon_sym_while] = ACTIONS(2328),
    [anon_sym_do] = ACTIONS(2328),
    [anon_sym_for] = ACTIONS(2328),
    [anon_sym_return] = ACTIONS(2328),
    [anon_sym_break] = ACTIONS(2328),
    [anon_sym_continue] = ACTIONS(2328),
    [anon_sym_goto] = ACTIONS(2328),
    [anon_sym_not] = ACTIONS(2328),
    [anon_sym_compl] = ACTIONS(2328),
    [anon_sym_DASH_DASH] = ACTIONS(2330),
    [anon_sym_PLUS_PLUS] = ACTIONS(2330),
    [anon_sym_sizeof] = ACTIONS(2328),
    [anon_sym___alignof__] = ACTIONS(2328),
    [anon_sym___alignof] = ACTIONS(2328),
    [anon_sym__alignof] = ACTIONS(2328),
    [anon_sym_alignof] = ACTIONS(2328),
    [anon_sym__Alignof] = ACTIONS(2328),
    [anon_sym_offsetof] = ACTIONS(2328),
    [anon_sym__Generic] = ACTIONS(2328),
    [anon_sym_asm] = ACTIONS(2328),
    [anon_sym___asm__] = ACTIONS(2328),
    [sym_number_literal] = ACTIONS(2330),
    [anon_sym_L_SQUOTE] = ACTIONS(2330),
    [anon_sym_u_SQUOTE] = ACTIONS(2330),
    [anon_sym_U_SQUOTE] = ACTIONS(2330),
    [anon_sym_u8_SQUOTE] = ACTIONS(2330),
    [anon_sym_SQUOTE] = ACTIONS(2330),
    [anon_sym_L_DQUOTE] = ACTIONS(2330),
    [anon_sym_u_DQUOTE] = ACTIONS(2330),
    [anon_sym_U_DQUOTE] = ACTIONS(2330),
    [anon_sym_u8_DQUOTE] = ACTIONS(2330),
    [anon_sym_DQUOTE] = ACTIONS(2330),
    [sym_true] = ACTIONS(2328),
    [sym_false] = ACTIONS(2328),
    [anon_sym_NULL] = ACTIONS(2328),
    [anon_sym_nullptr] = ACTIONS(2328),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2328),
    [anon_sym_decltype] = ACTIONS(2328),
    [sym_virtual] = ACTIONS(2328),
    [anon_sym_explicit] = ACTIONS(2328),
    [anon_sym_typename] = ACTIONS(2328),
    [anon_sym_template] = ACTIONS(2328),
    [anon_sym_operator] = ACTIONS(2328),
    [anon_sym_try] = ACTIONS(2328),
    [anon_sym_delete] = ACTIONS(2328),
    [anon_sym_throw] = ACTIONS(2328),
    [anon_sym_namespace] = ACTIONS(2328),
    [anon_sym_using] = ACTIONS(2328),
    [anon_sym_static_assert] = ACTIONS(2328),
    [anon_sym_concept] = ACTIONS(2328),
    [anon_sym_co_return] = ACTIONS(2328),
    [anon_sym_co_yield] = ACTIONS(2328),
    [anon_sym_R_DQUOTE] = ACTIONS(2330),
    [anon_sym_LR_DQUOTE] = ACTIONS(2330),
    [anon_sym_uR_DQUOTE] = ACTIONS(2330),
    [anon_sym_UR_DQUOTE] = ACTIONS(2330),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2330),
    [anon_sym_co_await] = ACTIONS(2328),
    [anon_sym_new] = ACTIONS(2328),
    [anon_sym_requires] = ACTIONS(2328),
    [sym_this] = ACTIONS(2328),
    [anon_sym_precise] = ACTIONS(2328),
    [anon_sym_shared] = ACTIONS(2328),
    [anon_sym_groupshared] = ACTIONS(2328),
    [anon_sym_uniform] = ACTIONS(2328),
    [anon_sym_row_major] = ACTIONS(2328),
    [anon_sym_column_major] = ACTIONS(2328),
    [anon_sym_globallycoherent] = ACTIONS(2328),
    [anon_sym_centroid] = ACTIONS(2328),
    [anon_sym_noperspective] = ACTIONS(2328),
    [anon_sym_nointerpolation] = ACTIONS(2328),
    [anon_sym_sample] = ACTIONS(2328),
    [anon_sym_linear] = ACTIONS(2328),
    [anon_sym_snorm] = ACTIONS(2328),
    [anon_sym_unorm] = ACTIONS(2328),
    [anon_sym_point] = ACTIONS(2328),
    [anon_sym_line] = ACTIONS(2328),
    [anon_sym_triangleadj] = ACTIONS(2328),
    [anon_sym_lineadj] = ACTIONS(2328),
    [anon_sym_triangle] = ACTIONS(2328),
  },
  [782] = {
    [ts_builtin_sym_end] = ACTIONS(2326),
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_include_token1] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_BANG] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_DASH] = ACTIONS(2324),
    [anon_sym_PLUS] = ACTIONS(2324),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym___cdecl] = ACTIONS(2324),
    [anon_sym___clrcall] = ACTIONS(2324),
    [anon_sym___stdcall] = ACTIONS(2324),
    [anon_sym___fastcall] = ACTIONS(2324),
    [anon_sym___thiscall] = ACTIONS(2324),
    [anon_sym___vectorcall] = ACTIONS(2324),
    [anon_sym_LBRACE] = ACTIONS(2326),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [anon_sym_if] = ACTIONS(2324),
    [anon_sym_switch] = ACTIONS(2324),
    [anon_sym_case] = ACTIONS(2324),
    [anon_sym_default] = ACTIONS(2324),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_do] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2324),
    [anon_sym_return] = ACTIONS(2324),
    [anon_sym_break] = ACTIONS(2324),
    [anon_sym_continue] = ACTIONS(2324),
    [anon_sym_goto] = ACTIONS(2324),
    [anon_sym_not] = ACTIONS(2324),
    [anon_sym_compl] = ACTIONS(2324),
    [anon_sym_DASH_DASH] = ACTIONS(2326),
    [anon_sym_PLUS_PLUS] = ACTIONS(2326),
    [anon_sym_sizeof] = ACTIONS(2324),
    [anon_sym___alignof__] = ACTIONS(2324),
    [anon_sym___alignof] = ACTIONS(2324),
    [anon_sym__alignof] = ACTIONS(2324),
    [anon_sym_alignof] = ACTIONS(2324),
    [anon_sym__Alignof] = ACTIONS(2324),
    [anon_sym_offsetof] = ACTIONS(2324),
    [anon_sym__Generic] = ACTIONS(2324),
    [anon_sym_asm] = ACTIONS(2324),
    [anon_sym___asm__] = ACTIONS(2324),
    [sym_number_literal] = ACTIONS(2326),
    [anon_sym_L_SQUOTE] = ACTIONS(2326),
    [anon_sym_u_SQUOTE] = ACTIONS(2326),
    [anon_sym_U_SQUOTE] = ACTIONS(2326),
    [anon_sym_u8_SQUOTE] = ACTIONS(2326),
    [anon_sym_SQUOTE] = ACTIONS(2326),
    [anon_sym_L_DQUOTE] = ACTIONS(2326),
    [anon_sym_u_DQUOTE] = ACTIONS(2326),
    [anon_sym_U_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8_DQUOTE] = ACTIONS(2326),
    [anon_sym_DQUOTE] = ACTIONS(2326),
    [sym_true] = ACTIONS(2324),
    [sym_false] = ACTIONS(2324),
    [anon_sym_NULL] = ACTIONS(2324),
    [anon_sym_nullptr] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_try] = ACTIONS(2324),
    [anon_sym_delete] = ACTIONS(2324),
    [anon_sym_throw] = ACTIONS(2324),
    [anon_sym_namespace] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_concept] = ACTIONS(2324),
    [anon_sym_co_return] = ACTIONS(2324),
    [anon_sym_co_yield] = ACTIONS(2324),
    [anon_sym_R_DQUOTE] = ACTIONS(2326),
    [anon_sym_LR_DQUOTE] = ACTIONS(2326),
    [anon_sym_uR_DQUOTE] = ACTIONS(2326),
    [anon_sym_UR_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2326),
    [anon_sym_co_await] = ACTIONS(2324),
    [anon_sym_new] = ACTIONS(2324),
    [anon_sym_requires] = ACTIONS(2324),
    [sym_this] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
  },
  [783] = {
    [ts_builtin_sym_end] = ACTIONS(2362),
    [sym_identifier] = ACTIONS(2360),
    [aux_sym_preproc_include_token1] = ACTIONS(2360),
    [aux_sym_preproc_def_token1] = ACTIONS(2360),
    [aux_sym_preproc_if_token1] = ACTIONS(2360),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2360),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2360),
    [sym_preproc_directive] = ACTIONS(2360),
    [anon_sym_LPAREN2] = ACTIONS(2362),
    [anon_sym_BANG] = ACTIONS(2362),
    [anon_sym_TILDE] = ACTIONS(2362),
    [anon_sym_DASH] = ACTIONS(2360),
    [anon_sym_PLUS] = ACTIONS(2360),
    [anon_sym_STAR] = ACTIONS(2362),
    [anon_sym_AMP_AMP] = ACTIONS(2362),
    [anon_sym_AMP] = ACTIONS(2360),
    [anon_sym___extension__] = ACTIONS(2360),
    [anon_sym_typedef] = ACTIONS(2360),
    [anon_sym_in] = ACTIONS(2360),
    [anon_sym_out] = ACTIONS(2360),
    [anon_sym_inout] = ACTIONS(2360),
    [anon_sym_extern] = ACTIONS(2360),
    [anon_sym___attribute__] = ACTIONS(2360),
    [anon_sym_COLON_COLON] = ACTIONS(2362),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2362),
    [anon_sym___declspec] = ACTIONS(2360),
    [anon_sym___based] = ACTIONS(2360),
    [anon_sym___cdecl] = ACTIONS(2360),
    [anon_sym___clrcall] = ACTIONS(2360),
    [anon_sym___stdcall] = ACTIONS(2360),
    [anon_sym___fastcall] = ACTIONS(2360),
    [anon_sym___thiscall] = ACTIONS(2360),
    [anon_sym___vectorcall] = ACTIONS(2360),
    [anon_sym_LBRACE] = ACTIONS(2362),
    [anon_sym_signed] = ACTIONS(2360),
    [anon_sym_unsigned] = ACTIONS(2360),
    [anon_sym_long] = ACTIONS(2360),
    [anon_sym_short] = ACTIONS(2360),
    [anon_sym_LBRACK] = ACTIONS(2360),
    [anon_sym_static] = ACTIONS(2360),
    [anon_sym_register] = ACTIONS(2360),
    [anon_sym_inline] = ACTIONS(2360),
    [anon_sym___inline] = ACTIONS(2360),
    [anon_sym___inline__] = ACTIONS(2360),
    [anon_sym___forceinline] = ACTIONS(2360),
    [anon_sym_thread_local] = ACTIONS(2360),
    [anon_sym___thread] = ACTIONS(2360),
    [anon_sym_const] = ACTIONS(2360),
    [anon_sym_constexpr] = ACTIONS(2360),
    [anon_sym_volatile] = ACTIONS(2360),
    [anon_sym_restrict] = ACTIONS(2360),
    [anon_sym___restrict__] = ACTIONS(2360),
    [anon_sym__Atomic] = ACTIONS(2360),
    [anon_sym__Noreturn] = ACTIONS(2360),
    [anon_sym_noreturn] = ACTIONS(2360),
    [anon_sym_mutable] = ACTIONS(2360),
    [anon_sym_constinit] = ACTIONS(2360),
    [anon_sym_consteval] = ACTIONS(2360),
    [anon_sym_alignas] = ACTIONS(2360),
    [anon_sym__Alignas] = ACTIONS(2360),
    [sym_primitive_type] = ACTIONS(2360),
    [anon_sym_enum] = ACTIONS(2360),
    [anon_sym_class] = ACTIONS(2360),
    [anon_sym_struct] = ACTIONS(2360),
    [anon_sym_union] = ACTIONS(2360),
    [anon_sym_if] = ACTIONS(2360),
    [anon_sym_switch] = ACTIONS(2360),
    [anon_sym_case] = ACTIONS(2360),
    [anon_sym_default] = ACTIONS(2360),
    [anon_sym_while] = ACTIONS(2360),
    [anon_sym_do] = ACTIONS(2360),
    [anon_sym_for] = ACTIONS(2360),
    [anon_sym_return] = ACTIONS(2360),
    [anon_sym_break] = ACTIONS(2360),
    [anon_sym_continue] = ACTIONS(2360),
    [anon_sym_goto] = ACTIONS(2360),
    [anon_sym_not] = ACTIONS(2360),
    [anon_sym_compl] = ACTIONS(2360),
    [anon_sym_DASH_DASH] = ACTIONS(2362),
    [anon_sym_PLUS_PLUS] = ACTIONS(2362),
    [anon_sym_sizeof] = ACTIONS(2360),
    [anon_sym___alignof__] = ACTIONS(2360),
    [anon_sym___alignof] = ACTIONS(2360),
    [anon_sym__alignof] = ACTIONS(2360),
    [anon_sym_alignof] = ACTIONS(2360),
    [anon_sym__Alignof] = ACTIONS(2360),
    [anon_sym_offsetof] = ACTIONS(2360),
    [anon_sym__Generic] = ACTIONS(2360),
    [anon_sym_asm] = ACTIONS(2360),
    [anon_sym___asm__] = ACTIONS(2360),
    [sym_number_literal] = ACTIONS(2362),
    [anon_sym_L_SQUOTE] = ACTIONS(2362),
    [anon_sym_u_SQUOTE] = ACTIONS(2362),
    [anon_sym_U_SQUOTE] = ACTIONS(2362),
    [anon_sym_u8_SQUOTE] = ACTIONS(2362),
    [anon_sym_SQUOTE] = ACTIONS(2362),
    [anon_sym_L_DQUOTE] = ACTIONS(2362),
    [anon_sym_u_DQUOTE] = ACTIONS(2362),
    [anon_sym_U_DQUOTE] = ACTIONS(2362),
    [anon_sym_u8_DQUOTE] = ACTIONS(2362),
    [anon_sym_DQUOTE] = ACTIONS(2362),
    [sym_true] = ACTIONS(2360),
    [sym_false] = ACTIONS(2360),
    [anon_sym_NULL] = ACTIONS(2360),
    [anon_sym_nullptr] = ACTIONS(2360),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2360),
    [anon_sym_decltype] = ACTIONS(2360),
    [sym_virtual] = ACTIONS(2360),
    [anon_sym_explicit] = ACTIONS(2360),
    [anon_sym_typename] = ACTIONS(2360),
    [anon_sym_template] = ACTIONS(2360),
    [anon_sym_operator] = ACTIONS(2360),
    [anon_sym_try] = ACTIONS(2360),
    [anon_sym_delete] = ACTIONS(2360),
    [anon_sym_throw] = ACTIONS(2360),
    [anon_sym_namespace] = ACTIONS(2360),
    [anon_sym_using] = ACTIONS(2360),
    [anon_sym_static_assert] = ACTIONS(2360),
    [anon_sym_concept] = ACTIONS(2360),
    [anon_sym_co_return] = ACTIONS(2360),
    [anon_sym_co_yield] = ACTIONS(2360),
    [anon_sym_R_DQUOTE] = ACTIONS(2362),
    [anon_sym_LR_DQUOTE] = ACTIONS(2362),
    [anon_sym_uR_DQUOTE] = ACTIONS(2362),
    [anon_sym_UR_DQUOTE] = ACTIONS(2362),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2362),
    [anon_sym_co_await] = ACTIONS(2360),
    [anon_sym_new] = ACTIONS(2360),
    [anon_sym_requires] = ACTIONS(2360),
    [sym_this] = ACTIONS(2360),
    [anon_sym_precise] = ACTIONS(2360),
    [anon_sym_shared] = ACTIONS(2360),
    [anon_sym_groupshared] = ACTIONS(2360),
    [anon_sym_uniform] = ACTIONS(2360),
    [anon_sym_row_major] = ACTIONS(2360),
    [anon_sym_column_major] = ACTIONS(2360),
    [anon_sym_globallycoherent] = ACTIONS(2360),
    [anon_sym_centroid] = ACTIONS(2360),
    [anon_sym_noperspective] = ACTIONS(2360),
    [anon_sym_nointerpolation] = ACTIONS(2360),
    [anon_sym_sample] = ACTIONS(2360),
    [anon_sym_linear] = ACTIONS(2360),
    [anon_sym_snorm] = ACTIONS(2360),
    [anon_sym_unorm] = ACTIONS(2360),
    [anon_sym_point] = ACTIONS(2360),
    [anon_sym_line] = ACTIONS(2360),
    [anon_sym_triangleadj] = ACTIONS(2360),
    [anon_sym_lineadj] = ACTIONS(2360),
    [anon_sym_triangle] = ACTIONS(2360),
  },
  [784] = {
    [sym_preproc_def] = STATE(785),
    [sym_preproc_function_def] = STATE(785),
    [sym_preproc_call] = STATE(785),
    [sym_preproc_if_in_field_declaration_list] = STATE(785),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(785),
    [sym_type_definition] = STATE(785),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(785),
    [sym_field_declaration] = STATE(785),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(785),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(785),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(785),
    [sym_operator_cast_declaration] = STATE(785),
    [sym_constructor_or_destructor_definition] = STATE(785),
    [sym_constructor_or_destructor_declaration] = STATE(785),
    [sym_friend_declaration] = STATE(785),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(785),
    [sym_alias_declaration] = STATE(785),
    [sym_static_assert_declaration] = STATE(785),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(785),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2987),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [785] = {
    [sym_preproc_def] = STATE(797),
    [sym_preproc_function_def] = STATE(797),
    [sym_preproc_call] = STATE(797),
    [sym_preproc_if_in_field_declaration_list] = STATE(797),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(797),
    [sym_type_definition] = STATE(797),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(797),
    [sym_field_declaration] = STATE(797),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(797),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(797),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(797),
    [sym_operator_cast_declaration] = STATE(797),
    [sym_constructor_or_destructor_definition] = STATE(797),
    [sym_constructor_or_destructor_declaration] = STATE(797),
    [sym_friend_declaration] = STATE(797),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(797),
    [sym_alias_declaration] = STATE(797),
    [sym_static_assert_declaration] = STATE(797),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(797),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2989),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [786] = {
    [ts_builtin_sym_end] = ACTIONS(2326),
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_include_token1] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_BANG] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_DASH] = ACTIONS(2324),
    [anon_sym_PLUS] = ACTIONS(2324),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym___cdecl] = ACTIONS(2324),
    [anon_sym___clrcall] = ACTIONS(2324),
    [anon_sym___stdcall] = ACTIONS(2324),
    [anon_sym___fastcall] = ACTIONS(2324),
    [anon_sym___thiscall] = ACTIONS(2324),
    [anon_sym___vectorcall] = ACTIONS(2324),
    [anon_sym_LBRACE] = ACTIONS(2326),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [anon_sym_if] = ACTIONS(2324),
    [anon_sym_switch] = ACTIONS(2324),
    [anon_sym_case] = ACTIONS(2324),
    [anon_sym_default] = ACTIONS(2324),
    [anon_sym_while] = ACTIONS(2324),
    [anon_sym_do] = ACTIONS(2324),
    [anon_sym_for] = ACTIONS(2324),
    [anon_sym_return] = ACTIONS(2324),
    [anon_sym_break] = ACTIONS(2324),
    [anon_sym_continue] = ACTIONS(2324),
    [anon_sym_goto] = ACTIONS(2324),
    [anon_sym_not] = ACTIONS(2324),
    [anon_sym_compl] = ACTIONS(2324),
    [anon_sym_DASH_DASH] = ACTIONS(2326),
    [anon_sym_PLUS_PLUS] = ACTIONS(2326),
    [anon_sym_sizeof] = ACTIONS(2324),
    [anon_sym___alignof__] = ACTIONS(2324),
    [anon_sym___alignof] = ACTIONS(2324),
    [anon_sym__alignof] = ACTIONS(2324),
    [anon_sym_alignof] = ACTIONS(2324),
    [anon_sym__Alignof] = ACTIONS(2324),
    [anon_sym_offsetof] = ACTIONS(2324),
    [anon_sym__Generic] = ACTIONS(2324),
    [anon_sym_asm] = ACTIONS(2324),
    [anon_sym___asm__] = ACTIONS(2324),
    [sym_number_literal] = ACTIONS(2326),
    [anon_sym_L_SQUOTE] = ACTIONS(2326),
    [anon_sym_u_SQUOTE] = ACTIONS(2326),
    [anon_sym_U_SQUOTE] = ACTIONS(2326),
    [anon_sym_u8_SQUOTE] = ACTIONS(2326),
    [anon_sym_SQUOTE] = ACTIONS(2326),
    [anon_sym_L_DQUOTE] = ACTIONS(2326),
    [anon_sym_u_DQUOTE] = ACTIONS(2326),
    [anon_sym_U_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8_DQUOTE] = ACTIONS(2326),
    [anon_sym_DQUOTE] = ACTIONS(2326),
    [sym_true] = ACTIONS(2324),
    [sym_false] = ACTIONS(2324),
    [anon_sym_NULL] = ACTIONS(2324),
    [anon_sym_nullptr] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_try] = ACTIONS(2324),
    [anon_sym_delete] = ACTIONS(2324),
    [anon_sym_throw] = ACTIONS(2324),
    [anon_sym_namespace] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_concept] = ACTIONS(2324),
    [anon_sym_co_return] = ACTIONS(2324),
    [anon_sym_co_yield] = ACTIONS(2324),
    [anon_sym_R_DQUOTE] = ACTIONS(2326),
    [anon_sym_LR_DQUOTE] = ACTIONS(2326),
    [anon_sym_uR_DQUOTE] = ACTIONS(2326),
    [anon_sym_UR_DQUOTE] = ACTIONS(2326),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2326),
    [anon_sym_co_await] = ACTIONS(2324),
    [anon_sym_new] = ACTIONS(2324),
    [anon_sym_requires] = ACTIONS(2324),
    [sym_this] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
  },
  [787] = {
    [ts_builtin_sym_end] = ACTIONS(2294),
    [sym_identifier] = ACTIONS(2292),
    [aux_sym_preproc_include_token1] = ACTIONS(2292),
    [aux_sym_preproc_def_token1] = ACTIONS(2292),
    [aux_sym_preproc_if_token1] = ACTIONS(2292),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2292),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2292),
    [sym_preproc_directive] = ACTIONS(2292),
    [anon_sym_LPAREN2] = ACTIONS(2294),
    [anon_sym_BANG] = ACTIONS(2294),
    [anon_sym_TILDE] = ACTIONS(2294),
    [anon_sym_DASH] = ACTIONS(2292),
    [anon_sym_PLUS] = ACTIONS(2292),
    [anon_sym_STAR] = ACTIONS(2294),
    [anon_sym_AMP_AMP] = ACTIONS(2294),
    [anon_sym_AMP] = ACTIONS(2292),
    [anon_sym___extension__] = ACTIONS(2292),
    [anon_sym_typedef] = ACTIONS(2292),
    [anon_sym_in] = ACTIONS(2292),
    [anon_sym_out] = ACTIONS(2292),
    [anon_sym_inout] = ACTIONS(2292),
    [anon_sym_extern] = ACTIONS(2292),
    [anon_sym___attribute__] = ACTIONS(2292),
    [anon_sym_COLON_COLON] = ACTIONS(2294),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2294),
    [anon_sym___declspec] = ACTIONS(2292),
    [anon_sym___based] = ACTIONS(2292),
    [anon_sym___cdecl] = ACTIONS(2292),
    [anon_sym___clrcall] = ACTIONS(2292),
    [anon_sym___stdcall] = ACTIONS(2292),
    [anon_sym___fastcall] = ACTIONS(2292),
    [anon_sym___thiscall] = ACTIONS(2292),
    [anon_sym___vectorcall] = ACTIONS(2292),
    [anon_sym_LBRACE] = ACTIONS(2294),
    [anon_sym_signed] = ACTIONS(2292),
    [anon_sym_unsigned] = ACTIONS(2292),
    [anon_sym_long] = ACTIONS(2292),
    [anon_sym_short] = ACTIONS(2292),
    [anon_sym_LBRACK] = ACTIONS(2292),
    [anon_sym_static] = ACTIONS(2292),
    [anon_sym_register] = ACTIONS(2292),
    [anon_sym_inline] = ACTIONS(2292),
    [anon_sym___inline] = ACTIONS(2292),
    [anon_sym___inline__] = ACTIONS(2292),
    [anon_sym___forceinline] = ACTIONS(2292),
    [anon_sym_thread_local] = ACTIONS(2292),
    [anon_sym___thread] = ACTIONS(2292),
    [anon_sym_const] = ACTIONS(2292),
    [anon_sym_constexpr] = ACTIONS(2292),
    [anon_sym_volatile] = ACTIONS(2292),
    [anon_sym_restrict] = ACTIONS(2292),
    [anon_sym___restrict__] = ACTIONS(2292),
    [anon_sym__Atomic] = ACTIONS(2292),
    [anon_sym__Noreturn] = ACTIONS(2292),
    [anon_sym_noreturn] = ACTIONS(2292),
    [anon_sym_mutable] = ACTIONS(2292),
    [anon_sym_constinit] = ACTIONS(2292),
    [anon_sym_consteval] = ACTIONS(2292),
    [anon_sym_alignas] = ACTIONS(2292),
    [anon_sym__Alignas] = ACTIONS(2292),
    [sym_primitive_type] = ACTIONS(2292),
    [anon_sym_enum] = ACTIONS(2292),
    [anon_sym_class] = ACTIONS(2292),
    [anon_sym_struct] = ACTIONS(2292),
    [anon_sym_union] = ACTIONS(2292),
    [anon_sym_if] = ACTIONS(2292),
    [anon_sym_switch] = ACTIONS(2292),
    [anon_sym_case] = ACTIONS(2292),
    [anon_sym_default] = ACTIONS(2292),
    [anon_sym_while] = ACTIONS(2292),
    [anon_sym_do] = ACTIONS(2292),
    [anon_sym_for] = ACTIONS(2292),
    [anon_sym_return] = ACTIONS(2292),
    [anon_sym_break] = ACTIONS(2292),
    [anon_sym_continue] = ACTIONS(2292),
    [anon_sym_goto] = ACTIONS(2292),
    [anon_sym_not] = ACTIONS(2292),
    [anon_sym_compl] = ACTIONS(2292),
    [anon_sym_DASH_DASH] = ACTIONS(2294),
    [anon_sym_PLUS_PLUS] = ACTIONS(2294),
    [anon_sym_sizeof] = ACTIONS(2292),
    [anon_sym___alignof__] = ACTIONS(2292),
    [anon_sym___alignof] = ACTIONS(2292),
    [anon_sym__alignof] = ACTIONS(2292),
    [anon_sym_alignof] = ACTIONS(2292),
    [anon_sym__Alignof] = ACTIONS(2292),
    [anon_sym_offsetof] = ACTIONS(2292),
    [anon_sym__Generic] = ACTIONS(2292),
    [anon_sym_asm] = ACTIONS(2292),
    [anon_sym___asm__] = ACTIONS(2292),
    [sym_number_literal] = ACTIONS(2294),
    [anon_sym_L_SQUOTE] = ACTIONS(2294),
    [anon_sym_u_SQUOTE] = ACTIONS(2294),
    [anon_sym_U_SQUOTE] = ACTIONS(2294),
    [anon_sym_u8_SQUOTE] = ACTIONS(2294),
    [anon_sym_SQUOTE] = ACTIONS(2294),
    [anon_sym_L_DQUOTE] = ACTIONS(2294),
    [anon_sym_u_DQUOTE] = ACTIONS(2294),
    [anon_sym_U_DQUOTE] = ACTIONS(2294),
    [anon_sym_u8_DQUOTE] = ACTIONS(2294),
    [anon_sym_DQUOTE] = ACTIONS(2294),
    [sym_true] = ACTIONS(2292),
    [sym_false] = ACTIONS(2292),
    [anon_sym_NULL] = ACTIONS(2292),
    [anon_sym_nullptr] = ACTIONS(2292),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2292),
    [anon_sym_decltype] = ACTIONS(2292),
    [sym_virtual] = ACTIONS(2292),
    [anon_sym_explicit] = ACTIONS(2292),
    [anon_sym_typename] = ACTIONS(2292),
    [anon_sym_template] = ACTIONS(2292),
    [anon_sym_operator] = ACTIONS(2292),
    [anon_sym_try] = ACTIONS(2292),
    [anon_sym_delete] = ACTIONS(2292),
    [anon_sym_throw] = ACTIONS(2292),
    [anon_sym_namespace] = ACTIONS(2292),
    [anon_sym_using] = ACTIONS(2292),
    [anon_sym_static_assert] = ACTIONS(2292),
    [anon_sym_concept] = ACTIONS(2292),
    [anon_sym_co_return] = ACTIONS(2292),
    [anon_sym_co_yield] = ACTIONS(2292),
    [anon_sym_R_DQUOTE] = ACTIONS(2294),
    [anon_sym_LR_DQUOTE] = ACTIONS(2294),
    [anon_sym_uR_DQUOTE] = ACTIONS(2294),
    [anon_sym_UR_DQUOTE] = ACTIONS(2294),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2294),
    [anon_sym_co_await] = ACTIONS(2292),
    [anon_sym_new] = ACTIONS(2292),
    [anon_sym_requires] = ACTIONS(2292),
    [sym_this] = ACTIONS(2292),
    [anon_sym_precise] = ACTIONS(2292),
    [anon_sym_shared] = ACTIONS(2292),
    [anon_sym_groupshared] = ACTIONS(2292),
    [anon_sym_uniform] = ACTIONS(2292),
    [anon_sym_row_major] = ACTIONS(2292),
    [anon_sym_column_major] = ACTIONS(2292),
    [anon_sym_globallycoherent] = ACTIONS(2292),
    [anon_sym_centroid] = ACTIONS(2292),
    [anon_sym_noperspective] = ACTIONS(2292),
    [anon_sym_nointerpolation] = ACTIONS(2292),
    [anon_sym_sample] = ACTIONS(2292),
    [anon_sym_linear] = ACTIONS(2292),
    [anon_sym_snorm] = ACTIONS(2292),
    [anon_sym_unorm] = ACTIONS(2292),
    [anon_sym_point] = ACTIONS(2292),
    [anon_sym_line] = ACTIONS(2292),
    [anon_sym_triangleadj] = ACTIONS(2292),
    [anon_sym_lineadj] = ACTIONS(2292),
    [anon_sym_triangle] = ACTIONS(2292),
  },
  [788] = {
    [ts_builtin_sym_end] = ACTIONS(2354),
    [sym_identifier] = ACTIONS(2352),
    [aux_sym_preproc_include_token1] = ACTIONS(2352),
    [aux_sym_preproc_def_token1] = ACTIONS(2352),
    [aux_sym_preproc_if_token1] = ACTIONS(2352),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2352),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2352),
    [sym_preproc_directive] = ACTIONS(2352),
    [anon_sym_LPAREN2] = ACTIONS(2354),
    [anon_sym_BANG] = ACTIONS(2354),
    [anon_sym_TILDE] = ACTIONS(2354),
    [anon_sym_DASH] = ACTIONS(2352),
    [anon_sym_PLUS] = ACTIONS(2352),
    [anon_sym_STAR] = ACTIONS(2354),
    [anon_sym_AMP_AMP] = ACTIONS(2354),
    [anon_sym_AMP] = ACTIONS(2352),
    [anon_sym___extension__] = ACTIONS(2352),
    [anon_sym_typedef] = ACTIONS(2352),
    [anon_sym_in] = ACTIONS(2352),
    [anon_sym_out] = ACTIONS(2352),
    [anon_sym_inout] = ACTIONS(2352),
    [anon_sym_extern] = ACTIONS(2352),
    [anon_sym___attribute__] = ACTIONS(2352),
    [anon_sym_COLON_COLON] = ACTIONS(2354),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2354),
    [anon_sym___declspec] = ACTIONS(2352),
    [anon_sym___based] = ACTIONS(2352),
    [anon_sym___cdecl] = ACTIONS(2352),
    [anon_sym___clrcall] = ACTIONS(2352),
    [anon_sym___stdcall] = ACTIONS(2352),
    [anon_sym___fastcall] = ACTIONS(2352),
    [anon_sym___thiscall] = ACTIONS(2352),
    [anon_sym___vectorcall] = ACTIONS(2352),
    [anon_sym_LBRACE] = ACTIONS(2354),
    [anon_sym_signed] = ACTIONS(2352),
    [anon_sym_unsigned] = ACTIONS(2352),
    [anon_sym_long] = ACTIONS(2352),
    [anon_sym_short] = ACTIONS(2352),
    [anon_sym_LBRACK] = ACTIONS(2352),
    [anon_sym_static] = ACTIONS(2352),
    [anon_sym_register] = ACTIONS(2352),
    [anon_sym_inline] = ACTIONS(2352),
    [anon_sym___inline] = ACTIONS(2352),
    [anon_sym___inline__] = ACTIONS(2352),
    [anon_sym___forceinline] = ACTIONS(2352),
    [anon_sym_thread_local] = ACTIONS(2352),
    [anon_sym___thread] = ACTIONS(2352),
    [anon_sym_const] = ACTIONS(2352),
    [anon_sym_constexpr] = ACTIONS(2352),
    [anon_sym_volatile] = ACTIONS(2352),
    [anon_sym_restrict] = ACTIONS(2352),
    [anon_sym___restrict__] = ACTIONS(2352),
    [anon_sym__Atomic] = ACTIONS(2352),
    [anon_sym__Noreturn] = ACTIONS(2352),
    [anon_sym_noreturn] = ACTIONS(2352),
    [anon_sym_mutable] = ACTIONS(2352),
    [anon_sym_constinit] = ACTIONS(2352),
    [anon_sym_consteval] = ACTIONS(2352),
    [anon_sym_alignas] = ACTIONS(2352),
    [anon_sym__Alignas] = ACTIONS(2352),
    [sym_primitive_type] = ACTIONS(2352),
    [anon_sym_enum] = ACTIONS(2352),
    [anon_sym_class] = ACTIONS(2352),
    [anon_sym_struct] = ACTIONS(2352),
    [anon_sym_union] = ACTIONS(2352),
    [anon_sym_if] = ACTIONS(2352),
    [anon_sym_switch] = ACTIONS(2352),
    [anon_sym_case] = ACTIONS(2352),
    [anon_sym_default] = ACTIONS(2352),
    [anon_sym_while] = ACTIONS(2352),
    [anon_sym_do] = ACTIONS(2352),
    [anon_sym_for] = ACTIONS(2352),
    [anon_sym_return] = ACTIONS(2352),
    [anon_sym_break] = ACTIONS(2352),
    [anon_sym_continue] = ACTIONS(2352),
    [anon_sym_goto] = ACTIONS(2352),
    [anon_sym_not] = ACTIONS(2352),
    [anon_sym_compl] = ACTIONS(2352),
    [anon_sym_DASH_DASH] = ACTIONS(2354),
    [anon_sym_PLUS_PLUS] = ACTIONS(2354),
    [anon_sym_sizeof] = ACTIONS(2352),
    [anon_sym___alignof__] = ACTIONS(2352),
    [anon_sym___alignof] = ACTIONS(2352),
    [anon_sym__alignof] = ACTIONS(2352),
    [anon_sym_alignof] = ACTIONS(2352),
    [anon_sym__Alignof] = ACTIONS(2352),
    [anon_sym_offsetof] = ACTIONS(2352),
    [anon_sym__Generic] = ACTIONS(2352),
    [anon_sym_asm] = ACTIONS(2352),
    [anon_sym___asm__] = ACTIONS(2352),
    [sym_number_literal] = ACTIONS(2354),
    [anon_sym_L_SQUOTE] = ACTIONS(2354),
    [anon_sym_u_SQUOTE] = ACTIONS(2354),
    [anon_sym_U_SQUOTE] = ACTIONS(2354),
    [anon_sym_u8_SQUOTE] = ACTIONS(2354),
    [anon_sym_SQUOTE] = ACTIONS(2354),
    [anon_sym_L_DQUOTE] = ACTIONS(2354),
    [anon_sym_u_DQUOTE] = ACTIONS(2354),
    [anon_sym_U_DQUOTE] = ACTIONS(2354),
    [anon_sym_u8_DQUOTE] = ACTIONS(2354),
    [anon_sym_DQUOTE] = ACTIONS(2354),
    [sym_true] = ACTIONS(2352),
    [sym_false] = ACTIONS(2352),
    [anon_sym_NULL] = ACTIONS(2352),
    [anon_sym_nullptr] = ACTIONS(2352),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2352),
    [anon_sym_decltype] = ACTIONS(2352),
    [sym_virtual] = ACTIONS(2352),
    [anon_sym_explicit] = ACTIONS(2352),
    [anon_sym_typename] = ACTIONS(2352),
    [anon_sym_template] = ACTIONS(2352),
    [anon_sym_operator] = ACTIONS(2352),
    [anon_sym_try] = ACTIONS(2352),
    [anon_sym_delete] = ACTIONS(2352),
    [anon_sym_throw] = ACTIONS(2352),
    [anon_sym_namespace] = ACTIONS(2352),
    [anon_sym_using] = ACTIONS(2352),
    [anon_sym_static_assert] = ACTIONS(2352),
    [anon_sym_concept] = ACTIONS(2352),
    [anon_sym_co_return] = ACTIONS(2352),
    [anon_sym_co_yield] = ACTIONS(2352),
    [anon_sym_R_DQUOTE] = ACTIONS(2354),
    [anon_sym_LR_DQUOTE] = ACTIONS(2354),
    [anon_sym_uR_DQUOTE] = ACTIONS(2354),
    [anon_sym_UR_DQUOTE] = ACTIONS(2354),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2354),
    [anon_sym_co_await] = ACTIONS(2352),
    [anon_sym_new] = ACTIONS(2352),
    [anon_sym_requires] = ACTIONS(2352),
    [sym_this] = ACTIONS(2352),
    [anon_sym_precise] = ACTIONS(2352),
    [anon_sym_shared] = ACTIONS(2352),
    [anon_sym_groupshared] = ACTIONS(2352),
    [anon_sym_uniform] = ACTIONS(2352),
    [anon_sym_row_major] = ACTIONS(2352),
    [anon_sym_column_major] = ACTIONS(2352),
    [anon_sym_globallycoherent] = ACTIONS(2352),
    [anon_sym_centroid] = ACTIONS(2352),
    [anon_sym_noperspective] = ACTIONS(2352),
    [anon_sym_nointerpolation] = ACTIONS(2352),
    [anon_sym_sample] = ACTIONS(2352),
    [anon_sym_linear] = ACTIONS(2352),
    [anon_sym_snorm] = ACTIONS(2352),
    [anon_sym_unorm] = ACTIONS(2352),
    [anon_sym_point] = ACTIONS(2352),
    [anon_sym_line] = ACTIONS(2352),
    [anon_sym_triangleadj] = ACTIONS(2352),
    [anon_sym_lineadj] = ACTIONS(2352),
    [anon_sym_triangle] = ACTIONS(2352),
  },
  [789] = {
    [ts_builtin_sym_end] = ACTIONS(2406),
    [sym_identifier] = ACTIONS(2404),
    [aux_sym_preproc_include_token1] = ACTIONS(2404),
    [aux_sym_preproc_def_token1] = ACTIONS(2404),
    [aux_sym_preproc_if_token1] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2404),
    [sym_preproc_directive] = ACTIONS(2404),
    [anon_sym_LPAREN2] = ACTIONS(2406),
    [anon_sym_BANG] = ACTIONS(2406),
    [anon_sym_TILDE] = ACTIONS(2406),
    [anon_sym_DASH] = ACTIONS(2404),
    [anon_sym_PLUS] = ACTIONS(2404),
    [anon_sym_STAR] = ACTIONS(2406),
    [anon_sym_AMP_AMP] = ACTIONS(2406),
    [anon_sym_AMP] = ACTIONS(2404),
    [anon_sym___extension__] = ACTIONS(2404),
    [anon_sym_typedef] = ACTIONS(2404),
    [anon_sym_in] = ACTIONS(2404),
    [anon_sym_out] = ACTIONS(2404),
    [anon_sym_inout] = ACTIONS(2404),
    [anon_sym_extern] = ACTIONS(2404),
    [anon_sym___attribute__] = ACTIONS(2404),
    [anon_sym_COLON_COLON] = ACTIONS(2406),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2406),
    [anon_sym___declspec] = ACTIONS(2404),
    [anon_sym___based] = ACTIONS(2404),
    [anon_sym___cdecl] = ACTIONS(2404),
    [anon_sym___clrcall] = ACTIONS(2404),
    [anon_sym___stdcall] = ACTIONS(2404),
    [anon_sym___fastcall] = ACTIONS(2404),
    [anon_sym___thiscall] = ACTIONS(2404),
    [anon_sym___vectorcall] = ACTIONS(2404),
    [anon_sym_LBRACE] = ACTIONS(2406),
    [anon_sym_signed] = ACTIONS(2404),
    [anon_sym_unsigned] = ACTIONS(2404),
    [anon_sym_long] = ACTIONS(2404),
    [anon_sym_short] = ACTIONS(2404),
    [anon_sym_LBRACK] = ACTIONS(2404),
    [anon_sym_static] = ACTIONS(2404),
    [anon_sym_register] = ACTIONS(2404),
    [anon_sym_inline] = ACTIONS(2404),
    [anon_sym___inline] = ACTIONS(2404),
    [anon_sym___inline__] = ACTIONS(2404),
    [anon_sym___forceinline] = ACTIONS(2404),
    [anon_sym_thread_local] = ACTIONS(2404),
    [anon_sym___thread] = ACTIONS(2404),
    [anon_sym_const] = ACTIONS(2404),
    [anon_sym_constexpr] = ACTIONS(2404),
    [anon_sym_volatile] = ACTIONS(2404),
    [anon_sym_restrict] = ACTIONS(2404),
    [anon_sym___restrict__] = ACTIONS(2404),
    [anon_sym__Atomic] = ACTIONS(2404),
    [anon_sym__Noreturn] = ACTIONS(2404),
    [anon_sym_noreturn] = ACTIONS(2404),
    [anon_sym_mutable] = ACTIONS(2404),
    [anon_sym_constinit] = ACTIONS(2404),
    [anon_sym_consteval] = ACTIONS(2404),
    [anon_sym_alignas] = ACTIONS(2404),
    [anon_sym__Alignas] = ACTIONS(2404),
    [sym_primitive_type] = ACTIONS(2404),
    [anon_sym_enum] = ACTIONS(2404),
    [anon_sym_class] = ACTIONS(2404),
    [anon_sym_struct] = ACTIONS(2404),
    [anon_sym_union] = ACTIONS(2404),
    [anon_sym_if] = ACTIONS(2404),
    [anon_sym_switch] = ACTIONS(2404),
    [anon_sym_case] = ACTIONS(2404),
    [anon_sym_default] = ACTIONS(2404),
    [anon_sym_while] = ACTIONS(2404),
    [anon_sym_do] = ACTIONS(2404),
    [anon_sym_for] = ACTIONS(2404),
    [anon_sym_return] = ACTIONS(2404),
    [anon_sym_break] = ACTIONS(2404),
    [anon_sym_continue] = ACTIONS(2404),
    [anon_sym_goto] = ACTIONS(2404),
    [anon_sym_not] = ACTIONS(2404),
    [anon_sym_compl] = ACTIONS(2404),
    [anon_sym_DASH_DASH] = ACTIONS(2406),
    [anon_sym_PLUS_PLUS] = ACTIONS(2406),
    [anon_sym_sizeof] = ACTIONS(2404),
    [anon_sym___alignof__] = ACTIONS(2404),
    [anon_sym___alignof] = ACTIONS(2404),
    [anon_sym__alignof] = ACTIONS(2404),
    [anon_sym_alignof] = ACTIONS(2404),
    [anon_sym__Alignof] = ACTIONS(2404),
    [anon_sym_offsetof] = ACTIONS(2404),
    [anon_sym__Generic] = ACTIONS(2404),
    [anon_sym_asm] = ACTIONS(2404),
    [anon_sym___asm__] = ACTIONS(2404),
    [sym_number_literal] = ACTIONS(2406),
    [anon_sym_L_SQUOTE] = ACTIONS(2406),
    [anon_sym_u_SQUOTE] = ACTIONS(2406),
    [anon_sym_U_SQUOTE] = ACTIONS(2406),
    [anon_sym_u8_SQUOTE] = ACTIONS(2406),
    [anon_sym_SQUOTE] = ACTIONS(2406),
    [anon_sym_L_DQUOTE] = ACTIONS(2406),
    [anon_sym_u_DQUOTE] = ACTIONS(2406),
    [anon_sym_U_DQUOTE] = ACTIONS(2406),
    [anon_sym_u8_DQUOTE] = ACTIONS(2406),
    [anon_sym_DQUOTE] = ACTIONS(2406),
    [sym_true] = ACTIONS(2404),
    [sym_false] = ACTIONS(2404),
    [anon_sym_NULL] = ACTIONS(2404),
    [anon_sym_nullptr] = ACTIONS(2404),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2404),
    [anon_sym_decltype] = ACTIONS(2404),
    [sym_virtual] = ACTIONS(2404),
    [anon_sym_explicit] = ACTIONS(2404),
    [anon_sym_typename] = ACTIONS(2404),
    [anon_sym_template] = ACTIONS(2404),
    [anon_sym_operator] = ACTIONS(2404),
    [anon_sym_try] = ACTIONS(2404),
    [anon_sym_delete] = ACTIONS(2404),
    [anon_sym_throw] = ACTIONS(2404),
    [anon_sym_namespace] = ACTIONS(2404),
    [anon_sym_using] = ACTIONS(2404),
    [anon_sym_static_assert] = ACTIONS(2404),
    [anon_sym_concept] = ACTIONS(2404),
    [anon_sym_co_return] = ACTIONS(2404),
    [anon_sym_co_yield] = ACTIONS(2404),
    [anon_sym_R_DQUOTE] = ACTIONS(2406),
    [anon_sym_LR_DQUOTE] = ACTIONS(2406),
    [anon_sym_uR_DQUOTE] = ACTIONS(2406),
    [anon_sym_UR_DQUOTE] = ACTIONS(2406),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2406),
    [anon_sym_co_await] = ACTIONS(2404),
    [anon_sym_new] = ACTIONS(2404),
    [anon_sym_requires] = ACTIONS(2404),
    [sym_this] = ACTIONS(2404),
    [anon_sym_precise] = ACTIONS(2404),
    [anon_sym_shared] = ACTIONS(2404),
    [anon_sym_groupshared] = ACTIONS(2404),
    [anon_sym_uniform] = ACTIONS(2404),
    [anon_sym_row_major] = ACTIONS(2404),
    [anon_sym_column_major] = ACTIONS(2404),
    [anon_sym_globallycoherent] = ACTIONS(2404),
    [anon_sym_centroid] = ACTIONS(2404),
    [anon_sym_noperspective] = ACTIONS(2404),
    [anon_sym_nointerpolation] = ACTIONS(2404),
    [anon_sym_sample] = ACTIONS(2404),
    [anon_sym_linear] = ACTIONS(2404),
    [anon_sym_snorm] = ACTIONS(2404),
    [anon_sym_unorm] = ACTIONS(2404),
    [anon_sym_point] = ACTIONS(2404),
    [anon_sym_line] = ACTIONS(2404),
    [anon_sym_triangleadj] = ACTIONS(2404),
    [anon_sym_lineadj] = ACTIONS(2404),
    [anon_sym_triangle] = ACTIONS(2404),
  },
  [790] = {
    [ts_builtin_sym_end] = ACTIONS(2559),
    [sym_identifier] = ACTIONS(2557),
    [aux_sym_preproc_include_token1] = ACTIONS(2557),
    [aux_sym_preproc_def_token1] = ACTIONS(2557),
    [aux_sym_preproc_if_token1] = ACTIONS(2557),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2557),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2557),
    [sym_preproc_directive] = ACTIONS(2557),
    [anon_sym_LPAREN2] = ACTIONS(2559),
    [anon_sym_BANG] = ACTIONS(2559),
    [anon_sym_TILDE] = ACTIONS(2559),
    [anon_sym_DASH] = ACTIONS(2557),
    [anon_sym_PLUS] = ACTIONS(2557),
    [anon_sym_STAR] = ACTIONS(2559),
    [anon_sym_AMP_AMP] = ACTIONS(2559),
    [anon_sym_AMP] = ACTIONS(2557),
    [anon_sym___extension__] = ACTIONS(2557),
    [anon_sym_typedef] = ACTIONS(2557),
    [anon_sym_in] = ACTIONS(2557),
    [anon_sym_out] = ACTIONS(2557),
    [anon_sym_inout] = ACTIONS(2557),
    [anon_sym_extern] = ACTIONS(2557),
    [anon_sym___attribute__] = ACTIONS(2557),
    [anon_sym_COLON_COLON] = ACTIONS(2559),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2559),
    [anon_sym___declspec] = ACTIONS(2557),
    [anon_sym___based] = ACTIONS(2557),
    [anon_sym___cdecl] = ACTIONS(2557),
    [anon_sym___clrcall] = ACTIONS(2557),
    [anon_sym___stdcall] = ACTIONS(2557),
    [anon_sym___fastcall] = ACTIONS(2557),
    [anon_sym___thiscall] = ACTIONS(2557),
    [anon_sym___vectorcall] = ACTIONS(2557),
    [anon_sym_LBRACE] = ACTIONS(2559),
    [anon_sym_signed] = ACTIONS(2557),
    [anon_sym_unsigned] = ACTIONS(2557),
    [anon_sym_long] = ACTIONS(2557),
    [anon_sym_short] = ACTIONS(2557),
    [anon_sym_LBRACK] = ACTIONS(2557),
    [anon_sym_static] = ACTIONS(2557),
    [anon_sym_register] = ACTIONS(2557),
    [anon_sym_inline] = ACTIONS(2557),
    [anon_sym___inline] = ACTIONS(2557),
    [anon_sym___inline__] = ACTIONS(2557),
    [anon_sym___forceinline] = ACTIONS(2557),
    [anon_sym_thread_local] = ACTIONS(2557),
    [anon_sym___thread] = ACTIONS(2557),
    [anon_sym_const] = ACTIONS(2557),
    [anon_sym_constexpr] = ACTIONS(2557),
    [anon_sym_volatile] = ACTIONS(2557),
    [anon_sym_restrict] = ACTIONS(2557),
    [anon_sym___restrict__] = ACTIONS(2557),
    [anon_sym__Atomic] = ACTIONS(2557),
    [anon_sym__Noreturn] = ACTIONS(2557),
    [anon_sym_noreturn] = ACTIONS(2557),
    [anon_sym_mutable] = ACTIONS(2557),
    [anon_sym_constinit] = ACTIONS(2557),
    [anon_sym_consteval] = ACTIONS(2557),
    [anon_sym_alignas] = ACTIONS(2557),
    [anon_sym__Alignas] = ACTIONS(2557),
    [sym_primitive_type] = ACTIONS(2557),
    [anon_sym_enum] = ACTIONS(2557),
    [anon_sym_class] = ACTIONS(2557),
    [anon_sym_struct] = ACTIONS(2557),
    [anon_sym_union] = ACTIONS(2557),
    [anon_sym_if] = ACTIONS(2557),
    [anon_sym_switch] = ACTIONS(2557),
    [anon_sym_case] = ACTIONS(2557),
    [anon_sym_default] = ACTIONS(2557),
    [anon_sym_while] = ACTIONS(2557),
    [anon_sym_do] = ACTIONS(2557),
    [anon_sym_for] = ACTIONS(2557),
    [anon_sym_return] = ACTIONS(2557),
    [anon_sym_break] = ACTIONS(2557),
    [anon_sym_continue] = ACTIONS(2557),
    [anon_sym_goto] = ACTIONS(2557),
    [anon_sym_not] = ACTIONS(2557),
    [anon_sym_compl] = ACTIONS(2557),
    [anon_sym_DASH_DASH] = ACTIONS(2559),
    [anon_sym_PLUS_PLUS] = ACTIONS(2559),
    [anon_sym_sizeof] = ACTIONS(2557),
    [anon_sym___alignof__] = ACTIONS(2557),
    [anon_sym___alignof] = ACTIONS(2557),
    [anon_sym__alignof] = ACTIONS(2557),
    [anon_sym_alignof] = ACTIONS(2557),
    [anon_sym__Alignof] = ACTIONS(2557),
    [anon_sym_offsetof] = ACTIONS(2557),
    [anon_sym__Generic] = ACTIONS(2557),
    [anon_sym_asm] = ACTIONS(2557),
    [anon_sym___asm__] = ACTIONS(2557),
    [sym_number_literal] = ACTIONS(2559),
    [anon_sym_L_SQUOTE] = ACTIONS(2559),
    [anon_sym_u_SQUOTE] = ACTIONS(2559),
    [anon_sym_U_SQUOTE] = ACTIONS(2559),
    [anon_sym_u8_SQUOTE] = ACTIONS(2559),
    [anon_sym_SQUOTE] = ACTIONS(2559),
    [anon_sym_L_DQUOTE] = ACTIONS(2559),
    [anon_sym_u_DQUOTE] = ACTIONS(2559),
    [anon_sym_U_DQUOTE] = ACTIONS(2559),
    [anon_sym_u8_DQUOTE] = ACTIONS(2559),
    [anon_sym_DQUOTE] = ACTIONS(2559),
    [sym_true] = ACTIONS(2557),
    [sym_false] = ACTIONS(2557),
    [anon_sym_NULL] = ACTIONS(2557),
    [anon_sym_nullptr] = ACTIONS(2557),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2557),
    [anon_sym_decltype] = ACTIONS(2557),
    [sym_virtual] = ACTIONS(2557),
    [anon_sym_explicit] = ACTIONS(2557),
    [anon_sym_typename] = ACTIONS(2557),
    [anon_sym_template] = ACTIONS(2557),
    [anon_sym_operator] = ACTIONS(2557),
    [anon_sym_try] = ACTIONS(2557),
    [anon_sym_delete] = ACTIONS(2557),
    [anon_sym_throw] = ACTIONS(2557),
    [anon_sym_namespace] = ACTIONS(2557),
    [anon_sym_using] = ACTIONS(2557),
    [anon_sym_static_assert] = ACTIONS(2557),
    [anon_sym_concept] = ACTIONS(2557),
    [anon_sym_co_return] = ACTIONS(2557),
    [anon_sym_co_yield] = ACTIONS(2557),
    [anon_sym_R_DQUOTE] = ACTIONS(2559),
    [anon_sym_LR_DQUOTE] = ACTIONS(2559),
    [anon_sym_uR_DQUOTE] = ACTIONS(2559),
    [anon_sym_UR_DQUOTE] = ACTIONS(2559),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2559),
    [anon_sym_co_await] = ACTIONS(2557),
    [anon_sym_new] = ACTIONS(2557),
    [anon_sym_requires] = ACTIONS(2557),
    [sym_this] = ACTIONS(2557),
    [anon_sym_precise] = ACTIONS(2557),
    [anon_sym_shared] = ACTIONS(2557),
    [anon_sym_groupshared] = ACTIONS(2557),
    [anon_sym_uniform] = ACTIONS(2557),
    [anon_sym_row_major] = ACTIONS(2557),
    [anon_sym_column_major] = ACTIONS(2557),
    [anon_sym_globallycoherent] = ACTIONS(2557),
    [anon_sym_centroid] = ACTIONS(2557),
    [anon_sym_noperspective] = ACTIONS(2557),
    [anon_sym_nointerpolation] = ACTIONS(2557),
    [anon_sym_sample] = ACTIONS(2557),
    [anon_sym_linear] = ACTIONS(2557),
    [anon_sym_snorm] = ACTIONS(2557),
    [anon_sym_unorm] = ACTIONS(2557),
    [anon_sym_point] = ACTIONS(2557),
    [anon_sym_line] = ACTIONS(2557),
    [anon_sym_triangleadj] = ACTIONS(2557),
    [anon_sym_lineadj] = ACTIONS(2557),
    [anon_sym_triangle] = ACTIONS(2557),
  },
  [791] = {
    [ts_builtin_sym_end] = ACTIONS(2414),
    [sym_identifier] = ACTIONS(2412),
    [aux_sym_preproc_include_token1] = ACTIONS(2412),
    [aux_sym_preproc_def_token1] = ACTIONS(2412),
    [aux_sym_preproc_if_token1] = ACTIONS(2412),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2412),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2412),
    [sym_preproc_directive] = ACTIONS(2412),
    [anon_sym_LPAREN2] = ACTIONS(2414),
    [anon_sym_BANG] = ACTIONS(2414),
    [anon_sym_TILDE] = ACTIONS(2414),
    [anon_sym_DASH] = ACTIONS(2412),
    [anon_sym_PLUS] = ACTIONS(2412),
    [anon_sym_STAR] = ACTIONS(2414),
    [anon_sym_AMP_AMP] = ACTIONS(2414),
    [anon_sym_AMP] = ACTIONS(2412),
    [anon_sym___extension__] = ACTIONS(2412),
    [anon_sym_typedef] = ACTIONS(2412),
    [anon_sym_in] = ACTIONS(2412),
    [anon_sym_out] = ACTIONS(2412),
    [anon_sym_inout] = ACTIONS(2412),
    [anon_sym_extern] = ACTIONS(2412),
    [anon_sym___attribute__] = ACTIONS(2412),
    [anon_sym_COLON_COLON] = ACTIONS(2414),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2414),
    [anon_sym___declspec] = ACTIONS(2412),
    [anon_sym___based] = ACTIONS(2412),
    [anon_sym___cdecl] = ACTIONS(2412),
    [anon_sym___clrcall] = ACTIONS(2412),
    [anon_sym___stdcall] = ACTIONS(2412),
    [anon_sym___fastcall] = ACTIONS(2412),
    [anon_sym___thiscall] = ACTIONS(2412),
    [anon_sym___vectorcall] = ACTIONS(2412),
    [anon_sym_LBRACE] = ACTIONS(2414),
    [anon_sym_signed] = ACTIONS(2412),
    [anon_sym_unsigned] = ACTIONS(2412),
    [anon_sym_long] = ACTIONS(2412),
    [anon_sym_short] = ACTIONS(2412),
    [anon_sym_LBRACK] = ACTIONS(2412),
    [anon_sym_static] = ACTIONS(2412),
    [anon_sym_register] = ACTIONS(2412),
    [anon_sym_inline] = ACTIONS(2412),
    [anon_sym___inline] = ACTIONS(2412),
    [anon_sym___inline__] = ACTIONS(2412),
    [anon_sym___forceinline] = ACTIONS(2412),
    [anon_sym_thread_local] = ACTIONS(2412),
    [anon_sym___thread] = ACTIONS(2412),
    [anon_sym_const] = ACTIONS(2412),
    [anon_sym_constexpr] = ACTIONS(2412),
    [anon_sym_volatile] = ACTIONS(2412),
    [anon_sym_restrict] = ACTIONS(2412),
    [anon_sym___restrict__] = ACTIONS(2412),
    [anon_sym__Atomic] = ACTIONS(2412),
    [anon_sym__Noreturn] = ACTIONS(2412),
    [anon_sym_noreturn] = ACTIONS(2412),
    [anon_sym_mutable] = ACTIONS(2412),
    [anon_sym_constinit] = ACTIONS(2412),
    [anon_sym_consteval] = ACTIONS(2412),
    [anon_sym_alignas] = ACTIONS(2412),
    [anon_sym__Alignas] = ACTIONS(2412),
    [sym_primitive_type] = ACTIONS(2412),
    [anon_sym_enum] = ACTIONS(2412),
    [anon_sym_class] = ACTIONS(2412),
    [anon_sym_struct] = ACTIONS(2412),
    [anon_sym_union] = ACTIONS(2412),
    [anon_sym_if] = ACTIONS(2412),
    [anon_sym_switch] = ACTIONS(2412),
    [anon_sym_case] = ACTIONS(2412),
    [anon_sym_default] = ACTIONS(2412),
    [anon_sym_while] = ACTIONS(2412),
    [anon_sym_do] = ACTIONS(2412),
    [anon_sym_for] = ACTIONS(2412),
    [anon_sym_return] = ACTIONS(2412),
    [anon_sym_break] = ACTIONS(2412),
    [anon_sym_continue] = ACTIONS(2412),
    [anon_sym_goto] = ACTIONS(2412),
    [anon_sym_not] = ACTIONS(2412),
    [anon_sym_compl] = ACTIONS(2412),
    [anon_sym_DASH_DASH] = ACTIONS(2414),
    [anon_sym_PLUS_PLUS] = ACTIONS(2414),
    [anon_sym_sizeof] = ACTIONS(2412),
    [anon_sym___alignof__] = ACTIONS(2412),
    [anon_sym___alignof] = ACTIONS(2412),
    [anon_sym__alignof] = ACTIONS(2412),
    [anon_sym_alignof] = ACTIONS(2412),
    [anon_sym__Alignof] = ACTIONS(2412),
    [anon_sym_offsetof] = ACTIONS(2412),
    [anon_sym__Generic] = ACTIONS(2412),
    [anon_sym_asm] = ACTIONS(2412),
    [anon_sym___asm__] = ACTIONS(2412),
    [sym_number_literal] = ACTIONS(2414),
    [anon_sym_L_SQUOTE] = ACTIONS(2414),
    [anon_sym_u_SQUOTE] = ACTIONS(2414),
    [anon_sym_U_SQUOTE] = ACTIONS(2414),
    [anon_sym_u8_SQUOTE] = ACTIONS(2414),
    [anon_sym_SQUOTE] = ACTIONS(2414),
    [anon_sym_L_DQUOTE] = ACTIONS(2414),
    [anon_sym_u_DQUOTE] = ACTIONS(2414),
    [anon_sym_U_DQUOTE] = ACTIONS(2414),
    [anon_sym_u8_DQUOTE] = ACTIONS(2414),
    [anon_sym_DQUOTE] = ACTIONS(2414),
    [sym_true] = ACTIONS(2412),
    [sym_false] = ACTIONS(2412),
    [anon_sym_NULL] = ACTIONS(2412),
    [anon_sym_nullptr] = ACTIONS(2412),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2412),
    [anon_sym_decltype] = ACTIONS(2412),
    [sym_virtual] = ACTIONS(2412),
    [anon_sym_explicit] = ACTIONS(2412),
    [anon_sym_typename] = ACTIONS(2412),
    [anon_sym_template] = ACTIONS(2412),
    [anon_sym_operator] = ACTIONS(2412),
    [anon_sym_try] = ACTIONS(2412),
    [anon_sym_delete] = ACTIONS(2412),
    [anon_sym_throw] = ACTIONS(2412),
    [anon_sym_namespace] = ACTIONS(2412),
    [anon_sym_using] = ACTIONS(2412),
    [anon_sym_static_assert] = ACTIONS(2412),
    [anon_sym_concept] = ACTIONS(2412),
    [anon_sym_co_return] = ACTIONS(2412),
    [anon_sym_co_yield] = ACTIONS(2412),
    [anon_sym_R_DQUOTE] = ACTIONS(2414),
    [anon_sym_LR_DQUOTE] = ACTIONS(2414),
    [anon_sym_uR_DQUOTE] = ACTIONS(2414),
    [anon_sym_UR_DQUOTE] = ACTIONS(2414),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2414),
    [anon_sym_co_await] = ACTIONS(2412),
    [anon_sym_new] = ACTIONS(2412),
    [anon_sym_requires] = ACTIONS(2412),
    [sym_this] = ACTIONS(2412),
    [anon_sym_precise] = ACTIONS(2412),
    [anon_sym_shared] = ACTIONS(2412),
    [anon_sym_groupshared] = ACTIONS(2412),
    [anon_sym_uniform] = ACTIONS(2412),
    [anon_sym_row_major] = ACTIONS(2412),
    [anon_sym_column_major] = ACTIONS(2412),
    [anon_sym_globallycoherent] = ACTIONS(2412),
    [anon_sym_centroid] = ACTIONS(2412),
    [anon_sym_noperspective] = ACTIONS(2412),
    [anon_sym_nointerpolation] = ACTIONS(2412),
    [anon_sym_sample] = ACTIONS(2412),
    [anon_sym_linear] = ACTIONS(2412),
    [anon_sym_snorm] = ACTIONS(2412),
    [anon_sym_unorm] = ACTIONS(2412),
    [anon_sym_point] = ACTIONS(2412),
    [anon_sym_line] = ACTIONS(2412),
    [anon_sym_triangleadj] = ACTIONS(2412),
    [anon_sym_lineadj] = ACTIONS(2412),
    [anon_sym_triangle] = ACTIONS(2412),
  },
  [792] = {
    [ts_builtin_sym_end] = ACTIONS(2488),
    [sym_identifier] = ACTIONS(2486),
    [aux_sym_preproc_include_token1] = ACTIONS(2486),
    [aux_sym_preproc_def_token1] = ACTIONS(2486),
    [aux_sym_preproc_if_token1] = ACTIONS(2486),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2486),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2486),
    [sym_preproc_directive] = ACTIONS(2486),
    [anon_sym_LPAREN2] = ACTIONS(2488),
    [anon_sym_BANG] = ACTIONS(2488),
    [anon_sym_TILDE] = ACTIONS(2488),
    [anon_sym_DASH] = ACTIONS(2486),
    [anon_sym_PLUS] = ACTIONS(2486),
    [anon_sym_STAR] = ACTIONS(2488),
    [anon_sym_AMP_AMP] = ACTIONS(2488),
    [anon_sym_AMP] = ACTIONS(2486),
    [anon_sym___extension__] = ACTIONS(2486),
    [anon_sym_typedef] = ACTIONS(2486),
    [anon_sym_in] = ACTIONS(2486),
    [anon_sym_out] = ACTIONS(2486),
    [anon_sym_inout] = ACTIONS(2486),
    [anon_sym_extern] = ACTIONS(2486),
    [anon_sym___attribute__] = ACTIONS(2486),
    [anon_sym_COLON_COLON] = ACTIONS(2488),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2488),
    [anon_sym___declspec] = ACTIONS(2486),
    [anon_sym___based] = ACTIONS(2486),
    [anon_sym___cdecl] = ACTIONS(2486),
    [anon_sym___clrcall] = ACTIONS(2486),
    [anon_sym___stdcall] = ACTIONS(2486),
    [anon_sym___fastcall] = ACTIONS(2486),
    [anon_sym___thiscall] = ACTIONS(2486),
    [anon_sym___vectorcall] = ACTIONS(2486),
    [anon_sym_LBRACE] = ACTIONS(2488),
    [anon_sym_signed] = ACTIONS(2486),
    [anon_sym_unsigned] = ACTIONS(2486),
    [anon_sym_long] = ACTIONS(2486),
    [anon_sym_short] = ACTIONS(2486),
    [anon_sym_LBRACK] = ACTIONS(2486),
    [anon_sym_static] = ACTIONS(2486),
    [anon_sym_register] = ACTIONS(2486),
    [anon_sym_inline] = ACTIONS(2486),
    [anon_sym___inline] = ACTIONS(2486),
    [anon_sym___inline__] = ACTIONS(2486),
    [anon_sym___forceinline] = ACTIONS(2486),
    [anon_sym_thread_local] = ACTIONS(2486),
    [anon_sym___thread] = ACTIONS(2486),
    [anon_sym_const] = ACTIONS(2486),
    [anon_sym_constexpr] = ACTIONS(2486),
    [anon_sym_volatile] = ACTIONS(2486),
    [anon_sym_restrict] = ACTIONS(2486),
    [anon_sym___restrict__] = ACTIONS(2486),
    [anon_sym__Atomic] = ACTIONS(2486),
    [anon_sym__Noreturn] = ACTIONS(2486),
    [anon_sym_noreturn] = ACTIONS(2486),
    [anon_sym_mutable] = ACTIONS(2486),
    [anon_sym_constinit] = ACTIONS(2486),
    [anon_sym_consteval] = ACTIONS(2486),
    [anon_sym_alignas] = ACTIONS(2486),
    [anon_sym__Alignas] = ACTIONS(2486),
    [sym_primitive_type] = ACTIONS(2486),
    [anon_sym_enum] = ACTIONS(2486),
    [anon_sym_class] = ACTIONS(2486),
    [anon_sym_struct] = ACTIONS(2486),
    [anon_sym_union] = ACTIONS(2486),
    [anon_sym_if] = ACTIONS(2486),
    [anon_sym_switch] = ACTIONS(2486),
    [anon_sym_case] = ACTIONS(2486),
    [anon_sym_default] = ACTIONS(2486),
    [anon_sym_while] = ACTIONS(2486),
    [anon_sym_do] = ACTIONS(2486),
    [anon_sym_for] = ACTIONS(2486),
    [anon_sym_return] = ACTIONS(2486),
    [anon_sym_break] = ACTIONS(2486),
    [anon_sym_continue] = ACTIONS(2486),
    [anon_sym_goto] = ACTIONS(2486),
    [anon_sym_not] = ACTIONS(2486),
    [anon_sym_compl] = ACTIONS(2486),
    [anon_sym_DASH_DASH] = ACTIONS(2488),
    [anon_sym_PLUS_PLUS] = ACTIONS(2488),
    [anon_sym_sizeof] = ACTIONS(2486),
    [anon_sym___alignof__] = ACTIONS(2486),
    [anon_sym___alignof] = ACTIONS(2486),
    [anon_sym__alignof] = ACTIONS(2486),
    [anon_sym_alignof] = ACTIONS(2486),
    [anon_sym__Alignof] = ACTIONS(2486),
    [anon_sym_offsetof] = ACTIONS(2486),
    [anon_sym__Generic] = ACTIONS(2486),
    [anon_sym_asm] = ACTIONS(2486),
    [anon_sym___asm__] = ACTIONS(2486),
    [sym_number_literal] = ACTIONS(2488),
    [anon_sym_L_SQUOTE] = ACTIONS(2488),
    [anon_sym_u_SQUOTE] = ACTIONS(2488),
    [anon_sym_U_SQUOTE] = ACTIONS(2488),
    [anon_sym_u8_SQUOTE] = ACTIONS(2488),
    [anon_sym_SQUOTE] = ACTIONS(2488),
    [anon_sym_L_DQUOTE] = ACTIONS(2488),
    [anon_sym_u_DQUOTE] = ACTIONS(2488),
    [anon_sym_U_DQUOTE] = ACTIONS(2488),
    [anon_sym_u8_DQUOTE] = ACTIONS(2488),
    [anon_sym_DQUOTE] = ACTIONS(2488),
    [sym_true] = ACTIONS(2486),
    [sym_false] = ACTIONS(2486),
    [anon_sym_NULL] = ACTIONS(2486),
    [anon_sym_nullptr] = ACTIONS(2486),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2486),
    [anon_sym_decltype] = ACTIONS(2486),
    [sym_virtual] = ACTIONS(2486),
    [anon_sym_explicit] = ACTIONS(2486),
    [anon_sym_typename] = ACTIONS(2486),
    [anon_sym_template] = ACTIONS(2486),
    [anon_sym_operator] = ACTIONS(2486),
    [anon_sym_try] = ACTIONS(2486),
    [anon_sym_delete] = ACTIONS(2486),
    [anon_sym_throw] = ACTIONS(2486),
    [anon_sym_namespace] = ACTIONS(2486),
    [anon_sym_using] = ACTIONS(2486),
    [anon_sym_static_assert] = ACTIONS(2486),
    [anon_sym_concept] = ACTIONS(2486),
    [anon_sym_co_return] = ACTIONS(2486),
    [anon_sym_co_yield] = ACTIONS(2486),
    [anon_sym_R_DQUOTE] = ACTIONS(2488),
    [anon_sym_LR_DQUOTE] = ACTIONS(2488),
    [anon_sym_uR_DQUOTE] = ACTIONS(2488),
    [anon_sym_UR_DQUOTE] = ACTIONS(2488),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2488),
    [anon_sym_co_await] = ACTIONS(2486),
    [anon_sym_new] = ACTIONS(2486),
    [anon_sym_requires] = ACTIONS(2486),
    [sym_this] = ACTIONS(2486),
    [anon_sym_precise] = ACTIONS(2486),
    [anon_sym_shared] = ACTIONS(2486),
    [anon_sym_groupshared] = ACTIONS(2486),
    [anon_sym_uniform] = ACTIONS(2486),
    [anon_sym_row_major] = ACTIONS(2486),
    [anon_sym_column_major] = ACTIONS(2486),
    [anon_sym_globallycoherent] = ACTIONS(2486),
    [anon_sym_centroid] = ACTIONS(2486),
    [anon_sym_noperspective] = ACTIONS(2486),
    [anon_sym_nointerpolation] = ACTIONS(2486),
    [anon_sym_sample] = ACTIONS(2486),
    [anon_sym_linear] = ACTIONS(2486),
    [anon_sym_snorm] = ACTIONS(2486),
    [anon_sym_unorm] = ACTIONS(2486),
    [anon_sym_point] = ACTIONS(2486),
    [anon_sym_line] = ACTIONS(2486),
    [anon_sym_triangleadj] = ACTIONS(2486),
    [anon_sym_lineadj] = ACTIONS(2486),
    [anon_sym_triangle] = ACTIONS(2486),
  },
  [793] = {
    [ts_builtin_sym_end] = ACTIONS(2406),
    [sym_identifier] = ACTIONS(2404),
    [aux_sym_preproc_include_token1] = ACTIONS(2404),
    [aux_sym_preproc_def_token1] = ACTIONS(2404),
    [aux_sym_preproc_if_token1] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2404),
    [sym_preproc_directive] = ACTIONS(2404),
    [anon_sym_LPAREN2] = ACTIONS(2406),
    [anon_sym_BANG] = ACTIONS(2406),
    [anon_sym_TILDE] = ACTIONS(2406),
    [anon_sym_DASH] = ACTIONS(2404),
    [anon_sym_PLUS] = ACTIONS(2404),
    [anon_sym_STAR] = ACTIONS(2406),
    [anon_sym_AMP_AMP] = ACTIONS(2406),
    [anon_sym_AMP] = ACTIONS(2404),
    [anon_sym___extension__] = ACTIONS(2404),
    [anon_sym_typedef] = ACTIONS(2404),
    [anon_sym_in] = ACTIONS(2404),
    [anon_sym_out] = ACTIONS(2404),
    [anon_sym_inout] = ACTIONS(2404),
    [anon_sym_extern] = ACTIONS(2404),
    [anon_sym___attribute__] = ACTIONS(2404),
    [anon_sym_COLON_COLON] = ACTIONS(2406),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2406),
    [anon_sym___declspec] = ACTIONS(2404),
    [anon_sym___based] = ACTIONS(2404),
    [anon_sym___cdecl] = ACTIONS(2404),
    [anon_sym___clrcall] = ACTIONS(2404),
    [anon_sym___stdcall] = ACTIONS(2404),
    [anon_sym___fastcall] = ACTIONS(2404),
    [anon_sym___thiscall] = ACTIONS(2404),
    [anon_sym___vectorcall] = ACTIONS(2404),
    [anon_sym_LBRACE] = ACTIONS(2406),
    [anon_sym_signed] = ACTIONS(2404),
    [anon_sym_unsigned] = ACTIONS(2404),
    [anon_sym_long] = ACTIONS(2404),
    [anon_sym_short] = ACTIONS(2404),
    [anon_sym_LBRACK] = ACTIONS(2404),
    [anon_sym_static] = ACTIONS(2404),
    [anon_sym_register] = ACTIONS(2404),
    [anon_sym_inline] = ACTIONS(2404),
    [anon_sym___inline] = ACTIONS(2404),
    [anon_sym___inline__] = ACTIONS(2404),
    [anon_sym___forceinline] = ACTIONS(2404),
    [anon_sym_thread_local] = ACTIONS(2404),
    [anon_sym___thread] = ACTIONS(2404),
    [anon_sym_const] = ACTIONS(2404),
    [anon_sym_constexpr] = ACTIONS(2404),
    [anon_sym_volatile] = ACTIONS(2404),
    [anon_sym_restrict] = ACTIONS(2404),
    [anon_sym___restrict__] = ACTIONS(2404),
    [anon_sym__Atomic] = ACTIONS(2404),
    [anon_sym__Noreturn] = ACTIONS(2404),
    [anon_sym_noreturn] = ACTIONS(2404),
    [anon_sym_mutable] = ACTIONS(2404),
    [anon_sym_constinit] = ACTIONS(2404),
    [anon_sym_consteval] = ACTIONS(2404),
    [anon_sym_alignas] = ACTIONS(2404),
    [anon_sym__Alignas] = ACTIONS(2404),
    [sym_primitive_type] = ACTIONS(2404),
    [anon_sym_enum] = ACTIONS(2404),
    [anon_sym_class] = ACTIONS(2404),
    [anon_sym_struct] = ACTIONS(2404),
    [anon_sym_union] = ACTIONS(2404),
    [anon_sym_if] = ACTIONS(2404),
    [anon_sym_switch] = ACTIONS(2404),
    [anon_sym_case] = ACTIONS(2404),
    [anon_sym_default] = ACTIONS(2404),
    [anon_sym_while] = ACTIONS(2404),
    [anon_sym_do] = ACTIONS(2404),
    [anon_sym_for] = ACTIONS(2404),
    [anon_sym_return] = ACTIONS(2404),
    [anon_sym_break] = ACTIONS(2404),
    [anon_sym_continue] = ACTIONS(2404),
    [anon_sym_goto] = ACTIONS(2404),
    [anon_sym_not] = ACTIONS(2404),
    [anon_sym_compl] = ACTIONS(2404),
    [anon_sym_DASH_DASH] = ACTIONS(2406),
    [anon_sym_PLUS_PLUS] = ACTIONS(2406),
    [anon_sym_sizeof] = ACTIONS(2404),
    [anon_sym___alignof__] = ACTIONS(2404),
    [anon_sym___alignof] = ACTIONS(2404),
    [anon_sym__alignof] = ACTIONS(2404),
    [anon_sym_alignof] = ACTIONS(2404),
    [anon_sym__Alignof] = ACTIONS(2404),
    [anon_sym_offsetof] = ACTIONS(2404),
    [anon_sym__Generic] = ACTIONS(2404),
    [anon_sym_asm] = ACTIONS(2404),
    [anon_sym___asm__] = ACTIONS(2404),
    [sym_number_literal] = ACTIONS(2406),
    [anon_sym_L_SQUOTE] = ACTIONS(2406),
    [anon_sym_u_SQUOTE] = ACTIONS(2406),
    [anon_sym_U_SQUOTE] = ACTIONS(2406),
    [anon_sym_u8_SQUOTE] = ACTIONS(2406),
    [anon_sym_SQUOTE] = ACTIONS(2406),
    [anon_sym_L_DQUOTE] = ACTIONS(2406),
    [anon_sym_u_DQUOTE] = ACTIONS(2406),
    [anon_sym_U_DQUOTE] = ACTIONS(2406),
    [anon_sym_u8_DQUOTE] = ACTIONS(2406),
    [anon_sym_DQUOTE] = ACTIONS(2406),
    [sym_true] = ACTIONS(2404),
    [sym_false] = ACTIONS(2404),
    [anon_sym_NULL] = ACTIONS(2404),
    [anon_sym_nullptr] = ACTIONS(2404),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2404),
    [anon_sym_decltype] = ACTIONS(2404),
    [sym_virtual] = ACTIONS(2404),
    [anon_sym_explicit] = ACTIONS(2404),
    [anon_sym_typename] = ACTIONS(2404),
    [anon_sym_template] = ACTIONS(2404),
    [anon_sym_operator] = ACTIONS(2404),
    [anon_sym_try] = ACTIONS(2404),
    [anon_sym_delete] = ACTIONS(2404),
    [anon_sym_throw] = ACTIONS(2404),
    [anon_sym_namespace] = ACTIONS(2404),
    [anon_sym_using] = ACTIONS(2404),
    [anon_sym_static_assert] = ACTIONS(2404),
    [anon_sym_concept] = ACTIONS(2404),
    [anon_sym_co_return] = ACTIONS(2404),
    [anon_sym_co_yield] = ACTIONS(2404),
    [anon_sym_R_DQUOTE] = ACTIONS(2406),
    [anon_sym_LR_DQUOTE] = ACTIONS(2406),
    [anon_sym_uR_DQUOTE] = ACTIONS(2406),
    [anon_sym_UR_DQUOTE] = ACTIONS(2406),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2406),
    [anon_sym_co_await] = ACTIONS(2404),
    [anon_sym_new] = ACTIONS(2404),
    [anon_sym_requires] = ACTIONS(2404),
    [sym_this] = ACTIONS(2404),
    [anon_sym_precise] = ACTIONS(2404),
    [anon_sym_shared] = ACTIONS(2404),
    [anon_sym_groupshared] = ACTIONS(2404),
    [anon_sym_uniform] = ACTIONS(2404),
    [anon_sym_row_major] = ACTIONS(2404),
    [anon_sym_column_major] = ACTIONS(2404),
    [anon_sym_globallycoherent] = ACTIONS(2404),
    [anon_sym_centroid] = ACTIONS(2404),
    [anon_sym_noperspective] = ACTIONS(2404),
    [anon_sym_nointerpolation] = ACTIONS(2404),
    [anon_sym_sample] = ACTIONS(2404),
    [anon_sym_linear] = ACTIONS(2404),
    [anon_sym_snorm] = ACTIONS(2404),
    [anon_sym_unorm] = ACTIONS(2404),
    [anon_sym_point] = ACTIONS(2404),
    [anon_sym_line] = ACTIONS(2404),
    [anon_sym_triangleadj] = ACTIONS(2404),
    [anon_sym_lineadj] = ACTIONS(2404),
    [anon_sym_triangle] = ACTIONS(2404),
  },
  [794] = {
    [sym_preproc_def] = STATE(799),
    [sym_preproc_function_def] = STATE(799),
    [sym_preproc_call] = STATE(799),
    [sym_preproc_if_in_field_declaration_list] = STATE(799),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(799),
    [sym_type_definition] = STATE(799),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(799),
    [sym_field_declaration] = STATE(799),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(799),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(799),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(799),
    [sym_operator_cast_declaration] = STATE(799),
    [sym_constructor_or_destructor_definition] = STATE(799),
    [sym_constructor_or_destructor_declaration] = STATE(799),
    [sym_friend_declaration] = STATE(799),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(799),
    [sym_alias_declaration] = STATE(799),
    [sym_static_assert_declaration] = STATE(799),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(799),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(2991),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [795] = {
    [ts_builtin_sym_end] = ACTIONS(2534),
    [sym_identifier] = ACTIONS(2532),
    [aux_sym_preproc_include_token1] = ACTIONS(2532),
    [aux_sym_preproc_def_token1] = ACTIONS(2532),
    [aux_sym_preproc_if_token1] = ACTIONS(2532),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2532),
    [sym_preproc_directive] = ACTIONS(2532),
    [anon_sym_LPAREN2] = ACTIONS(2534),
    [anon_sym_BANG] = ACTIONS(2534),
    [anon_sym_TILDE] = ACTIONS(2534),
    [anon_sym_DASH] = ACTIONS(2532),
    [anon_sym_PLUS] = ACTIONS(2532),
    [anon_sym_STAR] = ACTIONS(2534),
    [anon_sym_AMP_AMP] = ACTIONS(2534),
    [anon_sym_AMP] = ACTIONS(2532),
    [anon_sym___extension__] = ACTIONS(2532),
    [anon_sym_typedef] = ACTIONS(2532),
    [anon_sym_in] = ACTIONS(2532),
    [anon_sym_out] = ACTIONS(2532),
    [anon_sym_inout] = ACTIONS(2532),
    [anon_sym_extern] = ACTIONS(2532),
    [anon_sym___attribute__] = ACTIONS(2532),
    [anon_sym_COLON_COLON] = ACTIONS(2534),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2534),
    [anon_sym___declspec] = ACTIONS(2532),
    [anon_sym___based] = ACTIONS(2532),
    [anon_sym___cdecl] = ACTIONS(2532),
    [anon_sym___clrcall] = ACTIONS(2532),
    [anon_sym___stdcall] = ACTIONS(2532),
    [anon_sym___fastcall] = ACTIONS(2532),
    [anon_sym___thiscall] = ACTIONS(2532),
    [anon_sym___vectorcall] = ACTIONS(2532),
    [anon_sym_LBRACE] = ACTIONS(2534),
    [anon_sym_signed] = ACTIONS(2532),
    [anon_sym_unsigned] = ACTIONS(2532),
    [anon_sym_long] = ACTIONS(2532),
    [anon_sym_short] = ACTIONS(2532),
    [anon_sym_LBRACK] = ACTIONS(2532),
    [anon_sym_static] = ACTIONS(2532),
    [anon_sym_register] = ACTIONS(2532),
    [anon_sym_inline] = ACTIONS(2532),
    [anon_sym___inline] = ACTIONS(2532),
    [anon_sym___inline__] = ACTIONS(2532),
    [anon_sym___forceinline] = ACTIONS(2532),
    [anon_sym_thread_local] = ACTIONS(2532),
    [anon_sym___thread] = ACTIONS(2532),
    [anon_sym_const] = ACTIONS(2532),
    [anon_sym_constexpr] = ACTIONS(2532),
    [anon_sym_volatile] = ACTIONS(2532),
    [anon_sym_restrict] = ACTIONS(2532),
    [anon_sym___restrict__] = ACTIONS(2532),
    [anon_sym__Atomic] = ACTIONS(2532),
    [anon_sym__Noreturn] = ACTIONS(2532),
    [anon_sym_noreturn] = ACTIONS(2532),
    [anon_sym_mutable] = ACTIONS(2532),
    [anon_sym_constinit] = ACTIONS(2532),
    [anon_sym_consteval] = ACTIONS(2532),
    [anon_sym_alignas] = ACTIONS(2532),
    [anon_sym__Alignas] = ACTIONS(2532),
    [sym_primitive_type] = ACTIONS(2532),
    [anon_sym_enum] = ACTIONS(2532),
    [anon_sym_class] = ACTIONS(2532),
    [anon_sym_struct] = ACTIONS(2532),
    [anon_sym_union] = ACTIONS(2532),
    [anon_sym_if] = ACTIONS(2532),
    [anon_sym_switch] = ACTIONS(2532),
    [anon_sym_case] = ACTIONS(2532),
    [anon_sym_default] = ACTIONS(2532),
    [anon_sym_while] = ACTIONS(2532),
    [anon_sym_do] = ACTIONS(2532),
    [anon_sym_for] = ACTIONS(2532),
    [anon_sym_return] = ACTIONS(2532),
    [anon_sym_break] = ACTIONS(2532),
    [anon_sym_continue] = ACTIONS(2532),
    [anon_sym_goto] = ACTIONS(2532),
    [anon_sym_not] = ACTIONS(2532),
    [anon_sym_compl] = ACTIONS(2532),
    [anon_sym_DASH_DASH] = ACTIONS(2534),
    [anon_sym_PLUS_PLUS] = ACTIONS(2534),
    [anon_sym_sizeof] = ACTIONS(2532),
    [anon_sym___alignof__] = ACTIONS(2532),
    [anon_sym___alignof] = ACTIONS(2532),
    [anon_sym__alignof] = ACTIONS(2532),
    [anon_sym_alignof] = ACTIONS(2532),
    [anon_sym__Alignof] = ACTIONS(2532),
    [anon_sym_offsetof] = ACTIONS(2532),
    [anon_sym__Generic] = ACTIONS(2532),
    [anon_sym_asm] = ACTIONS(2532),
    [anon_sym___asm__] = ACTIONS(2532),
    [sym_number_literal] = ACTIONS(2534),
    [anon_sym_L_SQUOTE] = ACTIONS(2534),
    [anon_sym_u_SQUOTE] = ACTIONS(2534),
    [anon_sym_U_SQUOTE] = ACTIONS(2534),
    [anon_sym_u8_SQUOTE] = ACTIONS(2534),
    [anon_sym_SQUOTE] = ACTIONS(2534),
    [anon_sym_L_DQUOTE] = ACTIONS(2534),
    [anon_sym_u_DQUOTE] = ACTIONS(2534),
    [anon_sym_U_DQUOTE] = ACTIONS(2534),
    [anon_sym_u8_DQUOTE] = ACTIONS(2534),
    [anon_sym_DQUOTE] = ACTIONS(2534),
    [sym_true] = ACTIONS(2532),
    [sym_false] = ACTIONS(2532),
    [anon_sym_NULL] = ACTIONS(2532),
    [anon_sym_nullptr] = ACTIONS(2532),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2532),
    [anon_sym_decltype] = ACTIONS(2532),
    [sym_virtual] = ACTIONS(2532),
    [anon_sym_explicit] = ACTIONS(2532),
    [anon_sym_typename] = ACTIONS(2532),
    [anon_sym_template] = ACTIONS(2532),
    [anon_sym_operator] = ACTIONS(2532),
    [anon_sym_try] = ACTIONS(2532),
    [anon_sym_delete] = ACTIONS(2532),
    [anon_sym_throw] = ACTIONS(2532),
    [anon_sym_namespace] = ACTIONS(2532),
    [anon_sym_using] = ACTIONS(2532),
    [anon_sym_static_assert] = ACTIONS(2532),
    [anon_sym_concept] = ACTIONS(2532),
    [anon_sym_co_return] = ACTIONS(2532),
    [anon_sym_co_yield] = ACTIONS(2532),
    [anon_sym_R_DQUOTE] = ACTIONS(2534),
    [anon_sym_LR_DQUOTE] = ACTIONS(2534),
    [anon_sym_uR_DQUOTE] = ACTIONS(2534),
    [anon_sym_UR_DQUOTE] = ACTIONS(2534),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2534),
    [anon_sym_co_await] = ACTIONS(2532),
    [anon_sym_new] = ACTIONS(2532),
    [anon_sym_requires] = ACTIONS(2532),
    [sym_this] = ACTIONS(2532),
    [anon_sym_precise] = ACTIONS(2532),
    [anon_sym_shared] = ACTIONS(2532),
    [anon_sym_groupshared] = ACTIONS(2532),
    [anon_sym_uniform] = ACTIONS(2532),
    [anon_sym_row_major] = ACTIONS(2532),
    [anon_sym_column_major] = ACTIONS(2532),
    [anon_sym_globallycoherent] = ACTIONS(2532),
    [anon_sym_centroid] = ACTIONS(2532),
    [anon_sym_noperspective] = ACTIONS(2532),
    [anon_sym_nointerpolation] = ACTIONS(2532),
    [anon_sym_sample] = ACTIONS(2532),
    [anon_sym_linear] = ACTIONS(2532),
    [anon_sym_snorm] = ACTIONS(2532),
    [anon_sym_unorm] = ACTIONS(2532),
    [anon_sym_point] = ACTIONS(2532),
    [anon_sym_line] = ACTIONS(2532),
    [anon_sym_triangleadj] = ACTIONS(2532),
    [anon_sym_lineadj] = ACTIONS(2532),
    [anon_sym_triangle] = ACTIONS(2532),
  },
  [796] = {
    [ts_builtin_sym_end] = ACTIONS(2358),
    [sym_identifier] = ACTIONS(2356),
    [aux_sym_preproc_include_token1] = ACTIONS(2356),
    [aux_sym_preproc_def_token1] = ACTIONS(2356),
    [aux_sym_preproc_if_token1] = ACTIONS(2356),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2356),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2356),
    [sym_preproc_directive] = ACTIONS(2356),
    [anon_sym_LPAREN2] = ACTIONS(2358),
    [anon_sym_BANG] = ACTIONS(2358),
    [anon_sym_TILDE] = ACTIONS(2358),
    [anon_sym_DASH] = ACTIONS(2356),
    [anon_sym_PLUS] = ACTIONS(2356),
    [anon_sym_STAR] = ACTIONS(2358),
    [anon_sym_AMP_AMP] = ACTIONS(2358),
    [anon_sym_AMP] = ACTIONS(2356),
    [anon_sym___extension__] = ACTIONS(2356),
    [anon_sym_typedef] = ACTIONS(2356),
    [anon_sym_in] = ACTIONS(2356),
    [anon_sym_out] = ACTIONS(2356),
    [anon_sym_inout] = ACTIONS(2356),
    [anon_sym_extern] = ACTIONS(2356),
    [anon_sym___attribute__] = ACTIONS(2356),
    [anon_sym_COLON_COLON] = ACTIONS(2358),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2358),
    [anon_sym___declspec] = ACTIONS(2356),
    [anon_sym___based] = ACTIONS(2356),
    [anon_sym___cdecl] = ACTIONS(2356),
    [anon_sym___clrcall] = ACTIONS(2356),
    [anon_sym___stdcall] = ACTIONS(2356),
    [anon_sym___fastcall] = ACTIONS(2356),
    [anon_sym___thiscall] = ACTIONS(2356),
    [anon_sym___vectorcall] = ACTIONS(2356),
    [anon_sym_LBRACE] = ACTIONS(2358),
    [anon_sym_signed] = ACTIONS(2356),
    [anon_sym_unsigned] = ACTIONS(2356),
    [anon_sym_long] = ACTIONS(2356),
    [anon_sym_short] = ACTIONS(2356),
    [anon_sym_LBRACK] = ACTIONS(2356),
    [anon_sym_static] = ACTIONS(2356),
    [anon_sym_register] = ACTIONS(2356),
    [anon_sym_inline] = ACTIONS(2356),
    [anon_sym___inline] = ACTIONS(2356),
    [anon_sym___inline__] = ACTIONS(2356),
    [anon_sym___forceinline] = ACTIONS(2356),
    [anon_sym_thread_local] = ACTIONS(2356),
    [anon_sym___thread] = ACTIONS(2356),
    [anon_sym_const] = ACTIONS(2356),
    [anon_sym_constexpr] = ACTIONS(2356),
    [anon_sym_volatile] = ACTIONS(2356),
    [anon_sym_restrict] = ACTIONS(2356),
    [anon_sym___restrict__] = ACTIONS(2356),
    [anon_sym__Atomic] = ACTIONS(2356),
    [anon_sym__Noreturn] = ACTIONS(2356),
    [anon_sym_noreturn] = ACTIONS(2356),
    [anon_sym_mutable] = ACTIONS(2356),
    [anon_sym_constinit] = ACTIONS(2356),
    [anon_sym_consteval] = ACTIONS(2356),
    [anon_sym_alignas] = ACTIONS(2356),
    [anon_sym__Alignas] = ACTIONS(2356),
    [sym_primitive_type] = ACTIONS(2356),
    [anon_sym_enum] = ACTIONS(2356),
    [anon_sym_class] = ACTIONS(2356),
    [anon_sym_struct] = ACTIONS(2356),
    [anon_sym_union] = ACTIONS(2356),
    [anon_sym_if] = ACTIONS(2356),
    [anon_sym_switch] = ACTIONS(2356),
    [anon_sym_case] = ACTIONS(2356),
    [anon_sym_default] = ACTIONS(2356),
    [anon_sym_while] = ACTIONS(2356),
    [anon_sym_do] = ACTIONS(2356),
    [anon_sym_for] = ACTIONS(2356),
    [anon_sym_return] = ACTIONS(2356),
    [anon_sym_break] = ACTIONS(2356),
    [anon_sym_continue] = ACTIONS(2356),
    [anon_sym_goto] = ACTIONS(2356),
    [anon_sym_not] = ACTIONS(2356),
    [anon_sym_compl] = ACTIONS(2356),
    [anon_sym_DASH_DASH] = ACTIONS(2358),
    [anon_sym_PLUS_PLUS] = ACTIONS(2358),
    [anon_sym_sizeof] = ACTIONS(2356),
    [anon_sym___alignof__] = ACTIONS(2356),
    [anon_sym___alignof] = ACTIONS(2356),
    [anon_sym__alignof] = ACTIONS(2356),
    [anon_sym_alignof] = ACTIONS(2356),
    [anon_sym__Alignof] = ACTIONS(2356),
    [anon_sym_offsetof] = ACTIONS(2356),
    [anon_sym__Generic] = ACTIONS(2356),
    [anon_sym_asm] = ACTIONS(2356),
    [anon_sym___asm__] = ACTIONS(2356),
    [sym_number_literal] = ACTIONS(2358),
    [anon_sym_L_SQUOTE] = ACTIONS(2358),
    [anon_sym_u_SQUOTE] = ACTIONS(2358),
    [anon_sym_U_SQUOTE] = ACTIONS(2358),
    [anon_sym_u8_SQUOTE] = ACTIONS(2358),
    [anon_sym_SQUOTE] = ACTIONS(2358),
    [anon_sym_L_DQUOTE] = ACTIONS(2358),
    [anon_sym_u_DQUOTE] = ACTIONS(2358),
    [anon_sym_U_DQUOTE] = ACTIONS(2358),
    [anon_sym_u8_DQUOTE] = ACTIONS(2358),
    [anon_sym_DQUOTE] = ACTIONS(2358),
    [sym_true] = ACTIONS(2356),
    [sym_false] = ACTIONS(2356),
    [anon_sym_NULL] = ACTIONS(2356),
    [anon_sym_nullptr] = ACTIONS(2356),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2356),
    [anon_sym_decltype] = ACTIONS(2356),
    [sym_virtual] = ACTIONS(2356),
    [anon_sym_explicit] = ACTIONS(2356),
    [anon_sym_typename] = ACTIONS(2356),
    [anon_sym_template] = ACTIONS(2356),
    [anon_sym_operator] = ACTIONS(2356),
    [anon_sym_try] = ACTIONS(2356),
    [anon_sym_delete] = ACTIONS(2356),
    [anon_sym_throw] = ACTIONS(2356),
    [anon_sym_namespace] = ACTIONS(2356),
    [anon_sym_using] = ACTIONS(2356),
    [anon_sym_static_assert] = ACTIONS(2356),
    [anon_sym_concept] = ACTIONS(2356),
    [anon_sym_co_return] = ACTIONS(2356),
    [anon_sym_co_yield] = ACTIONS(2356),
    [anon_sym_R_DQUOTE] = ACTIONS(2358),
    [anon_sym_LR_DQUOTE] = ACTIONS(2358),
    [anon_sym_uR_DQUOTE] = ACTIONS(2358),
    [anon_sym_UR_DQUOTE] = ACTIONS(2358),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2358),
    [anon_sym_co_await] = ACTIONS(2356),
    [anon_sym_new] = ACTIONS(2356),
    [anon_sym_requires] = ACTIONS(2356),
    [sym_this] = ACTIONS(2356),
    [anon_sym_precise] = ACTIONS(2356),
    [anon_sym_shared] = ACTIONS(2356),
    [anon_sym_groupshared] = ACTIONS(2356),
    [anon_sym_uniform] = ACTIONS(2356),
    [anon_sym_row_major] = ACTIONS(2356),
    [anon_sym_column_major] = ACTIONS(2356),
    [anon_sym_globallycoherent] = ACTIONS(2356),
    [anon_sym_centroid] = ACTIONS(2356),
    [anon_sym_noperspective] = ACTIONS(2356),
    [anon_sym_nointerpolation] = ACTIONS(2356),
    [anon_sym_sample] = ACTIONS(2356),
    [anon_sym_linear] = ACTIONS(2356),
    [anon_sym_snorm] = ACTIONS(2356),
    [anon_sym_unorm] = ACTIONS(2356),
    [anon_sym_point] = ACTIONS(2356),
    [anon_sym_line] = ACTIONS(2356),
    [anon_sym_triangleadj] = ACTIONS(2356),
    [anon_sym_lineadj] = ACTIONS(2356),
    [anon_sym_triangle] = ACTIONS(2356),
  },
  [797] = {
    [sym_preproc_def] = STATE(797),
    [sym_preproc_function_def] = STATE(797),
    [sym_preproc_call] = STATE(797),
    [sym_preproc_if_in_field_declaration_list] = STATE(797),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(797),
    [sym_type_definition] = STATE(797),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(797),
    [sym_field_declaration] = STATE(797),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(797),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(797),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(797),
    [sym_operator_cast_declaration] = STATE(797),
    [sym_constructor_or_destructor_definition] = STATE(797),
    [sym_constructor_or_destructor_declaration] = STATE(797),
    [sym_friend_declaration] = STATE(797),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(797),
    [sym_alias_declaration] = STATE(797),
    [sym_static_assert_declaration] = STATE(797),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(797),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2728),
    [aux_sym_preproc_def_token1] = ACTIONS(2993),
    [aux_sym_preproc_if_token1] = ACTIONS(2996),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2999),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2999),
    [sym_preproc_directive] = ACTIONS(3002),
    [anon_sym_LPAREN2] = ACTIONS(2745),
    [anon_sym_TILDE] = ACTIONS(2748),
    [anon_sym_STAR] = ACTIONS(2751),
    [anon_sym_AMP_AMP] = ACTIONS(2754),
    [anon_sym_AMP] = ACTIONS(2757),
    [anon_sym___extension__] = ACTIONS(3005),
    [anon_sym_typedef] = ACTIONS(3008),
    [anon_sym_in] = ACTIONS(2766),
    [anon_sym_out] = ACTIONS(2766),
    [anon_sym_inout] = ACTIONS(2766),
    [anon_sym_extern] = ACTIONS(2769),
    [anon_sym___attribute__] = ACTIONS(2772),
    [anon_sym_COLON_COLON] = ACTIONS(2775),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2778),
    [anon_sym___declspec] = ACTIONS(2781),
    [anon_sym___based] = ACTIONS(2784),
    [anon_sym_RBRACE] = ACTIONS(3011),
    [anon_sym_signed] = ACTIONS(2787),
    [anon_sym_unsigned] = ACTIONS(2787),
    [anon_sym_long] = ACTIONS(2787),
    [anon_sym_short] = ACTIONS(2787),
    [anon_sym_LBRACK] = ACTIONS(2790),
    [anon_sym_static] = ACTIONS(2769),
    [anon_sym_register] = ACTIONS(2769),
    [anon_sym_inline] = ACTIONS(2769),
    [anon_sym___inline] = ACTIONS(2769),
    [anon_sym___inline__] = ACTIONS(2769),
    [anon_sym___forceinline] = ACTIONS(2769),
    [anon_sym_thread_local] = ACTIONS(2769),
    [anon_sym___thread] = ACTIONS(2769),
    [anon_sym_const] = ACTIONS(2793),
    [anon_sym_constexpr] = ACTIONS(2793),
    [anon_sym_volatile] = ACTIONS(2793),
    [anon_sym_restrict] = ACTIONS(2793),
    [anon_sym___restrict__] = ACTIONS(2793),
    [anon_sym__Atomic] = ACTIONS(2793),
    [anon_sym__Noreturn] = ACTIONS(2793),
    [anon_sym_noreturn] = ACTIONS(2793),
    [anon_sym_mutable] = ACTIONS(2793),
    [anon_sym_constinit] = ACTIONS(2793),
    [anon_sym_consteval] = ACTIONS(2793),
    [anon_sym_alignas] = ACTIONS(2796),
    [anon_sym__Alignas] = ACTIONS(2796),
    [sym_primitive_type] = ACTIONS(2799),
    [anon_sym_enum] = ACTIONS(2802),
    [anon_sym_class] = ACTIONS(2805),
    [anon_sym_struct] = ACTIONS(2808),
    [anon_sym_union] = ACTIONS(2811),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2814),
    [anon_sym_decltype] = ACTIONS(2817),
    [sym_virtual] = ACTIONS(2766),
    [anon_sym_explicit] = ACTIONS(2820),
    [anon_sym_typename] = ACTIONS(2823),
    [anon_sym_template] = ACTIONS(3013),
    [anon_sym_operator] = ACTIONS(2829),
    [anon_sym_friend] = ACTIONS(3016),
    [anon_sym_public] = ACTIONS(2835),
    [anon_sym_private] = ACTIONS(2835),
    [anon_sym_protected] = ACTIONS(2835),
    [anon_sym_using] = ACTIONS(3019),
    [anon_sym_static_assert] = ACTIONS(3022),
    [anon_sym_precise] = ACTIONS(2844),
    [anon_sym_shared] = ACTIONS(2844),
    [anon_sym_groupshared] = ACTIONS(2844),
    [anon_sym_uniform] = ACTIONS(2844),
    [anon_sym_row_major] = ACTIONS(2844),
    [anon_sym_column_major] = ACTIONS(2844),
    [anon_sym_globallycoherent] = ACTIONS(2844),
    [anon_sym_centroid] = ACTIONS(2844),
    [anon_sym_noperspective] = ACTIONS(2844),
    [anon_sym_nointerpolation] = ACTIONS(2844),
    [anon_sym_sample] = ACTIONS(2844),
    [anon_sym_linear] = ACTIONS(2844),
    [anon_sym_snorm] = ACTIONS(2844),
    [anon_sym_unorm] = ACTIONS(2844),
    [anon_sym_point] = ACTIONS(2844),
    [anon_sym_line] = ACTIONS(2844),
    [anon_sym_triangleadj] = ACTIONS(2844),
    [anon_sym_lineadj] = ACTIONS(2844),
    [anon_sym_triangle] = ACTIONS(2844),
  },
  [798] = {
    [ts_builtin_sym_end] = ACTIONS(2350),
    [sym_identifier] = ACTIONS(2348),
    [aux_sym_preproc_include_token1] = ACTIONS(2348),
    [aux_sym_preproc_def_token1] = ACTIONS(2348),
    [aux_sym_preproc_if_token1] = ACTIONS(2348),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2348),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2348),
    [sym_preproc_directive] = ACTIONS(2348),
    [anon_sym_LPAREN2] = ACTIONS(2350),
    [anon_sym_BANG] = ACTIONS(2350),
    [anon_sym_TILDE] = ACTIONS(2350),
    [anon_sym_DASH] = ACTIONS(2348),
    [anon_sym_PLUS] = ACTIONS(2348),
    [anon_sym_STAR] = ACTIONS(2350),
    [anon_sym_AMP_AMP] = ACTIONS(2350),
    [anon_sym_AMP] = ACTIONS(2348),
    [anon_sym___extension__] = ACTIONS(2348),
    [anon_sym_typedef] = ACTIONS(2348),
    [anon_sym_in] = ACTIONS(2348),
    [anon_sym_out] = ACTIONS(2348),
    [anon_sym_inout] = ACTIONS(2348),
    [anon_sym_extern] = ACTIONS(2348),
    [anon_sym___attribute__] = ACTIONS(2348),
    [anon_sym_COLON_COLON] = ACTIONS(2350),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2350),
    [anon_sym___declspec] = ACTIONS(2348),
    [anon_sym___based] = ACTIONS(2348),
    [anon_sym___cdecl] = ACTIONS(2348),
    [anon_sym___clrcall] = ACTIONS(2348),
    [anon_sym___stdcall] = ACTIONS(2348),
    [anon_sym___fastcall] = ACTIONS(2348),
    [anon_sym___thiscall] = ACTIONS(2348),
    [anon_sym___vectorcall] = ACTIONS(2348),
    [anon_sym_LBRACE] = ACTIONS(2350),
    [anon_sym_signed] = ACTIONS(2348),
    [anon_sym_unsigned] = ACTIONS(2348),
    [anon_sym_long] = ACTIONS(2348),
    [anon_sym_short] = ACTIONS(2348),
    [anon_sym_LBRACK] = ACTIONS(2348),
    [anon_sym_static] = ACTIONS(2348),
    [anon_sym_register] = ACTIONS(2348),
    [anon_sym_inline] = ACTIONS(2348),
    [anon_sym___inline] = ACTIONS(2348),
    [anon_sym___inline__] = ACTIONS(2348),
    [anon_sym___forceinline] = ACTIONS(2348),
    [anon_sym_thread_local] = ACTIONS(2348),
    [anon_sym___thread] = ACTIONS(2348),
    [anon_sym_const] = ACTIONS(2348),
    [anon_sym_constexpr] = ACTIONS(2348),
    [anon_sym_volatile] = ACTIONS(2348),
    [anon_sym_restrict] = ACTIONS(2348),
    [anon_sym___restrict__] = ACTIONS(2348),
    [anon_sym__Atomic] = ACTIONS(2348),
    [anon_sym__Noreturn] = ACTIONS(2348),
    [anon_sym_noreturn] = ACTIONS(2348),
    [anon_sym_mutable] = ACTIONS(2348),
    [anon_sym_constinit] = ACTIONS(2348),
    [anon_sym_consteval] = ACTIONS(2348),
    [anon_sym_alignas] = ACTIONS(2348),
    [anon_sym__Alignas] = ACTIONS(2348),
    [sym_primitive_type] = ACTIONS(2348),
    [anon_sym_enum] = ACTIONS(2348),
    [anon_sym_class] = ACTIONS(2348),
    [anon_sym_struct] = ACTIONS(2348),
    [anon_sym_union] = ACTIONS(2348),
    [anon_sym_if] = ACTIONS(2348),
    [anon_sym_switch] = ACTIONS(2348),
    [anon_sym_case] = ACTIONS(2348),
    [anon_sym_default] = ACTIONS(2348),
    [anon_sym_while] = ACTIONS(2348),
    [anon_sym_do] = ACTIONS(2348),
    [anon_sym_for] = ACTIONS(2348),
    [anon_sym_return] = ACTIONS(2348),
    [anon_sym_break] = ACTIONS(2348),
    [anon_sym_continue] = ACTIONS(2348),
    [anon_sym_goto] = ACTIONS(2348),
    [anon_sym_not] = ACTIONS(2348),
    [anon_sym_compl] = ACTIONS(2348),
    [anon_sym_DASH_DASH] = ACTIONS(2350),
    [anon_sym_PLUS_PLUS] = ACTIONS(2350),
    [anon_sym_sizeof] = ACTIONS(2348),
    [anon_sym___alignof__] = ACTIONS(2348),
    [anon_sym___alignof] = ACTIONS(2348),
    [anon_sym__alignof] = ACTIONS(2348),
    [anon_sym_alignof] = ACTIONS(2348),
    [anon_sym__Alignof] = ACTIONS(2348),
    [anon_sym_offsetof] = ACTIONS(2348),
    [anon_sym__Generic] = ACTIONS(2348),
    [anon_sym_asm] = ACTIONS(2348),
    [anon_sym___asm__] = ACTIONS(2348),
    [sym_number_literal] = ACTIONS(2350),
    [anon_sym_L_SQUOTE] = ACTIONS(2350),
    [anon_sym_u_SQUOTE] = ACTIONS(2350),
    [anon_sym_U_SQUOTE] = ACTIONS(2350),
    [anon_sym_u8_SQUOTE] = ACTIONS(2350),
    [anon_sym_SQUOTE] = ACTIONS(2350),
    [anon_sym_L_DQUOTE] = ACTIONS(2350),
    [anon_sym_u_DQUOTE] = ACTIONS(2350),
    [anon_sym_U_DQUOTE] = ACTIONS(2350),
    [anon_sym_u8_DQUOTE] = ACTIONS(2350),
    [anon_sym_DQUOTE] = ACTIONS(2350),
    [sym_true] = ACTIONS(2348),
    [sym_false] = ACTIONS(2348),
    [anon_sym_NULL] = ACTIONS(2348),
    [anon_sym_nullptr] = ACTIONS(2348),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2348),
    [anon_sym_decltype] = ACTIONS(2348),
    [sym_virtual] = ACTIONS(2348),
    [anon_sym_explicit] = ACTIONS(2348),
    [anon_sym_typename] = ACTIONS(2348),
    [anon_sym_template] = ACTIONS(2348),
    [anon_sym_operator] = ACTIONS(2348),
    [anon_sym_try] = ACTIONS(2348),
    [anon_sym_delete] = ACTIONS(2348),
    [anon_sym_throw] = ACTIONS(2348),
    [anon_sym_namespace] = ACTIONS(2348),
    [anon_sym_using] = ACTIONS(2348),
    [anon_sym_static_assert] = ACTIONS(2348),
    [anon_sym_concept] = ACTIONS(2348),
    [anon_sym_co_return] = ACTIONS(2348),
    [anon_sym_co_yield] = ACTIONS(2348),
    [anon_sym_R_DQUOTE] = ACTIONS(2350),
    [anon_sym_LR_DQUOTE] = ACTIONS(2350),
    [anon_sym_uR_DQUOTE] = ACTIONS(2350),
    [anon_sym_UR_DQUOTE] = ACTIONS(2350),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2350),
    [anon_sym_co_await] = ACTIONS(2348),
    [anon_sym_new] = ACTIONS(2348),
    [anon_sym_requires] = ACTIONS(2348),
    [sym_this] = ACTIONS(2348),
    [anon_sym_precise] = ACTIONS(2348),
    [anon_sym_shared] = ACTIONS(2348),
    [anon_sym_groupshared] = ACTIONS(2348),
    [anon_sym_uniform] = ACTIONS(2348),
    [anon_sym_row_major] = ACTIONS(2348),
    [anon_sym_column_major] = ACTIONS(2348),
    [anon_sym_globallycoherent] = ACTIONS(2348),
    [anon_sym_centroid] = ACTIONS(2348),
    [anon_sym_noperspective] = ACTIONS(2348),
    [anon_sym_nointerpolation] = ACTIONS(2348),
    [anon_sym_sample] = ACTIONS(2348),
    [anon_sym_linear] = ACTIONS(2348),
    [anon_sym_snorm] = ACTIONS(2348),
    [anon_sym_unorm] = ACTIONS(2348),
    [anon_sym_point] = ACTIONS(2348),
    [anon_sym_line] = ACTIONS(2348),
    [anon_sym_triangleadj] = ACTIONS(2348),
    [anon_sym_lineadj] = ACTIONS(2348),
    [anon_sym_triangle] = ACTIONS(2348),
  },
  [799] = {
    [sym_preproc_def] = STATE(797),
    [sym_preproc_function_def] = STATE(797),
    [sym_preproc_call] = STATE(797),
    [sym_preproc_if_in_field_declaration_list] = STATE(797),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(797),
    [sym_type_definition] = STATE(797),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(797),
    [sym_field_declaration] = STATE(797),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(797),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(797),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(797),
    [sym_operator_cast_declaration] = STATE(797),
    [sym_constructor_or_destructor_definition] = STATE(797),
    [sym_constructor_or_destructor_declaration] = STATE(797),
    [sym_friend_declaration] = STATE(797),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(797),
    [sym_alias_declaration] = STATE(797),
    [sym_static_assert_declaration] = STATE(797),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(797),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(3025),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [800] = {
    [ts_builtin_sym_end] = ACTIONS(2322),
    [sym_identifier] = ACTIONS(2320),
    [aux_sym_preproc_include_token1] = ACTIONS(2320),
    [aux_sym_preproc_def_token1] = ACTIONS(2320),
    [aux_sym_preproc_if_token1] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2320),
    [sym_preproc_directive] = ACTIONS(2320),
    [anon_sym_LPAREN2] = ACTIONS(2322),
    [anon_sym_BANG] = ACTIONS(2322),
    [anon_sym_TILDE] = ACTIONS(2322),
    [anon_sym_DASH] = ACTIONS(2320),
    [anon_sym_PLUS] = ACTIONS(2320),
    [anon_sym_STAR] = ACTIONS(2322),
    [anon_sym_AMP_AMP] = ACTIONS(2322),
    [anon_sym_AMP] = ACTIONS(2320),
    [anon_sym___extension__] = ACTIONS(2320),
    [anon_sym_typedef] = ACTIONS(2320),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_out] = ACTIONS(2320),
    [anon_sym_inout] = ACTIONS(2320),
    [anon_sym_extern] = ACTIONS(2320),
    [anon_sym___attribute__] = ACTIONS(2320),
    [anon_sym_COLON_COLON] = ACTIONS(2322),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2322),
    [anon_sym___declspec] = ACTIONS(2320),
    [anon_sym___based] = ACTIONS(2320),
    [anon_sym___cdecl] = ACTIONS(2320),
    [anon_sym___clrcall] = ACTIONS(2320),
    [anon_sym___stdcall] = ACTIONS(2320),
    [anon_sym___fastcall] = ACTIONS(2320),
    [anon_sym___thiscall] = ACTIONS(2320),
    [anon_sym___vectorcall] = ACTIONS(2320),
    [anon_sym_LBRACE] = ACTIONS(2322),
    [anon_sym_signed] = ACTIONS(2320),
    [anon_sym_unsigned] = ACTIONS(2320),
    [anon_sym_long] = ACTIONS(2320),
    [anon_sym_short] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2320),
    [anon_sym_static] = ACTIONS(2320),
    [anon_sym_register] = ACTIONS(2320),
    [anon_sym_inline] = ACTIONS(2320),
    [anon_sym___inline] = ACTIONS(2320),
    [anon_sym___inline__] = ACTIONS(2320),
    [anon_sym___forceinline] = ACTIONS(2320),
    [anon_sym_thread_local] = ACTIONS(2320),
    [anon_sym___thread] = ACTIONS(2320),
    [anon_sym_const] = ACTIONS(2320),
    [anon_sym_constexpr] = ACTIONS(2320),
    [anon_sym_volatile] = ACTIONS(2320),
    [anon_sym_restrict] = ACTIONS(2320),
    [anon_sym___restrict__] = ACTIONS(2320),
    [anon_sym__Atomic] = ACTIONS(2320),
    [anon_sym__Noreturn] = ACTIONS(2320),
    [anon_sym_noreturn] = ACTIONS(2320),
    [anon_sym_mutable] = ACTIONS(2320),
    [anon_sym_constinit] = ACTIONS(2320),
    [anon_sym_consteval] = ACTIONS(2320),
    [anon_sym_alignas] = ACTIONS(2320),
    [anon_sym__Alignas] = ACTIONS(2320),
    [sym_primitive_type] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_class] = ACTIONS(2320),
    [anon_sym_struct] = ACTIONS(2320),
    [anon_sym_union] = ACTIONS(2320),
    [anon_sym_if] = ACTIONS(2320),
    [anon_sym_switch] = ACTIONS(2320),
    [anon_sym_case] = ACTIONS(2320),
    [anon_sym_default] = ACTIONS(2320),
    [anon_sym_while] = ACTIONS(2320),
    [anon_sym_do] = ACTIONS(2320),
    [anon_sym_for] = ACTIONS(2320),
    [anon_sym_return] = ACTIONS(2320),
    [anon_sym_break] = ACTIONS(2320),
    [anon_sym_continue] = ACTIONS(2320),
    [anon_sym_goto] = ACTIONS(2320),
    [anon_sym_not] = ACTIONS(2320),
    [anon_sym_compl] = ACTIONS(2320),
    [anon_sym_DASH_DASH] = ACTIONS(2322),
    [anon_sym_PLUS_PLUS] = ACTIONS(2322),
    [anon_sym_sizeof] = ACTIONS(2320),
    [anon_sym___alignof__] = ACTIONS(2320),
    [anon_sym___alignof] = ACTIONS(2320),
    [anon_sym__alignof] = ACTIONS(2320),
    [anon_sym_alignof] = ACTIONS(2320),
    [anon_sym__Alignof] = ACTIONS(2320),
    [anon_sym_offsetof] = ACTIONS(2320),
    [anon_sym__Generic] = ACTIONS(2320),
    [anon_sym_asm] = ACTIONS(2320),
    [anon_sym___asm__] = ACTIONS(2320),
    [sym_number_literal] = ACTIONS(2322),
    [anon_sym_L_SQUOTE] = ACTIONS(2322),
    [anon_sym_u_SQUOTE] = ACTIONS(2322),
    [anon_sym_U_SQUOTE] = ACTIONS(2322),
    [anon_sym_u8_SQUOTE] = ACTIONS(2322),
    [anon_sym_SQUOTE] = ACTIONS(2322),
    [anon_sym_L_DQUOTE] = ACTIONS(2322),
    [anon_sym_u_DQUOTE] = ACTIONS(2322),
    [anon_sym_U_DQUOTE] = ACTIONS(2322),
    [anon_sym_u8_DQUOTE] = ACTIONS(2322),
    [anon_sym_DQUOTE] = ACTIONS(2322),
    [sym_true] = ACTIONS(2320),
    [sym_false] = ACTIONS(2320),
    [anon_sym_NULL] = ACTIONS(2320),
    [anon_sym_nullptr] = ACTIONS(2320),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2320),
    [anon_sym_decltype] = ACTIONS(2320),
    [sym_virtual] = ACTIONS(2320),
    [anon_sym_explicit] = ACTIONS(2320),
    [anon_sym_typename] = ACTIONS(2320),
    [anon_sym_template] = ACTIONS(2320),
    [anon_sym_operator] = ACTIONS(2320),
    [anon_sym_try] = ACTIONS(2320),
    [anon_sym_delete] = ACTIONS(2320),
    [anon_sym_throw] = ACTIONS(2320),
    [anon_sym_namespace] = ACTIONS(2320),
    [anon_sym_using] = ACTIONS(2320),
    [anon_sym_static_assert] = ACTIONS(2320),
    [anon_sym_concept] = ACTIONS(2320),
    [anon_sym_co_return] = ACTIONS(2320),
    [anon_sym_co_yield] = ACTIONS(2320),
    [anon_sym_R_DQUOTE] = ACTIONS(2322),
    [anon_sym_LR_DQUOTE] = ACTIONS(2322),
    [anon_sym_uR_DQUOTE] = ACTIONS(2322),
    [anon_sym_UR_DQUOTE] = ACTIONS(2322),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2322),
    [anon_sym_co_await] = ACTIONS(2320),
    [anon_sym_new] = ACTIONS(2320),
    [anon_sym_requires] = ACTIONS(2320),
    [sym_this] = ACTIONS(2320),
    [anon_sym_precise] = ACTIONS(2320),
    [anon_sym_shared] = ACTIONS(2320),
    [anon_sym_groupshared] = ACTIONS(2320),
    [anon_sym_uniform] = ACTIONS(2320),
    [anon_sym_row_major] = ACTIONS(2320),
    [anon_sym_column_major] = ACTIONS(2320),
    [anon_sym_globallycoherent] = ACTIONS(2320),
    [anon_sym_centroid] = ACTIONS(2320),
    [anon_sym_noperspective] = ACTIONS(2320),
    [anon_sym_nointerpolation] = ACTIONS(2320),
    [anon_sym_sample] = ACTIONS(2320),
    [anon_sym_linear] = ACTIONS(2320),
    [anon_sym_snorm] = ACTIONS(2320),
    [anon_sym_unorm] = ACTIONS(2320),
    [anon_sym_point] = ACTIONS(2320),
    [anon_sym_line] = ACTIONS(2320),
    [anon_sym_triangleadj] = ACTIONS(2320),
    [anon_sym_lineadj] = ACTIONS(2320),
    [anon_sym_triangle] = ACTIONS(2320),
  },
  [801] = {
    [ts_builtin_sym_end] = ACTIONS(2314),
    [sym_identifier] = ACTIONS(2312),
    [aux_sym_preproc_include_token1] = ACTIONS(2312),
    [aux_sym_preproc_def_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2312),
    [sym_preproc_directive] = ACTIONS(2312),
    [anon_sym_LPAREN2] = ACTIONS(2314),
    [anon_sym_BANG] = ACTIONS(2314),
    [anon_sym_TILDE] = ACTIONS(2314),
    [anon_sym_DASH] = ACTIONS(2312),
    [anon_sym_PLUS] = ACTIONS(2312),
    [anon_sym_STAR] = ACTIONS(2314),
    [anon_sym_AMP_AMP] = ACTIONS(2314),
    [anon_sym_AMP] = ACTIONS(2312),
    [anon_sym___extension__] = ACTIONS(2312),
    [anon_sym_typedef] = ACTIONS(2312),
    [anon_sym_in] = ACTIONS(2312),
    [anon_sym_out] = ACTIONS(2312),
    [anon_sym_inout] = ACTIONS(2312),
    [anon_sym_extern] = ACTIONS(2312),
    [anon_sym___attribute__] = ACTIONS(2312),
    [anon_sym_COLON_COLON] = ACTIONS(2314),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2314),
    [anon_sym___declspec] = ACTIONS(2312),
    [anon_sym___based] = ACTIONS(2312),
    [anon_sym___cdecl] = ACTIONS(2312),
    [anon_sym___clrcall] = ACTIONS(2312),
    [anon_sym___stdcall] = ACTIONS(2312),
    [anon_sym___fastcall] = ACTIONS(2312),
    [anon_sym___thiscall] = ACTIONS(2312),
    [anon_sym___vectorcall] = ACTIONS(2312),
    [anon_sym_LBRACE] = ACTIONS(2314),
    [anon_sym_signed] = ACTIONS(2312),
    [anon_sym_unsigned] = ACTIONS(2312),
    [anon_sym_long] = ACTIONS(2312),
    [anon_sym_short] = ACTIONS(2312),
    [anon_sym_LBRACK] = ACTIONS(2312),
    [anon_sym_static] = ACTIONS(2312),
    [anon_sym_register] = ACTIONS(2312),
    [anon_sym_inline] = ACTIONS(2312),
    [anon_sym___inline] = ACTIONS(2312),
    [anon_sym___inline__] = ACTIONS(2312),
    [anon_sym___forceinline] = ACTIONS(2312),
    [anon_sym_thread_local] = ACTIONS(2312),
    [anon_sym___thread] = ACTIONS(2312),
    [anon_sym_const] = ACTIONS(2312),
    [anon_sym_constexpr] = ACTIONS(2312),
    [anon_sym_volatile] = ACTIONS(2312),
    [anon_sym_restrict] = ACTIONS(2312),
    [anon_sym___restrict__] = ACTIONS(2312),
    [anon_sym__Atomic] = ACTIONS(2312),
    [anon_sym__Noreturn] = ACTIONS(2312),
    [anon_sym_noreturn] = ACTIONS(2312),
    [anon_sym_mutable] = ACTIONS(2312),
    [anon_sym_constinit] = ACTIONS(2312),
    [anon_sym_consteval] = ACTIONS(2312),
    [anon_sym_alignas] = ACTIONS(2312),
    [anon_sym__Alignas] = ACTIONS(2312),
    [sym_primitive_type] = ACTIONS(2312),
    [anon_sym_enum] = ACTIONS(2312),
    [anon_sym_class] = ACTIONS(2312),
    [anon_sym_struct] = ACTIONS(2312),
    [anon_sym_union] = ACTIONS(2312),
    [anon_sym_if] = ACTIONS(2312),
    [anon_sym_switch] = ACTIONS(2312),
    [anon_sym_case] = ACTIONS(2312),
    [anon_sym_default] = ACTIONS(2312),
    [anon_sym_while] = ACTIONS(2312),
    [anon_sym_do] = ACTIONS(2312),
    [anon_sym_for] = ACTIONS(2312),
    [anon_sym_return] = ACTIONS(2312),
    [anon_sym_break] = ACTIONS(2312),
    [anon_sym_continue] = ACTIONS(2312),
    [anon_sym_goto] = ACTIONS(2312),
    [anon_sym_not] = ACTIONS(2312),
    [anon_sym_compl] = ACTIONS(2312),
    [anon_sym_DASH_DASH] = ACTIONS(2314),
    [anon_sym_PLUS_PLUS] = ACTIONS(2314),
    [anon_sym_sizeof] = ACTIONS(2312),
    [anon_sym___alignof__] = ACTIONS(2312),
    [anon_sym___alignof] = ACTIONS(2312),
    [anon_sym__alignof] = ACTIONS(2312),
    [anon_sym_alignof] = ACTIONS(2312),
    [anon_sym__Alignof] = ACTIONS(2312),
    [anon_sym_offsetof] = ACTIONS(2312),
    [anon_sym__Generic] = ACTIONS(2312),
    [anon_sym_asm] = ACTIONS(2312),
    [anon_sym___asm__] = ACTIONS(2312),
    [sym_number_literal] = ACTIONS(2314),
    [anon_sym_L_SQUOTE] = ACTIONS(2314),
    [anon_sym_u_SQUOTE] = ACTIONS(2314),
    [anon_sym_U_SQUOTE] = ACTIONS(2314),
    [anon_sym_u8_SQUOTE] = ACTIONS(2314),
    [anon_sym_SQUOTE] = ACTIONS(2314),
    [anon_sym_L_DQUOTE] = ACTIONS(2314),
    [anon_sym_u_DQUOTE] = ACTIONS(2314),
    [anon_sym_U_DQUOTE] = ACTIONS(2314),
    [anon_sym_u8_DQUOTE] = ACTIONS(2314),
    [anon_sym_DQUOTE] = ACTIONS(2314),
    [sym_true] = ACTIONS(2312),
    [sym_false] = ACTIONS(2312),
    [anon_sym_NULL] = ACTIONS(2312),
    [anon_sym_nullptr] = ACTIONS(2312),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2312),
    [anon_sym_decltype] = ACTIONS(2312),
    [sym_virtual] = ACTIONS(2312),
    [anon_sym_explicit] = ACTIONS(2312),
    [anon_sym_typename] = ACTIONS(2312),
    [anon_sym_template] = ACTIONS(2312),
    [anon_sym_operator] = ACTIONS(2312),
    [anon_sym_try] = ACTIONS(2312),
    [anon_sym_delete] = ACTIONS(2312),
    [anon_sym_throw] = ACTIONS(2312),
    [anon_sym_namespace] = ACTIONS(2312),
    [anon_sym_using] = ACTIONS(2312),
    [anon_sym_static_assert] = ACTIONS(2312),
    [anon_sym_concept] = ACTIONS(2312),
    [anon_sym_co_return] = ACTIONS(2312),
    [anon_sym_co_yield] = ACTIONS(2312),
    [anon_sym_R_DQUOTE] = ACTIONS(2314),
    [anon_sym_LR_DQUOTE] = ACTIONS(2314),
    [anon_sym_uR_DQUOTE] = ACTIONS(2314),
    [anon_sym_UR_DQUOTE] = ACTIONS(2314),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2314),
    [anon_sym_co_await] = ACTIONS(2312),
    [anon_sym_new] = ACTIONS(2312),
    [anon_sym_requires] = ACTIONS(2312),
    [sym_this] = ACTIONS(2312),
    [anon_sym_precise] = ACTIONS(2312),
    [anon_sym_shared] = ACTIONS(2312),
    [anon_sym_groupshared] = ACTIONS(2312),
    [anon_sym_uniform] = ACTIONS(2312),
    [anon_sym_row_major] = ACTIONS(2312),
    [anon_sym_column_major] = ACTIONS(2312),
    [anon_sym_globallycoherent] = ACTIONS(2312),
    [anon_sym_centroid] = ACTIONS(2312),
    [anon_sym_noperspective] = ACTIONS(2312),
    [anon_sym_nointerpolation] = ACTIONS(2312),
    [anon_sym_sample] = ACTIONS(2312),
    [anon_sym_linear] = ACTIONS(2312),
    [anon_sym_snorm] = ACTIONS(2312),
    [anon_sym_unorm] = ACTIONS(2312),
    [anon_sym_point] = ACTIONS(2312),
    [anon_sym_line] = ACTIONS(2312),
    [anon_sym_triangleadj] = ACTIONS(2312),
    [anon_sym_lineadj] = ACTIONS(2312),
    [anon_sym_triangle] = ACTIONS(2312),
  },
  [802] = {
    [ts_builtin_sym_end] = ACTIONS(2538),
    [sym_identifier] = ACTIONS(2536),
    [aux_sym_preproc_include_token1] = ACTIONS(2536),
    [aux_sym_preproc_def_token1] = ACTIONS(2536),
    [aux_sym_preproc_if_token1] = ACTIONS(2536),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2536),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2536),
    [sym_preproc_directive] = ACTIONS(2536),
    [anon_sym_LPAREN2] = ACTIONS(2538),
    [anon_sym_BANG] = ACTIONS(2538),
    [anon_sym_TILDE] = ACTIONS(2538),
    [anon_sym_DASH] = ACTIONS(2536),
    [anon_sym_PLUS] = ACTIONS(2536),
    [anon_sym_STAR] = ACTIONS(2538),
    [anon_sym_AMP_AMP] = ACTIONS(2538),
    [anon_sym_AMP] = ACTIONS(2536),
    [anon_sym___extension__] = ACTIONS(2536),
    [anon_sym_typedef] = ACTIONS(2536),
    [anon_sym_in] = ACTIONS(2536),
    [anon_sym_out] = ACTIONS(2536),
    [anon_sym_inout] = ACTIONS(2536),
    [anon_sym_extern] = ACTIONS(2536),
    [anon_sym___attribute__] = ACTIONS(2536),
    [anon_sym_COLON_COLON] = ACTIONS(2538),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2538),
    [anon_sym___declspec] = ACTIONS(2536),
    [anon_sym___based] = ACTIONS(2536),
    [anon_sym___cdecl] = ACTIONS(2536),
    [anon_sym___clrcall] = ACTIONS(2536),
    [anon_sym___stdcall] = ACTIONS(2536),
    [anon_sym___fastcall] = ACTIONS(2536),
    [anon_sym___thiscall] = ACTIONS(2536),
    [anon_sym___vectorcall] = ACTIONS(2536),
    [anon_sym_LBRACE] = ACTIONS(2538),
    [anon_sym_signed] = ACTIONS(2536),
    [anon_sym_unsigned] = ACTIONS(2536),
    [anon_sym_long] = ACTIONS(2536),
    [anon_sym_short] = ACTIONS(2536),
    [anon_sym_LBRACK] = ACTIONS(2536),
    [anon_sym_static] = ACTIONS(2536),
    [anon_sym_register] = ACTIONS(2536),
    [anon_sym_inline] = ACTIONS(2536),
    [anon_sym___inline] = ACTIONS(2536),
    [anon_sym___inline__] = ACTIONS(2536),
    [anon_sym___forceinline] = ACTIONS(2536),
    [anon_sym_thread_local] = ACTIONS(2536),
    [anon_sym___thread] = ACTIONS(2536),
    [anon_sym_const] = ACTIONS(2536),
    [anon_sym_constexpr] = ACTIONS(2536),
    [anon_sym_volatile] = ACTIONS(2536),
    [anon_sym_restrict] = ACTIONS(2536),
    [anon_sym___restrict__] = ACTIONS(2536),
    [anon_sym__Atomic] = ACTIONS(2536),
    [anon_sym__Noreturn] = ACTIONS(2536),
    [anon_sym_noreturn] = ACTIONS(2536),
    [anon_sym_mutable] = ACTIONS(2536),
    [anon_sym_constinit] = ACTIONS(2536),
    [anon_sym_consteval] = ACTIONS(2536),
    [anon_sym_alignas] = ACTIONS(2536),
    [anon_sym__Alignas] = ACTIONS(2536),
    [sym_primitive_type] = ACTIONS(2536),
    [anon_sym_enum] = ACTIONS(2536),
    [anon_sym_class] = ACTIONS(2536),
    [anon_sym_struct] = ACTIONS(2536),
    [anon_sym_union] = ACTIONS(2536),
    [anon_sym_if] = ACTIONS(2536),
    [anon_sym_switch] = ACTIONS(2536),
    [anon_sym_case] = ACTIONS(2536),
    [anon_sym_default] = ACTIONS(2536),
    [anon_sym_while] = ACTIONS(2536),
    [anon_sym_do] = ACTIONS(2536),
    [anon_sym_for] = ACTIONS(2536),
    [anon_sym_return] = ACTIONS(2536),
    [anon_sym_break] = ACTIONS(2536),
    [anon_sym_continue] = ACTIONS(2536),
    [anon_sym_goto] = ACTIONS(2536),
    [anon_sym_not] = ACTIONS(2536),
    [anon_sym_compl] = ACTIONS(2536),
    [anon_sym_DASH_DASH] = ACTIONS(2538),
    [anon_sym_PLUS_PLUS] = ACTIONS(2538),
    [anon_sym_sizeof] = ACTIONS(2536),
    [anon_sym___alignof__] = ACTIONS(2536),
    [anon_sym___alignof] = ACTIONS(2536),
    [anon_sym__alignof] = ACTIONS(2536),
    [anon_sym_alignof] = ACTIONS(2536),
    [anon_sym__Alignof] = ACTIONS(2536),
    [anon_sym_offsetof] = ACTIONS(2536),
    [anon_sym__Generic] = ACTIONS(2536),
    [anon_sym_asm] = ACTIONS(2536),
    [anon_sym___asm__] = ACTIONS(2536),
    [sym_number_literal] = ACTIONS(2538),
    [anon_sym_L_SQUOTE] = ACTIONS(2538),
    [anon_sym_u_SQUOTE] = ACTIONS(2538),
    [anon_sym_U_SQUOTE] = ACTIONS(2538),
    [anon_sym_u8_SQUOTE] = ACTIONS(2538),
    [anon_sym_SQUOTE] = ACTIONS(2538),
    [anon_sym_L_DQUOTE] = ACTIONS(2538),
    [anon_sym_u_DQUOTE] = ACTIONS(2538),
    [anon_sym_U_DQUOTE] = ACTIONS(2538),
    [anon_sym_u8_DQUOTE] = ACTIONS(2538),
    [anon_sym_DQUOTE] = ACTIONS(2538),
    [sym_true] = ACTIONS(2536),
    [sym_false] = ACTIONS(2536),
    [anon_sym_NULL] = ACTIONS(2536),
    [anon_sym_nullptr] = ACTIONS(2536),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2536),
    [anon_sym_decltype] = ACTIONS(2536),
    [sym_virtual] = ACTIONS(2536),
    [anon_sym_explicit] = ACTIONS(2536),
    [anon_sym_typename] = ACTIONS(2536),
    [anon_sym_template] = ACTIONS(2536),
    [anon_sym_operator] = ACTIONS(2536),
    [anon_sym_try] = ACTIONS(2536),
    [anon_sym_delete] = ACTIONS(2536),
    [anon_sym_throw] = ACTIONS(2536),
    [anon_sym_namespace] = ACTIONS(2536),
    [anon_sym_using] = ACTIONS(2536),
    [anon_sym_static_assert] = ACTIONS(2536),
    [anon_sym_concept] = ACTIONS(2536),
    [anon_sym_co_return] = ACTIONS(2536),
    [anon_sym_co_yield] = ACTIONS(2536),
    [anon_sym_R_DQUOTE] = ACTIONS(2538),
    [anon_sym_LR_DQUOTE] = ACTIONS(2538),
    [anon_sym_uR_DQUOTE] = ACTIONS(2538),
    [anon_sym_UR_DQUOTE] = ACTIONS(2538),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2538),
    [anon_sym_co_await] = ACTIONS(2536),
    [anon_sym_new] = ACTIONS(2536),
    [anon_sym_requires] = ACTIONS(2536),
    [sym_this] = ACTIONS(2536),
    [anon_sym_precise] = ACTIONS(2536),
    [anon_sym_shared] = ACTIONS(2536),
    [anon_sym_groupshared] = ACTIONS(2536),
    [anon_sym_uniform] = ACTIONS(2536),
    [anon_sym_row_major] = ACTIONS(2536),
    [anon_sym_column_major] = ACTIONS(2536),
    [anon_sym_globallycoherent] = ACTIONS(2536),
    [anon_sym_centroid] = ACTIONS(2536),
    [anon_sym_noperspective] = ACTIONS(2536),
    [anon_sym_nointerpolation] = ACTIONS(2536),
    [anon_sym_sample] = ACTIONS(2536),
    [anon_sym_linear] = ACTIONS(2536),
    [anon_sym_snorm] = ACTIONS(2536),
    [anon_sym_unorm] = ACTIONS(2536),
    [anon_sym_point] = ACTIONS(2536),
    [anon_sym_line] = ACTIONS(2536),
    [anon_sym_triangleadj] = ACTIONS(2536),
    [anon_sym_lineadj] = ACTIONS(2536),
    [anon_sym_triangle] = ACTIONS(2536),
  },
  [803] = {
    [sym_preproc_def] = STATE(819),
    [sym_preproc_function_def] = STATE(819),
    [sym_preproc_call] = STATE(819),
    [sym_preproc_if_in_field_declaration_list] = STATE(819),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(819),
    [sym_type_definition] = STATE(819),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(819),
    [sym_field_declaration] = STATE(819),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(819),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(819),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(819),
    [sym_operator_cast_declaration] = STATE(819),
    [sym_constructor_or_destructor_definition] = STATE(819),
    [sym_constructor_or_destructor_declaration] = STATE(819),
    [sym_friend_declaration] = STATE(819),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(819),
    [sym_alias_declaration] = STATE(819),
    [sym_static_assert_declaration] = STATE(819),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(819),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(3027),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [804] = {
    [ts_builtin_sym_end] = ACTIONS(2306),
    [sym_identifier] = ACTIONS(2304),
    [aux_sym_preproc_include_token1] = ACTIONS(2304),
    [aux_sym_preproc_def_token1] = ACTIONS(2304),
    [aux_sym_preproc_if_token1] = ACTIONS(2304),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2304),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2304),
    [sym_preproc_directive] = ACTIONS(2304),
    [anon_sym_LPAREN2] = ACTIONS(2306),
    [anon_sym_BANG] = ACTIONS(2306),
    [anon_sym_TILDE] = ACTIONS(2306),
    [anon_sym_DASH] = ACTIONS(2304),
    [anon_sym_PLUS] = ACTIONS(2304),
    [anon_sym_STAR] = ACTIONS(2306),
    [anon_sym_AMP_AMP] = ACTIONS(2306),
    [anon_sym_AMP] = ACTIONS(2304),
    [anon_sym___extension__] = ACTIONS(2304),
    [anon_sym_typedef] = ACTIONS(2304),
    [anon_sym_in] = ACTIONS(2304),
    [anon_sym_out] = ACTIONS(2304),
    [anon_sym_inout] = ACTIONS(2304),
    [anon_sym_extern] = ACTIONS(2304),
    [anon_sym___attribute__] = ACTIONS(2304),
    [anon_sym_COLON_COLON] = ACTIONS(2306),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2306),
    [anon_sym___declspec] = ACTIONS(2304),
    [anon_sym___based] = ACTIONS(2304),
    [anon_sym___cdecl] = ACTIONS(2304),
    [anon_sym___clrcall] = ACTIONS(2304),
    [anon_sym___stdcall] = ACTIONS(2304),
    [anon_sym___fastcall] = ACTIONS(2304),
    [anon_sym___thiscall] = ACTIONS(2304),
    [anon_sym___vectorcall] = ACTIONS(2304),
    [anon_sym_LBRACE] = ACTIONS(2306),
    [anon_sym_signed] = ACTIONS(2304),
    [anon_sym_unsigned] = ACTIONS(2304),
    [anon_sym_long] = ACTIONS(2304),
    [anon_sym_short] = ACTIONS(2304),
    [anon_sym_LBRACK] = ACTIONS(2304),
    [anon_sym_static] = ACTIONS(2304),
    [anon_sym_register] = ACTIONS(2304),
    [anon_sym_inline] = ACTIONS(2304),
    [anon_sym___inline] = ACTIONS(2304),
    [anon_sym___inline__] = ACTIONS(2304),
    [anon_sym___forceinline] = ACTIONS(2304),
    [anon_sym_thread_local] = ACTIONS(2304),
    [anon_sym___thread] = ACTIONS(2304),
    [anon_sym_const] = ACTIONS(2304),
    [anon_sym_constexpr] = ACTIONS(2304),
    [anon_sym_volatile] = ACTIONS(2304),
    [anon_sym_restrict] = ACTIONS(2304),
    [anon_sym___restrict__] = ACTIONS(2304),
    [anon_sym__Atomic] = ACTIONS(2304),
    [anon_sym__Noreturn] = ACTIONS(2304),
    [anon_sym_noreturn] = ACTIONS(2304),
    [anon_sym_mutable] = ACTIONS(2304),
    [anon_sym_constinit] = ACTIONS(2304),
    [anon_sym_consteval] = ACTIONS(2304),
    [anon_sym_alignas] = ACTIONS(2304),
    [anon_sym__Alignas] = ACTIONS(2304),
    [sym_primitive_type] = ACTIONS(2304),
    [anon_sym_enum] = ACTIONS(2304),
    [anon_sym_class] = ACTIONS(2304),
    [anon_sym_struct] = ACTIONS(2304),
    [anon_sym_union] = ACTIONS(2304),
    [anon_sym_if] = ACTIONS(2304),
    [anon_sym_switch] = ACTIONS(2304),
    [anon_sym_case] = ACTIONS(2304),
    [anon_sym_default] = ACTIONS(2304),
    [anon_sym_while] = ACTIONS(2304),
    [anon_sym_do] = ACTIONS(2304),
    [anon_sym_for] = ACTIONS(2304),
    [anon_sym_return] = ACTIONS(2304),
    [anon_sym_break] = ACTIONS(2304),
    [anon_sym_continue] = ACTIONS(2304),
    [anon_sym_goto] = ACTIONS(2304),
    [anon_sym_not] = ACTIONS(2304),
    [anon_sym_compl] = ACTIONS(2304),
    [anon_sym_DASH_DASH] = ACTIONS(2306),
    [anon_sym_PLUS_PLUS] = ACTIONS(2306),
    [anon_sym_sizeof] = ACTIONS(2304),
    [anon_sym___alignof__] = ACTIONS(2304),
    [anon_sym___alignof] = ACTIONS(2304),
    [anon_sym__alignof] = ACTIONS(2304),
    [anon_sym_alignof] = ACTIONS(2304),
    [anon_sym__Alignof] = ACTIONS(2304),
    [anon_sym_offsetof] = ACTIONS(2304),
    [anon_sym__Generic] = ACTIONS(2304),
    [anon_sym_asm] = ACTIONS(2304),
    [anon_sym___asm__] = ACTIONS(2304),
    [sym_number_literal] = ACTIONS(2306),
    [anon_sym_L_SQUOTE] = ACTIONS(2306),
    [anon_sym_u_SQUOTE] = ACTIONS(2306),
    [anon_sym_U_SQUOTE] = ACTIONS(2306),
    [anon_sym_u8_SQUOTE] = ACTIONS(2306),
    [anon_sym_SQUOTE] = ACTIONS(2306),
    [anon_sym_L_DQUOTE] = ACTIONS(2306),
    [anon_sym_u_DQUOTE] = ACTIONS(2306),
    [anon_sym_U_DQUOTE] = ACTIONS(2306),
    [anon_sym_u8_DQUOTE] = ACTIONS(2306),
    [anon_sym_DQUOTE] = ACTIONS(2306),
    [sym_true] = ACTIONS(2304),
    [sym_false] = ACTIONS(2304),
    [anon_sym_NULL] = ACTIONS(2304),
    [anon_sym_nullptr] = ACTIONS(2304),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2304),
    [anon_sym_decltype] = ACTIONS(2304),
    [sym_virtual] = ACTIONS(2304),
    [anon_sym_explicit] = ACTIONS(2304),
    [anon_sym_typename] = ACTIONS(2304),
    [anon_sym_template] = ACTIONS(2304),
    [anon_sym_operator] = ACTIONS(2304),
    [anon_sym_try] = ACTIONS(2304),
    [anon_sym_delete] = ACTIONS(2304),
    [anon_sym_throw] = ACTIONS(2304),
    [anon_sym_namespace] = ACTIONS(2304),
    [anon_sym_using] = ACTIONS(2304),
    [anon_sym_static_assert] = ACTIONS(2304),
    [anon_sym_concept] = ACTIONS(2304),
    [anon_sym_co_return] = ACTIONS(2304),
    [anon_sym_co_yield] = ACTIONS(2304),
    [anon_sym_R_DQUOTE] = ACTIONS(2306),
    [anon_sym_LR_DQUOTE] = ACTIONS(2306),
    [anon_sym_uR_DQUOTE] = ACTIONS(2306),
    [anon_sym_UR_DQUOTE] = ACTIONS(2306),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2306),
    [anon_sym_co_await] = ACTIONS(2304),
    [anon_sym_new] = ACTIONS(2304),
    [anon_sym_requires] = ACTIONS(2304),
    [sym_this] = ACTIONS(2304),
    [anon_sym_precise] = ACTIONS(2304),
    [anon_sym_shared] = ACTIONS(2304),
    [anon_sym_groupshared] = ACTIONS(2304),
    [anon_sym_uniform] = ACTIONS(2304),
    [anon_sym_row_major] = ACTIONS(2304),
    [anon_sym_column_major] = ACTIONS(2304),
    [anon_sym_globallycoherent] = ACTIONS(2304),
    [anon_sym_centroid] = ACTIONS(2304),
    [anon_sym_noperspective] = ACTIONS(2304),
    [anon_sym_nointerpolation] = ACTIONS(2304),
    [anon_sym_sample] = ACTIONS(2304),
    [anon_sym_linear] = ACTIONS(2304),
    [anon_sym_snorm] = ACTIONS(2304),
    [anon_sym_unorm] = ACTIONS(2304),
    [anon_sym_point] = ACTIONS(2304),
    [anon_sym_line] = ACTIONS(2304),
    [anon_sym_triangleadj] = ACTIONS(2304),
    [anon_sym_lineadj] = ACTIONS(2304),
    [anon_sym_triangle] = ACTIONS(2304),
  },
  [805] = {
    [ts_builtin_sym_end] = ACTIONS(2366),
    [sym_identifier] = ACTIONS(2364),
    [aux_sym_preproc_include_token1] = ACTIONS(2364),
    [aux_sym_preproc_def_token1] = ACTIONS(2364),
    [aux_sym_preproc_if_token1] = ACTIONS(2364),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2364),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2364),
    [sym_preproc_directive] = ACTIONS(2364),
    [anon_sym_LPAREN2] = ACTIONS(2366),
    [anon_sym_BANG] = ACTIONS(2366),
    [anon_sym_TILDE] = ACTIONS(2366),
    [anon_sym_DASH] = ACTIONS(2364),
    [anon_sym_PLUS] = ACTIONS(2364),
    [anon_sym_STAR] = ACTIONS(2366),
    [anon_sym_AMP_AMP] = ACTIONS(2366),
    [anon_sym_AMP] = ACTIONS(2364),
    [anon_sym___extension__] = ACTIONS(2364),
    [anon_sym_typedef] = ACTIONS(2364),
    [anon_sym_in] = ACTIONS(2364),
    [anon_sym_out] = ACTIONS(2364),
    [anon_sym_inout] = ACTIONS(2364),
    [anon_sym_extern] = ACTIONS(2364),
    [anon_sym___attribute__] = ACTIONS(2364),
    [anon_sym_COLON_COLON] = ACTIONS(2366),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2366),
    [anon_sym___declspec] = ACTIONS(2364),
    [anon_sym___based] = ACTIONS(2364),
    [anon_sym___cdecl] = ACTIONS(2364),
    [anon_sym___clrcall] = ACTIONS(2364),
    [anon_sym___stdcall] = ACTIONS(2364),
    [anon_sym___fastcall] = ACTIONS(2364),
    [anon_sym___thiscall] = ACTIONS(2364),
    [anon_sym___vectorcall] = ACTIONS(2364),
    [anon_sym_LBRACE] = ACTIONS(2366),
    [anon_sym_signed] = ACTIONS(2364),
    [anon_sym_unsigned] = ACTIONS(2364),
    [anon_sym_long] = ACTIONS(2364),
    [anon_sym_short] = ACTIONS(2364),
    [anon_sym_LBRACK] = ACTIONS(2364),
    [anon_sym_static] = ACTIONS(2364),
    [anon_sym_register] = ACTIONS(2364),
    [anon_sym_inline] = ACTIONS(2364),
    [anon_sym___inline] = ACTIONS(2364),
    [anon_sym___inline__] = ACTIONS(2364),
    [anon_sym___forceinline] = ACTIONS(2364),
    [anon_sym_thread_local] = ACTIONS(2364),
    [anon_sym___thread] = ACTIONS(2364),
    [anon_sym_const] = ACTIONS(2364),
    [anon_sym_constexpr] = ACTIONS(2364),
    [anon_sym_volatile] = ACTIONS(2364),
    [anon_sym_restrict] = ACTIONS(2364),
    [anon_sym___restrict__] = ACTIONS(2364),
    [anon_sym__Atomic] = ACTIONS(2364),
    [anon_sym__Noreturn] = ACTIONS(2364),
    [anon_sym_noreturn] = ACTIONS(2364),
    [anon_sym_mutable] = ACTIONS(2364),
    [anon_sym_constinit] = ACTIONS(2364),
    [anon_sym_consteval] = ACTIONS(2364),
    [anon_sym_alignas] = ACTIONS(2364),
    [anon_sym__Alignas] = ACTIONS(2364),
    [sym_primitive_type] = ACTIONS(2364),
    [anon_sym_enum] = ACTIONS(2364),
    [anon_sym_class] = ACTIONS(2364),
    [anon_sym_struct] = ACTIONS(2364),
    [anon_sym_union] = ACTIONS(2364),
    [anon_sym_if] = ACTIONS(2364),
    [anon_sym_switch] = ACTIONS(2364),
    [anon_sym_case] = ACTIONS(2364),
    [anon_sym_default] = ACTIONS(2364),
    [anon_sym_while] = ACTIONS(2364),
    [anon_sym_do] = ACTIONS(2364),
    [anon_sym_for] = ACTIONS(2364),
    [anon_sym_return] = ACTIONS(2364),
    [anon_sym_break] = ACTIONS(2364),
    [anon_sym_continue] = ACTIONS(2364),
    [anon_sym_goto] = ACTIONS(2364),
    [anon_sym_not] = ACTIONS(2364),
    [anon_sym_compl] = ACTIONS(2364),
    [anon_sym_DASH_DASH] = ACTIONS(2366),
    [anon_sym_PLUS_PLUS] = ACTIONS(2366),
    [anon_sym_sizeof] = ACTIONS(2364),
    [anon_sym___alignof__] = ACTIONS(2364),
    [anon_sym___alignof] = ACTIONS(2364),
    [anon_sym__alignof] = ACTIONS(2364),
    [anon_sym_alignof] = ACTIONS(2364),
    [anon_sym__Alignof] = ACTIONS(2364),
    [anon_sym_offsetof] = ACTIONS(2364),
    [anon_sym__Generic] = ACTIONS(2364),
    [anon_sym_asm] = ACTIONS(2364),
    [anon_sym___asm__] = ACTIONS(2364),
    [sym_number_literal] = ACTIONS(2366),
    [anon_sym_L_SQUOTE] = ACTIONS(2366),
    [anon_sym_u_SQUOTE] = ACTIONS(2366),
    [anon_sym_U_SQUOTE] = ACTIONS(2366),
    [anon_sym_u8_SQUOTE] = ACTIONS(2366),
    [anon_sym_SQUOTE] = ACTIONS(2366),
    [anon_sym_L_DQUOTE] = ACTIONS(2366),
    [anon_sym_u_DQUOTE] = ACTIONS(2366),
    [anon_sym_U_DQUOTE] = ACTIONS(2366),
    [anon_sym_u8_DQUOTE] = ACTIONS(2366),
    [anon_sym_DQUOTE] = ACTIONS(2366),
    [sym_true] = ACTIONS(2364),
    [sym_false] = ACTIONS(2364),
    [anon_sym_NULL] = ACTIONS(2364),
    [anon_sym_nullptr] = ACTIONS(2364),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2364),
    [anon_sym_decltype] = ACTIONS(2364),
    [sym_virtual] = ACTIONS(2364),
    [anon_sym_explicit] = ACTIONS(2364),
    [anon_sym_typename] = ACTIONS(2364),
    [anon_sym_template] = ACTIONS(2364),
    [anon_sym_operator] = ACTIONS(2364),
    [anon_sym_try] = ACTIONS(2364),
    [anon_sym_delete] = ACTIONS(2364),
    [anon_sym_throw] = ACTIONS(2364),
    [anon_sym_namespace] = ACTIONS(2364),
    [anon_sym_using] = ACTIONS(2364),
    [anon_sym_static_assert] = ACTIONS(2364),
    [anon_sym_concept] = ACTIONS(2364),
    [anon_sym_co_return] = ACTIONS(2364),
    [anon_sym_co_yield] = ACTIONS(2364),
    [anon_sym_R_DQUOTE] = ACTIONS(2366),
    [anon_sym_LR_DQUOTE] = ACTIONS(2366),
    [anon_sym_uR_DQUOTE] = ACTIONS(2366),
    [anon_sym_UR_DQUOTE] = ACTIONS(2366),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2366),
    [anon_sym_co_await] = ACTIONS(2364),
    [anon_sym_new] = ACTIONS(2364),
    [anon_sym_requires] = ACTIONS(2364),
    [sym_this] = ACTIONS(2364),
    [anon_sym_precise] = ACTIONS(2364),
    [anon_sym_shared] = ACTIONS(2364),
    [anon_sym_groupshared] = ACTIONS(2364),
    [anon_sym_uniform] = ACTIONS(2364),
    [anon_sym_row_major] = ACTIONS(2364),
    [anon_sym_column_major] = ACTIONS(2364),
    [anon_sym_globallycoherent] = ACTIONS(2364),
    [anon_sym_centroid] = ACTIONS(2364),
    [anon_sym_noperspective] = ACTIONS(2364),
    [anon_sym_nointerpolation] = ACTIONS(2364),
    [anon_sym_sample] = ACTIONS(2364),
    [anon_sym_linear] = ACTIONS(2364),
    [anon_sym_snorm] = ACTIONS(2364),
    [anon_sym_unorm] = ACTIONS(2364),
    [anon_sym_point] = ACTIONS(2364),
    [anon_sym_line] = ACTIONS(2364),
    [anon_sym_triangleadj] = ACTIONS(2364),
    [anon_sym_lineadj] = ACTIONS(2364),
    [anon_sym_triangle] = ACTIONS(2364),
  },
  [806] = {
    [ts_builtin_sym_end] = ACTIONS(2450),
    [sym_identifier] = ACTIONS(2448),
    [aux_sym_preproc_include_token1] = ACTIONS(2448),
    [aux_sym_preproc_def_token1] = ACTIONS(2448),
    [aux_sym_preproc_if_token1] = ACTIONS(2448),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2448),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2448),
    [sym_preproc_directive] = ACTIONS(2448),
    [anon_sym_LPAREN2] = ACTIONS(2450),
    [anon_sym_BANG] = ACTIONS(2450),
    [anon_sym_TILDE] = ACTIONS(2450),
    [anon_sym_DASH] = ACTIONS(2448),
    [anon_sym_PLUS] = ACTIONS(2448),
    [anon_sym_STAR] = ACTIONS(2450),
    [anon_sym_AMP_AMP] = ACTIONS(2450),
    [anon_sym_AMP] = ACTIONS(2448),
    [anon_sym___extension__] = ACTIONS(2448),
    [anon_sym_typedef] = ACTIONS(2448),
    [anon_sym_in] = ACTIONS(2448),
    [anon_sym_out] = ACTIONS(2448),
    [anon_sym_inout] = ACTIONS(2448),
    [anon_sym_extern] = ACTIONS(2448),
    [anon_sym___attribute__] = ACTIONS(2448),
    [anon_sym_COLON_COLON] = ACTIONS(2450),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2450),
    [anon_sym___declspec] = ACTIONS(2448),
    [anon_sym___based] = ACTIONS(2448),
    [anon_sym___cdecl] = ACTIONS(2448),
    [anon_sym___clrcall] = ACTIONS(2448),
    [anon_sym___stdcall] = ACTIONS(2448),
    [anon_sym___fastcall] = ACTIONS(2448),
    [anon_sym___thiscall] = ACTIONS(2448),
    [anon_sym___vectorcall] = ACTIONS(2448),
    [anon_sym_LBRACE] = ACTIONS(2450),
    [anon_sym_signed] = ACTIONS(2448),
    [anon_sym_unsigned] = ACTIONS(2448),
    [anon_sym_long] = ACTIONS(2448),
    [anon_sym_short] = ACTIONS(2448),
    [anon_sym_LBRACK] = ACTIONS(2448),
    [anon_sym_static] = ACTIONS(2448),
    [anon_sym_register] = ACTIONS(2448),
    [anon_sym_inline] = ACTIONS(2448),
    [anon_sym___inline] = ACTIONS(2448),
    [anon_sym___inline__] = ACTIONS(2448),
    [anon_sym___forceinline] = ACTIONS(2448),
    [anon_sym_thread_local] = ACTIONS(2448),
    [anon_sym___thread] = ACTIONS(2448),
    [anon_sym_const] = ACTIONS(2448),
    [anon_sym_constexpr] = ACTIONS(2448),
    [anon_sym_volatile] = ACTIONS(2448),
    [anon_sym_restrict] = ACTIONS(2448),
    [anon_sym___restrict__] = ACTIONS(2448),
    [anon_sym__Atomic] = ACTIONS(2448),
    [anon_sym__Noreturn] = ACTIONS(2448),
    [anon_sym_noreturn] = ACTIONS(2448),
    [anon_sym_mutable] = ACTIONS(2448),
    [anon_sym_constinit] = ACTIONS(2448),
    [anon_sym_consteval] = ACTIONS(2448),
    [anon_sym_alignas] = ACTIONS(2448),
    [anon_sym__Alignas] = ACTIONS(2448),
    [sym_primitive_type] = ACTIONS(2448),
    [anon_sym_enum] = ACTIONS(2448),
    [anon_sym_class] = ACTIONS(2448),
    [anon_sym_struct] = ACTIONS(2448),
    [anon_sym_union] = ACTIONS(2448),
    [anon_sym_if] = ACTIONS(2448),
    [anon_sym_switch] = ACTIONS(2448),
    [anon_sym_case] = ACTIONS(2448),
    [anon_sym_default] = ACTIONS(2448),
    [anon_sym_while] = ACTIONS(2448),
    [anon_sym_do] = ACTIONS(2448),
    [anon_sym_for] = ACTIONS(2448),
    [anon_sym_return] = ACTIONS(2448),
    [anon_sym_break] = ACTIONS(2448),
    [anon_sym_continue] = ACTIONS(2448),
    [anon_sym_goto] = ACTIONS(2448),
    [anon_sym_not] = ACTIONS(2448),
    [anon_sym_compl] = ACTIONS(2448),
    [anon_sym_DASH_DASH] = ACTIONS(2450),
    [anon_sym_PLUS_PLUS] = ACTIONS(2450),
    [anon_sym_sizeof] = ACTIONS(2448),
    [anon_sym___alignof__] = ACTIONS(2448),
    [anon_sym___alignof] = ACTIONS(2448),
    [anon_sym__alignof] = ACTIONS(2448),
    [anon_sym_alignof] = ACTIONS(2448),
    [anon_sym__Alignof] = ACTIONS(2448),
    [anon_sym_offsetof] = ACTIONS(2448),
    [anon_sym__Generic] = ACTIONS(2448),
    [anon_sym_asm] = ACTIONS(2448),
    [anon_sym___asm__] = ACTIONS(2448),
    [sym_number_literal] = ACTIONS(2450),
    [anon_sym_L_SQUOTE] = ACTIONS(2450),
    [anon_sym_u_SQUOTE] = ACTIONS(2450),
    [anon_sym_U_SQUOTE] = ACTIONS(2450),
    [anon_sym_u8_SQUOTE] = ACTIONS(2450),
    [anon_sym_SQUOTE] = ACTIONS(2450),
    [anon_sym_L_DQUOTE] = ACTIONS(2450),
    [anon_sym_u_DQUOTE] = ACTIONS(2450),
    [anon_sym_U_DQUOTE] = ACTIONS(2450),
    [anon_sym_u8_DQUOTE] = ACTIONS(2450),
    [anon_sym_DQUOTE] = ACTIONS(2450),
    [sym_true] = ACTIONS(2448),
    [sym_false] = ACTIONS(2448),
    [anon_sym_NULL] = ACTIONS(2448),
    [anon_sym_nullptr] = ACTIONS(2448),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2448),
    [anon_sym_decltype] = ACTIONS(2448),
    [sym_virtual] = ACTIONS(2448),
    [anon_sym_explicit] = ACTIONS(2448),
    [anon_sym_typename] = ACTIONS(2448),
    [anon_sym_template] = ACTIONS(2448),
    [anon_sym_operator] = ACTIONS(2448),
    [anon_sym_try] = ACTIONS(2448),
    [anon_sym_delete] = ACTIONS(2448),
    [anon_sym_throw] = ACTIONS(2448),
    [anon_sym_namespace] = ACTIONS(2448),
    [anon_sym_using] = ACTIONS(2448),
    [anon_sym_static_assert] = ACTIONS(2448),
    [anon_sym_concept] = ACTIONS(2448),
    [anon_sym_co_return] = ACTIONS(2448),
    [anon_sym_co_yield] = ACTIONS(2448),
    [anon_sym_R_DQUOTE] = ACTIONS(2450),
    [anon_sym_LR_DQUOTE] = ACTIONS(2450),
    [anon_sym_uR_DQUOTE] = ACTIONS(2450),
    [anon_sym_UR_DQUOTE] = ACTIONS(2450),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2450),
    [anon_sym_co_await] = ACTIONS(2448),
    [anon_sym_new] = ACTIONS(2448),
    [anon_sym_requires] = ACTIONS(2448),
    [sym_this] = ACTIONS(2448),
    [anon_sym_precise] = ACTIONS(2448),
    [anon_sym_shared] = ACTIONS(2448),
    [anon_sym_groupshared] = ACTIONS(2448),
    [anon_sym_uniform] = ACTIONS(2448),
    [anon_sym_row_major] = ACTIONS(2448),
    [anon_sym_column_major] = ACTIONS(2448),
    [anon_sym_globallycoherent] = ACTIONS(2448),
    [anon_sym_centroid] = ACTIONS(2448),
    [anon_sym_noperspective] = ACTIONS(2448),
    [anon_sym_nointerpolation] = ACTIONS(2448),
    [anon_sym_sample] = ACTIONS(2448),
    [anon_sym_linear] = ACTIONS(2448),
    [anon_sym_snorm] = ACTIONS(2448),
    [anon_sym_unorm] = ACTIONS(2448),
    [anon_sym_point] = ACTIONS(2448),
    [anon_sym_line] = ACTIONS(2448),
    [anon_sym_triangleadj] = ACTIONS(2448),
    [anon_sym_lineadj] = ACTIONS(2448),
    [anon_sym_triangle] = ACTIONS(2448),
  },
  [807] = {
    [ts_builtin_sym_end] = ACTIONS(2346),
    [sym_identifier] = ACTIONS(2344),
    [aux_sym_preproc_include_token1] = ACTIONS(2344),
    [aux_sym_preproc_def_token1] = ACTIONS(2344),
    [aux_sym_preproc_if_token1] = ACTIONS(2344),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2344),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2344),
    [sym_preproc_directive] = ACTIONS(2344),
    [anon_sym_LPAREN2] = ACTIONS(2346),
    [anon_sym_BANG] = ACTIONS(2346),
    [anon_sym_TILDE] = ACTIONS(2346),
    [anon_sym_DASH] = ACTIONS(2344),
    [anon_sym_PLUS] = ACTIONS(2344),
    [anon_sym_STAR] = ACTIONS(2346),
    [anon_sym_AMP_AMP] = ACTIONS(2346),
    [anon_sym_AMP] = ACTIONS(2344),
    [anon_sym___extension__] = ACTIONS(2344),
    [anon_sym_typedef] = ACTIONS(2344),
    [anon_sym_in] = ACTIONS(2344),
    [anon_sym_out] = ACTIONS(2344),
    [anon_sym_inout] = ACTIONS(2344),
    [anon_sym_extern] = ACTIONS(2344),
    [anon_sym___attribute__] = ACTIONS(2344),
    [anon_sym_COLON_COLON] = ACTIONS(2346),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2346),
    [anon_sym___declspec] = ACTIONS(2344),
    [anon_sym___based] = ACTIONS(2344),
    [anon_sym___cdecl] = ACTIONS(2344),
    [anon_sym___clrcall] = ACTIONS(2344),
    [anon_sym___stdcall] = ACTIONS(2344),
    [anon_sym___fastcall] = ACTIONS(2344),
    [anon_sym___thiscall] = ACTIONS(2344),
    [anon_sym___vectorcall] = ACTIONS(2344),
    [anon_sym_LBRACE] = ACTIONS(2346),
    [anon_sym_signed] = ACTIONS(2344),
    [anon_sym_unsigned] = ACTIONS(2344),
    [anon_sym_long] = ACTIONS(2344),
    [anon_sym_short] = ACTIONS(2344),
    [anon_sym_LBRACK] = ACTIONS(2344),
    [anon_sym_static] = ACTIONS(2344),
    [anon_sym_register] = ACTIONS(2344),
    [anon_sym_inline] = ACTIONS(2344),
    [anon_sym___inline] = ACTIONS(2344),
    [anon_sym___inline__] = ACTIONS(2344),
    [anon_sym___forceinline] = ACTIONS(2344),
    [anon_sym_thread_local] = ACTIONS(2344),
    [anon_sym___thread] = ACTIONS(2344),
    [anon_sym_const] = ACTIONS(2344),
    [anon_sym_constexpr] = ACTIONS(2344),
    [anon_sym_volatile] = ACTIONS(2344),
    [anon_sym_restrict] = ACTIONS(2344),
    [anon_sym___restrict__] = ACTIONS(2344),
    [anon_sym__Atomic] = ACTIONS(2344),
    [anon_sym__Noreturn] = ACTIONS(2344),
    [anon_sym_noreturn] = ACTIONS(2344),
    [anon_sym_mutable] = ACTIONS(2344),
    [anon_sym_constinit] = ACTIONS(2344),
    [anon_sym_consteval] = ACTIONS(2344),
    [anon_sym_alignas] = ACTIONS(2344),
    [anon_sym__Alignas] = ACTIONS(2344),
    [sym_primitive_type] = ACTIONS(2344),
    [anon_sym_enum] = ACTIONS(2344),
    [anon_sym_class] = ACTIONS(2344),
    [anon_sym_struct] = ACTIONS(2344),
    [anon_sym_union] = ACTIONS(2344),
    [anon_sym_if] = ACTIONS(2344),
    [anon_sym_switch] = ACTIONS(2344),
    [anon_sym_case] = ACTIONS(2344),
    [anon_sym_default] = ACTIONS(2344),
    [anon_sym_while] = ACTIONS(2344),
    [anon_sym_do] = ACTIONS(2344),
    [anon_sym_for] = ACTIONS(2344),
    [anon_sym_return] = ACTIONS(2344),
    [anon_sym_break] = ACTIONS(2344),
    [anon_sym_continue] = ACTIONS(2344),
    [anon_sym_goto] = ACTIONS(2344),
    [anon_sym_not] = ACTIONS(2344),
    [anon_sym_compl] = ACTIONS(2344),
    [anon_sym_DASH_DASH] = ACTIONS(2346),
    [anon_sym_PLUS_PLUS] = ACTIONS(2346),
    [anon_sym_sizeof] = ACTIONS(2344),
    [anon_sym___alignof__] = ACTIONS(2344),
    [anon_sym___alignof] = ACTIONS(2344),
    [anon_sym__alignof] = ACTIONS(2344),
    [anon_sym_alignof] = ACTIONS(2344),
    [anon_sym__Alignof] = ACTIONS(2344),
    [anon_sym_offsetof] = ACTIONS(2344),
    [anon_sym__Generic] = ACTIONS(2344),
    [anon_sym_asm] = ACTIONS(2344),
    [anon_sym___asm__] = ACTIONS(2344),
    [sym_number_literal] = ACTIONS(2346),
    [anon_sym_L_SQUOTE] = ACTIONS(2346),
    [anon_sym_u_SQUOTE] = ACTIONS(2346),
    [anon_sym_U_SQUOTE] = ACTIONS(2346),
    [anon_sym_u8_SQUOTE] = ACTIONS(2346),
    [anon_sym_SQUOTE] = ACTIONS(2346),
    [anon_sym_L_DQUOTE] = ACTIONS(2346),
    [anon_sym_u_DQUOTE] = ACTIONS(2346),
    [anon_sym_U_DQUOTE] = ACTIONS(2346),
    [anon_sym_u8_DQUOTE] = ACTIONS(2346),
    [anon_sym_DQUOTE] = ACTIONS(2346),
    [sym_true] = ACTIONS(2344),
    [sym_false] = ACTIONS(2344),
    [anon_sym_NULL] = ACTIONS(2344),
    [anon_sym_nullptr] = ACTIONS(2344),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2344),
    [anon_sym_decltype] = ACTIONS(2344),
    [sym_virtual] = ACTIONS(2344),
    [anon_sym_explicit] = ACTIONS(2344),
    [anon_sym_typename] = ACTIONS(2344),
    [anon_sym_template] = ACTIONS(2344),
    [anon_sym_operator] = ACTIONS(2344),
    [anon_sym_try] = ACTIONS(2344),
    [anon_sym_delete] = ACTIONS(2344),
    [anon_sym_throw] = ACTIONS(2344),
    [anon_sym_namespace] = ACTIONS(2344),
    [anon_sym_using] = ACTIONS(2344),
    [anon_sym_static_assert] = ACTIONS(2344),
    [anon_sym_concept] = ACTIONS(2344),
    [anon_sym_co_return] = ACTIONS(2344),
    [anon_sym_co_yield] = ACTIONS(2344),
    [anon_sym_R_DQUOTE] = ACTIONS(2346),
    [anon_sym_LR_DQUOTE] = ACTIONS(2346),
    [anon_sym_uR_DQUOTE] = ACTIONS(2346),
    [anon_sym_UR_DQUOTE] = ACTIONS(2346),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2346),
    [anon_sym_co_await] = ACTIONS(2344),
    [anon_sym_new] = ACTIONS(2344),
    [anon_sym_requires] = ACTIONS(2344),
    [sym_this] = ACTIONS(2344),
    [anon_sym_precise] = ACTIONS(2344),
    [anon_sym_shared] = ACTIONS(2344),
    [anon_sym_groupshared] = ACTIONS(2344),
    [anon_sym_uniform] = ACTIONS(2344),
    [anon_sym_row_major] = ACTIONS(2344),
    [anon_sym_column_major] = ACTIONS(2344),
    [anon_sym_globallycoherent] = ACTIONS(2344),
    [anon_sym_centroid] = ACTIONS(2344),
    [anon_sym_noperspective] = ACTIONS(2344),
    [anon_sym_nointerpolation] = ACTIONS(2344),
    [anon_sym_sample] = ACTIONS(2344),
    [anon_sym_linear] = ACTIONS(2344),
    [anon_sym_snorm] = ACTIONS(2344),
    [anon_sym_unorm] = ACTIONS(2344),
    [anon_sym_point] = ACTIONS(2344),
    [anon_sym_line] = ACTIONS(2344),
    [anon_sym_triangleadj] = ACTIONS(2344),
    [anon_sym_lineadj] = ACTIONS(2344),
    [anon_sym_triangle] = ACTIONS(2344),
  },
  [808] = {
    [ts_builtin_sym_end] = ACTIONS(2446),
    [sym_identifier] = ACTIONS(2444),
    [aux_sym_preproc_include_token1] = ACTIONS(2444),
    [aux_sym_preproc_def_token1] = ACTIONS(2444),
    [aux_sym_preproc_if_token1] = ACTIONS(2444),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2444),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2444),
    [sym_preproc_directive] = ACTIONS(2444),
    [anon_sym_LPAREN2] = ACTIONS(2446),
    [anon_sym_BANG] = ACTIONS(2446),
    [anon_sym_TILDE] = ACTIONS(2446),
    [anon_sym_DASH] = ACTIONS(2444),
    [anon_sym_PLUS] = ACTIONS(2444),
    [anon_sym_STAR] = ACTIONS(2446),
    [anon_sym_AMP_AMP] = ACTIONS(2446),
    [anon_sym_AMP] = ACTIONS(2444),
    [anon_sym___extension__] = ACTIONS(2444),
    [anon_sym_typedef] = ACTIONS(2444),
    [anon_sym_in] = ACTIONS(2444),
    [anon_sym_out] = ACTIONS(2444),
    [anon_sym_inout] = ACTIONS(2444),
    [anon_sym_extern] = ACTIONS(2444),
    [anon_sym___attribute__] = ACTIONS(2444),
    [anon_sym_COLON_COLON] = ACTIONS(2446),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2446),
    [anon_sym___declspec] = ACTIONS(2444),
    [anon_sym___based] = ACTIONS(2444),
    [anon_sym___cdecl] = ACTIONS(2444),
    [anon_sym___clrcall] = ACTIONS(2444),
    [anon_sym___stdcall] = ACTIONS(2444),
    [anon_sym___fastcall] = ACTIONS(2444),
    [anon_sym___thiscall] = ACTIONS(2444),
    [anon_sym___vectorcall] = ACTIONS(2444),
    [anon_sym_LBRACE] = ACTIONS(2446),
    [anon_sym_signed] = ACTIONS(2444),
    [anon_sym_unsigned] = ACTIONS(2444),
    [anon_sym_long] = ACTIONS(2444),
    [anon_sym_short] = ACTIONS(2444),
    [anon_sym_LBRACK] = ACTIONS(2444),
    [anon_sym_static] = ACTIONS(2444),
    [anon_sym_register] = ACTIONS(2444),
    [anon_sym_inline] = ACTIONS(2444),
    [anon_sym___inline] = ACTIONS(2444),
    [anon_sym___inline__] = ACTIONS(2444),
    [anon_sym___forceinline] = ACTIONS(2444),
    [anon_sym_thread_local] = ACTIONS(2444),
    [anon_sym___thread] = ACTIONS(2444),
    [anon_sym_const] = ACTIONS(2444),
    [anon_sym_constexpr] = ACTIONS(2444),
    [anon_sym_volatile] = ACTIONS(2444),
    [anon_sym_restrict] = ACTIONS(2444),
    [anon_sym___restrict__] = ACTIONS(2444),
    [anon_sym__Atomic] = ACTIONS(2444),
    [anon_sym__Noreturn] = ACTIONS(2444),
    [anon_sym_noreturn] = ACTIONS(2444),
    [anon_sym_mutable] = ACTIONS(2444),
    [anon_sym_constinit] = ACTIONS(2444),
    [anon_sym_consteval] = ACTIONS(2444),
    [anon_sym_alignas] = ACTIONS(2444),
    [anon_sym__Alignas] = ACTIONS(2444),
    [sym_primitive_type] = ACTIONS(2444),
    [anon_sym_enum] = ACTIONS(2444),
    [anon_sym_class] = ACTIONS(2444),
    [anon_sym_struct] = ACTIONS(2444),
    [anon_sym_union] = ACTIONS(2444),
    [anon_sym_if] = ACTIONS(2444),
    [anon_sym_switch] = ACTIONS(2444),
    [anon_sym_case] = ACTIONS(2444),
    [anon_sym_default] = ACTIONS(2444),
    [anon_sym_while] = ACTIONS(2444),
    [anon_sym_do] = ACTIONS(2444),
    [anon_sym_for] = ACTIONS(2444),
    [anon_sym_return] = ACTIONS(2444),
    [anon_sym_break] = ACTIONS(2444),
    [anon_sym_continue] = ACTIONS(2444),
    [anon_sym_goto] = ACTIONS(2444),
    [anon_sym_not] = ACTIONS(2444),
    [anon_sym_compl] = ACTIONS(2444),
    [anon_sym_DASH_DASH] = ACTIONS(2446),
    [anon_sym_PLUS_PLUS] = ACTIONS(2446),
    [anon_sym_sizeof] = ACTIONS(2444),
    [anon_sym___alignof__] = ACTIONS(2444),
    [anon_sym___alignof] = ACTIONS(2444),
    [anon_sym__alignof] = ACTIONS(2444),
    [anon_sym_alignof] = ACTIONS(2444),
    [anon_sym__Alignof] = ACTIONS(2444),
    [anon_sym_offsetof] = ACTIONS(2444),
    [anon_sym__Generic] = ACTIONS(2444),
    [anon_sym_asm] = ACTIONS(2444),
    [anon_sym___asm__] = ACTIONS(2444),
    [sym_number_literal] = ACTIONS(2446),
    [anon_sym_L_SQUOTE] = ACTIONS(2446),
    [anon_sym_u_SQUOTE] = ACTIONS(2446),
    [anon_sym_U_SQUOTE] = ACTIONS(2446),
    [anon_sym_u8_SQUOTE] = ACTIONS(2446),
    [anon_sym_SQUOTE] = ACTIONS(2446),
    [anon_sym_L_DQUOTE] = ACTIONS(2446),
    [anon_sym_u_DQUOTE] = ACTIONS(2446),
    [anon_sym_U_DQUOTE] = ACTIONS(2446),
    [anon_sym_u8_DQUOTE] = ACTIONS(2446),
    [anon_sym_DQUOTE] = ACTIONS(2446),
    [sym_true] = ACTIONS(2444),
    [sym_false] = ACTIONS(2444),
    [anon_sym_NULL] = ACTIONS(2444),
    [anon_sym_nullptr] = ACTIONS(2444),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2444),
    [anon_sym_decltype] = ACTIONS(2444),
    [sym_virtual] = ACTIONS(2444),
    [anon_sym_explicit] = ACTIONS(2444),
    [anon_sym_typename] = ACTIONS(2444),
    [anon_sym_template] = ACTIONS(2444),
    [anon_sym_operator] = ACTIONS(2444),
    [anon_sym_try] = ACTIONS(2444),
    [anon_sym_delete] = ACTIONS(2444),
    [anon_sym_throw] = ACTIONS(2444),
    [anon_sym_namespace] = ACTIONS(2444),
    [anon_sym_using] = ACTIONS(2444),
    [anon_sym_static_assert] = ACTIONS(2444),
    [anon_sym_concept] = ACTIONS(2444),
    [anon_sym_co_return] = ACTIONS(2444),
    [anon_sym_co_yield] = ACTIONS(2444),
    [anon_sym_R_DQUOTE] = ACTIONS(2446),
    [anon_sym_LR_DQUOTE] = ACTIONS(2446),
    [anon_sym_uR_DQUOTE] = ACTIONS(2446),
    [anon_sym_UR_DQUOTE] = ACTIONS(2446),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2446),
    [anon_sym_co_await] = ACTIONS(2444),
    [anon_sym_new] = ACTIONS(2444),
    [anon_sym_requires] = ACTIONS(2444),
    [sym_this] = ACTIONS(2444),
    [anon_sym_precise] = ACTIONS(2444),
    [anon_sym_shared] = ACTIONS(2444),
    [anon_sym_groupshared] = ACTIONS(2444),
    [anon_sym_uniform] = ACTIONS(2444),
    [anon_sym_row_major] = ACTIONS(2444),
    [anon_sym_column_major] = ACTIONS(2444),
    [anon_sym_globallycoherent] = ACTIONS(2444),
    [anon_sym_centroid] = ACTIONS(2444),
    [anon_sym_noperspective] = ACTIONS(2444),
    [anon_sym_nointerpolation] = ACTIONS(2444),
    [anon_sym_sample] = ACTIONS(2444),
    [anon_sym_linear] = ACTIONS(2444),
    [anon_sym_snorm] = ACTIONS(2444),
    [anon_sym_unorm] = ACTIONS(2444),
    [anon_sym_point] = ACTIONS(2444),
    [anon_sym_line] = ACTIONS(2444),
    [anon_sym_triangleadj] = ACTIONS(2444),
    [anon_sym_lineadj] = ACTIONS(2444),
    [anon_sym_triangle] = ACTIONS(2444),
  },
  [809] = {
    [ts_builtin_sym_end] = ACTIONS(2442),
    [sym_identifier] = ACTIONS(2440),
    [aux_sym_preproc_include_token1] = ACTIONS(2440),
    [aux_sym_preproc_def_token1] = ACTIONS(2440),
    [aux_sym_preproc_if_token1] = ACTIONS(2440),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2440),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2440),
    [sym_preproc_directive] = ACTIONS(2440),
    [anon_sym_LPAREN2] = ACTIONS(2442),
    [anon_sym_BANG] = ACTIONS(2442),
    [anon_sym_TILDE] = ACTIONS(2442),
    [anon_sym_DASH] = ACTIONS(2440),
    [anon_sym_PLUS] = ACTIONS(2440),
    [anon_sym_STAR] = ACTIONS(2442),
    [anon_sym_AMP_AMP] = ACTIONS(2442),
    [anon_sym_AMP] = ACTIONS(2440),
    [anon_sym___extension__] = ACTIONS(2440),
    [anon_sym_typedef] = ACTIONS(2440),
    [anon_sym_in] = ACTIONS(2440),
    [anon_sym_out] = ACTIONS(2440),
    [anon_sym_inout] = ACTIONS(2440),
    [anon_sym_extern] = ACTIONS(2440),
    [anon_sym___attribute__] = ACTIONS(2440),
    [anon_sym_COLON_COLON] = ACTIONS(2442),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2442),
    [anon_sym___declspec] = ACTIONS(2440),
    [anon_sym___based] = ACTIONS(2440),
    [anon_sym___cdecl] = ACTIONS(2440),
    [anon_sym___clrcall] = ACTIONS(2440),
    [anon_sym___stdcall] = ACTIONS(2440),
    [anon_sym___fastcall] = ACTIONS(2440),
    [anon_sym___thiscall] = ACTIONS(2440),
    [anon_sym___vectorcall] = ACTIONS(2440),
    [anon_sym_LBRACE] = ACTIONS(2442),
    [anon_sym_signed] = ACTIONS(2440),
    [anon_sym_unsigned] = ACTIONS(2440),
    [anon_sym_long] = ACTIONS(2440),
    [anon_sym_short] = ACTIONS(2440),
    [anon_sym_LBRACK] = ACTIONS(2440),
    [anon_sym_static] = ACTIONS(2440),
    [anon_sym_register] = ACTIONS(2440),
    [anon_sym_inline] = ACTIONS(2440),
    [anon_sym___inline] = ACTIONS(2440),
    [anon_sym___inline__] = ACTIONS(2440),
    [anon_sym___forceinline] = ACTIONS(2440),
    [anon_sym_thread_local] = ACTIONS(2440),
    [anon_sym___thread] = ACTIONS(2440),
    [anon_sym_const] = ACTIONS(2440),
    [anon_sym_constexpr] = ACTIONS(2440),
    [anon_sym_volatile] = ACTIONS(2440),
    [anon_sym_restrict] = ACTIONS(2440),
    [anon_sym___restrict__] = ACTIONS(2440),
    [anon_sym__Atomic] = ACTIONS(2440),
    [anon_sym__Noreturn] = ACTIONS(2440),
    [anon_sym_noreturn] = ACTIONS(2440),
    [anon_sym_mutable] = ACTIONS(2440),
    [anon_sym_constinit] = ACTIONS(2440),
    [anon_sym_consteval] = ACTIONS(2440),
    [anon_sym_alignas] = ACTIONS(2440),
    [anon_sym__Alignas] = ACTIONS(2440),
    [sym_primitive_type] = ACTIONS(2440),
    [anon_sym_enum] = ACTIONS(2440),
    [anon_sym_class] = ACTIONS(2440),
    [anon_sym_struct] = ACTIONS(2440),
    [anon_sym_union] = ACTIONS(2440),
    [anon_sym_if] = ACTIONS(2440),
    [anon_sym_switch] = ACTIONS(2440),
    [anon_sym_case] = ACTIONS(2440),
    [anon_sym_default] = ACTIONS(2440),
    [anon_sym_while] = ACTIONS(2440),
    [anon_sym_do] = ACTIONS(2440),
    [anon_sym_for] = ACTIONS(2440),
    [anon_sym_return] = ACTIONS(2440),
    [anon_sym_break] = ACTIONS(2440),
    [anon_sym_continue] = ACTIONS(2440),
    [anon_sym_goto] = ACTIONS(2440),
    [anon_sym_not] = ACTIONS(2440),
    [anon_sym_compl] = ACTIONS(2440),
    [anon_sym_DASH_DASH] = ACTIONS(2442),
    [anon_sym_PLUS_PLUS] = ACTIONS(2442),
    [anon_sym_sizeof] = ACTIONS(2440),
    [anon_sym___alignof__] = ACTIONS(2440),
    [anon_sym___alignof] = ACTIONS(2440),
    [anon_sym__alignof] = ACTIONS(2440),
    [anon_sym_alignof] = ACTIONS(2440),
    [anon_sym__Alignof] = ACTIONS(2440),
    [anon_sym_offsetof] = ACTIONS(2440),
    [anon_sym__Generic] = ACTIONS(2440),
    [anon_sym_asm] = ACTIONS(2440),
    [anon_sym___asm__] = ACTIONS(2440),
    [sym_number_literal] = ACTIONS(2442),
    [anon_sym_L_SQUOTE] = ACTIONS(2442),
    [anon_sym_u_SQUOTE] = ACTIONS(2442),
    [anon_sym_U_SQUOTE] = ACTIONS(2442),
    [anon_sym_u8_SQUOTE] = ACTIONS(2442),
    [anon_sym_SQUOTE] = ACTIONS(2442),
    [anon_sym_L_DQUOTE] = ACTIONS(2442),
    [anon_sym_u_DQUOTE] = ACTIONS(2442),
    [anon_sym_U_DQUOTE] = ACTIONS(2442),
    [anon_sym_u8_DQUOTE] = ACTIONS(2442),
    [anon_sym_DQUOTE] = ACTIONS(2442),
    [sym_true] = ACTIONS(2440),
    [sym_false] = ACTIONS(2440),
    [anon_sym_NULL] = ACTIONS(2440),
    [anon_sym_nullptr] = ACTIONS(2440),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2440),
    [anon_sym_decltype] = ACTIONS(2440),
    [sym_virtual] = ACTIONS(2440),
    [anon_sym_explicit] = ACTIONS(2440),
    [anon_sym_typename] = ACTIONS(2440),
    [anon_sym_template] = ACTIONS(2440),
    [anon_sym_operator] = ACTIONS(2440),
    [anon_sym_try] = ACTIONS(2440),
    [anon_sym_delete] = ACTIONS(2440),
    [anon_sym_throw] = ACTIONS(2440),
    [anon_sym_namespace] = ACTIONS(2440),
    [anon_sym_using] = ACTIONS(2440),
    [anon_sym_static_assert] = ACTIONS(2440),
    [anon_sym_concept] = ACTIONS(2440),
    [anon_sym_co_return] = ACTIONS(2440),
    [anon_sym_co_yield] = ACTIONS(2440),
    [anon_sym_R_DQUOTE] = ACTIONS(2442),
    [anon_sym_LR_DQUOTE] = ACTIONS(2442),
    [anon_sym_uR_DQUOTE] = ACTIONS(2442),
    [anon_sym_UR_DQUOTE] = ACTIONS(2442),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2442),
    [anon_sym_co_await] = ACTIONS(2440),
    [anon_sym_new] = ACTIONS(2440),
    [anon_sym_requires] = ACTIONS(2440),
    [sym_this] = ACTIONS(2440),
    [anon_sym_precise] = ACTIONS(2440),
    [anon_sym_shared] = ACTIONS(2440),
    [anon_sym_groupshared] = ACTIONS(2440),
    [anon_sym_uniform] = ACTIONS(2440),
    [anon_sym_row_major] = ACTIONS(2440),
    [anon_sym_column_major] = ACTIONS(2440),
    [anon_sym_globallycoherent] = ACTIONS(2440),
    [anon_sym_centroid] = ACTIONS(2440),
    [anon_sym_noperspective] = ACTIONS(2440),
    [anon_sym_nointerpolation] = ACTIONS(2440),
    [anon_sym_sample] = ACTIONS(2440),
    [anon_sym_linear] = ACTIONS(2440),
    [anon_sym_snorm] = ACTIONS(2440),
    [anon_sym_unorm] = ACTIONS(2440),
    [anon_sym_point] = ACTIONS(2440),
    [anon_sym_line] = ACTIONS(2440),
    [anon_sym_triangleadj] = ACTIONS(2440),
    [anon_sym_lineadj] = ACTIONS(2440),
    [anon_sym_triangle] = ACTIONS(2440),
  },
  [810] = {
    [ts_builtin_sym_end] = ACTIONS(2310),
    [sym_identifier] = ACTIONS(2308),
    [aux_sym_preproc_include_token1] = ACTIONS(2308),
    [aux_sym_preproc_def_token1] = ACTIONS(2308),
    [aux_sym_preproc_if_token1] = ACTIONS(2308),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2308),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2308),
    [sym_preproc_directive] = ACTIONS(2308),
    [anon_sym_LPAREN2] = ACTIONS(2310),
    [anon_sym_BANG] = ACTIONS(2310),
    [anon_sym_TILDE] = ACTIONS(2310),
    [anon_sym_DASH] = ACTIONS(2308),
    [anon_sym_PLUS] = ACTIONS(2308),
    [anon_sym_STAR] = ACTIONS(2310),
    [anon_sym_AMP_AMP] = ACTIONS(2310),
    [anon_sym_AMP] = ACTIONS(2308),
    [anon_sym___extension__] = ACTIONS(2308),
    [anon_sym_typedef] = ACTIONS(2308),
    [anon_sym_in] = ACTIONS(2308),
    [anon_sym_out] = ACTIONS(2308),
    [anon_sym_inout] = ACTIONS(2308),
    [anon_sym_extern] = ACTIONS(2308),
    [anon_sym___attribute__] = ACTIONS(2308),
    [anon_sym_COLON_COLON] = ACTIONS(2310),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2310),
    [anon_sym___declspec] = ACTIONS(2308),
    [anon_sym___based] = ACTIONS(2308),
    [anon_sym___cdecl] = ACTIONS(2308),
    [anon_sym___clrcall] = ACTIONS(2308),
    [anon_sym___stdcall] = ACTIONS(2308),
    [anon_sym___fastcall] = ACTIONS(2308),
    [anon_sym___thiscall] = ACTIONS(2308),
    [anon_sym___vectorcall] = ACTIONS(2308),
    [anon_sym_LBRACE] = ACTIONS(2310),
    [anon_sym_signed] = ACTIONS(2308),
    [anon_sym_unsigned] = ACTIONS(2308),
    [anon_sym_long] = ACTIONS(2308),
    [anon_sym_short] = ACTIONS(2308),
    [anon_sym_LBRACK] = ACTIONS(2308),
    [anon_sym_static] = ACTIONS(2308),
    [anon_sym_register] = ACTIONS(2308),
    [anon_sym_inline] = ACTIONS(2308),
    [anon_sym___inline] = ACTIONS(2308),
    [anon_sym___inline__] = ACTIONS(2308),
    [anon_sym___forceinline] = ACTIONS(2308),
    [anon_sym_thread_local] = ACTIONS(2308),
    [anon_sym___thread] = ACTIONS(2308),
    [anon_sym_const] = ACTIONS(2308),
    [anon_sym_constexpr] = ACTIONS(2308),
    [anon_sym_volatile] = ACTIONS(2308),
    [anon_sym_restrict] = ACTIONS(2308),
    [anon_sym___restrict__] = ACTIONS(2308),
    [anon_sym__Atomic] = ACTIONS(2308),
    [anon_sym__Noreturn] = ACTIONS(2308),
    [anon_sym_noreturn] = ACTIONS(2308),
    [anon_sym_mutable] = ACTIONS(2308),
    [anon_sym_constinit] = ACTIONS(2308),
    [anon_sym_consteval] = ACTIONS(2308),
    [anon_sym_alignas] = ACTIONS(2308),
    [anon_sym__Alignas] = ACTIONS(2308),
    [sym_primitive_type] = ACTIONS(2308),
    [anon_sym_enum] = ACTIONS(2308),
    [anon_sym_class] = ACTIONS(2308),
    [anon_sym_struct] = ACTIONS(2308),
    [anon_sym_union] = ACTIONS(2308),
    [anon_sym_if] = ACTIONS(2308),
    [anon_sym_switch] = ACTIONS(2308),
    [anon_sym_case] = ACTIONS(2308),
    [anon_sym_default] = ACTIONS(2308),
    [anon_sym_while] = ACTIONS(2308),
    [anon_sym_do] = ACTIONS(2308),
    [anon_sym_for] = ACTIONS(2308),
    [anon_sym_return] = ACTIONS(2308),
    [anon_sym_break] = ACTIONS(2308),
    [anon_sym_continue] = ACTIONS(2308),
    [anon_sym_goto] = ACTIONS(2308),
    [anon_sym_not] = ACTIONS(2308),
    [anon_sym_compl] = ACTIONS(2308),
    [anon_sym_DASH_DASH] = ACTIONS(2310),
    [anon_sym_PLUS_PLUS] = ACTIONS(2310),
    [anon_sym_sizeof] = ACTIONS(2308),
    [anon_sym___alignof__] = ACTIONS(2308),
    [anon_sym___alignof] = ACTIONS(2308),
    [anon_sym__alignof] = ACTIONS(2308),
    [anon_sym_alignof] = ACTIONS(2308),
    [anon_sym__Alignof] = ACTIONS(2308),
    [anon_sym_offsetof] = ACTIONS(2308),
    [anon_sym__Generic] = ACTIONS(2308),
    [anon_sym_asm] = ACTIONS(2308),
    [anon_sym___asm__] = ACTIONS(2308),
    [sym_number_literal] = ACTIONS(2310),
    [anon_sym_L_SQUOTE] = ACTIONS(2310),
    [anon_sym_u_SQUOTE] = ACTIONS(2310),
    [anon_sym_U_SQUOTE] = ACTIONS(2310),
    [anon_sym_u8_SQUOTE] = ACTIONS(2310),
    [anon_sym_SQUOTE] = ACTIONS(2310),
    [anon_sym_L_DQUOTE] = ACTIONS(2310),
    [anon_sym_u_DQUOTE] = ACTIONS(2310),
    [anon_sym_U_DQUOTE] = ACTIONS(2310),
    [anon_sym_u8_DQUOTE] = ACTIONS(2310),
    [anon_sym_DQUOTE] = ACTIONS(2310),
    [sym_true] = ACTIONS(2308),
    [sym_false] = ACTIONS(2308),
    [anon_sym_NULL] = ACTIONS(2308),
    [anon_sym_nullptr] = ACTIONS(2308),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2308),
    [anon_sym_decltype] = ACTIONS(2308),
    [sym_virtual] = ACTIONS(2308),
    [anon_sym_explicit] = ACTIONS(2308),
    [anon_sym_typename] = ACTIONS(2308),
    [anon_sym_template] = ACTIONS(2308),
    [anon_sym_operator] = ACTIONS(2308),
    [anon_sym_try] = ACTIONS(2308),
    [anon_sym_delete] = ACTIONS(2308),
    [anon_sym_throw] = ACTIONS(2308),
    [anon_sym_namespace] = ACTIONS(2308),
    [anon_sym_using] = ACTIONS(2308),
    [anon_sym_static_assert] = ACTIONS(2308),
    [anon_sym_concept] = ACTIONS(2308),
    [anon_sym_co_return] = ACTIONS(2308),
    [anon_sym_co_yield] = ACTIONS(2308),
    [anon_sym_R_DQUOTE] = ACTIONS(2310),
    [anon_sym_LR_DQUOTE] = ACTIONS(2310),
    [anon_sym_uR_DQUOTE] = ACTIONS(2310),
    [anon_sym_UR_DQUOTE] = ACTIONS(2310),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2310),
    [anon_sym_co_await] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(2308),
    [anon_sym_requires] = ACTIONS(2308),
    [sym_this] = ACTIONS(2308),
    [anon_sym_precise] = ACTIONS(2308),
    [anon_sym_shared] = ACTIONS(2308),
    [anon_sym_groupshared] = ACTIONS(2308),
    [anon_sym_uniform] = ACTIONS(2308),
    [anon_sym_row_major] = ACTIONS(2308),
    [anon_sym_column_major] = ACTIONS(2308),
    [anon_sym_globallycoherent] = ACTIONS(2308),
    [anon_sym_centroid] = ACTIONS(2308),
    [anon_sym_noperspective] = ACTIONS(2308),
    [anon_sym_nointerpolation] = ACTIONS(2308),
    [anon_sym_sample] = ACTIONS(2308),
    [anon_sym_linear] = ACTIONS(2308),
    [anon_sym_snorm] = ACTIONS(2308),
    [anon_sym_unorm] = ACTIONS(2308),
    [anon_sym_point] = ACTIONS(2308),
    [anon_sym_line] = ACTIONS(2308),
    [anon_sym_triangleadj] = ACTIONS(2308),
    [anon_sym_lineadj] = ACTIONS(2308),
    [anon_sym_triangle] = ACTIONS(2308),
  },
  [811] = {
    [ts_builtin_sym_end] = ACTIONS(2434),
    [sym_identifier] = ACTIONS(2432),
    [aux_sym_preproc_include_token1] = ACTIONS(2432),
    [aux_sym_preproc_def_token1] = ACTIONS(2432),
    [aux_sym_preproc_if_token1] = ACTIONS(2432),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2432),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2432),
    [sym_preproc_directive] = ACTIONS(2432),
    [anon_sym_LPAREN2] = ACTIONS(2434),
    [anon_sym_BANG] = ACTIONS(2434),
    [anon_sym_TILDE] = ACTIONS(2434),
    [anon_sym_DASH] = ACTIONS(2432),
    [anon_sym_PLUS] = ACTIONS(2432),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_AMP_AMP] = ACTIONS(2434),
    [anon_sym_AMP] = ACTIONS(2432),
    [anon_sym___extension__] = ACTIONS(2432),
    [anon_sym_typedef] = ACTIONS(2432),
    [anon_sym_in] = ACTIONS(2432),
    [anon_sym_out] = ACTIONS(2432),
    [anon_sym_inout] = ACTIONS(2432),
    [anon_sym_extern] = ACTIONS(2432),
    [anon_sym___attribute__] = ACTIONS(2432),
    [anon_sym_COLON_COLON] = ACTIONS(2434),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2434),
    [anon_sym___declspec] = ACTIONS(2432),
    [anon_sym___based] = ACTIONS(2432),
    [anon_sym___cdecl] = ACTIONS(2432),
    [anon_sym___clrcall] = ACTIONS(2432),
    [anon_sym___stdcall] = ACTIONS(2432),
    [anon_sym___fastcall] = ACTIONS(2432),
    [anon_sym___thiscall] = ACTIONS(2432),
    [anon_sym___vectorcall] = ACTIONS(2432),
    [anon_sym_LBRACE] = ACTIONS(2434),
    [anon_sym_signed] = ACTIONS(2432),
    [anon_sym_unsigned] = ACTIONS(2432),
    [anon_sym_long] = ACTIONS(2432),
    [anon_sym_short] = ACTIONS(2432),
    [anon_sym_LBRACK] = ACTIONS(2432),
    [anon_sym_static] = ACTIONS(2432),
    [anon_sym_register] = ACTIONS(2432),
    [anon_sym_inline] = ACTIONS(2432),
    [anon_sym___inline] = ACTIONS(2432),
    [anon_sym___inline__] = ACTIONS(2432),
    [anon_sym___forceinline] = ACTIONS(2432),
    [anon_sym_thread_local] = ACTIONS(2432),
    [anon_sym___thread] = ACTIONS(2432),
    [anon_sym_const] = ACTIONS(2432),
    [anon_sym_constexpr] = ACTIONS(2432),
    [anon_sym_volatile] = ACTIONS(2432),
    [anon_sym_restrict] = ACTIONS(2432),
    [anon_sym___restrict__] = ACTIONS(2432),
    [anon_sym__Atomic] = ACTIONS(2432),
    [anon_sym__Noreturn] = ACTIONS(2432),
    [anon_sym_noreturn] = ACTIONS(2432),
    [anon_sym_mutable] = ACTIONS(2432),
    [anon_sym_constinit] = ACTIONS(2432),
    [anon_sym_consteval] = ACTIONS(2432),
    [anon_sym_alignas] = ACTIONS(2432),
    [anon_sym__Alignas] = ACTIONS(2432),
    [sym_primitive_type] = ACTIONS(2432),
    [anon_sym_enum] = ACTIONS(2432),
    [anon_sym_class] = ACTIONS(2432),
    [anon_sym_struct] = ACTIONS(2432),
    [anon_sym_union] = ACTIONS(2432),
    [anon_sym_if] = ACTIONS(2432),
    [anon_sym_switch] = ACTIONS(2432),
    [anon_sym_case] = ACTIONS(2432),
    [anon_sym_default] = ACTIONS(2432),
    [anon_sym_while] = ACTIONS(2432),
    [anon_sym_do] = ACTIONS(2432),
    [anon_sym_for] = ACTIONS(2432),
    [anon_sym_return] = ACTIONS(2432),
    [anon_sym_break] = ACTIONS(2432),
    [anon_sym_continue] = ACTIONS(2432),
    [anon_sym_goto] = ACTIONS(2432),
    [anon_sym_not] = ACTIONS(2432),
    [anon_sym_compl] = ACTIONS(2432),
    [anon_sym_DASH_DASH] = ACTIONS(2434),
    [anon_sym_PLUS_PLUS] = ACTIONS(2434),
    [anon_sym_sizeof] = ACTIONS(2432),
    [anon_sym___alignof__] = ACTIONS(2432),
    [anon_sym___alignof] = ACTIONS(2432),
    [anon_sym__alignof] = ACTIONS(2432),
    [anon_sym_alignof] = ACTIONS(2432),
    [anon_sym__Alignof] = ACTIONS(2432),
    [anon_sym_offsetof] = ACTIONS(2432),
    [anon_sym__Generic] = ACTIONS(2432),
    [anon_sym_asm] = ACTIONS(2432),
    [anon_sym___asm__] = ACTIONS(2432),
    [sym_number_literal] = ACTIONS(2434),
    [anon_sym_L_SQUOTE] = ACTIONS(2434),
    [anon_sym_u_SQUOTE] = ACTIONS(2434),
    [anon_sym_U_SQUOTE] = ACTIONS(2434),
    [anon_sym_u8_SQUOTE] = ACTIONS(2434),
    [anon_sym_SQUOTE] = ACTIONS(2434),
    [anon_sym_L_DQUOTE] = ACTIONS(2434),
    [anon_sym_u_DQUOTE] = ACTIONS(2434),
    [anon_sym_U_DQUOTE] = ACTIONS(2434),
    [anon_sym_u8_DQUOTE] = ACTIONS(2434),
    [anon_sym_DQUOTE] = ACTIONS(2434),
    [sym_true] = ACTIONS(2432),
    [sym_false] = ACTIONS(2432),
    [anon_sym_NULL] = ACTIONS(2432),
    [anon_sym_nullptr] = ACTIONS(2432),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2432),
    [anon_sym_decltype] = ACTIONS(2432),
    [sym_virtual] = ACTIONS(2432),
    [anon_sym_explicit] = ACTIONS(2432),
    [anon_sym_typename] = ACTIONS(2432),
    [anon_sym_template] = ACTIONS(2432),
    [anon_sym_operator] = ACTIONS(2432),
    [anon_sym_try] = ACTIONS(2432),
    [anon_sym_delete] = ACTIONS(2432),
    [anon_sym_throw] = ACTIONS(2432),
    [anon_sym_namespace] = ACTIONS(2432),
    [anon_sym_using] = ACTIONS(2432),
    [anon_sym_static_assert] = ACTIONS(2432),
    [anon_sym_concept] = ACTIONS(2432),
    [anon_sym_co_return] = ACTIONS(2432),
    [anon_sym_co_yield] = ACTIONS(2432),
    [anon_sym_R_DQUOTE] = ACTIONS(2434),
    [anon_sym_LR_DQUOTE] = ACTIONS(2434),
    [anon_sym_uR_DQUOTE] = ACTIONS(2434),
    [anon_sym_UR_DQUOTE] = ACTIONS(2434),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2434),
    [anon_sym_co_await] = ACTIONS(2432),
    [anon_sym_new] = ACTIONS(2432),
    [anon_sym_requires] = ACTIONS(2432),
    [sym_this] = ACTIONS(2432),
    [anon_sym_precise] = ACTIONS(2432),
    [anon_sym_shared] = ACTIONS(2432),
    [anon_sym_groupshared] = ACTIONS(2432),
    [anon_sym_uniform] = ACTIONS(2432),
    [anon_sym_row_major] = ACTIONS(2432),
    [anon_sym_column_major] = ACTIONS(2432),
    [anon_sym_globallycoherent] = ACTIONS(2432),
    [anon_sym_centroid] = ACTIONS(2432),
    [anon_sym_noperspective] = ACTIONS(2432),
    [anon_sym_nointerpolation] = ACTIONS(2432),
    [anon_sym_sample] = ACTIONS(2432),
    [anon_sym_linear] = ACTIONS(2432),
    [anon_sym_snorm] = ACTIONS(2432),
    [anon_sym_unorm] = ACTIONS(2432),
    [anon_sym_point] = ACTIONS(2432),
    [anon_sym_line] = ACTIONS(2432),
    [anon_sym_triangleadj] = ACTIONS(2432),
    [anon_sym_lineadj] = ACTIONS(2432),
    [anon_sym_triangle] = ACTIONS(2432),
  },
  [812] = {
    [ts_builtin_sym_end] = ACTIONS(2302),
    [sym_identifier] = ACTIONS(2300),
    [aux_sym_preproc_include_token1] = ACTIONS(2300),
    [aux_sym_preproc_def_token1] = ACTIONS(2300),
    [aux_sym_preproc_if_token1] = ACTIONS(2300),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2300),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2300),
    [sym_preproc_directive] = ACTIONS(2300),
    [anon_sym_LPAREN2] = ACTIONS(2302),
    [anon_sym_BANG] = ACTIONS(2302),
    [anon_sym_TILDE] = ACTIONS(2302),
    [anon_sym_DASH] = ACTIONS(2300),
    [anon_sym_PLUS] = ACTIONS(2300),
    [anon_sym_STAR] = ACTIONS(2302),
    [anon_sym_AMP_AMP] = ACTIONS(2302),
    [anon_sym_AMP] = ACTIONS(2300),
    [anon_sym___extension__] = ACTIONS(2300),
    [anon_sym_typedef] = ACTIONS(2300),
    [anon_sym_in] = ACTIONS(2300),
    [anon_sym_out] = ACTIONS(2300),
    [anon_sym_inout] = ACTIONS(2300),
    [anon_sym_extern] = ACTIONS(2300),
    [anon_sym___attribute__] = ACTIONS(2300),
    [anon_sym_COLON_COLON] = ACTIONS(2302),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2302),
    [anon_sym___declspec] = ACTIONS(2300),
    [anon_sym___based] = ACTIONS(2300),
    [anon_sym___cdecl] = ACTIONS(2300),
    [anon_sym___clrcall] = ACTIONS(2300),
    [anon_sym___stdcall] = ACTIONS(2300),
    [anon_sym___fastcall] = ACTIONS(2300),
    [anon_sym___thiscall] = ACTIONS(2300),
    [anon_sym___vectorcall] = ACTIONS(2300),
    [anon_sym_LBRACE] = ACTIONS(2302),
    [anon_sym_signed] = ACTIONS(2300),
    [anon_sym_unsigned] = ACTIONS(2300),
    [anon_sym_long] = ACTIONS(2300),
    [anon_sym_short] = ACTIONS(2300),
    [anon_sym_LBRACK] = ACTIONS(2300),
    [anon_sym_static] = ACTIONS(2300),
    [anon_sym_register] = ACTIONS(2300),
    [anon_sym_inline] = ACTIONS(2300),
    [anon_sym___inline] = ACTIONS(2300),
    [anon_sym___inline__] = ACTIONS(2300),
    [anon_sym___forceinline] = ACTIONS(2300),
    [anon_sym_thread_local] = ACTIONS(2300),
    [anon_sym___thread] = ACTIONS(2300),
    [anon_sym_const] = ACTIONS(2300),
    [anon_sym_constexpr] = ACTIONS(2300),
    [anon_sym_volatile] = ACTIONS(2300),
    [anon_sym_restrict] = ACTIONS(2300),
    [anon_sym___restrict__] = ACTIONS(2300),
    [anon_sym__Atomic] = ACTIONS(2300),
    [anon_sym__Noreturn] = ACTIONS(2300),
    [anon_sym_noreturn] = ACTIONS(2300),
    [anon_sym_mutable] = ACTIONS(2300),
    [anon_sym_constinit] = ACTIONS(2300),
    [anon_sym_consteval] = ACTIONS(2300),
    [anon_sym_alignas] = ACTIONS(2300),
    [anon_sym__Alignas] = ACTIONS(2300),
    [sym_primitive_type] = ACTIONS(2300),
    [anon_sym_enum] = ACTIONS(2300),
    [anon_sym_class] = ACTIONS(2300),
    [anon_sym_struct] = ACTIONS(2300),
    [anon_sym_union] = ACTIONS(2300),
    [anon_sym_if] = ACTIONS(2300),
    [anon_sym_switch] = ACTIONS(2300),
    [anon_sym_case] = ACTIONS(2300),
    [anon_sym_default] = ACTIONS(2300),
    [anon_sym_while] = ACTIONS(2300),
    [anon_sym_do] = ACTIONS(2300),
    [anon_sym_for] = ACTIONS(2300),
    [anon_sym_return] = ACTIONS(2300),
    [anon_sym_break] = ACTIONS(2300),
    [anon_sym_continue] = ACTIONS(2300),
    [anon_sym_goto] = ACTIONS(2300),
    [anon_sym_not] = ACTIONS(2300),
    [anon_sym_compl] = ACTIONS(2300),
    [anon_sym_DASH_DASH] = ACTIONS(2302),
    [anon_sym_PLUS_PLUS] = ACTIONS(2302),
    [anon_sym_sizeof] = ACTIONS(2300),
    [anon_sym___alignof__] = ACTIONS(2300),
    [anon_sym___alignof] = ACTIONS(2300),
    [anon_sym__alignof] = ACTIONS(2300),
    [anon_sym_alignof] = ACTIONS(2300),
    [anon_sym__Alignof] = ACTIONS(2300),
    [anon_sym_offsetof] = ACTIONS(2300),
    [anon_sym__Generic] = ACTIONS(2300),
    [anon_sym_asm] = ACTIONS(2300),
    [anon_sym___asm__] = ACTIONS(2300),
    [sym_number_literal] = ACTIONS(2302),
    [anon_sym_L_SQUOTE] = ACTIONS(2302),
    [anon_sym_u_SQUOTE] = ACTIONS(2302),
    [anon_sym_U_SQUOTE] = ACTIONS(2302),
    [anon_sym_u8_SQUOTE] = ACTIONS(2302),
    [anon_sym_SQUOTE] = ACTIONS(2302),
    [anon_sym_L_DQUOTE] = ACTIONS(2302),
    [anon_sym_u_DQUOTE] = ACTIONS(2302),
    [anon_sym_U_DQUOTE] = ACTIONS(2302),
    [anon_sym_u8_DQUOTE] = ACTIONS(2302),
    [anon_sym_DQUOTE] = ACTIONS(2302),
    [sym_true] = ACTIONS(2300),
    [sym_false] = ACTIONS(2300),
    [anon_sym_NULL] = ACTIONS(2300),
    [anon_sym_nullptr] = ACTIONS(2300),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2300),
    [anon_sym_decltype] = ACTIONS(2300),
    [sym_virtual] = ACTIONS(2300),
    [anon_sym_explicit] = ACTIONS(2300),
    [anon_sym_typename] = ACTIONS(2300),
    [anon_sym_template] = ACTIONS(2300),
    [anon_sym_operator] = ACTIONS(2300),
    [anon_sym_try] = ACTIONS(2300),
    [anon_sym_delete] = ACTIONS(2300),
    [anon_sym_throw] = ACTIONS(2300),
    [anon_sym_namespace] = ACTIONS(2300),
    [anon_sym_using] = ACTIONS(2300),
    [anon_sym_static_assert] = ACTIONS(2300),
    [anon_sym_concept] = ACTIONS(2300),
    [anon_sym_co_return] = ACTIONS(2300),
    [anon_sym_co_yield] = ACTIONS(2300),
    [anon_sym_R_DQUOTE] = ACTIONS(2302),
    [anon_sym_LR_DQUOTE] = ACTIONS(2302),
    [anon_sym_uR_DQUOTE] = ACTIONS(2302),
    [anon_sym_UR_DQUOTE] = ACTIONS(2302),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2302),
    [anon_sym_co_await] = ACTIONS(2300),
    [anon_sym_new] = ACTIONS(2300),
    [anon_sym_requires] = ACTIONS(2300),
    [sym_this] = ACTIONS(2300),
    [anon_sym_precise] = ACTIONS(2300),
    [anon_sym_shared] = ACTIONS(2300),
    [anon_sym_groupshared] = ACTIONS(2300),
    [anon_sym_uniform] = ACTIONS(2300),
    [anon_sym_row_major] = ACTIONS(2300),
    [anon_sym_column_major] = ACTIONS(2300),
    [anon_sym_globallycoherent] = ACTIONS(2300),
    [anon_sym_centroid] = ACTIONS(2300),
    [anon_sym_noperspective] = ACTIONS(2300),
    [anon_sym_nointerpolation] = ACTIONS(2300),
    [anon_sym_sample] = ACTIONS(2300),
    [anon_sym_linear] = ACTIONS(2300),
    [anon_sym_snorm] = ACTIONS(2300),
    [anon_sym_unorm] = ACTIONS(2300),
    [anon_sym_point] = ACTIONS(2300),
    [anon_sym_line] = ACTIONS(2300),
    [anon_sym_triangleadj] = ACTIONS(2300),
    [anon_sym_lineadj] = ACTIONS(2300),
    [anon_sym_triangle] = ACTIONS(2300),
  },
  [813] = {
    [sym_preproc_def] = STATE(748),
    [sym_preproc_function_def] = STATE(748),
    [sym_preproc_call] = STATE(748),
    [sym_preproc_if_in_field_declaration_list] = STATE(748),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(748),
    [sym_type_definition] = STATE(748),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(748),
    [sym_field_declaration] = STATE(748),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(748),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(748),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(748),
    [sym_operator_cast_declaration] = STATE(748),
    [sym_constructor_or_destructor_definition] = STATE(748),
    [sym_constructor_or_destructor_declaration] = STATE(748),
    [sym_friend_declaration] = STATE(748),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(748),
    [sym_alias_declaration] = STATE(748),
    [sym_static_assert_declaration] = STATE(748),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(748),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(3029),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [814] = {
    [ts_builtin_sym_end] = ACTIONS(2334),
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_include_token1] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_BANG] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_DASH] = ACTIONS(2332),
    [anon_sym_PLUS] = ACTIONS(2332),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym___cdecl] = ACTIONS(2332),
    [anon_sym___clrcall] = ACTIONS(2332),
    [anon_sym___stdcall] = ACTIONS(2332),
    [anon_sym___fastcall] = ACTIONS(2332),
    [anon_sym___thiscall] = ACTIONS(2332),
    [anon_sym___vectorcall] = ACTIONS(2332),
    [anon_sym_LBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_switch] = ACTIONS(2332),
    [anon_sym_case] = ACTIONS(2332),
    [anon_sym_default] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2332),
    [anon_sym_do] = ACTIONS(2332),
    [anon_sym_for] = ACTIONS(2332),
    [anon_sym_return] = ACTIONS(2332),
    [anon_sym_break] = ACTIONS(2332),
    [anon_sym_continue] = ACTIONS(2332),
    [anon_sym_goto] = ACTIONS(2332),
    [anon_sym_not] = ACTIONS(2332),
    [anon_sym_compl] = ACTIONS(2332),
    [anon_sym_DASH_DASH] = ACTIONS(2334),
    [anon_sym_PLUS_PLUS] = ACTIONS(2334),
    [anon_sym_sizeof] = ACTIONS(2332),
    [anon_sym___alignof__] = ACTIONS(2332),
    [anon_sym___alignof] = ACTIONS(2332),
    [anon_sym__alignof] = ACTIONS(2332),
    [anon_sym_alignof] = ACTIONS(2332),
    [anon_sym__Alignof] = ACTIONS(2332),
    [anon_sym_offsetof] = ACTIONS(2332),
    [anon_sym__Generic] = ACTIONS(2332),
    [anon_sym_asm] = ACTIONS(2332),
    [anon_sym___asm__] = ACTIONS(2332),
    [sym_number_literal] = ACTIONS(2334),
    [anon_sym_L_SQUOTE] = ACTIONS(2334),
    [anon_sym_u_SQUOTE] = ACTIONS(2334),
    [anon_sym_U_SQUOTE] = ACTIONS(2334),
    [anon_sym_u8_SQUOTE] = ACTIONS(2334),
    [anon_sym_SQUOTE] = ACTIONS(2334),
    [anon_sym_L_DQUOTE] = ACTIONS(2334),
    [anon_sym_u_DQUOTE] = ACTIONS(2334),
    [anon_sym_U_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8_DQUOTE] = ACTIONS(2334),
    [anon_sym_DQUOTE] = ACTIONS(2334),
    [sym_true] = ACTIONS(2332),
    [sym_false] = ACTIONS(2332),
    [anon_sym_NULL] = ACTIONS(2332),
    [anon_sym_nullptr] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_try] = ACTIONS(2332),
    [anon_sym_delete] = ACTIONS(2332),
    [anon_sym_throw] = ACTIONS(2332),
    [anon_sym_namespace] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_concept] = ACTIONS(2332),
    [anon_sym_co_return] = ACTIONS(2332),
    [anon_sym_co_yield] = ACTIONS(2332),
    [anon_sym_R_DQUOTE] = ACTIONS(2334),
    [anon_sym_LR_DQUOTE] = ACTIONS(2334),
    [anon_sym_uR_DQUOTE] = ACTIONS(2334),
    [anon_sym_UR_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2334),
    [anon_sym_co_await] = ACTIONS(2332),
    [anon_sym_new] = ACTIONS(2332),
    [anon_sym_requires] = ACTIONS(2332),
    [sym_this] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
  },
  [815] = {
    [ts_builtin_sym_end] = ACTIONS(2342),
    [sym_identifier] = ACTIONS(2340),
    [aux_sym_preproc_include_token1] = ACTIONS(2340),
    [aux_sym_preproc_def_token1] = ACTIONS(2340),
    [aux_sym_preproc_if_token1] = ACTIONS(2340),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2340),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2340),
    [sym_preproc_directive] = ACTIONS(2340),
    [anon_sym_LPAREN2] = ACTIONS(2342),
    [anon_sym_BANG] = ACTIONS(2342),
    [anon_sym_TILDE] = ACTIONS(2342),
    [anon_sym_DASH] = ACTIONS(2340),
    [anon_sym_PLUS] = ACTIONS(2340),
    [anon_sym_STAR] = ACTIONS(2342),
    [anon_sym_AMP_AMP] = ACTIONS(2342),
    [anon_sym_AMP] = ACTIONS(2340),
    [anon_sym___extension__] = ACTIONS(2340),
    [anon_sym_typedef] = ACTIONS(2340),
    [anon_sym_in] = ACTIONS(2340),
    [anon_sym_out] = ACTIONS(2340),
    [anon_sym_inout] = ACTIONS(2340),
    [anon_sym_extern] = ACTIONS(2340),
    [anon_sym___attribute__] = ACTIONS(2340),
    [anon_sym_COLON_COLON] = ACTIONS(2342),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2342),
    [anon_sym___declspec] = ACTIONS(2340),
    [anon_sym___based] = ACTIONS(2340),
    [anon_sym___cdecl] = ACTIONS(2340),
    [anon_sym___clrcall] = ACTIONS(2340),
    [anon_sym___stdcall] = ACTIONS(2340),
    [anon_sym___fastcall] = ACTIONS(2340),
    [anon_sym___thiscall] = ACTIONS(2340),
    [anon_sym___vectorcall] = ACTIONS(2340),
    [anon_sym_LBRACE] = ACTIONS(2342),
    [anon_sym_signed] = ACTIONS(2340),
    [anon_sym_unsigned] = ACTIONS(2340),
    [anon_sym_long] = ACTIONS(2340),
    [anon_sym_short] = ACTIONS(2340),
    [anon_sym_LBRACK] = ACTIONS(2340),
    [anon_sym_static] = ACTIONS(2340),
    [anon_sym_register] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(2340),
    [anon_sym___inline] = ACTIONS(2340),
    [anon_sym___inline__] = ACTIONS(2340),
    [anon_sym___forceinline] = ACTIONS(2340),
    [anon_sym_thread_local] = ACTIONS(2340),
    [anon_sym___thread] = ACTIONS(2340),
    [anon_sym_const] = ACTIONS(2340),
    [anon_sym_constexpr] = ACTIONS(2340),
    [anon_sym_volatile] = ACTIONS(2340),
    [anon_sym_restrict] = ACTIONS(2340),
    [anon_sym___restrict__] = ACTIONS(2340),
    [anon_sym__Atomic] = ACTIONS(2340),
    [anon_sym__Noreturn] = ACTIONS(2340),
    [anon_sym_noreturn] = ACTIONS(2340),
    [anon_sym_mutable] = ACTIONS(2340),
    [anon_sym_constinit] = ACTIONS(2340),
    [anon_sym_consteval] = ACTIONS(2340),
    [anon_sym_alignas] = ACTIONS(2340),
    [anon_sym__Alignas] = ACTIONS(2340),
    [sym_primitive_type] = ACTIONS(2340),
    [anon_sym_enum] = ACTIONS(2340),
    [anon_sym_class] = ACTIONS(2340),
    [anon_sym_struct] = ACTIONS(2340),
    [anon_sym_union] = ACTIONS(2340),
    [anon_sym_if] = ACTIONS(2340),
    [anon_sym_switch] = ACTIONS(2340),
    [anon_sym_case] = ACTIONS(2340),
    [anon_sym_default] = ACTIONS(2340),
    [anon_sym_while] = ACTIONS(2340),
    [anon_sym_do] = ACTIONS(2340),
    [anon_sym_for] = ACTIONS(2340),
    [anon_sym_return] = ACTIONS(2340),
    [anon_sym_break] = ACTIONS(2340),
    [anon_sym_continue] = ACTIONS(2340),
    [anon_sym_goto] = ACTIONS(2340),
    [anon_sym_not] = ACTIONS(2340),
    [anon_sym_compl] = ACTIONS(2340),
    [anon_sym_DASH_DASH] = ACTIONS(2342),
    [anon_sym_PLUS_PLUS] = ACTIONS(2342),
    [anon_sym_sizeof] = ACTIONS(2340),
    [anon_sym___alignof__] = ACTIONS(2340),
    [anon_sym___alignof] = ACTIONS(2340),
    [anon_sym__alignof] = ACTIONS(2340),
    [anon_sym_alignof] = ACTIONS(2340),
    [anon_sym__Alignof] = ACTIONS(2340),
    [anon_sym_offsetof] = ACTIONS(2340),
    [anon_sym__Generic] = ACTIONS(2340),
    [anon_sym_asm] = ACTIONS(2340),
    [anon_sym___asm__] = ACTIONS(2340),
    [sym_number_literal] = ACTIONS(2342),
    [anon_sym_L_SQUOTE] = ACTIONS(2342),
    [anon_sym_u_SQUOTE] = ACTIONS(2342),
    [anon_sym_U_SQUOTE] = ACTIONS(2342),
    [anon_sym_u8_SQUOTE] = ACTIONS(2342),
    [anon_sym_SQUOTE] = ACTIONS(2342),
    [anon_sym_L_DQUOTE] = ACTIONS(2342),
    [anon_sym_u_DQUOTE] = ACTIONS(2342),
    [anon_sym_U_DQUOTE] = ACTIONS(2342),
    [anon_sym_u8_DQUOTE] = ACTIONS(2342),
    [anon_sym_DQUOTE] = ACTIONS(2342),
    [sym_true] = ACTIONS(2340),
    [sym_false] = ACTIONS(2340),
    [anon_sym_NULL] = ACTIONS(2340),
    [anon_sym_nullptr] = ACTIONS(2340),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2340),
    [anon_sym_decltype] = ACTIONS(2340),
    [sym_virtual] = ACTIONS(2340),
    [anon_sym_explicit] = ACTIONS(2340),
    [anon_sym_typename] = ACTIONS(2340),
    [anon_sym_template] = ACTIONS(2340),
    [anon_sym_operator] = ACTIONS(2340),
    [anon_sym_try] = ACTIONS(2340),
    [anon_sym_delete] = ACTIONS(2340),
    [anon_sym_throw] = ACTIONS(2340),
    [anon_sym_namespace] = ACTIONS(2340),
    [anon_sym_using] = ACTIONS(2340),
    [anon_sym_static_assert] = ACTIONS(2340),
    [anon_sym_concept] = ACTIONS(2340),
    [anon_sym_co_return] = ACTIONS(2340),
    [anon_sym_co_yield] = ACTIONS(2340),
    [anon_sym_R_DQUOTE] = ACTIONS(2342),
    [anon_sym_LR_DQUOTE] = ACTIONS(2342),
    [anon_sym_uR_DQUOTE] = ACTIONS(2342),
    [anon_sym_UR_DQUOTE] = ACTIONS(2342),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2342),
    [anon_sym_co_await] = ACTIONS(2340),
    [anon_sym_new] = ACTIONS(2340),
    [anon_sym_requires] = ACTIONS(2340),
    [sym_this] = ACTIONS(2340),
    [anon_sym_precise] = ACTIONS(2340),
    [anon_sym_shared] = ACTIONS(2340),
    [anon_sym_groupshared] = ACTIONS(2340),
    [anon_sym_uniform] = ACTIONS(2340),
    [anon_sym_row_major] = ACTIONS(2340),
    [anon_sym_column_major] = ACTIONS(2340),
    [anon_sym_globallycoherent] = ACTIONS(2340),
    [anon_sym_centroid] = ACTIONS(2340),
    [anon_sym_noperspective] = ACTIONS(2340),
    [anon_sym_nointerpolation] = ACTIONS(2340),
    [anon_sym_sample] = ACTIONS(2340),
    [anon_sym_linear] = ACTIONS(2340),
    [anon_sym_snorm] = ACTIONS(2340),
    [anon_sym_unorm] = ACTIONS(2340),
    [anon_sym_point] = ACTIONS(2340),
    [anon_sym_line] = ACTIONS(2340),
    [anon_sym_triangleadj] = ACTIONS(2340),
    [anon_sym_lineadj] = ACTIONS(2340),
    [anon_sym_triangle] = ACTIONS(2340),
  },
  [816] = {
    [ts_builtin_sym_end] = ACTIONS(2430),
    [sym_identifier] = ACTIONS(2428),
    [aux_sym_preproc_include_token1] = ACTIONS(2428),
    [aux_sym_preproc_def_token1] = ACTIONS(2428),
    [aux_sym_preproc_if_token1] = ACTIONS(2428),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2428),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2428),
    [sym_preproc_directive] = ACTIONS(2428),
    [anon_sym_LPAREN2] = ACTIONS(2430),
    [anon_sym_BANG] = ACTIONS(2430),
    [anon_sym_TILDE] = ACTIONS(2430),
    [anon_sym_DASH] = ACTIONS(2428),
    [anon_sym_PLUS] = ACTIONS(2428),
    [anon_sym_STAR] = ACTIONS(2430),
    [anon_sym_AMP_AMP] = ACTIONS(2430),
    [anon_sym_AMP] = ACTIONS(2428),
    [anon_sym___extension__] = ACTIONS(2428),
    [anon_sym_typedef] = ACTIONS(2428),
    [anon_sym_in] = ACTIONS(2428),
    [anon_sym_out] = ACTIONS(2428),
    [anon_sym_inout] = ACTIONS(2428),
    [anon_sym_extern] = ACTIONS(2428),
    [anon_sym___attribute__] = ACTIONS(2428),
    [anon_sym_COLON_COLON] = ACTIONS(2430),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2430),
    [anon_sym___declspec] = ACTIONS(2428),
    [anon_sym___based] = ACTIONS(2428),
    [anon_sym___cdecl] = ACTIONS(2428),
    [anon_sym___clrcall] = ACTIONS(2428),
    [anon_sym___stdcall] = ACTIONS(2428),
    [anon_sym___fastcall] = ACTIONS(2428),
    [anon_sym___thiscall] = ACTIONS(2428),
    [anon_sym___vectorcall] = ACTIONS(2428),
    [anon_sym_LBRACE] = ACTIONS(2430),
    [anon_sym_signed] = ACTIONS(2428),
    [anon_sym_unsigned] = ACTIONS(2428),
    [anon_sym_long] = ACTIONS(2428),
    [anon_sym_short] = ACTIONS(2428),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [anon_sym_static] = ACTIONS(2428),
    [anon_sym_register] = ACTIONS(2428),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym___inline] = ACTIONS(2428),
    [anon_sym___inline__] = ACTIONS(2428),
    [anon_sym___forceinline] = ACTIONS(2428),
    [anon_sym_thread_local] = ACTIONS(2428),
    [anon_sym___thread] = ACTIONS(2428),
    [anon_sym_const] = ACTIONS(2428),
    [anon_sym_constexpr] = ACTIONS(2428),
    [anon_sym_volatile] = ACTIONS(2428),
    [anon_sym_restrict] = ACTIONS(2428),
    [anon_sym___restrict__] = ACTIONS(2428),
    [anon_sym__Atomic] = ACTIONS(2428),
    [anon_sym__Noreturn] = ACTIONS(2428),
    [anon_sym_noreturn] = ACTIONS(2428),
    [anon_sym_mutable] = ACTIONS(2428),
    [anon_sym_constinit] = ACTIONS(2428),
    [anon_sym_consteval] = ACTIONS(2428),
    [anon_sym_alignas] = ACTIONS(2428),
    [anon_sym__Alignas] = ACTIONS(2428),
    [sym_primitive_type] = ACTIONS(2428),
    [anon_sym_enum] = ACTIONS(2428),
    [anon_sym_class] = ACTIONS(2428),
    [anon_sym_struct] = ACTIONS(2428),
    [anon_sym_union] = ACTIONS(2428),
    [anon_sym_if] = ACTIONS(2428),
    [anon_sym_switch] = ACTIONS(2428),
    [anon_sym_case] = ACTIONS(2428),
    [anon_sym_default] = ACTIONS(2428),
    [anon_sym_while] = ACTIONS(2428),
    [anon_sym_do] = ACTIONS(2428),
    [anon_sym_for] = ACTIONS(2428),
    [anon_sym_return] = ACTIONS(2428),
    [anon_sym_break] = ACTIONS(2428),
    [anon_sym_continue] = ACTIONS(2428),
    [anon_sym_goto] = ACTIONS(2428),
    [anon_sym_not] = ACTIONS(2428),
    [anon_sym_compl] = ACTIONS(2428),
    [anon_sym_DASH_DASH] = ACTIONS(2430),
    [anon_sym_PLUS_PLUS] = ACTIONS(2430),
    [anon_sym_sizeof] = ACTIONS(2428),
    [anon_sym___alignof__] = ACTIONS(2428),
    [anon_sym___alignof] = ACTIONS(2428),
    [anon_sym__alignof] = ACTIONS(2428),
    [anon_sym_alignof] = ACTIONS(2428),
    [anon_sym__Alignof] = ACTIONS(2428),
    [anon_sym_offsetof] = ACTIONS(2428),
    [anon_sym__Generic] = ACTIONS(2428),
    [anon_sym_asm] = ACTIONS(2428),
    [anon_sym___asm__] = ACTIONS(2428),
    [sym_number_literal] = ACTIONS(2430),
    [anon_sym_L_SQUOTE] = ACTIONS(2430),
    [anon_sym_u_SQUOTE] = ACTIONS(2430),
    [anon_sym_U_SQUOTE] = ACTIONS(2430),
    [anon_sym_u8_SQUOTE] = ACTIONS(2430),
    [anon_sym_SQUOTE] = ACTIONS(2430),
    [anon_sym_L_DQUOTE] = ACTIONS(2430),
    [anon_sym_u_DQUOTE] = ACTIONS(2430),
    [anon_sym_U_DQUOTE] = ACTIONS(2430),
    [anon_sym_u8_DQUOTE] = ACTIONS(2430),
    [anon_sym_DQUOTE] = ACTIONS(2430),
    [sym_true] = ACTIONS(2428),
    [sym_false] = ACTIONS(2428),
    [anon_sym_NULL] = ACTIONS(2428),
    [anon_sym_nullptr] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2428),
    [anon_sym_decltype] = ACTIONS(2428),
    [sym_virtual] = ACTIONS(2428),
    [anon_sym_explicit] = ACTIONS(2428),
    [anon_sym_typename] = ACTIONS(2428),
    [anon_sym_template] = ACTIONS(2428),
    [anon_sym_operator] = ACTIONS(2428),
    [anon_sym_try] = ACTIONS(2428),
    [anon_sym_delete] = ACTIONS(2428),
    [anon_sym_throw] = ACTIONS(2428),
    [anon_sym_namespace] = ACTIONS(2428),
    [anon_sym_using] = ACTIONS(2428),
    [anon_sym_static_assert] = ACTIONS(2428),
    [anon_sym_concept] = ACTIONS(2428),
    [anon_sym_co_return] = ACTIONS(2428),
    [anon_sym_co_yield] = ACTIONS(2428),
    [anon_sym_R_DQUOTE] = ACTIONS(2430),
    [anon_sym_LR_DQUOTE] = ACTIONS(2430),
    [anon_sym_uR_DQUOTE] = ACTIONS(2430),
    [anon_sym_UR_DQUOTE] = ACTIONS(2430),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2430),
    [anon_sym_co_await] = ACTIONS(2428),
    [anon_sym_new] = ACTIONS(2428),
    [anon_sym_requires] = ACTIONS(2428),
    [sym_this] = ACTIONS(2428),
    [anon_sym_precise] = ACTIONS(2428),
    [anon_sym_shared] = ACTIONS(2428),
    [anon_sym_groupshared] = ACTIONS(2428),
    [anon_sym_uniform] = ACTIONS(2428),
    [anon_sym_row_major] = ACTIONS(2428),
    [anon_sym_column_major] = ACTIONS(2428),
    [anon_sym_globallycoherent] = ACTIONS(2428),
    [anon_sym_centroid] = ACTIONS(2428),
    [anon_sym_noperspective] = ACTIONS(2428),
    [anon_sym_nointerpolation] = ACTIONS(2428),
    [anon_sym_sample] = ACTIONS(2428),
    [anon_sym_linear] = ACTIONS(2428),
    [anon_sym_snorm] = ACTIONS(2428),
    [anon_sym_unorm] = ACTIONS(2428),
    [anon_sym_point] = ACTIONS(2428),
    [anon_sym_line] = ACTIONS(2428),
    [anon_sym_triangleadj] = ACTIONS(2428),
    [anon_sym_lineadj] = ACTIONS(2428),
    [anon_sym_triangle] = ACTIONS(2428),
  },
  [817] = {
    [ts_builtin_sym_end] = ACTIONS(2422),
    [sym_identifier] = ACTIONS(2420),
    [aux_sym_preproc_include_token1] = ACTIONS(2420),
    [aux_sym_preproc_def_token1] = ACTIONS(2420),
    [aux_sym_preproc_if_token1] = ACTIONS(2420),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2420),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2420),
    [sym_preproc_directive] = ACTIONS(2420),
    [anon_sym_LPAREN2] = ACTIONS(2422),
    [anon_sym_BANG] = ACTIONS(2422),
    [anon_sym_TILDE] = ACTIONS(2422),
    [anon_sym_DASH] = ACTIONS(2420),
    [anon_sym_PLUS] = ACTIONS(2420),
    [anon_sym_STAR] = ACTIONS(2422),
    [anon_sym_AMP_AMP] = ACTIONS(2422),
    [anon_sym_AMP] = ACTIONS(2420),
    [anon_sym___extension__] = ACTIONS(2420),
    [anon_sym_typedef] = ACTIONS(2420),
    [anon_sym_in] = ACTIONS(2420),
    [anon_sym_out] = ACTIONS(2420),
    [anon_sym_inout] = ACTIONS(2420),
    [anon_sym_extern] = ACTIONS(2420),
    [anon_sym___attribute__] = ACTIONS(2420),
    [anon_sym_COLON_COLON] = ACTIONS(2422),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2422),
    [anon_sym___declspec] = ACTIONS(2420),
    [anon_sym___based] = ACTIONS(2420),
    [anon_sym___cdecl] = ACTIONS(2420),
    [anon_sym___clrcall] = ACTIONS(2420),
    [anon_sym___stdcall] = ACTIONS(2420),
    [anon_sym___fastcall] = ACTIONS(2420),
    [anon_sym___thiscall] = ACTIONS(2420),
    [anon_sym___vectorcall] = ACTIONS(2420),
    [anon_sym_LBRACE] = ACTIONS(2422),
    [anon_sym_signed] = ACTIONS(2420),
    [anon_sym_unsigned] = ACTIONS(2420),
    [anon_sym_long] = ACTIONS(2420),
    [anon_sym_short] = ACTIONS(2420),
    [anon_sym_LBRACK] = ACTIONS(2420),
    [anon_sym_static] = ACTIONS(2420),
    [anon_sym_register] = ACTIONS(2420),
    [anon_sym_inline] = ACTIONS(2420),
    [anon_sym___inline] = ACTIONS(2420),
    [anon_sym___inline__] = ACTIONS(2420),
    [anon_sym___forceinline] = ACTIONS(2420),
    [anon_sym_thread_local] = ACTIONS(2420),
    [anon_sym___thread] = ACTIONS(2420),
    [anon_sym_const] = ACTIONS(2420),
    [anon_sym_constexpr] = ACTIONS(2420),
    [anon_sym_volatile] = ACTIONS(2420),
    [anon_sym_restrict] = ACTIONS(2420),
    [anon_sym___restrict__] = ACTIONS(2420),
    [anon_sym__Atomic] = ACTIONS(2420),
    [anon_sym__Noreturn] = ACTIONS(2420),
    [anon_sym_noreturn] = ACTIONS(2420),
    [anon_sym_mutable] = ACTIONS(2420),
    [anon_sym_constinit] = ACTIONS(2420),
    [anon_sym_consteval] = ACTIONS(2420),
    [anon_sym_alignas] = ACTIONS(2420),
    [anon_sym__Alignas] = ACTIONS(2420),
    [sym_primitive_type] = ACTIONS(2420),
    [anon_sym_enum] = ACTIONS(2420),
    [anon_sym_class] = ACTIONS(2420),
    [anon_sym_struct] = ACTIONS(2420),
    [anon_sym_union] = ACTIONS(2420),
    [anon_sym_if] = ACTIONS(2420),
    [anon_sym_switch] = ACTIONS(2420),
    [anon_sym_case] = ACTIONS(2420),
    [anon_sym_default] = ACTIONS(2420),
    [anon_sym_while] = ACTIONS(2420),
    [anon_sym_do] = ACTIONS(2420),
    [anon_sym_for] = ACTIONS(2420),
    [anon_sym_return] = ACTIONS(2420),
    [anon_sym_break] = ACTIONS(2420),
    [anon_sym_continue] = ACTIONS(2420),
    [anon_sym_goto] = ACTIONS(2420),
    [anon_sym_not] = ACTIONS(2420),
    [anon_sym_compl] = ACTIONS(2420),
    [anon_sym_DASH_DASH] = ACTIONS(2422),
    [anon_sym_PLUS_PLUS] = ACTIONS(2422),
    [anon_sym_sizeof] = ACTIONS(2420),
    [anon_sym___alignof__] = ACTIONS(2420),
    [anon_sym___alignof] = ACTIONS(2420),
    [anon_sym__alignof] = ACTIONS(2420),
    [anon_sym_alignof] = ACTIONS(2420),
    [anon_sym__Alignof] = ACTIONS(2420),
    [anon_sym_offsetof] = ACTIONS(2420),
    [anon_sym__Generic] = ACTIONS(2420),
    [anon_sym_asm] = ACTIONS(2420),
    [anon_sym___asm__] = ACTIONS(2420),
    [sym_number_literal] = ACTIONS(2422),
    [anon_sym_L_SQUOTE] = ACTIONS(2422),
    [anon_sym_u_SQUOTE] = ACTIONS(2422),
    [anon_sym_U_SQUOTE] = ACTIONS(2422),
    [anon_sym_u8_SQUOTE] = ACTIONS(2422),
    [anon_sym_SQUOTE] = ACTIONS(2422),
    [anon_sym_L_DQUOTE] = ACTIONS(2422),
    [anon_sym_u_DQUOTE] = ACTIONS(2422),
    [anon_sym_U_DQUOTE] = ACTIONS(2422),
    [anon_sym_u8_DQUOTE] = ACTIONS(2422),
    [anon_sym_DQUOTE] = ACTIONS(2422),
    [sym_true] = ACTIONS(2420),
    [sym_false] = ACTIONS(2420),
    [anon_sym_NULL] = ACTIONS(2420),
    [anon_sym_nullptr] = ACTIONS(2420),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2420),
    [anon_sym_decltype] = ACTIONS(2420),
    [sym_virtual] = ACTIONS(2420),
    [anon_sym_explicit] = ACTIONS(2420),
    [anon_sym_typename] = ACTIONS(2420),
    [anon_sym_template] = ACTIONS(2420),
    [anon_sym_operator] = ACTIONS(2420),
    [anon_sym_try] = ACTIONS(2420),
    [anon_sym_delete] = ACTIONS(2420),
    [anon_sym_throw] = ACTIONS(2420),
    [anon_sym_namespace] = ACTIONS(2420),
    [anon_sym_using] = ACTIONS(2420),
    [anon_sym_static_assert] = ACTIONS(2420),
    [anon_sym_concept] = ACTIONS(2420),
    [anon_sym_co_return] = ACTIONS(2420),
    [anon_sym_co_yield] = ACTIONS(2420),
    [anon_sym_R_DQUOTE] = ACTIONS(2422),
    [anon_sym_LR_DQUOTE] = ACTIONS(2422),
    [anon_sym_uR_DQUOTE] = ACTIONS(2422),
    [anon_sym_UR_DQUOTE] = ACTIONS(2422),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2422),
    [anon_sym_co_await] = ACTIONS(2420),
    [anon_sym_new] = ACTIONS(2420),
    [anon_sym_requires] = ACTIONS(2420),
    [sym_this] = ACTIONS(2420),
    [anon_sym_precise] = ACTIONS(2420),
    [anon_sym_shared] = ACTIONS(2420),
    [anon_sym_groupshared] = ACTIONS(2420),
    [anon_sym_uniform] = ACTIONS(2420),
    [anon_sym_row_major] = ACTIONS(2420),
    [anon_sym_column_major] = ACTIONS(2420),
    [anon_sym_globallycoherent] = ACTIONS(2420),
    [anon_sym_centroid] = ACTIONS(2420),
    [anon_sym_noperspective] = ACTIONS(2420),
    [anon_sym_nointerpolation] = ACTIONS(2420),
    [anon_sym_sample] = ACTIONS(2420),
    [anon_sym_linear] = ACTIONS(2420),
    [anon_sym_snorm] = ACTIONS(2420),
    [anon_sym_unorm] = ACTIONS(2420),
    [anon_sym_point] = ACTIONS(2420),
    [anon_sym_line] = ACTIONS(2420),
    [anon_sym_triangleadj] = ACTIONS(2420),
    [anon_sym_lineadj] = ACTIONS(2420),
    [anon_sym_triangle] = ACTIONS(2420),
  },
  [818] = {
    [ts_builtin_sym_end] = ACTIONS(2334),
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_include_token1] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_BANG] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_DASH] = ACTIONS(2332),
    [anon_sym_PLUS] = ACTIONS(2332),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym___cdecl] = ACTIONS(2332),
    [anon_sym___clrcall] = ACTIONS(2332),
    [anon_sym___stdcall] = ACTIONS(2332),
    [anon_sym___fastcall] = ACTIONS(2332),
    [anon_sym___thiscall] = ACTIONS(2332),
    [anon_sym___vectorcall] = ACTIONS(2332),
    [anon_sym_LBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [anon_sym_if] = ACTIONS(2332),
    [anon_sym_switch] = ACTIONS(2332),
    [anon_sym_case] = ACTIONS(2332),
    [anon_sym_default] = ACTIONS(2332),
    [anon_sym_while] = ACTIONS(2332),
    [anon_sym_do] = ACTIONS(2332),
    [anon_sym_for] = ACTIONS(2332),
    [anon_sym_return] = ACTIONS(2332),
    [anon_sym_break] = ACTIONS(2332),
    [anon_sym_continue] = ACTIONS(2332),
    [anon_sym_goto] = ACTIONS(2332),
    [anon_sym_not] = ACTIONS(2332),
    [anon_sym_compl] = ACTIONS(2332),
    [anon_sym_DASH_DASH] = ACTIONS(2334),
    [anon_sym_PLUS_PLUS] = ACTIONS(2334),
    [anon_sym_sizeof] = ACTIONS(2332),
    [anon_sym___alignof__] = ACTIONS(2332),
    [anon_sym___alignof] = ACTIONS(2332),
    [anon_sym__alignof] = ACTIONS(2332),
    [anon_sym_alignof] = ACTIONS(2332),
    [anon_sym__Alignof] = ACTIONS(2332),
    [anon_sym_offsetof] = ACTIONS(2332),
    [anon_sym__Generic] = ACTIONS(2332),
    [anon_sym_asm] = ACTIONS(2332),
    [anon_sym___asm__] = ACTIONS(2332),
    [sym_number_literal] = ACTIONS(2334),
    [anon_sym_L_SQUOTE] = ACTIONS(2334),
    [anon_sym_u_SQUOTE] = ACTIONS(2334),
    [anon_sym_U_SQUOTE] = ACTIONS(2334),
    [anon_sym_u8_SQUOTE] = ACTIONS(2334),
    [anon_sym_SQUOTE] = ACTIONS(2334),
    [anon_sym_L_DQUOTE] = ACTIONS(2334),
    [anon_sym_u_DQUOTE] = ACTIONS(2334),
    [anon_sym_U_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8_DQUOTE] = ACTIONS(2334),
    [anon_sym_DQUOTE] = ACTIONS(2334),
    [sym_true] = ACTIONS(2332),
    [sym_false] = ACTIONS(2332),
    [anon_sym_NULL] = ACTIONS(2332),
    [anon_sym_nullptr] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_try] = ACTIONS(2332),
    [anon_sym_delete] = ACTIONS(2332),
    [anon_sym_throw] = ACTIONS(2332),
    [anon_sym_namespace] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_concept] = ACTIONS(2332),
    [anon_sym_co_return] = ACTIONS(2332),
    [anon_sym_co_yield] = ACTIONS(2332),
    [anon_sym_R_DQUOTE] = ACTIONS(2334),
    [anon_sym_LR_DQUOTE] = ACTIONS(2334),
    [anon_sym_uR_DQUOTE] = ACTIONS(2334),
    [anon_sym_UR_DQUOTE] = ACTIONS(2334),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2334),
    [anon_sym_co_await] = ACTIONS(2332),
    [anon_sym_new] = ACTIONS(2332),
    [anon_sym_requires] = ACTIONS(2332),
    [sym_this] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
  },
  [819] = {
    [sym_preproc_def] = STATE(797),
    [sym_preproc_function_def] = STATE(797),
    [sym_preproc_call] = STATE(797),
    [sym_preproc_if_in_field_declaration_list] = STATE(797),
    [sym_preproc_ifdef_in_field_declaration_list] = STATE(797),
    [sym_type_definition] = STATE(797),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(5541),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__field_declaration_list_item] = STATE(797),
    [sym_field_declaration] = STATE(797),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(797),
    [sym_operator_cast] = STATE(6626),
    [sym_inline_method_definition] = STATE(797),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(797),
    [sym_operator_cast_declaration] = STATE(797),
    [sym_constructor_or_destructor_definition] = STATE(797),
    [sym_constructor_or_destructor_declaration] = STATE(797),
    [sym_friend_declaration] = STATE(797),
    [sym_access_specifier] = STATE(7901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_using_declaration] = STATE(797),
    [sym_alias_declaration] = STATE(797),
    [sym_static_assert_declaration] = STATE(797),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5409),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [aux_sym_preproc_if_in_field_declaration_list_repeat1] = STATE(797),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1978),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(2583),
    [aux_sym_preproc_def_token1] = ACTIONS(2857),
    [aux_sym_preproc_if_token1] = ACTIONS(2859),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2861),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2861),
    [sym_preproc_directive] = ACTIONS(2863),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(2865),
    [anon_sym_typedef] = ACTIONS(2867),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(2613),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_RBRACE] = ACTIONS(3031),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_public] = ACTIONS(2633),
    [anon_sym_private] = ACTIONS(2633),
    [anon_sym_protected] = ACTIONS(2633),
    [anon_sym_using] = ACTIONS(2875),
    [anon_sym_static_assert] = ACTIONS(2877),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [820] = {
    [sym_attribute_declaration] = STATE(828),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(482),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4378),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7684),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7796),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [sym_identifier] = ACTIONS(3033),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [821] = {
    [sym_attribute_declaration] = STATE(828),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(358),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7796),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [sym_identifier] = ACTIONS(3033),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [822] = {
    [sym_attribute_declaration] = STATE(891),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(7347),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7568),
    [aux_sym_attributed_declarator_repeat1] = STATE(891),
    [sym_identifier] = ACTIONS(3035),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(3037),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(3043),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(3045),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(3047),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(3049),
  },
  [823] = {
    [sym_attribute_declaration] = STATE(827),
    [sym_compound_statement] = STATE(468),
    [sym_attributed_statement] = STATE(468),
    [sym_statement] = STATE(356),
    [sym_labeled_statement] = STATE(468),
    [sym_expression_statement] = STATE(468),
    [sym_if_statement] = STATE(468),
    [sym_switch_statement] = STATE(468),
    [sym_case_statement] = STATE(468),
    [sym_while_statement] = STATE(468),
    [sym_do_statement] = STATE(468),
    [sym_for_statement] = STATE(468),
    [sym_return_statement] = STATE(468),
    [sym_break_statement] = STATE(468),
    [sym_continue_statement] = STATE(468),
    [sym_goto_statement] = STATE(468),
    [sym_seh_try_statement] = STATE(468),
    [sym_seh_leave_statement] = STATE(468),
    [sym_expression] = STATE(4453),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7849),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(468),
    [sym_co_return_statement] = STATE(468),
    [sym_co_yield_statement] = STATE(468),
    [sym_throw_statement] = STATE(468),
    [sym_try_statement] = STATE(468),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(468),
    [sym_cbuffer_specifier] = STATE(468),
    [sym_hlsl_attribute] = STATE(7711),
    [aux_sym_attributed_declarator_repeat1] = STATE(827),
    [sym_identifier] = ACTIONS(3051),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(785),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(793),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(797),
    [anon_sym_switch] = ACTIONS(799),
    [anon_sym_case] = ACTIONS(801),
    [anon_sym_default] = ACTIONS(803),
    [anon_sym_while] = ACTIONS(805),
    [anon_sym_do] = ACTIONS(807),
    [anon_sym_for] = ACTIONS(809),
    [anon_sym_return] = ACTIONS(811),
    [anon_sym_break] = ACTIONS(813),
    [anon_sym_continue] = ACTIONS(815),
    [anon_sym_goto] = ACTIONS(817),
    [anon_sym___try] = ACTIONS(819),
    [anon_sym___leave] = ACTIONS(821),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(825),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(827),
    [anon_sym_co_return] = ACTIONS(837),
    [anon_sym_co_yield] = ACTIONS(839),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(841),
    [anon_sym_cbuffer] = ACTIONS(843),
  },
  [824] = {
    [sym_attribute_declaration] = STATE(840),
    [sym_compound_statement] = STATE(416),
    [sym_attributed_statement] = STATE(416),
    [sym_statement] = STATE(365),
    [sym_labeled_statement] = STATE(416),
    [sym_expression_statement] = STATE(416),
    [sym_if_statement] = STATE(416),
    [sym_switch_statement] = STATE(416),
    [sym_case_statement] = STATE(416),
    [sym_while_statement] = STATE(416),
    [sym_do_statement] = STATE(416),
    [sym_for_statement] = STATE(416),
    [sym_return_statement] = STATE(416),
    [sym_break_statement] = STATE(416),
    [sym_continue_statement] = STATE(416),
    [sym_goto_statement] = STATE(416),
    [sym_seh_try_statement] = STATE(416),
    [sym_seh_leave_statement] = STATE(416),
    [sym_expression] = STATE(4525),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8558),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(416),
    [sym_co_return_statement] = STATE(416),
    [sym_co_yield_statement] = STATE(416),
    [sym_throw_statement] = STATE(416),
    [sym_try_statement] = STATE(416),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(416),
    [sym_cbuffer_specifier] = STATE(416),
    [sym_hlsl_attribute] = STATE(7458),
    [aux_sym_attributed_declarator_repeat1] = STATE(840),
    [sym_identifier] = ACTIONS(3053),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1477),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(81),
    [anon_sym_default] = ACTIONS(83),
    [anon_sym_while] = ACTIONS(85),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(1479),
    [anon_sym___leave] = ACTIONS(1481),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1483),
    [anon_sym_cbuffer] = ACTIONS(1485),
  },
  [825] = {
    [sym_attribute_declaration] = STATE(827),
    [sym_compound_statement] = STATE(468),
    [sym_attributed_statement] = STATE(468),
    [sym_statement] = STATE(441),
    [sym_labeled_statement] = STATE(468),
    [sym_expression_statement] = STATE(468),
    [sym_if_statement] = STATE(468),
    [sym_switch_statement] = STATE(468),
    [sym_case_statement] = STATE(468),
    [sym_while_statement] = STATE(468),
    [sym_do_statement] = STATE(468),
    [sym_for_statement] = STATE(468),
    [sym_return_statement] = STATE(468),
    [sym_break_statement] = STATE(468),
    [sym_continue_statement] = STATE(468),
    [sym_goto_statement] = STATE(468),
    [sym_seh_try_statement] = STATE(468),
    [sym_seh_leave_statement] = STATE(468),
    [sym_expression] = STATE(4453),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7849),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(468),
    [sym_co_return_statement] = STATE(468),
    [sym_co_yield_statement] = STATE(468),
    [sym_throw_statement] = STATE(468),
    [sym_try_statement] = STATE(468),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(468),
    [sym_cbuffer_specifier] = STATE(468),
    [sym_hlsl_attribute] = STATE(7711),
    [aux_sym_attributed_declarator_repeat1] = STATE(827),
    [sym_identifier] = ACTIONS(3051),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(785),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(793),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(797),
    [anon_sym_switch] = ACTIONS(799),
    [anon_sym_case] = ACTIONS(801),
    [anon_sym_default] = ACTIONS(803),
    [anon_sym_while] = ACTIONS(805),
    [anon_sym_do] = ACTIONS(807),
    [anon_sym_for] = ACTIONS(809),
    [anon_sym_return] = ACTIONS(811),
    [anon_sym_break] = ACTIONS(813),
    [anon_sym_continue] = ACTIONS(815),
    [anon_sym_goto] = ACTIONS(817),
    [anon_sym___try] = ACTIONS(819),
    [anon_sym___leave] = ACTIONS(821),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(825),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(827),
    [anon_sym_co_return] = ACTIONS(837),
    [anon_sym_co_yield] = ACTIONS(839),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(841),
    [anon_sym_cbuffer] = ACTIONS(843),
  },
  [826] = {
    [sym_attribute_declaration] = STATE(828),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(383),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7796),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [sym_identifier] = ACTIONS(3033),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [827] = {
    [sym_attribute_declaration] = STATE(888),
    [sym_compound_statement] = STATE(468),
    [sym_attributed_statement] = STATE(468),
    [sym_statement] = STATE(452),
    [sym_labeled_statement] = STATE(468),
    [sym_expression_statement] = STATE(468),
    [sym_if_statement] = STATE(468),
    [sym_switch_statement] = STATE(468),
    [sym_case_statement] = STATE(468),
    [sym_while_statement] = STATE(468),
    [sym_do_statement] = STATE(468),
    [sym_for_statement] = STATE(468),
    [sym_return_statement] = STATE(468),
    [sym_break_statement] = STATE(468),
    [sym_continue_statement] = STATE(468),
    [sym_goto_statement] = STATE(468),
    [sym_seh_try_statement] = STATE(468),
    [sym_seh_leave_statement] = STATE(468),
    [sym_expression] = STATE(4453),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7849),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(468),
    [sym_co_return_statement] = STATE(468),
    [sym_co_yield_statement] = STATE(468),
    [sym_throw_statement] = STATE(468),
    [sym_try_statement] = STATE(468),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(468),
    [sym_cbuffer_specifier] = STATE(468),
    [sym_hlsl_attribute] = STATE(7711),
    [aux_sym_attributed_declarator_repeat1] = STATE(888),
    [sym_identifier] = ACTIONS(3051),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(785),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(793),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(797),
    [anon_sym_switch] = ACTIONS(799),
    [anon_sym_case] = ACTIONS(801),
    [anon_sym_default] = ACTIONS(803),
    [anon_sym_while] = ACTIONS(805),
    [anon_sym_do] = ACTIONS(807),
    [anon_sym_for] = ACTIONS(809),
    [anon_sym_return] = ACTIONS(811),
    [anon_sym_break] = ACTIONS(813),
    [anon_sym_continue] = ACTIONS(815),
    [anon_sym_goto] = ACTIONS(817),
    [anon_sym___try] = ACTIONS(819),
    [anon_sym___leave] = ACTIONS(821),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(825),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(827),
    [anon_sym_co_return] = ACTIONS(837),
    [anon_sym_co_yield] = ACTIONS(839),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(841),
    [anon_sym_cbuffer] = ACTIONS(843),
  },
  [828] = {
    [sym_attribute_declaration] = STATE(858),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(470),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7796),
    [aux_sym_attributed_declarator_repeat1] = STATE(858),
    [sym_identifier] = ACTIONS(3033),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [829] = {
    [sym_attribute_declaration] = STATE(875),
    [sym_compound_statement] = STATE(1056),
    [sym_attributed_statement] = STATE(1056),
    [sym_statement] = STATE(1044),
    [sym_labeled_statement] = STATE(1056),
    [sym_expression_statement] = STATE(1056),
    [sym_if_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_case_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_do_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_return_statement] = STATE(1056),
    [sym_break_statement] = STATE(1056),
    [sym_continue_statement] = STATE(1056),
    [sym_goto_statement] = STATE(1056),
    [sym_seh_try_statement] = STATE(1056),
    [sym_seh_leave_statement] = STATE(1056),
    [sym_expression] = STATE(4514),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8003),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(1056),
    [sym_co_return_statement] = STATE(1056),
    [sym_co_yield_statement] = STATE(1056),
    [sym_throw_statement] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(1056),
    [sym_cbuffer_specifier] = STATE(1056),
    [sym_hlsl_attribute] = STATE(7744),
    [aux_sym_attributed_declarator_repeat1] = STATE(875),
    [sym_identifier] = ACTIONS(3055),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(1697),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(1701),
    [anon_sym_do] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1705),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1709),
    [anon_sym_continue] = ACTIONS(1711),
    [anon_sym_goto] = ACTIONS(1713),
    [anon_sym___try] = ACTIONS(1715),
    [anon_sym___leave] = ACTIONS(1717),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1719),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(1721),
    [anon_sym_co_return] = ACTIONS(1723),
    [anon_sym_co_yield] = ACTIONS(1725),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1727),
    [anon_sym_cbuffer] = ACTIONS(1729),
  },
  [830] = {
    [sym_attribute_declaration] = STATE(828),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(372),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7796),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [sym_identifier] = ACTIONS(3033),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [831] = {
    [sym_attribute_declaration] = STATE(827),
    [sym_compound_statement] = STATE(468),
    [sym_attributed_statement] = STATE(468),
    [sym_statement] = STATE(374),
    [sym_labeled_statement] = STATE(468),
    [sym_expression_statement] = STATE(468),
    [sym_if_statement] = STATE(468),
    [sym_switch_statement] = STATE(468),
    [sym_case_statement] = STATE(468),
    [sym_while_statement] = STATE(468),
    [sym_do_statement] = STATE(468),
    [sym_for_statement] = STATE(468),
    [sym_return_statement] = STATE(468),
    [sym_break_statement] = STATE(468),
    [sym_continue_statement] = STATE(468),
    [sym_goto_statement] = STATE(468),
    [sym_seh_try_statement] = STATE(468),
    [sym_seh_leave_statement] = STATE(468),
    [sym_expression] = STATE(4453),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7849),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(468),
    [sym_co_return_statement] = STATE(468),
    [sym_co_yield_statement] = STATE(468),
    [sym_throw_statement] = STATE(468),
    [sym_try_statement] = STATE(468),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(468),
    [sym_cbuffer_specifier] = STATE(468),
    [sym_hlsl_attribute] = STATE(7711),
    [aux_sym_attributed_declarator_repeat1] = STATE(827),
    [sym_identifier] = ACTIONS(3051),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(785),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(793),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(797),
    [anon_sym_switch] = ACTIONS(799),
    [anon_sym_case] = ACTIONS(801),
    [anon_sym_default] = ACTIONS(803),
    [anon_sym_while] = ACTIONS(805),
    [anon_sym_do] = ACTIONS(807),
    [anon_sym_for] = ACTIONS(809),
    [anon_sym_return] = ACTIONS(811),
    [anon_sym_break] = ACTIONS(813),
    [anon_sym_continue] = ACTIONS(815),
    [anon_sym_goto] = ACTIONS(817),
    [anon_sym___try] = ACTIONS(819),
    [anon_sym___leave] = ACTIONS(821),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(825),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(827),
    [anon_sym_co_return] = ACTIONS(837),
    [anon_sym_co_yield] = ACTIONS(839),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(841),
    [anon_sym_cbuffer] = ACTIONS(843),
  },
  [832] = {
    [sym_attribute_declaration] = STATE(840),
    [sym_compound_statement] = STATE(416),
    [sym_attributed_statement] = STATE(416),
    [sym_statement] = STATE(397),
    [sym_labeled_statement] = STATE(416),
    [sym_expression_statement] = STATE(416),
    [sym_if_statement] = STATE(416),
    [sym_switch_statement] = STATE(416),
    [sym_case_statement] = STATE(416),
    [sym_while_statement] = STATE(416),
    [sym_do_statement] = STATE(416),
    [sym_for_statement] = STATE(416),
    [sym_return_statement] = STATE(416),
    [sym_break_statement] = STATE(416),
    [sym_continue_statement] = STATE(416),
    [sym_goto_statement] = STATE(416),
    [sym_seh_try_statement] = STATE(416),
    [sym_seh_leave_statement] = STATE(416),
    [sym_expression] = STATE(4525),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8558),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(416),
    [sym_co_return_statement] = STATE(416),
    [sym_co_yield_statement] = STATE(416),
    [sym_throw_statement] = STATE(416),
    [sym_try_statement] = STATE(416),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(416),
    [sym_cbuffer_specifier] = STATE(416),
    [sym_hlsl_attribute] = STATE(7458),
    [aux_sym_attributed_declarator_repeat1] = STATE(840),
    [sym_identifier] = ACTIONS(3053),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1477),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(81),
    [anon_sym_default] = ACTIONS(83),
    [anon_sym_while] = ACTIONS(85),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(1479),
    [anon_sym___leave] = ACTIONS(1481),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1483),
    [anon_sym_cbuffer] = ACTIONS(1485),
  },
  [833] = {
    [sym_attribute_declaration] = STATE(840),
    [sym_compound_statement] = STATE(416),
    [sym_attributed_statement] = STATE(416),
    [sym_statement] = STATE(364),
    [sym_labeled_statement] = STATE(416),
    [sym_expression_statement] = STATE(416),
    [sym_if_statement] = STATE(416),
    [sym_switch_statement] = STATE(416),
    [sym_case_statement] = STATE(416),
    [sym_while_statement] = STATE(416),
    [sym_do_statement] = STATE(416),
    [sym_for_statement] = STATE(416),
    [sym_return_statement] = STATE(416),
    [sym_break_statement] = STATE(416),
    [sym_continue_statement] = STATE(416),
    [sym_goto_statement] = STATE(416),
    [sym_seh_try_statement] = STATE(416),
    [sym_seh_leave_statement] = STATE(416),
    [sym_expression] = STATE(4525),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8558),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(416),
    [sym_co_return_statement] = STATE(416),
    [sym_co_yield_statement] = STATE(416),
    [sym_throw_statement] = STATE(416),
    [sym_try_statement] = STATE(416),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(416),
    [sym_cbuffer_specifier] = STATE(416),
    [sym_hlsl_attribute] = STATE(7458),
    [aux_sym_attributed_declarator_repeat1] = STATE(840),
    [sym_identifier] = ACTIONS(3053),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1477),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(81),
    [anon_sym_default] = ACTIONS(83),
    [anon_sym_while] = ACTIONS(85),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(1479),
    [anon_sym___leave] = ACTIONS(1481),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1483),
    [anon_sym_cbuffer] = ACTIONS(1485),
  },
  [834] = {
    [sym_attribute_declaration] = STATE(875),
    [sym_compound_statement] = STATE(1056),
    [sym_attributed_statement] = STATE(1056),
    [sym_statement] = STATE(1047),
    [sym_labeled_statement] = STATE(1056),
    [sym_expression_statement] = STATE(1056),
    [sym_if_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_case_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_do_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_return_statement] = STATE(1056),
    [sym_break_statement] = STATE(1056),
    [sym_continue_statement] = STATE(1056),
    [sym_goto_statement] = STATE(1056),
    [sym_seh_try_statement] = STATE(1056),
    [sym_seh_leave_statement] = STATE(1056),
    [sym_expression] = STATE(4514),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8003),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(1056),
    [sym_co_return_statement] = STATE(1056),
    [sym_co_yield_statement] = STATE(1056),
    [sym_throw_statement] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(1056),
    [sym_cbuffer_specifier] = STATE(1056),
    [sym_hlsl_attribute] = STATE(7744),
    [aux_sym_attributed_declarator_repeat1] = STATE(875),
    [sym_identifier] = ACTIONS(3055),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(1697),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(1701),
    [anon_sym_do] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1705),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1709),
    [anon_sym_continue] = ACTIONS(1711),
    [anon_sym_goto] = ACTIONS(1713),
    [anon_sym___try] = ACTIONS(1715),
    [anon_sym___leave] = ACTIONS(1717),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1719),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(1721),
    [anon_sym_co_return] = ACTIONS(1723),
    [anon_sym_co_yield] = ACTIONS(1725),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1727),
    [anon_sym_cbuffer] = ACTIONS(1729),
  },
  [835] = {
    [sym_attribute_declaration] = STATE(828),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(524),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7796),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [sym_identifier] = ACTIONS(3033),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [836] = {
    [sym_attribute_declaration] = STATE(850),
    [sym_compound_statement] = STATE(178),
    [sym_attributed_statement] = STATE(178),
    [sym_statement] = STATE(171),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(7801),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [sym_identifier] = ACTIONS(3057),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [837] = {
    [sym_attribute_declaration] = STATE(828),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(520),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7796),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [sym_identifier] = ACTIONS(3033),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [838] = {
    [sym_attribute_declaration] = STATE(840),
    [sym_compound_statement] = STATE(416),
    [sym_attributed_statement] = STATE(416),
    [sym_statement] = STATE(534),
    [sym_labeled_statement] = STATE(416),
    [sym_expression_statement] = STATE(416),
    [sym_if_statement] = STATE(416),
    [sym_switch_statement] = STATE(416),
    [sym_case_statement] = STATE(416),
    [sym_while_statement] = STATE(416),
    [sym_do_statement] = STATE(416),
    [sym_for_statement] = STATE(416),
    [sym_return_statement] = STATE(416),
    [sym_break_statement] = STATE(416),
    [sym_continue_statement] = STATE(416),
    [sym_goto_statement] = STATE(416),
    [sym_seh_try_statement] = STATE(416),
    [sym_seh_leave_statement] = STATE(416),
    [sym_expression] = STATE(4525),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8558),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(416),
    [sym_co_return_statement] = STATE(416),
    [sym_co_yield_statement] = STATE(416),
    [sym_throw_statement] = STATE(416),
    [sym_try_statement] = STATE(416),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(416),
    [sym_cbuffer_specifier] = STATE(416),
    [sym_hlsl_attribute] = STATE(7458),
    [aux_sym_attributed_declarator_repeat1] = STATE(840),
    [sym_identifier] = ACTIONS(3053),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1477),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(81),
    [anon_sym_default] = ACTIONS(83),
    [anon_sym_while] = ACTIONS(85),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(1479),
    [anon_sym___leave] = ACTIONS(1481),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1483),
    [anon_sym_cbuffer] = ACTIONS(1485),
  },
  [839] = {
    [sym_attribute_declaration] = STATE(839),
    [sym_compound_statement] = STATE(1056),
    [sym_attributed_statement] = STATE(1056),
    [sym_statement] = STATE(1018),
    [sym_labeled_statement] = STATE(1056),
    [sym_expression_statement] = STATE(1056),
    [sym_if_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_case_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_do_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_return_statement] = STATE(1056),
    [sym_break_statement] = STATE(1056),
    [sym_continue_statement] = STATE(1056),
    [sym_goto_statement] = STATE(1056),
    [sym_seh_try_statement] = STATE(1056),
    [sym_seh_leave_statement] = STATE(1056),
    [sym_expression] = STATE(4514),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8003),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(1056),
    [sym_co_return_statement] = STATE(1056),
    [sym_co_yield_statement] = STATE(1056),
    [sym_throw_statement] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(1056),
    [sym_cbuffer_specifier] = STATE(1056),
    [sym_hlsl_attribute] = STATE(7744),
    [aux_sym_attributed_declarator_repeat1] = STATE(839),
    [sym_identifier] = ACTIONS(3059),
    [anon_sym_LPAREN2] = ACTIONS(3062),
    [anon_sym_BANG] = ACTIONS(3065),
    [anon_sym_TILDE] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3068),
    [anon_sym_PLUS] = ACTIONS(3068),
    [anon_sym_STAR] = ACTIONS(3071),
    [anon_sym_AMP] = ACTIONS(3071),
    [anon_sym_SEMI] = ACTIONS(3074),
    [anon_sym_COLON_COLON] = ACTIONS(3077),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3080),
    [anon_sym_LBRACE] = ACTIONS(3083),
    [anon_sym_LBRACK] = ACTIONS(3086),
    [sym_primitive_type] = ACTIONS(3089),
    [anon_sym_if] = ACTIONS(3092),
    [anon_sym_switch] = ACTIONS(3095),
    [anon_sym_case] = ACTIONS(3098),
    [anon_sym_default] = ACTIONS(3101),
    [anon_sym_while] = ACTIONS(3104),
    [anon_sym_do] = ACTIONS(3107),
    [anon_sym_for] = ACTIONS(3110),
    [anon_sym_return] = ACTIONS(3113),
    [anon_sym_break] = ACTIONS(3116),
    [anon_sym_continue] = ACTIONS(3119),
    [anon_sym_goto] = ACTIONS(3122),
    [anon_sym___try] = ACTIONS(3125),
    [anon_sym___leave] = ACTIONS(3128),
    [anon_sym_not] = ACTIONS(3068),
    [anon_sym_compl] = ACTIONS(3068),
    [anon_sym_DASH_DASH] = ACTIONS(3131),
    [anon_sym_PLUS_PLUS] = ACTIONS(3131),
    [anon_sym_sizeof] = ACTIONS(3134),
    [anon_sym___alignof__] = ACTIONS(3137),
    [anon_sym___alignof] = ACTIONS(3137),
    [anon_sym__alignof] = ACTIONS(3137),
    [anon_sym_alignof] = ACTIONS(3137),
    [anon_sym__Alignof] = ACTIONS(3137),
    [anon_sym_offsetof] = ACTIONS(3140),
    [anon_sym__Generic] = ACTIONS(3143),
    [anon_sym_asm] = ACTIONS(3146),
    [anon_sym___asm__] = ACTIONS(3146),
    [sym_number_literal] = ACTIONS(3149),
    [anon_sym_L_SQUOTE] = ACTIONS(3152),
    [anon_sym_u_SQUOTE] = ACTIONS(3152),
    [anon_sym_U_SQUOTE] = ACTIONS(3152),
    [anon_sym_u8_SQUOTE] = ACTIONS(3152),
    [anon_sym_SQUOTE] = ACTIONS(3152),
    [anon_sym_L_DQUOTE] = ACTIONS(3155),
    [anon_sym_u_DQUOTE] = ACTIONS(3155),
    [anon_sym_U_DQUOTE] = ACTIONS(3155),
    [anon_sym_u8_DQUOTE] = ACTIONS(3155),
    [anon_sym_DQUOTE] = ACTIONS(3155),
    [sym_true] = ACTIONS(3158),
    [sym_false] = ACTIONS(3158),
    [anon_sym_NULL] = ACTIONS(3161),
    [anon_sym_nullptr] = ACTIONS(3161),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(3164),
    [anon_sym_template] = ACTIONS(3167),
    [anon_sym_try] = ACTIONS(3170),
    [anon_sym_delete] = ACTIONS(3173),
    [anon_sym_throw] = ACTIONS(3176),
    [anon_sym_co_return] = ACTIONS(3179),
    [anon_sym_co_yield] = ACTIONS(3182),
    [anon_sym_R_DQUOTE] = ACTIONS(3185),
    [anon_sym_LR_DQUOTE] = ACTIONS(3185),
    [anon_sym_uR_DQUOTE] = ACTIONS(3185),
    [anon_sym_UR_DQUOTE] = ACTIONS(3185),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3185),
    [anon_sym_co_await] = ACTIONS(3188),
    [anon_sym_new] = ACTIONS(3191),
    [anon_sym_requires] = ACTIONS(3194),
    [sym_this] = ACTIONS(3158),
    [anon_sym_discard] = ACTIONS(3197),
    [anon_sym_cbuffer] = ACTIONS(3200),
  },
  [840] = {
    [sym_attribute_declaration] = STATE(871),
    [sym_compound_statement] = STATE(416),
    [sym_attributed_statement] = STATE(416),
    [sym_statement] = STATE(393),
    [sym_labeled_statement] = STATE(416),
    [sym_expression_statement] = STATE(416),
    [sym_if_statement] = STATE(416),
    [sym_switch_statement] = STATE(416),
    [sym_case_statement] = STATE(416),
    [sym_while_statement] = STATE(416),
    [sym_do_statement] = STATE(416),
    [sym_for_statement] = STATE(416),
    [sym_return_statement] = STATE(416),
    [sym_break_statement] = STATE(416),
    [sym_continue_statement] = STATE(416),
    [sym_goto_statement] = STATE(416),
    [sym_seh_try_statement] = STATE(416),
    [sym_seh_leave_statement] = STATE(416),
    [sym_expression] = STATE(4525),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8558),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(416),
    [sym_co_return_statement] = STATE(416),
    [sym_co_yield_statement] = STATE(416),
    [sym_throw_statement] = STATE(416),
    [sym_try_statement] = STATE(416),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(416),
    [sym_cbuffer_specifier] = STATE(416),
    [sym_hlsl_attribute] = STATE(7458),
    [aux_sym_attributed_declarator_repeat1] = STATE(871),
    [sym_identifier] = ACTIONS(3053),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1477),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(81),
    [anon_sym_default] = ACTIONS(83),
    [anon_sym_while] = ACTIONS(85),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(1479),
    [anon_sym___leave] = ACTIONS(1481),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1483),
    [anon_sym_cbuffer] = ACTIONS(1485),
  },
  [841] = {
    [sym_attribute_declaration] = STATE(828),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(518),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7796),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [sym_identifier] = ACTIONS(3033),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [842] = {
    [sym_attribute_declaration] = STATE(891),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(8372),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7568),
    [aux_sym_attributed_declarator_repeat1] = STATE(891),
    [sym_identifier] = ACTIONS(3035),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(3037),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(3043),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(3045),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(3047),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(3049),
  },
  [843] = {
    [sym_attribute_declaration] = STATE(850),
    [sym_compound_statement] = STATE(178),
    [sym_attributed_statement] = STATE(178),
    [sym_statement] = STATE(210),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(7801),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [sym_identifier] = ACTIONS(3057),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [844] = {
    [sym_attribute_declaration] = STATE(827),
    [sym_compound_statement] = STATE(468),
    [sym_attributed_statement] = STATE(468),
    [sym_statement] = STATE(391),
    [sym_labeled_statement] = STATE(468),
    [sym_expression_statement] = STATE(468),
    [sym_if_statement] = STATE(468),
    [sym_switch_statement] = STATE(468),
    [sym_case_statement] = STATE(468),
    [sym_while_statement] = STATE(468),
    [sym_do_statement] = STATE(468),
    [sym_for_statement] = STATE(468),
    [sym_return_statement] = STATE(468),
    [sym_break_statement] = STATE(468),
    [sym_continue_statement] = STATE(468),
    [sym_goto_statement] = STATE(468),
    [sym_seh_try_statement] = STATE(468),
    [sym_seh_leave_statement] = STATE(468),
    [sym_expression] = STATE(4453),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7849),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(468),
    [sym_co_return_statement] = STATE(468),
    [sym_co_yield_statement] = STATE(468),
    [sym_throw_statement] = STATE(468),
    [sym_try_statement] = STATE(468),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(468),
    [sym_cbuffer_specifier] = STATE(468),
    [sym_hlsl_attribute] = STATE(7711),
    [aux_sym_attributed_declarator_repeat1] = STATE(827),
    [sym_identifier] = ACTIONS(3051),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(785),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(793),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(797),
    [anon_sym_switch] = ACTIONS(799),
    [anon_sym_case] = ACTIONS(801),
    [anon_sym_default] = ACTIONS(803),
    [anon_sym_while] = ACTIONS(805),
    [anon_sym_do] = ACTIONS(807),
    [anon_sym_for] = ACTIONS(809),
    [anon_sym_return] = ACTIONS(811),
    [anon_sym_break] = ACTIONS(813),
    [anon_sym_continue] = ACTIONS(815),
    [anon_sym_goto] = ACTIONS(817),
    [anon_sym___try] = ACTIONS(819),
    [anon_sym___leave] = ACTIONS(821),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(825),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(827),
    [anon_sym_co_return] = ACTIONS(837),
    [anon_sym_co_yield] = ACTIONS(839),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(841),
    [anon_sym_cbuffer] = ACTIONS(843),
  },
  [845] = {
    [sym_attribute_declaration] = STATE(827),
    [sym_compound_statement] = STATE(468),
    [sym_attributed_statement] = STATE(468),
    [sym_statement] = STATE(438),
    [sym_labeled_statement] = STATE(468),
    [sym_expression_statement] = STATE(468),
    [sym_if_statement] = STATE(468),
    [sym_switch_statement] = STATE(468),
    [sym_case_statement] = STATE(468),
    [sym_while_statement] = STATE(468),
    [sym_do_statement] = STATE(468),
    [sym_for_statement] = STATE(468),
    [sym_return_statement] = STATE(468),
    [sym_break_statement] = STATE(468),
    [sym_continue_statement] = STATE(468),
    [sym_goto_statement] = STATE(468),
    [sym_seh_try_statement] = STATE(468),
    [sym_seh_leave_statement] = STATE(468),
    [sym_expression] = STATE(4453),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7849),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(468),
    [sym_co_return_statement] = STATE(468),
    [sym_co_yield_statement] = STATE(468),
    [sym_throw_statement] = STATE(468),
    [sym_try_statement] = STATE(468),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(468),
    [sym_cbuffer_specifier] = STATE(468),
    [sym_hlsl_attribute] = STATE(7711),
    [aux_sym_attributed_declarator_repeat1] = STATE(827),
    [sym_identifier] = ACTIONS(3051),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(785),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(793),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(797),
    [anon_sym_switch] = ACTIONS(799),
    [anon_sym_case] = ACTIONS(801),
    [anon_sym_default] = ACTIONS(803),
    [anon_sym_while] = ACTIONS(805),
    [anon_sym_do] = ACTIONS(807),
    [anon_sym_for] = ACTIONS(809),
    [anon_sym_return] = ACTIONS(811),
    [anon_sym_break] = ACTIONS(813),
    [anon_sym_continue] = ACTIONS(815),
    [anon_sym_goto] = ACTIONS(817),
    [anon_sym___try] = ACTIONS(819),
    [anon_sym___leave] = ACTIONS(821),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(825),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(827),
    [anon_sym_co_return] = ACTIONS(837),
    [anon_sym_co_yield] = ACTIONS(839),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(841),
    [anon_sym_cbuffer] = ACTIONS(843),
  },
  [846] = {
    [sym_attribute_declaration] = STATE(840),
    [sym_compound_statement] = STATE(416),
    [sym_attributed_statement] = STATE(416),
    [sym_statement] = STATE(379),
    [sym_labeled_statement] = STATE(416),
    [sym_expression_statement] = STATE(416),
    [sym_if_statement] = STATE(416),
    [sym_switch_statement] = STATE(416),
    [sym_case_statement] = STATE(416),
    [sym_while_statement] = STATE(416),
    [sym_do_statement] = STATE(416),
    [sym_for_statement] = STATE(416),
    [sym_return_statement] = STATE(416),
    [sym_break_statement] = STATE(416),
    [sym_continue_statement] = STATE(416),
    [sym_goto_statement] = STATE(416),
    [sym_seh_try_statement] = STATE(416),
    [sym_seh_leave_statement] = STATE(416),
    [sym_expression] = STATE(4525),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8558),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(416),
    [sym_co_return_statement] = STATE(416),
    [sym_co_yield_statement] = STATE(416),
    [sym_throw_statement] = STATE(416),
    [sym_try_statement] = STATE(416),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(416),
    [sym_cbuffer_specifier] = STATE(416),
    [sym_hlsl_attribute] = STATE(7458),
    [aux_sym_attributed_declarator_repeat1] = STATE(840),
    [sym_identifier] = ACTIONS(3053),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1477),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(81),
    [anon_sym_default] = ACTIONS(83),
    [anon_sym_while] = ACTIONS(85),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(1479),
    [anon_sym___leave] = ACTIONS(1481),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1483),
    [anon_sym_cbuffer] = ACTIONS(1485),
  },
  [847] = {
    [sym_attribute_declaration] = STATE(840),
    [sym_compound_statement] = STATE(416),
    [sym_attributed_statement] = STATE(416),
    [sym_statement] = STATE(395),
    [sym_labeled_statement] = STATE(416),
    [sym_expression_statement] = STATE(416),
    [sym_if_statement] = STATE(416),
    [sym_switch_statement] = STATE(416),
    [sym_case_statement] = STATE(416),
    [sym_while_statement] = STATE(416),
    [sym_do_statement] = STATE(416),
    [sym_for_statement] = STATE(416),
    [sym_return_statement] = STATE(416),
    [sym_break_statement] = STATE(416),
    [sym_continue_statement] = STATE(416),
    [sym_goto_statement] = STATE(416),
    [sym_seh_try_statement] = STATE(416),
    [sym_seh_leave_statement] = STATE(416),
    [sym_expression] = STATE(4525),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8558),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(416),
    [sym_co_return_statement] = STATE(416),
    [sym_co_yield_statement] = STATE(416),
    [sym_throw_statement] = STATE(416),
    [sym_try_statement] = STATE(416),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(416),
    [sym_cbuffer_specifier] = STATE(416),
    [sym_hlsl_attribute] = STATE(7458),
    [aux_sym_attributed_declarator_repeat1] = STATE(840),
    [sym_identifier] = ACTIONS(3053),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1477),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(81),
    [anon_sym_default] = ACTIONS(83),
    [anon_sym_while] = ACTIONS(85),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(1479),
    [anon_sym___leave] = ACTIONS(1481),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1483),
    [anon_sym_cbuffer] = ACTIONS(1485),
  },
  [848] = {
    [sym_attribute_declaration] = STATE(875),
    [sym_compound_statement] = STATE(1056),
    [sym_attributed_statement] = STATE(1056),
    [sym_statement] = STATE(988),
    [sym_labeled_statement] = STATE(1056),
    [sym_expression_statement] = STATE(1056),
    [sym_if_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_case_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_do_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_return_statement] = STATE(1056),
    [sym_break_statement] = STATE(1056),
    [sym_continue_statement] = STATE(1056),
    [sym_goto_statement] = STATE(1056),
    [sym_seh_try_statement] = STATE(1056),
    [sym_seh_leave_statement] = STATE(1056),
    [sym_expression] = STATE(4514),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8003),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(1056),
    [sym_co_return_statement] = STATE(1056),
    [sym_co_yield_statement] = STATE(1056),
    [sym_throw_statement] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(1056),
    [sym_cbuffer_specifier] = STATE(1056),
    [sym_hlsl_attribute] = STATE(7744),
    [aux_sym_attributed_declarator_repeat1] = STATE(875),
    [sym_identifier] = ACTIONS(3055),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(1697),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(1701),
    [anon_sym_do] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1705),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1709),
    [anon_sym_continue] = ACTIONS(1711),
    [anon_sym_goto] = ACTIONS(1713),
    [anon_sym___try] = ACTIONS(1715),
    [anon_sym___leave] = ACTIONS(1717),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1719),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(1721),
    [anon_sym_co_return] = ACTIONS(1723),
    [anon_sym_co_yield] = ACTIONS(1725),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1727),
    [anon_sym_cbuffer] = ACTIONS(1729),
  },
  [849] = {
    [sym_attribute_declaration] = STATE(875),
    [sym_compound_statement] = STATE(1056),
    [sym_attributed_statement] = STATE(1056),
    [sym_statement] = STATE(1001),
    [sym_labeled_statement] = STATE(1056),
    [sym_expression_statement] = STATE(1056),
    [sym_if_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_case_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_do_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_return_statement] = STATE(1056),
    [sym_break_statement] = STATE(1056),
    [sym_continue_statement] = STATE(1056),
    [sym_goto_statement] = STATE(1056),
    [sym_seh_try_statement] = STATE(1056),
    [sym_seh_leave_statement] = STATE(1056),
    [sym_expression] = STATE(4514),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8003),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(1056),
    [sym_co_return_statement] = STATE(1056),
    [sym_co_yield_statement] = STATE(1056),
    [sym_throw_statement] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(1056),
    [sym_cbuffer_specifier] = STATE(1056),
    [sym_hlsl_attribute] = STATE(7744),
    [aux_sym_attributed_declarator_repeat1] = STATE(875),
    [sym_identifier] = ACTIONS(3055),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(1697),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(1701),
    [anon_sym_do] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1705),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1709),
    [anon_sym_continue] = ACTIONS(1711),
    [anon_sym_goto] = ACTIONS(1713),
    [anon_sym___try] = ACTIONS(1715),
    [anon_sym___leave] = ACTIONS(1717),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1719),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(1721),
    [anon_sym_co_return] = ACTIONS(1723),
    [anon_sym_co_yield] = ACTIONS(1725),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1727),
    [anon_sym_cbuffer] = ACTIONS(1729),
  },
  [850] = {
    [sym_attribute_declaration] = STATE(873),
    [sym_compound_statement] = STATE(178),
    [sym_attributed_statement] = STATE(178),
    [sym_statement] = STATE(189),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(7801),
    [aux_sym_attributed_declarator_repeat1] = STATE(873),
    [sym_identifier] = ACTIONS(3057),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [851] = {
    [sym_attribute_declaration] = STATE(827),
    [sym_compound_statement] = STATE(468),
    [sym_attributed_statement] = STATE(468),
    [sym_statement] = STATE(352),
    [sym_labeled_statement] = STATE(468),
    [sym_expression_statement] = STATE(468),
    [sym_if_statement] = STATE(468),
    [sym_switch_statement] = STATE(468),
    [sym_case_statement] = STATE(468),
    [sym_while_statement] = STATE(468),
    [sym_do_statement] = STATE(468),
    [sym_for_statement] = STATE(468),
    [sym_return_statement] = STATE(468),
    [sym_break_statement] = STATE(468),
    [sym_continue_statement] = STATE(468),
    [sym_goto_statement] = STATE(468),
    [sym_seh_try_statement] = STATE(468),
    [sym_seh_leave_statement] = STATE(468),
    [sym_expression] = STATE(4453),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7849),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(468),
    [sym_co_return_statement] = STATE(468),
    [sym_co_yield_statement] = STATE(468),
    [sym_throw_statement] = STATE(468),
    [sym_try_statement] = STATE(468),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(468),
    [sym_cbuffer_specifier] = STATE(468),
    [sym_hlsl_attribute] = STATE(7711),
    [aux_sym_attributed_declarator_repeat1] = STATE(827),
    [sym_identifier] = ACTIONS(3051),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(785),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(793),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(797),
    [anon_sym_switch] = ACTIONS(799),
    [anon_sym_case] = ACTIONS(801),
    [anon_sym_default] = ACTIONS(803),
    [anon_sym_while] = ACTIONS(805),
    [anon_sym_do] = ACTIONS(807),
    [anon_sym_for] = ACTIONS(809),
    [anon_sym_return] = ACTIONS(811),
    [anon_sym_break] = ACTIONS(813),
    [anon_sym_continue] = ACTIONS(815),
    [anon_sym_goto] = ACTIONS(817),
    [anon_sym___try] = ACTIONS(819),
    [anon_sym___leave] = ACTIONS(821),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(825),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(827),
    [anon_sym_co_return] = ACTIONS(837),
    [anon_sym_co_yield] = ACTIONS(839),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(841),
    [anon_sym_cbuffer] = ACTIONS(843),
  },
  [852] = {
    [sym_attribute_declaration] = STATE(840),
    [sym_compound_statement] = STATE(416),
    [sym_attributed_statement] = STATE(416),
    [sym_statement] = STATE(425),
    [sym_labeled_statement] = STATE(416),
    [sym_expression_statement] = STATE(416),
    [sym_if_statement] = STATE(416),
    [sym_switch_statement] = STATE(416),
    [sym_case_statement] = STATE(416),
    [sym_while_statement] = STATE(416),
    [sym_do_statement] = STATE(416),
    [sym_for_statement] = STATE(416),
    [sym_return_statement] = STATE(416),
    [sym_break_statement] = STATE(416),
    [sym_continue_statement] = STATE(416),
    [sym_goto_statement] = STATE(416),
    [sym_seh_try_statement] = STATE(416),
    [sym_seh_leave_statement] = STATE(416),
    [sym_expression] = STATE(4525),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8558),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(416),
    [sym_co_return_statement] = STATE(416),
    [sym_co_yield_statement] = STATE(416),
    [sym_throw_statement] = STATE(416),
    [sym_try_statement] = STATE(416),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(416),
    [sym_cbuffer_specifier] = STATE(416),
    [sym_hlsl_attribute] = STATE(7458),
    [aux_sym_attributed_declarator_repeat1] = STATE(840),
    [sym_identifier] = ACTIONS(3053),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1477),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(81),
    [anon_sym_default] = ACTIONS(83),
    [anon_sym_while] = ACTIONS(85),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(1479),
    [anon_sym___leave] = ACTIONS(1481),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1483),
    [anon_sym_cbuffer] = ACTIONS(1485),
  },
  [853] = {
    [sym_attribute_declaration] = STATE(875),
    [sym_compound_statement] = STATE(1056),
    [sym_attributed_statement] = STATE(1056),
    [sym_statement] = STATE(990),
    [sym_labeled_statement] = STATE(1056),
    [sym_expression_statement] = STATE(1056),
    [sym_if_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_case_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_do_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_return_statement] = STATE(1056),
    [sym_break_statement] = STATE(1056),
    [sym_continue_statement] = STATE(1056),
    [sym_goto_statement] = STATE(1056),
    [sym_seh_try_statement] = STATE(1056),
    [sym_seh_leave_statement] = STATE(1056),
    [sym_expression] = STATE(4514),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8003),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(1056),
    [sym_co_return_statement] = STATE(1056),
    [sym_co_yield_statement] = STATE(1056),
    [sym_throw_statement] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(1056),
    [sym_cbuffer_specifier] = STATE(1056),
    [sym_hlsl_attribute] = STATE(7744),
    [aux_sym_attributed_declarator_repeat1] = STATE(875),
    [sym_identifier] = ACTIONS(3055),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(1697),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(1701),
    [anon_sym_do] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1705),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1709),
    [anon_sym_continue] = ACTIONS(1711),
    [anon_sym_goto] = ACTIONS(1713),
    [anon_sym___try] = ACTIONS(1715),
    [anon_sym___leave] = ACTIONS(1717),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1719),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(1721),
    [anon_sym_co_return] = ACTIONS(1723),
    [anon_sym_co_yield] = ACTIONS(1725),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1727),
    [anon_sym_cbuffer] = ACTIONS(1729),
  },
  [854] = {
    [sym_attribute_declaration] = STATE(891),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(8386),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7568),
    [aux_sym_attributed_declarator_repeat1] = STATE(891),
    [sym_identifier] = ACTIONS(3035),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(3037),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(3043),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(3045),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(3047),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(3049),
  },
  [855] = {
    [sym_attribute_declaration] = STATE(840),
    [sym_compound_statement] = STATE(416),
    [sym_attributed_statement] = STATE(416),
    [sym_statement] = STATE(394),
    [sym_labeled_statement] = STATE(416),
    [sym_expression_statement] = STATE(416),
    [sym_if_statement] = STATE(416),
    [sym_switch_statement] = STATE(416),
    [sym_case_statement] = STATE(416),
    [sym_while_statement] = STATE(416),
    [sym_do_statement] = STATE(416),
    [sym_for_statement] = STATE(416),
    [sym_return_statement] = STATE(416),
    [sym_break_statement] = STATE(416),
    [sym_continue_statement] = STATE(416),
    [sym_goto_statement] = STATE(416),
    [sym_seh_try_statement] = STATE(416),
    [sym_seh_leave_statement] = STATE(416),
    [sym_expression] = STATE(4525),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8558),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(416),
    [sym_co_return_statement] = STATE(416),
    [sym_co_yield_statement] = STATE(416),
    [sym_throw_statement] = STATE(416),
    [sym_try_statement] = STATE(416),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(416),
    [sym_cbuffer_specifier] = STATE(416),
    [sym_hlsl_attribute] = STATE(7458),
    [aux_sym_attributed_declarator_repeat1] = STATE(840),
    [sym_identifier] = ACTIONS(3053),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1477),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(81),
    [anon_sym_default] = ACTIONS(83),
    [anon_sym_while] = ACTIONS(85),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(1479),
    [anon_sym___leave] = ACTIONS(1481),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1483),
    [anon_sym_cbuffer] = ACTIONS(1485),
  },
  [856] = {
    [sym_attribute_declaration] = STATE(850),
    [sym_compound_statement] = STATE(178),
    [sym_attributed_statement] = STATE(178),
    [sym_statement] = STATE(164),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(7801),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [sym_identifier] = ACTIONS(3057),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [857] = {
    [sym_attribute_declaration] = STATE(850),
    [sym_compound_statement] = STATE(178),
    [sym_attributed_statement] = STATE(178),
    [sym_statement] = STATE(206),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(7801),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [sym_identifier] = ACTIONS(3057),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [858] = {
    [sym_attribute_declaration] = STATE(858),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(470),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7796),
    [aux_sym_attributed_declarator_repeat1] = STATE(858),
    [sym_identifier] = ACTIONS(3203),
    [anon_sym_LPAREN2] = ACTIONS(3062),
    [anon_sym_BANG] = ACTIONS(3065),
    [anon_sym_TILDE] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3068),
    [anon_sym_PLUS] = ACTIONS(3068),
    [anon_sym_STAR] = ACTIONS(3071),
    [anon_sym_AMP] = ACTIONS(3071),
    [anon_sym_SEMI] = ACTIONS(3206),
    [anon_sym_COLON_COLON] = ACTIONS(3077),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3080),
    [anon_sym_LBRACE] = ACTIONS(3209),
    [anon_sym_LBRACK] = ACTIONS(3086),
    [sym_primitive_type] = ACTIONS(3089),
    [anon_sym_if] = ACTIONS(3212),
    [anon_sym_switch] = ACTIONS(3215),
    [anon_sym_case] = ACTIONS(3218),
    [anon_sym_default] = ACTIONS(3221),
    [anon_sym_while] = ACTIONS(3224),
    [anon_sym_do] = ACTIONS(3227),
    [anon_sym_for] = ACTIONS(3230),
    [anon_sym_return] = ACTIONS(3233),
    [anon_sym_break] = ACTIONS(3236),
    [anon_sym_continue] = ACTIONS(3239),
    [anon_sym_goto] = ACTIONS(3242),
    [anon_sym___try] = ACTIONS(3245),
    [anon_sym___leave] = ACTIONS(3248),
    [anon_sym_not] = ACTIONS(3068),
    [anon_sym_compl] = ACTIONS(3068),
    [anon_sym_DASH_DASH] = ACTIONS(3131),
    [anon_sym_PLUS_PLUS] = ACTIONS(3131),
    [anon_sym_sizeof] = ACTIONS(3134),
    [anon_sym___alignof__] = ACTIONS(3137),
    [anon_sym___alignof] = ACTIONS(3137),
    [anon_sym__alignof] = ACTIONS(3137),
    [anon_sym_alignof] = ACTIONS(3137),
    [anon_sym__Alignof] = ACTIONS(3137),
    [anon_sym_offsetof] = ACTIONS(3140),
    [anon_sym__Generic] = ACTIONS(3143),
    [anon_sym_asm] = ACTIONS(3146),
    [anon_sym___asm__] = ACTIONS(3146),
    [sym_number_literal] = ACTIONS(3149),
    [anon_sym_L_SQUOTE] = ACTIONS(3152),
    [anon_sym_u_SQUOTE] = ACTIONS(3152),
    [anon_sym_U_SQUOTE] = ACTIONS(3152),
    [anon_sym_u8_SQUOTE] = ACTIONS(3152),
    [anon_sym_SQUOTE] = ACTIONS(3152),
    [anon_sym_L_DQUOTE] = ACTIONS(3155),
    [anon_sym_u_DQUOTE] = ACTIONS(3155),
    [anon_sym_U_DQUOTE] = ACTIONS(3155),
    [anon_sym_u8_DQUOTE] = ACTIONS(3155),
    [anon_sym_DQUOTE] = ACTIONS(3155),
    [sym_true] = ACTIONS(3158),
    [sym_false] = ACTIONS(3158),
    [anon_sym_NULL] = ACTIONS(3161),
    [anon_sym_nullptr] = ACTIONS(3161),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(3164),
    [anon_sym_template] = ACTIONS(3167),
    [anon_sym_try] = ACTIONS(3251),
    [anon_sym_delete] = ACTIONS(3173),
    [anon_sym_throw] = ACTIONS(3254),
    [anon_sym_co_return] = ACTIONS(3257),
    [anon_sym_co_yield] = ACTIONS(3260),
    [anon_sym_R_DQUOTE] = ACTIONS(3185),
    [anon_sym_LR_DQUOTE] = ACTIONS(3185),
    [anon_sym_uR_DQUOTE] = ACTIONS(3185),
    [anon_sym_UR_DQUOTE] = ACTIONS(3185),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3185),
    [anon_sym_co_await] = ACTIONS(3188),
    [anon_sym_new] = ACTIONS(3191),
    [anon_sym_requires] = ACTIONS(3194),
    [sym_this] = ACTIONS(3158),
    [anon_sym_discard] = ACTIONS(3263),
    [anon_sym_cbuffer] = ACTIONS(3266),
  },
  [859] = {
    [sym_attribute_declaration] = STATE(891),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(8196),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7568),
    [aux_sym_attributed_declarator_repeat1] = STATE(891),
    [sym_identifier] = ACTIONS(3035),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(3037),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(3043),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(3045),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(3047),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(3049),
  },
  [860] = {
    [sym_attribute_declaration] = STATE(850),
    [sym_compound_statement] = STATE(178),
    [sym_attributed_statement] = STATE(178),
    [sym_statement] = STATE(214),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(7801),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [sym_identifier] = ACTIONS(3057),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [861] = {
    [sym_attribute_declaration] = STATE(828),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(543),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7796),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [sym_identifier] = ACTIONS(3033),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [862] = {
    [sym_attribute_declaration] = STATE(850),
    [sym_compound_statement] = STATE(178),
    [sym_attributed_statement] = STATE(178),
    [sym_statement] = STATE(221),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(7801),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [sym_identifier] = ACTIONS(3057),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [863] = {
    [sym_attribute_declaration] = STATE(891),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(534),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7568),
    [aux_sym_attributed_declarator_repeat1] = STATE(891),
    [sym_identifier] = ACTIONS(3035),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(3037),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(3043),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(3045),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(3047),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(3049),
  },
  [864] = {
    [sym_attribute_declaration] = STATE(850),
    [sym_compound_statement] = STATE(178),
    [sym_attributed_statement] = STATE(178),
    [sym_statement] = STATE(220),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(7801),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [sym_identifier] = ACTIONS(3057),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [865] = {
    [sym_attribute_declaration] = STATE(875),
    [sym_compound_statement] = STATE(1056),
    [sym_attributed_statement] = STATE(1056),
    [sym_statement] = STATE(996),
    [sym_labeled_statement] = STATE(1056),
    [sym_expression_statement] = STATE(1056),
    [sym_if_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_case_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_do_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_return_statement] = STATE(1056),
    [sym_break_statement] = STATE(1056),
    [sym_continue_statement] = STATE(1056),
    [sym_goto_statement] = STATE(1056),
    [sym_seh_try_statement] = STATE(1056),
    [sym_seh_leave_statement] = STATE(1056),
    [sym_expression] = STATE(4514),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8003),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(1056),
    [sym_co_return_statement] = STATE(1056),
    [sym_co_yield_statement] = STATE(1056),
    [sym_throw_statement] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(1056),
    [sym_cbuffer_specifier] = STATE(1056),
    [sym_hlsl_attribute] = STATE(7744),
    [aux_sym_attributed_declarator_repeat1] = STATE(875),
    [sym_identifier] = ACTIONS(3055),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(1697),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(1701),
    [anon_sym_do] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1705),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1709),
    [anon_sym_continue] = ACTIONS(1711),
    [anon_sym_goto] = ACTIONS(1713),
    [anon_sym___try] = ACTIONS(1715),
    [anon_sym___leave] = ACTIONS(1717),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1719),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(1721),
    [anon_sym_co_return] = ACTIONS(1723),
    [anon_sym_co_yield] = ACTIONS(1725),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1727),
    [anon_sym_cbuffer] = ACTIONS(1729),
  },
  [866] = {
    [sym_attribute_declaration] = STATE(891),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(425),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7568),
    [aux_sym_attributed_declarator_repeat1] = STATE(891),
    [sym_identifier] = ACTIONS(3035),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(3037),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(3043),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(3045),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(3047),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(3049),
  },
  [867] = {
    [sym_attribute_declaration] = STATE(850),
    [sym_compound_statement] = STATE(178),
    [sym_attributed_statement] = STATE(178),
    [sym_statement] = STATE(204),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(7801),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [sym_identifier] = ACTIONS(3057),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [868] = {
    [sym_attribute_declaration] = STATE(891),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(7174),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7568),
    [aux_sym_attributed_declarator_repeat1] = STATE(891),
    [sym_identifier] = ACTIONS(3035),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(3037),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(3043),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(3045),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(3047),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(3049),
  },
  [869] = {
    [sym_attribute_declaration] = STATE(891),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(529),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7568),
    [aux_sym_attributed_declarator_repeat1] = STATE(891),
    [sym_identifier] = ACTIONS(3035),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(3037),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(3043),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(3045),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(3047),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(3049),
  },
  [870] = {
    [sym_attribute_declaration] = STATE(891),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(394),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7568),
    [aux_sym_attributed_declarator_repeat1] = STATE(891),
    [sym_identifier] = ACTIONS(3035),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(3037),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(3043),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(3045),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(3047),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(3049),
  },
  [871] = {
    [sym_attribute_declaration] = STATE(871),
    [sym_compound_statement] = STATE(416),
    [sym_attributed_statement] = STATE(416),
    [sym_statement] = STATE(393),
    [sym_labeled_statement] = STATE(416),
    [sym_expression_statement] = STATE(416),
    [sym_if_statement] = STATE(416),
    [sym_switch_statement] = STATE(416),
    [sym_case_statement] = STATE(416),
    [sym_while_statement] = STATE(416),
    [sym_do_statement] = STATE(416),
    [sym_for_statement] = STATE(416),
    [sym_return_statement] = STATE(416),
    [sym_break_statement] = STATE(416),
    [sym_continue_statement] = STATE(416),
    [sym_goto_statement] = STATE(416),
    [sym_seh_try_statement] = STATE(416),
    [sym_seh_leave_statement] = STATE(416),
    [sym_expression] = STATE(4525),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8558),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(416),
    [sym_co_return_statement] = STATE(416),
    [sym_co_yield_statement] = STATE(416),
    [sym_throw_statement] = STATE(416),
    [sym_try_statement] = STATE(416),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(416),
    [sym_cbuffer_specifier] = STATE(416),
    [sym_hlsl_attribute] = STATE(7458),
    [aux_sym_attributed_declarator_repeat1] = STATE(871),
    [sym_identifier] = ACTIONS(3269),
    [anon_sym_LPAREN2] = ACTIONS(3062),
    [anon_sym_BANG] = ACTIONS(3065),
    [anon_sym_TILDE] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3068),
    [anon_sym_PLUS] = ACTIONS(3068),
    [anon_sym_STAR] = ACTIONS(3071),
    [anon_sym_AMP] = ACTIONS(3071),
    [anon_sym_SEMI] = ACTIONS(3272),
    [anon_sym_COLON_COLON] = ACTIONS(3077),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3080),
    [anon_sym_LBRACE] = ACTIONS(3275),
    [anon_sym_LBRACK] = ACTIONS(3086),
    [sym_primitive_type] = ACTIONS(3089),
    [anon_sym_if] = ACTIONS(3278),
    [anon_sym_switch] = ACTIONS(3281),
    [anon_sym_case] = ACTIONS(3284),
    [anon_sym_default] = ACTIONS(3287),
    [anon_sym_while] = ACTIONS(3290),
    [anon_sym_do] = ACTIONS(3293),
    [anon_sym_for] = ACTIONS(3296),
    [anon_sym_return] = ACTIONS(3299),
    [anon_sym_break] = ACTIONS(3302),
    [anon_sym_continue] = ACTIONS(3305),
    [anon_sym_goto] = ACTIONS(3308),
    [anon_sym___try] = ACTIONS(3311),
    [anon_sym___leave] = ACTIONS(3314),
    [anon_sym_not] = ACTIONS(3068),
    [anon_sym_compl] = ACTIONS(3068),
    [anon_sym_DASH_DASH] = ACTIONS(3131),
    [anon_sym_PLUS_PLUS] = ACTIONS(3131),
    [anon_sym_sizeof] = ACTIONS(3134),
    [anon_sym___alignof__] = ACTIONS(3137),
    [anon_sym___alignof] = ACTIONS(3137),
    [anon_sym__alignof] = ACTIONS(3137),
    [anon_sym_alignof] = ACTIONS(3137),
    [anon_sym__Alignof] = ACTIONS(3137),
    [anon_sym_offsetof] = ACTIONS(3140),
    [anon_sym__Generic] = ACTIONS(3143),
    [anon_sym_asm] = ACTIONS(3146),
    [anon_sym___asm__] = ACTIONS(3146),
    [sym_number_literal] = ACTIONS(3149),
    [anon_sym_L_SQUOTE] = ACTIONS(3152),
    [anon_sym_u_SQUOTE] = ACTIONS(3152),
    [anon_sym_U_SQUOTE] = ACTIONS(3152),
    [anon_sym_u8_SQUOTE] = ACTIONS(3152),
    [anon_sym_SQUOTE] = ACTIONS(3152),
    [anon_sym_L_DQUOTE] = ACTIONS(3155),
    [anon_sym_u_DQUOTE] = ACTIONS(3155),
    [anon_sym_U_DQUOTE] = ACTIONS(3155),
    [anon_sym_u8_DQUOTE] = ACTIONS(3155),
    [anon_sym_DQUOTE] = ACTIONS(3155),
    [sym_true] = ACTIONS(3158),
    [sym_false] = ACTIONS(3158),
    [anon_sym_NULL] = ACTIONS(3161),
    [anon_sym_nullptr] = ACTIONS(3161),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(3164),
    [anon_sym_template] = ACTIONS(3167),
    [anon_sym_try] = ACTIONS(3317),
    [anon_sym_delete] = ACTIONS(3173),
    [anon_sym_throw] = ACTIONS(3320),
    [anon_sym_co_return] = ACTIONS(3323),
    [anon_sym_co_yield] = ACTIONS(3326),
    [anon_sym_R_DQUOTE] = ACTIONS(3185),
    [anon_sym_LR_DQUOTE] = ACTIONS(3185),
    [anon_sym_uR_DQUOTE] = ACTIONS(3185),
    [anon_sym_UR_DQUOTE] = ACTIONS(3185),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3185),
    [anon_sym_co_await] = ACTIONS(3188),
    [anon_sym_new] = ACTIONS(3191),
    [anon_sym_requires] = ACTIONS(3194),
    [sym_this] = ACTIONS(3158),
    [anon_sym_discard] = ACTIONS(3329),
    [anon_sym_cbuffer] = ACTIONS(3332),
  },
  [872] = {
    [sym_attribute_declaration] = STATE(872),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(393),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7568),
    [aux_sym_attributed_declarator_repeat1] = STATE(872),
    [sym_identifier] = ACTIONS(3335),
    [anon_sym_LPAREN2] = ACTIONS(3062),
    [anon_sym_BANG] = ACTIONS(3065),
    [anon_sym_TILDE] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3068),
    [anon_sym_PLUS] = ACTIONS(3068),
    [anon_sym_STAR] = ACTIONS(3071),
    [anon_sym_AMP] = ACTIONS(3071),
    [anon_sym_SEMI] = ACTIONS(3206),
    [anon_sym_COLON_COLON] = ACTIONS(3077),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3080),
    [anon_sym_LBRACE] = ACTIONS(3275),
    [anon_sym_LBRACK] = ACTIONS(3086),
    [sym_primitive_type] = ACTIONS(3089),
    [anon_sym_if] = ACTIONS(3338),
    [anon_sym_switch] = ACTIONS(3281),
    [anon_sym_case] = ACTIONS(3098),
    [anon_sym_default] = ACTIONS(3101),
    [anon_sym_while] = ACTIONS(3341),
    [anon_sym_do] = ACTIONS(3293),
    [anon_sym_for] = ACTIONS(3344),
    [anon_sym_return] = ACTIONS(3299),
    [anon_sym_break] = ACTIONS(3302),
    [anon_sym_continue] = ACTIONS(3305),
    [anon_sym_goto] = ACTIONS(3308),
    [anon_sym___try] = ACTIONS(3347),
    [anon_sym___leave] = ACTIONS(3248),
    [anon_sym_not] = ACTIONS(3068),
    [anon_sym_compl] = ACTIONS(3068),
    [anon_sym_DASH_DASH] = ACTIONS(3131),
    [anon_sym_PLUS_PLUS] = ACTIONS(3131),
    [anon_sym_sizeof] = ACTIONS(3134),
    [anon_sym___alignof__] = ACTIONS(3137),
    [anon_sym___alignof] = ACTIONS(3137),
    [anon_sym__alignof] = ACTIONS(3137),
    [anon_sym_alignof] = ACTIONS(3137),
    [anon_sym__Alignof] = ACTIONS(3137),
    [anon_sym_offsetof] = ACTIONS(3140),
    [anon_sym__Generic] = ACTIONS(3143),
    [anon_sym_asm] = ACTIONS(3146),
    [anon_sym___asm__] = ACTIONS(3146),
    [sym_number_literal] = ACTIONS(3149),
    [anon_sym_L_SQUOTE] = ACTIONS(3152),
    [anon_sym_u_SQUOTE] = ACTIONS(3152),
    [anon_sym_U_SQUOTE] = ACTIONS(3152),
    [anon_sym_u8_SQUOTE] = ACTIONS(3152),
    [anon_sym_SQUOTE] = ACTIONS(3152),
    [anon_sym_L_DQUOTE] = ACTIONS(3155),
    [anon_sym_u_DQUOTE] = ACTIONS(3155),
    [anon_sym_U_DQUOTE] = ACTIONS(3155),
    [anon_sym_u8_DQUOTE] = ACTIONS(3155),
    [anon_sym_DQUOTE] = ACTIONS(3155),
    [sym_true] = ACTIONS(3158),
    [sym_false] = ACTIONS(3158),
    [anon_sym_NULL] = ACTIONS(3161),
    [anon_sym_nullptr] = ACTIONS(3161),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(3164),
    [anon_sym_template] = ACTIONS(3167),
    [anon_sym_try] = ACTIONS(3317),
    [anon_sym_delete] = ACTIONS(3173),
    [anon_sym_throw] = ACTIONS(3320),
    [anon_sym_co_return] = ACTIONS(3323),
    [anon_sym_co_yield] = ACTIONS(3326),
    [anon_sym_R_DQUOTE] = ACTIONS(3185),
    [anon_sym_LR_DQUOTE] = ACTIONS(3185),
    [anon_sym_uR_DQUOTE] = ACTIONS(3185),
    [anon_sym_UR_DQUOTE] = ACTIONS(3185),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3185),
    [anon_sym_co_await] = ACTIONS(3188),
    [anon_sym_new] = ACTIONS(3191),
    [anon_sym_requires] = ACTIONS(3194),
    [sym_this] = ACTIONS(3158),
    [anon_sym_discard] = ACTIONS(3263),
    [anon_sym_cbuffer] = ACTIONS(3350),
  },
  [873] = {
    [sym_attribute_declaration] = STATE(873),
    [sym_compound_statement] = STATE(178),
    [sym_attributed_statement] = STATE(178),
    [sym_statement] = STATE(189),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(7801),
    [aux_sym_attributed_declarator_repeat1] = STATE(873),
    [sym_identifier] = ACTIONS(3353),
    [anon_sym_LPAREN2] = ACTIONS(3062),
    [anon_sym_BANG] = ACTIONS(3065),
    [anon_sym_TILDE] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3068),
    [anon_sym_PLUS] = ACTIONS(3068),
    [anon_sym_STAR] = ACTIONS(3071),
    [anon_sym_AMP] = ACTIONS(3071),
    [anon_sym_SEMI] = ACTIONS(3356),
    [anon_sym_COLON_COLON] = ACTIONS(3077),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3080),
    [anon_sym_LBRACE] = ACTIONS(3359),
    [anon_sym_LBRACK] = ACTIONS(3086),
    [sym_primitive_type] = ACTIONS(3089),
    [anon_sym_if] = ACTIONS(3362),
    [anon_sym_switch] = ACTIONS(3365),
    [anon_sym_case] = ACTIONS(3368),
    [anon_sym_default] = ACTIONS(3371),
    [anon_sym_while] = ACTIONS(3374),
    [anon_sym_do] = ACTIONS(3377),
    [anon_sym_for] = ACTIONS(3380),
    [anon_sym_return] = ACTIONS(3383),
    [anon_sym_break] = ACTIONS(3386),
    [anon_sym_continue] = ACTIONS(3389),
    [anon_sym_goto] = ACTIONS(3392),
    [anon_sym___try] = ACTIONS(3395),
    [anon_sym___leave] = ACTIONS(3398),
    [anon_sym_not] = ACTIONS(3068),
    [anon_sym_compl] = ACTIONS(3068),
    [anon_sym_DASH_DASH] = ACTIONS(3131),
    [anon_sym_PLUS_PLUS] = ACTIONS(3131),
    [anon_sym_sizeof] = ACTIONS(3134),
    [anon_sym___alignof__] = ACTIONS(3137),
    [anon_sym___alignof] = ACTIONS(3137),
    [anon_sym__alignof] = ACTIONS(3137),
    [anon_sym_alignof] = ACTIONS(3137),
    [anon_sym__Alignof] = ACTIONS(3137),
    [anon_sym_offsetof] = ACTIONS(3140),
    [anon_sym__Generic] = ACTIONS(3143),
    [anon_sym_asm] = ACTIONS(3146),
    [anon_sym___asm__] = ACTIONS(3146),
    [sym_number_literal] = ACTIONS(3149),
    [anon_sym_L_SQUOTE] = ACTIONS(3152),
    [anon_sym_u_SQUOTE] = ACTIONS(3152),
    [anon_sym_U_SQUOTE] = ACTIONS(3152),
    [anon_sym_u8_SQUOTE] = ACTIONS(3152),
    [anon_sym_SQUOTE] = ACTIONS(3152),
    [anon_sym_L_DQUOTE] = ACTIONS(3155),
    [anon_sym_u_DQUOTE] = ACTIONS(3155),
    [anon_sym_U_DQUOTE] = ACTIONS(3155),
    [anon_sym_u8_DQUOTE] = ACTIONS(3155),
    [anon_sym_DQUOTE] = ACTIONS(3155),
    [sym_true] = ACTIONS(3158),
    [sym_false] = ACTIONS(3158),
    [anon_sym_NULL] = ACTIONS(3161),
    [anon_sym_nullptr] = ACTIONS(3161),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(3164),
    [anon_sym_template] = ACTIONS(3167),
    [anon_sym_try] = ACTIONS(3401),
    [anon_sym_delete] = ACTIONS(3173),
    [anon_sym_throw] = ACTIONS(3404),
    [anon_sym_co_return] = ACTIONS(3407),
    [anon_sym_co_yield] = ACTIONS(3410),
    [anon_sym_R_DQUOTE] = ACTIONS(3185),
    [anon_sym_LR_DQUOTE] = ACTIONS(3185),
    [anon_sym_uR_DQUOTE] = ACTIONS(3185),
    [anon_sym_UR_DQUOTE] = ACTIONS(3185),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3185),
    [anon_sym_co_await] = ACTIONS(3188),
    [anon_sym_new] = ACTIONS(3191),
    [anon_sym_requires] = ACTIONS(3194),
    [sym_this] = ACTIONS(3158),
    [anon_sym_discard] = ACTIONS(3413),
    [anon_sym_cbuffer] = ACTIONS(3416),
  },
  [874] = {
    [sym_attribute_declaration] = STATE(891),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(395),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7568),
    [aux_sym_attributed_declarator_repeat1] = STATE(891),
    [sym_identifier] = ACTIONS(3035),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(3037),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(3043),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(3045),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(3047),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(3049),
  },
  [875] = {
    [sym_attribute_declaration] = STATE(839),
    [sym_compound_statement] = STATE(1056),
    [sym_attributed_statement] = STATE(1056),
    [sym_statement] = STATE(1018),
    [sym_labeled_statement] = STATE(1056),
    [sym_expression_statement] = STATE(1056),
    [sym_if_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_case_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_do_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_return_statement] = STATE(1056),
    [sym_break_statement] = STATE(1056),
    [sym_continue_statement] = STATE(1056),
    [sym_goto_statement] = STATE(1056),
    [sym_seh_try_statement] = STATE(1056),
    [sym_seh_leave_statement] = STATE(1056),
    [sym_expression] = STATE(4514),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8003),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(1056),
    [sym_co_return_statement] = STATE(1056),
    [sym_co_yield_statement] = STATE(1056),
    [sym_throw_statement] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(1056),
    [sym_cbuffer_specifier] = STATE(1056),
    [sym_hlsl_attribute] = STATE(7744),
    [aux_sym_attributed_declarator_repeat1] = STATE(839),
    [sym_identifier] = ACTIONS(3055),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(1697),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(1701),
    [anon_sym_do] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1705),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1709),
    [anon_sym_continue] = ACTIONS(1711),
    [anon_sym_goto] = ACTIONS(1713),
    [anon_sym___try] = ACTIONS(1715),
    [anon_sym___leave] = ACTIONS(1717),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1719),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(1721),
    [anon_sym_co_return] = ACTIONS(1723),
    [anon_sym_co_yield] = ACTIONS(1725),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1727),
    [anon_sym_cbuffer] = ACTIONS(1729),
  },
  [876] = {
    [sym_attribute_declaration] = STATE(891),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(397),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7568),
    [aux_sym_attributed_declarator_repeat1] = STATE(891),
    [sym_identifier] = ACTIONS(3035),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(3037),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(3043),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(3045),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(3047),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(3049),
  },
  [877] = {
    [sym_attribute_declaration] = STATE(828),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(479),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7796),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [sym_identifier] = ACTIONS(3033),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [878] = {
    [sym_attribute_declaration] = STATE(875),
    [sym_compound_statement] = STATE(1056),
    [sym_attributed_statement] = STATE(1056),
    [sym_statement] = STATE(1000),
    [sym_labeled_statement] = STATE(1056),
    [sym_expression_statement] = STATE(1056),
    [sym_if_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_case_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_do_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_return_statement] = STATE(1056),
    [sym_break_statement] = STATE(1056),
    [sym_continue_statement] = STATE(1056),
    [sym_goto_statement] = STATE(1056),
    [sym_seh_try_statement] = STATE(1056),
    [sym_seh_leave_statement] = STATE(1056),
    [sym_expression] = STATE(4514),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8003),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(1056),
    [sym_co_return_statement] = STATE(1056),
    [sym_co_yield_statement] = STATE(1056),
    [sym_throw_statement] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(1056),
    [sym_cbuffer_specifier] = STATE(1056),
    [sym_hlsl_attribute] = STATE(7744),
    [aux_sym_attributed_declarator_repeat1] = STATE(875),
    [sym_identifier] = ACTIONS(3055),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(1697),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(1701),
    [anon_sym_do] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1705),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1709),
    [anon_sym_continue] = ACTIONS(1711),
    [anon_sym_goto] = ACTIONS(1713),
    [anon_sym___try] = ACTIONS(1715),
    [anon_sym___leave] = ACTIONS(1717),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1719),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(1721),
    [anon_sym_co_return] = ACTIONS(1723),
    [anon_sym_co_yield] = ACTIONS(1725),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1727),
    [anon_sym_cbuffer] = ACTIONS(1729),
  },
  [879] = {
    [sym_attribute_declaration] = STATE(850),
    [sym_compound_statement] = STATE(178),
    [sym_attributed_statement] = STATE(178),
    [sym_statement] = STATE(170),
    [sym_labeled_statement] = STATE(178),
    [sym_expression_statement] = STATE(178),
    [sym_if_statement] = STATE(178),
    [sym_switch_statement] = STATE(178),
    [sym_case_statement] = STATE(178),
    [sym_while_statement] = STATE(178),
    [sym_do_statement] = STATE(178),
    [sym_for_statement] = STATE(178),
    [sym_return_statement] = STATE(178),
    [sym_break_statement] = STATE(178),
    [sym_continue_statement] = STATE(178),
    [sym_goto_statement] = STATE(178),
    [sym_seh_try_statement] = STATE(178),
    [sym_seh_leave_statement] = STATE(178),
    [sym_expression] = STATE(4474),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8247),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(178),
    [sym_co_return_statement] = STATE(178),
    [sym_co_yield_statement] = STATE(178),
    [sym_throw_statement] = STATE(178),
    [sym_try_statement] = STATE(178),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(178),
    [sym_cbuffer_specifier] = STATE(178),
    [sym_hlsl_attribute] = STATE(7801),
    [aux_sym_attributed_declarator_repeat1] = STATE(850),
    [sym_identifier] = ACTIONS(3057),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(285),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(293),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(297),
    [anon_sym_switch] = ACTIONS(299),
    [anon_sym_case] = ACTIONS(301),
    [anon_sym_default] = ACTIONS(303),
    [anon_sym_while] = ACTIONS(305),
    [anon_sym_do] = ACTIONS(307),
    [anon_sym_for] = ACTIONS(309),
    [anon_sym_return] = ACTIONS(311),
    [anon_sym_break] = ACTIONS(313),
    [anon_sym_continue] = ACTIONS(315),
    [anon_sym_goto] = ACTIONS(317),
    [anon_sym___try] = ACTIONS(319),
    [anon_sym___leave] = ACTIONS(321),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(325),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(327),
    [anon_sym_co_return] = ACTIONS(337),
    [anon_sym_co_yield] = ACTIONS(339),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(341),
    [anon_sym_cbuffer] = ACTIONS(343),
  },
  [880] = {
    [sym_attribute_declaration] = STATE(827),
    [sym_compound_statement] = STATE(468),
    [sym_attributed_statement] = STATE(468),
    [sym_statement] = STATE(406),
    [sym_labeled_statement] = STATE(468),
    [sym_expression_statement] = STATE(468),
    [sym_if_statement] = STATE(468),
    [sym_switch_statement] = STATE(468),
    [sym_case_statement] = STATE(468),
    [sym_while_statement] = STATE(468),
    [sym_do_statement] = STATE(468),
    [sym_for_statement] = STATE(468),
    [sym_return_statement] = STATE(468),
    [sym_break_statement] = STATE(468),
    [sym_continue_statement] = STATE(468),
    [sym_goto_statement] = STATE(468),
    [sym_seh_try_statement] = STATE(468),
    [sym_seh_leave_statement] = STATE(468),
    [sym_expression] = STATE(4453),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7849),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(468),
    [sym_co_return_statement] = STATE(468),
    [sym_co_yield_statement] = STATE(468),
    [sym_throw_statement] = STATE(468),
    [sym_try_statement] = STATE(468),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(468),
    [sym_cbuffer_specifier] = STATE(468),
    [sym_hlsl_attribute] = STATE(7711),
    [aux_sym_attributed_declarator_repeat1] = STATE(827),
    [sym_identifier] = ACTIONS(3051),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(785),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(793),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(797),
    [anon_sym_switch] = ACTIONS(799),
    [anon_sym_case] = ACTIONS(801),
    [anon_sym_default] = ACTIONS(803),
    [anon_sym_while] = ACTIONS(805),
    [anon_sym_do] = ACTIONS(807),
    [anon_sym_for] = ACTIONS(809),
    [anon_sym_return] = ACTIONS(811),
    [anon_sym_break] = ACTIONS(813),
    [anon_sym_continue] = ACTIONS(815),
    [anon_sym_goto] = ACTIONS(817),
    [anon_sym___try] = ACTIONS(819),
    [anon_sym___leave] = ACTIONS(821),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(825),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(827),
    [anon_sym_co_return] = ACTIONS(837),
    [anon_sym_co_yield] = ACTIONS(839),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(841),
    [anon_sym_cbuffer] = ACTIONS(843),
  },
  [881] = {
    [sym_attribute_declaration] = STATE(827),
    [sym_compound_statement] = STATE(468),
    [sym_attributed_statement] = STATE(468),
    [sym_statement] = STATE(407),
    [sym_labeled_statement] = STATE(468),
    [sym_expression_statement] = STATE(468),
    [sym_if_statement] = STATE(468),
    [sym_switch_statement] = STATE(468),
    [sym_case_statement] = STATE(468),
    [sym_while_statement] = STATE(468),
    [sym_do_statement] = STATE(468),
    [sym_for_statement] = STATE(468),
    [sym_return_statement] = STATE(468),
    [sym_break_statement] = STATE(468),
    [sym_continue_statement] = STATE(468),
    [sym_goto_statement] = STATE(468),
    [sym_seh_try_statement] = STATE(468),
    [sym_seh_leave_statement] = STATE(468),
    [sym_expression] = STATE(4453),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7849),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(468),
    [sym_co_return_statement] = STATE(468),
    [sym_co_yield_statement] = STATE(468),
    [sym_throw_statement] = STATE(468),
    [sym_try_statement] = STATE(468),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(468),
    [sym_cbuffer_specifier] = STATE(468),
    [sym_hlsl_attribute] = STATE(7711),
    [aux_sym_attributed_declarator_repeat1] = STATE(827),
    [sym_identifier] = ACTIONS(3051),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(785),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(793),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(797),
    [anon_sym_switch] = ACTIONS(799),
    [anon_sym_case] = ACTIONS(801),
    [anon_sym_default] = ACTIONS(803),
    [anon_sym_while] = ACTIONS(805),
    [anon_sym_do] = ACTIONS(807),
    [anon_sym_for] = ACTIONS(809),
    [anon_sym_return] = ACTIONS(811),
    [anon_sym_break] = ACTIONS(813),
    [anon_sym_continue] = ACTIONS(815),
    [anon_sym_goto] = ACTIONS(817),
    [anon_sym___try] = ACTIONS(819),
    [anon_sym___leave] = ACTIONS(821),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(825),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(827),
    [anon_sym_co_return] = ACTIONS(837),
    [anon_sym_co_yield] = ACTIONS(839),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(841),
    [anon_sym_cbuffer] = ACTIONS(843),
  },
  [882] = {
    [sym_attribute_declaration] = STATE(875),
    [sym_compound_statement] = STATE(1056),
    [sym_attributed_statement] = STATE(1056),
    [sym_statement] = STATE(1009),
    [sym_labeled_statement] = STATE(1056),
    [sym_expression_statement] = STATE(1056),
    [sym_if_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_case_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_do_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_return_statement] = STATE(1056),
    [sym_break_statement] = STATE(1056),
    [sym_continue_statement] = STATE(1056),
    [sym_goto_statement] = STATE(1056),
    [sym_seh_try_statement] = STATE(1056),
    [sym_seh_leave_statement] = STATE(1056),
    [sym_expression] = STATE(4514),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8003),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(1056),
    [sym_co_return_statement] = STATE(1056),
    [sym_co_yield_statement] = STATE(1056),
    [sym_throw_statement] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(1056),
    [sym_cbuffer_specifier] = STATE(1056),
    [sym_hlsl_attribute] = STATE(7744),
    [aux_sym_attributed_declarator_repeat1] = STATE(875),
    [sym_identifier] = ACTIONS(3055),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(1697),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(1701),
    [anon_sym_do] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1705),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1709),
    [anon_sym_continue] = ACTIONS(1711),
    [anon_sym_goto] = ACTIONS(1713),
    [anon_sym___try] = ACTIONS(1715),
    [anon_sym___leave] = ACTIONS(1717),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1719),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(1721),
    [anon_sym_co_return] = ACTIONS(1723),
    [anon_sym_co_yield] = ACTIONS(1725),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1727),
    [anon_sym_cbuffer] = ACTIONS(1729),
  },
  [883] = {
    [sym_attribute_declaration] = STATE(875),
    [sym_compound_statement] = STATE(1056),
    [sym_attributed_statement] = STATE(1056),
    [sym_statement] = STATE(1013),
    [sym_labeled_statement] = STATE(1056),
    [sym_expression_statement] = STATE(1056),
    [sym_if_statement] = STATE(1056),
    [sym_switch_statement] = STATE(1056),
    [sym_case_statement] = STATE(1056),
    [sym_while_statement] = STATE(1056),
    [sym_do_statement] = STATE(1056),
    [sym_for_statement] = STATE(1056),
    [sym_return_statement] = STATE(1056),
    [sym_break_statement] = STATE(1056),
    [sym_continue_statement] = STATE(1056),
    [sym_goto_statement] = STATE(1056),
    [sym_seh_try_statement] = STATE(1056),
    [sym_seh_leave_statement] = STATE(1056),
    [sym_expression] = STATE(4514),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8003),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(1056),
    [sym_co_return_statement] = STATE(1056),
    [sym_co_yield_statement] = STATE(1056),
    [sym_throw_statement] = STATE(1056),
    [sym_try_statement] = STATE(1056),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(1056),
    [sym_cbuffer_specifier] = STATE(1056),
    [sym_hlsl_attribute] = STATE(7744),
    [aux_sym_attributed_declarator_repeat1] = STATE(875),
    [sym_identifier] = ACTIONS(3055),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(1697),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(1701),
    [anon_sym_do] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1705),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1709),
    [anon_sym_continue] = ACTIONS(1711),
    [anon_sym_goto] = ACTIONS(1713),
    [anon_sym___try] = ACTIONS(1715),
    [anon_sym___leave] = ACTIONS(1717),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(1719),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(1721),
    [anon_sym_co_return] = ACTIONS(1723),
    [anon_sym_co_yield] = ACTIONS(1725),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1727),
    [anon_sym_cbuffer] = ACTIONS(1729),
  },
  [884] = {
    [sym_attribute_declaration] = STATE(891),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(8416),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7568),
    [aux_sym_attributed_declarator_repeat1] = STATE(891),
    [sym_identifier] = ACTIONS(3035),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(3037),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(3043),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(3045),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(3047),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(3049),
  },
  [885] = {
    [sym_attribute_declaration] = STATE(891),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(8440),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7568),
    [aux_sym_attributed_declarator_repeat1] = STATE(891),
    [sym_identifier] = ACTIONS(3035),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(3037),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(3043),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(3045),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(3047),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(3049),
  },
  [886] = {
    [sym_attribute_declaration] = STATE(828),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(482),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7796),
    [aux_sym_attributed_declarator_repeat1] = STATE(828),
    [sym_identifier] = ACTIONS(3033),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(633),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_switch] = ACTIONS(193),
    [anon_sym_case] = ACTIONS(195),
    [anon_sym_default] = ACTIONS(197),
    [anon_sym_while] = ACTIONS(199),
    [anon_sym_do] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_return] = ACTIONS(205),
    [anon_sym_break] = ACTIONS(207),
    [anon_sym_continue] = ACTIONS(209),
    [anon_sym_goto] = ACTIONS(211),
    [anon_sym___try] = ACTIONS(213),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(225),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(227),
    [anon_sym_co_return] = ACTIONS(237),
    [anon_sym_co_yield] = ACTIONS(239),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(243),
  },
  [887] = {
    [sym_attribute_declaration] = STATE(891),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(7110),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7568),
    [aux_sym_attributed_declarator_repeat1] = STATE(891),
    [sym_identifier] = ACTIONS(3035),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(3037),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(3043),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(3045),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(3047),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(3049),
  },
  [888] = {
    [sym_attribute_declaration] = STATE(888),
    [sym_compound_statement] = STATE(468),
    [sym_attributed_statement] = STATE(468),
    [sym_statement] = STATE(452),
    [sym_labeled_statement] = STATE(468),
    [sym_expression_statement] = STATE(468),
    [sym_if_statement] = STATE(468),
    [sym_switch_statement] = STATE(468),
    [sym_case_statement] = STATE(468),
    [sym_while_statement] = STATE(468),
    [sym_do_statement] = STATE(468),
    [sym_for_statement] = STATE(468),
    [sym_return_statement] = STATE(468),
    [sym_break_statement] = STATE(468),
    [sym_continue_statement] = STATE(468),
    [sym_goto_statement] = STATE(468),
    [sym_seh_try_statement] = STATE(468),
    [sym_seh_leave_statement] = STATE(468),
    [sym_expression] = STATE(4453),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7849),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(468),
    [sym_co_return_statement] = STATE(468),
    [sym_co_yield_statement] = STATE(468),
    [sym_throw_statement] = STATE(468),
    [sym_try_statement] = STATE(468),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(468),
    [sym_cbuffer_specifier] = STATE(468),
    [sym_hlsl_attribute] = STATE(7711),
    [aux_sym_attributed_declarator_repeat1] = STATE(888),
    [sym_identifier] = ACTIONS(3419),
    [anon_sym_LPAREN2] = ACTIONS(3062),
    [anon_sym_BANG] = ACTIONS(3065),
    [anon_sym_TILDE] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3068),
    [anon_sym_PLUS] = ACTIONS(3068),
    [anon_sym_STAR] = ACTIONS(3071),
    [anon_sym_AMP] = ACTIONS(3071),
    [anon_sym_SEMI] = ACTIONS(3422),
    [anon_sym_COLON_COLON] = ACTIONS(3077),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3080),
    [anon_sym_LBRACE] = ACTIONS(3425),
    [anon_sym_LBRACK] = ACTIONS(3086),
    [sym_primitive_type] = ACTIONS(3089),
    [anon_sym_if] = ACTIONS(3428),
    [anon_sym_switch] = ACTIONS(3431),
    [anon_sym_case] = ACTIONS(3434),
    [anon_sym_default] = ACTIONS(3437),
    [anon_sym_while] = ACTIONS(3440),
    [anon_sym_do] = ACTIONS(3443),
    [anon_sym_for] = ACTIONS(3446),
    [anon_sym_return] = ACTIONS(3449),
    [anon_sym_break] = ACTIONS(3452),
    [anon_sym_continue] = ACTIONS(3455),
    [anon_sym_goto] = ACTIONS(3458),
    [anon_sym___try] = ACTIONS(3461),
    [anon_sym___leave] = ACTIONS(3464),
    [anon_sym_not] = ACTIONS(3068),
    [anon_sym_compl] = ACTIONS(3068),
    [anon_sym_DASH_DASH] = ACTIONS(3131),
    [anon_sym_PLUS_PLUS] = ACTIONS(3131),
    [anon_sym_sizeof] = ACTIONS(3134),
    [anon_sym___alignof__] = ACTIONS(3137),
    [anon_sym___alignof] = ACTIONS(3137),
    [anon_sym__alignof] = ACTIONS(3137),
    [anon_sym_alignof] = ACTIONS(3137),
    [anon_sym__Alignof] = ACTIONS(3137),
    [anon_sym_offsetof] = ACTIONS(3140),
    [anon_sym__Generic] = ACTIONS(3143),
    [anon_sym_asm] = ACTIONS(3146),
    [anon_sym___asm__] = ACTIONS(3146),
    [sym_number_literal] = ACTIONS(3149),
    [anon_sym_L_SQUOTE] = ACTIONS(3152),
    [anon_sym_u_SQUOTE] = ACTIONS(3152),
    [anon_sym_U_SQUOTE] = ACTIONS(3152),
    [anon_sym_u8_SQUOTE] = ACTIONS(3152),
    [anon_sym_SQUOTE] = ACTIONS(3152),
    [anon_sym_L_DQUOTE] = ACTIONS(3155),
    [anon_sym_u_DQUOTE] = ACTIONS(3155),
    [anon_sym_U_DQUOTE] = ACTIONS(3155),
    [anon_sym_u8_DQUOTE] = ACTIONS(3155),
    [anon_sym_DQUOTE] = ACTIONS(3155),
    [sym_true] = ACTIONS(3158),
    [sym_false] = ACTIONS(3158),
    [anon_sym_NULL] = ACTIONS(3161),
    [anon_sym_nullptr] = ACTIONS(3161),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(3164),
    [anon_sym_template] = ACTIONS(3167),
    [anon_sym_try] = ACTIONS(3467),
    [anon_sym_delete] = ACTIONS(3173),
    [anon_sym_throw] = ACTIONS(3470),
    [anon_sym_co_return] = ACTIONS(3473),
    [anon_sym_co_yield] = ACTIONS(3476),
    [anon_sym_R_DQUOTE] = ACTIONS(3185),
    [anon_sym_LR_DQUOTE] = ACTIONS(3185),
    [anon_sym_uR_DQUOTE] = ACTIONS(3185),
    [anon_sym_UR_DQUOTE] = ACTIONS(3185),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3185),
    [anon_sym_co_await] = ACTIONS(3188),
    [anon_sym_new] = ACTIONS(3191),
    [anon_sym_requires] = ACTIONS(3194),
    [sym_this] = ACTIONS(3158),
    [anon_sym_discard] = ACTIONS(3479),
    [anon_sym_cbuffer] = ACTIONS(3482),
  },
  [889] = {
    [sym_attribute_declaration] = STATE(840),
    [sym_compound_statement] = STATE(416),
    [sym_attributed_statement] = STATE(416),
    [sym_statement] = STATE(529),
    [sym_labeled_statement] = STATE(416),
    [sym_expression_statement] = STATE(416),
    [sym_if_statement] = STATE(416),
    [sym_switch_statement] = STATE(416),
    [sym_case_statement] = STATE(416),
    [sym_while_statement] = STATE(416),
    [sym_do_statement] = STATE(416),
    [sym_for_statement] = STATE(416),
    [sym_return_statement] = STATE(416),
    [sym_break_statement] = STATE(416),
    [sym_continue_statement] = STATE(416),
    [sym_goto_statement] = STATE(416),
    [sym_seh_try_statement] = STATE(416),
    [sym_seh_leave_statement] = STATE(416),
    [sym_expression] = STATE(4525),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8558),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(416),
    [sym_co_return_statement] = STATE(416),
    [sym_co_yield_statement] = STATE(416),
    [sym_throw_statement] = STATE(416),
    [sym_try_statement] = STATE(416),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(416),
    [sym_cbuffer_specifier] = STATE(416),
    [sym_hlsl_attribute] = STATE(7458),
    [aux_sym_attributed_declarator_repeat1] = STATE(840),
    [sym_identifier] = ACTIONS(3053),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(1477),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(77),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(81),
    [anon_sym_default] = ACTIONS(83),
    [anon_sym_while] = ACTIONS(85),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(89),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(1479),
    [anon_sym___leave] = ACTIONS(1481),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(1483),
    [anon_sym_cbuffer] = ACTIONS(1485),
  },
  [890] = {
    [sym_attribute_declaration] = STATE(827),
    [sym_compound_statement] = STATE(468),
    [sym_attributed_statement] = STATE(468),
    [sym_statement] = STATE(413),
    [sym_labeled_statement] = STATE(468),
    [sym_expression_statement] = STATE(468),
    [sym_if_statement] = STATE(468),
    [sym_switch_statement] = STATE(468),
    [sym_case_statement] = STATE(468),
    [sym_while_statement] = STATE(468),
    [sym_do_statement] = STATE(468),
    [sym_for_statement] = STATE(468),
    [sym_return_statement] = STATE(468),
    [sym_break_statement] = STATE(468),
    [sym_continue_statement] = STATE(468),
    [sym_goto_statement] = STATE(468),
    [sym_seh_try_statement] = STATE(468),
    [sym_seh_leave_statement] = STATE(468),
    [sym_expression] = STATE(4453),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7849),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(468),
    [sym_co_return_statement] = STATE(468),
    [sym_co_yield_statement] = STATE(468),
    [sym_throw_statement] = STATE(468),
    [sym_try_statement] = STATE(468),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(468),
    [sym_cbuffer_specifier] = STATE(468),
    [sym_hlsl_attribute] = STATE(7711),
    [aux_sym_attributed_declarator_repeat1] = STATE(827),
    [sym_identifier] = ACTIONS(3051),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(785),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(793),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(797),
    [anon_sym_switch] = ACTIONS(799),
    [anon_sym_case] = ACTIONS(801),
    [anon_sym_default] = ACTIONS(803),
    [anon_sym_while] = ACTIONS(805),
    [anon_sym_do] = ACTIONS(807),
    [anon_sym_for] = ACTIONS(809),
    [anon_sym_return] = ACTIONS(811),
    [anon_sym_break] = ACTIONS(813),
    [anon_sym_continue] = ACTIONS(815),
    [anon_sym_goto] = ACTIONS(817),
    [anon_sym___try] = ACTIONS(819),
    [anon_sym___leave] = ACTIONS(821),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(825),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(827),
    [anon_sym_co_return] = ACTIONS(837),
    [anon_sym_co_yield] = ACTIONS(839),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(841),
    [anon_sym_cbuffer] = ACTIONS(843),
  },
  [891] = {
    [sym_attribute_declaration] = STATE(872),
    [sym_compound_statement] = STATE(484),
    [sym_attributed_statement] = STATE(484),
    [sym_statement] = STATE(393),
    [sym_labeled_statement] = STATE(484),
    [sym_expression_statement] = STATE(484),
    [sym_if_statement] = STATE(484),
    [sym_switch_statement] = STATE(484),
    [sym_case_statement] = STATE(484),
    [sym_while_statement] = STATE(484),
    [sym_do_statement] = STATE(484),
    [sym_for_statement] = STATE(484),
    [sym_return_statement] = STATE(484),
    [sym_break_statement] = STATE(484),
    [sym_continue_statement] = STATE(484),
    [sym_goto_statement] = STATE(484),
    [sym_seh_try_statement] = STATE(484),
    [sym_seh_leave_statement] = STATE(484),
    [sym_expression] = STATE(4511),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8431),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_for_range_loop] = STATE(484),
    [sym_co_return_statement] = STATE(484),
    [sym_co_yield_statement] = STATE(484),
    [sym_throw_statement] = STATE(484),
    [sym_try_statement] = STATE(484),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_discard_statement] = STATE(484),
    [sym_cbuffer_specifier] = STATE(484),
    [sym_hlsl_attribute] = STATE(7568),
    [aux_sym_attributed_declarator_repeat1] = STATE(872),
    [sym_identifier] = ACTIONS(3035),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(175),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1262),
    [anon_sym_LBRACE] = ACTIONS(53),
    [anon_sym_LBRACK] = ACTIONS(1264),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_if] = ACTIONS(3037),
    [anon_sym_switch] = ACTIONS(79),
    [anon_sym_case] = ACTIONS(3039),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(3043),
    [anon_sym_do] = ACTIONS(87),
    [anon_sym_for] = ACTIONS(3045),
    [anon_sym_return] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_goto] = ACTIONS(97),
    [anon_sym___try] = ACTIONS(3047),
    [anon_sym___leave] = ACTIONS(215),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_try] = ACTIONS(133),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_throw] = ACTIONS(137),
    [anon_sym_co_return] = ACTIONS(147),
    [anon_sym_co_yield] = ACTIONS(149),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
    [anon_sym_discard] = ACTIONS(241),
    [anon_sym_cbuffer] = ACTIONS(3049),
  },
  [892] = {
    [sym__declaration_modifiers] = STATE(1976),
    [sym__declaration_specifiers] = STATE(6157),
    [sym_attribute_specifier] = STATE(1976),
    [sym_attribute_declaration] = STATE(1976),
    [sym_ms_declspec_modifier] = STATE(1976),
    [sym_storage_class_specifier] = STATE(1976),
    [sym_type_qualifier] = STATE(1976),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1976),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1976),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2659),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym_COMMA] = ACTIONS(3487),
    [anon_sym_BANG] = ACTIONS(3489),
    [anon_sym_TILDE] = ACTIONS(3487),
    [anon_sym_DASH] = ACTIONS(3489),
    [anon_sym_PLUS] = ACTIONS(3489),
    [anon_sym_STAR] = ACTIONS(3489),
    [anon_sym_SLASH] = ACTIONS(3489),
    [anon_sym_PERCENT] = ACTIONS(3489),
    [anon_sym_PIPE_PIPE] = ACTIONS(3487),
    [anon_sym_AMP_AMP] = ACTIONS(3487),
    [anon_sym_PIPE] = ACTIONS(3489),
    [anon_sym_CARET] = ACTIONS(3489),
    [anon_sym_AMP] = ACTIONS(3489),
    [anon_sym_EQ_EQ] = ACTIONS(3487),
    [anon_sym_BANG_EQ] = ACTIONS(3487),
    [anon_sym_GT] = ACTIONS(3489),
    [anon_sym_GT_EQ] = ACTIONS(3487),
    [anon_sym_LT_EQ] = ACTIONS(3489),
    [anon_sym_LT] = ACTIONS(3489),
    [anon_sym_LT_LT] = ACTIONS(3489),
    [anon_sym_GT_GT] = ACTIONS(3489),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(3491),
    [anon_sym_out] = ACTIONS(3491),
    [anon_sym_inout] = ACTIONS(3491),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(3495),
    [anon_sym_unsigned] = ACTIONS(3495),
    [anon_sym_long] = ACTIONS(3495),
    [anon_sym_short] = ACTIONS(3495),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_EQ] = ACTIONS(3489),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(3497),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [anon_sym_STAR_EQ] = ACTIONS(3487),
    [anon_sym_SLASH_EQ] = ACTIONS(3487),
    [anon_sym_PERCENT_EQ] = ACTIONS(3487),
    [anon_sym_PLUS_EQ] = ACTIONS(3487),
    [anon_sym_DASH_EQ] = ACTIONS(3487),
    [anon_sym_LT_LT_EQ] = ACTIONS(3487),
    [anon_sym_GT_GT_EQ] = ACTIONS(3487),
    [anon_sym_AMP_EQ] = ACTIONS(3487),
    [anon_sym_CARET_EQ] = ACTIONS(3487),
    [anon_sym_PIPE_EQ] = ACTIONS(3487),
    [anon_sym_and_eq] = ACTIONS(3489),
    [anon_sym_or_eq] = ACTIONS(3489),
    [anon_sym_xor_eq] = ACTIONS(3489),
    [anon_sym_not] = ACTIONS(3489),
    [anon_sym_compl] = ACTIONS(3489),
    [anon_sym_LT_EQ_GT] = ACTIONS(3487),
    [anon_sym_or] = ACTIONS(3489),
    [anon_sym_and] = ACTIONS(3489),
    [anon_sym_bitor] = ACTIONS(3489),
    [anon_sym_xor] = ACTIONS(3489),
    [anon_sym_bitand] = ACTIONS(3489),
    [anon_sym_not_eq] = ACTIONS(3489),
    [anon_sym_DASH_DASH] = ACTIONS(3487),
    [anon_sym_PLUS_PLUS] = ACTIONS(3487),
    [anon_sym_DASH_GT] = ACTIONS(3489),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(3491),
    [anon_sym_typename] = ACTIONS(3499),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3501),
    [anon_sym_co_await] = ACTIONS(3489),
    [anon_sym_new] = ACTIONS(3501),
    [anon_sym_DASH_GT_STAR] = ACTIONS(3487),
    [anon_sym_LPAREN_RPAREN] = ACTIONS(3487),
    [anon_sym_LBRACK_RBRACK] = ACTIONS(3487),
    [anon_sym_DQUOTE_DQUOTE] = ACTIONS(3503),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [893] = {
    [sym__declaration_modifiers] = STATE(1976),
    [sym__declaration_specifiers] = STATE(6157),
    [sym_attribute_specifier] = STATE(1976),
    [sym_attribute_declaration] = STATE(1976),
    [sym_ms_declspec_modifier] = STATE(1976),
    [sym_storage_class_specifier] = STATE(1976),
    [sym_type_qualifier] = STATE(1976),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1976),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1976),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2659),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym_COMMA] = ACTIONS(3505),
    [anon_sym_BANG] = ACTIONS(3507),
    [anon_sym_TILDE] = ACTIONS(3505),
    [anon_sym_DASH] = ACTIONS(3507),
    [anon_sym_PLUS] = ACTIONS(3507),
    [anon_sym_STAR] = ACTIONS(3507),
    [anon_sym_SLASH] = ACTIONS(3507),
    [anon_sym_PERCENT] = ACTIONS(3507),
    [anon_sym_PIPE_PIPE] = ACTIONS(3505),
    [anon_sym_AMP_AMP] = ACTIONS(3505),
    [anon_sym_PIPE] = ACTIONS(3507),
    [anon_sym_CARET] = ACTIONS(3507),
    [anon_sym_AMP] = ACTIONS(3507),
    [anon_sym_EQ_EQ] = ACTIONS(3505),
    [anon_sym_BANG_EQ] = ACTIONS(3505),
    [anon_sym_GT] = ACTIONS(3507),
    [anon_sym_GT_EQ] = ACTIONS(3505),
    [anon_sym_LT_EQ] = ACTIONS(3507),
    [anon_sym_LT] = ACTIONS(3507),
    [anon_sym_LT_LT] = ACTIONS(3507),
    [anon_sym_GT_GT] = ACTIONS(3507),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(3491),
    [anon_sym_out] = ACTIONS(3491),
    [anon_sym_inout] = ACTIONS(3491),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(3495),
    [anon_sym_unsigned] = ACTIONS(3495),
    [anon_sym_long] = ACTIONS(3495),
    [anon_sym_short] = ACTIONS(3495),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_EQ] = ACTIONS(3507),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(3497),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [anon_sym_STAR_EQ] = ACTIONS(3505),
    [anon_sym_SLASH_EQ] = ACTIONS(3505),
    [anon_sym_PERCENT_EQ] = ACTIONS(3505),
    [anon_sym_PLUS_EQ] = ACTIONS(3505),
    [anon_sym_DASH_EQ] = ACTIONS(3505),
    [anon_sym_LT_LT_EQ] = ACTIONS(3505),
    [anon_sym_GT_GT_EQ] = ACTIONS(3505),
    [anon_sym_AMP_EQ] = ACTIONS(3505),
    [anon_sym_CARET_EQ] = ACTIONS(3505),
    [anon_sym_PIPE_EQ] = ACTIONS(3505),
    [anon_sym_and_eq] = ACTIONS(3507),
    [anon_sym_or_eq] = ACTIONS(3507),
    [anon_sym_xor_eq] = ACTIONS(3507),
    [anon_sym_not] = ACTIONS(3507),
    [anon_sym_compl] = ACTIONS(3507),
    [anon_sym_LT_EQ_GT] = ACTIONS(3505),
    [anon_sym_or] = ACTIONS(3507),
    [anon_sym_and] = ACTIONS(3507),
    [anon_sym_bitor] = ACTIONS(3507),
    [anon_sym_xor] = ACTIONS(3507),
    [anon_sym_bitand] = ACTIONS(3507),
    [anon_sym_not_eq] = ACTIONS(3507),
    [anon_sym_DASH_DASH] = ACTIONS(3505),
    [anon_sym_PLUS_PLUS] = ACTIONS(3505),
    [anon_sym_DASH_GT] = ACTIONS(3507),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(3491),
    [anon_sym_typename] = ACTIONS(3499),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3509),
    [anon_sym_co_await] = ACTIONS(3507),
    [anon_sym_new] = ACTIONS(3509),
    [anon_sym_DASH_GT_STAR] = ACTIONS(3505),
    [anon_sym_LPAREN_RPAREN] = ACTIONS(3505),
    [anon_sym_LBRACK_RBRACK] = ACTIONS(3505),
    [anon_sym_DQUOTE_DQUOTE] = ACTIONS(3511),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [894] = {
    [sym_expression] = STATE(2723),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_initializer_list] = STATE(2848),
    [sym_char_literal] = STATE(3061),
    [sym_concatenated_string] = STATE(3059),
    [sym_string_literal] = STATE(2449),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2444),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3513),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3515),
    [anon_sym_COMMA] = ACTIONS(3515),
    [aux_sym_preproc_if_token2] = ACTIONS(3515),
    [aux_sym_preproc_else_token1] = ACTIONS(3515),
    [aux_sym_preproc_elif_token1] = ACTIONS(3513),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(3515),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(3515),
    [anon_sym_LPAREN2] = ACTIONS(3515),
    [anon_sym_BANG] = ACTIONS(3517),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_DASH] = ACTIONS(3513),
    [anon_sym_PLUS] = ACTIONS(3513),
    [anon_sym_STAR] = ACTIONS(3513),
    [anon_sym_SLASH] = ACTIONS(3513),
    [anon_sym_PERCENT] = ACTIONS(3513),
    [anon_sym_PIPE_PIPE] = ACTIONS(3515),
    [anon_sym_AMP_AMP] = ACTIONS(3515),
    [anon_sym_PIPE] = ACTIONS(3513),
    [anon_sym_CARET] = ACTIONS(3513),
    [anon_sym_AMP] = ACTIONS(3513),
    [anon_sym_EQ_EQ] = ACTIONS(3515),
    [anon_sym_BANG_EQ] = ACTIONS(3515),
    [anon_sym_GT] = ACTIONS(3513),
    [anon_sym_GT_EQ] = ACTIONS(3515),
    [anon_sym_LT_EQ] = ACTIONS(3513),
    [anon_sym_LT] = ACTIONS(3513),
    [anon_sym_LT_LT] = ACTIONS(3513),
    [anon_sym_GT_GT] = ACTIONS(3513),
    [anon_sym_COLON_COLON] = ACTIONS(3521),
    [anon_sym_LBRACE] = ACTIONS(3523),
    [anon_sym_LBRACK] = ACTIONS(3515),
    [anon_sym_EQ] = ACTIONS(3513),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_QMARK] = ACTIONS(3515),
    [anon_sym_STAR_EQ] = ACTIONS(3515),
    [anon_sym_SLASH_EQ] = ACTIONS(3515),
    [anon_sym_PERCENT_EQ] = ACTIONS(3515),
    [anon_sym_PLUS_EQ] = ACTIONS(3515),
    [anon_sym_DASH_EQ] = ACTIONS(3515),
    [anon_sym_LT_LT_EQ] = ACTIONS(3515),
    [anon_sym_GT_GT_EQ] = ACTIONS(3515),
    [anon_sym_AMP_EQ] = ACTIONS(3515),
    [anon_sym_CARET_EQ] = ACTIONS(3515),
    [anon_sym_PIPE_EQ] = ACTIONS(3515),
    [anon_sym_and_eq] = ACTIONS(3513),
    [anon_sym_or_eq] = ACTIONS(3513),
    [anon_sym_xor_eq] = ACTIONS(3513),
    [anon_sym_not] = ACTIONS(3517),
    [anon_sym_compl] = ACTIONS(3517),
    [anon_sym_LT_EQ_GT] = ACTIONS(3515),
    [anon_sym_or] = ACTIONS(3513),
    [anon_sym_and] = ACTIONS(3513),
    [anon_sym_bitor] = ACTIONS(3513),
    [anon_sym_xor] = ACTIONS(3513),
    [anon_sym_bitand] = ACTIONS(3513),
    [anon_sym_not_eq] = ACTIONS(3513),
    [anon_sym_DASH_DASH] = ACTIONS(3515),
    [anon_sym_PLUS_PLUS] = ACTIONS(3515),
    [anon_sym_sizeof] = ACTIONS(3527),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [anon_sym_DOT] = ACTIONS(3513),
    [anon_sym_DOT_STAR] = ACTIONS(3515),
    [anon_sym_DASH_GT] = ACTIONS(3515),
    [sym_number_literal] = ACTIONS(3537),
    [anon_sym_L_SQUOTE] = ACTIONS(3539),
    [anon_sym_u_SQUOTE] = ACTIONS(3539),
    [anon_sym_U_SQUOTE] = ACTIONS(3539),
    [anon_sym_u8_SQUOTE] = ACTIONS(3539),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3547),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [anon_sym_co_await] = ACTIONS(3551),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [895] = {
    [sym_expression] = STATE(2723),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_initializer_list] = STATE(2848),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3515),
    [anon_sym_COMMA] = ACTIONS(3515),
    [anon_sym_RPAREN] = ACTIONS(3515),
    [anon_sym_LPAREN2] = ACTIONS(3515),
    [anon_sym_BANG] = ACTIONS(3559),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3513),
    [anon_sym_PLUS] = ACTIONS(3513),
    [anon_sym_STAR] = ACTIONS(3513),
    [anon_sym_SLASH] = ACTIONS(3513),
    [anon_sym_PERCENT] = ACTIONS(3513),
    [anon_sym_PIPE_PIPE] = ACTIONS(3515),
    [anon_sym_AMP_AMP] = ACTIONS(3515),
    [anon_sym_PIPE] = ACTIONS(3513),
    [anon_sym_CARET] = ACTIONS(3513),
    [anon_sym_AMP] = ACTIONS(3513),
    [anon_sym_EQ_EQ] = ACTIONS(3515),
    [anon_sym_BANG_EQ] = ACTIONS(3515),
    [anon_sym_GT] = ACTIONS(3513),
    [anon_sym_GT_EQ] = ACTIONS(3515),
    [anon_sym_LT_EQ] = ACTIONS(3513),
    [anon_sym_LT] = ACTIONS(3513),
    [anon_sym_LT_LT] = ACTIONS(3513),
    [anon_sym_GT_GT] = ACTIONS(3513),
    [anon_sym_SEMI] = ACTIONS(3515),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACE] = ACTIONS(3523),
    [anon_sym_RBRACE] = ACTIONS(3515),
    [anon_sym_LBRACK] = ACTIONS(3515),
    [anon_sym_RBRACK] = ACTIONS(3515),
    [anon_sym_EQ] = ACTIONS(3513),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_QMARK] = ACTIONS(3515),
    [anon_sym_STAR_EQ] = ACTIONS(3515),
    [anon_sym_SLASH_EQ] = ACTIONS(3515),
    [anon_sym_PERCENT_EQ] = ACTIONS(3515),
    [anon_sym_PLUS_EQ] = ACTIONS(3515),
    [anon_sym_DASH_EQ] = ACTIONS(3515),
    [anon_sym_LT_LT_EQ] = ACTIONS(3515),
    [anon_sym_GT_GT_EQ] = ACTIONS(3515),
    [anon_sym_AMP_EQ] = ACTIONS(3515),
    [anon_sym_CARET_EQ] = ACTIONS(3515),
    [anon_sym_PIPE_EQ] = ACTIONS(3515),
    [anon_sym_and_eq] = ACTIONS(3513),
    [anon_sym_or_eq] = ACTIONS(3513),
    [anon_sym_xor_eq] = ACTIONS(3513),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_LT_EQ_GT] = ACTIONS(3515),
    [anon_sym_or] = ACTIONS(3513),
    [anon_sym_and] = ACTIONS(3513),
    [anon_sym_bitor] = ACTIONS(3513),
    [anon_sym_xor] = ACTIONS(3513),
    [anon_sym_bitand] = ACTIONS(3513),
    [anon_sym_not_eq] = ACTIONS(3513),
    [anon_sym_DASH_DASH] = ACTIONS(3515),
    [anon_sym_PLUS_PLUS] = ACTIONS(3515),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [anon_sym_DOT] = ACTIONS(3513),
    [anon_sym_DOT_STAR] = ACTIONS(3515),
    [anon_sym_DASH_GT] = ACTIONS(3515),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [896] = {
    [sym_function_definition] = STATE(677),
    [sym_declaration] = STATE(677),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4694),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1965),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6018),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2254),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__empty_declaration] = STATE(677),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1831),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(677),
    [sym_operator_cast] = STATE(6668),
    [sym__constructor_specifiers] = STATE(1831),
    [sym_operator_cast_definition] = STATE(677),
    [sym_operator_cast_declaration] = STATE(677),
    [sym_constructor_or_destructor_definition] = STATE(677),
    [sym_constructor_or_destructor_declaration] = STATE(677),
    [sym_friend_declaration] = STATE(677),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_alias_declaration] = STATE(677),
    [sym_concept_definition] = STATE(677),
    [sym_requires_clause] = STATE(910),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5415),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6668),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [sym_hlsl_attribute] = STATE(1361),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1831),
    [sym_identifier] = ACTIONS(3581),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3583),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(3585),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(3587),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(3589),
    [anon_sym_using] = ACTIONS(3591),
    [anon_sym_concept] = ACTIONS(835),
    [anon_sym_requires] = ACTIONS(3593),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [897] = {
    [sym_function_definition] = STATE(310),
    [sym_declaration] = STATE(310),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1943),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6025),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2258),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__empty_declaration] = STATE(310),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1820),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(310),
    [sym_operator_cast] = STATE(6628),
    [sym__constructor_specifiers] = STATE(1820),
    [sym_operator_cast_definition] = STATE(310),
    [sym_operator_cast_declaration] = STATE(310),
    [sym_constructor_or_destructor_definition] = STATE(310),
    [sym_constructor_or_destructor_declaration] = STATE(310),
    [sym_friend_declaration] = STATE(310),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_alias_declaration] = STATE(310),
    [sym_concept_definition] = STATE(310),
    [sym_requires_clause] = STATE(917),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5415),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6628),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [sym_hlsl_attribute] = STATE(1327),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1820),
    [sym_identifier] = ACTIONS(3581),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3583),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(3585),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(3595),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(3597),
    [anon_sym_using] = ACTIONS(3599),
    [anon_sym_concept] = ACTIONS(335),
    [anon_sym_requires] = ACTIONS(3593),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [898] = {
    [sym_function_definition] = STATE(2146),
    [sym_declaration] = STATE(2146),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4730),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1947),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2259),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__empty_declaration] = STATE(2146),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(2146),
    [sym_operator_cast] = STATE(6626),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(2146),
    [sym_operator_cast_declaration] = STATE(2146),
    [sym_constructor_or_destructor_definition] = STATE(2146),
    [sym_constructor_or_destructor_declaration] = STATE(2146),
    [sym_friend_declaration] = STATE(2146),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_alias_declaration] = STATE(2146),
    [sym_concept_definition] = STATE(2146),
    [sym_requires_clause] = STATE(912),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5415),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [sym_hlsl_attribute] = STATE(1336),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(3581),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3583),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(3585),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_using] = ACTIONS(3601),
    [anon_sym_concept] = ACTIONS(3603),
    [anon_sym_requires] = ACTIONS(3593),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [899] = {
    [sym_function_definition] = STATE(1887),
    [sym_declaration] = STATE(1887),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4626),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1953),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6102),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2265),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__empty_declaration] = STATE(1887),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1832),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(1887),
    [sym_operator_cast] = STATE(6636),
    [sym__constructor_specifiers] = STATE(1832),
    [sym_operator_cast_definition] = STATE(1887),
    [sym_operator_cast_declaration] = STATE(1887),
    [sym_constructor_or_destructor_definition] = STATE(1887),
    [sym_constructor_or_destructor_declaration] = STATE(1887),
    [sym_friend_declaration] = STATE(1887),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_alias_declaration] = STATE(1887),
    [sym_concept_definition] = STATE(1887),
    [sym_requires_clause] = STATE(943),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5415),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6636),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [sym_hlsl_attribute] = STATE(1357),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1832),
    [sym_identifier] = ACTIONS(3581),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3583),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(3585),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(2629),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2631),
    [anon_sym_using] = ACTIONS(3605),
    [anon_sym_concept] = ACTIONS(3607),
    [anon_sym_requires] = ACTIONS(3593),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [900] = {
    [sym_function_definition] = STATE(2137),
    [sym_declaration] = STATE(2137),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4664),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1962),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6069),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2263),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__empty_declaration] = STATE(2137),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1829),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(2137),
    [sym_operator_cast] = STATE(6635),
    [sym__constructor_specifiers] = STATE(1829),
    [sym_operator_cast_definition] = STATE(2137),
    [sym_operator_cast_declaration] = STATE(2137),
    [sym_constructor_or_destructor_definition] = STATE(2137),
    [sym_constructor_or_destructor_declaration] = STATE(2137),
    [sym_friend_declaration] = STATE(2137),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_alias_declaration] = STATE(2137),
    [sym_concept_definition] = STATE(2137),
    [sym_requires_clause] = STATE(908),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5415),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6635),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [sym_hlsl_attribute] = STATE(1312),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1829),
    [sym_identifier] = ACTIONS(3581),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3583),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(3585),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(2945),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2947),
    [anon_sym_using] = ACTIONS(3609),
    [anon_sym_concept] = ACTIONS(3611),
    [anon_sym_requires] = ACTIONS(3593),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [901] = {
    [sym_function_definition] = STATE(779),
    [sym_declaration] = STATE(779),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4633),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1945),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6036),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2257),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__empty_declaration] = STATE(779),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1826),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(779),
    [sym_operator_cast] = STATE(6631),
    [sym__constructor_specifiers] = STATE(1826),
    [sym_operator_cast_definition] = STATE(779),
    [sym_operator_cast_declaration] = STATE(779),
    [sym_constructor_or_destructor_definition] = STATE(779),
    [sym_constructor_or_destructor_declaration] = STATE(779),
    [sym_friend_declaration] = STATE(779),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_alias_declaration] = STATE(779),
    [sym_concept_definition] = STATE(779),
    [sym_requires_clause] = STATE(915),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5415),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6631),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [sym_hlsl_attribute] = STATE(1303),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1826),
    [sym_identifier] = ACTIONS(3581),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3583),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(3585),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(3613),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(3615),
    [anon_sym_using] = ACTIONS(3617),
    [anon_sym_concept] = ACTIONS(145),
    [anon_sym_requires] = ACTIONS(3593),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [902] = {
    [sym_function_definition] = STATE(696),
    [sym_declaration] = STATE(696),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6017),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__empty_declaration] = STATE(696),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1830),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(696),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1830),
    [sym_operator_cast_definition] = STATE(696),
    [sym_operator_cast_declaration] = STATE(696),
    [sym_constructor_or_destructor_definition] = STATE(696),
    [sym_constructor_or_destructor_declaration] = STATE(696),
    [sym_friend_declaration] = STATE(696),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_alias_declaration] = STATE(696),
    [sym_concept_definition] = STATE(696),
    [sym_requires_clause] = STATE(938),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5415),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [sym_hlsl_attribute] = STATE(1354),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1830),
    [sym_identifier] = ACTIONS(3581),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3583),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(3585),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(3619),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(3621),
    [anon_sym_using] = ACTIONS(3623),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_requires] = ACTIONS(3593),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [903] = {
    [sym_expression] = STATE(3270),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_initializer_list] = STATE(3608),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3515),
    [anon_sym_COMMA] = ACTIONS(3515),
    [anon_sym_RPAREN] = ACTIONS(3515),
    [anon_sym_LPAREN2] = ACTIONS(3515),
    [anon_sym_BANG] = ACTIONS(2026),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(3513),
    [anon_sym_PLUS] = ACTIONS(3513),
    [anon_sym_STAR] = ACTIONS(3513),
    [anon_sym_SLASH] = ACTIONS(3513),
    [anon_sym_PERCENT] = ACTIONS(3513),
    [anon_sym_PIPE_PIPE] = ACTIONS(3515),
    [anon_sym_AMP_AMP] = ACTIONS(3515),
    [anon_sym_PIPE] = ACTIONS(3513),
    [anon_sym_CARET] = ACTIONS(3513),
    [anon_sym_AMP] = ACTIONS(3513),
    [anon_sym_EQ_EQ] = ACTIONS(3515),
    [anon_sym_BANG_EQ] = ACTIONS(3515),
    [anon_sym_GT] = ACTIONS(3513),
    [anon_sym_GT_EQ] = ACTIONS(3515),
    [anon_sym_LT_EQ] = ACTIONS(3513),
    [anon_sym_LT] = ACTIONS(3513),
    [anon_sym_LT_LT] = ACTIONS(3513),
    [anon_sym_GT_GT] = ACTIONS(3513),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACE] = ACTIONS(3627),
    [anon_sym_LBRACK] = ACTIONS(3515),
    [anon_sym_EQ] = ACTIONS(3513),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_QMARK] = ACTIONS(3515),
    [anon_sym_STAR_EQ] = ACTIONS(3515),
    [anon_sym_SLASH_EQ] = ACTIONS(3515),
    [anon_sym_PERCENT_EQ] = ACTIONS(3515),
    [anon_sym_PLUS_EQ] = ACTIONS(3515),
    [anon_sym_DASH_EQ] = ACTIONS(3515),
    [anon_sym_LT_LT_EQ] = ACTIONS(3515),
    [anon_sym_GT_GT_EQ] = ACTIONS(3515),
    [anon_sym_AMP_EQ] = ACTIONS(3515),
    [anon_sym_CARET_EQ] = ACTIONS(3515),
    [anon_sym_PIPE_EQ] = ACTIONS(3515),
    [anon_sym_and_eq] = ACTIONS(3513),
    [anon_sym_or_eq] = ACTIONS(3513),
    [anon_sym_xor_eq] = ACTIONS(3513),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_LT_EQ_GT] = ACTIONS(3515),
    [anon_sym_or] = ACTIONS(3513),
    [anon_sym_and] = ACTIONS(3513),
    [anon_sym_bitor] = ACTIONS(3513),
    [anon_sym_xor] = ACTIONS(3513),
    [anon_sym_bitand] = ACTIONS(3513),
    [anon_sym_not_eq] = ACTIONS(3513),
    [anon_sym_DASH_DASH] = ACTIONS(3515),
    [anon_sym_PLUS_PLUS] = ACTIONS(3515),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [anon_sym_DOT] = ACTIONS(3513),
    [anon_sym_DOT_STAR] = ACTIONS(3515),
    [anon_sym_DASH_GT] = ACTIONS(3513),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [anon_sym_DASH_GT_STAR] = ACTIONS(3515),
    [sym_this] = ACTIONS(2068),
  },
  [904] = {
    [sym_identifier] = ACTIONS(3631),
    [anon_sym_COMMA] = ACTIONS(3633),
    [anon_sym_RPAREN] = ACTIONS(3633),
    [anon_sym_LPAREN2] = ACTIONS(3633),
    [anon_sym_BANG] = ACTIONS(3633),
    [anon_sym_TILDE] = ACTIONS(3633),
    [anon_sym_DASH] = ACTIONS(3631),
    [anon_sym_PLUS] = ACTIONS(3631),
    [anon_sym_STAR] = ACTIONS(3633),
    [anon_sym_AMP_AMP] = ACTIONS(3633),
    [anon_sym_AMP] = ACTIONS(3631),
    [anon_sym_SEMI] = ACTIONS(3633),
    [anon_sym___extension__] = ACTIONS(3631),
    [anon_sym_in] = ACTIONS(3631),
    [anon_sym_out] = ACTIONS(3631),
    [anon_sym_inout] = ACTIONS(3631),
    [anon_sym_extern] = ACTIONS(3631),
    [anon_sym___attribute__] = ACTIONS(3631),
    [anon_sym_COLON_COLON] = ACTIONS(3633),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3633),
    [anon_sym___declspec] = ACTIONS(3631),
    [anon_sym___based] = ACTIONS(3631),
    [anon_sym_LBRACE] = ACTIONS(3633),
    [anon_sym_signed] = ACTIONS(3631),
    [anon_sym_unsigned] = ACTIONS(3631),
    [anon_sym_long] = ACTIONS(3631),
    [anon_sym_short] = ACTIONS(3631),
    [anon_sym_LBRACK] = ACTIONS(3631),
    [anon_sym_static] = ACTIONS(3631),
    [anon_sym_EQ] = ACTIONS(3633),
    [anon_sym_register] = ACTIONS(3631),
    [anon_sym_inline] = ACTIONS(3631),
    [anon_sym___inline] = ACTIONS(3631),
    [anon_sym___inline__] = ACTIONS(3631),
    [anon_sym___forceinline] = ACTIONS(3631),
    [anon_sym_thread_local] = ACTIONS(3631),
    [anon_sym___thread] = ACTIONS(3631),
    [anon_sym_const] = ACTIONS(3631),
    [anon_sym_constexpr] = ACTIONS(3631),
    [anon_sym_volatile] = ACTIONS(3631),
    [anon_sym_restrict] = ACTIONS(3631),
    [anon_sym___restrict__] = ACTIONS(3631),
    [anon_sym__Atomic] = ACTIONS(3631),
    [anon_sym__Noreturn] = ACTIONS(3631),
    [anon_sym_noreturn] = ACTIONS(3631),
    [anon_sym_mutable] = ACTIONS(3631),
    [anon_sym_constinit] = ACTIONS(3631),
    [anon_sym_consteval] = ACTIONS(3631),
    [anon_sym_alignas] = ACTIONS(3631),
    [anon_sym__Alignas] = ACTIONS(3631),
    [sym_primitive_type] = ACTIONS(3631),
    [anon_sym_enum] = ACTIONS(3631),
    [anon_sym_class] = ACTIONS(3631),
    [anon_sym_struct] = ACTIONS(3631),
    [anon_sym_union] = ACTIONS(3631),
    [anon_sym_if] = ACTIONS(3631),
    [anon_sym_switch] = ACTIONS(3631),
    [anon_sym_case] = ACTIONS(3631),
    [anon_sym_default] = ACTIONS(3631),
    [anon_sym_while] = ACTIONS(3631),
    [anon_sym_do] = ACTIONS(3631),
    [anon_sym_for] = ACTIONS(3631),
    [anon_sym_return] = ACTIONS(3631),
    [anon_sym_break] = ACTIONS(3631),
    [anon_sym_continue] = ACTIONS(3631),
    [anon_sym_goto] = ACTIONS(3631),
    [anon_sym___try] = ACTIONS(3631),
    [anon_sym___leave] = ACTIONS(3631),
    [anon_sym_not] = ACTIONS(3631),
    [anon_sym_compl] = ACTIONS(3631),
    [anon_sym_DASH_DASH] = ACTIONS(3633),
    [anon_sym_PLUS_PLUS] = ACTIONS(3633),
    [anon_sym_sizeof] = ACTIONS(3631),
    [anon_sym___alignof__] = ACTIONS(3631),
    [anon_sym___alignof] = ACTIONS(3631),
    [anon_sym__alignof] = ACTIONS(3631),
    [anon_sym_alignof] = ACTIONS(3631),
    [anon_sym__Alignof] = ACTIONS(3631),
    [anon_sym_offsetof] = ACTIONS(3631),
    [anon_sym__Generic] = ACTIONS(3631),
    [anon_sym_asm] = ACTIONS(3631),
    [anon_sym___asm__] = ACTIONS(3631),
    [sym_number_literal] = ACTIONS(3633),
    [anon_sym_L_SQUOTE] = ACTIONS(3633),
    [anon_sym_u_SQUOTE] = ACTIONS(3633),
    [anon_sym_U_SQUOTE] = ACTIONS(3633),
    [anon_sym_u8_SQUOTE] = ACTIONS(3633),
    [anon_sym_SQUOTE] = ACTIONS(3633),
    [anon_sym_L_DQUOTE] = ACTIONS(3633),
    [anon_sym_u_DQUOTE] = ACTIONS(3633),
    [anon_sym_U_DQUOTE] = ACTIONS(3633),
    [anon_sym_u8_DQUOTE] = ACTIONS(3633),
    [anon_sym_DQUOTE] = ACTIONS(3633),
    [sym_true] = ACTIONS(3631),
    [sym_false] = ACTIONS(3631),
    [anon_sym_NULL] = ACTIONS(3631),
    [anon_sym_nullptr] = ACTIONS(3631),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3631),
    [anon_sym_decltype] = ACTIONS(3631),
    [sym_virtual] = ACTIONS(3631),
    [anon_sym_explicit] = ACTIONS(3631),
    [anon_sym_typename] = ACTIONS(3631),
    [anon_sym_template] = ACTIONS(3631),
    [anon_sym_operator] = ACTIONS(3631),
    [anon_sym_try] = ACTIONS(3631),
    [anon_sym_delete] = ACTIONS(3631),
    [anon_sym_throw] = ACTIONS(3631),
    [anon_sym_co_return] = ACTIONS(3631),
    [anon_sym_co_yield] = ACTIONS(3631),
    [anon_sym_R_DQUOTE] = ACTIONS(3633),
    [anon_sym_LR_DQUOTE] = ACTIONS(3633),
    [anon_sym_uR_DQUOTE] = ACTIONS(3633),
    [anon_sym_UR_DQUOTE] = ACTIONS(3633),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3633),
    [anon_sym_co_await] = ACTIONS(3631),
    [anon_sym_new] = ACTIONS(3631),
    [anon_sym_requires] = ACTIONS(3631),
    [sym_this] = ACTIONS(3631),
    [anon_sym_discard] = ACTIONS(3631),
    [anon_sym_precise] = ACTIONS(3631),
    [anon_sym_shared] = ACTIONS(3631),
    [anon_sym_groupshared] = ACTIONS(3631),
    [anon_sym_uniform] = ACTIONS(3631),
    [anon_sym_row_major] = ACTIONS(3631),
    [anon_sym_column_major] = ACTIONS(3631),
    [anon_sym_globallycoherent] = ACTIONS(3631),
    [anon_sym_centroid] = ACTIONS(3631),
    [anon_sym_noperspective] = ACTIONS(3631),
    [anon_sym_nointerpolation] = ACTIONS(3631),
    [anon_sym_sample] = ACTIONS(3631),
    [anon_sym_linear] = ACTIONS(3631),
    [anon_sym_snorm] = ACTIONS(3631),
    [anon_sym_unorm] = ACTIONS(3631),
    [anon_sym_point] = ACTIONS(3631),
    [anon_sym_line] = ACTIONS(3631),
    [anon_sym_triangleadj] = ACTIONS(3631),
    [anon_sym_lineadj] = ACTIONS(3631),
    [anon_sym_triangle] = ACTIONS(3631),
    [anon_sym_cbuffer] = ACTIONS(3631),
  },
  [905] = {
    [sym_expression] = STATE(2723),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_initializer_list] = STATE(2848),
    [sym_char_literal] = STATE(3360),
    [sym_concatenated_string] = STATE(3359),
    [sym_string_literal] = STATE(2634),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2625),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3635),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3515),
    [anon_sym_COMMA] = ACTIONS(3515),
    [anon_sym_LPAREN2] = ACTIONS(3515),
    [anon_sym_BANG] = ACTIONS(3637),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3513),
    [anon_sym_PLUS] = ACTIONS(3513),
    [anon_sym_STAR] = ACTIONS(3513),
    [anon_sym_SLASH] = ACTIONS(3513),
    [anon_sym_PERCENT] = ACTIONS(3513),
    [anon_sym_PIPE_PIPE] = ACTIONS(3515),
    [anon_sym_AMP_AMP] = ACTIONS(3515),
    [anon_sym_PIPE] = ACTIONS(3513),
    [anon_sym_CARET] = ACTIONS(3513),
    [anon_sym_AMP] = ACTIONS(3513),
    [anon_sym_EQ_EQ] = ACTIONS(3515),
    [anon_sym_BANG_EQ] = ACTIONS(3515),
    [anon_sym_GT] = ACTIONS(3513),
    [anon_sym_GT_EQ] = ACTIONS(3515),
    [anon_sym_LT_EQ] = ACTIONS(3513),
    [anon_sym_LT] = ACTIONS(3513),
    [anon_sym_LT_LT] = ACTIONS(3513),
    [anon_sym_GT_GT] = ACTIONS(3513),
    [anon_sym_SEMI] = ACTIONS(3515),
    [anon_sym___attribute__] = ACTIONS(3513),
    [anon_sym_COLON_COLON] = ACTIONS(3641),
    [anon_sym_LBRACE] = ACTIONS(3523),
    [anon_sym_LBRACK] = ACTIONS(3515),
    [anon_sym_EQ] = ACTIONS(3513),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_QMARK] = ACTIONS(3515),
    [anon_sym_STAR_EQ] = ACTIONS(3515),
    [anon_sym_SLASH_EQ] = ACTIONS(3515),
    [anon_sym_PERCENT_EQ] = ACTIONS(3515),
    [anon_sym_PLUS_EQ] = ACTIONS(3515),
    [anon_sym_DASH_EQ] = ACTIONS(3515),
    [anon_sym_LT_LT_EQ] = ACTIONS(3515),
    [anon_sym_GT_GT_EQ] = ACTIONS(3515),
    [anon_sym_AMP_EQ] = ACTIONS(3515),
    [anon_sym_CARET_EQ] = ACTIONS(3515),
    [anon_sym_PIPE_EQ] = ACTIONS(3515),
    [anon_sym_and_eq] = ACTIONS(3513),
    [anon_sym_or_eq] = ACTIONS(3513),
    [anon_sym_xor_eq] = ACTIONS(3513),
    [anon_sym_not] = ACTIONS(3637),
    [anon_sym_compl] = ACTIONS(3637),
    [anon_sym_LT_EQ_GT] = ACTIONS(3515),
    [anon_sym_or] = ACTIONS(3513),
    [anon_sym_and] = ACTIONS(3513),
    [anon_sym_bitor] = ACTIONS(3513),
    [anon_sym_xor] = ACTIONS(3513),
    [anon_sym_bitand] = ACTIONS(3513),
    [anon_sym_not_eq] = ACTIONS(3513),
    [anon_sym_DASH_DASH] = ACTIONS(3515),
    [anon_sym_PLUS_PLUS] = ACTIONS(3515),
    [anon_sym_sizeof] = ACTIONS(3643),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [anon_sym_DOT] = ACTIONS(3513),
    [anon_sym_DOT_STAR] = ACTIONS(3515),
    [anon_sym_DASH_GT] = ACTIONS(3515),
    [sym_number_literal] = ACTIONS(3645),
    [anon_sym_L_SQUOTE] = ACTIONS(3647),
    [anon_sym_u_SQUOTE] = ACTIONS(3647),
    [anon_sym_U_SQUOTE] = ACTIONS(3647),
    [anon_sym_u8_SQUOTE] = ACTIONS(3647),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [anon_sym_L_DQUOTE] = ACTIONS(3649),
    [anon_sym_u_DQUOTE] = ACTIONS(3649),
    [anon_sym_U_DQUOTE] = ACTIONS(3649),
    [anon_sym_u8_DQUOTE] = ACTIONS(3649),
    [anon_sym_DQUOTE] = ACTIONS(3649),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3651),
    [anon_sym_R_DQUOTE] = ACTIONS(3653),
    [anon_sym_LR_DQUOTE] = ACTIONS(3653),
    [anon_sym_uR_DQUOTE] = ACTIONS(3653),
    [anon_sym_UR_DQUOTE] = ACTIONS(3653),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3653),
    [anon_sym_co_await] = ACTIONS(3655),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [906] = {
    [sym_identifier] = ACTIONS(3657),
    [anon_sym_COMMA] = ACTIONS(3659),
    [anon_sym_RPAREN] = ACTIONS(3659),
    [anon_sym_LPAREN2] = ACTIONS(3659),
    [anon_sym_BANG] = ACTIONS(3659),
    [anon_sym_TILDE] = ACTIONS(3659),
    [anon_sym_DASH] = ACTIONS(3657),
    [anon_sym_PLUS] = ACTIONS(3657),
    [anon_sym_STAR] = ACTIONS(3659),
    [anon_sym_AMP_AMP] = ACTIONS(3659),
    [anon_sym_AMP] = ACTIONS(3657),
    [anon_sym_SEMI] = ACTIONS(3659),
    [anon_sym___extension__] = ACTIONS(3657),
    [anon_sym_in] = ACTIONS(3657),
    [anon_sym_out] = ACTIONS(3657),
    [anon_sym_inout] = ACTIONS(3657),
    [anon_sym_extern] = ACTIONS(3657),
    [anon_sym___attribute__] = ACTIONS(3657),
    [anon_sym_COLON_COLON] = ACTIONS(3659),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3659),
    [anon_sym___declspec] = ACTIONS(3657),
    [anon_sym___based] = ACTIONS(3657),
    [anon_sym_LBRACE] = ACTIONS(3659),
    [anon_sym_signed] = ACTIONS(3657),
    [anon_sym_unsigned] = ACTIONS(3657),
    [anon_sym_long] = ACTIONS(3657),
    [anon_sym_short] = ACTIONS(3657),
    [anon_sym_LBRACK] = ACTIONS(3657),
    [anon_sym_static] = ACTIONS(3657),
    [anon_sym_EQ] = ACTIONS(3659),
    [anon_sym_register] = ACTIONS(3657),
    [anon_sym_inline] = ACTIONS(3657),
    [anon_sym___inline] = ACTIONS(3657),
    [anon_sym___inline__] = ACTIONS(3657),
    [anon_sym___forceinline] = ACTIONS(3657),
    [anon_sym_thread_local] = ACTIONS(3657),
    [anon_sym___thread] = ACTIONS(3657),
    [anon_sym_const] = ACTIONS(3657),
    [anon_sym_constexpr] = ACTIONS(3657),
    [anon_sym_volatile] = ACTIONS(3657),
    [anon_sym_restrict] = ACTIONS(3657),
    [anon_sym___restrict__] = ACTIONS(3657),
    [anon_sym__Atomic] = ACTIONS(3657),
    [anon_sym__Noreturn] = ACTIONS(3657),
    [anon_sym_noreturn] = ACTIONS(3657),
    [anon_sym_mutable] = ACTIONS(3657),
    [anon_sym_constinit] = ACTIONS(3657),
    [anon_sym_consteval] = ACTIONS(3657),
    [anon_sym_alignas] = ACTIONS(3657),
    [anon_sym__Alignas] = ACTIONS(3657),
    [sym_primitive_type] = ACTIONS(3657),
    [anon_sym_enum] = ACTIONS(3657),
    [anon_sym_class] = ACTIONS(3657),
    [anon_sym_struct] = ACTIONS(3657),
    [anon_sym_union] = ACTIONS(3657),
    [anon_sym_if] = ACTIONS(3657),
    [anon_sym_switch] = ACTIONS(3657),
    [anon_sym_case] = ACTIONS(3657),
    [anon_sym_default] = ACTIONS(3657),
    [anon_sym_while] = ACTIONS(3657),
    [anon_sym_do] = ACTIONS(3657),
    [anon_sym_for] = ACTIONS(3657),
    [anon_sym_return] = ACTIONS(3657),
    [anon_sym_break] = ACTIONS(3657),
    [anon_sym_continue] = ACTIONS(3657),
    [anon_sym_goto] = ACTIONS(3657),
    [anon_sym___try] = ACTIONS(3657),
    [anon_sym___leave] = ACTIONS(3657),
    [anon_sym_not] = ACTIONS(3657),
    [anon_sym_compl] = ACTIONS(3657),
    [anon_sym_DASH_DASH] = ACTIONS(3659),
    [anon_sym_PLUS_PLUS] = ACTIONS(3659),
    [anon_sym_sizeof] = ACTIONS(3657),
    [anon_sym___alignof__] = ACTIONS(3657),
    [anon_sym___alignof] = ACTIONS(3657),
    [anon_sym__alignof] = ACTIONS(3657),
    [anon_sym_alignof] = ACTIONS(3657),
    [anon_sym__Alignof] = ACTIONS(3657),
    [anon_sym_offsetof] = ACTIONS(3657),
    [anon_sym__Generic] = ACTIONS(3657),
    [anon_sym_asm] = ACTIONS(3657),
    [anon_sym___asm__] = ACTIONS(3657),
    [sym_number_literal] = ACTIONS(3659),
    [anon_sym_L_SQUOTE] = ACTIONS(3659),
    [anon_sym_u_SQUOTE] = ACTIONS(3659),
    [anon_sym_U_SQUOTE] = ACTIONS(3659),
    [anon_sym_u8_SQUOTE] = ACTIONS(3659),
    [anon_sym_SQUOTE] = ACTIONS(3659),
    [anon_sym_L_DQUOTE] = ACTIONS(3659),
    [anon_sym_u_DQUOTE] = ACTIONS(3659),
    [anon_sym_U_DQUOTE] = ACTIONS(3659),
    [anon_sym_u8_DQUOTE] = ACTIONS(3659),
    [anon_sym_DQUOTE] = ACTIONS(3659),
    [sym_true] = ACTIONS(3657),
    [sym_false] = ACTIONS(3657),
    [anon_sym_NULL] = ACTIONS(3657),
    [anon_sym_nullptr] = ACTIONS(3657),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3657),
    [anon_sym_decltype] = ACTIONS(3657),
    [sym_virtual] = ACTIONS(3657),
    [anon_sym_explicit] = ACTIONS(3657),
    [anon_sym_typename] = ACTIONS(3657),
    [anon_sym_template] = ACTIONS(3657),
    [anon_sym_operator] = ACTIONS(3657),
    [anon_sym_try] = ACTIONS(3657),
    [anon_sym_delete] = ACTIONS(3657),
    [anon_sym_throw] = ACTIONS(3657),
    [anon_sym_co_return] = ACTIONS(3657),
    [anon_sym_co_yield] = ACTIONS(3657),
    [anon_sym_R_DQUOTE] = ACTIONS(3659),
    [anon_sym_LR_DQUOTE] = ACTIONS(3659),
    [anon_sym_uR_DQUOTE] = ACTIONS(3659),
    [anon_sym_UR_DQUOTE] = ACTIONS(3659),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3659),
    [anon_sym_co_await] = ACTIONS(3657),
    [anon_sym_new] = ACTIONS(3657),
    [anon_sym_requires] = ACTIONS(3657),
    [sym_this] = ACTIONS(3657),
    [anon_sym_discard] = ACTIONS(3657),
    [anon_sym_precise] = ACTIONS(3657),
    [anon_sym_shared] = ACTIONS(3657),
    [anon_sym_groupshared] = ACTIONS(3657),
    [anon_sym_uniform] = ACTIONS(3657),
    [anon_sym_row_major] = ACTIONS(3657),
    [anon_sym_column_major] = ACTIONS(3657),
    [anon_sym_globallycoherent] = ACTIONS(3657),
    [anon_sym_centroid] = ACTIONS(3657),
    [anon_sym_noperspective] = ACTIONS(3657),
    [anon_sym_nointerpolation] = ACTIONS(3657),
    [anon_sym_sample] = ACTIONS(3657),
    [anon_sym_linear] = ACTIONS(3657),
    [anon_sym_snorm] = ACTIONS(3657),
    [anon_sym_unorm] = ACTIONS(3657),
    [anon_sym_point] = ACTIONS(3657),
    [anon_sym_line] = ACTIONS(3657),
    [anon_sym_triangleadj] = ACTIONS(3657),
    [anon_sym_lineadj] = ACTIONS(3657),
    [anon_sym_triangle] = ACTIONS(3657),
    [anon_sym_cbuffer] = ACTIONS(3657),
  },
  [907] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3138),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8453),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(8261),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8259),
    [sym__unary_right_fold] = STATE(8258),
    [sym__binary_fold] = STATE(8257),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8546),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [908] = {
    [sym_function_definition] = STATE(2029),
    [sym_declaration] = STATE(2029),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4664),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1962),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6069),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2263),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__empty_declaration] = STATE(2029),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1829),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(2029),
    [sym_operator_cast] = STATE(6635),
    [sym__constructor_specifiers] = STATE(1829),
    [sym_operator_cast_definition] = STATE(2029),
    [sym_operator_cast_declaration] = STATE(2029),
    [sym_constructor_or_destructor_definition] = STATE(2029),
    [sym_constructor_or_destructor_declaration] = STATE(2029),
    [sym_friend_declaration] = STATE(2029),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_alias_declaration] = STATE(2029),
    [sym_concept_definition] = STATE(2029),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5415),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6635),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [sym_hlsl_attribute] = STATE(1312),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1829),
    [sym_identifier] = ACTIONS(3581),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3583),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(3585),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(2945),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2947),
    [anon_sym_using] = ACTIONS(3609),
    [anon_sym_concept] = ACTIONS(3611),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [909] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3138),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8453),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(8381),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8259),
    [sym__unary_right_fold] = STATE(8258),
    [sym__binary_fold] = STATE(8257),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8546),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [910] = {
    [sym_function_definition] = STATE(550),
    [sym_declaration] = STATE(550),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4694),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1965),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6018),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2254),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__empty_declaration] = STATE(550),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1831),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(550),
    [sym_operator_cast] = STATE(6668),
    [sym__constructor_specifiers] = STATE(1831),
    [sym_operator_cast_definition] = STATE(550),
    [sym_operator_cast_declaration] = STATE(550),
    [sym_constructor_or_destructor_definition] = STATE(550),
    [sym_constructor_or_destructor_declaration] = STATE(550),
    [sym_friend_declaration] = STATE(550),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_alias_declaration] = STATE(550),
    [sym_concept_definition] = STATE(550),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5415),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6668),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [sym_hlsl_attribute] = STATE(1361),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1831),
    [sym_identifier] = ACTIONS(3581),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3583),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(3585),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(3587),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(3589),
    [anon_sym_using] = ACTIONS(3591),
    [anon_sym_concept] = ACTIONS(835),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [911] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3138),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8453),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(8352),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8259),
    [sym__unary_right_fold] = STATE(8258),
    [sym__binary_fold] = STATE(8257),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8546),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [912] = {
    [sym_function_definition] = STATE(2131),
    [sym_declaration] = STATE(2131),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4730),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1947),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6105),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2259),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__empty_declaration] = STATE(2131),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1822),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(2131),
    [sym_operator_cast] = STATE(6626),
    [sym__constructor_specifiers] = STATE(1822),
    [sym_operator_cast_definition] = STATE(2131),
    [sym_operator_cast_declaration] = STATE(2131),
    [sym_constructor_or_destructor_definition] = STATE(2131),
    [sym_constructor_or_destructor_declaration] = STATE(2131),
    [sym_friend_declaration] = STATE(2131),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_alias_declaration] = STATE(2131),
    [sym_concept_definition] = STATE(2131),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5415),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6626),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [sym_hlsl_attribute] = STATE(1336),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1822),
    [sym_identifier] = ACTIONS(3581),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3583),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(3585),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(2871),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2873),
    [anon_sym_using] = ACTIONS(3601),
    [anon_sym_concept] = ACTIONS(3603),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [913] = {
    [sym_expression] = STATE(3397),
    [sym__string] = STATE(3729),
    [sym_conditional_expression] = STATE(3729),
    [sym_assignment_expression] = STATE(3729),
    [sym_pointer_expression] = STATE(3736),
    [sym_unary_expression] = STATE(3729),
    [sym_binary_expression] = STATE(3729),
    [sym_update_expression] = STATE(3729),
    [sym_cast_expression] = STATE(3729),
    [sym_sizeof_expression] = STATE(3729),
    [sym_alignof_expression] = STATE(3729),
    [sym_offsetof_expression] = STATE(3729),
    [sym_generic_expression] = STATE(3729),
    [sym_subscript_expression] = STATE(3736),
    [sym_call_expression] = STATE(3736),
    [sym_gnu_asm_expression] = STATE(3729),
    [sym_field_expression] = STATE(3736),
    [sym_compound_literal_expression] = STATE(3729),
    [sym_parenthesized_expression] = STATE(3736),
    [sym_initializer_list] = STATE(3727),
    [sym_char_literal] = STATE(3602),
    [sym_concatenated_string] = STATE(3610),
    [sym_string_literal] = STATE(2698),
    [sym_null] = STATE(3729),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7745),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3729),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(3729),
    [sym_new_expression] = STATE(3729),
    [sym_delete_expression] = STATE(3729),
    [sym_requires_clause] = STATE(3729),
    [sym_requires_expression] = STATE(3729),
    [sym_lambda_expression] = STATE(3729),
    [sym_lambda_capture_specifier] = STATE(5813),
    [sym_fold_expression] = STATE(3729),
    [sym_parameter_pack_expansion] = STATE(3729),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3736),
    [sym_qualified_type_identifier] = STATE(7745),
    [sym_user_defined_literal] = STATE(3736),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3515),
    [anon_sym_COMMA] = ACTIONS(3515),
    [anon_sym_LPAREN2] = ACTIONS(3515),
    [anon_sym_BANG] = ACTIONS(3669),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3513),
    [anon_sym_PLUS] = ACTIONS(3513),
    [anon_sym_STAR] = ACTIONS(3513),
    [anon_sym_SLASH] = ACTIONS(3513),
    [anon_sym_PERCENT] = ACTIONS(3513),
    [anon_sym_PIPE_PIPE] = ACTIONS(3515),
    [anon_sym_AMP_AMP] = ACTIONS(3515),
    [anon_sym_PIPE] = ACTIONS(3513),
    [anon_sym_CARET] = ACTIONS(3513),
    [anon_sym_AMP] = ACTIONS(3513),
    [anon_sym_EQ_EQ] = ACTIONS(3515),
    [anon_sym_BANG_EQ] = ACTIONS(3515),
    [anon_sym_GT] = ACTIONS(3513),
    [anon_sym_GT_EQ] = ACTIONS(3513),
    [anon_sym_LT_EQ] = ACTIONS(3513),
    [anon_sym_LT] = ACTIONS(3513),
    [anon_sym_LT_LT] = ACTIONS(3513),
    [anon_sym_GT_GT] = ACTIONS(3513),
    [anon_sym_COLON_COLON] = ACTIONS(3673),
    [anon_sym_LBRACE] = ACTIONS(3675),
    [anon_sym_LBRACK] = ACTIONS(3515),
    [anon_sym_EQ] = ACTIONS(3513),
    [sym_primitive_type] = ACTIONS(3677),
    [anon_sym_QMARK] = ACTIONS(3515),
    [anon_sym_STAR_EQ] = ACTIONS(3515),
    [anon_sym_SLASH_EQ] = ACTIONS(3515),
    [anon_sym_PERCENT_EQ] = ACTIONS(3515),
    [anon_sym_PLUS_EQ] = ACTIONS(3515),
    [anon_sym_DASH_EQ] = ACTIONS(3515),
    [anon_sym_LT_LT_EQ] = ACTIONS(3515),
    [anon_sym_GT_GT_EQ] = ACTIONS(3513),
    [anon_sym_AMP_EQ] = ACTIONS(3515),
    [anon_sym_CARET_EQ] = ACTIONS(3515),
    [anon_sym_PIPE_EQ] = ACTIONS(3515),
    [anon_sym_and_eq] = ACTIONS(3513),
    [anon_sym_or_eq] = ACTIONS(3513),
    [anon_sym_xor_eq] = ACTIONS(3513),
    [anon_sym_not] = ACTIONS(3669),
    [anon_sym_compl] = ACTIONS(3669),
    [anon_sym_LT_EQ_GT] = ACTIONS(3515),
    [anon_sym_or] = ACTIONS(3513),
    [anon_sym_and] = ACTIONS(3513),
    [anon_sym_bitor] = ACTIONS(3513),
    [anon_sym_xor] = ACTIONS(3513),
    [anon_sym_bitand] = ACTIONS(3513),
    [anon_sym_not_eq] = ACTIONS(3513),
    [anon_sym_DASH_DASH] = ACTIONS(3515),
    [anon_sym_PLUS_PLUS] = ACTIONS(3515),
    [anon_sym_sizeof] = ACTIONS(3679),
    [anon_sym___alignof__] = ACTIONS(3681),
    [anon_sym___alignof] = ACTIONS(3681),
    [anon_sym__alignof] = ACTIONS(3681),
    [anon_sym_alignof] = ACTIONS(3681),
    [anon_sym__Alignof] = ACTIONS(3681),
    [anon_sym_offsetof] = ACTIONS(3683),
    [anon_sym__Generic] = ACTIONS(3685),
    [anon_sym_asm] = ACTIONS(3687),
    [anon_sym___asm__] = ACTIONS(3687),
    [anon_sym_DOT] = ACTIONS(3513),
    [anon_sym_DOT_STAR] = ACTIONS(3515),
    [anon_sym_DASH_GT] = ACTIONS(3515),
    [sym_number_literal] = ACTIONS(3689),
    [anon_sym_L_SQUOTE] = ACTIONS(3691),
    [anon_sym_u_SQUOTE] = ACTIONS(3691),
    [anon_sym_U_SQUOTE] = ACTIONS(3691),
    [anon_sym_u8_SQUOTE] = ACTIONS(3691),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [anon_sym_L_DQUOTE] = ACTIONS(3693),
    [anon_sym_u_DQUOTE] = ACTIONS(3693),
    [anon_sym_U_DQUOTE] = ACTIONS(3693),
    [anon_sym_u8_DQUOTE] = ACTIONS(3693),
    [anon_sym_DQUOTE] = ACTIONS(3693),
    [sym_true] = ACTIONS(3695),
    [sym_false] = ACTIONS(3695),
    [anon_sym_NULL] = ACTIONS(3697),
    [anon_sym_nullptr] = ACTIONS(3697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(3515),
    [anon_sym_delete] = ACTIONS(3699),
    [anon_sym_R_DQUOTE] = ACTIONS(3701),
    [anon_sym_LR_DQUOTE] = ACTIONS(3701),
    [anon_sym_uR_DQUOTE] = ACTIONS(3701),
    [anon_sym_UR_DQUOTE] = ACTIONS(3701),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3701),
    [anon_sym_co_await] = ACTIONS(3703),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_requires] = ACTIONS(3707),
    [sym_this] = ACTIONS(3695),
  },
  [914] = {
    [sym_field_declaration_list] = STATE(1046),
    [sym_virtual_specifier] = STATE(6741),
    [sym_base_class_clause] = STATE(7701),
    [sym_identifier] = ACTIONS(1921),
    [anon_sym_LPAREN2] = ACTIONS(1923),
    [anon_sym_BANG] = ACTIONS(1923),
    [anon_sym_TILDE] = ACTIONS(1923),
    [anon_sym_DASH] = ACTIONS(1921),
    [anon_sym_PLUS] = ACTIONS(1921),
    [anon_sym_STAR] = ACTIONS(1923),
    [anon_sym_AMP] = ACTIONS(1923),
    [anon_sym_COLON] = ACTIONS(1911),
    [anon_sym_SEMI] = ACTIONS(1923),
    [anon_sym___extension__] = ACTIONS(1921),
    [anon_sym_typedef] = ACTIONS(1921),
    [anon_sym_in] = ACTIONS(1921),
    [anon_sym_out] = ACTIONS(1921),
    [anon_sym_inout] = ACTIONS(1921),
    [anon_sym_extern] = ACTIONS(1921),
    [anon_sym___attribute__] = ACTIONS(1921),
    [anon_sym_COLON_COLON] = ACTIONS(1923),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1923),
    [anon_sym___declspec] = ACTIONS(1921),
    [anon_sym_LBRACE] = ACTIONS(3709),
    [anon_sym_signed] = ACTIONS(1921),
    [anon_sym_unsigned] = ACTIONS(1921),
    [anon_sym_long] = ACTIONS(1921),
    [anon_sym_short] = ACTIONS(1921),
    [anon_sym_LBRACK] = ACTIONS(1921),
    [anon_sym_static] = ACTIONS(1921),
    [anon_sym_register] = ACTIONS(1921),
    [anon_sym_inline] = ACTIONS(1921),
    [anon_sym___inline] = ACTIONS(1921),
    [anon_sym___inline__] = ACTIONS(1921),
    [anon_sym___forceinline] = ACTIONS(1921),
    [anon_sym_thread_local] = ACTIONS(1921),
    [anon_sym___thread] = ACTIONS(1921),
    [anon_sym_const] = ACTIONS(1921),
    [anon_sym_constexpr] = ACTIONS(1921),
    [anon_sym_volatile] = ACTIONS(1921),
    [anon_sym_restrict] = ACTIONS(1921),
    [anon_sym___restrict__] = ACTIONS(1921),
    [anon_sym__Atomic] = ACTIONS(1921),
    [anon_sym__Noreturn] = ACTIONS(1921),
    [anon_sym_noreturn] = ACTIONS(1921),
    [anon_sym_mutable] = ACTIONS(1921),
    [anon_sym_constinit] = ACTIONS(1921),
    [anon_sym_consteval] = ACTIONS(1921),
    [anon_sym_alignas] = ACTIONS(1921),
    [anon_sym__Alignas] = ACTIONS(1921),
    [sym_primitive_type] = ACTIONS(1921),
    [anon_sym_enum] = ACTIONS(1921),
    [anon_sym_class] = ACTIONS(1921),
    [anon_sym_struct] = ACTIONS(1921),
    [anon_sym_union] = ACTIONS(1921),
    [anon_sym_if] = ACTIONS(1921),
    [anon_sym_else] = ACTIONS(1921),
    [anon_sym_switch] = ACTIONS(1921),
    [anon_sym_while] = ACTIONS(1921),
    [anon_sym_do] = ACTIONS(1921),
    [anon_sym_for] = ACTIONS(1921),
    [anon_sym_return] = ACTIONS(1921),
    [anon_sym_break] = ACTIONS(1921),
    [anon_sym_continue] = ACTIONS(1921),
    [anon_sym_goto] = ACTIONS(1921),
    [anon_sym___try] = ACTIONS(1921),
    [anon_sym___leave] = ACTIONS(1921),
    [anon_sym_not] = ACTIONS(1921),
    [anon_sym_compl] = ACTIONS(1921),
    [anon_sym_DASH_DASH] = ACTIONS(1923),
    [anon_sym_PLUS_PLUS] = ACTIONS(1923),
    [anon_sym_sizeof] = ACTIONS(1921),
    [anon_sym___alignof__] = ACTIONS(1921),
    [anon_sym___alignof] = ACTIONS(1921),
    [anon_sym__alignof] = ACTIONS(1921),
    [anon_sym_alignof] = ACTIONS(1921),
    [anon_sym__Alignof] = ACTIONS(1921),
    [anon_sym_offsetof] = ACTIONS(1921),
    [anon_sym__Generic] = ACTIONS(1921),
    [anon_sym_asm] = ACTIONS(1921),
    [anon_sym___asm__] = ACTIONS(1921),
    [sym_number_literal] = ACTIONS(1923),
    [anon_sym_L_SQUOTE] = ACTIONS(1923),
    [anon_sym_u_SQUOTE] = ACTIONS(1923),
    [anon_sym_U_SQUOTE] = ACTIONS(1923),
    [anon_sym_u8_SQUOTE] = ACTIONS(1923),
    [anon_sym_SQUOTE] = ACTIONS(1923),
    [anon_sym_L_DQUOTE] = ACTIONS(1923),
    [anon_sym_u_DQUOTE] = ACTIONS(1923),
    [anon_sym_U_DQUOTE] = ACTIONS(1923),
    [anon_sym_u8_DQUOTE] = ACTIONS(1923),
    [anon_sym_DQUOTE] = ACTIONS(1923),
    [sym_true] = ACTIONS(1921),
    [sym_false] = ACTIONS(1921),
    [anon_sym_NULL] = ACTIONS(1921),
    [anon_sym_nullptr] = ACTIONS(1921),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1921),
    [anon_sym_decltype] = ACTIONS(1921),
    [anon_sym_final] = ACTIONS(1915),
    [anon_sym_override] = ACTIONS(1915),
    [sym_virtual] = ACTIONS(1921),
    [anon_sym_typename] = ACTIONS(1921),
    [anon_sym_template] = ACTIONS(1921),
    [anon_sym_try] = ACTIONS(1921),
    [anon_sym_delete] = ACTIONS(1921),
    [anon_sym_throw] = ACTIONS(1921),
    [anon_sym_co_return] = ACTIONS(1921),
    [anon_sym_co_yield] = ACTIONS(1921),
    [anon_sym_R_DQUOTE] = ACTIONS(1923),
    [anon_sym_LR_DQUOTE] = ACTIONS(1923),
    [anon_sym_uR_DQUOTE] = ACTIONS(1923),
    [anon_sym_UR_DQUOTE] = ACTIONS(1923),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1923),
    [anon_sym_co_await] = ACTIONS(1921),
    [anon_sym_new] = ACTIONS(1921),
    [anon_sym_requires] = ACTIONS(1921),
    [sym_this] = ACTIONS(1921),
    [anon_sym_discard] = ACTIONS(1921),
    [anon_sym_precise] = ACTIONS(1921),
    [anon_sym_shared] = ACTIONS(1921),
    [anon_sym_groupshared] = ACTIONS(1921),
    [anon_sym_uniform] = ACTIONS(1921),
    [anon_sym_row_major] = ACTIONS(1921),
    [anon_sym_column_major] = ACTIONS(1921),
    [anon_sym_globallycoherent] = ACTIONS(1921),
    [anon_sym_centroid] = ACTIONS(1921),
    [anon_sym_noperspective] = ACTIONS(1921),
    [anon_sym_nointerpolation] = ACTIONS(1921),
    [anon_sym_sample] = ACTIONS(1921),
    [anon_sym_linear] = ACTIONS(1921),
    [anon_sym_snorm] = ACTIONS(1921),
    [anon_sym_unorm] = ACTIONS(1921),
    [anon_sym_point] = ACTIONS(1921),
    [anon_sym_line] = ACTIONS(1921),
    [anon_sym_triangleadj] = ACTIONS(1921),
    [anon_sym_lineadj] = ACTIONS(1921),
    [anon_sym_triangle] = ACTIONS(1921),
    [anon_sym_cbuffer] = ACTIONS(1921),
  },
  [915] = {
    [sym_function_definition] = STATE(798),
    [sym_declaration] = STATE(798),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4633),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1945),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6036),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2257),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__empty_declaration] = STATE(798),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1826),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(798),
    [sym_operator_cast] = STATE(6631),
    [sym__constructor_specifiers] = STATE(1826),
    [sym_operator_cast_definition] = STATE(798),
    [sym_operator_cast_declaration] = STATE(798),
    [sym_constructor_or_destructor_definition] = STATE(798),
    [sym_constructor_or_destructor_declaration] = STATE(798),
    [sym_friend_declaration] = STATE(798),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_alias_declaration] = STATE(798),
    [sym_concept_definition] = STATE(798),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5415),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6631),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [sym_hlsl_attribute] = STATE(1303),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1826),
    [sym_identifier] = ACTIONS(3581),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3583),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(3585),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(3613),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(3615),
    [anon_sym_using] = ACTIONS(3617),
    [anon_sym_concept] = ACTIONS(145),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [916] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3138),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8453),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(8568),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8259),
    [sym__unary_right_fold] = STATE(8258),
    [sym__binary_fold] = STATE(8257),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8546),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [917] = {
    [sym_function_definition] = STATE(256),
    [sym_declaration] = STATE(256),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1943),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6025),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2258),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__empty_declaration] = STATE(256),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1820),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(256),
    [sym_operator_cast] = STATE(6628),
    [sym__constructor_specifiers] = STATE(1820),
    [sym_operator_cast_definition] = STATE(256),
    [sym_operator_cast_declaration] = STATE(256),
    [sym_constructor_or_destructor_definition] = STATE(256),
    [sym_constructor_or_destructor_declaration] = STATE(256),
    [sym_friend_declaration] = STATE(256),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_alias_declaration] = STATE(256),
    [sym_concept_definition] = STATE(256),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5415),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6628),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [sym_hlsl_attribute] = STATE(1327),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1820),
    [sym_identifier] = ACTIONS(3581),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3583),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(3585),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(3595),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(3597),
    [anon_sym_using] = ACTIONS(3599),
    [anon_sym_concept] = ACTIONS(335),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [918] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3112),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8573),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(8426),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8570),
    [sym__unary_right_fold] = STATE(8567),
    [sym__binary_fold] = STATE(8566),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8565),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [919] = {
    [sym_field_declaration_list] = STATE(1022),
    [sym_virtual_specifier] = STATE(6771),
    [sym_base_class_clause] = STATE(7688),
    [sym_identifier] = ACTIONS(1907),
    [anon_sym_LPAREN2] = ACTIONS(1909),
    [anon_sym_BANG] = ACTIONS(1909),
    [anon_sym_TILDE] = ACTIONS(1909),
    [anon_sym_DASH] = ACTIONS(1907),
    [anon_sym_PLUS] = ACTIONS(1907),
    [anon_sym_STAR] = ACTIONS(1909),
    [anon_sym_AMP] = ACTIONS(1909),
    [anon_sym_COLON] = ACTIONS(1911),
    [anon_sym_SEMI] = ACTIONS(1909),
    [anon_sym___extension__] = ACTIONS(1907),
    [anon_sym_typedef] = ACTIONS(1907),
    [anon_sym_in] = ACTIONS(1907),
    [anon_sym_out] = ACTIONS(1907),
    [anon_sym_inout] = ACTIONS(1907),
    [anon_sym_extern] = ACTIONS(1907),
    [anon_sym___attribute__] = ACTIONS(1907),
    [anon_sym_COLON_COLON] = ACTIONS(1909),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1909),
    [anon_sym___declspec] = ACTIONS(1907),
    [anon_sym_LBRACE] = ACTIONS(3709),
    [anon_sym_signed] = ACTIONS(1907),
    [anon_sym_unsigned] = ACTIONS(1907),
    [anon_sym_long] = ACTIONS(1907),
    [anon_sym_short] = ACTIONS(1907),
    [anon_sym_LBRACK] = ACTIONS(1907),
    [anon_sym_static] = ACTIONS(1907),
    [anon_sym_register] = ACTIONS(1907),
    [anon_sym_inline] = ACTIONS(1907),
    [anon_sym___inline] = ACTIONS(1907),
    [anon_sym___inline__] = ACTIONS(1907),
    [anon_sym___forceinline] = ACTIONS(1907),
    [anon_sym_thread_local] = ACTIONS(1907),
    [anon_sym___thread] = ACTIONS(1907),
    [anon_sym_const] = ACTIONS(1907),
    [anon_sym_constexpr] = ACTIONS(1907),
    [anon_sym_volatile] = ACTIONS(1907),
    [anon_sym_restrict] = ACTIONS(1907),
    [anon_sym___restrict__] = ACTIONS(1907),
    [anon_sym__Atomic] = ACTIONS(1907),
    [anon_sym__Noreturn] = ACTIONS(1907),
    [anon_sym_noreturn] = ACTIONS(1907),
    [anon_sym_mutable] = ACTIONS(1907),
    [anon_sym_constinit] = ACTIONS(1907),
    [anon_sym_consteval] = ACTIONS(1907),
    [anon_sym_alignas] = ACTIONS(1907),
    [anon_sym__Alignas] = ACTIONS(1907),
    [sym_primitive_type] = ACTIONS(1907),
    [anon_sym_enum] = ACTIONS(1907),
    [anon_sym_class] = ACTIONS(1907),
    [anon_sym_struct] = ACTIONS(1907),
    [anon_sym_union] = ACTIONS(1907),
    [anon_sym_if] = ACTIONS(1907),
    [anon_sym_else] = ACTIONS(1907),
    [anon_sym_switch] = ACTIONS(1907),
    [anon_sym_while] = ACTIONS(1907),
    [anon_sym_do] = ACTIONS(1907),
    [anon_sym_for] = ACTIONS(1907),
    [anon_sym_return] = ACTIONS(1907),
    [anon_sym_break] = ACTIONS(1907),
    [anon_sym_continue] = ACTIONS(1907),
    [anon_sym_goto] = ACTIONS(1907),
    [anon_sym___try] = ACTIONS(1907),
    [anon_sym___leave] = ACTIONS(1907),
    [anon_sym_not] = ACTIONS(1907),
    [anon_sym_compl] = ACTIONS(1907),
    [anon_sym_DASH_DASH] = ACTIONS(1909),
    [anon_sym_PLUS_PLUS] = ACTIONS(1909),
    [anon_sym_sizeof] = ACTIONS(1907),
    [anon_sym___alignof__] = ACTIONS(1907),
    [anon_sym___alignof] = ACTIONS(1907),
    [anon_sym__alignof] = ACTIONS(1907),
    [anon_sym_alignof] = ACTIONS(1907),
    [anon_sym__Alignof] = ACTIONS(1907),
    [anon_sym_offsetof] = ACTIONS(1907),
    [anon_sym__Generic] = ACTIONS(1907),
    [anon_sym_asm] = ACTIONS(1907),
    [anon_sym___asm__] = ACTIONS(1907),
    [sym_number_literal] = ACTIONS(1909),
    [anon_sym_L_SQUOTE] = ACTIONS(1909),
    [anon_sym_u_SQUOTE] = ACTIONS(1909),
    [anon_sym_U_SQUOTE] = ACTIONS(1909),
    [anon_sym_u8_SQUOTE] = ACTIONS(1909),
    [anon_sym_SQUOTE] = ACTIONS(1909),
    [anon_sym_L_DQUOTE] = ACTIONS(1909),
    [anon_sym_u_DQUOTE] = ACTIONS(1909),
    [anon_sym_U_DQUOTE] = ACTIONS(1909),
    [anon_sym_u8_DQUOTE] = ACTIONS(1909),
    [anon_sym_DQUOTE] = ACTIONS(1909),
    [sym_true] = ACTIONS(1907),
    [sym_false] = ACTIONS(1907),
    [anon_sym_NULL] = ACTIONS(1907),
    [anon_sym_nullptr] = ACTIONS(1907),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1907),
    [anon_sym_decltype] = ACTIONS(1907),
    [anon_sym_final] = ACTIONS(1915),
    [anon_sym_override] = ACTIONS(1915),
    [sym_virtual] = ACTIONS(1907),
    [anon_sym_typename] = ACTIONS(1907),
    [anon_sym_template] = ACTIONS(1907),
    [anon_sym_try] = ACTIONS(1907),
    [anon_sym_delete] = ACTIONS(1907),
    [anon_sym_throw] = ACTIONS(1907),
    [anon_sym_co_return] = ACTIONS(1907),
    [anon_sym_co_yield] = ACTIONS(1907),
    [anon_sym_R_DQUOTE] = ACTIONS(1909),
    [anon_sym_LR_DQUOTE] = ACTIONS(1909),
    [anon_sym_uR_DQUOTE] = ACTIONS(1909),
    [anon_sym_UR_DQUOTE] = ACTIONS(1909),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1909),
    [anon_sym_co_await] = ACTIONS(1907),
    [anon_sym_new] = ACTIONS(1907),
    [anon_sym_requires] = ACTIONS(1907),
    [sym_this] = ACTIONS(1907),
    [anon_sym_discard] = ACTIONS(1907),
    [anon_sym_precise] = ACTIONS(1907),
    [anon_sym_shared] = ACTIONS(1907),
    [anon_sym_groupshared] = ACTIONS(1907),
    [anon_sym_uniform] = ACTIONS(1907),
    [anon_sym_row_major] = ACTIONS(1907),
    [anon_sym_column_major] = ACTIONS(1907),
    [anon_sym_globallycoherent] = ACTIONS(1907),
    [anon_sym_centroid] = ACTIONS(1907),
    [anon_sym_noperspective] = ACTIONS(1907),
    [anon_sym_nointerpolation] = ACTIONS(1907),
    [anon_sym_sample] = ACTIONS(1907),
    [anon_sym_linear] = ACTIONS(1907),
    [anon_sym_snorm] = ACTIONS(1907),
    [anon_sym_unorm] = ACTIONS(1907),
    [anon_sym_point] = ACTIONS(1907),
    [anon_sym_line] = ACTIONS(1907),
    [anon_sym_triangleadj] = ACTIONS(1907),
    [anon_sym_lineadj] = ACTIONS(1907),
    [anon_sym_triangle] = ACTIONS(1907),
    [anon_sym_cbuffer] = ACTIONS(1907),
  },
  [920] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3138),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8453),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(8244),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8259),
    [sym__unary_right_fold] = STATE(8258),
    [sym__binary_fold] = STATE(8257),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8546),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [921] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3138),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8453),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(8578),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8551),
    [sym__unary_right_fold] = STATE(8550),
    [sym__binary_fold] = STATE(8549),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8546),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [922] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3141),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8262),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(7993),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(7995),
    [sym__unary_right_fold] = STATE(7997),
    [sym__binary_fold] = STATE(7999),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8256),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [923] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3138),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8453),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(8552),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8551),
    [sym__unary_right_fold] = STATE(8550),
    [sym__binary_fold] = STATE(8549),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8546),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [924] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3138),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8453),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(8398),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8551),
    [sym__unary_right_fold] = STATE(8550),
    [sym__binary_fold] = STATE(8549),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8546),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [925] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3112),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8573),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(7892),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(7861),
    [sym__unary_right_fold] = STATE(7859),
    [sym__binary_fold] = STATE(7857),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8565),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [926] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3112),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8573),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(7862),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(7861),
    [sym__unary_right_fold] = STATE(7859),
    [sym__binary_fold] = STATE(7857),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8565),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [927] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3138),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8453),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(7932),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8551),
    [sym__unary_right_fold] = STATE(8550),
    [sym__binary_fold] = STATE(8549),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8546),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [928] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3138),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8453),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(8222),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8551),
    [sym__unary_right_fold] = STATE(8550),
    [sym__binary_fold] = STATE(8549),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8546),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [929] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3138),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8453),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(8122),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8551),
    [sym__unary_right_fold] = STATE(8550),
    [sym__binary_fold] = STATE(8549),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8546),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [930] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3138),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8453),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(8541),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8551),
    [sym__unary_right_fold] = STATE(8550),
    [sym__binary_fold] = STATE(8549),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8546),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [931] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3138),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8453),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(8100),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8259),
    [sym__unary_right_fold] = STATE(8258),
    [sym__binary_fold] = STATE(8257),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8546),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [932] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3138),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8453),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(8191),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8259),
    [sym__unary_right_fold] = STATE(8258),
    [sym__binary_fold] = STATE(8257),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8546),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [933] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3138),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8453),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(8001),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8551),
    [sym__unary_right_fold] = STATE(8550),
    [sym__binary_fold] = STATE(8549),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8546),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [934] = {
    [sym_expression] = STATE(3462),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_initializer_list] = STATE(2848),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3515),
    [anon_sym_COMMA] = ACTIONS(3515),
    [anon_sym_LPAREN2] = ACTIONS(3515),
    [anon_sym_BANG] = ACTIONS(3711),
    [anon_sym_TILDE] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3513),
    [anon_sym_PLUS] = ACTIONS(3513),
    [anon_sym_STAR] = ACTIONS(3513),
    [anon_sym_SLASH] = ACTIONS(3513),
    [anon_sym_PERCENT] = ACTIONS(3513),
    [anon_sym_PIPE_PIPE] = ACTIONS(3515),
    [anon_sym_AMP_AMP] = ACTIONS(3515),
    [anon_sym_PIPE] = ACTIONS(3513),
    [anon_sym_CARET] = ACTIONS(3513),
    [anon_sym_AMP] = ACTIONS(3513),
    [anon_sym_EQ_EQ] = ACTIONS(3515),
    [anon_sym_BANG_EQ] = ACTIONS(3515),
    [anon_sym_GT] = ACTIONS(3513),
    [anon_sym_GT_EQ] = ACTIONS(3515),
    [anon_sym_LT_EQ] = ACTIONS(3513),
    [anon_sym_LT] = ACTIONS(3513),
    [anon_sym_LT_LT] = ACTIONS(3513),
    [anon_sym_GT_GT] = ACTIONS(3513),
    [anon_sym_COLON] = ACTIONS(3513),
    [anon_sym_COLON_COLON] = ACTIONS(3715),
    [anon_sym_LBRACE] = ACTIONS(3523),
    [anon_sym_LBRACK] = ACTIONS(3515),
    [anon_sym_EQ] = ACTIONS(3513),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_QMARK] = ACTIONS(3515),
    [anon_sym_STAR_EQ] = ACTIONS(3515),
    [anon_sym_SLASH_EQ] = ACTIONS(3515),
    [anon_sym_PERCENT_EQ] = ACTIONS(3515),
    [anon_sym_PLUS_EQ] = ACTIONS(3515),
    [anon_sym_DASH_EQ] = ACTIONS(3515),
    [anon_sym_LT_LT_EQ] = ACTIONS(3515),
    [anon_sym_GT_GT_EQ] = ACTIONS(3515),
    [anon_sym_AMP_EQ] = ACTIONS(3515),
    [anon_sym_CARET_EQ] = ACTIONS(3515),
    [anon_sym_PIPE_EQ] = ACTIONS(3515),
    [anon_sym_and_eq] = ACTIONS(3513),
    [anon_sym_or_eq] = ACTIONS(3513),
    [anon_sym_xor_eq] = ACTIONS(3513),
    [anon_sym_not] = ACTIONS(3711),
    [anon_sym_compl] = ACTIONS(3711),
    [anon_sym_LT_EQ_GT] = ACTIONS(3515),
    [anon_sym_or] = ACTIONS(3513),
    [anon_sym_and] = ACTIONS(3513),
    [anon_sym_bitor] = ACTIONS(3513),
    [anon_sym_xor] = ACTIONS(3513),
    [anon_sym_bitand] = ACTIONS(3513),
    [anon_sym_not_eq] = ACTIONS(3513),
    [anon_sym_DASH_DASH] = ACTIONS(3515),
    [anon_sym_PLUS_PLUS] = ACTIONS(3515),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [anon_sym_DOT] = ACTIONS(3513),
    [anon_sym_DOT_STAR] = ACTIONS(3515),
    [anon_sym_DASH_GT] = ACTIONS(3515),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3719),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [935] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3138),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8453),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(8187),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8551),
    [sym__unary_right_fold] = STATE(8550),
    [sym__binary_fold] = STATE(8549),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8546),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [936] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3112),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8573),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(8572),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8570),
    [sym__unary_right_fold] = STATE(8567),
    [sym__binary_fold] = STATE(8566),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8565),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [937] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3141),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8262),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(7979),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8027),
    [sym__unary_right_fold] = STATE(8025),
    [sym__binary_fold] = STATE(8021),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8256),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [938] = {
    [sym_function_definition] = STATE(645),
    [sym_declaration] = STATE(645),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1955),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6017),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2256),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__empty_declaration] = STATE(645),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1830),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(645),
    [sym_operator_cast] = STATE(6629),
    [sym__constructor_specifiers] = STATE(1830),
    [sym_operator_cast_definition] = STATE(645),
    [sym_operator_cast_declaration] = STATE(645),
    [sym_constructor_or_destructor_definition] = STATE(645),
    [sym_constructor_or_destructor_declaration] = STATE(645),
    [sym_friend_declaration] = STATE(645),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_alias_declaration] = STATE(645),
    [sym_concept_definition] = STATE(645),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5415),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6629),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [sym_hlsl_attribute] = STATE(1354),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1830),
    [sym_identifier] = ACTIONS(3581),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3583),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(3585),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(3619),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(3621),
    [anon_sym_using] = ACTIONS(3623),
    [anon_sym_concept] = ACTIONS(235),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [939] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3138),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8453),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(8383),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8551),
    [sym__unary_right_fold] = STATE(8550),
    [sym__binary_fold] = STATE(8549),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8546),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [940] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3141),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8262),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(8029),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8027),
    [sym__unary_right_fold] = STATE(8025),
    [sym__binary_fold] = STATE(8021),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8256),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [941] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3138),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8453),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(8212),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(8259),
    [sym__unary_right_fold] = STATE(8258),
    [sym__binary_fold] = STATE(8257),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8546),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [942] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(3141),
    [sym__string] = STATE(3609),
    [sym_comma_expression] = STATE(8262),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_type_descriptor] = STATE(8037),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7503),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym__unary_left_fold] = STATE(7995),
    [sym__unary_right_fold] = STATE(7997),
    [sym__binary_fold] = STATE(7999),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5625),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym__assignment_expression_lhs] = STATE(8256),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3661),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2040),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [943] = {
    [sym_function_definition] = STATE(1844),
    [sym_declaration] = STATE(1844),
    [sym__declaration_modifiers] = STATE(2369),
    [sym__declaration_specifiers] = STATE(4626),
    [sym_attribute_specifier] = STATE(2369),
    [sym_attribute_declaration] = STATE(2369),
    [sym_ms_declspec_modifier] = STATE(2369),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(1953),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6102),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2369),
    [sym_type_qualifier] = STATE(2369),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2265),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym__empty_declaration] = STATE(1844),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_explicit_function_specifier] = STATE(1832),
    [sym_dependent_type] = STATE(2277),
    [sym_template_declaration] = STATE(1844),
    [sym_operator_cast] = STATE(6636),
    [sym__constructor_specifiers] = STATE(1832),
    [sym_operator_cast_definition] = STATE(1844),
    [sym_operator_cast_declaration] = STATE(1844),
    [sym_constructor_or_destructor_definition] = STATE(1844),
    [sym_constructor_or_destructor_declaration] = STATE(1844),
    [sym_friend_declaration] = STATE(1844),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_alias_declaration] = STATE(1844),
    [sym_concept_definition] = STATE(1844),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5415),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualified_operator_cast_identifier] = STATE(6636),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2369),
    [sym_hlsl_attribute] = STATE(1357),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [aux_sym_operator_cast_definition_repeat1] = STATE(1832),
    [sym_identifier] = ACTIONS(3581),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(37),
    [anon_sym_out] = ACTIONS(37),
    [anon_sym_inout] = ACTIONS(37),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3583),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(3585),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(37),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(2629),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_friend] = ACTIONS(2631),
    [anon_sym_using] = ACTIONS(3605),
    [anon_sym_concept] = ACTIONS(3607),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [944] = {
    [sym_template_argument_list] = STATE(952),
    [sym_identifier] = ACTIONS(1933),
    [anon_sym_LPAREN2] = ACTIONS(1935),
    [anon_sym_BANG] = ACTIONS(1935),
    [anon_sym_TILDE] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1933),
    [anon_sym_PLUS] = ACTIONS(1933),
    [anon_sym_STAR] = ACTIONS(1935),
    [anon_sym_AMP] = ACTIONS(1935),
    [anon_sym_LT] = ACTIONS(3723),
    [anon_sym_COLON] = ACTIONS(1933),
    [anon_sym_SEMI] = ACTIONS(1935),
    [anon_sym___extension__] = ACTIONS(1933),
    [anon_sym_typedef] = ACTIONS(1933),
    [anon_sym_in] = ACTIONS(1933),
    [anon_sym_out] = ACTIONS(1933),
    [anon_sym_inout] = ACTIONS(1933),
    [anon_sym_extern] = ACTIONS(1933),
    [anon_sym___attribute__] = ACTIONS(1933),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1935),
    [anon_sym___declspec] = ACTIONS(1933),
    [anon_sym_LBRACE] = ACTIONS(1935),
    [anon_sym_signed] = ACTIONS(1933),
    [anon_sym_unsigned] = ACTIONS(1933),
    [anon_sym_long] = ACTIONS(1933),
    [anon_sym_short] = ACTIONS(1933),
    [anon_sym_LBRACK] = ACTIONS(1933),
    [anon_sym_static] = ACTIONS(1933),
    [anon_sym_register] = ACTIONS(1933),
    [anon_sym_inline] = ACTIONS(1933),
    [anon_sym___inline] = ACTIONS(1933),
    [anon_sym___inline__] = ACTIONS(1933),
    [anon_sym___forceinline] = ACTIONS(1933),
    [anon_sym_thread_local] = ACTIONS(1933),
    [anon_sym___thread] = ACTIONS(1933),
    [anon_sym_const] = ACTIONS(1933),
    [anon_sym_constexpr] = ACTIONS(1933),
    [anon_sym_volatile] = ACTIONS(1933),
    [anon_sym_restrict] = ACTIONS(1933),
    [anon_sym___restrict__] = ACTIONS(1933),
    [anon_sym__Atomic] = ACTIONS(1933),
    [anon_sym__Noreturn] = ACTIONS(1933),
    [anon_sym_noreturn] = ACTIONS(1933),
    [anon_sym_mutable] = ACTIONS(1933),
    [anon_sym_constinit] = ACTIONS(1933),
    [anon_sym_consteval] = ACTIONS(1933),
    [anon_sym_alignas] = ACTIONS(1933),
    [anon_sym__Alignas] = ACTIONS(1933),
    [sym_primitive_type] = ACTIONS(1933),
    [anon_sym_enum] = ACTIONS(1933),
    [anon_sym_class] = ACTIONS(1933),
    [anon_sym_struct] = ACTIONS(1933),
    [anon_sym_union] = ACTIONS(1933),
    [anon_sym_if] = ACTIONS(1933),
    [anon_sym_else] = ACTIONS(1933),
    [anon_sym_switch] = ACTIONS(1933),
    [anon_sym_while] = ACTIONS(1933),
    [anon_sym_do] = ACTIONS(1933),
    [anon_sym_for] = ACTIONS(1933),
    [anon_sym_return] = ACTIONS(1933),
    [anon_sym_break] = ACTIONS(1933),
    [anon_sym_continue] = ACTIONS(1933),
    [anon_sym_goto] = ACTIONS(1933),
    [anon_sym___try] = ACTIONS(1933),
    [anon_sym___leave] = ACTIONS(1933),
    [anon_sym_not] = ACTIONS(1933),
    [anon_sym_compl] = ACTIONS(1933),
    [anon_sym_DASH_DASH] = ACTIONS(1935),
    [anon_sym_PLUS_PLUS] = ACTIONS(1935),
    [anon_sym_sizeof] = ACTIONS(1933),
    [anon_sym___alignof__] = ACTIONS(1933),
    [anon_sym___alignof] = ACTIONS(1933),
    [anon_sym__alignof] = ACTIONS(1933),
    [anon_sym_alignof] = ACTIONS(1933),
    [anon_sym__Alignof] = ACTIONS(1933),
    [anon_sym_offsetof] = ACTIONS(1933),
    [anon_sym__Generic] = ACTIONS(1933),
    [anon_sym_asm] = ACTIONS(1933),
    [anon_sym___asm__] = ACTIONS(1933),
    [sym_number_literal] = ACTIONS(1935),
    [anon_sym_L_SQUOTE] = ACTIONS(1935),
    [anon_sym_u_SQUOTE] = ACTIONS(1935),
    [anon_sym_U_SQUOTE] = ACTIONS(1935),
    [anon_sym_u8_SQUOTE] = ACTIONS(1935),
    [anon_sym_SQUOTE] = ACTIONS(1935),
    [anon_sym_L_DQUOTE] = ACTIONS(1935),
    [anon_sym_u_DQUOTE] = ACTIONS(1935),
    [anon_sym_U_DQUOTE] = ACTIONS(1935),
    [anon_sym_u8_DQUOTE] = ACTIONS(1935),
    [anon_sym_DQUOTE] = ACTIONS(1935),
    [sym_true] = ACTIONS(1933),
    [sym_false] = ACTIONS(1933),
    [anon_sym_NULL] = ACTIONS(1933),
    [anon_sym_nullptr] = ACTIONS(1933),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1933),
    [anon_sym_decltype] = ACTIONS(1933),
    [anon_sym_final] = ACTIONS(1933),
    [anon_sym_override] = ACTIONS(1933),
    [sym_virtual] = ACTIONS(1933),
    [anon_sym_typename] = ACTIONS(1933),
    [anon_sym_template] = ACTIONS(1933),
    [anon_sym_try] = ACTIONS(1933),
    [anon_sym_delete] = ACTIONS(1933),
    [anon_sym_throw] = ACTIONS(1933),
    [anon_sym_co_return] = ACTIONS(1933),
    [anon_sym_co_yield] = ACTIONS(1933),
    [anon_sym_R_DQUOTE] = ACTIONS(1935),
    [anon_sym_LR_DQUOTE] = ACTIONS(1935),
    [anon_sym_uR_DQUOTE] = ACTIONS(1935),
    [anon_sym_UR_DQUOTE] = ACTIONS(1935),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1935),
    [anon_sym_co_await] = ACTIONS(1933),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_requires] = ACTIONS(1933),
    [sym_this] = ACTIONS(1933),
    [anon_sym_discard] = ACTIONS(1933),
    [anon_sym_precise] = ACTIONS(1933),
    [anon_sym_shared] = ACTIONS(1933),
    [anon_sym_groupshared] = ACTIONS(1933),
    [anon_sym_uniform] = ACTIONS(1933),
    [anon_sym_row_major] = ACTIONS(1933),
    [anon_sym_column_major] = ACTIONS(1933),
    [anon_sym_globallycoherent] = ACTIONS(1933),
    [anon_sym_centroid] = ACTIONS(1933),
    [anon_sym_noperspective] = ACTIONS(1933),
    [anon_sym_nointerpolation] = ACTIONS(1933),
    [anon_sym_sample] = ACTIONS(1933),
    [anon_sym_linear] = ACTIONS(1933),
    [anon_sym_snorm] = ACTIONS(1933),
    [anon_sym_unorm] = ACTIONS(1933),
    [anon_sym_point] = ACTIONS(1933),
    [anon_sym_line] = ACTIONS(1933),
    [anon_sym_triangleadj] = ACTIONS(1933),
    [anon_sym_lineadj] = ACTIONS(1933),
    [anon_sym_triangle] = ACTIONS(1933),
    [anon_sym_cbuffer] = ACTIONS(1933),
  },
  [945] = {
    [sym_template_argument_list] = STATE(952),
    [sym_identifier] = ACTIONS(1941),
    [anon_sym_LPAREN2] = ACTIONS(1943),
    [anon_sym_BANG] = ACTIONS(1943),
    [anon_sym_TILDE] = ACTIONS(1943),
    [anon_sym_DASH] = ACTIONS(1941),
    [anon_sym_PLUS] = ACTIONS(1941),
    [anon_sym_STAR] = ACTIONS(1943),
    [anon_sym_AMP] = ACTIONS(1943),
    [anon_sym_LT] = ACTIONS(3723),
    [anon_sym_COLON] = ACTIONS(1941),
    [anon_sym_SEMI] = ACTIONS(1943),
    [anon_sym___extension__] = ACTIONS(1941),
    [anon_sym_typedef] = ACTIONS(1941),
    [anon_sym_in] = ACTIONS(1941),
    [anon_sym_out] = ACTIONS(1941),
    [anon_sym_inout] = ACTIONS(1941),
    [anon_sym_extern] = ACTIONS(1941),
    [anon_sym___attribute__] = ACTIONS(1941),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1943),
    [anon_sym___declspec] = ACTIONS(1941),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_signed] = ACTIONS(1941),
    [anon_sym_unsigned] = ACTIONS(1941),
    [anon_sym_long] = ACTIONS(1941),
    [anon_sym_short] = ACTIONS(1941),
    [anon_sym_LBRACK] = ACTIONS(1941),
    [anon_sym_static] = ACTIONS(1941),
    [anon_sym_register] = ACTIONS(1941),
    [anon_sym_inline] = ACTIONS(1941),
    [anon_sym___inline] = ACTIONS(1941),
    [anon_sym___inline__] = ACTIONS(1941),
    [anon_sym___forceinline] = ACTIONS(1941),
    [anon_sym_thread_local] = ACTIONS(1941),
    [anon_sym___thread] = ACTIONS(1941),
    [anon_sym_const] = ACTIONS(1941),
    [anon_sym_constexpr] = ACTIONS(1941),
    [anon_sym_volatile] = ACTIONS(1941),
    [anon_sym_restrict] = ACTIONS(1941),
    [anon_sym___restrict__] = ACTIONS(1941),
    [anon_sym__Atomic] = ACTIONS(1941),
    [anon_sym__Noreturn] = ACTIONS(1941),
    [anon_sym_noreturn] = ACTIONS(1941),
    [anon_sym_mutable] = ACTIONS(1941),
    [anon_sym_constinit] = ACTIONS(1941),
    [anon_sym_consteval] = ACTIONS(1941),
    [anon_sym_alignas] = ACTIONS(1941),
    [anon_sym__Alignas] = ACTIONS(1941),
    [sym_primitive_type] = ACTIONS(1941),
    [anon_sym_enum] = ACTIONS(1941),
    [anon_sym_class] = ACTIONS(1941),
    [anon_sym_struct] = ACTIONS(1941),
    [anon_sym_union] = ACTIONS(1941),
    [anon_sym_if] = ACTIONS(1941),
    [anon_sym_else] = ACTIONS(1941),
    [anon_sym_switch] = ACTIONS(1941),
    [anon_sym_while] = ACTIONS(1941),
    [anon_sym_do] = ACTIONS(1941),
    [anon_sym_for] = ACTIONS(1941),
    [anon_sym_return] = ACTIONS(1941),
    [anon_sym_break] = ACTIONS(1941),
    [anon_sym_continue] = ACTIONS(1941),
    [anon_sym_goto] = ACTIONS(1941),
    [anon_sym___try] = ACTIONS(1941),
    [anon_sym___leave] = ACTIONS(1941),
    [anon_sym_not] = ACTIONS(1941),
    [anon_sym_compl] = ACTIONS(1941),
    [anon_sym_DASH_DASH] = ACTIONS(1943),
    [anon_sym_PLUS_PLUS] = ACTIONS(1943),
    [anon_sym_sizeof] = ACTIONS(1941),
    [anon_sym___alignof__] = ACTIONS(1941),
    [anon_sym___alignof] = ACTIONS(1941),
    [anon_sym__alignof] = ACTIONS(1941),
    [anon_sym_alignof] = ACTIONS(1941),
    [anon_sym__Alignof] = ACTIONS(1941),
    [anon_sym_offsetof] = ACTIONS(1941),
    [anon_sym__Generic] = ACTIONS(1941),
    [anon_sym_asm] = ACTIONS(1941),
    [anon_sym___asm__] = ACTIONS(1941),
    [sym_number_literal] = ACTIONS(1943),
    [anon_sym_L_SQUOTE] = ACTIONS(1943),
    [anon_sym_u_SQUOTE] = ACTIONS(1943),
    [anon_sym_U_SQUOTE] = ACTIONS(1943),
    [anon_sym_u8_SQUOTE] = ACTIONS(1943),
    [anon_sym_SQUOTE] = ACTIONS(1943),
    [anon_sym_L_DQUOTE] = ACTIONS(1943),
    [anon_sym_u_DQUOTE] = ACTIONS(1943),
    [anon_sym_U_DQUOTE] = ACTIONS(1943),
    [anon_sym_u8_DQUOTE] = ACTIONS(1943),
    [anon_sym_DQUOTE] = ACTIONS(1943),
    [sym_true] = ACTIONS(1941),
    [sym_false] = ACTIONS(1941),
    [anon_sym_NULL] = ACTIONS(1941),
    [anon_sym_nullptr] = ACTIONS(1941),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1941),
    [anon_sym_decltype] = ACTIONS(1941),
    [anon_sym_final] = ACTIONS(1941),
    [anon_sym_override] = ACTIONS(1941),
    [sym_virtual] = ACTIONS(1941),
    [anon_sym_typename] = ACTIONS(1941),
    [anon_sym_template] = ACTIONS(1941),
    [anon_sym_try] = ACTIONS(1941),
    [anon_sym_delete] = ACTIONS(1941),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_co_return] = ACTIONS(1941),
    [anon_sym_co_yield] = ACTIONS(1941),
    [anon_sym_R_DQUOTE] = ACTIONS(1943),
    [anon_sym_LR_DQUOTE] = ACTIONS(1943),
    [anon_sym_uR_DQUOTE] = ACTIONS(1943),
    [anon_sym_UR_DQUOTE] = ACTIONS(1943),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1943),
    [anon_sym_co_await] = ACTIONS(1941),
    [anon_sym_new] = ACTIONS(1941),
    [anon_sym_requires] = ACTIONS(1941),
    [sym_this] = ACTIONS(1941),
    [anon_sym_discard] = ACTIONS(1941),
    [anon_sym_precise] = ACTIONS(1941),
    [anon_sym_shared] = ACTIONS(1941),
    [anon_sym_groupshared] = ACTIONS(1941),
    [anon_sym_uniform] = ACTIONS(1941),
    [anon_sym_row_major] = ACTIONS(1941),
    [anon_sym_column_major] = ACTIONS(1941),
    [anon_sym_globallycoherent] = ACTIONS(1941),
    [anon_sym_centroid] = ACTIONS(1941),
    [anon_sym_noperspective] = ACTIONS(1941),
    [anon_sym_nointerpolation] = ACTIONS(1941),
    [anon_sym_sample] = ACTIONS(1941),
    [anon_sym_linear] = ACTIONS(1941),
    [anon_sym_snorm] = ACTIONS(1941),
    [anon_sym_unorm] = ACTIONS(1941),
    [anon_sym_point] = ACTIONS(1941),
    [anon_sym_line] = ACTIONS(1941),
    [anon_sym_triangleadj] = ACTIONS(1941),
    [anon_sym_lineadj] = ACTIONS(1941),
    [anon_sym_triangle] = ACTIONS(1941),
    [anon_sym_cbuffer] = ACTIONS(1941),
  },
  [946] = {
    [sym_identifier] = ACTIONS(3725),
    [anon_sym_LPAREN2] = ACTIONS(3728),
    [anon_sym_BANG] = ACTIONS(3731),
    [anon_sym_TILDE] = ACTIONS(3728),
    [anon_sym_DASH] = ACTIONS(3733),
    [anon_sym_PLUS] = ACTIONS(3733),
    [anon_sym_STAR] = ACTIONS(3728),
    [anon_sym_AMP_AMP] = ACTIONS(3735),
    [anon_sym_AMP] = ACTIONS(3725),
    [anon_sym_SEMI] = ACTIONS(3731),
    [anon_sym___extension__] = ACTIONS(3737),
    [anon_sym_in] = ACTIONS(3737),
    [anon_sym_out] = ACTIONS(3737),
    [anon_sym_inout] = ACTIONS(3737),
    [anon_sym_extern] = ACTIONS(3737),
    [anon_sym___attribute__] = ACTIONS(3737),
    [anon_sym_COLON_COLON] = ACTIONS(3728),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3728),
    [anon_sym___declspec] = ACTIONS(3737),
    [anon_sym___based] = ACTIONS(3737),
    [anon_sym_LBRACE] = ACTIONS(3731),
    [anon_sym_signed] = ACTIONS(3737),
    [anon_sym_unsigned] = ACTIONS(3737),
    [anon_sym_long] = ACTIONS(3737),
    [anon_sym_short] = ACTIONS(3737),
    [anon_sym_LBRACK] = ACTIONS(3725),
    [anon_sym_static] = ACTIONS(3737),
    [anon_sym_register] = ACTIONS(3737),
    [anon_sym_inline] = ACTIONS(3737),
    [anon_sym___inline] = ACTIONS(3737),
    [anon_sym___inline__] = ACTIONS(3737),
    [anon_sym___forceinline] = ACTIONS(3737),
    [anon_sym_thread_local] = ACTIONS(3737),
    [anon_sym___thread] = ACTIONS(3737),
    [anon_sym_const] = ACTIONS(3737),
    [anon_sym_constexpr] = ACTIONS(3737),
    [anon_sym_volatile] = ACTIONS(3737),
    [anon_sym_restrict] = ACTIONS(3737),
    [anon_sym___restrict__] = ACTIONS(3737),
    [anon_sym__Atomic] = ACTIONS(3737),
    [anon_sym__Noreturn] = ACTIONS(3737),
    [anon_sym_noreturn] = ACTIONS(3737),
    [anon_sym_mutable] = ACTIONS(3737),
    [anon_sym_constinit] = ACTIONS(3737),
    [anon_sym_consteval] = ACTIONS(3737),
    [anon_sym_alignas] = ACTIONS(3737),
    [anon_sym__Alignas] = ACTIONS(3737),
    [sym_primitive_type] = ACTIONS(3725),
    [anon_sym_enum] = ACTIONS(3737),
    [anon_sym_class] = ACTIONS(3737),
    [anon_sym_struct] = ACTIONS(3737),
    [anon_sym_union] = ACTIONS(3737),
    [anon_sym_if] = ACTIONS(3733),
    [anon_sym_switch] = ACTIONS(3733),
    [anon_sym_case] = ACTIONS(3733),
    [anon_sym_default] = ACTIONS(3733),
    [anon_sym_while] = ACTIONS(3733),
    [anon_sym_do] = ACTIONS(3733),
    [anon_sym_for] = ACTIONS(3733),
    [anon_sym_return] = ACTIONS(3733),
    [anon_sym_break] = ACTIONS(3733),
    [anon_sym_continue] = ACTIONS(3733),
    [anon_sym_goto] = ACTIONS(3733),
    [anon_sym___try] = ACTIONS(3733),
    [anon_sym___leave] = ACTIONS(3733),
    [anon_sym_not] = ACTIONS(3733),
    [anon_sym_compl] = ACTIONS(3733),
    [anon_sym_DASH_DASH] = ACTIONS(3731),
    [anon_sym_PLUS_PLUS] = ACTIONS(3731),
    [anon_sym_sizeof] = ACTIONS(3733),
    [anon_sym___alignof__] = ACTIONS(3733),
    [anon_sym___alignof] = ACTIONS(3733),
    [anon_sym__alignof] = ACTIONS(3733),
    [anon_sym_alignof] = ACTIONS(3733),
    [anon_sym__Alignof] = ACTIONS(3733),
    [anon_sym_offsetof] = ACTIONS(3733),
    [anon_sym__Generic] = ACTIONS(3733),
    [anon_sym_asm] = ACTIONS(3733),
    [anon_sym___asm__] = ACTIONS(3733),
    [sym_number_literal] = ACTIONS(3731),
    [anon_sym_L_SQUOTE] = ACTIONS(3731),
    [anon_sym_u_SQUOTE] = ACTIONS(3731),
    [anon_sym_U_SQUOTE] = ACTIONS(3731),
    [anon_sym_u8_SQUOTE] = ACTIONS(3731),
    [anon_sym_SQUOTE] = ACTIONS(3731),
    [anon_sym_L_DQUOTE] = ACTIONS(3731),
    [anon_sym_u_DQUOTE] = ACTIONS(3731),
    [anon_sym_U_DQUOTE] = ACTIONS(3731),
    [anon_sym_u8_DQUOTE] = ACTIONS(3731),
    [anon_sym_DQUOTE] = ACTIONS(3731),
    [sym_true] = ACTIONS(3733),
    [sym_false] = ACTIONS(3733),
    [anon_sym_NULL] = ACTIONS(3733),
    [anon_sym_nullptr] = ACTIONS(3733),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3737),
    [anon_sym_decltype] = ACTIONS(3725),
    [sym_virtual] = ACTIONS(3737),
    [anon_sym_explicit] = ACTIONS(3737),
    [anon_sym_typename] = ACTIONS(3737),
    [anon_sym_template] = ACTIONS(3725),
    [anon_sym_operator] = ACTIONS(3737),
    [anon_sym_try] = ACTIONS(3733),
    [anon_sym_delete] = ACTIONS(3733),
    [anon_sym_throw] = ACTIONS(3733),
    [anon_sym_co_return] = ACTIONS(3733),
    [anon_sym_co_yield] = ACTIONS(3733),
    [anon_sym_R_DQUOTE] = ACTIONS(3731),
    [anon_sym_LR_DQUOTE] = ACTIONS(3731),
    [anon_sym_uR_DQUOTE] = ACTIONS(3731),
    [anon_sym_UR_DQUOTE] = ACTIONS(3731),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3731),
    [anon_sym_co_await] = ACTIONS(3733),
    [anon_sym_new] = ACTIONS(3733),
    [anon_sym_requires] = ACTIONS(3733),
    [sym_this] = ACTIONS(3733),
    [anon_sym_discard] = ACTIONS(3733),
    [anon_sym_precise] = ACTIONS(3737),
    [anon_sym_shared] = ACTIONS(3737),
    [anon_sym_groupshared] = ACTIONS(3737),
    [anon_sym_uniform] = ACTIONS(3737),
    [anon_sym_row_major] = ACTIONS(3737),
    [anon_sym_column_major] = ACTIONS(3737),
    [anon_sym_globallycoherent] = ACTIONS(3737),
    [anon_sym_centroid] = ACTIONS(3737),
    [anon_sym_noperspective] = ACTIONS(3737),
    [anon_sym_nointerpolation] = ACTIONS(3737),
    [anon_sym_sample] = ACTIONS(3737),
    [anon_sym_linear] = ACTIONS(3737),
    [anon_sym_snorm] = ACTIONS(3737),
    [anon_sym_unorm] = ACTIONS(3737),
    [anon_sym_point] = ACTIONS(3737),
    [anon_sym_line] = ACTIONS(3737),
    [anon_sym_triangleadj] = ACTIONS(3737),
    [anon_sym_lineadj] = ACTIONS(3737),
    [anon_sym_triangle] = ACTIONS(3737),
    [anon_sym_cbuffer] = ACTIONS(3733),
  },
  [947] = {
    [sym_expression] = STATE(3762),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_initializer_list] = STATE(3967),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3515),
    [anon_sym_COMMA] = ACTIONS(3515),
    [anon_sym_RPAREN] = ACTIONS(3515),
    [anon_sym_LPAREN2] = ACTIONS(3515),
    [anon_sym_BANG] = ACTIONS(1823),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(3513),
    [anon_sym_PLUS] = ACTIONS(3513),
    [anon_sym_STAR] = ACTIONS(3513),
    [anon_sym_SLASH] = ACTIONS(3513),
    [anon_sym_PERCENT] = ACTIONS(3513),
    [anon_sym_PIPE_PIPE] = ACTIONS(3515),
    [anon_sym_AMP_AMP] = ACTIONS(3515),
    [anon_sym_PIPE] = ACTIONS(3513),
    [anon_sym_CARET] = ACTIONS(3513),
    [anon_sym_AMP] = ACTIONS(3513),
    [anon_sym_EQ_EQ] = ACTIONS(3515),
    [anon_sym_BANG_EQ] = ACTIONS(3515),
    [anon_sym_GT] = ACTIONS(3513),
    [anon_sym_GT_EQ] = ACTIONS(3515),
    [anon_sym_LT_EQ] = ACTIONS(3513),
    [anon_sym_LT] = ACTIONS(3513),
    [anon_sym_LT_LT] = ACTIONS(3513),
    [anon_sym_GT_GT] = ACTIONS(3513),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACE] = ACTIONS(3741),
    [anon_sym_LBRACK] = ACTIONS(3515),
    [anon_sym_EQ] = ACTIONS(3513),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_QMARK] = ACTIONS(3515),
    [anon_sym_STAR_EQ] = ACTIONS(3515),
    [anon_sym_SLASH_EQ] = ACTIONS(3515),
    [anon_sym_PERCENT_EQ] = ACTIONS(3515),
    [anon_sym_PLUS_EQ] = ACTIONS(3515),
    [anon_sym_DASH_EQ] = ACTIONS(3515),
    [anon_sym_LT_LT_EQ] = ACTIONS(3515),
    [anon_sym_GT_GT_EQ] = ACTIONS(3515),
    [anon_sym_AMP_EQ] = ACTIONS(3515),
    [anon_sym_CARET_EQ] = ACTIONS(3515),
    [anon_sym_PIPE_EQ] = ACTIONS(3515),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_LT_EQ_GT] = ACTIONS(3515),
    [anon_sym_or] = ACTIONS(3513),
    [anon_sym_and] = ACTIONS(3513),
    [anon_sym_bitor] = ACTIONS(3513),
    [anon_sym_xor] = ACTIONS(3513),
    [anon_sym_bitand] = ACTIONS(3513),
    [anon_sym_not_eq] = ACTIONS(3513),
    [anon_sym_DASH_DASH] = ACTIONS(3515),
    [anon_sym_PLUS_PLUS] = ACTIONS(3515),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [anon_sym_DOT] = ACTIONS(3513),
    [anon_sym_DOT_STAR] = ACTIONS(3515),
    [anon_sym_DASH_GT] = ACTIONS(3513),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [anon_sym_DASH_GT_STAR] = ACTIONS(3515),
    [sym_this] = ACTIONS(1859),
  },
  [948] = {
    [sym_identifier] = ACTIONS(1917),
    [anon_sym_LPAREN2] = ACTIONS(1919),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_COLON] = ACTIONS(1917),
    [anon_sym_SEMI] = ACTIONS(1919),
    [anon_sym___extension__] = ACTIONS(1917),
    [anon_sym_typedef] = ACTIONS(1917),
    [anon_sym_in] = ACTIONS(1917),
    [anon_sym_out] = ACTIONS(1917),
    [anon_sym_inout] = ACTIONS(1917),
    [anon_sym_extern] = ACTIONS(1917),
    [anon_sym___attribute__] = ACTIONS(1917),
    [anon_sym_COLON_COLON] = ACTIONS(1919),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1919),
    [anon_sym___declspec] = ACTIONS(1917),
    [anon_sym_LBRACE] = ACTIONS(1919),
    [anon_sym_signed] = ACTIONS(1917),
    [anon_sym_unsigned] = ACTIONS(1917),
    [anon_sym_long] = ACTIONS(1917),
    [anon_sym_short] = ACTIONS(1917),
    [anon_sym_LBRACK] = ACTIONS(1917),
    [anon_sym_static] = ACTIONS(1917),
    [anon_sym_register] = ACTIONS(1917),
    [anon_sym_inline] = ACTIONS(1917),
    [anon_sym___inline] = ACTIONS(1917),
    [anon_sym___inline__] = ACTIONS(1917),
    [anon_sym___forceinline] = ACTIONS(1917),
    [anon_sym_thread_local] = ACTIONS(1917),
    [anon_sym___thread] = ACTIONS(1917),
    [anon_sym_const] = ACTIONS(1917),
    [anon_sym_constexpr] = ACTIONS(1917),
    [anon_sym_volatile] = ACTIONS(1917),
    [anon_sym_restrict] = ACTIONS(1917),
    [anon_sym___restrict__] = ACTIONS(1917),
    [anon_sym__Atomic] = ACTIONS(1917),
    [anon_sym__Noreturn] = ACTIONS(1917),
    [anon_sym_noreturn] = ACTIONS(1917),
    [anon_sym_mutable] = ACTIONS(1917),
    [anon_sym_constinit] = ACTIONS(1917),
    [anon_sym_consteval] = ACTIONS(1917),
    [anon_sym_alignas] = ACTIONS(1917),
    [anon_sym__Alignas] = ACTIONS(1917),
    [sym_primitive_type] = ACTIONS(1917),
    [anon_sym_enum] = ACTIONS(1917),
    [anon_sym_class] = ACTIONS(1917),
    [anon_sym_struct] = ACTIONS(1917),
    [anon_sym_union] = ACTIONS(1917),
    [anon_sym_if] = ACTIONS(1917),
    [anon_sym_else] = ACTIONS(1917),
    [anon_sym_switch] = ACTIONS(1917),
    [anon_sym_while] = ACTIONS(1917),
    [anon_sym_do] = ACTIONS(1917),
    [anon_sym_for] = ACTIONS(1917),
    [anon_sym_return] = ACTIONS(1917),
    [anon_sym_break] = ACTIONS(1917),
    [anon_sym_continue] = ACTIONS(1917),
    [anon_sym_goto] = ACTIONS(1917),
    [anon_sym___try] = ACTIONS(1917),
    [anon_sym___leave] = ACTIONS(1917),
    [anon_sym_not] = ACTIONS(1917),
    [anon_sym_compl] = ACTIONS(1917),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_sizeof] = ACTIONS(1917),
    [anon_sym___alignof__] = ACTIONS(1917),
    [anon_sym___alignof] = ACTIONS(1917),
    [anon_sym__alignof] = ACTIONS(1917),
    [anon_sym_alignof] = ACTIONS(1917),
    [anon_sym__Alignof] = ACTIONS(1917),
    [anon_sym_offsetof] = ACTIONS(1917),
    [anon_sym__Generic] = ACTIONS(1917),
    [anon_sym_asm] = ACTIONS(1917),
    [anon_sym___asm__] = ACTIONS(1917),
    [sym_number_literal] = ACTIONS(1919),
    [anon_sym_L_SQUOTE] = ACTIONS(1919),
    [anon_sym_u_SQUOTE] = ACTIONS(1919),
    [anon_sym_U_SQUOTE] = ACTIONS(1919),
    [anon_sym_u8_SQUOTE] = ACTIONS(1919),
    [anon_sym_SQUOTE] = ACTIONS(1919),
    [anon_sym_L_DQUOTE] = ACTIONS(1919),
    [anon_sym_u_DQUOTE] = ACTIONS(1919),
    [anon_sym_U_DQUOTE] = ACTIONS(1919),
    [anon_sym_u8_DQUOTE] = ACTIONS(1919),
    [anon_sym_DQUOTE] = ACTIONS(1919),
    [sym_true] = ACTIONS(1917),
    [sym_false] = ACTIONS(1917),
    [anon_sym_NULL] = ACTIONS(1917),
    [anon_sym_nullptr] = ACTIONS(1917),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1917),
    [anon_sym_decltype] = ACTIONS(1917),
    [anon_sym_final] = ACTIONS(1917),
    [anon_sym_override] = ACTIONS(1917),
    [sym_virtual] = ACTIONS(1917),
    [anon_sym_typename] = ACTIONS(1917),
    [anon_sym_template] = ACTIONS(1917),
    [anon_sym_try] = ACTIONS(1917),
    [anon_sym_delete] = ACTIONS(1917),
    [anon_sym_throw] = ACTIONS(1917),
    [anon_sym_co_return] = ACTIONS(1917),
    [anon_sym_co_yield] = ACTIONS(1917),
    [anon_sym_R_DQUOTE] = ACTIONS(1919),
    [anon_sym_LR_DQUOTE] = ACTIONS(1919),
    [anon_sym_uR_DQUOTE] = ACTIONS(1919),
    [anon_sym_UR_DQUOTE] = ACTIONS(1919),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1919),
    [anon_sym_co_await] = ACTIONS(1917),
    [anon_sym_new] = ACTIONS(1917),
    [anon_sym_requires] = ACTIONS(1917),
    [sym_this] = ACTIONS(1917),
    [anon_sym_discard] = ACTIONS(1917),
    [anon_sym_precise] = ACTIONS(1917),
    [anon_sym_shared] = ACTIONS(1917),
    [anon_sym_groupshared] = ACTIONS(1917),
    [anon_sym_uniform] = ACTIONS(1917),
    [anon_sym_row_major] = ACTIONS(1917),
    [anon_sym_column_major] = ACTIONS(1917),
    [anon_sym_globallycoherent] = ACTIONS(1917),
    [anon_sym_centroid] = ACTIONS(1917),
    [anon_sym_noperspective] = ACTIONS(1917),
    [anon_sym_nointerpolation] = ACTIONS(1917),
    [anon_sym_sample] = ACTIONS(1917),
    [anon_sym_linear] = ACTIONS(1917),
    [anon_sym_snorm] = ACTIONS(1917),
    [anon_sym_unorm] = ACTIONS(1917),
    [anon_sym_point] = ACTIONS(1917),
    [anon_sym_line] = ACTIONS(1917),
    [anon_sym_triangleadj] = ACTIONS(1917),
    [anon_sym_lineadj] = ACTIONS(1917),
    [anon_sym_triangle] = ACTIONS(1917),
    [anon_sym_cbuffer] = ACTIONS(1917),
  },
  [949] = {
    [sym_identifier] = ACTIONS(1899),
    [anon_sym_LPAREN2] = ACTIONS(1901),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_COLON] = ACTIONS(1899),
    [anon_sym_SEMI] = ACTIONS(1901),
    [anon_sym___extension__] = ACTIONS(1899),
    [anon_sym_typedef] = ACTIONS(1899),
    [anon_sym_in] = ACTIONS(1899),
    [anon_sym_out] = ACTIONS(1899),
    [anon_sym_inout] = ACTIONS(1899),
    [anon_sym_extern] = ACTIONS(1899),
    [anon_sym___attribute__] = ACTIONS(1899),
    [anon_sym_COLON_COLON] = ACTIONS(1901),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1901),
    [anon_sym___declspec] = ACTIONS(1899),
    [anon_sym_LBRACE] = ACTIONS(1901),
    [anon_sym_signed] = ACTIONS(1899),
    [anon_sym_unsigned] = ACTIONS(1899),
    [anon_sym_long] = ACTIONS(1899),
    [anon_sym_short] = ACTIONS(1899),
    [anon_sym_LBRACK] = ACTIONS(1899),
    [anon_sym_static] = ACTIONS(1899),
    [anon_sym_register] = ACTIONS(1899),
    [anon_sym_inline] = ACTIONS(1899),
    [anon_sym___inline] = ACTIONS(1899),
    [anon_sym___inline__] = ACTIONS(1899),
    [anon_sym___forceinline] = ACTIONS(1899),
    [anon_sym_thread_local] = ACTIONS(1899),
    [anon_sym___thread] = ACTIONS(1899),
    [anon_sym_const] = ACTIONS(1899),
    [anon_sym_constexpr] = ACTIONS(1899),
    [anon_sym_volatile] = ACTIONS(1899),
    [anon_sym_restrict] = ACTIONS(1899),
    [anon_sym___restrict__] = ACTIONS(1899),
    [anon_sym__Atomic] = ACTIONS(1899),
    [anon_sym__Noreturn] = ACTIONS(1899),
    [anon_sym_noreturn] = ACTIONS(1899),
    [anon_sym_mutable] = ACTIONS(1899),
    [anon_sym_constinit] = ACTIONS(1899),
    [anon_sym_consteval] = ACTIONS(1899),
    [anon_sym_alignas] = ACTIONS(1899),
    [anon_sym__Alignas] = ACTIONS(1899),
    [sym_primitive_type] = ACTIONS(1899),
    [anon_sym_enum] = ACTIONS(1899),
    [anon_sym_class] = ACTIONS(1899),
    [anon_sym_struct] = ACTIONS(1899),
    [anon_sym_union] = ACTIONS(1899),
    [anon_sym_if] = ACTIONS(1899),
    [anon_sym_else] = ACTIONS(1899),
    [anon_sym_switch] = ACTIONS(1899),
    [anon_sym_while] = ACTIONS(1899),
    [anon_sym_do] = ACTIONS(1899),
    [anon_sym_for] = ACTIONS(1899),
    [anon_sym_return] = ACTIONS(1899),
    [anon_sym_break] = ACTIONS(1899),
    [anon_sym_continue] = ACTIONS(1899),
    [anon_sym_goto] = ACTIONS(1899),
    [anon_sym___try] = ACTIONS(1899),
    [anon_sym___leave] = ACTIONS(1899),
    [anon_sym_not] = ACTIONS(1899),
    [anon_sym_compl] = ACTIONS(1899),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_sizeof] = ACTIONS(1899),
    [anon_sym___alignof__] = ACTIONS(1899),
    [anon_sym___alignof] = ACTIONS(1899),
    [anon_sym__alignof] = ACTIONS(1899),
    [anon_sym_alignof] = ACTIONS(1899),
    [anon_sym__Alignof] = ACTIONS(1899),
    [anon_sym_offsetof] = ACTIONS(1899),
    [anon_sym__Generic] = ACTIONS(1899),
    [anon_sym_asm] = ACTIONS(1899),
    [anon_sym___asm__] = ACTIONS(1899),
    [sym_number_literal] = ACTIONS(1901),
    [anon_sym_L_SQUOTE] = ACTIONS(1901),
    [anon_sym_u_SQUOTE] = ACTIONS(1901),
    [anon_sym_U_SQUOTE] = ACTIONS(1901),
    [anon_sym_u8_SQUOTE] = ACTIONS(1901),
    [anon_sym_SQUOTE] = ACTIONS(1901),
    [anon_sym_L_DQUOTE] = ACTIONS(1901),
    [anon_sym_u_DQUOTE] = ACTIONS(1901),
    [anon_sym_U_DQUOTE] = ACTIONS(1901),
    [anon_sym_u8_DQUOTE] = ACTIONS(1901),
    [anon_sym_DQUOTE] = ACTIONS(1901),
    [sym_true] = ACTIONS(1899),
    [sym_false] = ACTIONS(1899),
    [anon_sym_NULL] = ACTIONS(1899),
    [anon_sym_nullptr] = ACTIONS(1899),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1899),
    [anon_sym_decltype] = ACTIONS(1899),
    [anon_sym_final] = ACTIONS(1899),
    [anon_sym_override] = ACTIONS(1899),
    [sym_virtual] = ACTIONS(1899),
    [anon_sym_typename] = ACTIONS(1899),
    [anon_sym_template] = ACTIONS(1899),
    [anon_sym_try] = ACTIONS(1899),
    [anon_sym_delete] = ACTIONS(1899),
    [anon_sym_throw] = ACTIONS(1899),
    [anon_sym_co_return] = ACTIONS(1899),
    [anon_sym_co_yield] = ACTIONS(1899),
    [anon_sym_R_DQUOTE] = ACTIONS(1901),
    [anon_sym_LR_DQUOTE] = ACTIONS(1901),
    [anon_sym_uR_DQUOTE] = ACTIONS(1901),
    [anon_sym_UR_DQUOTE] = ACTIONS(1901),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1901),
    [anon_sym_co_await] = ACTIONS(1899),
    [anon_sym_new] = ACTIONS(1899),
    [anon_sym_requires] = ACTIONS(1899),
    [sym_this] = ACTIONS(1899),
    [anon_sym_discard] = ACTIONS(1899),
    [anon_sym_precise] = ACTIONS(1899),
    [anon_sym_shared] = ACTIONS(1899),
    [anon_sym_groupshared] = ACTIONS(1899),
    [anon_sym_uniform] = ACTIONS(1899),
    [anon_sym_row_major] = ACTIONS(1899),
    [anon_sym_column_major] = ACTIONS(1899),
    [anon_sym_globallycoherent] = ACTIONS(1899),
    [anon_sym_centroid] = ACTIONS(1899),
    [anon_sym_noperspective] = ACTIONS(1899),
    [anon_sym_nointerpolation] = ACTIONS(1899),
    [anon_sym_sample] = ACTIONS(1899),
    [anon_sym_linear] = ACTIONS(1899),
    [anon_sym_snorm] = ACTIONS(1899),
    [anon_sym_unorm] = ACTIONS(1899),
    [anon_sym_point] = ACTIONS(1899),
    [anon_sym_line] = ACTIONS(1899),
    [anon_sym_triangleadj] = ACTIONS(1899),
    [anon_sym_lineadj] = ACTIONS(1899),
    [anon_sym_triangle] = ACTIONS(1899),
    [anon_sym_cbuffer] = ACTIONS(1899),
  },
  [950] = {
    [sym_identifier] = ACTIONS(1953),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_BANG] = ACTIONS(1955),
    [anon_sym_TILDE] = ACTIONS(1955),
    [anon_sym_DASH] = ACTIONS(1953),
    [anon_sym_PLUS] = ACTIONS(1953),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1955),
    [anon_sym_COLON] = ACTIONS(1953),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym_typedef] = ACTIONS(1953),
    [anon_sym_in] = ACTIONS(1953),
    [anon_sym_out] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1953),
    [anon_sym_extern] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1955),
    [anon_sym___declspec] = ACTIONS(1953),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_signed] = ACTIONS(1953),
    [anon_sym_unsigned] = ACTIONS(1953),
    [anon_sym_long] = ACTIONS(1953),
    [anon_sym_short] = ACTIONS(1953),
    [anon_sym_LBRACK] = ACTIONS(1953),
    [anon_sym_static] = ACTIONS(1953),
    [anon_sym_register] = ACTIONS(1953),
    [anon_sym_inline] = ACTIONS(1953),
    [anon_sym___inline] = ACTIONS(1953),
    [anon_sym___inline__] = ACTIONS(1953),
    [anon_sym___forceinline] = ACTIONS(1953),
    [anon_sym_thread_local] = ACTIONS(1953),
    [anon_sym___thread] = ACTIONS(1953),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [sym_primitive_type] = ACTIONS(1953),
    [anon_sym_enum] = ACTIONS(1953),
    [anon_sym_class] = ACTIONS(1953),
    [anon_sym_struct] = ACTIONS(1953),
    [anon_sym_union] = ACTIONS(1953),
    [anon_sym_if] = ACTIONS(1953),
    [anon_sym_else] = ACTIONS(1953),
    [anon_sym_switch] = ACTIONS(1953),
    [anon_sym_while] = ACTIONS(1953),
    [anon_sym_do] = ACTIONS(1953),
    [anon_sym_for] = ACTIONS(1953),
    [anon_sym_return] = ACTIONS(1953),
    [anon_sym_break] = ACTIONS(1953),
    [anon_sym_continue] = ACTIONS(1953),
    [anon_sym_goto] = ACTIONS(1953),
    [anon_sym___try] = ACTIONS(1953),
    [anon_sym___leave] = ACTIONS(1953),
    [anon_sym_not] = ACTIONS(1953),
    [anon_sym_compl] = ACTIONS(1953),
    [anon_sym_DASH_DASH] = ACTIONS(1955),
    [anon_sym_PLUS_PLUS] = ACTIONS(1955),
    [anon_sym_sizeof] = ACTIONS(1953),
    [anon_sym___alignof__] = ACTIONS(1953),
    [anon_sym___alignof] = ACTIONS(1953),
    [anon_sym__alignof] = ACTIONS(1953),
    [anon_sym_alignof] = ACTIONS(1953),
    [anon_sym__Alignof] = ACTIONS(1953),
    [anon_sym_offsetof] = ACTIONS(1953),
    [anon_sym__Generic] = ACTIONS(1953),
    [anon_sym_asm] = ACTIONS(1953),
    [anon_sym___asm__] = ACTIONS(1953),
    [sym_number_literal] = ACTIONS(1955),
    [anon_sym_L_SQUOTE] = ACTIONS(1955),
    [anon_sym_u_SQUOTE] = ACTIONS(1955),
    [anon_sym_U_SQUOTE] = ACTIONS(1955),
    [anon_sym_u8_SQUOTE] = ACTIONS(1955),
    [anon_sym_SQUOTE] = ACTIONS(1955),
    [anon_sym_L_DQUOTE] = ACTIONS(1955),
    [anon_sym_u_DQUOTE] = ACTIONS(1955),
    [anon_sym_U_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8_DQUOTE] = ACTIONS(1955),
    [anon_sym_DQUOTE] = ACTIONS(1955),
    [sym_true] = ACTIONS(1953),
    [sym_false] = ACTIONS(1953),
    [anon_sym_NULL] = ACTIONS(1953),
    [anon_sym_nullptr] = ACTIONS(1953),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
    [sym_virtual] = ACTIONS(1953),
    [anon_sym_typename] = ACTIONS(1953),
    [anon_sym_template] = ACTIONS(1953),
    [anon_sym_try] = ACTIONS(1953),
    [anon_sym_delete] = ACTIONS(1953),
    [anon_sym_throw] = ACTIONS(1953),
    [anon_sym_co_return] = ACTIONS(1953),
    [anon_sym_co_yield] = ACTIONS(1953),
    [anon_sym_R_DQUOTE] = ACTIONS(1955),
    [anon_sym_LR_DQUOTE] = ACTIONS(1955),
    [anon_sym_uR_DQUOTE] = ACTIONS(1955),
    [anon_sym_UR_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1955),
    [anon_sym_co_await] = ACTIONS(1953),
    [anon_sym_new] = ACTIONS(1953),
    [anon_sym_requires] = ACTIONS(1953),
    [sym_this] = ACTIONS(1953),
    [anon_sym_discard] = ACTIONS(1953),
    [anon_sym_precise] = ACTIONS(1953),
    [anon_sym_shared] = ACTIONS(1953),
    [anon_sym_groupshared] = ACTIONS(1953),
    [anon_sym_uniform] = ACTIONS(1953),
    [anon_sym_row_major] = ACTIONS(1953),
    [anon_sym_column_major] = ACTIONS(1953),
    [anon_sym_globallycoherent] = ACTIONS(1953),
    [anon_sym_centroid] = ACTIONS(1953),
    [anon_sym_noperspective] = ACTIONS(1953),
    [anon_sym_nointerpolation] = ACTIONS(1953),
    [anon_sym_sample] = ACTIONS(1953),
    [anon_sym_linear] = ACTIONS(1953),
    [anon_sym_snorm] = ACTIONS(1953),
    [anon_sym_unorm] = ACTIONS(1953),
    [anon_sym_point] = ACTIONS(1953),
    [anon_sym_line] = ACTIONS(1953),
    [anon_sym_triangleadj] = ACTIONS(1953),
    [anon_sym_lineadj] = ACTIONS(1953),
    [anon_sym_triangle] = ACTIONS(1953),
    [anon_sym_cbuffer] = ACTIONS(1953),
  },
  [951] = {
    [sym_identifier] = ACTIONS(1953),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_BANG] = ACTIONS(1955),
    [anon_sym_TILDE] = ACTIONS(1955),
    [anon_sym_DASH] = ACTIONS(1953),
    [anon_sym_PLUS] = ACTIONS(1953),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1955),
    [anon_sym_COLON] = ACTIONS(1953),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym_typedef] = ACTIONS(1953),
    [anon_sym_in] = ACTIONS(1953),
    [anon_sym_out] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1953),
    [anon_sym_extern] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1955),
    [anon_sym___declspec] = ACTIONS(1953),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_signed] = ACTIONS(1953),
    [anon_sym_unsigned] = ACTIONS(1953),
    [anon_sym_long] = ACTIONS(1953),
    [anon_sym_short] = ACTIONS(1953),
    [anon_sym_LBRACK] = ACTIONS(1953),
    [anon_sym_static] = ACTIONS(1953),
    [anon_sym_register] = ACTIONS(1953),
    [anon_sym_inline] = ACTIONS(1953),
    [anon_sym___inline] = ACTIONS(1953),
    [anon_sym___inline__] = ACTIONS(1953),
    [anon_sym___forceinline] = ACTIONS(1953),
    [anon_sym_thread_local] = ACTIONS(1953),
    [anon_sym___thread] = ACTIONS(1953),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [sym_primitive_type] = ACTIONS(1953),
    [anon_sym_enum] = ACTIONS(1953),
    [anon_sym_class] = ACTIONS(1953),
    [anon_sym_struct] = ACTIONS(1953),
    [anon_sym_union] = ACTIONS(1953),
    [anon_sym_if] = ACTIONS(1953),
    [anon_sym_else] = ACTIONS(1953),
    [anon_sym_switch] = ACTIONS(1953),
    [anon_sym_while] = ACTIONS(1953),
    [anon_sym_do] = ACTIONS(1953),
    [anon_sym_for] = ACTIONS(1953),
    [anon_sym_return] = ACTIONS(1953),
    [anon_sym_break] = ACTIONS(1953),
    [anon_sym_continue] = ACTIONS(1953),
    [anon_sym_goto] = ACTIONS(1953),
    [anon_sym___try] = ACTIONS(1953),
    [anon_sym___leave] = ACTIONS(1953),
    [anon_sym_not] = ACTIONS(1953),
    [anon_sym_compl] = ACTIONS(1953),
    [anon_sym_DASH_DASH] = ACTIONS(1955),
    [anon_sym_PLUS_PLUS] = ACTIONS(1955),
    [anon_sym_sizeof] = ACTIONS(1953),
    [anon_sym___alignof__] = ACTIONS(1953),
    [anon_sym___alignof] = ACTIONS(1953),
    [anon_sym__alignof] = ACTIONS(1953),
    [anon_sym_alignof] = ACTIONS(1953),
    [anon_sym__Alignof] = ACTIONS(1953),
    [anon_sym_offsetof] = ACTIONS(1953),
    [anon_sym__Generic] = ACTIONS(1953),
    [anon_sym_asm] = ACTIONS(1953),
    [anon_sym___asm__] = ACTIONS(1953),
    [sym_number_literal] = ACTIONS(1955),
    [anon_sym_L_SQUOTE] = ACTIONS(1955),
    [anon_sym_u_SQUOTE] = ACTIONS(1955),
    [anon_sym_U_SQUOTE] = ACTIONS(1955),
    [anon_sym_u8_SQUOTE] = ACTIONS(1955),
    [anon_sym_SQUOTE] = ACTIONS(1955),
    [anon_sym_L_DQUOTE] = ACTIONS(1955),
    [anon_sym_u_DQUOTE] = ACTIONS(1955),
    [anon_sym_U_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8_DQUOTE] = ACTIONS(1955),
    [anon_sym_DQUOTE] = ACTIONS(1955),
    [sym_true] = ACTIONS(1953),
    [sym_false] = ACTIONS(1953),
    [anon_sym_NULL] = ACTIONS(1953),
    [anon_sym_nullptr] = ACTIONS(1953),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
    [sym_virtual] = ACTIONS(1953),
    [anon_sym_typename] = ACTIONS(1953),
    [anon_sym_template] = ACTIONS(1953),
    [anon_sym_try] = ACTIONS(1953),
    [anon_sym_delete] = ACTIONS(1953),
    [anon_sym_throw] = ACTIONS(1953),
    [anon_sym_co_return] = ACTIONS(1953),
    [anon_sym_co_yield] = ACTIONS(1953),
    [anon_sym_R_DQUOTE] = ACTIONS(1955),
    [anon_sym_LR_DQUOTE] = ACTIONS(1955),
    [anon_sym_uR_DQUOTE] = ACTIONS(1955),
    [anon_sym_UR_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1955),
    [anon_sym_co_await] = ACTIONS(1953),
    [anon_sym_new] = ACTIONS(1953),
    [anon_sym_requires] = ACTIONS(1953),
    [sym_this] = ACTIONS(1953),
    [anon_sym_discard] = ACTIONS(1953),
    [anon_sym_precise] = ACTIONS(1953),
    [anon_sym_shared] = ACTIONS(1953),
    [anon_sym_groupshared] = ACTIONS(1953),
    [anon_sym_uniform] = ACTIONS(1953),
    [anon_sym_row_major] = ACTIONS(1953),
    [anon_sym_column_major] = ACTIONS(1953),
    [anon_sym_globallycoherent] = ACTIONS(1953),
    [anon_sym_centroid] = ACTIONS(1953),
    [anon_sym_noperspective] = ACTIONS(1953),
    [anon_sym_nointerpolation] = ACTIONS(1953),
    [anon_sym_sample] = ACTIONS(1953),
    [anon_sym_linear] = ACTIONS(1953),
    [anon_sym_snorm] = ACTIONS(1953),
    [anon_sym_unorm] = ACTIONS(1953),
    [anon_sym_point] = ACTIONS(1953),
    [anon_sym_line] = ACTIONS(1953),
    [anon_sym_triangleadj] = ACTIONS(1953),
    [anon_sym_lineadj] = ACTIONS(1953),
    [anon_sym_triangle] = ACTIONS(1953),
    [anon_sym_cbuffer] = ACTIONS(1953),
  },
  [952] = {
    [sym_identifier] = ACTIONS(1959),
    [anon_sym_LPAREN2] = ACTIONS(1961),
    [anon_sym_BANG] = ACTIONS(1961),
    [anon_sym_TILDE] = ACTIONS(1961),
    [anon_sym_DASH] = ACTIONS(1959),
    [anon_sym_PLUS] = ACTIONS(1959),
    [anon_sym_STAR] = ACTIONS(1961),
    [anon_sym_AMP] = ACTIONS(1961),
    [anon_sym_COLON] = ACTIONS(1959),
    [anon_sym_SEMI] = ACTIONS(1961),
    [anon_sym___extension__] = ACTIONS(1959),
    [anon_sym_typedef] = ACTIONS(1959),
    [anon_sym_in] = ACTIONS(1959),
    [anon_sym_out] = ACTIONS(1959),
    [anon_sym_inout] = ACTIONS(1959),
    [anon_sym_extern] = ACTIONS(1959),
    [anon_sym___attribute__] = ACTIONS(1959),
    [anon_sym_COLON_COLON] = ACTIONS(1961),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1961),
    [anon_sym___declspec] = ACTIONS(1959),
    [anon_sym_LBRACE] = ACTIONS(1961),
    [anon_sym_signed] = ACTIONS(1959),
    [anon_sym_unsigned] = ACTIONS(1959),
    [anon_sym_long] = ACTIONS(1959),
    [anon_sym_short] = ACTIONS(1959),
    [anon_sym_LBRACK] = ACTIONS(1959),
    [anon_sym_static] = ACTIONS(1959),
    [anon_sym_register] = ACTIONS(1959),
    [anon_sym_inline] = ACTIONS(1959),
    [anon_sym___inline] = ACTIONS(1959),
    [anon_sym___inline__] = ACTIONS(1959),
    [anon_sym___forceinline] = ACTIONS(1959),
    [anon_sym_thread_local] = ACTIONS(1959),
    [anon_sym___thread] = ACTIONS(1959),
    [anon_sym_const] = ACTIONS(1959),
    [anon_sym_constexpr] = ACTIONS(1959),
    [anon_sym_volatile] = ACTIONS(1959),
    [anon_sym_restrict] = ACTIONS(1959),
    [anon_sym___restrict__] = ACTIONS(1959),
    [anon_sym__Atomic] = ACTIONS(1959),
    [anon_sym__Noreturn] = ACTIONS(1959),
    [anon_sym_noreturn] = ACTIONS(1959),
    [anon_sym_mutable] = ACTIONS(1959),
    [anon_sym_constinit] = ACTIONS(1959),
    [anon_sym_consteval] = ACTIONS(1959),
    [anon_sym_alignas] = ACTIONS(1959),
    [anon_sym__Alignas] = ACTIONS(1959),
    [sym_primitive_type] = ACTIONS(1959),
    [anon_sym_enum] = ACTIONS(1959),
    [anon_sym_class] = ACTIONS(1959),
    [anon_sym_struct] = ACTIONS(1959),
    [anon_sym_union] = ACTIONS(1959),
    [anon_sym_if] = ACTIONS(1959),
    [anon_sym_else] = ACTIONS(1959),
    [anon_sym_switch] = ACTIONS(1959),
    [anon_sym_while] = ACTIONS(1959),
    [anon_sym_do] = ACTIONS(1959),
    [anon_sym_for] = ACTIONS(1959),
    [anon_sym_return] = ACTIONS(1959),
    [anon_sym_break] = ACTIONS(1959),
    [anon_sym_continue] = ACTIONS(1959),
    [anon_sym_goto] = ACTIONS(1959),
    [anon_sym___try] = ACTIONS(1959),
    [anon_sym___leave] = ACTIONS(1959),
    [anon_sym_not] = ACTIONS(1959),
    [anon_sym_compl] = ACTIONS(1959),
    [anon_sym_DASH_DASH] = ACTIONS(1961),
    [anon_sym_PLUS_PLUS] = ACTIONS(1961),
    [anon_sym_sizeof] = ACTIONS(1959),
    [anon_sym___alignof__] = ACTIONS(1959),
    [anon_sym___alignof] = ACTIONS(1959),
    [anon_sym__alignof] = ACTIONS(1959),
    [anon_sym_alignof] = ACTIONS(1959),
    [anon_sym__Alignof] = ACTIONS(1959),
    [anon_sym_offsetof] = ACTIONS(1959),
    [anon_sym__Generic] = ACTIONS(1959),
    [anon_sym_asm] = ACTIONS(1959),
    [anon_sym___asm__] = ACTIONS(1959),
    [sym_number_literal] = ACTIONS(1961),
    [anon_sym_L_SQUOTE] = ACTIONS(1961),
    [anon_sym_u_SQUOTE] = ACTIONS(1961),
    [anon_sym_U_SQUOTE] = ACTIONS(1961),
    [anon_sym_u8_SQUOTE] = ACTIONS(1961),
    [anon_sym_SQUOTE] = ACTIONS(1961),
    [anon_sym_L_DQUOTE] = ACTIONS(1961),
    [anon_sym_u_DQUOTE] = ACTIONS(1961),
    [anon_sym_U_DQUOTE] = ACTIONS(1961),
    [anon_sym_u8_DQUOTE] = ACTIONS(1961),
    [anon_sym_DQUOTE] = ACTIONS(1961),
    [sym_true] = ACTIONS(1959),
    [sym_false] = ACTIONS(1959),
    [anon_sym_NULL] = ACTIONS(1959),
    [anon_sym_nullptr] = ACTIONS(1959),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1959),
    [anon_sym_decltype] = ACTIONS(1959),
    [anon_sym_final] = ACTIONS(1959),
    [anon_sym_override] = ACTIONS(1959),
    [sym_virtual] = ACTIONS(1959),
    [anon_sym_typename] = ACTIONS(1959),
    [anon_sym_template] = ACTIONS(1959),
    [anon_sym_try] = ACTIONS(1959),
    [anon_sym_delete] = ACTIONS(1959),
    [anon_sym_throw] = ACTIONS(1959),
    [anon_sym_co_return] = ACTIONS(1959),
    [anon_sym_co_yield] = ACTIONS(1959),
    [anon_sym_R_DQUOTE] = ACTIONS(1961),
    [anon_sym_LR_DQUOTE] = ACTIONS(1961),
    [anon_sym_uR_DQUOTE] = ACTIONS(1961),
    [anon_sym_UR_DQUOTE] = ACTIONS(1961),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1961),
    [anon_sym_co_await] = ACTIONS(1959),
    [anon_sym_new] = ACTIONS(1959),
    [anon_sym_requires] = ACTIONS(1959),
    [sym_this] = ACTIONS(1959),
    [anon_sym_discard] = ACTIONS(1959),
    [anon_sym_precise] = ACTIONS(1959),
    [anon_sym_shared] = ACTIONS(1959),
    [anon_sym_groupshared] = ACTIONS(1959),
    [anon_sym_uniform] = ACTIONS(1959),
    [anon_sym_row_major] = ACTIONS(1959),
    [anon_sym_column_major] = ACTIONS(1959),
    [anon_sym_globallycoherent] = ACTIONS(1959),
    [anon_sym_centroid] = ACTIONS(1959),
    [anon_sym_noperspective] = ACTIONS(1959),
    [anon_sym_nointerpolation] = ACTIONS(1959),
    [anon_sym_sample] = ACTIONS(1959),
    [anon_sym_linear] = ACTIONS(1959),
    [anon_sym_snorm] = ACTIONS(1959),
    [anon_sym_unorm] = ACTIONS(1959),
    [anon_sym_point] = ACTIONS(1959),
    [anon_sym_line] = ACTIONS(1959),
    [anon_sym_triangleadj] = ACTIONS(1959),
    [anon_sym_lineadj] = ACTIONS(1959),
    [anon_sym_triangle] = ACTIONS(1959),
    [anon_sym_cbuffer] = ACTIONS(1959),
  },
  [953] = {
    [sym_catch_clause] = STATE(956),
    [aux_sym_constructor_try_statement_repeat1] = STATE(956),
    [sym_identifier] = ACTIONS(1963),
    [anon_sym_LPAREN2] = ACTIONS(1965),
    [anon_sym_BANG] = ACTIONS(1965),
    [anon_sym_TILDE] = ACTIONS(1965),
    [anon_sym_DASH] = ACTIONS(1963),
    [anon_sym_PLUS] = ACTIONS(1963),
    [anon_sym_STAR] = ACTIONS(1965),
    [anon_sym_AMP] = ACTIONS(1965),
    [anon_sym_SEMI] = ACTIONS(1965),
    [anon_sym___extension__] = ACTIONS(1963),
    [anon_sym_typedef] = ACTIONS(1963),
    [anon_sym_in] = ACTIONS(1963),
    [anon_sym_out] = ACTIONS(1963),
    [anon_sym_inout] = ACTIONS(1963),
    [anon_sym_extern] = ACTIONS(1963),
    [anon_sym___attribute__] = ACTIONS(1963),
    [anon_sym_COLON_COLON] = ACTIONS(1965),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1965),
    [anon_sym___declspec] = ACTIONS(1963),
    [anon_sym_LBRACE] = ACTIONS(1965),
    [anon_sym_signed] = ACTIONS(1963),
    [anon_sym_unsigned] = ACTIONS(1963),
    [anon_sym_long] = ACTIONS(1963),
    [anon_sym_short] = ACTIONS(1963),
    [anon_sym_LBRACK] = ACTIONS(1963),
    [anon_sym_static] = ACTIONS(1963),
    [anon_sym_register] = ACTIONS(1963),
    [anon_sym_inline] = ACTIONS(1963),
    [anon_sym___inline] = ACTIONS(1963),
    [anon_sym___inline__] = ACTIONS(1963),
    [anon_sym___forceinline] = ACTIONS(1963),
    [anon_sym_thread_local] = ACTIONS(1963),
    [anon_sym___thread] = ACTIONS(1963),
    [anon_sym_const] = ACTIONS(1963),
    [anon_sym_constexpr] = ACTIONS(1963),
    [anon_sym_volatile] = ACTIONS(1963),
    [anon_sym_restrict] = ACTIONS(1963),
    [anon_sym___restrict__] = ACTIONS(1963),
    [anon_sym__Atomic] = ACTIONS(1963),
    [anon_sym__Noreturn] = ACTIONS(1963),
    [anon_sym_noreturn] = ACTIONS(1963),
    [anon_sym_mutable] = ACTIONS(1963),
    [anon_sym_constinit] = ACTIONS(1963),
    [anon_sym_consteval] = ACTIONS(1963),
    [anon_sym_alignas] = ACTIONS(1963),
    [anon_sym__Alignas] = ACTIONS(1963),
    [sym_primitive_type] = ACTIONS(1963),
    [anon_sym_enum] = ACTIONS(1963),
    [anon_sym_class] = ACTIONS(1963),
    [anon_sym_struct] = ACTIONS(1963),
    [anon_sym_union] = ACTIONS(1963),
    [anon_sym_if] = ACTIONS(1963),
    [anon_sym_else] = ACTIONS(1963),
    [anon_sym_switch] = ACTIONS(1963),
    [anon_sym_while] = ACTIONS(1963),
    [anon_sym_do] = ACTIONS(1963),
    [anon_sym_for] = ACTIONS(1963),
    [anon_sym_return] = ACTIONS(1963),
    [anon_sym_break] = ACTIONS(1963),
    [anon_sym_continue] = ACTIONS(1963),
    [anon_sym_goto] = ACTIONS(1963),
    [anon_sym___try] = ACTIONS(1963),
    [anon_sym___leave] = ACTIONS(1963),
    [anon_sym_not] = ACTIONS(1963),
    [anon_sym_compl] = ACTIONS(1963),
    [anon_sym_DASH_DASH] = ACTIONS(1965),
    [anon_sym_PLUS_PLUS] = ACTIONS(1965),
    [anon_sym_sizeof] = ACTIONS(1963),
    [anon_sym___alignof__] = ACTIONS(1963),
    [anon_sym___alignof] = ACTIONS(1963),
    [anon_sym__alignof] = ACTIONS(1963),
    [anon_sym_alignof] = ACTIONS(1963),
    [anon_sym__Alignof] = ACTIONS(1963),
    [anon_sym_offsetof] = ACTIONS(1963),
    [anon_sym__Generic] = ACTIONS(1963),
    [anon_sym_asm] = ACTIONS(1963),
    [anon_sym___asm__] = ACTIONS(1963),
    [sym_number_literal] = ACTIONS(1965),
    [anon_sym_L_SQUOTE] = ACTIONS(1965),
    [anon_sym_u_SQUOTE] = ACTIONS(1965),
    [anon_sym_U_SQUOTE] = ACTIONS(1965),
    [anon_sym_u8_SQUOTE] = ACTIONS(1965),
    [anon_sym_SQUOTE] = ACTIONS(1965),
    [anon_sym_L_DQUOTE] = ACTIONS(1965),
    [anon_sym_u_DQUOTE] = ACTIONS(1965),
    [anon_sym_U_DQUOTE] = ACTIONS(1965),
    [anon_sym_u8_DQUOTE] = ACTIONS(1965),
    [anon_sym_DQUOTE] = ACTIONS(1965),
    [sym_true] = ACTIONS(1963),
    [sym_false] = ACTIONS(1963),
    [anon_sym_NULL] = ACTIONS(1963),
    [anon_sym_nullptr] = ACTIONS(1963),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1963),
    [anon_sym_decltype] = ACTIONS(1963),
    [sym_virtual] = ACTIONS(1963),
    [anon_sym_typename] = ACTIONS(1963),
    [anon_sym_template] = ACTIONS(1963),
    [anon_sym_try] = ACTIONS(1963),
    [anon_sym_delete] = ACTIONS(1963),
    [anon_sym_throw] = ACTIONS(1963),
    [anon_sym_co_return] = ACTIONS(1963),
    [anon_sym_co_yield] = ACTIONS(1963),
    [anon_sym_catch] = ACTIONS(3745),
    [anon_sym_R_DQUOTE] = ACTIONS(1965),
    [anon_sym_LR_DQUOTE] = ACTIONS(1965),
    [anon_sym_uR_DQUOTE] = ACTIONS(1965),
    [anon_sym_UR_DQUOTE] = ACTIONS(1965),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1965),
    [anon_sym_co_await] = ACTIONS(1963),
    [anon_sym_new] = ACTIONS(1963),
    [anon_sym_requires] = ACTIONS(1963),
    [sym_this] = ACTIONS(1963),
    [anon_sym_discard] = ACTIONS(1963),
    [anon_sym_precise] = ACTIONS(1963),
    [anon_sym_shared] = ACTIONS(1963),
    [anon_sym_groupshared] = ACTIONS(1963),
    [anon_sym_uniform] = ACTIONS(1963),
    [anon_sym_row_major] = ACTIONS(1963),
    [anon_sym_column_major] = ACTIONS(1963),
    [anon_sym_globallycoherent] = ACTIONS(1963),
    [anon_sym_centroid] = ACTIONS(1963),
    [anon_sym_noperspective] = ACTIONS(1963),
    [anon_sym_nointerpolation] = ACTIONS(1963),
    [anon_sym_sample] = ACTIONS(1963),
    [anon_sym_linear] = ACTIONS(1963),
    [anon_sym_snorm] = ACTIONS(1963),
    [anon_sym_unorm] = ACTIONS(1963),
    [anon_sym_point] = ACTIONS(1963),
    [anon_sym_line] = ACTIONS(1963),
    [anon_sym_triangleadj] = ACTIONS(1963),
    [anon_sym_lineadj] = ACTIONS(1963),
    [anon_sym_triangle] = ACTIONS(1963),
    [anon_sym_cbuffer] = ACTIONS(1963),
  },
  [954] = {
    [sym_identifier] = ACTIONS(1953),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_BANG] = ACTIONS(1955),
    [anon_sym_TILDE] = ACTIONS(1955),
    [anon_sym_DASH] = ACTIONS(1953),
    [anon_sym_PLUS] = ACTIONS(1953),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1955),
    [anon_sym_COLON] = ACTIONS(1953),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym_typedef] = ACTIONS(1953),
    [anon_sym_in] = ACTIONS(1953),
    [anon_sym_out] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1953),
    [anon_sym_extern] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1955),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1955),
    [anon_sym___declspec] = ACTIONS(1953),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_signed] = ACTIONS(1953),
    [anon_sym_unsigned] = ACTIONS(1953),
    [anon_sym_long] = ACTIONS(1953),
    [anon_sym_short] = ACTIONS(1953),
    [anon_sym_LBRACK] = ACTIONS(1953),
    [anon_sym_static] = ACTIONS(1953),
    [anon_sym_register] = ACTIONS(1953),
    [anon_sym_inline] = ACTIONS(1953),
    [anon_sym___inline] = ACTIONS(1953),
    [anon_sym___inline__] = ACTIONS(1953),
    [anon_sym___forceinline] = ACTIONS(1953),
    [anon_sym_thread_local] = ACTIONS(1953),
    [anon_sym___thread] = ACTIONS(1953),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [sym_primitive_type] = ACTIONS(1953),
    [anon_sym_enum] = ACTIONS(1953),
    [anon_sym_class] = ACTIONS(1953),
    [anon_sym_struct] = ACTIONS(1953),
    [anon_sym_union] = ACTIONS(1953),
    [anon_sym_if] = ACTIONS(1953),
    [anon_sym_else] = ACTIONS(1953),
    [anon_sym_switch] = ACTIONS(1953),
    [anon_sym_while] = ACTIONS(1953),
    [anon_sym_do] = ACTIONS(1953),
    [anon_sym_for] = ACTIONS(1953),
    [anon_sym_return] = ACTIONS(1953),
    [anon_sym_break] = ACTIONS(1953),
    [anon_sym_continue] = ACTIONS(1953),
    [anon_sym_goto] = ACTIONS(1953),
    [anon_sym___try] = ACTIONS(1953),
    [anon_sym___leave] = ACTIONS(1953),
    [anon_sym_not] = ACTIONS(1953),
    [anon_sym_compl] = ACTIONS(1953),
    [anon_sym_DASH_DASH] = ACTIONS(1955),
    [anon_sym_PLUS_PLUS] = ACTIONS(1955),
    [anon_sym_sizeof] = ACTIONS(1953),
    [anon_sym___alignof__] = ACTIONS(1953),
    [anon_sym___alignof] = ACTIONS(1953),
    [anon_sym__alignof] = ACTIONS(1953),
    [anon_sym_alignof] = ACTIONS(1953),
    [anon_sym__Alignof] = ACTIONS(1953),
    [anon_sym_offsetof] = ACTIONS(1953),
    [anon_sym__Generic] = ACTIONS(1953),
    [anon_sym_asm] = ACTIONS(1953),
    [anon_sym___asm__] = ACTIONS(1953),
    [sym_number_literal] = ACTIONS(1955),
    [anon_sym_L_SQUOTE] = ACTIONS(1955),
    [anon_sym_u_SQUOTE] = ACTIONS(1955),
    [anon_sym_U_SQUOTE] = ACTIONS(1955),
    [anon_sym_u8_SQUOTE] = ACTIONS(1955),
    [anon_sym_SQUOTE] = ACTIONS(1955),
    [anon_sym_L_DQUOTE] = ACTIONS(1955),
    [anon_sym_u_DQUOTE] = ACTIONS(1955),
    [anon_sym_U_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8_DQUOTE] = ACTIONS(1955),
    [anon_sym_DQUOTE] = ACTIONS(1955),
    [sym_true] = ACTIONS(1953),
    [sym_false] = ACTIONS(1953),
    [anon_sym_NULL] = ACTIONS(1953),
    [anon_sym_nullptr] = ACTIONS(1953),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
    [sym_virtual] = ACTIONS(1953),
    [anon_sym_typename] = ACTIONS(1953),
    [anon_sym_template] = ACTIONS(1953),
    [anon_sym_try] = ACTIONS(1953),
    [anon_sym_delete] = ACTIONS(1953),
    [anon_sym_throw] = ACTIONS(1953),
    [anon_sym_co_return] = ACTIONS(1953),
    [anon_sym_co_yield] = ACTIONS(1953),
    [anon_sym_R_DQUOTE] = ACTIONS(1955),
    [anon_sym_LR_DQUOTE] = ACTIONS(1955),
    [anon_sym_uR_DQUOTE] = ACTIONS(1955),
    [anon_sym_UR_DQUOTE] = ACTIONS(1955),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1955),
    [anon_sym_co_await] = ACTIONS(1953),
    [anon_sym_new] = ACTIONS(1953),
    [anon_sym_requires] = ACTIONS(1953),
    [sym_this] = ACTIONS(1953),
    [anon_sym_discard] = ACTIONS(1953),
    [anon_sym_precise] = ACTIONS(1953),
    [anon_sym_shared] = ACTIONS(1953),
    [anon_sym_groupshared] = ACTIONS(1953),
    [anon_sym_uniform] = ACTIONS(1953),
    [anon_sym_row_major] = ACTIONS(1953),
    [anon_sym_column_major] = ACTIONS(1953),
    [anon_sym_globallycoherent] = ACTIONS(1953),
    [anon_sym_centroid] = ACTIONS(1953),
    [anon_sym_noperspective] = ACTIONS(1953),
    [anon_sym_nointerpolation] = ACTIONS(1953),
    [anon_sym_sample] = ACTIONS(1953),
    [anon_sym_linear] = ACTIONS(1953),
    [anon_sym_snorm] = ACTIONS(1953),
    [anon_sym_unorm] = ACTIONS(1953),
    [anon_sym_point] = ACTIONS(1953),
    [anon_sym_line] = ACTIONS(1953),
    [anon_sym_triangleadj] = ACTIONS(1953),
    [anon_sym_lineadj] = ACTIONS(1953),
    [anon_sym_triangle] = ACTIONS(1953),
    [anon_sym_cbuffer] = ACTIONS(1953),
  },
  [955] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_LPAREN2] = ACTIONS(1971),
    [anon_sym_BANG] = ACTIONS(1971),
    [anon_sym_TILDE] = ACTIONS(1971),
    [anon_sym_DASH] = ACTIONS(1969),
    [anon_sym_PLUS] = ACTIONS(1969),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_AMP] = ACTIONS(1971),
    [anon_sym_COLON] = ACTIONS(1969),
    [anon_sym_SEMI] = ACTIONS(1971),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym_typedef] = ACTIONS(1969),
    [anon_sym_in] = ACTIONS(1969),
    [anon_sym_out] = ACTIONS(1969),
    [anon_sym_inout] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1971),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym_LBRACE] = ACTIONS(1971),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1969),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [anon_sym_if] = ACTIONS(1969),
    [anon_sym_else] = ACTIONS(1969),
    [anon_sym_switch] = ACTIONS(1969),
    [anon_sym_while] = ACTIONS(1969),
    [anon_sym_do] = ACTIONS(1969),
    [anon_sym_for] = ACTIONS(1969),
    [anon_sym_return] = ACTIONS(1969),
    [anon_sym_break] = ACTIONS(1969),
    [anon_sym_continue] = ACTIONS(1969),
    [anon_sym_goto] = ACTIONS(1969),
    [anon_sym___try] = ACTIONS(1969),
    [anon_sym___leave] = ACTIONS(1969),
    [anon_sym_not] = ACTIONS(1969),
    [anon_sym_compl] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1971),
    [anon_sym_PLUS_PLUS] = ACTIONS(1971),
    [anon_sym_sizeof] = ACTIONS(1969),
    [anon_sym___alignof__] = ACTIONS(1969),
    [anon_sym___alignof] = ACTIONS(1969),
    [anon_sym__alignof] = ACTIONS(1969),
    [anon_sym_alignof] = ACTIONS(1969),
    [anon_sym__Alignof] = ACTIONS(1969),
    [anon_sym_offsetof] = ACTIONS(1969),
    [anon_sym__Generic] = ACTIONS(1969),
    [anon_sym_asm] = ACTIONS(1969),
    [anon_sym___asm__] = ACTIONS(1969),
    [sym_number_literal] = ACTIONS(1971),
    [anon_sym_L_SQUOTE] = ACTIONS(1971),
    [anon_sym_u_SQUOTE] = ACTIONS(1971),
    [anon_sym_U_SQUOTE] = ACTIONS(1971),
    [anon_sym_u8_SQUOTE] = ACTIONS(1971),
    [anon_sym_SQUOTE] = ACTIONS(1971),
    [anon_sym_L_DQUOTE] = ACTIONS(1971),
    [anon_sym_u_DQUOTE] = ACTIONS(1971),
    [anon_sym_U_DQUOTE] = ACTIONS(1971),
    [anon_sym_u8_DQUOTE] = ACTIONS(1971),
    [anon_sym_DQUOTE] = ACTIONS(1971),
    [sym_true] = ACTIONS(1969),
    [sym_false] = ACTIONS(1969),
    [anon_sym_NULL] = ACTIONS(1969),
    [anon_sym_nullptr] = ACTIONS(1969),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_final] = ACTIONS(1969),
    [anon_sym_override] = ACTIONS(1969),
    [sym_virtual] = ACTIONS(1969),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1969),
    [anon_sym_try] = ACTIONS(1969),
    [anon_sym_delete] = ACTIONS(1969),
    [anon_sym_throw] = ACTIONS(1969),
    [anon_sym_co_return] = ACTIONS(1969),
    [anon_sym_co_yield] = ACTIONS(1969),
    [anon_sym_R_DQUOTE] = ACTIONS(1971),
    [anon_sym_LR_DQUOTE] = ACTIONS(1971),
    [anon_sym_uR_DQUOTE] = ACTIONS(1971),
    [anon_sym_UR_DQUOTE] = ACTIONS(1971),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1971),
    [anon_sym_co_await] = ACTIONS(1969),
    [anon_sym_new] = ACTIONS(1969),
    [anon_sym_requires] = ACTIONS(1969),
    [sym_this] = ACTIONS(1969),
    [anon_sym_discard] = ACTIONS(1969),
    [anon_sym_precise] = ACTIONS(1969),
    [anon_sym_shared] = ACTIONS(1969),
    [anon_sym_groupshared] = ACTIONS(1969),
    [anon_sym_uniform] = ACTIONS(1969),
    [anon_sym_row_major] = ACTIONS(1969),
    [anon_sym_column_major] = ACTIONS(1969),
    [anon_sym_globallycoherent] = ACTIONS(1969),
    [anon_sym_centroid] = ACTIONS(1969),
    [anon_sym_noperspective] = ACTIONS(1969),
    [anon_sym_nointerpolation] = ACTIONS(1969),
    [anon_sym_sample] = ACTIONS(1969),
    [anon_sym_linear] = ACTIONS(1969),
    [anon_sym_snorm] = ACTIONS(1969),
    [anon_sym_unorm] = ACTIONS(1969),
    [anon_sym_point] = ACTIONS(1969),
    [anon_sym_line] = ACTIONS(1969),
    [anon_sym_triangleadj] = ACTIONS(1969),
    [anon_sym_lineadj] = ACTIONS(1969),
    [anon_sym_triangle] = ACTIONS(1969),
    [anon_sym_cbuffer] = ACTIONS(1969),
  },
  [956] = {
    [sym_catch_clause] = STATE(956),
    [aux_sym_constructor_try_statement_repeat1] = STATE(956),
    [sym_identifier] = ACTIONS(1973),
    [anon_sym_LPAREN2] = ACTIONS(1975),
    [anon_sym_BANG] = ACTIONS(1975),
    [anon_sym_TILDE] = ACTIONS(1975),
    [anon_sym_DASH] = ACTIONS(1973),
    [anon_sym_PLUS] = ACTIONS(1973),
    [anon_sym_STAR] = ACTIONS(1975),
    [anon_sym_AMP] = ACTIONS(1975),
    [anon_sym_SEMI] = ACTIONS(1975),
    [anon_sym___extension__] = ACTIONS(1973),
    [anon_sym_typedef] = ACTIONS(1973),
    [anon_sym_in] = ACTIONS(1973),
    [anon_sym_out] = ACTIONS(1973),
    [anon_sym_inout] = ACTIONS(1973),
    [anon_sym_extern] = ACTIONS(1973),
    [anon_sym___attribute__] = ACTIONS(1973),
    [anon_sym_COLON_COLON] = ACTIONS(1975),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1975),
    [anon_sym___declspec] = ACTIONS(1973),
    [anon_sym_LBRACE] = ACTIONS(1975),
    [anon_sym_signed] = ACTIONS(1973),
    [anon_sym_unsigned] = ACTIONS(1973),
    [anon_sym_long] = ACTIONS(1973),
    [anon_sym_short] = ACTIONS(1973),
    [anon_sym_LBRACK] = ACTIONS(1973),
    [anon_sym_static] = ACTIONS(1973),
    [anon_sym_register] = ACTIONS(1973),
    [anon_sym_inline] = ACTIONS(1973),
    [anon_sym___inline] = ACTIONS(1973),
    [anon_sym___inline__] = ACTIONS(1973),
    [anon_sym___forceinline] = ACTIONS(1973),
    [anon_sym_thread_local] = ACTIONS(1973),
    [anon_sym___thread] = ACTIONS(1973),
    [anon_sym_const] = ACTIONS(1973),
    [anon_sym_constexpr] = ACTIONS(1973),
    [anon_sym_volatile] = ACTIONS(1973),
    [anon_sym_restrict] = ACTIONS(1973),
    [anon_sym___restrict__] = ACTIONS(1973),
    [anon_sym__Atomic] = ACTIONS(1973),
    [anon_sym__Noreturn] = ACTIONS(1973),
    [anon_sym_noreturn] = ACTIONS(1973),
    [anon_sym_mutable] = ACTIONS(1973),
    [anon_sym_constinit] = ACTIONS(1973),
    [anon_sym_consteval] = ACTIONS(1973),
    [anon_sym_alignas] = ACTIONS(1973),
    [anon_sym__Alignas] = ACTIONS(1973),
    [sym_primitive_type] = ACTIONS(1973),
    [anon_sym_enum] = ACTIONS(1973),
    [anon_sym_class] = ACTIONS(1973),
    [anon_sym_struct] = ACTIONS(1973),
    [anon_sym_union] = ACTIONS(1973),
    [anon_sym_if] = ACTIONS(1973),
    [anon_sym_else] = ACTIONS(1973),
    [anon_sym_switch] = ACTIONS(1973),
    [anon_sym_while] = ACTIONS(1973),
    [anon_sym_do] = ACTIONS(1973),
    [anon_sym_for] = ACTIONS(1973),
    [anon_sym_return] = ACTIONS(1973),
    [anon_sym_break] = ACTIONS(1973),
    [anon_sym_continue] = ACTIONS(1973),
    [anon_sym_goto] = ACTIONS(1973),
    [anon_sym___try] = ACTIONS(1973),
    [anon_sym___leave] = ACTIONS(1973),
    [anon_sym_not] = ACTIONS(1973),
    [anon_sym_compl] = ACTIONS(1973),
    [anon_sym_DASH_DASH] = ACTIONS(1975),
    [anon_sym_PLUS_PLUS] = ACTIONS(1975),
    [anon_sym_sizeof] = ACTIONS(1973),
    [anon_sym___alignof__] = ACTIONS(1973),
    [anon_sym___alignof] = ACTIONS(1973),
    [anon_sym__alignof] = ACTIONS(1973),
    [anon_sym_alignof] = ACTIONS(1973),
    [anon_sym__Alignof] = ACTIONS(1973),
    [anon_sym_offsetof] = ACTIONS(1973),
    [anon_sym__Generic] = ACTIONS(1973),
    [anon_sym_asm] = ACTIONS(1973),
    [anon_sym___asm__] = ACTIONS(1973),
    [sym_number_literal] = ACTIONS(1975),
    [anon_sym_L_SQUOTE] = ACTIONS(1975),
    [anon_sym_u_SQUOTE] = ACTIONS(1975),
    [anon_sym_U_SQUOTE] = ACTIONS(1975),
    [anon_sym_u8_SQUOTE] = ACTIONS(1975),
    [anon_sym_SQUOTE] = ACTIONS(1975),
    [anon_sym_L_DQUOTE] = ACTIONS(1975),
    [anon_sym_u_DQUOTE] = ACTIONS(1975),
    [anon_sym_U_DQUOTE] = ACTIONS(1975),
    [anon_sym_u8_DQUOTE] = ACTIONS(1975),
    [anon_sym_DQUOTE] = ACTIONS(1975),
    [sym_true] = ACTIONS(1973),
    [sym_false] = ACTIONS(1973),
    [anon_sym_NULL] = ACTIONS(1973),
    [anon_sym_nullptr] = ACTIONS(1973),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1973),
    [anon_sym_decltype] = ACTIONS(1973),
    [sym_virtual] = ACTIONS(1973),
    [anon_sym_typename] = ACTIONS(1973),
    [anon_sym_template] = ACTIONS(1973),
    [anon_sym_try] = ACTIONS(1973),
    [anon_sym_delete] = ACTIONS(1973),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_co_return] = ACTIONS(1973),
    [anon_sym_co_yield] = ACTIONS(1973),
    [anon_sym_catch] = ACTIONS(3747),
    [anon_sym_R_DQUOTE] = ACTIONS(1975),
    [anon_sym_LR_DQUOTE] = ACTIONS(1975),
    [anon_sym_uR_DQUOTE] = ACTIONS(1975),
    [anon_sym_UR_DQUOTE] = ACTIONS(1975),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1975),
    [anon_sym_co_await] = ACTIONS(1973),
    [anon_sym_new] = ACTIONS(1973),
    [anon_sym_requires] = ACTIONS(1973),
    [sym_this] = ACTIONS(1973),
    [anon_sym_discard] = ACTIONS(1973),
    [anon_sym_precise] = ACTIONS(1973),
    [anon_sym_shared] = ACTIONS(1973),
    [anon_sym_groupshared] = ACTIONS(1973),
    [anon_sym_uniform] = ACTIONS(1973),
    [anon_sym_row_major] = ACTIONS(1973),
    [anon_sym_column_major] = ACTIONS(1973),
    [anon_sym_globallycoherent] = ACTIONS(1973),
    [anon_sym_centroid] = ACTIONS(1973),
    [anon_sym_noperspective] = ACTIONS(1973),
    [anon_sym_nointerpolation] = ACTIONS(1973),
    [anon_sym_sample] = ACTIONS(1973),
    [anon_sym_linear] = ACTIONS(1973),
    [anon_sym_snorm] = ACTIONS(1973),
    [anon_sym_unorm] = ACTIONS(1973),
    [anon_sym_point] = ACTIONS(1973),
    [anon_sym_line] = ACTIONS(1973),
    [anon_sym_triangleadj] = ACTIONS(1973),
    [anon_sym_lineadj] = ACTIONS(1973),
    [anon_sym_triangle] = ACTIONS(1973),
    [anon_sym_cbuffer] = ACTIONS(1973),
  },
  [957] = {
    [sym_identifier] = ACTIONS(1887),
    [anon_sym_LPAREN2] = ACTIONS(1889),
    [anon_sym_BANG] = ACTIONS(1889),
    [anon_sym_TILDE] = ACTIONS(1889),
    [anon_sym_DASH] = ACTIONS(1887),
    [anon_sym_PLUS] = ACTIONS(1887),
    [anon_sym_STAR] = ACTIONS(1889),
    [anon_sym_AMP] = ACTIONS(1889),
    [anon_sym_COLON] = ACTIONS(1887),
    [anon_sym_SEMI] = ACTIONS(1889),
    [anon_sym___extension__] = ACTIONS(1887),
    [anon_sym_typedef] = ACTIONS(1887),
    [anon_sym_in] = ACTIONS(1887),
    [anon_sym_out] = ACTIONS(1887),
    [anon_sym_inout] = ACTIONS(1887),
    [anon_sym_extern] = ACTIONS(1887),
    [anon_sym___attribute__] = ACTIONS(1887),
    [anon_sym_COLON_COLON] = ACTIONS(1889),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1889),
    [anon_sym___declspec] = ACTIONS(1887),
    [anon_sym_LBRACE] = ACTIONS(1889),
    [anon_sym_signed] = ACTIONS(1887),
    [anon_sym_unsigned] = ACTIONS(1887),
    [anon_sym_long] = ACTIONS(1887),
    [anon_sym_short] = ACTIONS(1887),
    [anon_sym_LBRACK] = ACTIONS(1887),
    [anon_sym_static] = ACTIONS(1887),
    [anon_sym_register] = ACTIONS(1887),
    [anon_sym_inline] = ACTIONS(1887),
    [anon_sym___inline] = ACTIONS(1887),
    [anon_sym___inline__] = ACTIONS(1887),
    [anon_sym___forceinline] = ACTIONS(1887),
    [anon_sym_thread_local] = ACTIONS(1887),
    [anon_sym___thread] = ACTIONS(1887),
    [anon_sym_const] = ACTIONS(1887),
    [anon_sym_constexpr] = ACTIONS(1887),
    [anon_sym_volatile] = ACTIONS(1887),
    [anon_sym_restrict] = ACTIONS(1887),
    [anon_sym___restrict__] = ACTIONS(1887),
    [anon_sym__Atomic] = ACTIONS(1887),
    [anon_sym__Noreturn] = ACTIONS(1887),
    [anon_sym_noreturn] = ACTIONS(1887),
    [anon_sym_mutable] = ACTIONS(1887),
    [anon_sym_constinit] = ACTIONS(1887),
    [anon_sym_consteval] = ACTIONS(1887),
    [anon_sym_alignas] = ACTIONS(1887),
    [anon_sym__Alignas] = ACTIONS(1887),
    [sym_primitive_type] = ACTIONS(1887),
    [anon_sym_enum] = ACTIONS(1887),
    [anon_sym_class] = ACTIONS(1887),
    [anon_sym_struct] = ACTIONS(1887),
    [anon_sym_union] = ACTIONS(1887),
    [anon_sym_if] = ACTIONS(1887),
    [anon_sym_else] = ACTIONS(1887),
    [anon_sym_switch] = ACTIONS(1887),
    [anon_sym_while] = ACTIONS(1887),
    [anon_sym_do] = ACTIONS(1887),
    [anon_sym_for] = ACTIONS(1887),
    [anon_sym_return] = ACTIONS(1887),
    [anon_sym_break] = ACTIONS(1887),
    [anon_sym_continue] = ACTIONS(1887),
    [anon_sym_goto] = ACTIONS(1887),
    [anon_sym___try] = ACTIONS(1887),
    [anon_sym___leave] = ACTIONS(1887),
    [anon_sym_not] = ACTIONS(1887),
    [anon_sym_compl] = ACTIONS(1887),
    [anon_sym_DASH_DASH] = ACTIONS(1889),
    [anon_sym_PLUS_PLUS] = ACTIONS(1889),
    [anon_sym_sizeof] = ACTIONS(1887),
    [anon_sym___alignof__] = ACTIONS(1887),
    [anon_sym___alignof] = ACTIONS(1887),
    [anon_sym__alignof] = ACTIONS(1887),
    [anon_sym_alignof] = ACTIONS(1887),
    [anon_sym__Alignof] = ACTIONS(1887),
    [anon_sym_offsetof] = ACTIONS(1887),
    [anon_sym__Generic] = ACTIONS(1887),
    [anon_sym_asm] = ACTIONS(1887),
    [anon_sym___asm__] = ACTIONS(1887),
    [sym_number_literal] = ACTIONS(1889),
    [anon_sym_L_SQUOTE] = ACTIONS(1889),
    [anon_sym_u_SQUOTE] = ACTIONS(1889),
    [anon_sym_U_SQUOTE] = ACTIONS(1889),
    [anon_sym_u8_SQUOTE] = ACTIONS(1889),
    [anon_sym_SQUOTE] = ACTIONS(1889),
    [anon_sym_L_DQUOTE] = ACTIONS(1889),
    [anon_sym_u_DQUOTE] = ACTIONS(1889),
    [anon_sym_U_DQUOTE] = ACTIONS(1889),
    [anon_sym_u8_DQUOTE] = ACTIONS(1889),
    [anon_sym_DQUOTE] = ACTIONS(1889),
    [sym_true] = ACTIONS(1887),
    [sym_false] = ACTIONS(1887),
    [anon_sym_NULL] = ACTIONS(1887),
    [anon_sym_nullptr] = ACTIONS(1887),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1887),
    [anon_sym_decltype] = ACTIONS(1887),
    [anon_sym_final] = ACTIONS(1887),
    [anon_sym_override] = ACTIONS(1887),
    [sym_virtual] = ACTIONS(1887),
    [anon_sym_typename] = ACTIONS(1887),
    [anon_sym_template] = ACTIONS(1887),
    [anon_sym_try] = ACTIONS(1887),
    [anon_sym_delete] = ACTIONS(1887),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_co_return] = ACTIONS(1887),
    [anon_sym_co_yield] = ACTIONS(1887),
    [anon_sym_R_DQUOTE] = ACTIONS(1889),
    [anon_sym_LR_DQUOTE] = ACTIONS(1889),
    [anon_sym_uR_DQUOTE] = ACTIONS(1889),
    [anon_sym_UR_DQUOTE] = ACTIONS(1889),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1889),
    [anon_sym_co_await] = ACTIONS(1887),
    [anon_sym_new] = ACTIONS(1887),
    [anon_sym_requires] = ACTIONS(1887),
    [sym_this] = ACTIONS(1887),
    [anon_sym_discard] = ACTIONS(1887),
    [anon_sym_precise] = ACTIONS(1887),
    [anon_sym_shared] = ACTIONS(1887),
    [anon_sym_groupshared] = ACTIONS(1887),
    [anon_sym_uniform] = ACTIONS(1887),
    [anon_sym_row_major] = ACTIONS(1887),
    [anon_sym_column_major] = ACTIONS(1887),
    [anon_sym_globallycoherent] = ACTIONS(1887),
    [anon_sym_centroid] = ACTIONS(1887),
    [anon_sym_noperspective] = ACTIONS(1887),
    [anon_sym_nointerpolation] = ACTIONS(1887),
    [anon_sym_sample] = ACTIONS(1887),
    [anon_sym_linear] = ACTIONS(1887),
    [anon_sym_snorm] = ACTIONS(1887),
    [anon_sym_unorm] = ACTIONS(1887),
    [anon_sym_point] = ACTIONS(1887),
    [anon_sym_line] = ACTIONS(1887),
    [anon_sym_triangleadj] = ACTIONS(1887),
    [anon_sym_lineadj] = ACTIONS(1887),
    [anon_sym_triangle] = ACTIONS(1887),
    [anon_sym_cbuffer] = ACTIONS(1887),
  },
  [958] = {
    [sym_identifier] = ACTIONS(1949),
    [anon_sym_LPAREN2] = ACTIONS(1951),
    [anon_sym_BANG] = ACTIONS(1951),
    [anon_sym_TILDE] = ACTIONS(1951),
    [anon_sym_DASH] = ACTIONS(1949),
    [anon_sym_PLUS] = ACTIONS(1949),
    [anon_sym_STAR] = ACTIONS(1951),
    [anon_sym_AMP] = ACTIONS(1951),
    [anon_sym_COLON] = ACTIONS(1949),
    [anon_sym_SEMI] = ACTIONS(1951),
    [anon_sym___extension__] = ACTIONS(1949),
    [anon_sym_typedef] = ACTIONS(1949),
    [anon_sym_in] = ACTIONS(1949),
    [anon_sym_out] = ACTIONS(1949),
    [anon_sym_inout] = ACTIONS(1949),
    [anon_sym_extern] = ACTIONS(1949),
    [anon_sym___attribute__] = ACTIONS(1949),
    [anon_sym_COLON_COLON] = ACTIONS(1951),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1951),
    [anon_sym___declspec] = ACTIONS(1949),
    [anon_sym_LBRACE] = ACTIONS(1951),
    [anon_sym_signed] = ACTIONS(1949),
    [anon_sym_unsigned] = ACTIONS(1949),
    [anon_sym_long] = ACTIONS(1949),
    [anon_sym_short] = ACTIONS(1949),
    [anon_sym_LBRACK] = ACTIONS(1949),
    [anon_sym_static] = ACTIONS(1949),
    [anon_sym_register] = ACTIONS(1949),
    [anon_sym_inline] = ACTIONS(1949),
    [anon_sym___inline] = ACTIONS(1949),
    [anon_sym___inline__] = ACTIONS(1949),
    [anon_sym___forceinline] = ACTIONS(1949),
    [anon_sym_thread_local] = ACTIONS(1949),
    [anon_sym___thread] = ACTIONS(1949),
    [anon_sym_const] = ACTIONS(1949),
    [anon_sym_constexpr] = ACTIONS(1949),
    [anon_sym_volatile] = ACTIONS(1949),
    [anon_sym_restrict] = ACTIONS(1949),
    [anon_sym___restrict__] = ACTIONS(1949),
    [anon_sym__Atomic] = ACTIONS(1949),
    [anon_sym__Noreturn] = ACTIONS(1949),
    [anon_sym_noreturn] = ACTIONS(1949),
    [anon_sym_mutable] = ACTIONS(1949),
    [anon_sym_constinit] = ACTIONS(1949),
    [anon_sym_consteval] = ACTIONS(1949),
    [anon_sym_alignas] = ACTIONS(1949),
    [anon_sym__Alignas] = ACTIONS(1949),
    [sym_primitive_type] = ACTIONS(1949),
    [anon_sym_enum] = ACTIONS(1949),
    [anon_sym_class] = ACTIONS(1949),
    [anon_sym_struct] = ACTIONS(1949),
    [anon_sym_union] = ACTIONS(1949),
    [anon_sym_if] = ACTIONS(1949),
    [anon_sym_else] = ACTIONS(1949),
    [anon_sym_switch] = ACTIONS(1949),
    [anon_sym_while] = ACTIONS(1949),
    [anon_sym_do] = ACTIONS(1949),
    [anon_sym_for] = ACTIONS(1949),
    [anon_sym_return] = ACTIONS(1949),
    [anon_sym_break] = ACTIONS(1949),
    [anon_sym_continue] = ACTIONS(1949),
    [anon_sym_goto] = ACTIONS(1949),
    [anon_sym___try] = ACTIONS(1949),
    [anon_sym___leave] = ACTIONS(1949),
    [anon_sym_not] = ACTIONS(1949),
    [anon_sym_compl] = ACTIONS(1949),
    [anon_sym_DASH_DASH] = ACTIONS(1951),
    [anon_sym_PLUS_PLUS] = ACTIONS(1951),
    [anon_sym_sizeof] = ACTIONS(1949),
    [anon_sym___alignof__] = ACTIONS(1949),
    [anon_sym___alignof] = ACTIONS(1949),
    [anon_sym__alignof] = ACTIONS(1949),
    [anon_sym_alignof] = ACTIONS(1949),
    [anon_sym__Alignof] = ACTIONS(1949),
    [anon_sym_offsetof] = ACTIONS(1949),
    [anon_sym__Generic] = ACTIONS(1949),
    [anon_sym_asm] = ACTIONS(1949),
    [anon_sym___asm__] = ACTIONS(1949),
    [sym_number_literal] = ACTIONS(1951),
    [anon_sym_L_SQUOTE] = ACTIONS(1951),
    [anon_sym_u_SQUOTE] = ACTIONS(1951),
    [anon_sym_U_SQUOTE] = ACTIONS(1951),
    [anon_sym_u8_SQUOTE] = ACTIONS(1951),
    [anon_sym_SQUOTE] = ACTIONS(1951),
    [anon_sym_L_DQUOTE] = ACTIONS(1951),
    [anon_sym_u_DQUOTE] = ACTIONS(1951),
    [anon_sym_U_DQUOTE] = ACTIONS(1951),
    [anon_sym_u8_DQUOTE] = ACTIONS(1951),
    [anon_sym_DQUOTE] = ACTIONS(1951),
    [sym_true] = ACTIONS(1949),
    [sym_false] = ACTIONS(1949),
    [anon_sym_NULL] = ACTIONS(1949),
    [anon_sym_nullptr] = ACTIONS(1949),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1949),
    [anon_sym_decltype] = ACTIONS(1949),
    [anon_sym_final] = ACTIONS(1949),
    [anon_sym_override] = ACTIONS(1949),
    [sym_virtual] = ACTIONS(1949),
    [anon_sym_typename] = ACTIONS(1949),
    [anon_sym_template] = ACTIONS(1949),
    [anon_sym_try] = ACTIONS(1949),
    [anon_sym_delete] = ACTIONS(1949),
    [anon_sym_throw] = ACTIONS(1949),
    [anon_sym_co_return] = ACTIONS(1949),
    [anon_sym_co_yield] = ACTIONS(1949),
    [anon_sym_R_DQUOTE] = ACTIONS(1951),
    [anon_sym_LR_DQUOTE] = ACTIONS(1951),
    [anon_sym_uR_DQUOTE] = ACTIONS(1951),
    [anon_sym_UR_DQUOTE] = ACTIONS(1951),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1951),
    [anon_sym_co_await] = ACTIONS(1949),
    [anon_sym_new] = ACTIONS(1949),
    [anon_sym_requires] = ACTIONS(1949),
    [sym_this] = ACTIONS(1949),
    [anon_sym_discard] = ACTIONS(1949),
    [anon_sym_precise] = ACTIONS(1949),
    [anon_sym_shared] = ACTIONS(1949),
    [anon_sym_groupshared] = ACTIONS(1949),
    [anon_sym_uniform] = ACTIONS(1949),
    [anon_sym_row_major] = ACTIONS(1949),
    [anon_sym_column_major] = ACTIONS(1949),
    [anon_sym_globallycoherent] = ACTIONS(1949),
    [anon_sym_centroid] = ACTIONS(1949),
    [anon_sym_noperspective] = ACTIONS(1949),
    [anon_sym_nointerpolation] = ACTIONS(1949),
    [anon_sym_sample] = ACTIONS(1949),
    [anon_sym_linear] = ACTIONS(1949),
    [anon_sym_snorm] = ACTIONS(1949),
    [anon_sym_unorm] = ACTIONS(1949),
    [anon_sym_point] = ACTIONS(1949),
    [anon_sym_line] = ACTIONS(1949),
    [anon_sym_triangleadj] = ACTIONS(1949),
    [anon_sym_lineadj] = ACTIONS(1949),
    [anon_sym_triangle] = ACTIONS(1949),
    [anon_sym_cbuffer] = ACTIONS(1949),
  },
  [959] = {
    [sym_identifier] = ACTIONS(1925),
    [anon_sym_LPAREN2] = ACTIONS(1927),
    [anon_sym_BANG] = ACTIONS(1927),
    [anon_sym_TILDE] = ACTIONS(1927),
    [anon_sym_DASH] = ACTIONS(1925),
    [anon_sym_PLUS] = ACTIONS(1925),
    [anon_sym_STAR] = ACTIONS(1927),
    [anon_sym_AMP] = ACTIONS(1927),
    [anon_sym_COLON] = ACTIONS(1925),
    [anon_sym_SEMI] = ACTIONS(1927),
    [anon_sym___extension__] = ACTIONS(1925),
    [anon_sym_typedef] = ACTIONS(1925),
    [anon_sym_in] = ACTIONS(1925),
    [anon_sym_out] = ACTIONS(1925),
    [anon_sym_inout] = ACTIONS(1925),
    [anon_sym_extern] = ACTIONS(1925),
    [anon_sym___attribute__] = ACTIONS(1925),
    [anon_sym_COLON_COLON] = ACTIONS(1927),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1927),
    [anon_sym___declspec] = ACTIONS(1925),
    [anon_sym_LBRACE] = ACTIONS(1927),
    [anon_sym_signed] = ACTIONS(1925),
    [anon_sym_unsigned] = ACTIONS(1925),
    [anon_sym_long] = ACTIONS(1925),
    [anon_sym_short] = ACTIONS(1925),
    [anon_sym_LBRACK] = ACTIONS(1925),
    [anon_sym_static] = ACTIONS(1925),
    [anon_sym_register] = ACTIONS(1925),
    [anon_sym_inline] = ACTIONS(1925),
    [anon_sym___inline] = ACTIONS(1925),
    [anon_sym___inline__] = ACTIONS(1925),
    [anon_sym___forceinline] = ACTIONS(1925),
    [anon_sym_thread_local] = ACTIONS(1925),
    [anon_sym___thread] = ACTIONS(1925),
    [anon_sym_const] = ACTIONS(1925),
    [anon_sym_constexpr] = ACTIONS(1925),
    [anon_sym_volatile] = ACTIONS(1925),
    [anon_sym_restrict] = ACTIONS(1925),
    [anon_sym___restrict__] = ACTIONS(1925),
    [anon_sym__Atomic] = ACTIONS(1925),
    [anon_sym__Noreturn] = ACTIONS(1925),
    [anon_sym_noreturn] = ACTIONS(1925),
    [anon_sym_mutable] = ACTIONS(1925),
    [anon_sym_constinit] = ACTIONS(1925),
    [anon_sym_consteval] = ACTIONS(1925),
    [anon_sym_alignas] = ACTIONS(1925),
    [anon_sym__Alignas] = ACTIONS(1925),
    [sym_primitive_type] = ACTIONS(1925),
    [anon_sym_enum] = ACTIONS(1925),
    [anon_sym_class] = ACTIONS(1925),
    [anon_sym_struct] = ACTIONS(1925),
    [anon_sym_union] = ACTIONS(1925),
    [anon_sym_if] = ACTIONS(1925),
    [anon_sym_else] = ACTIONS(1925),
    [anon_sym_switch] = ACTIONS(1925),
    [anon_sym_while] = ACTIONS(1925),
    [anon_sym_do] = ACTIONS(1925),
    [anon_sym_for] = ACTIONS(1925),
    [anon_sym_return] = ACTIONS(1925),
    [anon_sym_break] = ACTIONS(1925),
    [anon_sym_continue] = ACTIONS(1925),
    [anon_sym_goto] = ACTIONS(1925),
    [anon_sym___try] = ACTIONS(1925),
    [anon_sym___leave] = ACTIONS(1925),
    [anon_sym_not] = ACTIONS(1925),
    [anon_sym_compl] = ACTIONS(1925),
    [anon_sym_DASH_DASH] = ACTIONS(1927),
    [anon_sym_PLUS_PLUS] = ACTIONS(1927),
    [anon_sym_sizeof] = ACTIONS(1925),
    [anon_sym___alignof__] = ACTIONS(1925),
    [anon_sym___alignof] = ACTIONS(1925),
    [anon_sym__alignof] = ACTIONS(1925),
    [anon_sym_alignof] = ACTIONS(1925),
    [anon_sym__Alignof] = ACTIONS(1925),
    [anon_sym_offsetof] = ACTIONS(1925),
    [anon_sym__Generic] = ACTIONS(1925),
    [anon_sym_asm] = ACTIONS(1925),
    [anon_sym___asm__] = ACTIONS(1925),
    [sym_number_literal] = ACTIONS(1927),
    [anon_sym_L_SQUOTE] = ACTIONS(1927),
    [anon_sym_u_SQUOTE] = ACTIONS(1927),
    [anon_sym_U_SQUOTE] = ACTIONS(1927),
    [anon_sym_u8_SQUOTE] = ACTIONS(1927),
    [anon_sym_SQUOTE] = ACTIONS(1927),
    [anon_sym_L_DQUOTE] = ACTIONS(1927),
    [anon_sym_u_DQUOTE] = ACTIONS(1927),
    [anon_sym_U_DQUOTE] = ACTIONS(1927),
    [anon_sym_u8_DQUOTE] = ACTIONS(1927),
    [anon_sym_DQUOTE] = ACTIONS(1927),
    [sym_true] = ACTIONS(1925),
    [sym_false] = ACTIONS(1925),
    [anon_sym_NULL] = ACTIONS(1925),
    [anon_sym_nullptr] = ACTIONS(1925),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1925),
    [anon_sym_decltype] = ACTIONS(1925),
    [anon_sym_final] = ACTIONS(1925),
    [anon_sym_override] = ACTIONS(1925),
    [sym_virtual] = ACTIONS(1925),
    [anon_sym_typename] = ACTIONS(1925),
    [anon_sym_template] = ACTIONS(1925),
    [anon_sym_try] = ACTIONS(1925),
    [anon_sym_delete] = ACTIONS(1925),
    [anon_sym_throw] = ACTIONS(1925),
    [anon_sym_co_return] = ACTIONS(1925),
    [anon_sym_co_yield] = ACTIONS(1925),
    [anon_sym_R_DQUOTE] = ACTIONS(1927),
    [anon_sym_LR_DQUOTE] = ACTIONS(1927),
    [anon_sym_uR_DQUOTE] = ACTIONS(1927),
    [anon_sym_UR_DQUOTE] = ACTIONS(1927),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1927),
    [anon_sym_co_await] = ACTIONS(1925),
    [anon_sym_new] = ACTIONS(1925),
    [anon_sym_requires] = ACTIONS(1925),
    [sym_this] = ACTIONS(1925),
    [anon_sym_discard] = ACTIONS(1925),
    [anon_sym_precise] = ACTIONS(1925),
    [anon_sym_shared] = ACTIONS(1925),
    [anon_sym_groupshared] = ACTIONS(1925),
    [anon_sym_uniform] = ACTIONS(1925),
    [anon_sym_row_major] = ACTIONS(1925),
    [anon_sym_column_major] = ACTIONS(1925),
    [anon_sym_globallycoherent] = ACTIONS(1925),
    [anon_sym_centroid] = ACTIONS(1925),
    [anon_sym_noperspective] = ACTIONS(1925),
    [anon_sym_nointerpolation] = ACTIONS(1925),
    [anon_sym_sample] = ACTIONS(1925),
    [anon_sym_linear] = ACTIONS(1925),
    [anon_sym_snorm] = ACTIONS(1925),
    [anon_sym_unorm] = ACTIONS(1925),
    [anon_sym_point] = ACTIONS(1925),
    [anon_sym_line] = ACTIONS(1925),
    [anon_sym_triangleadj] = ACTIONS(1925),
    [anon_sym_lineadj] = ACTIONS(1925),
    [anon_sym_triangle] = ACTIONS(1925),
    [anon_sym_cbuffer] = ACTIONS(1925),
  },
  [960] = {
    [sym_identifier] = ACTIONS(1895),
    [anon_sym_LPAREN2] = ACTIONS(1897),
    [anon_sym_BANG] = ACTIONS(1897),
    [anon_sym_TILDE] = ACTIONS(1897),
    [anon_sym_DASH] = ACTIONS(1895),
    [anon_sym_PLUS] = ACTIONS(1895),
    [anon_sym_STAR] = ACTIONS(1897),
    [anon_sym_AMP] = ACTIONS(1897),
    [anon_sym_COLON] = ACTIONS(1895),
    [anon_sym_SEMI] = ACTIONS(1897),
    [anon_sym___extension__] = ACTIONS(1895),
    [anon_sym_typedef] = ACTIONS(1895),
    [anon_sym_in] = ACTIONS(1895),
    [anon_sym_out] = ACTIONS(1895),
    [anon_sym_inout] = ACTIONS(1895),
    [anon_sym_extern] = ACTIONS(1895),
    [anon_sym___attribute__] = ACTIONS(1895),
    [anon_sym_COLON_COLON] = ACTIONS(1897),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1897),
    [anon_sym___declspec] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1897),
    [anon_sym_signed] = ACTIONS(1895),
    [anon_sym_unsigned] = ACTIONS(1895),
    [anon_sym_long] = ACTIONS(1895),
    [anon_sym_short] = ACTIONS(1895),
    [anon_sym_LBRACK] = ACTIONS(1895),
    [anon_sym_static] = ACTIONS(1895),
    [anon_sym_register] = ACTIONS(1895),
    [anon_sym_inline] = ACTIONS(1895),
    [anon_sym___inline] = ACTIONS(1895),
    [anon_sym___inline__] = ACTIONS(1895),
    [anon_sym___forceinline] = ACTIONS(1895),
    [anon_sym_thread_local] = ACTIONS(1895),
    [anon_sym___thread] = ACTIONS(1895),
    [anon_sym_const] = ACTIONS(1895),
    [anon_sym_constexpr] = ACTIONS(1895),
    [anon_sym_volatile] = ACTIONS(1895),
    [anon_sym_restrict] = ACTIONS(1895),
    [anon_sym___restrict__] = ACTIONS(1895),
    [anon_sym__Atomic] = ACTIONS(1895),
    [anon_sym__Noreturn] = ACTIONS(1895),
    [anon_sym_noreturn] = ACTIONS(1895),
    [anon_sym_mutable] = ACTIONS(1895),
    [anon_sym_constinit] = ACTIONS(1895),
    [anon_sym_consteval] = ACTIONS(1895),
    [anon_sym_alignas] = ACTIONS(1895),
    [anon_sym__Alignas] = ACTIONS(1895),
    [sym_primitive_type] = ACTIONS(1895),
    [anon_sym_enum] = ACTIONS(1895),
    [anon_sym_class] = ACTIONS(1895),
    [anon_sym_struct] = ACTIONS(1895),
    [anon_sym_union] = ACTIONS(1895),
    [anon_sym_if] = ACTIONS(1895),
    [anon_sym_else] = ACTIONS(1895),
    [anon_sym_switch] = ACTIONS(1895),
    [anon_sym_while] = ACTIONS(1895),
    [anon_sym_do] = ACTIONS(1895),
    [anon_sym_for] = ACTIONS(1895),
    [anon_sym_return] = ACTIONS(1895),
    [anon_sym_break] = ACTIONS(1895),
    [anon_sym_continue] = ACTIONS(1895),
    [anon_sym_goto] = ACTIONS(1895),
    [anon_sym___try] = ACTIONS(1895),
    [anon_sym___leave] = ACTIONS(1895),
    [anon_sym_not] = ACTIONS(1895),
    [anon_sym_compl] = ACTIONS(1895),
    [anon_sym_DASH_DASH] = ACTIONS(1897),
    [anon_sym_PLUS_PLUS] = ACTIONS(1897),
    [anon_sym_sizeof] = ACTIONS(1895),
    [anon_sym___alignof__] = ACTIONS(1895),
    [anon_sym___alignof] = ACTIONS(1895),
    [anon_sym__alignof] = ACTIONS(1895),
    [anon_sym_alignof] = ACTIONS(1895),
    [anon_sym__Alignof] = ACTIONS(1895),
    [anon_sym_offsetof] = ACTIONS(1895),
    [anon_sym__Generic] = ACTIONS(1895),
    [anon_sym_asm] = ACTIONS(1895),
    [anon_sym___asm__] = ACTIONS(1895),
    [sym_number_literal] = ACTIONS(1897),
    [anon_sym_L_SQUOTE] = ACTIONS(1897),
    [anon_sym_u_SQUOTE] = ACTIONS(1897),
    [anon_sym_U_SQUOTE] = ACTIONS(1897),
    [anon_sym_u8_SQUOTE] = ACTIONS(1897),
    [anon_sym_SQUOTE] = ACTIONS(1897),
    [anon_sym_L_DQUOTE] = ACTIONS(1897),
    [anon_sym_u_DQUOTE] = ACTIONS(1897),
    [anon_sym_U_DQUOTE] = ACTIONS(1897),
    [anon_sym_u8_DQUOTE] = ACTIONS(1897),
    [anon_sym_DQUOTE] = ACTIONS(1897),
    [sym_true] = ACTIONS(1895),
    [sym_false] = ACTIONS(1895),
    [anon_sym_NULL] = ACTIONS(1895),
    [anon_sym_nullptr] = ACTIONS(1895),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1895),
    [anon_sym_decltype] = ACTIONS(1895),
    [anon_sym_final] = ACTIONS(1895),
    [anon_sym_override] = ACTIONS(1895),
    [sym_virtual] = ACTIONS(1895),
    [anon_sym_typename] = ACTIONS(1895),
    [anon_sym_template] = ACTIONS(1895),
    [anon_sym_try] = ACTIONS(1895),
    [anon_sym_delete] = ACTIONS(1895),
    [anon_sym_throw] = ACTIONS(1895),
    [anon_sym_co_return] = ACTIONS(1895),
    [anon_sym_co_yield] = ACTIONS(1895),
    [anon_sym_R_DQUOTE] = ACTIONS(1897),
    [anon_sym_LR_DQUOTE] = ACTIONS(1897),
    [anon_sym_uR_DQUOTE] = ACTIONS(1897),
    [anon_sym_UR_DQUOTE] = ACTIONS(1897),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1897),
    [anon_sym_co_await] = ACTIONS(1895),
    [anon_sym_new] = ACTIONS(1895),
    [anon_sym_requires] = ACTIONS(1895),
    [sym_this] = ACTIONS(1895),
    [anon_sym_discard] = ACTIONS(1895),
    [anon_sym_precise] = ACTIONS(1895),
    [anon_sym_shared] = ACTIONS(1895),
    [anon_sym_groupshared] = ACTIONS(1895),
    [anon_sym_uniform] = ACTIONS(1895),
    [anon_sym_row_major] = ACTIONS(1895),
    [anon_sym_column_major] = ACTIONS(1895),
    [anon_sym_globallycoherent] = ACTIONS(1895),
    [anon_sym_centroid] = ACTIONS(1895),
    [anon_sym_noperspective] = ACTIONS(1895),
    [anon_sym_nointerpolation] = ACTIONS(1895),
    [anon_sym_sample] = ACTIONS(1895),
    [anon_sym_linear] = ACTIONS(1895),
    [anon_sym_snorm] = ACTIONS(1895),
    [anon_sym_unorm] = ACTIONS(1895),
    [anon_sym_point] = ACTIONS(1895),
    [anon_sym_line] = ACTIONS(1895),
    [anon_sym_triangleadj] = ACTIONS(1895),
    [anon_sym_lineadj] = ACTIONS(1895),
    [anon_sym_triangle] = ACTIONS(1895),
    [anon_sym_cbuffer] = ACTIONS(1895),
  },
  [961] = {
    [sym_identifier] = ACTIONS(1891),
    [anon_sym_LPAREN2] = ACTIONS(1893),
    [anon_sym_BANG] = ACTIONS(1893),
    [anon_sym_TILDE] = ACTIONS(1893),
    [anon_sym_DASH] = ACTIONS(1891),
    [anon_sym_PLUS] = ACTIONS(1891),
    [anon_sym_STAR] = ACTIONS(1893),
    [anon_sym_AMP] = ACTIONS(1893),
    [anon_sym_COLON] = ACTIONS(1891),
    [anon_sym_SEMI] = ACTIONS(1893),
    [anon_sym___extension__] = ACTIONS(1891),
    [anon_sym_typedef] = ACTIONS(1891),
    [anon_sym_in] = ACTIONS(1891),
    [anon_sym_out] = ACTIONS(1891),
    [anon_sym_inout] = ACTIONS(1891),
    [anon_sym_extern] = ACTIONS(1891),
    [anon_sym___attribute__] = ACTIONS(1891),
    [anon_sym_COLON_COLON] = ACTIONS(1893),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1893),
    [anon_sym___declspec] = ACTIONS(1891),
    [anon_sym_LBRACE] = ACTIONS(1893),
    [anon_sym_signed] = ACTIONS(1891),
    [anon_sym_unsigned] = ACTIONS(1891),
    [anon_sym_long] = ACTIONS(1891),
    [anon_sym_short] = ACTIONS(1891),
    [anon_sym_LBRACK] = ACTIONS(1891),
    [anon_sym_static] = ACTIONS(1891),
    [anon_sym_register] = ACTIONS(1891),
    [anon_sym_inline] = ACTIONS(1891),
    [anon_sym___inline] = ACTIONS(1891),
    [anon_sym___inline__] = ACTIONS(1891),
    [anon_sym___forceinline] = ACTIONS(1891),
    [anon_sym_thread_local] = ACTIONS(1891),
    [anon_sym___thread] = ACTIONS(1891),
    [anon_sym_const] = ACTIONS(1891),
    [anon_sym_constexpr] = ACTIONS(1891),
    [anon_sym_volatile] = ACTIONS(1891),
    [anon_sym_restrict] = ACTIONS(1891),
    [anon_sym___restrict__] = ACTIONS(1891),
    [anon_sym__Atomic] = ACTIONS(1891),
    [anon_sym__Noreturn] = ACTIONS(1891),
    [anon_sym_noreturn] = ACTIONS(1891),
    [anon_sym_mutable] = ACTIONS(1891),
    [anon_sym_constinit] = ACTIONS(1891),
    [anon_sym_consteval] = ACTIONS(1891),
    [anon_sym_alignas] = ACTIONS(1891),
    [anon_sym__Alignas] = ACTIONS(1891),
    [sym_primitive_type] = ACTIONS(1891),
    [anon_sym_enum] = ACTIONS(1891),
    [anon_sym_class] = ACTIONS(1891),
    [anon_sym_struct] = ACTIONS(1891),
    [anon_sym_union] = ACTIONS(1891),
    [anon_sym_if] = ACTIONS(1891),
    [anon_sym_else] = ACTIONS(1891),
    [anon_sym_switch] = ACTIONS(1891),
    [anon_sym_while] = ACTIONS(1891),
    [anon_sym_do] = ACTIONS(1891),
    [anon_sym_for] = ACTIONS(1891),
    [anon_sym_return] = ACTIONS(1891),
    [anon_sym_break] = ACTIONS(1891),
    [anon_sym_continue] = ACTIONS(1891),
    [anon_sym_goto] = ACTIONS(1891),
    [anon_sym___try] = ACTIONS(1891),
    [anon_sym___leave] = ACTIONS(1891),
    [anon_sym_not] = ACTIONS(1891),
    [anon_sym_compl] = ACTIONS(1891),
    [anon_sym_DASH_DASH] = ACTIONS(1893),
    [anon_sym_PLUS_PLUS] = ACTIONS(1893),
    [anon_sym_sizeof] = ACTIONS(1891),
    [anon_sym___alignof__] = ACTIONS(1891),
    [anon_sym___alignof] = ACTIONS(1891),
    [anon_sym__alignof] = ACTIONS(1891),
    [anon_sym_alignof] = ACTIONS(1891),
    [anon_sym__Alignof] = ACTIONS(1891),
    [anon_sym_offsetof] = ACTIONS(1891),
    [anon_sym__Generic] = ACTIONS(1891),
    [anon_sym_asm] = ACTIONS(1891),
    [anon_sym___asm__] = ACTIONS(1891),
    [sym_number_literal] = ACTIONS(1893),
    [anon_sym_L_SQUOTE] = ACTIONS(1893),
    [anon_sym_u_SQUOTE] = ACTIONS(1893),
    [anon_sym_U_SQUOTE] = ACTIONS(1893),
    [anon_sym_u8_SQUOTE] = ACTIONS(1893),
    [anon_sym_SQUOTE] = ACTIONS(1893),
    [anon_sym_L_DQUOTE] = ACTIONS(1893),
    [anon_sym_u_DQUOTE] = ACTIONS(1893),
    [anon_sym_U_DQUOTE] = ACTIONS(1893),
    [anon_sym_u8_DQUOTE] = ACTIONS(1893),
    [anon_sym_DQUOTE] = ACTIONS(1893),
    [sym_true] = ACTIONS(1891),
    [sym_false] = ACTIONS(1891),
    [anon_sym_NULL] = ACTIONS(1891),
    [anon_sym_nullptr] = ACTIONS(1891),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1891),
    [anon_sym_decltype] = ACTIONS(1891),
    [anon_sym_final] = ACTIONS(1891),
    [anon_sym_override] = ACTIONS(1891),
    [sym_virtual] = ACTIONS(1891),
    [anon_sym_typename] = ACTIONS(1891),
    [anon_sym_template] = ACTIONS(1891),
    [anon_sym_try] = ACTIONS(1891),
    [anon_sym_delete] = ACTIONS(1891),
    [anon_sym_throw] = ACTIONS(1891),
    [anon_sym_co_return] = ACTIONS(1891),
    [anon_sym_co_yield] = ACTIONS(1891),
    [anon_sym_R_DQUOTE] = ACTIONS(1893),
    [anon_sym_LR_DQUOTE] = ACTIONS(1893),
    [anon_sym_uR_DQUOTE] = ACTIONS(1893),
    [anon_sym_UR_DQUOTE] = ACTIONS(1893),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1893),
    [anon_sym_co_await] = ACTIONS(1891),
    [anon_sym_new] = ACTIONS(1891),
    [anon_sym_requires] = ACTIONS(1891),
    [sym_this] = ACTIONS(1891),
    [anon_sym_discard] = ACTIONS(1891),
    [anon_sym_precise] = ACTIONS(1891),
    [anon_sym_shared] = ACTIONS(1891),
    [anon_sym_groupshared] = ACTIONS(1891),
    [anon_sym_uniform] = ACTIONS(1891),
    [anon_sym_row_major] = ACTIONS(1891),
    [anon_sym_column_major] = ACTIONS(1891),
    [anon_sym_globallycoherent] = ACTIONS(1891),
    [anon_sym_centroid] = ACTIONS(1891),
    [anon_sym_noperspective] = ACTIONS(1891),
    [anon_sym_nointerpolation] = ACTIONS(1891),
    [anon_sym_sample] = ACTIONS(1891),
    [anon_sym_linear] = ACTIONS(1891),
    [anon_sym_snorm] = ACTIONS(1891),
    [anon_sym_unorm] = ACTIONS(1891),
    [anon_sym_point] = ACTIONS(1891),
    [anon_sym_line] = ACTIONS(1891),
    [anon_sym_triangleadj] = ACTIONS(1891),
    [anon_sym_lineadj] = ACTIONS(1891),
    [anon_sym_triangle] = ACTIONS(1891),
    [anon_sym_cbuffer] = ACTIONS(1891),
  },
  [962] = {
    [sym_identifier] = ACTIONS(1903),
    [anon_sym_LPAREN2] = ACTIONS(1905),
    [anon_sym_BANG] = ACTIONS(1905),
    [anon_sym_TILDE] = ACTIONS(1905),
    [anon_sym_DASH] = ACTIONS(1903),
    [anon_sym_PLUS] = ACTIONS(1903),
    [anon_sym_STAR] = ACTIONS(1905),
    [anon_sym_AMP] = ACTIONS(1905),
    [anon_sym_COLON] = ACTIONS(1903),
    [anon_sym_SEMI] = ACTIONS(1905),
    [anon_sym___extension__] = ACTIONS(1903),
    [anon_sym_typedef] = ACTIONS(1903),
    [anon_sym_in] = ACTIONS(1903),
    [anon_sym_out] = ACTIONS(1903),
    [anon_sym_inout] = ACTIONS(1903),
    [anon_sym_extern] = ACTIONS(1903),
    [anon_sym___attribute__] = ACTIONS(1903),
    [anon_sym_COLON_COLON] = ACTIONS(1905),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1905),
    [anon_sym___declspec] = ACTIONS(1903),
    [anon_sym_LBRACE] = ACTIONS(1905),
    [anon_sym_signed] = ACTIONS(1903),
    [anon_sym_unsigned] = ACTIONS(1903),
    [anon_sym_long] = ACTIONS(1903),
    [anon_sym_short] = ACTIONS(1903),
    [anon_sym_LBRACK] = ACTIONS(1903),
    [anon_sym_static] = ACTIONS(1903),
    [anon_sym_register] = ACTIONS(1903),
    [anon_sym_inline] = ACTIONS(1903),
    [anon_sym___inline] = ACTIONS(1903),
    [anon_sym___inline__] = ACTIONS(1903),
    [anon_sym___forceinline] = ACTIONS(1903),
    [anon_sym_thread_local] = ACTIONS(1903),
    [anon_sym___thread] = ACTIONS(1903),
    [anon_sym_const] = ACTIONS(1903),
    [anon_sym_constexpr] = ACTIONS(1903),
    [anon_sym_volatile] = ACTIONS(1903),
    [anon_sym_restrict] = ACTIONS(1903),
    [anon_sym___restrict__] = ACTIONS(1903),
    [anon_sym__Atomic] = ACTIONS(1903),
    [anon_sym__Noreturn] = ACTIONS(1903),
    [anon_sym_noreturn] = ACTIONS(1903),
    [anon_sym_mutable] = ACTIONS(1903),
    [anon_sym_constinit] = ACTIONS(1903),
    [anon_sym_consteval] = ACTIONS(1903),
    [anon_sym_alignas] = ACTIONS(1903),
    [anon_sym__Alignas] = ACTIONS(1903),
    [sym_primitive_type] = ACTIONS(1903),
    [anon_sym_enum] = ACTIONS(1903),
    [anon_sym_class] = ACTIONS(1903),
    [anon_sym_struct] = ACTIONS(1903),
    [anon_sym_union] = ACTIONS(1903),
    [anon_sym_if] = ACTIONS(1903),
    [anon_sym_else] = ACTIONS(1903),
    [anon_sym_switch] = ACTIONS(1903),
    [anon_sym_while] = ACTIONS(1903),
    [anon_sym_do] = ACTIONS(1903),
    [anon_sym_for] = ACTIONS(1903),
    [anon_sym_return] = ACTIONS(1903),
    [anon_sym_break] = ACTIONS(1903),
    [anon_sym_continue] = ACTIONS(1903),
    [anon_sym_goto] = ACTIONS(1903),
    [anon_sym___try] = ACTIONS(1903),
    [anon_sym___leave] = ACTIONS(1903),
    [anon_sym_not] = ACTIONS(1903),
    [anon_sym_compl] = ACTIONS(1903),
    [anon_sym_DASH_DASH] = ACTIONS(1905),
    [anon_sym_PLUS_PLUS] = ACTIONS(1905),
    [anon_sym_sizeof] = ACTIONS(1903),
    [anon_sym___alignof__] = ACTIONS(1903),
    [anon_sym___alignof] = ACTIONS(1903),
    [anon_sym__alignof] = ACTIONS(1903),
    [anon_sym_alignof] = ACTIONS(1903),
    [anon_sym__Alignof] = ACTIONS(1903),
    [anon_sym_offsetof] = ACTIONS(1903),
    [anon_sym__Generic] = ACTIONS(1903),
    [anon_sym_asm] = ACTIONS(1903),
    [anon_sym___asm__] = ACTIONS(1903),
    [sym_number_literal] = ACTIONS(1905),
    [anon_sym_L_SQUOTE] = ACTIONS(1905),
    [anon_sym_u_SQUOTE] = ACTIONS(1905),
    [anon_sym_U_SQUOTE] = ACTIONS(1905),
    [anon_sym_u8_SQUOTE] = ACTIONS(1905),
    [anon_sym_SQUOTE] = ACTIONS(1905),
    [anon_sym_L_DQUOTE] = ACTIONS(1905),
    [anon_sym_u_DQUOTE] = ACTIONS(1905),
    [anon_sym_U_DQUOTE] = ACTIONS(1905),
    [anon_sym_u8_DQUOTE] = ACTIONS(1905),
    [anon_sym_DQUOTE] = ACTIONS(1905),
    [sym_true] = ACTIONS(1903),
    [sym_false] = ACTIONS(1903),
    [anon_sym_NULL] = ACTIONS(1903),
    [anon_sym_nullptr] = ACTIONS(1903),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1903),
    [anon_sym_decltype] = ACTIONS(1903),
    [anon_sym_final] = ACTIONS(1903),
    [anon_sym_override] = ACTIONS(1903),
    [sym_virtual] = ACTIONS(1903),
    [anon_sym_typename] = ACTIONS(1903),
    [anon_sym_template] = ACTIONS(1903),
    [anon_sym_try] = ACTIONS(1903),
    [anon_sym_delete] = ACTIONS(1903),
    [anon_sym_throw] = ACTIONS(1903),
    [anon_sym_co_return] = ACTIONS(1903),
    [anon_sym_co_yield] = ACTIONS(1903),
    [anon_sym_R_DQUOTE] = ACTIONS(1905),
    [anon_sym_LR_DQUOTE] = ACTIONS(1905),
    [anon_sym_uR_DQUOTE] = ACTIONS(1905),
    [anon_sym_UR_DQUOTE] = ACTIONS(1905),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1905),
    [anon_sym_co_await] = ACTIONS(1903),
    [anon_sym_new] = ACTIONS(1903),
    [anon_sym_requires] = ACTIONS(1903),
    [sym_this] = ACTIONS(1903),
    [anon_sym_discard] = ACTIONS(1903),
    [anon_sym_precise] = ACTIONS(1903),
    [anon_sym_shared] = ACTIONS(1903),
    [anon_sym_groupshared] = ACTIONS(1903),
    [anon_sym_uniform] = ACTIONS(1903),
    [anon_sym_row_major] = ACTIONS(1903),
    [anon_sym_column_major] = ACTIONS(1903),
    [anon_sym_globallycoherent] = ACTIONS(1903),
    [anon_sym_centroid] = ACTIONS(1903),
    [anon_sym_noperspective] = ACTIONS(1903),
    [anon_sym_nointerpolation] = ACTIONS(1903),
    [anon_sym_sample] = ACTIONS(1903),
    [anon_sym_linear] = ACTIONS(1903),
    [anon_sym_snorm] = ACTIONS(1903),
    [anon_sym_unorm] = ACTIONS(1903),
    [anon_sym_point] = ACTIONS(1903),
    [anon_sym_line] = ACTIONS(1903),
    [anon_sym_triangleadj] = ACTIONS(1903),
    [anon_sym_lineadj] = ACTIONS(1903),
    [anon_sym_triangle] = ACTIONS(1903),
    [anon_sym_cbuffer] = ACTIONS(1903),
  },
  [963] = {
    [sym_type_qualifier] = STATE(3990),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4777),
    [sym_sized_type_specifier] = STATE(2981),
    [sym_enum_specifier] = STATE(2981),
    [sym_struct_specifier] = STATE(2981),
    [sym_union_specifier] = STATE(2981),
    [sym_expression] = STATE(4423),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_type_descriptor] = STATE(6729),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_placeholder_type_specifier] = STATE(2981),
    [sym_decltype_auto] = STATE(2980),
    [sym_decltype] = STATE(2937),
    [sym_class_specifier] = STATE(2981),
    [sym__class_name] = STATE(7712),
    [sym_dependent_type] = STATE(2981),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_type_parameter_pack_expansion] = STATE(7380),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5560),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3667),
    [aux_sym__type_definition_type_repeat1] = STATE(3990),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(3750),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_signed] = ACTIONS(3762),
    [anon_sym_unsigned] = ACTIONS(3762),
    [anon_sym_long] = ACTIONS(3762),
    [anon_sym_short] = ACTIONS(3762),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3766),
    [anon_sym_class] = ACTIONS(3768),
    [anon_sym_struct] = ACTIONS(3770),
    [anon_sym_union] = ACTIONS(3772),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3796),
    [anon_sym_decltype] = ACTIONS(3798),
    [anon_sym_typename] = ACTIONS(3800),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(3802),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [964] = {
    [sym_type_qualifier] = STATE(3990),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4777),
    [sym_sized_type_specifier] = STATE(2981),
    [sym_enum_specifier] = STATE(2981),
    [sym_struct_specifier] = STATE(2981),
    [sym_union_specifier] = STATE(2981),
    [sym_expression] = STATE(4323),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_type_descriptor] = STATE(6749),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_placeholder_type_specifier] = STATE(2981),
    [sym_decltype_auto] = STATE(2980),
    [sym_decltype] = STATE(2937),
    [sym_class_specifier] = STATE(2981),
    [sym__class_name] = STATE(7712),
    [sym_dependent_type] = STATE(2981),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_type_parameter_pack_expansion] = STATE(7296),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5560),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3667),
    [aux_sym__type_definition_type_repeat1] = STATE(3990),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(3750),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_signed] = ACTIONS(3762),
    [anon_sym_unsigned] = ACTIONS(3762),
    [anon_sym_long] = ACTIONS(3762),
    [anon_sym_short] = ACTIONS(3762),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3766),
    [anon_sym_class] = ACTIONS(3768),
    [anon_sym_struct] = ACTIONS(3770),
    [anon_sym_union] = ACTIONS(3772),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3796),
    [anon_sym_decltype] = ACTIONS(3798),
    [anon_sym_typename] = ACTIONS(3800),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(3814),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [965] = {
    [sym_type_qualifier] = STATE(3990),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4777),
    [sym_sized_type_specifier] = STATE(2981),
    [sym_enum_specifier] = STATE(2981),
    [sym_struct_specifier] = STATE(2981),
    [sym_union_specifier] = STATE(2981),
    [sym_expression] = STATE(4327),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_type_descriptor] = STATE(6818),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_placeholder_type_specifier] = STATE(2981),
    [sym_decltype_auto] = STATE(2980),
    [sym_decltype] = STATE(2937),
    [sym_class_specifier] = STATE(2981),
    [sym__class_name] = STATE(7712),
    [sym_dependent_type] = STATE(2981),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_type_parameter_pack_expansion] = STATE(7238),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5560),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3667),
    [aux_sym__type_definition_type_repeat1] = STATE(3990),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(3750),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_signed] = ACTIONS(3762),
    [anon_sym_unsigned] = ACTIONS(3762),
    [anon_sym_long] = ACTIONS(3762),
    [anon_sym_short] = ACTIONS(3762),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3766),
    [anon_sym_class] = ACTIONS(3768),
    [anon_sym_struct] = ACTIONS(3770),
    [anon_sym_union] = ACTIONS(3772),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3796),
    [anon_sym_decltype] = ACTIONS(3798),
    [anon_sym_typename] = ACTIONS(3800),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(3816),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [966] = {
    [sym_type_qualifier] = STATE(3990),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4777),
    [sym_sized_type_specifier] = STATE(2981),
    [sym_enum_specifier] = STATE(2981),
    [sym_struct_specifier] = STATE(2981),
    [sym_union_specifier] = STATE(2981),
    [sym_expression] = STATE(4372),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_type_descriptor] = STATE(6881),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_placeholder_type_specifier] = STATE(2981),
    [sym_decltype_auto] = STATE(2980),
    [sym_decltype] = STATE(2937),
    [sym_class_specifier] = STATE(2981),
    [sym__class_name] = STATE(7712),
    [sym_dependent_type] = STATE(2981),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_type_parameter_pack_expansion] = STATE(7172),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5560),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3667),
    [aux_sym__type_definition_type_repeat1] = STATE(3990),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(3750),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_signed] = ACTIONS(3762),
    [anon_sym_unsigned] = ACTIONS(3762),
    [anon_sym_long] = ACTIONS(3762),
    [anon_sym_short] = ACTIONS(3762),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3766),
    [anon_sym_class] = ACTIONS(3768),
    [anon_sym_struct] = ACTIONS(3770),
    [anon_sym_union] = ACTIONS(3772),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3796),
    [anon_sym_decltype] = ACTIONS(3798),
    [anon_sym_typename] = ACTIONS(3800),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(3818),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [967] = {
    [sym_type_qualifier] = STATE(3990),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4777),
    [sym_sized_type_specifier] = STATE(2981),
    [sym_enum_specifier] = STATE(2981),
    [sym_struct_specifier] = STATE(2981),
    [sym_union_specifier] = STATE(2981),
    [sym_expression] = STATE(4325),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_type_descriptor] = STATE(6802),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_placeholder_type_specifier] = STATE(2981),
    [sym_decltype_auto] = STATE(2980),
    [sym_decltype] = STATE(2937),
    [sym_class_specifier] = STATE(2981),
    [sym__class_name] = STATE(7712),
    [sym_dependent_type] = STATE(2981),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_type_parameter_pack_expansion] = STATE(7263),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5560),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3667),
    [aux_sym__type_definition_type_repeat1] = STATE(3990),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(3750),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_signed] = ACTIONS(3762),
    [anon_sym_unsigned] = ACTIONS(3762),
    [anon_sym_long] = ACTIONS(3762),
    [anon_sym_short] = ACTIONS(3762),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3766),
    [anon_sym_class] = ACTIONS(3768),
    [anon_sym_struct] = ACTIONS(3770),
    [anon_sym_union] = ACTIONS(3772),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3796),
    [anon_sym_decltype] = ACTIONS(3798),
    [anon_sym_typename] = ACTIONS(3800),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(3820),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [968] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(1189),
    [sym_raw_string_literal] = STATE(2868),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2233),
    [sym_identifier] = ACTIONS(3822),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3826),
    [anon_sym_TILDE] = ACTIONS(3830),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3834),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3837),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3834),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(3840),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON] = ACTIONS(3843),
    [anon_sym_SEMI] = ACTIONS(3837),
    [anon_sym___extension__] = ACTIONS(3822),
    [anon_sym_in] = ACTIONS(3822),
    [anon_sym_out] = ACTIONS(3822),
    [anon_sym_inout] = ACTIONS(3822),
    [anon_sym_extern] = ACTIONS(3822),
    [anon_sym___attribute__] = ACTIONS(3822),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3845),
    [anon_sym___declspec] = ACTIONS(3822),
    [anon_sym___based] = ACTIONS(3822),
    [anon_sym___cdecl] = ACTIONS(3822),
    [anon_sym___clrcall] = ACTIONS(3822),
    [anon_sym___stdcall] = ACTIONS(3822),
    [anon_sym___fastcall] = ACTIONS(3822),
    [anon_sym___thiscall] = ACTIONS(3822),
    [anon_sym___vectorcall] = ACTIONS(3822),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_RBRACE] = ACTIONS(3824),
    [anon_sym_signed] = ACTIONS(3848),
    [anon_sym_unsigned] = ACTIONS(3848),
    [anon_sym_long] = ACTIONS(3848),
    [anon_sym_short] = ACTIONS(3848),
    [anon_sym_LBRACK] = ACTIONS(3850),
    [anon_sym_static] = ACTIONS(3822),
    [anon_sym_EQ] = ACTIONS(3854),
    [anon_sym_register] = ACTIONS(3822),
    [anon_sym_inline] = ACTIONS(3822),
    [anon_sym___inline] = ACTIONS(3822),
    [anon_sym___inline__] = ACTIONS(3822),
    [anon_sym___forceinline] = ACTIONS(3822),
    [anon_sym_thread_local] = ACTIONS(3822),
    [anon_sym___thread] = ACTIONS(3822),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3822),
    [anon_sym_volatile] = ACTIONS(3822),
    [anon_sym_restrict] = ACTIONS(3822),
    [anon_sym___restrict__] = ACTIONS(3822),
    [anon_sym__Atomic] = ACTIONS(3822),
    [anon_sym__Noreturn] = ACTIONS(3822),
    [anon_sym_noreturn] = ACTIONS(3822),
    [anon_sym_mutable] = ACTIONS(3822),
    [anon_sym_constinit] = ACTIONS(3822),
    [anon_sym_consteval] = ACTIONS(3822),
    [anon_sym_alignas] = ACTIONS(3822),
    [anon_sym__Alignas] = ACTIONS(3822),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3856),
    [anon_sym_SLASH_EQ] = ACTIONS(3856),
    [anon_sym_PERCENT_EQ] = ACTIONS(3856),
    [anon_sym_PLUS_EQ] = ACTIONS(3856),
    [anon_sym_DASH_EQ] = ACTIONS(3856),
    [anon_sym_LT_LT_EQ] = ACTIONS(3856),
    [anon_sym_GT_GT_EQ] = ACTIONS(3856),
    [anon_sym_AMP_EQ] = ACTIONS(3856),
    [anon_sym_CARET_EQ] = ACTIONS(3856),
    [anon_sym_PIPE_EQ] = ACTIONS(3856),
    [anon_sym_and_eq] = ACTIONS(3854),
    [anon_sym_or_eq] = ACTIONS(3854),
    [anon_sym_xor_eq] = ACTIONS(3854),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3832),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3832),
    [anon_sym_not_eq] = ACTIONS(3832),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3822),
    [anon_sym_decltype] = ACTIONS(3822),
    [sym_virtual] = ACTIONS(3822),
    [anon_sym_template] = ACTIONS(3822),
    [anon_sym_operator] = ACTIONS(3822),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_precise] = ACTIONS(3822),
    [anon_sym_shared] = ACTIONS(3822),
    [anon_sym_groupshared] = ACTIONS(3822),
    [anon_sym_uniform] = ACTIONS(3822),
    [anon_sym_row_major] = ACTIONS(3822),
    [anon_sym_column_major] = ACTIONS(3822),
    [anon_sym_globallycoherent] = ACTIONS(3822),
    [anon_sym_centroid] = ACTIONS(3822),
    [anon_sym_noperspective] = ACTIONS(3822),
    [anon_sym_nointerpolation] = ACTIONS(3822),
    [anon_sym_sample] = ACTIONS(3822),
    [anon_sym_linear] = ACTIONS(3822),
    [anon_sym_snorm] = ACTIONS(3822),
    [anon_sym_unorm] = ACTIONS(3822),
    [anon_sym_point] = ACTIONS(3822),
    [anon_sym_line] = ACTIONS(3822),
    [anon_sym_triangleadj] = ACTIONS(3822),
    [anon_sym_lineadj] = ACTIONS(3822),
    [anon_sym_triangle] = ACTIONS(3822),
  },
  [969] = {
    [sym_type_qualifier] = STATE(3990),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4777),
    [sym_sized_type_specifier] = STATE(2981),
    [sym_enum_specifier] = STATE(2981),
    [sym_struct_specifier] = STATE(2981),
    [sym_union_specifier] = STATE(2981),
    [sym_expression] = STATE(4408),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_type_descriptor] = STATE(6854),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_placeholder_type_specifier] = STATE(2981),
    [sym_decltype_auto] = STATE(2980),
    [sym_decltype] = STATE(2937),
    [sym_class_specifier] = STATE(2981),
    [sym__class_name] = STATE(7712),
    [sym_dependent_type] = STATE(2981),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_type_parameter_pack_expansion] = STATE(7202),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5560),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3667),
    [aux_sym__type_definition_type_repeat1] = STATE(3990),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(3750),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_signed] = ACTIONS(3762),
    [anon_sym_unsigned] = ACTIONS(3762),
    [anon_sym_long] = ACTIONS(3762),
    [anon_sym_short] = ACTIONS(3762),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3766),
    [anon_sym_class] = ACTIONS(3768),
    [anon_sym_struct] = ACTIONS(3770),
    [anon_sym_union] = ACTIONS(3772),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3796),
    [anon_sym_decltype] = ACTIONS(3798),
    [anon_sym_typename] = ACTIONS(3800),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(3862),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [970] = {
    [sym_type_qualifier] = STATE(3990),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4777),
    [sym_sized_type_specifier] = STATE(2981),
    [sym_enum_specifier] = STATE(2981),
    [sym_struct_specifier] = STATE(2981),
    [sym_union_specifier] = STATE(2981),
    [sym_expression] = STATE(4333),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_type_descriptor] = STATE(6840),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_placeholder_type_specifier] = STATE(2981),
    [sym_decltype_auto] = STATE(2980),
    [sym_decltype] = STATE(2937),
    [sym_class_specifier] = STATE(2981),
    [sym__class_name] = STATE(7712),
    [sym_dependent_type] = STATE(2981),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_type_parameter_pack_expansion] = STATE(7212),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5560),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3667),
    [aux_sym__type_definition_type_repeat1] = STATE(3990),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(3750),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_signed] = ACTIONS(3762),
    [anon_sym_unsigned] = ACTIONS(3762),
    [anon_sym_long] = ACTIONS(3762),
    [anon_sym_short] = ACTIONS(3762),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3766),
    [anon_sym_class] = ACTIONS(3768),
    [anon_sym_struct] = ACTIONS(3770),
    [anon_sym_union] = ACTIONS(3772),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3796),
    [anon_sym_decltype] = ACTIONS(3798),
    [anon_sym_typename] = ACTIONS(3800),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(3864),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [971] = {
    [sym_type_qualifier] = STATE(3990),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4777),
    [sym_sized_type_specifier] = STATE(2981),
    [sym_enum_specifier] = STATE(2981),
    [sym_struct_specifier] = STATE(2981),
    [sym_union_specifier] = STATE(2981),
    [sym_expression] = STATE(4425),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_type_descriptor] = STATE(6824),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_placeholder_type_specifier] = STATE(2981),
    [sym_decltype_auto] = STATE(2980),
    [sym_decltype] = STATE(2937),
    [sym_class_specifier] = STATE(2981),
    [sym__class_name] = STATE(7712),
    [sym_dependent_type] = STATE(2981),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_type_parameter_pack_expansion] = STATE(7396),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5560),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3667),
    [aux_sym__type_definition_type_repeat1] = STATE(3990),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(3750),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_signed] = ACTIONS(3762),
    [anon_sym_unsigned] = ACTIONS(3762),
    [anon_sym_long] = ACTIONS(3762),
    [anon_sym_short] = ACTIONS(3762),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3766),
    [anon_sym_class] = ACTIONS(3768),
    [anon_sym_struct] = ACTIONS(3770),
    [anon_sym_union] = ACTIONS(3772),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3796),
    [anon_sym_decltype] = ACTIONS(3798),
    [anon_sym_typename] = ACTIONS(3800),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(3866),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [972] = {
    [sym_type_qualifier] = STATE(3990),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4777),
    [sym_sized_type_specifier] = STATE(2981),
    [sym_enum_specifier] = STATE(2981),
    [sym_struct_specifier] = STATE(2981),
    [sym_union_specifier] = STATE(2981),
    [sym_expression] = STATE(4424),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_type_descriptor] = STATE(6815),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_placeholder_type_specifier] = STATE(2981),
    [sym_decltype_auto] = STATE(2980),
    [sym_decltype] = STATE(2937),
    [sym_class_specifier] = STATE(2981),
    [sym__class_name] = STATE(7712),
    [sym_dependent_type] = STATE(2981),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_type_parameter_pack_expansion] = STATE(7388),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5560),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3667),
    [aux_sym__type_definition_type_repeat1] = STATE(3990),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(3750),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_signed] = ACTIONS(3762),
    [anon_sym_unsigned] = ACTIONS(3762),
    [anon_sym_long] = ACTIONS(3762),
    [anon_sym_short] = ACTIONS(3762),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3766),
    [anon_sym_class] = ACTIONS(3768),
    [anon_sym_struct] = ACTIONS(3770),
    [anon_sym_union] = ACTIONS(3772),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3796),
    [anon_sym_decltype] = ACTIONS(3798),
    [anon_sym_typename] = ACTIONS(3800),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(3868),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [973] = {
    [sym_type_qualifier] = STATE(3990),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4777),
    [sym_sized_type_specifier] = STATE(2981),
    [sym_enum_specifier] = STATE(2981),
    [sym_struct_specifier] = STATE(2981),
    [sym_union_specifier] = STATE(2981),
    [sym_expression] = STATE(4338),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_type_descriptor] = STATE(6874),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_placeholder_type_specifier] = STATE(2981),
    [sym_decltype_auto] = STATE(2980),
    [sym_decltype] = STATE(2937),
    [sym_class_specifier] = STATE(2981),
    [sym__class_name] = STATE(7712),
    [sym_dependent_type] = STATE(2981),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_type_parameter_pack_expansion] = STATE(7177),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5560),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3667),
    [aux_sym__type_definition_type_repeat1] = STATE(3990),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(3750),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_signed] = ACTIONS(3762),
    [anon_sym_unsigned] = ACTIONS(3762),
    [anon_sym_long] = ACTIONS(3762),
    [anon_sym_short] = ACTIONS(3762),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3766),
    [anon_sym_class] = ACTIONS(3768),
    [anon_sym_struct] = ACTIONS(3770),
    [anon_sym_union] = ACTIONS(3772),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3796),
    [anon_sym_decltype] = ACTIONS(3798),
    [anon_sym_typename] = ACTIONS(3800),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(3870),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [974] = {
    [sym_type_qualifier] = STATE(3990),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4777),
    [sym_sized_type_specifier] = STATE(2981),
    [sym_enum_specifier] = STATE(2981),
    [sym_struct_specifier] = STATE(2981),
    [sym_union_specifier] = STATE(2981),
    [sym_expression] = STATE(4419),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_type_descriptor] = STATE(6733),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_placeholder_type_specifier] = STATE(2981),
    [sym_decltype_auto] = STATE(2980),
    [sym_decltype] = STATE(2937),
    [sym_class_specifier] = STATE(2981),
    [sym__class_name] = STATE(7712),
    [sym_dependent_type] = STATE(2981),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_type_parameter_pack_expansion] = STATE(7371),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5560),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3667),
    [aux_sym__type_definition_type_repeat1] = STATE(3990),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(3750),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_signed] = ACTIONS(3762),
    [anon_sym_unsigned] = ACTIONS(3762),
    [anon_sym_long] = ACTIONS(3762),
    [anon_sym_short] = ACTIONS(3762),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3766),
    [anon_sym_class] = ACTIONS(3768),
    [anon_sym_struct] = ACTIONS(3770),
    [anon_sym_union] = ACTIONS(3772),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3796),
    [anon_sym_decltype] = ACTIONS(3798),
    [anon_sym_typename] = ACTIONS(3800),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(3872),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [975] = {
    [sym_type_qualifier] = STATE(3990),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4777),
    [sym_sized_type_specifier] = STATE(2981),
    [sym_enum_specifier] = STATE(2981),
    [sym_struct_specifier] = STATE(2981),
    [sym_union_specifier] = STATE(2981),
    [sym_expression] = STATE(4340),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_type_descriptor] = STATE(6914),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_placeholder_type_specifier] = STATE(2981),
    [sym_decltype_auto] = STATE(2980),
    [sym_decltype] = STATE(2937),
    [sym_class_specifier] = STATE(2981),
    [sym__class_name] = STATE(7712),
    [sym_dependent_type] = STATE(2981),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_type_parameter_pack_expansion] = STATE(7419),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5560),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3667),
    [aux_sym__type_definition_type_repeat1] = STATE(3990),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(3750),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_signed] = ACTIONS(3762),
    [anon_sym_unsigned] = ACTIONS(3762),
    [anon_sym_long] = ACTIONS(3762),
    [anon_sym_short] = ACTIONS(3762),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3766),
    [anon_sym_class] = ACTIONS(3768),
    [anon_sym_struct] = ACTIONS(3770),
    [anon_sym_union] = ACTIONS(3772),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3796),
    [anon_sym_decltype] = ACTIONS(3798),
    [anon_sym_typename] = ACTIONS(3800),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(3874),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [976] = {
    [sym_type_qualifier] = STATE(3990),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4777),
    [sym_sized_type_specifier] = STATE(2981),
    [sym_enum_specifier] = STATE(2981),
    [sym_struct_specifier] = STATE(2981),
    [sym_union_specifier] = STATE(2981),
    [sym_expression] = STATE(4376),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_type_descriptor] = STATE(6780),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_placeholder_type_specifier] = STATE(2981),
    [sym_decltype_auto] = STATE(2980),
    [sym_decltype] = STATE(2937),
    [sym_class_specifier] = STATE(2981),
    [sym__class_name] = STATE(7712),
    [sym_dependent_type] = STATE(2981),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_type_parameter_pack_expansion] = STATE(7298),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5560),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3667),
    [aux_sym__type_definition_type_repeat1] = STATE(3990),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(3750),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_signed] = ACTIONS(3762),
    [anon_sym_unsigned] = ACTIONS(3762),
    [anon_sym_long] = ACTIONS(3762),
    [anon_sym_short] = ACTIONS(3762),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3766),
    [anon_sym_class] = ACTIONS(3768),
    [anon_sym_struct] = ACTIONS(3770),
    [anon_sym_union] = ACTIONS(3772),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3796),
    [anon_sym_decltype] = ACTIONS(3798),
    [anon_sym_typename] = ACTIONS(3800),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(3876),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [977] = {
    [sym_type_qualifier] = STATE(3990),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4777),
    [sym_sized_type_specifier] = STATE(2981),
    [sym_enum_specifier] = STATE(2981),
    [sym_struct_specifier] = STATE(2981),
    [sym_union_specifier] = STATE(2981),
    [sym_expression] = STATE(4342),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_type_descriptor] = STATE(6788),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_placeholder_type_specifier] = STATE(2981),
    [sym_decltype_auto] = STATE(2980),
    [sym_decltype] = STATE(2937),
    [sym_class_specifier] = STATE(2981),
    [sym__class_name] = STATE(7712),
    [sym_dependent_type] = STATE(2981),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_type_parameter_pack_expansion] = STATE(7285),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5560),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3667),
    [aux_sym__type_definition_type_repeat1] = STATE(3990),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(3750),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_signed] = ACTIONS(3762),
    [anon_sym_unsigned] = ACTIONS(3762),
    [anon_sym_long] = ACTIONS(3762),
    [anon_sym_short] = ACTIONS(3762),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3766),
    [anon_sym_class] = ACTIONS(3768),
    [anon_sym_struct] = ACTIONS(3770),
    [anon_sym_union] = ACTIONS(3772),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3796),
    [anon_sym_decltype] = ACTIONS(3798),
    [anon_sym_typename] = ACTIONS(3800),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(3878),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [978] = {
    [sym_type_qualifier] = STATE(3990),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4777),
    [sym_sized_type_specifier] = STATE(2981),
    [sym_enum_specifier] = STATE(2981),
    [sym_struct_specifier] = STATE(2981),
    [sym_union_specifier] = STATE(2981),
    [sym_expression] = STATE(4417),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_type_descriptor] = STATE(6750),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_placeholder_type_specifier] = STATE(2981),
    [sym_decltype_auto] = STATE(2980),
    [sym_decltype] = STATE(2937),
    [sym_class_specifier] = STATE(2981),
    [sym__class_name] = STATE(7712),
    [sym_dependent_type] = STATE(2981),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_type_parameter_pack_expansion] = STATE(7359),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5560),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3667),
    [aux_sym__type_definition_type_repeat1] = STATE(3990),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(3750),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_signed] = ACTIONS(3762),
    [anon_sym_unsigned] = ACTIONS(3762),
    [anon_sym_long] = ACTIONS(3762),
    [anon_sym_short] = ACTIONS(3762),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3766),
    [anon_sym_class] = ACTIONS(3768),
    [anon_sym_struct] = ACTIONS(3770),
    [anon_sym_union] = ACTIONS(3772),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3796),
    [anon_sym_decltype] = ACTIONS(3798),
    [anon_sym_typename] = ACTIONS(3800),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(3880),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [979] = {
    [sym_type_qualifier] = STATE(3990),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4777),
    [sym_sized_type_specifier] = STATE(2981),
    [sym_enum_specifier] = STATE(2981),
    [sym_struct_specifier] = STATE(2981),
    [sym_union_specifier] = STATE(2981),
    [sym_expression] = STATE(4391),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_type_descriptor] = STATE(6941),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_placeholder_type_specifier] = STATE(2981),
    [sym_decltype_auto] = STATE(2980),
    [sym_decltype] = STATE(2937),
    [sym_class_specifier] = STATE(2981),
    [sym__class_name] = STATE(7712),
    [sym_dependent_type] = STATE(2981),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_type_parameter_pack_expansion] = STATE(7114),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5560),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3667),
    [aux_sym__type_definition_type_repeat1] = STATE(3990),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(3750),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_signed] = ACTIONS(3762),
    [anon_sym_unsigned] = ACTIONS(3762),
    [anon_sym_long] = ACTIONS(3762),
    [anon_sym_short] = ACTIONS(3762),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3766),
    [anon_sym_class] = ACTIONS(3768),
    [anon_sym_struct] = ACTIONS(3770),
    [anon_sym_union] = ACTIONS(3772),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3796),
    [anon_sym_decltype] = ACTIONS(3798),
    [anon_sym_typename] = ACTIONS(3800),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(3882),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [980] = {
    [sym_type_qualifier] = STATE(3990),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4777),
    [sym_sized_type_specifier] = STATE(2981),
    [sym_enum_specifier] = STATE(2981),
    [sym_struct_specifier] = STATE(2981),
    [sym_union_specifier] = STATE(2981),
    [sym_expression] = STATE(4348),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_type_descriptor] = STATE(6950),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_placeholder_type_specifier] = STATE(2981),
    [sym_decltype_auto] = STATE(2980),
    [sym_decltype] = STATE(2937),
    [sym_class_specifier] = STATE(2981),
    [sym__class_name] = STATE(7712),
    [sym_dependent_type] = STATE(2981),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_type_parameter_pack_expansion] = STATE(7095),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5560),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3667),
    [aux_sym__type_definition_type_repeat1] = STATE(3990),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(3750),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_signed] = ACTIONS(3762),
    [anon_sym_unsigned] = ACTIONS(3762),
    [anon_sym_long] = ACTIONS(3762),
    [anon_sym_short] = ACTIONS(3762),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3766),
    [anon_sym_class] = ACTIONS(3768),
    [anon_sym_struct] = ACTIONS(3770),
    [anon_sym_union] = ACTIONS(3772),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3796),
    [anon_sym_decltype] = ACTIONS(3798),
    [anon_sym_typename] = ACTIONS(3800),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(3884),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [981] = {
    [sym_type_qualifier] = STATE(3990),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4777),
    [sym_sized_type_specifier] = STATE(2981),
    [sym_enum_specifier] = STATE(2981),
    [sym_struct_specifier] = STATE(2981),
    [sym_union_specifier] = STATE(2981),
    [sym_expression] = STATE(4321),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_type_descriptor] = STATE(6922),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_placeholder_type_specifier] = STATE(2981),
    [sym_decltype_auto] = STATE(2980),
    [sym_decltype] = STATE(2937),
    [sym_class_specifier] = STATE(2981),
    [sym__class_name] = STATE(7712),
    [sym_dependent_type] = STATE(2981),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_type_parameter_pack_expansion] = STATE(7415),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5560),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3667),
    [aux_sym__type_definition_type_repeat1] = STATE(3990),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(3750),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_signed] = ACTIONS(3762),
    [anon_sym_unsigned] = ACTIONS(3762),
    [anon_sym_long] = ACTIONS(3762),
    [anon_sym_short] = ACTIONS(3762),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3766),
    [anon_sym_class] = ACTIONS(3768),
    [anon_sym_struct] = ACTIONS(3770),
    [anon_sym_union] = ACTIONS(3772),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3796),
    [anon_sym_decltype] = ACTIONS(3798),
    [anon_sym_typename] = ACTIONS(3800),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(3886),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [982] = {
    [sym_type_qualifier] = STATE(3990),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4777),
    [sym_sized_type_specifier] = STATE(2981),
    [sym_enum_specifier] = STATE(2981),
    [sym_struct_specifier] = STATE(2981),
    [sym_union_specifier] = STATE(2981),
    [sym_expression] = STATE(4388),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_type_descriptor] = STATE(6776),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_placeholder_type_specifier] = STATE(2981),
    [sym_decltype_auto] = STATE(2980),
    [sym_decltype] = STATE(2937),
    [sym_class_specifier] = STATE(2981),
    [sym__class_name] = STATE(7712),
    [sym_dependent_type] = STATE(2981),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_type_parameter_pack_expansion] = STATE(7306),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5560),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3667),
    [aux_sym__type_definition_type_repeat1] = STATE(3990),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(3750),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_signed] = ACTIONS(3762),
    [anon_sym_unsigned] = ACTIONS(3762),
    [anon_sym_long] = ACTIONS(3762),
    [anon_sym_short] = ACTIONS(3762),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3766),
    [anon_sym_class] = ACTIONS(3768),
    [anon_sym_struct] = ACTIONS(3770),
    [anon_sym_union] = ACTIONS(3772),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3796),
    [anon_sym_decltype] = ACTIONS(3798),
    [anon_sym_typename] = ACTIONS(3800),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(3888),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [983] = {
    [sym_type_qualifier] = STATE(3990),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4777),
    [sym_sized_type_specifier] = STATE(2981),
    [sym_enum_specifier] = STATE(2981),
    [sym_struct_specifier] = STATE(2981),
    [sym_union_specifier] = STATE(2981),
    [sym_expression] = STATE(4409),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_type_descriptor] = STATE(6758),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_placeholder_type_specifier] = STATE(2981),
    [sym_decltype_auto] = STATE(2980),
    [sym_decltype] = STATE(2937),
    [sym_class_specifier] = STATE(2981),
    [sym__class_name] = STATE(7712),
    [sym_dependent_type] = STATE(2981),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_type_parameter_pack_expansion] = STATE(7343),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5560),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3667),
    [aux_sym__type_definition_type_repeat1] = STATE(3990),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(3750),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_signed] = ACTIONS(3762),
    [anon_sym_unsigned] = ACTIONS(3762),
    [anon_sym_long] = ACTIONS(3762),
    [anon_sym_short] = ACTIONS(3762),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3766),
    [anon_sym_class] = ACTIONS(3768),
    [anon_sym_struct] = ACTIONS(3770),
    [anon_sym_union] = ACTIONS(3772),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3796),
    [anon_sym_decltype] = ACTIONS(3798),
    [anon_sym_typename] = ACTIONS(3800),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(3890),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [984] = {
    [sym_type_qualifier] = STATE(3990),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4777),
    [sym_sized_type_specifier] = STATE(2981),
    [sym_enum_specifier] = STATE(2981),
    [sym_struct_specifier] = STATE(2981),
    [sym_union_specifier] = STATE(2981),
    [sym_expression] = STATE(4422),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_type_descriptor] = STATE(7000),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_placeholder_type_specifier] = STATE(2981),
    [sym_decltype_auto] = STATE(2980),
    [sym_decltype] = STATE(2937),
    [sym_class_specifier] = STATE(2981),
    [sym__class_name] = STATE(7712),
    [sym_dependent_type] = STATE(2981),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_type_parameter_pack_expansion] = STATE(7037),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5560),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3667),
    [aux_sym__type_definition_type_repeat1] = STATE(3990),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(3750),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_signed] = ACTIONS(3762),
    [anon_sym_unsigned] = ACTIONS(3762),
    [anon_sym_long] = ACTIONS(3762),
    [anon_sym_short] = ACTIONS(3762),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3766),
    [anon_sym_class] = ACTIONS(3768),
    [anon_sym_struct] = ACTIONS(3770),
    [anon_sym_union] = ACTIONS(3772),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3796),
    [anon_sym_decltype] = ACTIONS(3798),
    [anon_sym_typename] = ACTIONS(3800),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(3892),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [985] = {
    [sym_type_qualifier] = STATE(3990),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4777),
    [sym_sized_type_specifier] = STATE(2981),
    [sym_enum_specifier] = STATE(2981),
    [sym_struct_specifier] = STATE(2981),
    [sym_union_specifier] = STATE(2981),
    [sym_expression] = STATE(4397),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_type_descriptor] = STATE(6769),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_placeholder_type_specifier] = STATE(2981),
    [sym_decltype_auto] = STATE(2980),
    [sym_decltype] = STATE(2937),
    [sym_class_specifier] = STATE(2981),
    [sym__class_name] = STATE(7712),
    [sym_dependent_type] = STATE(2981),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_type_parameter_pack_expansion] = STATE(7325),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5560),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3667),
    [aux_sym__type_definition_type_repeat1] = STATE(3990),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(3750),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_signed] = ACTIONS(3762),
    [anon_sym_unsigned] = ACTIONS(3762),
    [anon_sym_long] = ACTIONS(3762),
    [anon_sym_short] = ACTIONS(3762),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3766),
    [anon_sym_class] = ACTIONS(3768),
    [anon_sym_struct] = ACTIONS(3770),
    [anon_sym_union] = ACTIONS(3772),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3796),
    [anon_sym_decltype] = ACTIONS(3798),
    [anon_sym_typename] = ACTIONS(3800),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(3894),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [986] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(1189),
    [sym_raw_string_literal] = STATE(2868),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2233),
    [sym_identifier] = ACTIONS(3822),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3826),
    [anon_sym_TILDE] = ACTIONS(3830),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3834),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3837),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3834),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(3840),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON] = ACTIONS(3896),
    [anon_sym_SEMI] = ACTIONS(3837),
    [anon_sym___extension__] = ACTIONS(3822),
    [anon_sym_in] = ACTIONS(3822),
    [anon_sym_out] = ACTIONS(3822),
    [anon_sym_inout] = ACTIONS(3822),
    [anon_sym_extern] = ACTIONS(3822),
    [anon_sym___attribute__] = ACTIONS(3822),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3845),
    [anon_sym___declspec] = ACTIONS(3822),
    [anon_sym___based] = ACTIONS(3822),
    [anon_sym___cdecl] = ACTIONS(3822),
    [anon_sym___clrcall] = ACTIONS(3822),
    [anon_sym___stdcall] = ACTIONS(3822),
    [anon_sym___fastcall] = ACTIONS(3822),
    [anon_sym___thiscall] = ACTIONS(3822),
    [anon_sym___vectorcall] = ACTIONS(3822),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_signed] = ACTIONS(3848),
    [anon_sym_unsigned] = ACTIONS(3848),
    [anon_sym_long] = ACTIONS(3848),
    [anon_sym_short] = ACTIONS(3848),
    [anon_sym_LBRACK] = ACTIONS(3850),
    [anon_sym_static] = ACTIONS(3822),
    [anon_sym_EQ] = ACTIONS(3854),
    [anon_sym_register] = ACTIONS(3822),
    [anon_sym_inline] = ACTIONS(3822),
    [anon_sym___inline] = ACTIONS(3822),
    [anon_sym___inline__] = ACTIONS(3822),
    [anon_sym___forceinline] = ACTIONS(3822),
    [anon_sym_thread_local] = ACTIONS(3822),
    [anon_sym___thread] = ACTIONS(3822),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3822),
    [anon_sym_volatile] = ACTIONS(3822),
    [anon_sym_restrict] = ACTIONS(3822),
    [anon_sym___restrict__] = ACTIONS(3822),
    [anon_sym__Atomic] = ACTIONS(3822),
    [anon_sym__Noreturn] = ACTIONS(3822),
    [anon_sym_noreturn] = ACTIONS(3822),
    [anon_sym_mutable] = ACTIONS(3822),
    [anon_sym_constinit] = ACTIONS(3822),
    [anon_sym_consteval] = ACTIONS(3822),
    [anon_sym_alignas] = ACTIONS(3822),
    [anon_sym__Alignas] = ACTIONS(3822),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3856),
    [anon_sym_SLASH_EQ] = ACTIONS(3856),
    [anon_sym_PERCENT_EQ] = ACTIONS(3856),
    [anon_sym_PLUS_EQ] = ACTIONS(3856),
    [anon_sym_DASH_EQ] = ACTIONS(3856),
    [anon_sym_LT_LT_EQ] = ACTIONS(3856),
    [anon_sym_GT_GT_EQ] = ACTIONS(3856),
    [anon_sym_AMP_EQ] = ACTIONS(3856),
    [anon_sym_CARET_EQ] = ACTIONS(3856),
    [anon_sym_PIPE_EQ] = ACTIONS(3856),
    [anon_sym_and_eq] = ACTIONS(3854),
    [anon_sym_or_eq] = ACTIONS(3854),
    [anon_sym_xor_eq] = ACTIONS(3854),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3832),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3832),
    [anon_sym_not_eq] = ACTIONS(3832),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3822),
    [anon_sym_decltype] = ACTIONS(3822),
    [sym_virtual] = ACTIONS(3822),
    [anon_sym_template] = ACTIONS(3822),
    [anon_sym_operator] = ACTIONS(3822),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_precise] = ACTIONS(3822),
    [anon_sym_shared] = ACTIONS(3822),
    [anon_sym_groupshared] = ACTIONS(3822),
    [anon_sym_uniform] = ACTIONS(3822),
    [anon_sym_row_major] = ACTIONS(3822),
    [anon_sym_column_major] = ACTIONS(3822),
    [anon_sym_globallycoherent] = ACTIONS(3822),
    [anon_sym_centroid] = ACTIONS(3822),
    [anon_sym_noperspective] = ACTIONS(3822),
    [anon_sym_nointerpolation] = ACTIONS(3822),
    [anon_sym_sample] = ACTIONS(3822),
    [anon_sym_linear] = ACTIONS(3822),
    [anon_sym_snorm] = ACTIONS(3822),
    [anon_sym_unorm] = ACTIONS(3822),
    [anon_sym_point] = ACTIONS(3822),
    [anon_sym_line] = ACTIONS(3822),
    [anon_sym_triangleadj] = ACTIONS(3822),
    [anon_sym_lineadj] = ACTIONS(3822),
    [anon_sym_triangle] = ACTIONS(3822),
  },
  [987] = {
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_unaligned_ptr_modifier] = STATE(4205),
    [sym_ms_pointer_modifier] = STATE(3203),
    [sym__declarator] = STATE(6320),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6270),
    [sym_array_declarator] = STATE(6270),
    [sym_type_qualifier] = STATE(4050),
    [sym_alignas_qualifier] = STATE(4472),
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3391),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5624),
    [sym_qualified_identifier] = STATE(3390),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(2790),
    [aux_sym__type_definition_type_repeat1] = STATE(4050),
    [aux_sym_pointer_declarator_repeat1] = STATE(3203),
    [sym_identifier] = ACTIONS(3898),
    [anon_sym_LPAREN2] = ACTIONS(3900),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3902),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym___based] = ACTIONS(49),
    [sym_ms_restrict_modifier] = ACTIONS(3906),
    [sym_ms_unsigned_ptr_modifier] = ACTIONS(3906),
    [sym_ms_signed_ptr_modifier] = ACTIONS(3906),
    [anon_sym__unaligned] = ACTIONS(3908),
    [anon_sym___unaligned] = ACTIONS(3908),
    [anon_sym_LBRACK] = ACTIONS(2038),
    [anon_sym_const] = ACTIONS(3904),
    [anon_sym_constexpr] = ACTIONS(3904),
    [anon_sym_volatile] = ACTIONS(3904),
    [anon_sym_restrict] = ACTIONS(3904),
    [anon_sym___restrict__] = ACTIONS(3904),
    [anon_sym__Atomic] = ACTIONS(3904),
    [anon_sym__Noreturn] = ACTIONS(3904),
    [anon_sym_noreturn] = ACTIONS(3904),
    [anon_sym_mutable] = ACTIONS(3904),
    [anon_sym_constinit] = ACTIONS(3904),
    [anon_sym_consteval] = ACTIONS(3904),
    [anon_sym_alignas] = ACTIONS(3910),
    [anon_sym__Alignas] = ACTIONS(3910),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(2078),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [988] = {
    [sym_else_clause] = STATE(1021),
    [sym_identifier] = ACTIONS(1994),
    [anon_sym_LPAREN2] = ACTIONS(1996),
    [anon_sym_BANG] = ACTIONS(1996),
    [anon_sym_TILDE] = ACTIONS(1996),
    [anon_sym_DASH] = ACTIONS(1994),
    [anon_sym_PLUS] = ACTIONS(1994),
    [anon_sym_STAR] = ACTIONS(1996),
    [anon_sym_AMP] = ACTIONS(1996),
    [anon_sym_SEMI] = ACTIONS(1996),
    [anon_sym___extension__] = ACTIONS(1994),
    [anon_sym_typedef] = ACTIONS(1994),
    [anon_sym_in] = ACTIONS(1994),
    [anon_sym_out] = ACTIONS(1994),
    [anon_sym_inout] = ACTIONS(1994),
    [anon_sym_extern] = ACTIONS(1994),
    [anon_sym___attribute__] = ACTIONS(1994),
    [anon_sym_COLON_COLON] = ACTIONS(1996),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1996),
    [anon_sym___declspec] = ACTIONS(1994),
    [anon_sym_LBRACE] = ACTIONS(1996),
    [anon_sym_signed] = ACTIONS(1994),
    [anon_sym_unsigned] = ACTIONS(1994),
    [anon_sym_long] = ACTIONS(1994),
    [anon_sym_short] = ACTIONS(1994),
    [anon_sym_LBRACK] = ACTIONS(1994),
    [anon_sym_static] = ACTIONS(1994),
    [anon_sym_register] = ACTIONS(1994),
    [anon_sym_inline] = ACTIONS(1994),
    [anon_sym___inline] = ACTIONS(1994),
    [anon_sym___inline__] = ACTIONS(1994),
    [anon_sym___forceinline] = ACTIONS(1994),
    [anon_sym_thread_local] = ACTIONS(1994),
    [anon_sym___thread] = ACTIONS(1994),
    [anon_sym_const] = ACTIONS(1994),
    [anon_sym_constexpr] = ACTIONS(1994),
    [anon_sym_volatile] = ACTIONS(1994),
    [anon_sym_restrict] = ACTIONS(1994),
    [anon_sym___restrict__] = ACTIONS(1994),
    [anon_sym__Atomic] = ACTIONS(1994),
    [anon_sym__Noreturn] = ACTIONS(1994),
    [anon_sym_noreturn] = ACTIONS(1994),
    [anon_sym_mutable] = ACTIONS(1994),
    [anon_sym_constinit] = ACTIONS(1994),
    [anon_sym_consteval] = ACTIONS(1994),
    [anon_sym_alignas] = ACTIONS(1994),
    [anon_sym__Alignas] = ACTIONS(1994),
    [sym_primitive_type] = ACTIONS(1994),
    [anon_sym_enum] = ACTIONS(1994),
    [anon_sym_class] = ACTIONS(1994),
    [anon_sym_struct] = ACTIONS(1994),
    [anon_sym_union] = ACTIONS(1994),
    [anon_sym_if] = ACTIONS(1994),
    [anon_sym_else] = ACTIONS(3914),
    [anon_sym_switch] = ACTIONS(1994),
    [anon_sym_while] = ACTIONS(1994),
    [anon_sym_do] = ACTIONS(1994),
    [anon_sym_for] = ACTIONS(1994),
    [anon_sym_return] = ACTIONS(1994),
    [anon_sym_break] = ACTIONS(1994),
    [anon_sym_continue] = ACTIONS(1994),
    [anon_sym_goto] = ACTIONS(1994),
    [anon_sym___try] = ACTIONS(1994),
    [anon_sym___leave] = ACTIONS(1994),
    [anon_sym_not] = ACTIONS(1994),
    [anon_sym_compl] = ACTIONS(1994),
    [anon_sym_DASH_DASH] = ACTIONS(1996),
    [anon_sym_PLUS_PLUS] = ACTIONS(1996),
    [anon_sym_sizeof] = ACTIONS(1994),
    [anon_sym___alignof__] = ACTIONS(1994),
    [anon_sym___alignof] = ACTIONS(1994),
    [anon_sym__alignof] = ACTIONS(1994),
    [anon_sym_alignof] = ACTIONS(1994),
    [anon_sym__Alignof] = ACTIONS(1994),
    [anon_sym_offsetof] = ACTIONS(1994),
    [anon_sym__Generic] = ACTIONS(1994),
    [anon_sym_asm] = ACTIONS(1994),
    [anon_sym___asm__] = ACTIONS(1994),
    [sym_number_literal] = ACTIONS(1996),
    [anon_sym_L_SQUOTE] = ACTIONS(1996),
    [anon_sym_u_SQUOTE] = ACTIONS(1996),
    [anon_sym_U_SQUOTE] = ACTIONS(1996),
    [anon_sym_u8_SQUOTE] = ACTIONS(1996),
    [anon_sym_SQUOTE] = ACTIONS(1996),
    [anon_sym_L_DQUOTE] = ACTIONS(1996),
    [anon_sym_u_DQUOTE] = ACTIONS(1996),
    [anon_sym_U_DQUOTE] = ACTIONS(1996),
    [anon_sym_u8_DQUOTE] = ACTIONS(1996),
    [anon_sym_DQUOTE] = ACTIONS(1996),
    [sym_true] = ACTIONS(1994),
    [sym_false] = ACTIONS(1994),
    [anon_sym_NULL] = ACTIONS(1994),
    [anon_sym_nullptr] = ACTIONS(1994),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1994),
    [anon_sym_decltype] = ACTIONS(1994),
    [sym_virtual] = ACTIONS(1994),
    [anon_sym_typename] = ACTIONS(1994),
    [anon_sym_template] = ACTIONS(1994),
    [anon_sym_try] = ACTIONS(1994),
    [anon_sym_delete] = ACTIONS(1994),
    [anon_sym_throw] = ACTIONS(1994),
    [anon_sym_co_return] = ACTIONS(1994),
    [anon_sym_co_yield] = ACTIONS(1994),
    [anon_sym_R_DQUOTE] = ACTIONS(1996),
    [anon_sym_LR_DQUOTE] = ACTIONS(1996),
    [anon_sym_uR_DQUOTE] = ACTIONS(1996),
    [anon_sym_UR_DQUOTE] = ACTIONS(1996),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1996),
    [anon_sym_co_await] = ACTIONS(1994),
    [anon_sym_new] = ACTIONS(1994),
    [anon_sym_requires] = ACTIONS(1994),
    [sym_this] = ACTIONS(1994),
    [anon_sym_discard] = ACTIONS(1994),
    [anon_sym_precise] = ACTIONS(1994),
    [anon_sym_shared] = ACTIONS(1994),
    [anon_sym_groupshared] = ACTIONS(1994),
    [anon_sym_uniform] = ACTIONS(1994),
    [anon_sym_row_major] = ACTIONS(1994),
    [anon_sym_column_major] = ACTIONS(1994),
    [anon_sym_globallycoherent] = ACTIONS(1994),
    [anon_sym_centroid] = ACTIONS(1994),
    [anon_sym_noperspective] = ACTIONS(1994),
    [anon_sym_nointerpolation] = ACTIONS(1994),
    [anon_sym_sample] = ACTIONS(1994),
    [anon_sym_linear] = ACTIONS(1994),
    [anon_sym_snorm] = ACTIONS(1994),
    [anon_sym_unorm] = ACTIONS(1994),
    [anon_sym_point] = ACTIONS(1994),
    [anon_sym_line] = ACTIONS(1994),
    [anon_sym_triangleadj] = ACTIONS(1994),
    [anon_sym_lineadj] = ACTIONS(1994),
    [anon_sym_triangle] = ACTIONS(1994),
    [anon_sym_cbuffer] = ACTIONS(1994),
  },
  [989] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(1189),
    [sym_raw_string_literal] = STATE(2868),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2233),
    [sym_identifier] = ACTIONS(3822),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3826),
    [anon_sym_TILDE] = ACTIONS(3830),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3834),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3837),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3834),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(3840),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON] = ACTIONS(3916),
    [anon_sym_SEMI] = ACTIONS(3837),
    [anon_sym___extension__] = ACTIONS(3822),
    [anon_sym_in] = ACTIONS(3822),
    [anon_sym_out] = ACTIONS(3822),
    [anon_sym_inout] = ACTIONS(3822),
    [anon_sym_extern] = ACTIONS(3822),
    [anon_sym___attribute__] = ACTIONS(3822),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3845),
    [anon_sym___declspec] = ACTIONS(3822),
    [anon_sym___based] = ACTIONS(3822),
    [anon_sym___cdecl] = ACTIONS(3822),
    [anon_sym___clrcall] = ACTIONS(3822),
    [anon_sym___stdcall] = ACTIONS(3822),
    [anon_sym___fastcall] = ACTIONS(3822),
    [anon_sym___thiscall] = ACTIONS(3822),
    [anon_sym___vectorcall] = ACTIONS(3822),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_signed] = ACTIONS(3848),
    [anon_sym_unsigned] = ACTIONS(3848),
    [anon_sym_long] = ACTIONS(3848),
    [anon_sym_short] = ACTIONS(3848),
    [anon_sym_LBRACK] = ACTIONS(3850),
    [anon_sym_static] = ACTIONS(3822),
    [anon_sym_EQ] = ACTIONS(3854),
    [anon_sym_register] = ACTIONS(3822),
    [anon_sym_inline] = ACTIONS(3822),
    [anon_sym___inline] = ACTIONS(3822),
    [anon_sym___inline__] = ACTIONS(3822),
    [anon_sym___forceinline] = ACTIONS(3822),
    [anon_sym_thread_local] = ACTIONS(3822),
    [anon_sym___thread] = ACTIONS(3822),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3822),
    [anon_sym_volatile] = ACTIONS(3822),
    [anon_sym_restrict] = ACTIONS(3822),
    [anon_sym___restrict__] = ACTIONS(3822),
    [anon_sym__Atomic] = ACTIONS(3822),
    [anon_sym__Noreturn] = ACTIONS(3822),
    [anon_sym_noreturn] = ACTIONS(3822),
    [anon_sym_mutable] = ACTIONS(3822),
    [anon_sym_constinit] = ACTIONS(3822),
    [anon_sym_consteval] = ACTIONS(3822),
    [anon_sym_alignas] = ACTIONS(3822),
    [anon_sym__Alignas] = ACTIONS(3822),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3856),
    [anon_sym_SLASH_EQ] = ACTIONS(3856),
    [anon_sym_PERCENT_EQ] = ACTIONS(3856),
    [anon_sym_PLUS_EQ] = ACTIONS(3856),
    [anon_sym_DASH_EQ] = ACTIONS(3856),
    [anon_sym_LT_LT_EQ] = ACTIONS(3856),
    [anon_sym_GT_GT_EQ] = ACTIONS(3856),
    [anon_sym_AMP_EQ] = ACTIONS(3856),
    [anon_sym_CARET_EQ] = ACTIONS(3856),
    [anon_sym_PIPE_EQ] = ACTIONS(3856),
    [anon_sym_and_eq] = ACTIONS(3854),
    [anon_sym_or_eq] = ACTIONS(3854),
    [anon_sym_xor_eq] = ACTIONS(3854),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3832),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3832),
    [anon_sym_not_eq] = ACTIONS(3832),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3822),
    [anon_sym_decltype] = ACTIONS(3822),
    [sym_virtual] = ACTIONS(3822),
    [anon_sym_template] = ACTIONS(3822),
    [anon_sym_operator] = ACTIONS(3822),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_precise] = ACTIONS(3822),
    [anon_sym_shared] = ACTIONS(3822),
    [anon_sym_groupshared] = ACTIONS(3822),
    [anon_sym_uniform] = ACTIONS(3822),
    [anon_sym_row_major] = ACTIONS(3822),
    [anon_sym_column_major] = ACTIONS(3822),
    [anon_sym_globallycoherent] = ACTIONS(3822),
    [anon_sym_centroid] = ACTIONS(3822),
    [anon_sym_noperspective] = ACTIONS(3822),
    [anon_sym_nointerpolation] = ACTIONS(3822),
    [anon_sym_sample] = ACTIONS(3822),
    [anon_sym_linear] = ACTIONS(3822),
    [anon_sym_snorm] = ACTIONS(3822),
    [anon_sym_unorm] = ACTIONS(3822),
    [anon_sym_point] = ACTIONS(3822),
    [anon_sym_line] = ACTIONS(3822),
    [anon_sym_triangleadj] = ACTIONS(3822),
    [anon_sym_lineadj] = ACTIONS(3822),
    [anon_sym_triangle] = ACTIONS(3822),
  },
  [990] = {
    [sym_else_clause] = STATE(1042),
    [sym_identifier] = ACTIONS(2008),
    [anon_sym_LPAREN2] = ACTIONS(2010),
    [anon_sym_BANG] = ACTIONS(2010),
    [anon_sym_TILDE] = ACTIONS(2010),
    [anon_sym_DASH] = ACTIONS(2008),
    [anon_sym_PLUS] = ACTIONS(2008),
    [anon_sym_STAR] = ACTIONS(2010),
    [anon_sym_AMP] = ACTIONS(2010),
    [anon_sym_SEMI] = ACTIONS(2010),
    [anon_sym___extension__] = ACTIONS(2008),
    [anon_sym_typedef] = ACTIONS(2008),
    [anon_sym_in] = ACTIONS(2008),
    [anon_sym_out] = ACTIONS(2008),
    [anon_sym_inout] = ACTIONS(2008),
    [anon_sym_extern] = ACTIONS(2008),
    [anon_sym___attribute__] = ACTIONS(2008),
    [anon_sym_COLON_COLON] = ACTIONS(2010),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2010),
    [anon_sym___declspec] = ACTIONS(2008),
    [anon_sym_LBRACE] = ACTIONS(2010),
    [anon_sym_signed] = ACTIONS(2008),
    [anon_sym_unsigned] = ACTIONS(2008),
    [anon_sym_long] = ACTIONS(2008),
    [anon_sym_short] = ACTIONS(2008),
    [anon_sym_LBRACK] = ACTIONS(2008),
    [anon_sym_static] = ACTIONS(2008),
    [anon_sym_register] = ACTIONS(2008),
    [anon_sym_inline] = ACTIONS(2008),
    [anon_sym___inline] = ACTIONS(2008),
    [anon_sym___inline__] = ACTIONS(2008),
    [anon_sym___forceinline] = ACTIONS(2008),
    [anon_sym_thread_local] = ACTIONS(2008),
    [anon_sym___thread] = ACTIONS(2008),
    [anon_sym_const] = ACTIONS(2008),
    [anon_sym_constexpr] = ACTIONS(2008),
    [anon_sym_volatile] = ACTIONS(2008),
    [anon_sym_restrict] = ACTIONS(2008),
    [anon_sym___restrict__] = ACTIONS(2008),
    [anon_sym__Atomic] = ACTIONS(2008),
    [anon_sym__Noreturn] = ACTIONS(2008),
    [anon_sym_noreturn] = ACTIONS(2008),
    [anon_sym_mutable] = ACTIONS(2008),
    [anon_sym_constinit] = ACTIONS(2008),
    [anon_sym_consteval] = ACTIONS(2008),
    [anon_sym_alignas] = ACTIONS(2008),
    [anon_sym__Alignas] = ACTIONS(2008),
    [sym_primitive_type] = ACTIONS(2008),
    [anon_sym_enum] = ACTIONS(2008),
    [anon_sym_class] = ACTIONS(2008),
    [anon_sym_struct] = ACTIONS(2008),
    [anon_sym_union] = ACTIONS(2008),
    [anon_sym_if] = ACTIONS(2008),
    [anon_sym_else] = ACTIONS(3914),
    [anon_sym_switch] = ACTIONS(2008),
    [anon_sym_while] = ACTIONS(2008),
    [anon_sym_do] = ACTIONS(2008),
    [anon_sym_for] = ACTIONS(2008),
    [anon_sym_return] = ACTIONS(2008),
    [anon_sym_break] = ACTIONS(2008),
    [anon_sym_continue] = ACTIONS(2008),
    [anon_sym_goto] = ACTIONS(2008),
    [anon_sym___try] = ACTIONS(2008),
    [anon_sym___leave] = ACTIONS(2008),
    [anon_sym_not] = ACTIONS(2008),
    [anon_sym_compl] = ACTIONS(2008),
    [anon_sym_DASH_DASH] = ACTIONS(2010),
    [anon_sym_PLUS_PLUS] = ACTIONS(2010),
    [anon_sym_sizeof] = ACTIONS(2008),
    [anon_sym___alignof__] = ACTIONS(2008),
    [anon_sym___alignof] = ACTIONS(2008),
    [anon_sym__alignof] = ACTIONS(2008),
    [anon_sym_alignof] = ACTIONS(2008),
    [anon_sym__Alignof] = ACTIONS(2008),
    [anon_sym_offsetof] = ACTIONS(2008),
    [anon_sym__Generic] = ACTIONS(2008),
    [anon_sym_asm] = ACTIONS(2008),
    [anon_sym___asm__] = ACTIONS(2008),
    [sym_number_literal] = ACTIONS(2010),
    [anon_sym_L_SQUOTE] = ACTIONS(2010),
    [anon_sym_u_SQUOTE] = ACTIONS(2010),
    [anon_sym_U_SQUOTE] = ACTIONS(2010),
    [anon_sym_u8_SQUOTE] = ACTIONS(2010),
    [anon_sym_SQUOTE] = ACTIONS(2010),
    [anon_sym_L_DQUOTE] = ACTIONS(2010),
    [anon_sym_u_DQUOTE] = ACTIONS(2010),
    [anon_sym_U_DQUOTE] = ACTIONS(2010),
    [anon_sym_u8_DQUOTE] = ACTIONS(2010),
    [anon_sym_DQUOTE] = ACTIONS(2010),
    [sym_true] = ACTIONS(2008),
    [sym_false] = ACTIONS(2008),
    [anon_sym_NULL] = ACTIONS(2008),
    [anon_sym_nullptr] = ACTIONS(2008),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2008),
    [anon_sym_decltype] = ACTIONS(2008),
    [sym_virtual] = ACTIONS(2008),
    [anon_sym_typename] = ACTIONS(2008),
    [anon_sym_template] = ACTIONS(2008),
    [anon_sym_try] = ACTIONS(2008),
    [anon_sym_delete] = ACTIONS(2008),
    [anon_sym_throw] = ACTIONS(2008),
    [anon_sym_co_return] = ACTIONS(2008),
    [anon_sym_co_yield] = ACTIONS(2008),
    [anon_sym_R_DQUOTE] = ACTIONS(2010),
    [anon_sym_LR_DQUOTE] = ACTIONS(2010),
    [anon_sym_uR_DQUOTE] = ACTIONS(2010),
    [anon_sym_UR_DQUOTE] = ACTIONS(2010),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2010),
    [anon_sym_co_await] = ACTIONS(2008),
    [anon_sym_new] = ACTIONS(2008),
    [anon_sym_requires] = ACTIONS(2008),
    [sym_this] = ACTIONS(2008),
    [anon_sym_discard] = ACTIONS(2008),
    [anon_sym_precise] = ACTIONS(2008),
    [anon_sym_shared] = ACTIONS(2008),
    [anon_sym_groupshared] = ACTIONS(2008),
    [anon_sym_uniform] = ACTIONS(2008),
    [anon_sym_row_major] = ACTIONS(2008),
    [anon_sym_column_major] = ACTIONS(2008),
    [anon_sym_globallycoherent] = ACTIONS(2008),
    [anon_sym_centroid] = ACTIONS(2008),
    [anon_sym_noperspective] = ACTIONS(2008),
    [anon_sym_nointerpolation] = ACTIONS(2008),
    [anon_sym_sample] = ACTIONS(2008),
    [anon_sym_linear] = ACTIONS(2008),
    [anon_sym_snorm] = ACTIONS(2008),
    [anon_sym_unorm] = ACTIONS(2008),
    [anon_sym_point] = ACTIONS(2008),
    [anon_sym_line] = ACTIONS(2008),
    [anon_sym_triangleadj] = ACTIONS(2008),
    [anon_sym_lineadj] = ACTIONS(2008),
    [anon_sym_triangle] = ACTIONS(2008),
    [anon_sym_cbuffer] = ACTIONS(2008),
  },
  [991] = {
    [sym_identifier] = ACTIONS(2012),
    [anon_sym_LPAREN2] = ACTIONS(2014),
    [anon_sym_BANG] = ACTIONS(2014),
    [anon_sym_TILDE] = ACTIONS(2014),
    [anon_sym_DASH] = ACTIONS(2012),
    [anon_sym_PLUS] = ACTIONS(2012),
    [anon_sym_STAR] = ACTIONS(2014),
    [anon_sym_AMP] = ACTIONS(2014),
    [anon_sym_SEMI] = ACTIONS(2014),
    [anon_sym___extension__] = ACTIONS(2012),
    [anon_sym_typedef] = ACTIONS(2012),
    [anon_sym_in] = ACTIONS(2012),
    [anon_sym_out] = ACTIONS(2012),
    [anon_sym_inout] = ACTIONS(2012),
    [anon_sym_extern] = ACTIONS(2012),
    [anon_sym___attribute__] = ACTIONS(2012),
    [anon_sym_COLON_COLON] = ACTIONS(2014),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2014),
    [anon_sym___declspec] = ACTIONS(2012),
    [anon_sym_LBRACE] = ACTIONS(2014),
    [anon_sym_signed] = ACTIONS(2012),
    [anon_sym_unsigned] = ACTIONS(2012),
    [anon_sym_long] = ACTIONS(2012),
    [anon_sym_short] = ACTIONS(2012),
    [anon_sym_LBRACK] = ACTIONS(2012),
    [anon_sym_static] = ACTIONS(2012),
    [anon_sym_register] = ACTIONS(2012),
    [anon_sym_inline] = ACTIONS(2012),
    [anon_sym___inline] = ACTIONS(2012),
    [anon_sym___inline__] = ACTIONS(2012),
    [anon_sym___forceinline] = ACTIONS(2012),
    [anon_sym_thread_local] = ACTIONS(2012),
    [anon_sym___thread] = ACTIONS(2012),
    [anon_sym_const] = ACTIONS(2012),
    [anon_sym_constexpr] = ACTIONS(2012),
    [anon_sym_volatile] = ACTIONS(2012),
    [anon_sym_restrict] = ACTIONS(2012),
    [anon_sym___restrict__] = ACTIONS(2012),
    [anon_sym__Atomic] = ACTIONS(2012),
    [anon_sym__Noreturn] = ACTIONS(2012),
    [anon_sym_noreturn] = ACTIONS(2012),
    [anon_sym_mutable] = ACTIONS(2012),
    [anon_sym_constinit] = ACTIONS(2012),
    [anon_sym_consteval] = ACTIONS(2012),
    [anon_sym_alignas] = ACTIONS(2012),
    [anon_sym__Alignas] = ACTIONS(2012),
    [sym_primitive_type] = ACTIONS(2012),
    [anon_sym_enum] = ACTIONS(2012),
    [anon_sym_class] = ACTIONS(2012),
    [anon_sym_struct] = ACTIONS(2012),
    [anon_sym_union] = ACTIONS(2012),
    [anon_sym_if] = ACTIONS(2012),
    [anon_sym_else] = ACTIONS(2012),
    [anon_sym_switch] = ACTIONS(2012),
    [anon_sym_while] = ACTIONS(2012),
    [anon_sym_do] = ACTIONS(2012),
    [anon_sym_for] = ACTIONS(2012),
    [anon_sym_return] = ACTIONS(2012),
    [anon_sym_break] = ACTIONS(2012),
    [anon_sym_continue] = ACTIONS(2012),
    [anon_sym_goto] = ACTIONS(2012),
    [anon_sym___try] = ACTIONS(2012),
    [anon_sym___leave] = ACTIONS(2012),
    [anon_sym_not] = ACTIONS(2012),
    [anon_sym_compl] = ACTIONS(2012),
    [anon_sym_DASH_DASH] = ACTIONS(2014),
    [anon_sym_PLUS_PLUS] = ACTIONS(2014),
    [anon_sym_sizeof] = ACTIONS(2012),
    [anon_sym___alignof__] = ACTIONS(2012),
    [anon_sym___alignof] = ACTIONS(2012),
    [anon_sym__alignof] = ACTIONS(2012),
    [anon_sym_alignof] = ACTIONS(2012),
    [anon_sym__Alignof] = ACTIONS(2012),
    [anon_sym_offsetof] = ACTIONS(2012),
    [anon_sym__Generic] = ACTIONS(2012),
    [anon_sym_asm] = ACTIONS(2012),
    [anon_sym___asm__] = ACTIONS(2012),
    [sym_number_literal] = ACTIONS(2014),
    [anon_sym_L_SQUOTE] = ACTIONS(2014),
    [anon_sym_u_SQUOTE] = ACTIONS(2014),
    [anon_sym_U_SQUOTE] = ACTIONS(2014),
    [anon_sym_u8_SQUOTE] = ACTIONS(2014),
    [anon_sym_SQUOTE] = ACTIONS(2014),
    [anon_sym_L_DQUOTE] = ACTIONS(2014),
    [anon_sym_u_DQUOTE] = ACTIONS(2014),
    [anon_sym_U_DQUOTE] = ACTIONS(2014),
    [anon_sym_u8_DQUOTE] = ACTIONS(2014),
    [anon_sym_DQUOTE] = ACTIONS(2014),
    [sym_true] = ACTIONS(2012),
    [sym_false] = ACTIONS(2012),
    [anon_sym_NULL] = ACTIONS(2012),
    [anon_sym_nullptr] = ACTIONS(2012),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2012),
    [anon_sym_decltype] = ACTIONS(2012),
    [sym_virtual] = ACTIONS(2012),
    [anon_sym_typename] = ACTIONS(2012),
    [anon_sym_template] = ACTIONS(2012),
    [anon_sym_try] = ACTIONS(2012),
    [anon_sym_delete] = ACTIONS(2012),
    [anon_sym_throw] = ACTIONS(2012),
    [anon_sym_co_return] = ACTIONS(2012),
    [anon_sym_co_yield] = ACTIONS(2012),
    [anon_sym_catch] = ACTIONS(2012),
    [anon_sym_R_DQUOTE] = ACTIONS(2014),
    [anon_sym_LR_DQUOTE] = ACTIONS(2014),
    [anon_sym_uR_DQUOTE] = ACTIONS(2014),
    [anon_sym_UR_DQUOTE] = ACTIONS(2014),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2014),
    [anon_sym_co_await] = ACTIONS(2012),
    [anon_sym_new] = ACTIONS(2012),
    [anon_sym_requires] = ACTIONS(2012),
    [sym_this] = ACTIONS(2012),
    [anon_sym_discard] = ACTIONS(2012),
    [anon_sym_precise] = ACTIONS(2012),
    [anon_sym_shared] = ACTIONS(2012),
    [anon_sym_groupshared] = ACTIONS(2012),
    [anon_sym_uniform] = ACTIONS(2012),
    [anon_sym_row_major] = ACTIONS(2012),
    [anon_sym_column_major] = ACTIONS(2012),
    [anon_sym_globallycoherent] = ACTIONS(2012),
    [anon_sym_centroid] = ACTIONS(2012),
    [anon_sym_noperspective] = ACTIONS(2012),
    [anon_sym_nointerpolation] = ACTIONS(2012),
    [anon_sym_sample] = ACTIONS(2012),
    [anon_sym_linear] = ACTIONS(2012),
    [anon_sym_snorm] = ACTIONS(2012),
    [anon_sym_unorm] = ACTIONS(2012),
    [anon_sym_point] = ACTIONS(2012),
    [anon_sym_line] = ACTIONS(2012),
    [anon_sym_triangleadj] = ACTIONS(2012),
    [anon_sym_lineadj] = ACTIONS(2012),
    [anon_sym_triangle] = ACTIONS(2012),
    [anon_sym_cbuffer] = ACTIONS(2012),
  },
  [992] = {
    [sym_type_qualifier] = STATE(3990),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4777),
    [sym_sized_type_specifier] = STATE(2981),
    [sym_enum_specifier] = STATE(2981),
    [sym_struct_specifier] = STATE(2981),
    [sym_union_specifier] = STATE(2981),
    [sym_expression] = STATE(4580),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_type_descriptor] = STATE(7424),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_placeholder_type_specifier] = STATE(2981),
    [sym_decltype_auto] = STATE(2980),
    [sym_decltype] = STATE(2937),
    [sym_class_specifier] = STATE(2981),
    [sym__class_name] = STATE(7712),
    [sym_dependent_type] = STATE(2981),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_type_parameter_pack_expansion] = STATE(7622),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5560),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3667),
    [aux_sym__type_definition_type_repeat1] = STATE(3990),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2571),
    [sym_identifier] = ACTIONS(3750),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_signed] = ACTIONS(3762),
    [anon_sym_unsigned] = ACTIONS(3762),
    [anon_sym_long] = ACTIONS(3762),
    [anon_sym_short] = ACTIONS(3762),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3764),
    [anon_sym_enum] = ACTIONS(3766),
    [anon_sym_class] = ACTIONS(3768),
    [anon_sym_struct] = ACTIONS(3770),
    [anon_sym_union] = ACTIONS(3772),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3796),
    [anon_sym_decltype] = ACTIONS(3798),
    [anon_sym_typename] = ACTIONS(3800),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [993] = {
    [sym_identifier] = ACTIONS(1931),
    [anon_sym_LPAREN2] = ACTIONS(1929),
    [anon_sym_BANG] = ACTIONS(1929),
    [anon_sym_TILDE] = ACTIONS(1929),
    [anon_sym_DASH] = ACTIONS(1931),
    [anon_sym_PLUS] = ACTIONS(1931),
    [anon_sym_STAR] = ACTIONS(1929),
    [anon_sym_AMP] = ACTIONS(1929),
    [anon_sym_SEMI] = ACTIONS(1929),
    [anon_sym___extension__] = ACTIONS(1931),
    [anon_sym_typedef] = ACTIONS(1931),
    [anon_sym_in] = ACTIONS(1931),
    [anon_sym_out] = ACTIONS(1931),
    [anon_sym_inout] = ACTIONS(1931),
    [anon_sym_extern] = ACTIONS(1931),
    [anon_sym___attribute__] = ACTIONS(1931),
    [anon_sym_COLON_COLON] = ACTIONS(1929),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1929),
    [anon_sym___declspec] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1929),
    [anon_sym_signed] = ACTIONS(1931),
    [anon_sym_unsigned] = ACTIONS(1931),
    [anon_sym_long] = ACTIONS(1931),
    [anon_sym_short] = ACTIONS(1931),
    [anon_sym_LBRACK] = ACTIONS(1931),
    [anon_sym_static] = ACTIONS(1931),
    [anon_sym_register] = ACTIONS(1931),
    [anon_sym_inline] = ACTIONS(1931),
    [anon_sym___inline] = ACTIONS(1931),
    [anon_sym___inline__] = ACTIONS(1931),
    [anon_sym___forceinline] = ACTIONS(1931),
    [anon_sym_thread_local] = ACTIONS(1931),
    [anon_sym___thread] = ACTIONS(1931),
    [anon_sym_const] = ACTIONS(1931),
    [anon_sym_constexpr] = ACTIONS(1931),
    [anon_sym_volatile] = ACTIONS(1931),
    [anon_sym_restrict] = ACTIONS(1931),
    [anon_sym___restrict__] = ACTIONS(1931),
    [anon_sym__Atomic] = ACTIONS(1931),
    [anon_sym__Noreturn] = ACTIONS(1931),
    [anon_sym_noreturn] = ACTIONS(1931),
    [anon_sym_mutable] = ACTIONS(1931),
    [anon_sym_constinit] = ACTIONS(1931),
    [anon_sym_consteval] = ACTIONS(1931),
    [anon_sym_alignas] = ACTIONS(1931),
    [anon_sym__Alignas] = ACTIONS(1931),
    [sym_primitive_type] = ACTIONS(1931),
    [anon_sym_enum] = ACTIONS(1931),
    [anon_sym_class] = ACTIONS(1931),
    [anon_sym_struct] = ACTIONS(1931),
    [anon_sym_union] = ACTIONS(1931),
    [anon_sym_if] = ACTIONS(1931),
    [anon_sym_else] = ACTIONS(1931),
    [anon_sym_switch] = ACTIONS(1931),
    [anon_sym_while] = ACTIONS(1931),
    [anon_sym_do] = ACTIONS(1931),
    [anon_sym_for] = ACTIONS(1931),
    [anon_sym_return] = ACTIONS(1931),
    [anon_sym_break] = ACTIONS(1931),
    [anon_sym_continue] = ACTIONS(1931),
    [anon_sym_goto] = ACTIONS(1931),
    [anon_sym___try] = ACTIONS(1931),
    [anon_sym___leave] = ACTIONS(1931),
    [anon_sym_not] = ACTIONS(1931),
    [anon_sym_compl] = ACTIONS(1931),
    [anon_sym_DASH_DASH] = ACTIONS(1929),
    [anon_sym_PLUS_PLUS] = ACTIONS(1929),
    [anon_sym_sizeof] = ACTIONS(1931),
    [anon_sym___alignof__] = ACTIONS(1931),
    [anon_sym___alignof] = ACTIONS(1931),
    [anon_sym__alignof] = ACTIONS(1931),
    [anon_sym_alignof] = ACTIONS(1931),
    [anon_sym__Alignof] = ACTIONS(1931),
    [anon_sym_offsetof] = ACTIONS(1931),
    [anon_sym__Generic] = ACTIONS(1931),
    [anon_sym_asm] = ACTIONS(1931),
    [anon_sym___asm__] = ACTIONS(1931),
    [sym_number_literal] = ACTIONS(1929),
    [anon_sym_L_SQUOTE] = ACTIONS(1929),
    [anon_sym_u_SQUOTE] = ACTIONS(1929),
    [anon_sym_U_SQUOTE] = ACTIONS(1929),
    [anon_sym_u8_SQUOTE] = ACTIONS(1929),
    [anon_sym_SQUOTE] = ACTIONS(1929),
    [anon_sym_L_DQUOTE] = ACTIONS(1929),
    [anon_sym_u_DQUOTE] = ACTIONS(1929),
    [anon_sym_U_DQUOTE] = ACTIONS(1929),
    [anon_sym_u8_DQUOTE] = ACTIONS(1929),
    [anon_sym_DQUOTE] = ACTIONS(1929),
    [sym_true] = ACTIONS(1931),
    [sym_false] = ACTIONS(1931),
    [anon_sym_NULL] = ACTIONS(1931),
    [anon_sym_nullptr] = ACTIONS(1931),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1931),
    [anon_sym_decltype] = ACTIONS(1931),
    [sym_virtual] = ACTIONS(1931),
    [anon_sym_typename] = ACTIONS(1931),
    [anon_sym_template] = ACTIONS(1931),
    [anon_sym_try] = ACTIONS(1931),
    [anon_sym_delete] = ACTIONS(1931),
    [anon_sym_throw] = ACTIONS(1931),
    [anon_sym_co_return] = ACTIONS(1931),
    [anon_sym_co_yield] = ACTIONS(1931),
    [anon_sym_catch] = ACTIONS(1931),
    [anon_sym_R_DQUOTE] = ACTIONS(1929),
    [anon_sym_LR_DQUOTE] = ACTIONS(1929),
    [anon_sym_uR_DQUOTE] = ACTIONS(1929),
    [anon_sym_UR_DQUOTE] = ACTIONS(1929),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1929),
    [anon_sym_co_await] = ACTIONS(1931),
    [anon_sym_new] = ACTIONS(1931),
    [anon_sym_requires] = ACTIONS(1931),
    [sym_this] = ACTIONS(1931),
    [anon_sym_discard] = ACTIONS(1931),
    [anon_sym_precise] = ACTIONS(1931),
    [anon_sym_shared] = ACTIONS(1931),
    [anon_sym_groupshared] = ACTIONS(1931),
    [anon_sym_uniform] = ACTIONS(1931),
    [anon_sym_row_major] = ACTIONS(1931),
    [anon_sym_column_major] = ACTIONS(1931),
    [anon_sym_globallycoherent] = ACTIONS(1931),
    [anon_sym_centroid] = ACTIONS(1931),
    [anon_sym_noperspective] = ACTIONS(1931),
    [anon_sym_nointerpolation] = ACTIONS(1931),
    [anon_sym_sample] = ACTIONS(1931),
    [anon_sym_linear] = ACTIONS(1931),
    [anon_sym_snorm] = ACTIONS(1931),
    [anon_sym_unorm] = ACTIONS(1931),
    [anon_sym_point] = ACTIONS(1931),
    [anon_sym_line] = ACTIONS(1931),
    [anon_sym_triangleadj] = ACTIONS(1931),
    [anon_sym_lineadj] = ACTIONS(1931),
    [anon_sym_triangle] = ACTIONS(1931),
    [anon_sym_cbuffer] = ACTIONS(1931),
  },
  [994] = {
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_unaligned_ptr_modifier] = STATE(4205),
    [sym_ms_pointer_modifier] = STATE(3203),
    [sym__declarator] = STATE(6320),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6270),
    [sym_array_declarator] = STATE(6270),
    [sym_type_qualifier] = STATE(4050),
    [sym_alignas_qualifier] = STATE(4472),
    [sym_expression] = STATE(3306),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3415),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5636),
    [sym_qualified_identifier] = STATE(3419),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3659),
    [aux_sym__type_definition_type_repeat1] = STATE(4050),
    [aux_sym_pointer_declarator_repeat1] = STATE(3203),
    [sym_identifier] = ACTIONS(3918),
    [anon_sym_LPAREN2] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(2028),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2030),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym___based] = ACTIONS(49),
    [sym_ms_restrict_modifier] = ACTIONS(3906),
    [sym_ms_unsigned_ptr_modifier] = ACTIONS(3906),
    [sym_ms_signed_ptr_modifier] = ACTIONS(3906),
    [anon_sym__unaligned] = ACTIONS(3908),
    [anon_sym___unaligned] = ACTIONS(3908),
    [anon_sym_LBRACK] = ACTIONS(2038),
    [anon_sym_const] = ACTIONS(3904),
    [anon_sym_constexpr] = ACTIONS(3904),
    [anon_sym_volatile] = ACTIONS(3904),
    [anon_sym_restrict] = ACTIONS(3904),
    [anon_sym___restrict__] = ACTIONS(3904),
    [anon_sym__Atomic] = ACTIONS(3904),
    [anon_sym__Noreturn] = ACTIONS(3904),
    [anon_sym_noreturn] = ACTIONS(3904),
    [anon_sym_mutable] = ACTIONS(3904),
    [anon_sym_constinit] = ACTIONS(3904),
    [anon_sym_consteval] = ACTIONS(3904),
    [anon_sym_alignas] = ACTIONS(3910),
    [anon_sym__Alignas] = ACTIONS(3910),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(2078),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [995] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(1189),
    [sym_raw_string_literal] = STATE(2868),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2233),
    [sym_identifier] = ACTIONS(3822),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3826),
    [anon_sym_TILDE] = ACTIONS(3830),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3834),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3837),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3834),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(3840),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON] = ACTIONS(3920),
    [anon_sym_SEMI] = ACTIONS(3837),
    [anon_sym___extension__] = ACTIONS(3822),
    [anon_sym_in] = ACTIONS(3822),
    [anon_sym_out] = ACTIONS(3822),
    [anon_sym_inout] = ACTIONS(3822),
    [anon_sym_extern] = ACTIONS(3822),
    [anon_sym___attribute__] = ACTIONS(3822),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3845),
    [anon_sym___declspec] = ACTIONS(3822),
    [anon_sym___based] = ACTIONS(3822),
    [anon_sym___cdecl] = ACTIONS(3822),
    [anon_sym___clrcall] = ACTIONS(3822),
    [anon_sym___stdcall] = ACTIONS(3822),
    [anon_sym___fastcall] = ACTIONS(3822),
    [anon_sym___thiscall] = ACTIONS(3822),
    [anon_sym___vectorcall] = ACTIONS(3822),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_signed] = ACTIONS(3848),
    [anon_sym_unsigned] = ACTIONS(3848),
    [anon_sym_long] = ACTIONS(3848),
    [anon_sym_short] = ACTIONS(3848),
    [anon_sym_LBRACK] = ACTIONS(3850),
    [anon_sym_static] = ACTIONS(3822),
    [anon_sym_EQ] = ACTIONS(3854),
    [anon_sym_register] = ACTIONS(3822),
    [anon_sym_inline] = ACTIONS(3822),
    [anon_sym___inline] = ACTIONS(3822),
    [anon_sym___inline__] = ACTIONS(3822),
    [anon_sym___forceinline] = ACTIONS(3822),
    [anon_sym_thread_local] = ACTIONS(3822),
    [anon_sym___thread] = ACTIONS(3822),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3822),
    [anon_sym_volatile] = ACTIONS(3822),
    [anon_sym_restrict] = ACTIONS(3822),
    [anon_sym___restrict__] = ACTIONS(3822),
    [anon_sym__Atomic] = ACTIONS(3822),
    [anon_sym__Noreturn] = ACTIONS(3822),
    [anon_sym_noreturn] = ACTIONS(3822),
    [anon_sym_mutable] = ACTIONS(3822),
    [anon_sym_constinit] = ACTIONS(3822),
    [anon_sym_consteval] = ACTIONS(3822),
    [anon_sym_alignas] = ACTIONS(3822),
    [anon_sym__Alignas] = ACTIONS(3822),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3856),
    [anon_sym_SLASH_EQ] = ACTIONS(3856),
    [anon_sym_PERCENT_EQ] = ACTIONS(3856),
    [anon_sym_PLUS_EQ] = ACTIONS(3856),
    [anon_sym_DASH_EQ] = ACTIONS(3856),
    [anon_sym_LT_LT_EQ] = ACTIONS(3856),
    [anon_sym_GT_GT_EQ] = ACTIONS(3856),
    [anon_sym_AMP_EQ] = ACTIONS(3856),
    [anon_sym_CARET_EQ] = ACTIONS(3856),
    [anon_sym_PIPE_EQ] = ACTIONS(3856),
    [anon_sym_and_eq] = ACTIONS(3854),
    [anon_sym_or_eq] = ACTIONS(3854),
    [anon_sym_xor_eq] = ACTIONS(3854),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3832),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3832),
    [anon_sym_not_eq] = ACTIONS(3832),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3822),
    [anon_sym_decltype] = ACTIONS(3822),
    [sym_virtual] = ACTIONS(3822),
    [anon_sym_template] = ACTIONS(3822),
    [anon_sym_operator] = ACTIONS(3822),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_precise] = ACTIONS(3822),
    [anon_sym_shared] = ACTIONS(3822),
    [anon_sym_groupshared] = ACTIONS(3822),
    [anon_sym_uniform] = ACTIONS(3822),
    [anon_sym_row_major] = ACTIONS(3822),
    [anon_sym_column_major] = ACTIONS(3822),
    [anon_sym_globallycoherent] = ACTIONS(3822),
    [anon_sym_centroid] = ACTIONS(3822),
    [anon_sym_noperspective] = ACTIONS(3822),
    [anon_sym_nointerpolation] = ACTIONS(3822),
    [anon_sym_sample] = ACTIONS(3822),
    [anon_sym_linear] = ACTIONS(3822),
    [anon_sym_snorm] = ACTIONS(3822),
    [anon_sym_unorm] = ACTIONS(3822),
    [anon_sym_point] = ACTIONS(3822),
    [anon_sym_line] = ACTIONS(3822),
    [anon_sym_triangleadj] = ACTIONS(3822),
    [anon_sym_lineadj] = ACTIONS(3822),
    [anon_sym_triangle] = ACTIONS(3822),
  },
  [996] = {
    [sym_else_clause] = STATE(1014),
    [sym_identifier] = ACTIONS(2004),
    [anon_sym_LPAREN2] = ACTIONS(2006),
    [anon_sym_BANG] = ACTIONS(2006),
    [anon_sym_TILDE] = ACTIONS(2006),
    [anon_sym_DASH] = ACTIONS(2004),
    [anon_sym_PLUS] = ACTIONS(2004),
    [anon_sym_STAR] = ACTIONS(2006),
    [anon_sym_AMP] = ACTIONS(2006),
    [anon_sym_SEMI] = ACTIONS(2006),
    [anon_sym___extension__] = ACTIONS(2004),
    [anon_sym_typedef] = ACTIONS(2004),
    [anon_sym_in] = ACTIONS(2004),
    [anon_sym_out] = ACTIONS(2004),
    [anon_sym_inout] = ACTIONS(2004),
    [anon_sym_extern] = ACTIONS(2004),
    [anon_sym___attribute__] = ACTIONS(2004),
    [anon_sym_COLON_COLON] = ACTIONS(2006),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2006),
    [anon_sym___declspec] = ACTIONS(2004),
    [anon_sym_LBRACE] = ACTIONS(2006),
    [anon_sym_signed] = ACTIONS(2004),
    [anon_sym_unsigned] = ACTIONS(2004),
    [anon_sym_long] = ACTIONS(2004),
    [anon_sym_short] = ACTIONS(2004),
    [anon_sym_LBRACK] = ACTIONS(2004),
    [anon_sym_static] = ACTIONS(2004),
    [anon_sym_register] = ACTIONS(2004),
    [anon_sym_inline] = ACTIONS(2004),
    [anon_sym___inline] = ACTIONS(2004),
    [anon_sym___inline__] = ACTIONS(2004),
    [anon_sym___forceinline] = ACTIONS(2004),
    [anon_sym_thread_local] = ACTIONS(2004),
    [anon_sym___thread] = ACTIONS(2004),
    [anon_sym_const] = ACTIONS(2004),
    [anon_sym_constexpr] = ACTIONS(2004),
    [anon_sym_volatile] = ACTIONS(2004),
    [anon_sym_restrict] = ACTIONS(2004),
    [anon_sym___restrict__] = ACTIONS(2004),
    [anon_sym__Atomic] = ACTIONS(2004),
    [anon_sym__Noreturn] = ACTIONS(2004),
    [anon_sym_noreturn] = ACTIONS(2004),
    [anon_sym_mutable] = ACTIONS(2004),
    [anon_sym_constinit] = ACTIONS(2004),
    [anon_sym_consteval] = ACTIONS(2004),
    [anon_sym_alignas] = ACTIONS(2004),
    [anon_sym__Alignas] = ACTIONS(2004),
    [sym_primitive_type] = ACTIONS(2004),
    [anon_sym_enum] = ACTIONS(2004),
    [anon_sym_class] = ACTIONS(2004),
    [anon_sym_struct] = ACTIONS(2004),
    [anon_sym_union] = ACTIONS(2004),
    [anon_sym_if] = ACTIONS(2004),
    [anon_sym_else] = ACTIONS(3914),
    [anon_sym_switch] = ACTIONS(2004),
    [anon_sym_while] = ACTIONS(2004),
    [anon_sym_do] = ACTIONS(2004),
    [anon_sym_for] = ACTIONS(2004),
    [anon_sym_return] = ACTIONS(2004),
    [anon_sym_break] = ACTIONS(2004),
    [anon_sym_continue] = ACTIONS(2004),
    [anon_sym_goto] = ACTIONS(2004),
    [anon_sym___try] = ACTIONS(2004),
    [anon_sym___leave] = ACTIONS(2004),
    [anon_sym_not] = ACTIONS(2004),
    [anon_sym_compl] = ACTIONS(2004),
    [anon_sym_DASH_DASH] = ACTIONS(2006),
    [anon_sym_PLUS_PLUS] = ACTIONS(2006),
    [anon_sym_sizeof] = ACTIONS(2004),
    [anon_sym___alignof__] = ACTIONS(2004),
    [anon_sym___alignof] = ACTIONS(2004),
    [anon_sym__alignof] = ACTIONS(2004),
    [anon_sym_alignof] = ACTIONS(2004),
    [anon_sym__Alignof] = ACTIONS(2004),
    [anon_sym_offsetof] = ACTIONS(2004),
    [anon_sym__Generic] = ACTIONS(2004),
    [anon_sym_asm] = ACTIONS(2004),
    [anon_sym___asm__] = ACTIONS(2004),
    [sym_number_literal] = ACTIONS(2006),
    [anon_sym_L_SQUOTE] = ACTIONS(2006),
    [anon_sym_u_SQUOTE] = ACTIONS(2006),
    [anon_sym_U_SQUOTE] = ACTIONS(2006),
    [anon_sym_u8_SQUOTE] = ACTIONS(2006),
    [anon_sym_SQUOTE] = ACTIONS(2006),
    [anon_sym_L_DQUOTE] = ACTIONS(2006),
    [anon_sym_u_DQUOTE] = ACTIONS(2006),
    [anon_sym_U_DQUOTE] = ACTIONS(2006),
    [anon_sym_u8_DQUOTE] = ACTIONS(2006),
    [anon_sym_DQUOTE] = ACTIONS(2006),
    [sym_true] = ACTIONS(2004),
    [sym_false] = ACTIONS(2004),
    [anon_sym_NULL] = ACTIONS(2004),
    [anon_sym_nullptr] = ACTIONS(2004),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2004),
    [anon_sym_decltype] = ACTIONS(2004),
    [sym_virtual] = ACTIONS(2004),
    [anon_sym_typename] = ACTIONS(2004),
    [anon_sym_template] = ACTIONS(2004),
    [anon_sym_try] = ACTIONS(2004),
    [anon_sym_delete] = ACTIONS(2004),
    [anon_sym_throw] = ACTIONS(2004),
    [anon_sym_co_return] = ACTIONS(2004),
    [anon_sym_co_yield] = ACTIONS(2004),
    [anon_sym_R_DQUOTE] = ACTIONS(2006),
    [anon_sym_LR_DQUOTE] = ACTIONS(2006),
    [anon_sym_uR_DQUOTE] = ACTIONS(2006),
    [anon_sym_UR_DQUOTE] = ACTIONS(2006),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2006),
    [anon_sym_co_await] = ACTIONS(2004),
    [anon_sym_new] = ACTIONS(2004),
    [anon_sym_requires] = ACTIONS(2004),
    [sym_this] = ACTIONS(2004),
    [anon_sym_discard] = ACTIONS(2004),
    [anon_sym_precise] = ACTIONS(2004),
    [anon_sym_shared] = ACTIONS(2004),
    [anon_sym_groupshared] = ACTIONS(2004),
    [anon_sym_uniform] = ACTIONS(2004),
    [anon_sym_row_major] = ACTIONS(2004),
    [anon_sym_column_major] = ACTIONS(2004),
    [anon_sym_globallycoherent] = ACTIONS(2004),
    [anon_sym_centroid] = ACTIONS(2004),
    [anon_sym_noperspective] = ACTIONS(2004),
    [anon_sym_nointerpolation] = ACTIONS(2004),
    [anon_sym_sample] = ACTIONS(2004),
    [anon_sym_linear] = ACTIONS(2004),
    [anon_sym_snorm] = ACTIONS(2004),
    [anon_sym_unorm] = ACTIONS(2004),
    [anon_sym_point] = ACTIONS(2004),
    [anon_sym_line] = ACTIONS(2004),
    [anon_sym_triangleadj] = ACTIONS(2004),
    [anon_sym_lineadj] = ACTIONS(2004),
    [anon_sym_triangle] = ACTIONS(2004),
    [anon_sym_cbuffer] = ACTIONS(2004),
  },
  [997] = {
    [sym_identifier] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1945),
    [anon_sym_BANG] = ACTIONS(1945),
    [anon_sym_TILDE] = ACTIONS(1945),
    [anon_sym_DASH] = ACTIONS(1947),
    [anon_sym_PLUS] = ACTIONS(1947),
    [anon_sym_STAR] = ACTIONS(1945),
    [anon_sym_AMP] = ACTIONS(1945),
    [anon_sym_SEMI] = ACTIONS(1945),
    [anon_sym___extension__] = ACTIONS(1947),
    [anon_sym_typedef] = ACTIONS(1947),
    [anon_sym_in] = ACTIONS(1947),
    [anon_sym_out] = ACTIONS(1947),
    [anon_sym_inout] = ACTIONS(1947),
    [anon_sym_extern] = ACTIONS(1947),
    [anon_sym___attribute__] = ACTIONS(1947),
    [anon_sym_COLON_COLON] = ACTIONS(1945),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1945),
    [anon_sym___declspec] = ACTIONS(1947),
    [anon_sym_LBRACE] = ACTIONS(1945),
    [anon_sym_signed] = ACTIONS(1947),
    [anon_sym_unsigned] = ACTIONS(1947),
    [anon_sym_long] = ACTIONS(1947),
    [anon_sym_short] = ACTIONS(1947),
    [anon_sym_LBRACK] = ACTIONS(1947),
    [anon_sym_static] = ACTIONS(1947),
    [anon_sym_register] = ACTIONS(1947),
    [anon_sym_inline] = ACTIONS(1947),
    [anon_sym___inline] = ACTIONS(1947),
    [anon_sym___inline__] = ACTIONS(1947),
    [anon_sym___forceinline] = ACTIONS(1947),
    [anon_sym_thread_local] = ACTIONS(1947),
    [anon_sym___thread] = ACTIONS(1947),
    [anon_sym_const] = ACTIONS(1947),
    [anon_sym_constexpr] = ACTIONS(1947),
    [anon_sym_volatile] = ACTIONS(1947),
    [anon_sym_restrict] = ACTIONS(1947),
    [anon_sym___restrict__] = ACTIONS(1947),
    [anon_sym__Atomic] = ACTIONS(1947),
    [anon_sym__Noreturn] = ACTIONS(1947),
    [anon_sym_noreturn] = ACTIONS(1947),
    [anon_sym_mutable] = ACTIONS(1947),
    [anon_sym_constinit] = ACTIONS(1947),
    [anon_sym_consteval] = ACTIONS(1947),
    [anon_sym_alignas] = ACTIONS(1947),
    [anon_sym__Alignas] = ACTIONS(1947),
    [sym_primitive_type] = ACTIONS(1947),
    [anon_sym_enum] = ACTIONS(1947),
    [anon_sym_class] = ACTIONS(1947),
    [anon_sym_struct] = ACTIONS(1947),
    [anon_sym_union] = ACTIONS(1947),
    [anon_sym_if] = ACTIONS(1947),
    [anon_sym_else] = ACTIONS(1947),
    [anon_sym_switch] = ACTIONS(1947),
    [anon_sym_while] = ACTIONS(1947),
    [anon_sym_do] = ACTIONS(1947),
    [anon_sym_for] = ACTIONS(1947),
    [anon_sym_return] = ACTIONS(1947),
    [anon_sym_break] = ACTIONS(1947),
    [anon_sym_continue] = ACTIONS(1947),
    [anon_sym_goto] = ACTIONS(1947),
    [anon_sym___try] = ACTIONS(1947),
    [anon_sym___leave] = ACTIONS(1947),
    [anon_sym_not] = ACTIONS(1947),
    [anon_sym_compl] = ACTIONS(1947),
    [anon_sym_DASH_DASH] = ACTIONS(1945),
    [anon_sym_PLUS_PLUS] = ACTIONS(1945),
    [anon_sym_sizeof] = ACTIONS(1947),
    [anon_sym___alignof__] = ACTIONS(1947),
    [anon_sym___alignof] = ACTIONS(1947),
    [anon_sym__alignof] = ACTIONS(1947),
    [anon_sym_alignof] = ACTIONS(1947),
    [anon_sym__Alignof] = ACTIONS(1947),
    [anon_sym_offsetof] = ACTIONS(1947),
    [anon_sym__Generic] = ACTIONS(1947),
    [anon_sym_asm] = ACTIONS(1947),
    [anon_sym___asm__] = ACTIONS(1947),
    [sym_number_literal] = ACTIONS(1945),
    [anon_sym_L_SQUOTE] = ACTIONS(1945),
    [anon_sym_u_SQUOTE] = ACTIONS(1945),
    [anon_sym_U_SQUOTE] = ACTIONS(1945),
    [anon_sym_u8_SQUOTE] = ACTIONS(1945),
    [anon_sym_SQUOTE] = ACTIONS(1945),
    [anon_sym_L_DQUOTE] = ACTIONS(1945),
    [anon_sym_u_DQUOTE] = ACTIONS(1945),
    [anon_sym_U_DQUOTE] = ACTIONS(1945),
    [anon_sym_u8_DQUOTE] = ACTIONS(1945),
    [anon_sym_DQUOTE] = ACTIONS(1945),
    [sym_true] = ACTIONS(1947),
    [sym_false] = ACTIONS(1947),
    [anon_sym_NULL] = ACTIONS(1947),
    [anon_sym_nullptr] = ACTIONS(1947),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1947),
    [anon_sym_decltype] = ACTIONS(1947),
    [sym_virtual] = ACTIONS(1947),
    [anon_sym_typename] = ACTIONS(1947),
    [anon_sym_template] = ACTIONS(1947),
    [anon_sym_try] = ACTIONS(1947),
    [anon_sym_delete] = ACTIONS(1947),
    [anon_sym_throw] = ACTIONS(1947),
    [anon_sym_co_return] = ACTIONS(1947),
    [anon_sym_co_yield] = ACTIONS(1947),
    [anon_sym_catch] = ACTIONS(1947),
    [anon_sym_R_DQUOTE] = ACTIONS(1945),
    [anon_sym_LR_DQUOTE] = ACTIONS(1945),
    [anon_sym_uR_DQUOTE] = ACTIONS(1945),
    [anon_sym_UR_DQUOTE] = ACTIONS(1945),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1945),
    [anon_sym_co_await] = ACTIONS(1947),
    [anon_sym_new] = ACTIONS(1947),
    [anon_sym_requires] = ACTIONS(1947),
    [sym_this] = ACTIONS(1947),
    [anon_sym_discard] = ACTIONS(1947),
    [anon_sym_precise] = ACTIONS(1947),
    [anon_sym_shared] = ACTIONS(1947),
    [anon_sym_groupshared] = ACTIONS(1947),
    [anon_sym_uniform] = ACTIONS(1947),
    [anon_sym_row_major] = ACTIONS(1947),
    [anon_sym_column_major] = ACTIONS(1947),
    [anon_sym_globallycoherent] = ACTIONS(1947),
    [anon_sym_centroid] = ACTIONS(1947),
    [anon_sym_noperspective] = ACTIONS(1947),
    [anon_sym_nointerpolation] = ACTIONS(1947),
    [anon_sym_sample] = ACTIONS(1947),
    [anon_sym_linear] = ACTIONS(1947),
    [anon_sym_snorm] = ACTIONS(1947),
    [anon_sym_unorm] = ACTIONS(1947),
    [anon_sym_point] = ACTIONS(1947),
    [anon_sym_line] = ACTIONS(1947),
    [anon_sym_triangleadj] = ACTIONS(1947),
    [anon_sym_lineadj] = ACTIONS(1947),
    [anon_sym_triangle] = ACTIONS(1947),
    [anon_sym_cbuffer] = ACTIONS(1947),
  },
  [998] = {
    [sym_identifier] = ACTIONS(2174),
    [anon_sym_LPAREN2] = ACTIONS(2176),
    [anon_sym_BANG] = ACTIONS(2176),
    [anon_sym_TILDE] = ACTIONS(2176),
    [anon_sym_DASH] = ACTIONS(2174),
    [anon_sym_PLUS] = ACTIONS(2174),
    [anon_sym_STAR] = ACTIONS(2176),
    [anon_sym_AMP] = ACTIONS(2176),
    [anon_sym_SEMI] = ACTIONS(2176),
    [anon_sym___extension__] = ACTIONS(2174),
    [anon_sym_typedef] = ACTIONS(2174),
    [anon_sym_in] = ACTIONS(2174),
    [anon_sym_out] = ACTIONS(2174),
    [anon_sym_inout] = ACTIONS(2174),
    [anon_sym_extern] = ACTIONS(2174),
    [anon_sym___attribute__] = ACTIONS(2174),
    [anon_sym_COLON_COLON] = ACTIONS(2176),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2176),
    [anon_sym___declspec] = ACTIONS(2174),
    [anon_sym_LBRACE] = ACTIONS(2176),
    [anon_sym_signed] = ACTIONS(2174),
    [anon_sym_unsigned] = ACTIONS(2174),
    [anon_sym_long] = ACTIONS(2174),
    [anon_sym_short] = ACTIONS(2174),
    [anon_sym_LBRACK] = ACTIONS(2174),
    [anon_sym_static] = ACTIONS(2174),
    [anon_sym_register] = ACTIONS(2174),
    [anon_sym_inline] = ACTIONS(2174),
    [anon_sym___inline] = ACTIONS(2174),
    [anon_sym___inline__] = ACTIONS(2174),
    [anon_sym___forceinline] = ACTIONS(2174),
    [anon_sym_thread_local] = ACTIONS(2174),
    [anon_sym___thread] = ACTIONS(2174),
    [anon_sym_const] = ACTIONS(2174),
    [anon_sym_constexpr] = ACTIONS(2174),
    [anon_sym_volatile] = ACTIONS(2174),
    [anon_sym_restrict] = ACTIONS(2174),
    [anon_sym___restrict__] = ACTIONS(2174),
    [anon_sym__Atomic] = ACTIONS(2174),
    [anon_sym__Noreturn] = ACTIONS(2174),
    [anon_sym_noreturn] = ACTIONS(2174),
    [anon_sym_mutable] = ACTIONS(2174),
    [anon_sym_constinit] = ACTIONS(2174),
    [anon_sym_consteval] = ACTIONS(2174),
    [anon_sym_alignas] = ACTIONS(2174),
    [anon_sym__Alignas] = ACTIONS(2174),
    [sym_primitive_type] = ACTIONS(2174),
    [anon_sym_enum] = ACTIONS(2174),
    [anon_sym_class] = ACTIONS(2174),
    [anon_sym_struct] = ACTIONS(2174),
    [anon_sym_union] = ACTIONS(2174),
    [anon_sym_if] = ACTIONS(2174),
    [anon_sym_else] = ACTIONS(2174),
    [anon_sym_switch] = ACTIONS(2174),
    [anon_sym_while] = ACTIONS(2174),
    [anon_sym_do] = ACTIONS(2174),
    [anon_sym_for] = ACTIONS(2174),
    [anon_sym_return] = ACTIONS(2174),
    [anon_sym_break] = ACTIONS(2174),
    [anon_sym_continue] = ACTIONS(2174),
    [anon_sym_goto] = ACTIONS(2174),
    [anon_sym___try] = ACTIONS(2174),
    [anon_sym___leave] = ACTIONS(2174),
    [anon_sym_not] = ACTIONS(2174),
    [anon_sym_compl] = ACTIONS(2174),
    [anon_sym_DASH_DASH] = ACTIONS(2176),
    [anon_sym_PLUS_PLUS] = ACTIONS(2176),
    [anon_sym_sizeof] = ACTIONS(2174),
    [anon_sym___alignof__] = ACTIONS(2174),
    [anon_sym___alignof] = ACTIONS(2174),
    [anon_sym__alignof] = ACTIONS(2174),
    [anon_sym_alignof] = ACTIONS(2174),
    [anon_sym__Alignof] = ACTIONS(2174),
    [anon_sym_offsetof] = ACTIONS(2174),
    [anon_sym__Generic] = ACTIONS(2174),
    [anon_sym_asm] = ACTIONS(2174),
    [anon_sym___asm__] = ACTIONS(2174),
    [sym_number_literal] = ACTIONS(2176),
    [anon_sym_L_SQUOTE] = ACTIONS(2176),
    [anon_sym_u_SQUOTE] = ACTIONS(2176),
    [anon_sym_U_SQUOTE] = ACTIONS(2176),
    [anon_sym_u8_SQUOTE] = ACTIONS(2176),
    [anon_sym_SQUOTE] = ACTIONS(2176),
    [anon_sym_L_DQUOTE] = ACTIONS(2176),
    [anon_sym_u_DQUOTE] = ACTIONS(2176),
    [anon_sym_U_DQUOTE] = ACTIONS(2176),
    [anon_sym_u8_DQUOTE] = ACTIONS(2176),
    [anon_sym_DQUOTE] = ACTIONS(2176),
    [sym_true] = ACTIONS(2174),
    [sym_false] = ACTIONS(2174),
    [anon_sym_NULL] = ACTIONS(2174),
    [anon_sym_nullptr] = ACTIONS(2174),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2174),
    [anon_sym_decltype] = ACTIONS(2174),
    [sym_virtual] = ACTIONS(2174),
    [anon_sym_typename] = ACTIONS(2174),
    [anon_sym_template] = ACTIONS(2174),
    [anon_sym_try] = ACTIONS(2174),
    [anon_sym_delete] = ACTIONS(2174),
    [anon_sym_throw] = ACTIONS(2174),
    [anon_sym_co_return] = ACTIONS(2174),
    [anon_sym_co_yield] = ACTIONS(2174),
    [anon_sym_R_DQUOTE] = ACTIONS(2176),
    [anon_sym_LR_DQUOTE] = ACTIONS(2176),
    [anon_sym_uR_DQUOTE] = ACTIONS(2176),
    [anon_sym_UR_DQUOTE] = ACTIONS(2176),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2176),
    [anon_sym_co_await] = ACTIONS(2174),
    [anon_sym_new] = ACTIONS(2174),
    [anon_sym_requires] = ACTIONS(2174),
    [sym_this] = ACTIONS(2174),
    [anon_sym_discard] = ACTIONS(2174),
    [anon_sym_precise] = ACTIONS(2174),
    [anon_sym_shared] = ACTIONS(2174),
    [anon_sym_groupshared] = ACTIONS(2174),
    [anon_sym_uniform] = ACTIONS(2174),
    [anon_sym_row_major] = ACTIONS(2174),
    [anon_sym_column_major] = ACTIONS(2174),
    [anon_sym_globallycoherent] = ACTIONS(2174),
    [anon_sym_centroid] = ACTIONS(2174),
    [anon_sym_noperspective] = ACTIONS(2174),
    [anon_sym_nointerpolation] = ACTIONS(2174),
    [anon_sym_sample] = ACTIONS(2174),
    [anon_sym_linear] = ACTIONS(2174),
    [anon_sym_snorm] = ACTIONS(2174),
    [anon_sym_unorm] = ACTIONS(2174),
    [anon_sym_point] = ACTIONS(2174),
    [anon_sym_line] = ACTIONS(2174),
    [anon_sym_triangleadj] = ACTIONS(2174),
    [anon_sym_lineadj] = ACTIONS(2174),
    [anon_sym_triangle] = ACTIONS(2174),
    [anon_sym_cbuffer] = ACTIONS(2174),
  },
  [999] = {
    [sym_identifier] = ACTIONS(2276),
    [anon_sym_LPAREN2] = ACTIONS(2278),
    [anon_sym_BANG] = ACTIONS(2278),
    [anon_sym_TILDE] = ACTIONS(2278),
    [anon_sym_DASH] = ACTIONS(2276),
    [anon_sym_PLUS] = ACTIONS(2276),
    [anon_sym_STAR] = ACTIONS(2278),
    [anon_sym_AMP] = ACTIONS(2278),
    [anon_sym_SEMI] = ACTIONS(2278),
    [anon_sym___extension__] = ACTIONS(2276),
    [anon_sym_typedef] = ACTIONS(2276),
    [anon_sym_in] = ACTIONS(2276),
    [anon_sym_out] = ACTIONS(2276),
    [anon_sym_inout] = ACTIONS(2276),
    [anon_sym_extern] = ACTIONS(2276),
    [anon_sym___attribute__] = ACTIONS(2276),
    [anon_sym_COLON_COLON] = ACTIONS(2278),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2278),
    [anon_sym___declspec] = ACTIONS(2276),
    [anon_sym_LBRACE] = ACTIONS(2278),
    [anon_sym_signed] = ACTIONS(2276),
    [anon_sym_unsigned] = ACTIONS(2276),
    [anon_sym_long] = ACTIONS(2276),
    [anon_sym_short] = ACTIONS(2276),
    [anon_sym_LBRACK] = ACTIONS(2276),
    [anon_sym_static] = ACTIONS(2276),
    [anon_sym_register] = ACTIONS(2276),
    [anon_sym_inline] = ACTIONS(2276),
    [anon_sym___inline] = ACTIONS(2276),
    [anon_sym___inline__] = ACTIONS(2276),
    [anon_sym___forceinline] = ACTIONS(2276),
    [anon_sym_thread_local] = ACTIONS(2276),
    [anon_sym___thread] = ACTIONS(2276),
    [anon_sym_const] = ACTIONS(2276),
    [anon_sym_constexpr] = ACTIONS(2276),
    [anon_sym_volatile] = ACTIONS(2276),
    [anon_sym_restrict] = ACTIONS(2276),
    [anon_sym___restrict__] = ACTIONS(2276),
    [anon_sym__Atomic] = ACTIONS(2276),
    [anon_sym__Noreturn] = ACTIONS(2276),
    [anon_sym_noreturn] = ACTIONS(2276),
    [anon_sym_mutable] = ACTIONS(2276),
    [anon_sym_constinit] = ACTIONS(2276),
    [anon_sym_consteval] = ACTIONS(2276),
    [anon_sym_alignas] = ACTIONS(2276),
    [anon_sym__Alignas] = ACTIONS(2276),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2276),
    [anon_sym_class] = ACTIONS(2276),
    [anon_sym_struct] = ACTIONS(2276),
    [anon_sym_union] = ACTIONS(2276),
    [anon_sym_if] = ACTIONS(2276),
    [anon_sym_else] = ACTIONS(2276),
    [anon_sym_switch] = ACTIONS(2276),
    [anon_sym_while] = ACTIONS(2276),
    [anon_sym_do] = ACTIONS(2276),
    [anon_sym_for] = ACTIONS(2276),
    [anon_sym_return] = ACTIONS(2276),
    [anon_sym_break] = ACTIONS(2276),
    [anon_sym_continue] = ACTIONS(2276),
    [anon_sym_goto] = ACTIONS(2276),
    [anon_sym___try] = ACTIONS(2276),
    [anon_sym___leave] = ACTIONS(2276),
    [anon_sym_not] = ACTIONS(2276),
    [anon_sym_compl] = ACTIONS(2276),
    [anon_sym_DASH_DASH] = ACTIONS(2278),
    [anon_sym_PLUS_PLUS] = ACTIONS(2278),
    [anon_sym_sizeof] = ACTIONS(2276),
    [anon_sym___alignof__] = ACTIONS(2276),
    [anon_sym___alignof] = ACTIONS(2276),
    [anon_sym__alignof] = ACTIONS(2276),
    [anon_sym_alignof] = ACTIONS(2276),
    [anon_sym__Alignof] = ACTIONS(2276),
    [anon_sym_offsetof] = ACTIONS(2276),
    [anon_sym__Generic] = ACTIONS(2276),
    [anon_sym_asm] = ACTIONS(2276),
    [anon_sym___asm__] = ACTIONS(2276),
    [sym_number_literal] = ACTIONS(2278),
    [anon_sym_L_SQUOTE] = ACTIONS(2278),
    [anon_sym_u_SQUOTE] = ACTIONS(2278),
    [anon_sym_U_SQUOTE] = ACTIONS(2278),
    [anon_sym_u8_SQUOTE] = ACTIONS(2278),
    [anon_sym_SQUOTE] = ACTIONS(2278),
    [anon_sym_L_DQUOTE] = ACTIONS(2278),
    [anon_sym_u_DQUOTE] = ACTIONS(2278),
    [anon_sym_U_DQUOTE] = ACTIONS(2278),
    [anon_sym_u8_DQUOTE] = ACTIONS(2278),
    [anon_sym_DQUOTE] = ACTIONS(2278),
    [sym_true] = ACTIONS(2276),
    [sym_false] = ACTIONS(2276),
    [anon_sym_NULL] = ACTIONS(2276),
    [anon_sym_nullptr] = ACTIONS(2276),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2276),
    [anon_sym_decltype] = ACTIONS(2276),
    [sym_virtual] = ACTIONS(2276),
    [anon_sym_typename] = ACTIONS(2276),
    [anon_sym_template] = ACTIONS(2276),
    [anon_sym_try] = ACTIONS(2276),
    [anon_sym_delete] = ACTIONS(2276),
    [anon_sym_throw] = ACTIONS(2276),
    [anon_sym_co_return] = ACTIONS(2276),
    [anon_sym_co_yield] = ACTIONS(2276),
    [anon_sym_R_DQUOTE] = ACTIONS(2278),
    [anon_sym_LR_DQUOTE] = ACTIONS(2278),
    [anon_sym_uR_DQUOTE] = ACTIONS(2278),
    [anon_sym_UR_DQUOTE] = ACTIONS(2278),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2278),
    [anon_sym_co_await] = ACTIONS(2276),
    [anon_sym_new] = ACTIONS(2276),
    [anon_sym_requires] = ACTIONS(2276),
    [sym_this] = ACTIONS(2276),
    [anon_sym_discard] = ACTIONS(2276),
    [anon_sym_precise] = ACTIONS(2276),
    [anon_sym_shared] = ACTIONS(2276),
    [anon_sym_groupshared] = ACTIONS(2276),
    [anon_sym_uniform] = ACTIONS(2276),
    [anon_sym_row_major] = ACTIONS(2276),
    [anon_sym_column_major] = ACTIONS(2276),
    [anon_sym_globallycoherent] = ACTIONS(2276),
    [anon_sym_centroid] = ACTIONS(2276),
    [anon_sym_noperspective] = ACTIONS(2276),
    [anon_sym_nointerpolation] = ACTIONS(2276),
    [anon_sym_sample] = ACTIONS(2276),
    [anon_sym_linear] = ACTIONS(2276),
    [anon_sym_snorm] = ACTIONS(2276),
    [anon_sym_unorm] = ACTIONS(2276),
    [anon_sym_point] = ACTIONS(2276),
    [anon_sym_line] = ACTIONS(2276),
    [anon_sym_triangleadj] = ACTIONS(2276),
    [anon_sym_lineadj] = ACTIONS(2276),
    [anon_sym_triangle] = ACTIONS(2276),
    [anon_sym_cbuffer] = ACTIONS(2276),
  },
  [1000] = {
    [sym_identifier] = ACTIONS(2256),
    [anon_sym_LPAREN2] = ACTIONS(2258),
    [anon_sym_BANG] = ACTIONS(2258),
    [anon_sym_TILDE] = ACTIONS(2258),
    [anon_sym_DASH] = ACTIONS(2256),
    [anon_sym_PLUS] = ACTIONS(2256),
    [anon_sym_STAR] = ACTIONS(2258),
    [anon_sym_AMP] = ACTIONS(2258),
    [anon_sym_SEMI] = ACTIONS(2258),
    [anon_sym___extension__] = ACTIONS(2256),
    [anon_sym_typedef] = ACTIONS(2256),
    [anon_sym_in] = ACTIONS(2256),
    [anon_sym_out] = ACTIONS(2256),
    [anon_sym_inout] = ACTIONS(2256),
    [anon_sym_extern] = ACTIONS(2256),
    [anon_sym___attribute__] = ACTIONS(2256),
    [anon_sym_COLON_COLON] = ACTIONS(2258),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2258),
    [anon_sym___declspec] = ACTIONS(2256),
    [anon_sym_LBRACE] = ACTIONS(2258),
    [anon_sym_signed] = ACTIONS(2256),
    [anon_sym_unsigned] = ACTIONS(2256),
    [anon_sym_long] = ACTIONS(2256),
    [anon_sym_short] = ACTIONS(2256),
    [anon_sym_LBRACK] = ACTIONS(2256),
    [anon_sym_static] = ACTIONS(2256),
    [anon_sym_register] = ACTIONS(2256),
    [anon_sym_inline] = ACTIONS(2256),
    [anon_sym___inline] = ACTIONS(2256),
    [anon_sym___inline__] = ACTIONS(2256),
    [anon_sym___forceinline] = ACTIONS(2256),
    [anon_sym_thread_local] = ACTIONS(2256),
    [anon_sym___thread] = ACTIONS(2256),
    [anon_sym_const] = ACTIONS(2256),
    [anon_sym_constexpr] = ACTIONS(2256),
    [anon_sym_volatile] = ACTIONS(2256),
    [anon_sym_restrict] = ACTIONS(2256),
    [anon_sym___restrict__] = ACTIONS(2256),
    [anon_sym__Atomic] = ACTIONS(2256),
    [anon_sym__Noreturn] = ACTIONS(2256),
    [anon_sym_noreturn] = ACTIONS(2256),
    [anon_sym_mutable] = ACTIONS(2256),
    [anon_sym_constinit] = ACTIONS(2256),
    [anon_sym_consteval] = ACTIONS(2256),
    [anon_sym_alignas] = ACTIONS(2256),
    [anon_sym__Alignas] = ACTIONS(2256),
    [sym_primitive_type] = ACTIONS(2256),
    [anon_sym_enum] = ACTIONS(2256),
    [anon_sym_class] = ACTIONS(2256),
    [anon_sym_struct] = ACTIONS(2256),
    [anon_sym_union] = ACTIONS(2256),
    [anon_sym_if] = ACTIONS(2256),
    [anon_sym_else] = ACTIONS(2256),
    [anon_sym_switch] = ACTIONS(2256),
    [anon_sym_while] = ACTIONS(2256),
    [anon_sym_do] = ACTIONS(2256),
    [anon_sym_for] = ACTIONS(2256),
    [anon_sym_return] = ACTIONS(2256),
    [anon_sym_break] = ACTIONS(2256),
    [anon_sym_continue] = ACTIONS(2256),
    [anon_sym_goto] = ACTIONS(2256),
    [anon_sym___try] = ACTIONS(2256),
    [anon_sym___leave] = ACTIONS(2256),
    [anon_sym_not] = ACTIONS(2256),
    [anon_sym_compl] = ACTIONS(2256),
    [anon_sym_DASH_DASH] = ACTIONS(2258),
    [anon_sym_PLUS_PLUS] = ACTIONS(2258),
    [anon_sym_sizeof] = ACTIONS(2256),
    [anon_sym___alignof__] = ACTIONS(2256),
    [anon_sym___alignof] = ACTIONS(2256),
    [anon_sym__alignof] = ACTIONS(2256),
    [anon_sym_alignof] = ACTIONS(2256),
    [anon_sym__Alignof] = ACTIONS(2256),
    [anon_sym_offsetof] = ACTIONS(2256),
    [anon_sym__Generic] = ACTIONS(2256),
    [anon_sym_asm] = ACTIONS(2256),
    [anon_sym___asm__] = ACTIONS(2256),
    [sym_number_literal] = ACTIONS(2258),
    [anon_sym_L_SQUOTE] = ACTIONS(2258),
    [anon_sym_u_SQUOTE] = ACTIONS(2258),
    [anon_sym_U_SQUOTE] = ACTIONS(2258),
    [anon_sym_u8_SQUOTE] = ACTIONS(2258),
    [anon_sym_SQUOTE] = ACTIONS(2258),
    [anon_sym_L_DQUOTE] = ACTIONS(2258),
    [anon_sym_u_DQUOTE] = ACTIONS(2258),
    [anon_sym_U_DQUOTE] = ACTIONS(2258),
    [anon_sym_u8_DQUOTE] = ACTIONS(2258),
    [anon_sym_DQUOTE] = ACTIONS(2258),
    [sym_true] = ACTIONS(2256),
    [sym_false] = ACTIONS(2256),
    [anon_sym_NULL] = ACTIONS(2256),
    [anon_sym_nullptr] = ACTIONS(2256),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2256),
    [anon_sym_decltype] = ACTIONS(2256),
    [sym_virtual] = ACTIONS(2256),
    [anon_sym_typename] = ACTIONS(2256),
    [anon_sym_template] = ACTIONS(2256),
    [anon_sym_try] = ACTIONS(2256),
    [anon_sym_delete] = ACTIONS(2256),
    [anon_sym_throw] = ACTIONS(2256),
    [anon_sym_co_return] = ACTIONS(2256),
    [anon_sym_co_yield] = ACTIONS(2256),
    [anon_sym_R_DQUOTE] = ACTIONS(2258),
    [anon_sym_LR_DQUOTE] = ACTIONS(2258),
    [anon_sym_uR_DQUOTE] = ACTIONS(2258),
    [anon_sym_UR_DQUOTE] = ACTIONS(2258),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2258),
    [anon_sym_co_await] = ACTIONS(2256),
    [anon_sym_new] = ACTIONS(2256),
    [anon_sym_requires] = ACTIONS(2256),
    [sym_this] = ACTIONS(2256),
    [anon_sym_discard] = ACTIONS(2256),
    [anon_sym_precise] = ACTIONS(2256),
    [anon_sym_shared] = ACTIONS(2256),
    [anon_sym_groupshared] = ACTIONS(2256),
    [anon_sym_uniform] = ACTIONS(2256),
    [anon_sym_row_major] = ACTIONS(2256),
    [anon_sym_column_major] = ACTIONS(2256),
    [anon_sym_globallycoherent] = ACTIONS(2256),
    [anon_sym_centroid] = ACTIONS(2256),
    [anon_sym_noperspective] = ACTIONS(2256),
    [anon_sym_nointerpolation] = ACTIONS(2256),
    [anon_sym_sample] = ACTIONS(2256),
    [anon_sym_linear] = ACTIONS(2256),
    [anon_sym_snorm] = ACTIONS(2256),
    [anon_sym_unorm] = ACTIONS(2256),
    [anon_sym_point] = ACTIONS(2256),
    [anon_sym_line] = ACTIONS(2256),
    [anon_sym_triangleadj] = ACTIONS(2256),
    [anon_sym_lineadj] = ACTIONS(2256),
    [anon_sym_triangle] = ACTIONS(2256),
    [anon_sym_cbuffer] = ACTIONS(2256),
  },
  [1001] = {
    [sym_identifier] = ACTIONS(2198),
    [anon_sym_LPAREN2] = ACTIONS(2200),
    [anon_sym_BANG] = ACTIONS(2200),
    [anon_sym_TILDE] = ACTIONS(2200),
    [anon_sym_DASH] = ACTIONS(2198),
    [anon_sym_PLUS] = ACTIONS(2198),
    [anon_sym_STAR] = ACTIONS(2200),
    [anon_sym_AMP] = ACTIONS(2200),
    [anon_sym_SEMI] = ACTIONS(2200),
    [anon_sym___extension__] = ACTIONS(2198),
    [anon_sym_typedef] = ACTIONS(2198),
    [anon_sym_in] = ACTIONS(2198),
    [anon_sym_out] = ACTIONS(2198),
    [anon_sym_inout] = ACTIONS(2198),
    [anon_sym_extern] = ACTIONS(2198),
    [anon_sym___attribute__] = ACTIONS(2198),
    [anon_sym_COLON_COLON] = ACTIONS(2200),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2200),
    [anon_sym___declspec] = ACTIONS(2198),
    [anon_sym_LBRACE] = ACTIONS(2200),
    [anon_sym_signed] = ACTIONS(2198),
    [anon_sym_unsigned] = ACTIONS(2198),
    [anon_sym_long] = ACTIONS(2198),
    [anon_sym_short] = ACTIONS(2198),
    [anon_sym_LBRACK] = ACTIONS(2198),
    [anon_sym_static] = ACTIONS(2198),
    [anon_sym_register] = ACTIONS(2198),
    [anon_sym_inline] = ACTIONS(2198),
    [anon_sym___inline] = ACTIONS(2198),
    [anon_sym___inline__] = ACTIONS(2198),
    [anon_sym___forceinline] = ACTIONS(2198),
    [anon_sym_thread_local] = ACTIONS(2198),
    [anon_sym___thread] = ACTIONS(2198),
    [anon_sym_const] = ACTIONS(2198),
    [anon_sym_constexpr] = ACTIONS(2198),
    [anon_sym_volatile] = ACTIONS(2198),
    [anon_sym_restrict] = ACTIONS(2198),
    [anon_sym___restrict__] = ACTIONS(2198),
    [anon_sym__Atomic] = ACTIONS(2198),
    [anon_sym__Noreturn] = ACTIONS(2198),
    [anon_sym_noreturn] = ACTIONS(2198),
    [anon_sym_mutable] = ACTIONS(2198),
    [anon_sym_constinit] = ACTIONS(2198),
    [anon_sym_consteval] = ACTIONS(2198),
    [anon_sym_alignas] = ACTIONS(2198),
    [anon_sym__Alignas] = ACTIONS(2198),
    [sym_primitive_type] = ACTIONS(2198),
    [anon_sym_enum] = ACTIONS(2198),
    [anon_sym_class] = ACTIONS(2198),
    [anon_sym_struct] = ACTIONS(2198),
    [anon_sym_union] = ACTIONS(2198),
    [anon_sym_if] = ACTIONS(2198),
    [anon_sym_else] = ACTIONS(2198),
    [anon_sym_switch] = ACTIONS(2198),
    [anon_sym_while] = ACTIONS(2198),
    [anon_sym_do] = ACTIONS(2198),
    [anon_sym_for] = ACTIONS(2198),
    [anon_sym_return] = ACTIONS(2198),
    [anon_sym_break] = ACTIONS(2198),
    [anon_sym_continue] = ACTIONS(2198),
    [anon_sym_goto] = ACTIONS(2198),
    [anon_sym___try] = ACTIONS(2198),
    [anon_sym___leave] = ACTIONS(2198),
    [anon_sym_not] = ACTIONS(2198),
    [anon_sym_compl] = ACTIONS(2198),
    [anon_sym_DASH_DASH] = ACTIONS(2200),
    [anon_sym_PLUS_PLUS] = ACTIONS(2200),
    [anon_sym_sizeof] = ACTIONS(2198),
    [anon_sym___alignof__] = ACTIONS(2198),
    [anon_sym___alignof] = ACTIONS(2198),
    [anon_sym__alignof] = ACTIONS(2198),
    [anon_sym_alignof] = ACTIONS(2198),
    [anon_sym__Alignof] = ACTIONS(2198),
    [anon_sym_offsetof] = ACTIONS(2198),
    [anon_sym__Generic] = ACTIONS(2198),
    [anon_sym_asm] = ACTIONS(2198),
    [anon_sym___asm__] = ACTIONS(2198),
    [sym_number_literal] = ACTIONS(2200),
    [anon_sym_L_SQUOTE] = ACTIONS(2200),
    [anon_sym_u_SQUOTE] = ACTIONS(2200),
    [anon_sym_U_SQUOTE] = ACTIONS(2200),
    [anon_sym_u8_SQUOTE] = ACTIONS(2200),
    [anon_sym_SQUOTE] = ACTIONS(2200),
    [anon_sym_L_DQUOTE] = ACTIONS(2200),
    [anon_sym_u_DQUOTE] = ACTIONS(2200),
    [anon_sym_U_DQUOTE] = ACTIONS(2200),
    [anon_sym_u8_DQUOTE] = ACTIONS(2200),
    [anon_sym_DQUOTE] = ACTIONS(2200),
    [sym_true] = ACTIONS(2198),
    [sym_false] = ACTIONS(2198),
    [anon_sym_NULL] = ACTIONS(2198),
    [anon_sym_nullptr] = ACTIONS(2198),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2198),
    [anon_sym_decltype] = ACTIONS(2198),
    [sym_virtual] = ACTIONS(2198),
    [anon_sym_typename] = ACTIONS(2198),
    [anon_sym_template] = ACTIONS(2198),
    [anon_sym_try] = ACTIONS(2198),
    [anon_sym_delete] = ACTIONS(2198),
    [anon_sym_throw] = ACTIONS(2198),
    [anon_sym_co_return] = ACTIONS(2198),
    [anon_sym_co_yield] = ACTIONS(2198),
    [anon_sym_R_DQUOTE] = ACTIONS(2200),
    [anon_sym_LR_DQUOTE] = ACTIONS(2200),
    [anon_sym_uR_DQUOTE] = ACTIONS(2200),
    [anon_sym_UR_DQUOTE] = ACTIONS(2200),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2200),
    [anon_sym_co_await] = ACTIONS(2198),
    [anon_sym_new] = ACTIONS(2198),
    [anon_sym_requires] = ACTIONS(2198),
    [sym_this] = ACTIONS(2198),
    [anon_sym_discard] = ACTIONS(2198),
    [anon_sym_precise] = ACTIONS(2198),
    [anon_sym_shared] = ACTIONS(2198),
    [anon_sym_groupshared] = ACTIONS(2198),
    [anon_sym_uniform] = ACTIONS(2198),
    [anon_sym_row_major] = ACTIONS(2198),
    [anon_sym_column_major] = ACTIONS(2198),
    [anon_sym_globallycoherent] = ACTIONS(2198),
    [anon_sym_centroid] = ACTIONS(2198),
    [anon_sym_noperspective] = ACTIONS(2198),
    [anon_sym_nointerpolation] = ACTIONS(2198),
    [anon_sym_sample] = ACTIONS(2198),
    [anon_sym_linear] = ACTIONS(2198),
    [anon_sym_snorm] = ACTIONS(2198),
    [anon_sym_unorm] = ACTIONS(2198),
    [anon_sym_point] = ACTIONS(2198),
    [anon_sym_line] = ACTIONS(2198),
    [anon_sym_triangleadj] = ACTIONS(2198),
    [anon_sym_lineadj] = ACTIONS(2198),
    [anon_sym_triangle] = ACTIONS(2198),
    [anon_sym_cbuffer] = ACTIONS(2198),
  },
  [1002] = {
    [sym_identifier] = ACTIONS(3631),
    [anon_sym_LPAREN2] = ACTIONS(3633),
    [anon_sym_BANG] = ACTIONS(3633),
    [anon_sym_TILDE] = ACTIONS(3633),
    [anon_sym_DASH] = ACTIONS(3631),
    [anon_sym_PLUS] = ACTIONS(3631),
    [anon_sym_STAR] = ACTIONS(3633),
    [anon_sym_AMP] = ACTIONS(3633),
    [anon_sym_SEMI] = ACTIONS(3633),
    [anon_sym___extension__] = ACTIONS(3631),
    [anon_sym_in] = ACTIONS(3631),
    [anon_sym_out] = ACTIONS(3631),
    [anon_sym_inout] = ACTIONS(3631),
    [anon_sym_extern] = ACTIONS(3631),
    [anon_sym___attribute__] = ACTIONS(3631),
    [anon_sym_COLON_COLON] = ACTIONS(3633),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3633),
    [anon_sym___declspec] = ACTIONS(3631),
    [anon_sym_LBRACE] = ACTIONS(3633),
    [anon_sym_signed] = ACTIONS(3631),
    [anon_sym_unsigned] = ACTIONS(3631),
    [anon_sym_long] = ACTIONS(3631),
    [anon_sym_short] = ACTIONS(3631),
    [anon_sym_LBRACK] = ACTIONS(3631),
    [anon_sym_static] = ACTIONS(3631),
    [anon_sym_register] = ACTIONS(3631),
    [anon_sym_inline] = ACTIONS(3631),
    [anon_sym___inline] = ACTIONS(3631),
    [anon_sym___inline__] = ACTIONS(3631),
    [anon_sym___forceinline] = ACTIONS(3631),
    [anon_sym_thread_local] = ACTIONS(3631),
    [anon_sym___thread] = ACTIONS(3631),
    [anon_sym_const] = ACTIONS(3631),
    [anon_sym_constexpr] = ACTIONS(3631),
    [anon_sym_volatile] = ACTIONS(3631),
    [anon_sym_restrict] = ACTIONS(3631),
    [anon_sym___restrict__] = ACTIONS(3631),
    [anon_sym__Atomic] = ACTIONS(3631),
    [anon_sym__Noreturn] = ACTIONS(3631),
    [anon_sym_noreturn] = ACTIONS(3631),
    [anon_sym_mutable] = ACTIONS(3631),
    [anon_sym_constinit] = ACTIONS(3631),
    [anon_sym_consteval] = ACTIONS(3631),
    [anon_sym_alignas] = ACTIONS(3631),
    [anon_sym__Alignas] = ACTIONS(3631),
    [sym_primitive_type] = ACTIONS(3631),
    [anon_sym_enum] = ACTIONS(3631),
    [anon_sym_class] = ACTIONS(3631),
    [anon_sym_struct] = ACTIONS(3631),
    [anon_sym_union] = ACTIONS(3631),
    [anon_sym_if] = ACTIONS(3631),
    [anon_sym_switch] = ACTIONS(3631),
    [anon_sym_case] = ACTIONS(3631),
    [anon_sym_default] = ACTIONS(3631),
    [anon_sym_while] = ACTIONS(3631),
    [anon_sym_do] = ACTIONS(3631),
    [anon_sym_for] = ACTIONS(3631),
    [anon_sym_return] = ACTIONS(3631),
    [anon_sym_break] = ACTIONS(3631),
    [anon_sym_continue] = ACTIONS(3631),
    [anon_sym_goto] = ACTIONS(3631),
    [anon_sym___try] = ACTIONS(3631),
    [anon_sym___leave] = ACTIONS(3631),
    [anon_sym_not] = ACTIONS(3631),
    [anon_sym_compl] = ACTIONS(3631),
    [anon_sym_DASH_DASH] = ACTIONS(3633),
    [anon_sym_PLUS_PLUS] = ACTIONS(3633),
    [anon_sym_sizeof] = ACTIONS(3631),
    [anon_sym___alignof__] = ACTIONS(3631),
    [anon_sym___alignof] = ACTIONS(3631),
    [anon_sym__alignof] = ACTIONS(3631),
    [anon_sym_alignof] = ACTIONS(3631),
    [anon_sym__Alignof] = ACTIONS(3631),
    [anon_sym_offsetof] = ACTIONS(3631),
    [anon_sym__Generic] = ACTIONS(3631),
    [anon_sym_asm] = ACTIONS(3631),
    [anon_sym___asm__] = ACTIONS(3631),
    [sym_number_literal] = ACTIONS(3633),
    [anon_sym_L_SQUOTE] = ACTIONS(3633),
    [anon_sym_u_SQUOTE] = ACTIONS(3633),
    [anon_sym_U_SQUOTE] = ACTIONS(3633),
    [anon_sym_u8_SQUOTE] = ACTIONS(3633),
    [anon_sym_SQUOTE] = ACTIONS(3633),
    [anon_sym_L_DQUOTE] = ACTIONS(3633),
    [anon_sym_u_DQUOTE] = ACTIONS(3633),
    [anon_sym_U_DQUOTE] = ACTIONS(3633),
    [anon_sym_u8_DQUOTE] = ACTIONS(3633),
    [anon_sym_DQUOTE] = ACTIONS(3633),
    [sym_true] = ACTIONS(3631),
    [sym_false] = ACTIONS(3631),
    [anon_sym_NULL] = ACTIONS(3631),
    [anon_sym_nullptr] = ACTIONS(3631),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3631),
    [anon_sym_decltype] = ACTIONS(3631),
    [sym_virtual] = ACTIONS(3631),
    [anon_sym_typename] = ACTIONS(3631),
    [anon_sym_template] = ACTIONS(3631),
    [anon_sym_try] = ACTIONS(3631),
    [anon_sym_delete] = ACTIONS(3631),
    [anon_sym_throw] = ACTIONS(3631),
    [anon_sym_co_return] = ACTIONS(3631),
    [anon_sym_co_yield] = ACTIONS(3631),
    [anon_sym_R_DQUOTE] = ACTIONS(3633),
    [anon_sym_LR_DQUOTE] = ACTIONS(3633),
    [anon_sym_uR_DQUOTE] = ACTIONS(3633),
    [anon_sym_UR_DQUOTE] = ACTIONS(3633),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3633),
    [anon_sym_co_await] = ACTIONS(3631),
    [anon_sym_new] = ACTIONS(3631),
    [anon_sym_requires] = ACTIONS(3631),
    [sym_this] = ACTIONS(3631),
    [anon_sym_discard] = ACTIONS(3631),
    [anon_sym_precise] = ACTIONS(3631),
    [anon_sym_shared] = ACTIONS(3631),
    [anon_sym_groupshared] = ACTIONS(3631),
    [anon_sym_uniform] = ACTIONS(3631),
    [anon_sym_row_major] = ACTIONS(3631),
    [anon_sym_column_major] = ACTIONS(3631),
    [anon_sym_globallycoherent] = ACTIONS(3631),
    [anon_sym_centroid] = ACTIONS(3631),
    [anon_sym_noperspective] = ACTIONS(3631),
    [anon_sym_nointerpolation] = ACTIONS(3631),
    [anon_sym_sample] = ACTIONS(3631),
    [anon_sym_linear] = ACTIONS(3631),
    [anon_sym_snorm] = ACTIONS(3631),
    [anon_sym_unorm] = ACTIONS(3631),
    [anon_sym_point] = ACTIONS(3631),
    [anon_sym_line] = ACTIONS(3631),
    [anon_sym_triangleadj] = ACTIONS(3631),
    [anon_sym_lineadj] = ACTIONS(3631),
    [anon_sym_triangle] = ACTIONS(3631),
    [anon_sym_cbuffer] = ACTIONS(3631),
  },
  [1003] = {
    [sym_identifier] = ACTIONS(2194),
    [anon_sym_LPAREN2] = ACTIONS(2196),
    [anon_sym_BANG] = ACTIONS(2196),
    [anon_sym_TILDE] = ACTIONS(2196),
    [anon_sym_DASH] = ACTIONS(2194),
    [anon_sym_PLUS] = ACTIONS(2194),
    [anon_sym_STAR] = ACTIONS(2196),
    [anon_sym_AMP] = ACTIONS(2196),
    [anon_sym_SEMI] = ACTIONS(2196),
    [anon_sym___extension__] = ACTIONS(2194),
    [anon_sym_typedef] = ACTIONS(2194),
    [anon_sym_in] = ACTIONS(2194),
    [anon_sym_out] = ACTIONS(2194),
    [anon_sym_inout] = ACTIONS(2194),
    [anon_sym_extern] = ACTIONS(2194),
    [anon_sym___attribute__] = ACTIONS(2194),
    [anon_sym_COLON_COLON] = ACTIONS(2196),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2196),
    [anon_sym___declspec] = ACTIONS(2194),
    [anon_sym_LBRACE] = ACTIONS(2196),
    [anon_sym_signed] = ACTIONS(2194),
    [anon_sym_unsigned] = ACTIONS(2194),
    [anon_sym_long] = ACTIONS(2194),
    [anon_sym_short] = ACTIONS(2194),
    [anon_sym_LBRACK] = ACTIONS(2194),
    [anon_sym_static] = ACTIONS(2194),
    [anon_sym_register] = ACTIONS(2194),
    [anon_sym_inline] = ACTIONS(2194),
    [anon_sym___inline] = ACTIONS(2194),
    [anon_sym___inline__] = ACTIONS(2194),
    [anon_sym___forceinline] = ACTIONS(2194),
    [anon_sym_thread_local] = ACTIONS(2194),
    [anon_sym___thread] = ACTIONS(2194),
    [anon_sym_const] = ACTIONS(2194),
    [anon_sym_constexpr] = ACTIONS(2194),
    [anon_sym_volatile] = ACTIONS(2194),
    [anon_sym_restrict] = ACTIONS(2194),
    [anon_sym___restrict__] = ACTIONS(2194),
    [anon_sym__Atomic] = ACTIONS(2194),
    [anon_sym__Noreturn] = ACTIONS(2194),
    [anon_sym_noreturn] = ACTIONS(2194),
    [anon_sym_mutable] = ACTIONS(2194),
    [anon_sym_constinit] = ACTIONS(2194),
    [anon_sym_consteval] = ACTIONS(2194),
    [anon_sym_alignas] = ACTIONS(2194),
    [anon_sym__Alignas] = ACTIONS(2194),
    [sym_primitive_type] = ACTIONS(2194),
    [anon_sym_enum] = ACTIONS(2194),
    [anon_sym_class] = ACTIONS(2194),
    [anon_sym_struct] = ACTIONS(2194),
    [anon_sym_union] = ACTIONS(2194),
    [anon_sym_if] = ACTIONS(2194),
    [anon_sym_else] = ACTIONS(2194),
    [anon_sym_switch] = ACTIONS(2194),
    [anon_sym_while] = ACTIONS(2194),
    [anon_sym_do] = ACTIONS(2194),
    [anon_sym_for] = ACTIONS(2194),
    [anon_sym_return] = ACTIONS(2194),
    [anon_sym_break] = ACTIONS(2194),
    [anon_sym_continue] = ACTIONS(2194),
    [anon_sym_goto] = ACTIONS(2194),
    [anon_sym___try] = ACTIONS(2194),
    [anon_sym___leave] = ACTIONS(2194),
    [anon_sym_not] = ACTIONS(2194),
    [anon_sym_compl] = ACTIONS(2194),
    [anon_sym_DASH_DASH] = ACTIONS(2196),
    [anon_sym_PLUS_PLUS] = ACTIONS(2196),
    [anon_sym_sizeof] = ACTIONS(2194),
    [anon_sym___alignof__] = ACTIONS(2194),
    [anon_sym___alignof] = ACTIONS(2194),
    [anon_sym__alignof] = ACTIONS(2194),
    [anon_sym_alignof] = ACTIONS(2194),
    [anon_sym__Alignof] = ACTIONS(2194),
    [anon_sym_offsetof] = ACTIONS(2194),
    [anon_sym__Generic] = ACTIONS(2194),
    [anon_sym_asm] = ACTIONS(2194),
    [anon_sym___asm__] = ACTIONS(2194),
    [sym_number_literal] = ACTIONS(2196),
    [anon_sym_L_SQUOTE] = ACTIONS(2196),
    [anon_sym_u_SQUOTE] = ACTIONS(2196),
    [anon_sym_U_SQUOTE] = ACTIONS(2196),
    [anon_sym_u8_SQUOTE] = ACTIONS(2196),
    [anon_sym_SQUOTE] = ACTIONS(2196),
    [anon_sym_L_DQUOTE] = ACTIONS(2196),
    [anon_sym_u_DQUOTE] = ACTIONS(2196),
    [anon_sym_U_DQUOTE] = ACTIONS(2196),
    [anon_sym_u8_DQUOTE] = ACTIONS(2196),
    [anon_sym_DQUOTE] = ACTIONS(2196),
    [sym_true] = ACTIONS(2194),
    [sym_false] = ACTIONS(2194),
    [anon_sym_NULL] = ACTIONS(2194),
    [anon_sym_nullptr] = ACTIONS(2194),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2194),
    [anon_sym_decltype] = ACTIONS(2194),
    [sym_virtual] = ACTIONS(2194),
    [anon_sym_typename] = ACTIONS(2194),
    [anon_sym_template] = ACTIONS(2194),
    [anon_sym_try] = ACTIONS(2194),
    [anon_sym_delete] = ACTIONS(2194),
    [anon_sym_throw] = ACTIONS(2194),
    [anon_sym_co_return] = ACTIONS(2194),
    [anon_sym_co_yield] = ACTIONS(2194),
    [anon_sym_R_DQUOTE] = ACTIONS(2196),
    [anon_sym_LR_DQUOTE] = ACTIONS(2196),
    [anon_sym_uR_DQUOTE] = ACTIONS(2196),
    [anon_sym_UR_DQUOTE] = ACTIONS(2196),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2196),
    [anon_sym_co_await] = ACTIONS(2194),
    [anon_sym_new] = ACTIONS(2194),
    [anon_sym_requires] = ACTIONS(2194),
    [sym_this] = ACTIONS(2194),
    [anon_sym_discard] = ACTIONS(2194),
    [anon_sym_precise] = ACTIONS(2194),
    [anon_sym_shared] = ACTIONS(2194),
    [anon_sym_groupshared] = ACTIONS(2194),
    [anon_sym_uniform] = ACTIONS(2194),
    [anon_sym_row_major] = ACTIONS(2194),
    [anon_sym_column_major] = ACTIONS(2194),
    [anon_sym_globallycoherent] = ACTIONS(2194),
    [anon_sym_centroid] = ACTIONS(2194),
    [anon_sym_noperspective] = ACTIONS(2194),
    [anon_sym_nointerpolation] = ACTIONS(2194),
    [anon_sym_sample] = ACTIONS(2194),
    [anon_sym_linear] = ACTIONS(2194),
    [anon_sym_snorm] = ACTIONS(2194),
    [anon_sym_unorm] = ACTIONS(2194),
    [anon_sym_point] = ACTIONS(2194),
    [anon_sym_line] = ACTIONS(2194),
    [anon_sym_triangleadj] = ACTIONS(2194),
    [anon_sym_lineadj] = ACTIONS(2194),
    [anon_sym_triangle] = ACTIONS(2194),
    [anon_sym_cbuffer] = ACTIONS(2194),
  },
  [1004] = {
    [sym_identifier] = ACTIONS(2248),
    [anon_sym_LPAREN2] = ACTIONS(2250),
    [anon_sym_BANG] = ACTIONS(2250),
    [anon_sym_TILDE] = ACTIONS(2250),
    [anon_sym_DASH] = ACTIONS(2248),
    [anon_sym_PLUS] = ACTIONS(2248),
    [anon_sym_STAR] = ACTIONS(2250),
    [anon_sym_AMP] = ACTIONS(2250),
    [anon_sym_SEMI] = ACTIONS(2250),
    [anon_sym___extension__] = ACTIONS(2248),
    [anon_sym_typedef] = ACTIONS(2248),
    [anon_sym_in] = ACTIONS(2248),
    [anon_sym_out] = ACTIONS(2248),
    [anon_sym_inout] = ACTIONS(2248),
    [anon_sym_extern] = ACTIONS(2248),
    [anon_sym___attribute__] = ACTIONS(2248),
    [anon_sym_COLON_COLON] = ACTIONS(2250),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2250),
    [anon_sym___declspec] = ACTIONS(2248),
    [anon_sym_LBRACE] = ACTIONS(2250),
    [anon_sym_signed] = ACTIONS(2248),
    [anon_sym_unsigned] = ACTIONS(2248),
    [anon_sym_long] = ACTIONS(2248),
    [anon_sym_short] = ACTIONS(2248),
    [anon_sym_LBRACK] = ACTIONS(2248),
    [anon_sym_static] = ACTIONS(2248),
    [anon_sym_register] = ACTIONS(2248),
    [anon_sym_inline] = ACTIONS(2248),
    [anon_sym___inline] = ACTIONS(2248),
    [anon_sym___inline__] = ACTIONS(2248),
    [anon_sym___forceinline] = ACTIONS(2248),
    [anon_sym_thread_local] = ACTIONS(2248),
    [anon_sym___thread] = ACTIONS(2248),
    [anon_sym_const] = ACTIONS(2248),
    [anon_sym_constexpr] = ACTIONS(2248),
    [anon_sym_volatile] = ACTIONS(2248),
    [anon_sym_restrict] = ACTIONS(2248),
    [anon_sym___restrict__] = ACTIONS(2248),
    [anon_sym__Atomic] = ACTIONS(2248),
    [anon_sym__Noreturn] = ACTIONS(2248),
    [anon_sym_noreturn] = ACTIONS(2248),
    [anon_sym_mutable] = ACTIONS(2248),
    [anon_sym_constinit] = ACTIONS(2248),
    [anon_sym_consteval] = ACTIONS(2248),
    [anon_sym_alignas] = ACTIONS(2248),
    [anon_sym__Alignas] = ACTIONS(2248),
    [sym_primitive_type] = ACTIONS(2248),
    [anon_sym_enum] = ACTIONS(2248),
    [anon_sym_class] = ACTIONS(2248),
    [anon_sym_struct] = ACTIONS(2248),
    [anon_sym_union] = ACTIONS(2248),
    [anon_sym_if] = ACTIONS(2248),
    [anon_sym_else] = ACTIONS(2248),
    [anon_sym_switch] = ACTIONS(2248),
    [anon_sym_while] = ACTIONS(2248),
    [anon_sym_do] = ACTIONS(2248),
    [anon_sym_for] = ACTIONS(2248),
    [anon_sym_return] = ACTIONS(2248),
    [anon_sym_break] = ACTIONS(2248),
    [anon_sym_continue] = ACTIONS(2248),
    [anon_sym_goto] = ACTIONS(2248),
    [anon_sym___try] = ACTIONS(2248),
    [anon_sym___leave] = ACTIONS(2248),
    [anon_sym_not] = ACTIONS(2248),
    [anon_sym_compl] = ACTIONS(2248),
    [anon_sym_DASH_DASH] = ACTIONS(2250),
    [anon_sym_PLUS_PLUS] = ACTIONS(2250),
    [anon_sym_sizeof] = ACTIONS(2248),
    [anon_sym___alignof__] = ACTIONS(2248),
    [anon_sym___alignof] = ACTIONS(2248),
    [anon_sym__alignof] = ACTIONS(2248),
    [anon_sym_alignof] = ACTIONS(2248),
    [anon_sym__Alignof] = ACTIONS(2248),
    [anon_sym_offsetof] = ACTIONS(2248),
    [anon_sym__Generic] = ACTIONS(2248),
    [anon_sym_asm] = ACTIONS(2248),
    [anon_sym___asm__] = ACTIONS(2248),
    [sym_number_literal] = ACTIONS(2250),
    [anon_sym_L_SQUOTE] = ACTIONS(2250),
    [anon_sym_u_SQUOTE] = ACTIONS(2250),
    [anon_sym_U_SQUOTE] = ACTIONS(2250),
    [anon_sym_u8_SQUOTE] = ACTIONS(2250),
    [anon_sym_SQUOTE] = ACTIONS(2250),
    [anon_sym_L_DQUOTE] = ACTIONS(2250),
    [anon_sym_u_DQUOTE] = ACTIONS(2250),
    [anon_sym_U_DQUOTE] = ACTIONS(2250),
    [anon_sym_u8_DQUOTE] = ACTIONS(2250),
    [anon_sym_DQUOTE] = ACTIONS(2250),
    [sym_true] = ACTIONS(2248),
    [sym_false] = ACTIONS(2248),
    [anon_sym_NULL] = ACTIONS(2248),
    [anon_sym_nullptr] = ACTIONS(2248),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2248),
    [anon_sym_decltype] = ACTIONS(2248),
    [sym_virtual] = ACTIONS(2248),
    [anon_sym_typename] = ACTIONS(2248),
    [anon_sym_template] = ACTIONS(2248),
    [anon_sym_try] = ACTIONS(2248),
    [anon_sym_delete] = ACTIONS(2248),
    [anon_sym_throw] = ACTIONS(2248),
    [anon_sym_co_return] = ACTIONS(2248),
    [anon_sym_co_yield] = ACTIONS(2248),
    [anon_sym_R_DQUOTE] = ACTIONS(2250),
    [anon_sym_LR_DQUOTE] = ACTIONS(2250),
    [anon_sym_uR_DQUOTE] = ACTIONS(2250),
    [anon_sym_UR_DQUOTE] = ACTIONS(2250),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2250),
    [anon_sym_co_await] = ACTIONS(2248),
    [anon_sym_new] = ACTIONS(2248),
    [anon_sym_requires] = ACTIONS(2248),
    [sym_this] = ACTIONS(2248),
    [anon_sym_discard] = ACTIONS(2248),
    [anon_sym_precise] = ACTIONS(2248),
    [anon_sym_shared] = ACTIONS(2248),
    [anon_sym_groupshared] = ACTIONS(2248),
    [anon_sym_uniform] = ACTIONS(2248),
    [anon_sym_row_major] = ACTIONS(2248),
    [anon_sym_column_major] = ACTIONS(2248),
    [anon_sym_globallycoherent] = ACTIONS(2248),
    [anon_sym_centroid] = ACTIONS(2248),
    [anon_sym_noperspective] = ACTIONS(2248),
    [anon_sym_nointerpolation] = ACTIONS(2248),
    [anon_sym_sample] = ACTIONS(2248),
    [anon_sym_linear] = ACTIONS(2248),
    [anon_sym_snorm] = ACTIONS(2248),
    [anon_sym_unorm] = ACTIONS(2248),
    [anon_sym_point] = ACTIONS(2248),
    [anon_sym_line] = ACTIONS(2248),
    [anon_sym_triangleadj] = ACTIONS(2248),
    [anon_sym_lineadj] = ACTIONS(2248),
    [anon_sym_triangle] = ACTIONS(2248),
    [anon_sym_cbuffer] = ACTIONS(2248),
  },
  [1005] = {
    [sym_identifier] = ACTIONS(2248),
    [anon_sym_LPAREN2] = ACTIONS(2250),
    [anon_sym_BANG] = ACTIONS(2250),
    [anon_sym_TILDE] = ACTIONS(2250),
    [anon_sym_DASH] = ACTIONS(2248),
    [anon_sym_PLUS] = ACTIONS(2248),
    [anon_sym_STAR] = ACTIONS(2250),
    [anon_sym_AMP] = ACTIONS(2250),
    [anon_sym_SEMI] = ACTIONS(2250),
    [anon_sym___extension__] = ACTIONS(2248),
    [anon_sym_typedef] = ACTIONS(2248),
    [anon_sym_in] = ACTIONS(2248),
    [anon_sym_out] = ACTIONS(2248),
    [anon_sym_inout] = ACTIONS(2248),
    [anon_sym_extern] = ACTIONS(2248),
    [anon_sym___attribute__] = ACTIONS(2248),
    [anon_sym_COLON_COLON] = ACTIONS(2250),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2250),
    [anon_sym___declspec] = ACTIONS(2248),
    [anon_sym_LBRACE] = ACTIONS(2250),
    [anon_sym_signed] = ACTIONS(2248),
    [anon_sym_unsigned] = ACTIONS(2248),
    [anon_sym_long] = ACTIONS(2248),
    [anon_sym_short] = ACTIONS(2248),
    [anon_sym_LBRACK] = ACTIONS(2248),
    [anon_sym_static] = ACTIONS(2248),
    [anon_sym_register] = ACTIONS(2248),
    [anon_sym_inline] = ACTIONS(2248),
    [anon_sym___inline] = ACTIONS(2248),
    [anon_sym___inline__] = ACTIONS(2248),
    [anon_sym___forceinline] = ACTIONS(2248),
    [anon_sym_thread_local] = ACTIONS(2248),
    [anon_sym___thread] = ACTIONS(2248),
    [anon_sym_const] = ACTIONS(2248),
    [anon_sym_constexpr] = ACTIONS(2248),
    [anon_sym_volatile] = ACTIONS(2248),
    [anon_sym_restrict] = ACTIONS(2248),
    [anon_sym___restrict__] = ACTIONS(2248),
    [anon_sym__Atomic] = ACTIONS(2248),
    [anon_sym__Noreturn] = ACTIONS(2248),
    [anon_sym_noreturn] = ACTIONS(2248),
    [anon_sym_mutable] = ACTIONS(2248),
    [anon_sym_constinit] = ACTIONS(2248),
    [anon_sym_consteval] = ACTIONS(2248),
    [anon_sym_alignas] = ACTIONS(2248),
    [anon_sym__Alignas] = ACTIONS(2248),
    [sym_primitive_type] = ACTIONS(2248),
    [anon_sym_enum] = ACTIONS(2248),
    [anon_sym_class] = ACTIONS(2248),
    [anon_sym_struct] = ACTIONS(2248),
    [anon_sym_union] = ACTIONS(2248),
    [anon_sym_if] = ACTIONS(2248),
    [anon_sym_else] = ACTIONS(2248),
    [anon_sym_switch] = ACTIONS(2248),
    [anon_sym_while] = ACTIONS(2248),
    [anon_sym_do] = ACTIONS(2248),
    [anon_sym_for] = ACTIONS(2248),
    [anon_sym_return] = ACTIONS(2248),
    [anon_sym_break] = ACTIONS(2248),
    [anon_sym_continue] = ACTIONS(2248),
    [anon_sym_goto] = ACTIONS(2248),
    [anon_sym___try] = ACTIONS(2248),
    [anon_sym___leave] = ACTIONS(2248),
    [anon_sym_not] = ACTIONS(2248),
    [anon_sym_compl] = ACTIONS(2248),
    [anon_sym_DASH_DASH] = ACTIONS(2250),
    [anon_sym_PLUS_PLUS] = ACTIONS(2250),
    [anon_sym_sizeof] = ACTIONS(2248),
    [anon_sym___alignof__] = ACTIONS(2248),
    [anon_sym___alignof] = ACTIONS(2248),
    [anon_sym__alignof] = ACTIONS(2248),
    [anon_sym_alignof] = ACTIONS(2248),
    [anon_sym__Alignof] = ACTIONS(2248),
    [anon_sym_offsetof] = ACTIONS(2248),
    [anon_sym__Generic] = ACTIONS(2248),
    [anon_sym_asm] = ACTIONS(2248),
    [anon_sym___asm__] = ACTIONS(2248),
    [sym_number_literal] = ACTIONS(2250),
    [anon_sym_L_SQUOTE] = ACTIONS(2250),
    [anon_sym_u_SQUOTE] = ACTIONS(2250),
    [anon_sym_U_SQUOTE] = ACTIONS(2250),
    [anon_sym_u8_SQUOTE] = ACTIONS(2250),
    [anon_sym_SQUOTE] = ACTIONS(2250),
    [anon_sym_L_DQUOTE] = ACTIONS(2250),
    [anon_sym_u_DQUOTE] = ACTIONS(2250),
    [anon_sym_U_DQUOTE] = ACTIONS(2250),
    [anon_sym_u8_DQUOTE] = ACTIONS(2250),
    [anon_sym_DQUOTE] = ACTIONS(2250),
    [sym_true] = ACTIONS(2248),
    [sym_false] = ACTIONS(2248),
    [anon_sym_NULL] = ACTIONS(2248),
    [anon_sym_nullptr] = ACTIONS(2248),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2248),
    [anon_sym_decltype] = ACTIONS(2248),
    [sym_virtual] = ACTIONS(2248),
    [anon_sym_typename] = ACTIONS(2248),
    [anon_sym_template] = ACTIONS(2248),
    [anon_sym_try] = ACTIONS(2248),
    [anon_sym_delete] = ACTIONS(2248),
    [anon_sym_throw] = ACTIONS(2248),
    [anon_sym_co_return] = ACTIONS(2248),
    [anon_sym_co_yield] = ACTIONS(2248),
    [anon_sym_R_DQUOTE] = ACTIONS(2250),
    [anon_sym_LR_DQUOTE] = ACTIONS(2250),
    [anon_sym_uR_DQUOTE] = ACTIONS(2250),
    [anon_sym_UR_DQUOTE] = ACTIONS(2250),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2250),
    [anon_sym_co_await] = ACTIONS(2248),
    [anon_sym_new] = ACTIONS(2248),
    [anon_sym_requires] = ACTIONS(2248),
    [sym_this] = ACTIONS(2248),
    [anon_sym_discard] = ACTIONS(2248),
    [anon_sym_precise] = ACTIONS(2248),
    [anon_sym_shared] = ACTIONS(2248),
    [anon_sym_groupshared] = ACTIONS(2248),
    [anon_sym_uniform] = ACTIONS(2248),
    [anon_sym_row_major] = ACTIONS(2248),
    [anon_sym_column_major] = ACTIONS(2248),
    [anon_sym_globallycoherent] = ACTIONS(2248),
    [anon_sym_centroid] = ACTIONS(2248),
    [anon_sym_noperspective] = ACTIONS(2248),
    [anon_sym_nointerpolation] = ACTIONS(2248),
    [anon_sym_sample] = ACTIONS(2248),
    [anon_sym_linear] = ACTIONS(2248),
    [anon_sym_snorm] = ACTIONS(2248),
    [anon_sym_unorm] = ACTIONS(2248),
    [anon_sym_point] = ACTIONS(2248),
    [anon_sym_line] = ACTIONS(2248),
    [anon_sym_triangleadj] = ACTIONS(2248),
    [anon_sym_lineadj] = ACTIONS(2248),
    [anon_sym_triangle] = ACTIONS(2248),
    [anon_sym_cbuffer] = ACTIONS(2248),
  },
  [1006] = {
    [sym_identifier] = ACTIONS(2260),
    [anon_sym_LPAREN2] = ACTIONS(2262),
    [anon_sym_BANG] = ACTIONS(2262),
    [anon_sym_TILDE] = ACTIONS(2262),
    [anon_sym_DASH] = ACTIONS(2260),
    [anon_sym_PLUS] = ACTIONS(2260),
    [anon_sym_STAR] = ACTIONS(2262),
    [anon_sym_AMP] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(2260),
    [anon_sym_typedef] = ACTIONS(2260),
    [anon_sym_in] = ACTIONS(2260),
    [anon_sym_out] = ACTIONS(2260),
    [anon_sym_inout] = ACTIONS(2260),
    [anon_sym_extern] = ACTIONS(2260),
    [anon_sym___attribute__] = ACTIONS(2260),
    [anon_sym_COLON_COLON] = ACTIONS(2262),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2262),
    [anon_sym___declspec] = ACTIONS(2260),
    [anon_sym_LBRACE] = ACTIONS(2262),
    [anon_sym_signed] = ACTIONS(2260),
    [anon_sym_unsigned] = ACTIONS(2260),
    [anon_sym_long] = ACTIONS(2260),
    [anon_sym_short] = ACTIONS(2260),
    [anon_sym_LBRACK] = ACTIONS(2260),
    [anon_sym_static] = ACTIONS(2260),
    [anon_sym_register] = ACTIONS(2260),
    [anon_sym_inline] = ACTIONS(2260),
    [anon_sym___inline] = ACTIONS(2260),
    [anon_sym___inline__] = ACTIONS(2260),
    [anon_sym___forceinline] = ACTIONS(2260),
    [anon_sym_thread_local] = ACTIONS(2260),
    [anon_sym___thread] = ACTIONS(2260),
    [anon_sym_const] = ACTIONS(2260),
    [anon_sym_constexpr] = ACTIONS(2260),
    [anon_sym_volatile] = ACTIONS(2260),
    [anon_sym_restrict] = ACTIONS(2260),
    [anon_sym___restrict__] = ACTIONS(2260),
    [anon_sym__Atomic] = ACTIONS(2260),
    [anon_sym__Noreturn] = ACTIONS(2260),
    [anon_sym_noreturn] = ACTIONS(2260),
    [anon_sym_mutable] = ACTIONS(2260),
    [anon_sym_constinit] = ACTIONS(2260),
    [anon_sym_consteval] = ACTIONS(2260),
    [anon_sym_alignas] = ACTIONS(2260),
    [anon_sym__Alignas] = ACTIONS(2260),
    [sym_primitive_type] = ACTIONS(2260),
    [anon_sym_enum] = ACTIONS(2260),
    [anon_sym_class] = ACTIONS(2260),
    [anon_sym_struct] = ACTIONS(2260),
    [anon_sym_union] = ACTIONS(2260),
    [anon_sym_if] = ACTIONS(2260),
    [anon_sym_else] = ACTIONS(2260),
    [anon_sym_switch] = ACTIONS(2260),
    [anon_sym_while] = ACTIONS(2260),
    [anon_sym_do] = ACTIONS(2260),
    [anon_sym_for] = ACTIONS(2260),
    [anon_sym_return] = ACTIONS(2260),
    [anon_sym_break] = ACTIONS(2260),
    [anon_sym_continue] = ACTIONS(2260),
    [anon_sym_goto] = ACTIONS(2260),
    [anon_sym___try] = ACTIONS(2260),
    [anon_sym___leave] = ACTIONS(2260),
    [anon_sym_not] = ACTIONS(2260),
    [anon_sym_compl] = ACTIONS(2260),
    [anon_sym_DASH_DASH] = ACTIONS(2262),
    [anon_sym_PLUS_PLUS] = ACTIONS(2262),
    [anon_sym_sizeof] = ACTIONS(2260),
    [anon_sym___alignof__] = ACTIONS(2260),
    [anon_sym___alignof] = ACTIONS(2260),
    [anon_sym__alignof] = ACTIONS(2260),
    [anon_sym_alignof] = ACTIONS(2260),
    [anon_sym__Alignof] = ACTIONS(2260),
    [anon_sym_offsetof] = ACTIONS(2260),
    [anon_sym__Generic] = ACTIONS(2260),
    [anon_sym_asm] = ACTIONS(2260),
    [anon_sym___asm__] = ACTIONS(2260),
    [sym_number_literal] = ACTIONS(2262),
    [anon_sym_L_SQUOTE] = ACTIONS(2262),
    [anon_sym_u_SQUOTE] = ACTIONS(2262),
    [anon_sym_U_SQUOTE] = ACTIONS(2262),
    [anon_sym_u8_SQUOTE] = ACTIONS(2262),
    [anon_sym_SQUOTE] = ACTIONS(2262),
    [anon_sym_L_DQUOTE] = ACTIONS(2262),
    [anon_sym_u_DQUOTE] = ACTIONS(2262),
    [anon_sym_U_DQUOTE] = ACTIONS(2262),
    [anon_sym_u8_DQUOTE] = ACTIONS(2262),
    [anon_sym_DQUOTE] = ACTIONS(2262),
    [sym_true] = ACTIONS(2260),
    [sym_false] = ACTIONS(2260),
    [anon_sym_NULL] = ACTIONS(2260),
    [anon_sym_nullptr] = ACTIONS(2260),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2260),
    [anon_sym_decltype] = ACTIONS(2260),
    [sym_virtual] = ACTIONS(2260),
    [anon_sym_typename] = ACTIONS(2260),
    [anon_sym_template] = ACTIONS(2260),
    [anon_sym_try] = ACTIONS(2260),
    [anon_sym_delete] = ACTIONS(2260),
    [anon_sym_throw] = ACTIONS(2260),
    [anon_sym_co_return] = ACTIONS(2260),
    [anon_sym_co_yield] = ACTIONS(2260),
    [anon_sym_R_DQUOTE] = ACTIONS(2262),
    [anon_sym_LR_DQUOTE] = ACTIONS(2262),
    [anon_sym_uR_DQUOTE] = ACTIONS(2262),
    [anon_sym_UR_DQUOTE] = ACTIONS(2262),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2262),
    [anon_sym_co_await] = ACTIONS(2260),
    [anon_sym_new] = ACTIONS(2260),
    [anon_sym_requires] = ACTIONS(2260),
    [sym_this] = ACTIONS(2260),
    [anon_sym_discard] = ACTIONS(2260),
    [anon_sym_precise] = ACTIONS(2260),
    [anon_sym_shared] = ACTIONS(2260),
    [anon_sym_groupshared] = ACTIONS(2260),
    [anon_sym_uniform] = ACTIONS(2260),
    [anon_sym_row_major] = ACTIONS(2260),
    [anon_sym_column_major] = ACTIONS(2260),
    [anon_sym_globallycoherent] = ACTIONS(2260),
    [anon_sym_centroid] = ACTIONS(2260),
    [anon_sym_noperspective] = ACTIONS(2260),
    [anon_sym_nointerpolation] = ACTIONS(2260),
    [anon_sym_sample] = ACTIONS(2260),
    [anon_sym_linear] = ACTIONS(2260),
    [anon_sym_snorm] = ACTIONS(2260),
    [anon_sym_unorm] = ACTIONS(2260),
    [anon_sym_point] = ACTIONS(2260),
    [anon_sym_line] = ACTIONS(2260),
    [anon_sym_triangleadj] = ACTIONS(2260),
    [anon_sym_lineadj] = ACTIONS(2260),
    [anon_sym_triangle] = ACTIONS(2260),
    [anon_sym_cbuffer] = ACTIONS(2260),
  },
  [1007] = {
    [sym_identifier] = ACTIONS(2098),
    [anon_sym_LPAREN2] = ACTIONS(2100),
    [anon_sym_BANG] = ACTIONS(2100),
    [anon_sym_TILDE] = ACTIONS(2100),
    [anon_sym_DASH] = ACTIONS(2098),
    [anon_sym_PLUS] = ACTIONS(2098),
    [anon_sym_STAR] = ACTIONS(2100),
    [anon_sym_AMP] = ACTIONS(2100),
    [anon_sym_SEMI] = ACTIONS(2100),
    [anon_sym___extension__] = ACTIONS(2098),
    [anon_sym_typedef] = ACTIONS(2098),
    [anon_sym_in] = ACTIONS(2098),
    [anon_sym_out] = ACTIONS(2098),
    [anon_sym_inout] = ACTIONS(2098),
    [anon_sym_extern] = ACTIONS(2098),
    [anon_sym___attribute__] = ACTIONS(2098),
    [anon_sym_COLON_COLON] = ACTIONS(2100),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2100),
    [anon_sym___declspec] = ACTIONS(2098),
    [anon_sym_LBRACE] = ACTIONS(2100),
    [anon_sym_signed] = ACTIONS(2098),
    [anon_sym_unsigned] = ACTIONS(2098),
    [anon_sym_long] = ACTIONS(2098),
    [anon_sym_short] = ACTIONS(2098),
    [anon_sym_LBRACK] = ACTIONS(2098),
    [anon_sym_static] = ACTIONS(2098),
    [anon_sym_register] = ACTIONS(2098),
    [anon_sym_inline] = ACTIONS(2098),
    [anon_sym___inline] = ACTIONS(2098),
    [anon_sym___inline__] = ACTIONS(2098),
    [anon_sym___forceinline] = ACTIONS(2098),
    [anon_sym_thread_local] = ACTIONS(2098),
    [anon_sym___thread] = ACTIONS(2098),
    [anon_sym_const] = ACTIONS(2098),
    [anon_sym_constexpr] = ACTIONS(2098),
    [anon_sym_volatile] = ACTIONS(2098),
    [anon_sym_restrict] = ACTIONS(2098),
    [anon_sym___restrict__] = ACTIONS(2098),
    [anon_sym__Atomic] = ACTIONS(2098),
    [anon_sym__Noreturn] = ACTIONS(2098),
    [anon_sym_noreturn] = ACTIONS(2098),
    [anon_sym_mutable] = ACTIONS(2098),
    [anon_sym_constinit] = ACTIONS(2098),
    [anon_sym_consteval] = ACTIONS(2098),
    [anon_sym_alignas] = ACTIONS(2098),
    [anon_sym__Alignas] = ACTIONS(2098),
    [sym_primitive_type] = ACTIONS(2098),
    [anon_sym_enum] = ACTIONS(2098),
    [anon_sym_class] = ACTIONS(2098),
    [anon_sym_struct] = ACTIONS(2098),
    [anon_sym_union] = ACTIONS(2098),
    [anon_sym_if] = ACTIONS(2098),
    [anon_sym_else] = ACTIONS(2098),
    [anon_sym_switch] = ACTIONS(2098),
    [anon_sym_while] = ACTIONS(2098),
    [anon_sym_do] = ACTIONS(2098),
    [anon_sym_for] = ACTIONS(2098),
    [anon_sym_return] = ACTIONS(2098),
    [anon_sym_break] = ACTIONS(2098),
    [anon_sym_continue] = ACTIONS(2098),
    [anon_sym_goto] = ACTIONS(2098),
    [anon_sym___try] = ACTIONS(2098),
    [anon_sym___leave] = ACTIONS(2098),
    [anon_sym_not] = ACTIONS(2098),
    [anon_sym_compl] = ACTIONS(2098),
    [anon_sym_DASH_DASH] = ACTIONS(2100),
    [anon_sym_PLUS_PLUS] = ACTIONS(2100),
    [anon_sym_sizeof] = ACTIONS(2098),
    [anon_sym___alignof__] = ACTIONS(2098),
    [anon_sym___alignof] = ACTIONS(2098),
    [anon_sym__alignof] = ACTIONS(2098),
    [anon_sym_alignof] = ACTIONS(2098),
    [anon_sym__Alignof] = ACTIONS(2098),
    [anon_sym_offsetof] = ACTIONS(2098),
    [anon_sym__Generic] = ACTIONS(2098),
    [anon_sym_asm] = ACTIONS(2098),
    [anon_sym___asm__] = ACTIONS(2098),
    [sym_number_literal] = ACTIONS(2100),
    [anon_sym_L_SQUOTE] = ACTIONS(2100),
    [anon_sym_u_SQUOTE] = ACTIONS(2100),
    [anon_sym_U_SQUOTE] = ACTIONS(2100),
    [anon_sym_u8_SQUOTE] = ACTIONS(2100),
    [anon_sym_SQUOTE] = ACTIONS(2100),
    [anon_sym_L_DQUOTE] = ACTIONS(2100),
    [anon_sym_u_DQUOTE] = ACTIONS(2100),
    [anon_sym_U_DQUOTE] = ACTIONS(2100),
    [anon_sym_u8_DQUOTE] = ACTIONS(2100),
    [anon_sym_DQUOTE] = ACTIONS(2100),
    [sym_true] = ACTIONS(2098),
    [sym_false] = ACTIONS(2098),
    [anon_sym_NULL] = ACTIONS(2098),
    [anon_sym_nullptr] = ACTIONS(2098),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2098),
    [anon_sym_decltype] = ACTIONS(2098),
    [sym_virtual] = ACTIONS(2098),
    [anon_sym_typename] = ACTIONS(2098),
    [anon_sym_template] = ACTIONS(2098),
    [anon_sym_try] = ACTIONS(2098),
    [anon_sym_delete] = ACTIONS(2098),
    [anon_sym_throw] = ACTIONS(2098),
    [anon_sym_co_return] = ACTIONS(2098),
    [anon_sym_co_yield] = ACTIONS(2098),
    [anon_sym_R_DQUOTE] = ACTIONS(2100),
    [anon_sym_LR_DQUOTE] = ACTIONS(2100),
    [anon_sym_uR_DQUOTE] = ACTIONS(2100),
    [anon_sym_UR_DQUOTE] = ACTIONS(2100),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2100),
    [anon_sym_co_await] = ACTIONS(2098),
    [anon_sym_new] = ACTIONS(2098),
    [anon_sym_requires] = ACTIONS(2098),
    [sym_this] = ACTIONS(2098),
    [anon_sym_discard] = ACTIONS(2098),
    [anon_sym_precise] = ACTIONS(2098),
    [anon_sym_shared] = ACTIONS(2098),
    [anon_sym_groupshared] = ACTIONS(2098),
    [anon_sym_uniform] = ACTIONS(2098),
    [anon_sym_row_major] = ACTIONS(2098),
    [anon_sym_column_major] = ACTIONS(2098),
    [anon_sym_globallycoherent] = ACTIONS(2098),
    [anon_sym_centroid] = ACTIONS(2098),
    [anon_sym_noperspective] = ACTIONS(2098),
    [anon_sym_nointerpolation] = ACTIONS(2098),
    [anon_sym_sample] = ACTIONS(2098),
    [anon_sym_linear] = ACTIONS(2098),
    [anon_sym_snorm] = ACTIONS(2098),
    [anon_sym_unorm] = ACTIONS(2098),
    [anon_sym_point] = ACTIONS(2098),
    [anon_sym_line] = ACTIONS(2098),
    [anon_sym_triangleadj] = ACTIONS(2098),
    [anon_sym_lineadj] = ACTIONS(2098),
    [anon_sym_triangle] = ACTIONS(2098),
    [anon_sym_cbuffer] = ACTIONS(2098),
  },
  [1008] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(4652),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_type_descriptor] = STATE(7855),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5574),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3922),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3924),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1009] = {
    [sym_identifier] = ACTIONS(2252),
    [anon_sym_LPAREN2] = ACTIONS(2254),
    [anon_sym_BANG] = ACTIONS(2254),
    [anon_sym_TILDE] = ACTIONS(2254),
    [anon_sym_DASH] = ACTIONS(2252),
    [anon_sym_PLUS] = ACTIONS(2252),
    [anon_sym_STAR] = ACTIONS(2254),
    [anon_sym_AMP] = ACTIONS(2254),
    [anon_sym_SEMI] = ACTIONS(2254),
    [anon_sym___extension__] = ACTIONS(2252),
    [anon_sym_typedef] = ACTIONS(2252),
    [anon_sym_in] = ACTIONS(2252),
    [anon_sym_out] = ACTIONS(2252),
    [anon_sym_inout] = ACTIONS(2252),
    [anon_sym_extern] = ACTIONS(2252),
    [anon_sym___attribute__] = ACTIONS(2252),
    [anon_sym_COLON_COLON] = ACTIONS(2254),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2254),
    [anon_sym___declspec] = ACTIONS(2252),
    [anon_sym_LBRACE] = ACTIONS(2254),
    [anon_sym_signed] = ACTIONS(2252),
    [anon_sym_unsigned] = ACTIONS(2252),
    [anon_sym_long] = ACTIONS(2252),
    [anon_sym_short] = ACTIONS(2252),
    [anon_sym_LBRACK] = ACTIONS(2252),
    [anon_sym_static] = ACTIONS(2252),
    [anon_sym_register] = ACTIONS(2252),
    [anon_sym_inline] = ACTIONS(2252),
    [anon_sym___inline] = ACTIONS(2252),
    [anon_sym___inline__] = ACTIONS(2252),
    [anon_sym___forceinline] = ACTIONS(2252),
    [anon_sym_thread_local] = ACTIONS(2252),
    [anon_sym___thread] = ACTIONS(2252),
    [anon_sym_const] = ACTIONS(2252),
    [anon_sym_constexpr] = ACTIONS(2252),
    [anon_sym_volatile] = ACTIONS(2252),
    [anon_sym_restrict] = ACTIONS(2252),
    [anon_sym___restrict__] = ACTIONS(2252),
    [anon_sym__Atomic] = ACTIONS(2252),
    [anon_sym__Noreturn] = ACTIONS(2252),
    [anon_sym_noreturn] = ACTIONS(2252),
    [anon_sym_mutable] = ACTIONS(2252),
    [anon_sym_constinit] = ACTIONS(2252),
    [anon_sym_consteval] = ACTIONS(2252),
    [anon_sym_alignas] = ACTIONS(2252),
    [anon_sym__Alignas] = ACTIONS(2252),
    [sym_primitive_type] = ACTIONS(2252),
    [anon_sym_enum] = ACTIONS(2252),
    [anon_sym_class] = ACTIONS(2252),
    [anon_sym_struct] = ACTIONS(2252),
    [anon_sym_union] = ACTIONS(2252),
    [anon_sym_if] = ACTIONS(2252),
    [anon_sym_else] = ACTIONS(2252),
    [anon_sym_switch] = ACTIONS(2252),
    [anon_sym_while] = ACTIONS(2252),
    [anon_sym_do] = ACTIONS(2252),
    [anon_sym_for] = ACTIONS(2252),
    [anon_sym_return] = ACTIONS(2252),
    [anon_sym_break] = ACTIONS(2252),
    [anon_sym_continue] = ACTIONS(2252),
    [anon_sym_goto] = ACTIONS(2252),
    [anon_sym___try] = ACTIONS(2252),
    [anon_sym___leave] = ACTIONS(2252),
    [anon_sym_not] = ACTIONS(2252),
    [anon_sym_compl] = ACTIONS(2252),
    [anon_sym_DASH_DASH] = ACTIONS(2254),
    [anon_sym_PLUS_PLUS] = ACTIONS(2254),
    [anon_sym_sizeof] = ACTIONS(2252),
    [anon_sym___alignof__] = ACTIONS(2252),
    [anon_sym___alignof] = ACTIONS(2252),
    [anon_sym__alignof] = ACTIONS(2252),
    [anon_sym_alignof] = ACTIONS(2252),
    [anon_sym__Alignof] = ACTIONS(2252),
    [anon_sym_offsetof] = ACTIONS(2252),
    [anon_sym__Generic] = ACTIONS(2252),
    [anon_sym_asm] = ACTIONS(2252),
    [anon_sym___asm__] = ACTIONS(2252),
    [sym_number_literal] = ACTIONS(2254),
    [anon_sym_L_SQUOTE] = ACTIONS(2254),
    [anon_sym_u_SQUOTE] = ACTIONS(2254),
    [anon_sym_U_SQUOTE] = ACTIONS(2254),
    [anon_sym_u8_SQUOTE] = ACTIONS(2254),
    [anon_sym_SQUOTE] = ACTIONS(2254),
    [anon_sym_L_DQUOTE] = ACTIONS(2254),
    [anon_sym_u_DQUOTE] = ACTIONS(2254),
    [anon_sym_U_DQUOTE] = ACTIONS(2254),
    [anon_sym_u8_DQUOTE] = ACTIONS(2254),
    [anon_sym_DQUOTE] = ACTIONS(2254),
    [sym_true] = ACTIONS(2252),
    [sym_false] = ACTIONS(2252),
    [anon_sym_NULL] = ACTIONS(2252),
    [anon_sym_nullptr] = ACTIONS(2252),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2252),
    [anon_sym_decltype] = ACTIONS(2252),
    [sym_virtual] = ACTIONS(2252),
    [anon_sym_typename] = ACTIONS(2252),
    [anon_sym_template] = ACTIONS(2252),
    [anon_sym_try] = ACTIONS(2252),
    [anon_sym_delete] = ACTIONS(2252),
    [anon_sym_throw] = ACTIONS(2252),
    [anon_sym_co_return] = ACTIONS(2252),
    [anon_sym_co_yield] = ACTIONS(2252),
    [anon_sym_R_DQUOTE] = ACTIONS(2254),
    [anon_sym_LR_DQUOTE] = ACTIONS(2254),
    [anon_sym_uR_DQUOTE] = ACTIONS(2254),
    [anon_sym_UR_DQUOTE] = ACTIONS(2254),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2254),
    [anon_sym_co_await] = ACTIONS(2252),
    [anon_sym_new] = ACTIONS(2252),
    [anon_sym_requires] = ACTIONS(2252),
    [sym_this] = ACTIONS(2252),
    [anon_sym_discard] = ACTIONS(2252),
    [anon_sym_precise] = ACTIONS(2252),
    [anon_sym_shared] = ACTIONS(2252),
    [anon_sym_groupshared] = ACTIONS(2252),
    [anon_sym_uniform] = ACTIONS(2252),
    [anon_sym_row_major] = ACTIONS(2252),
    [anon_sym_column_major] = ACTIONS(2252),
    [anon_sym_globallycoherent] = ACTIONS(2252),
    [anon_sym_centroid] = ACTIONS(2252),
    [anon_sym_noperspective] = ACTIONS(2252),
    [anon_sym_nointerpolation] = ACTIONS(2252),
    [anon_sym_sample] = ACTIONS(2252),
    [anon_sym_linear] = ACTIONS(2252),
    [anon_sym_snorm] = ACTIONS(2252),
    [anon_sym_unorm] = ACTIONS(2252),
    [anon_sym_point] = ACTIONS(2252),
    [anon_sym_line] = ACTIONS(2252),
    [anon_sym_triangleadj] = ACTIONS(2252),
    [anon_sym_lineadj] = ACTIONS(2252),
    [anon_sym_triangle] = ACTIONS(2252),
    [anon_sym_cbuffer] = ACTIONS(2252),
  },
  [1010] = {
    [sym_identifier] = ACTIONS(2204),
    [anon_sym_LPAREN2] = ACTIONS(2206),
    [anon_sym_BANG] = ACTIONS(2206),
    [anon_sym_TILDE] = ACTIONS(2206),
    [anon_sym_DASH] = ACTIONS(2204),
    [anon_sym_PLUS] = ACTIONS(2204),
    [anon_sym_STAR] = ACTIONS(2206),
    [anon_sym_AMP] = ACTIONS(2206),
    [anon_sym_SEMI] = ACTIONS(2206),
    [anon_sym___extension__] = ACTIONS(2204),
    [anon_sym_typedef] = ACTIONS(2204),
    [anon_sym_in] = ACTIONS(2204),
    [anon_sym_out] = ACTIONS(2204),
    [anon_sym_inout] = ACTIONS(2204),
    [anon_sym_extern] = ACTIONS(2204),
    [anon_sym___attribute__] = ACTIONS(2204),
    [anon_sym_COLON_COLON] = ACTIONS(2206),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2206),
    [anon_sym___declspec] = ACTIONS(2204),
    [anon_sym_LBRACE] = ACTIONS(2206),
    [anon_sym_signed] = ACTIONS(2204),
    [anon_sym_unsigned] = ACTIONS(2204),
    [anon_sym_long] = ACTIONS(2204),
    [anon_sym_short] = ACTIONS(2204),
    [anon_sym_LBRACK] = ACTIONS(2204),
    [anon_sym_static] = ACTIONS(2204),
    [anon_sym_register] = ACTIONS(2204),
    [anon_sym_inline] = ACTIONS(2204),
    [anon_sym___inline] = ACTIONS(2204),
    [anon_sym___inline__] = ACTIONS(2204),
    [anon_sym___forceinline] = ACTIONS(2204),
    [anon_sym_thread_local] = ACTIONS(2204),
    [anon_sym___thread] = ACTIONS(2204),
    [anon_sym_const] = ACTIONS(2204),
    [anon_sym_constexpr] = ACTIONS(2204),
    [anon_sym_volatile] = ACTIONS(2204),
    [anon_sym_restrict] = ACTIONS(2204),
    [anon_sym___restrict__] = ACTIONS(2204),
    [anon_sym__Atomic] = ACTIONS(2204),
    [anon_sym__Noreturn] = ACTIONS(2204),
    [anon_sym_noreturn] = ACTIONS(2204),
    [anon_sym_mutable] = ACTIONS(2204),
    [anon_sym_constinit] = ACTIONS(2204),
    [anon_sym_consteval] = ACTIONS(2204),
    [anon_sym_alignas] = ACTIONS(2204),
    [anon_sym__Alignas] = ACTIONS(2204),
    [sym_primitive_type] = ACTIONS(2204),
    [anon_sym_enum] = ACTIONS(2204),
    [anon_sym_class] = ACTIONS(2204),
    [anon_sym_struct] = ACTIONS(2204),
    [anon_sym_union] = ACTIONS(2204),
    [anon_sym_if] = ACTIONS(2204),
    [anon_sym_else] = ACTIONS(2204),
    [anon_sym_switch] = ACTIONS(2204),
    [anon_sym_while] = ACTIONS(2204),
    [anon_sym_do] = ACTIONS(2204),
    [anon_sym_for] = ACTIONS(2204),
    [anon_sym_return] = ACTIONS(2204),
    [anon_sym_break] = ACTIONS(2204),
    [anon_sym_continue] = ACTIONS(2204),
    [anon_sym_goto] = ACTIONS(2204),
    [anon_sym___try] = ACTIONS(2204),
    [anon_sym___leave] = ACTIONS(2204),
    [anon_sym_not] = ACTIONS(2204),
    [anon_sym_compl] = ACTIONS(2204),
    [anon_sym_DASH_DASH] = ACTIONS(2206),
    [anon_sym_PLUS_PLUS] = ACTIONS(2206),
    [anon_sym_sizeof] = ACTIONS(2204),
    [anon_sym___alignof__] = ACTIONS(2204),
    [anon_sym___alignof] = ACTIONS(2204),
    [anon_sym__alignof] = ACTIONS(2204),
    [anon_sym_alignof] = ACTIONS(2204),
    [anon_sym__Alignof] = ACTIONS(2204),
    [anon_sym_offsetof] = ACTIONS(2204),
    [anon_sym__Generic] = ACTIONS(2204),
    [anon_sym_asm] = ACTIONS(2204),
    [anon_sym___asm__] = ACTIONS(2204),
    [sym_number_literal] = ACTIONS(2206),
    [anon_sym_L_SQUOTE] = ACTIONS(2206),
    [anon_sym_u_SQUOTE] = ACTIONS(2206),
    [anon_sym_U_SQUOTE] = ACTIONS(2206),
    [anon_sym_u8_SQUOTE] = ACTIONS(2206),
    [anon_sym_SQUOTE] = ACTIONS(2206),
    [anon_sym_L_DQUOTE] = ACTIONS(2206),
    [anon_sym_u_DQUOTE] = ACTIONS(2206),
    [anon_sym_U_DQUOTE] = ACTIONS(2206),
    [anon_sym_u8_DQUOTE] = ACTIONS(2206),
    [anon_sym_DQUOTE] = ACTIONS(2206),
    [sym_true] = ACTIONS(2204),
    [sym_false] = ACTIONS(2204),
    [anon_sym_NULL] = ACTIONS(2204),
    [anon_sym_nullptr] = ACTIONS(2204),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2204),
    [anon_sym_decltype] = ACTIONS(2204),
    [sym_virtual] = ACTIONS(2204),
    [anon_sym_typename] = ACTIONS(2204),
    [anon_sym_template] = ACTIONS(2204),
    [anon_sym_try] = ACTIONS(2204),
    [anon_sym_delete] = ACTIONS(2204),
    [anon_sym_throw] = ACTIONS(2204),
    [anon_sym_co_return] = ACTIONS(2204),
    [anon_sym_co_yield] = ACTIONS(2204),
    [anon_sym_R_DQUOTE] = ACTIONS(2206),
    [anon_sym_LR_DQUOTE] = ACTIONS(2206),
    [anon_sym_uR_DQUOTE] = ACTIONS(2206),
    [anon_sym_UR_DQUOTE] = ACTIONS(2206),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2206),
    [anon_sym_co_await] = ACTIONS(2204),
    [anon_sym_new] = ACTIONS(2204),
    [anon_sym_requires] = ACTIONS(2204),
    [sym_this] = ACTIONS(2204),
    [anon_sym_discard] = ACTIONS(2204),
    [anon_sym_precise] = ACTIONS(2204),
    [anon_sym_shared] = ACTIONS(2204),
    [anon_sym_groupshared] = ACTIONS(2204),
    [anon_sym_uniform] = ACTIONS(2204),
    [anon_sym_row_major] = ACTIONS(2204),
    [anon_sym_column_major] = ACTIONS(2204),
    [anon_sym_globallycoherent] = ACTIONS(2204),
    [anon_sym_centroid] = ACTIONS(2204),
    [anon_sym_noperspective] = ACTIONS(2204),
    [anon_sym_nointerpolation] = ACTIONS(2204),
    [anon_sym_sample] = ACTIONS(2204),
    [anon_sym_linear] = ACTIONS(2204),
    [anon_sym_snorm] = ACTIONS(2204),
    [anon_sym_unorm] = ACTIONS(2204),
    [anon_sym_point] = ACTIONS(2204),
    [anon_sym_line] = ACTIONS(2204),
    [anon_sym_triangleadj] = ACTIONS(2204),
    [anon_sym_lineadj] = ACTIONS(2204),
    [anon_sym_triangle] = ACTIONS(2204),
    [anon_sym_cbuffer] = ACTIONS(2204),
  },
  [1011] = {
    [sym_identifier] = ACTIONS(2216),
    [anon_sym_LPAREN2] = ACTIONS(2218),
    [anon_sym_BANG] = ACTIONS(2218),
    [anon_sym_TILDE] = ACTIONS(2218),
    [anon_sym_DASH] = ACTIONS(2216),
    [anon_sym_PLUS] = ACTIONS(2216),
    [anon_sym_STAR] = ACTIONS(2218),
    [anon_sym_AMP] = ACTIONS(2218),
    [anon_sym_SEMI] = ACTIONS(2218),
    [anon_sym___extension__] = ACTIONS(2216),
    [anon_sym_typedef] = ACTIONS(2216),
    [anon_sym_in] = ACTIONS(2216),
    [anon_sym_out] = ACTIONS(2216),
    [anon_sym_inout] = ACTIONS(2216),
    [anon_sym_extern] = ACTIONS(2216),
    [anon_sym___attribute__] = ACTIONS(2216),
    [anon_sym_COLON_COLON] = ACTIONS(2218),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2218),
    [anon_sym___declspec] = ACTIONS(2216),
    [anon_sym_LBRACE] = ACTIONS(2218),
    [anon_sym_signed] = ACTIONS(2216),
    [anon_sym_unsigned] = ACTIONS(2216),
    [anon_sym_long] = ACTIONS(2216),
    [anon_sym_short] = ACTIONS(2216),
    [anon_sym_LBRACK] = ACTIONS(2216),
    [anon_sym_static] = ACTIONS(2216),
    [anon_sym_register] = ACTIONS(2216),
    [anon_sym_inline] = ACTIONS(2216),
    [anon_sym___inline] = ACTIONS(2216),
    [anon_sym___inline__] = ACTIONS(2216),
    [anon_sym___forceinline] = ACTIONS(2216),
    [anon_sym_thread_local] = ACTIONS(2216),
    [anon_sym___thread] = ACTIONS(2216),
    [anon_sym_const] = ACTIONS(2216),
    [anon_sym_constexpr] = ACTIONS(2216),
    [anon_sym_volatile] = ACTIONS(2216),
    [anon_sym_restrict] = ACTIONS(2216),
    [anon_sym___restrict__] = ACTIONS(2216),
    [anon_sym__Atomic] = ACTIONS(2216),
    [anon_sym__Noreturn] = ACTIONS(2216),
    [anon_sym_noreturn] = ACTIONS(2216),
    [anon_sym_mutable] = ACTIONS(2216),
    [anon_sym_constinit] = ACTIONS(2216),
    [anon_sym_consteval] = ACTIONS(2216),
    [anon_sym_alignas] = ACTIONS(2216),
    [anon_sym__Alignas] = ACTIONS(2216),
    [sym_primitive_type] = ACTIONS(2216),
    [anon_sym_enum] = ACTIONS(2216),
    [anon_sym_class] = ACTIONS(2216),
    [anon_sym_struct] = ACTIONS(2216),
    [anon_sym_union] = ACTIONS(2216),
    [anon_sym_if] = ACTIONS(2216),
    [anon_sym_else] = ACTIONS(2216),
    [anon_sym_switch] = ACTIONS(2216),
    [anon_sym_while] = ACTIONS(2216),
    [anon_sym_do] = ACTIONS(2216),
    [anon_sym_for] = ACTIONS(2216),
    [anon_sym_return] = ACTIONS(2216),
    [anon_sym_break] = ACTIONS(2216),
    [anon_sym_continue] = ACTIONS(2216),
    [anon_sym_goto] = ACTIONS(2216),
    [anon_sym___try] = ACTIONS(2216),
    [anon_sym___leave] = ACTIONS(2216),
    [anon_sym_not] = ACTIONS(2216),
    [anon_sym_compl] = ACTIONS(2216),
    [anon_sym_DASH_DASH] = ACTIONS(2218),
    [anon_sym_PLUS_PLUS] = ACTIONS(2218),
    [anon_sym_sizeof] = ACTIONS(2216),
    [anon_sym___alignof__] = ACTIONS(2216),
    [anon_sym___alignof] = ACTIONS(2216),
    [anon_sym__alignof] = ACTIONS(2216),
    [anon_sym_alignof] = ACTIONS(2216),
    [anon_sym__Alignof] = ACTIONS(2216),
    [anon_sym_offsetof] = ACTIONS(2216),
    [anon_sym__Generic] = ACTIONS(2216),
    [anon_sym_asm] = ACTIONS(2216),
    [anon_sym___asm__] = ACTIONS(2216),
    [sym_number_literal] = ACTIONS(2218),
    [anon_sym_L_SQUOTE] = ACTIONS(2218),
    [anon_sym_u_SQUOTE] = ACTIONS(2218),
    [anon_sym_U_SQUOTE] = ACTIONS(2218),
    [anon_sym_u8_SQUOTE] = ACTIONS(2218),
    [anon_sym_SQUOTE] = ACTIONS(2218),
    [anon_sym_L_DQUOTE] = ACTIONS(2218),
    [anon_sym_u_DQUOTE] = ACTIONS(2218),
    [anon_sym_U_DQUOTE] = ACTIONS(2218),
    [anon_sym_u8_DQUOTE] = ACTIONS(2218),
    [anon_sym_DQUOTE] = ACTIONS(2218),
    [sym_true] = ACTIONS(2216),
    [sym_false] = ACTIONS(2216),
    [anon_sym_NULL] = ACTIONS(2216),
    [anon_sym_nullptr] = ACTIONS(2216),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2216),
    [anon_sym_decltype] = ACTIONS(2216),
    [sym_virtual] = ACTIONS(2216),
    [anon_sym_typename] = ACTIONS(2216),
    [anon_sym_template] = ACTIONS(2216),
    [anon_sym_try] = ACTIONS(2216),
    [anon_sym_delete] = ACTIONS(2216),
    [anon_sym_throw] = ACTIONS(2216),
    [anon_sym_co_return] = ACTIONS(2216),
    [anon_sym_co_yield] = ACTIONS(2216),
    [anon_sym_R_DQUOTE] = ACTIONS(2218),
    [anon_sym_LR_DQUOTE] = ACTIONS(2218),
    [anon_sym_uR_DQUOTE] = ACTIONS(2218),
    [anon_sym_UR_DQUOTE] = ACTIONS(2218),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2218),
    [anon_sym_co_await] = ACTIONS(2216),
    [anon_sym_new] = ACTIONS(2216),
    [anon_sym_requires] = ACTIONS(2216),
    [sym_this] = ACTIONS(2216),
    [anon_sym_discard] = ACTIONS(2216),
    [anon_sym_precise] = ACTIONS(2216),
    [anon_sym_shared] = ACTIONS(2216),
    [anon_sym_groupshared] = ACTIONS(2216),
    [anon_sym_uniform] = ACTIONS(2216),
    [anon_sym_row_major] = ACTIONS(2216),
    [anon_sym_column_major] = ACTIONS(2216),
    [anon_sym_globallycoherent] = ACTIONS(2216),
    [anon_sym_centroid] = ACTIONS(2216),
    [anon_sym_noperspective] = ACTIONS(2216),
    [anon_sym_nointerpolation] = ACTIONS(2216),
    [anon_sym_sample] = ACTIONS(2216),
    [anon_sym_linear] = ACTIONS(2216),
    [anon_sym_snorm] = ACTIONS(2216),
    [anon_sym_unorm] = ACTIONS(2216),
    [anon_sym_point] = ACTIONS(2216),
    [anon_sym_line] = ACTIONS(2216),
    [anon_sym_triangleadj] = ACTIONS(2216),
    [anon_sym_lineadj] = ACTIONS(2216),
    [anon_sym_triangle] = ACTIONS(2216),
    [anon_sym_cbuffer] = ACTIONS(2216),
  },
  [1012] = {
    [sym_identifier] = ACTIONS(2220),
    [anon_sym_LPAREN2] = ACTIONS(2222),
    [anon_sym_BANG] = ACTIONS(2222),
    [anon_sym_TILDE] = ACTIONS(2222),
    [anon_sym_DASH] = ACTIONS(2220),
    [anon_sym_PLUS] = ACTIONS(2220),
    [anon_sym_STAR] = ACTIONS(2222),
    [anon_sym_AMP] = ACTIONS(2222),
    [anon_sym_SEMI] = ACTIONS(2222),
    [anon_sym___extension__] = ACTIONS(2220),
    [anon_sym_typedef] = ACTIONS(2220),
    [anon_sym_in] = ACTIONS(2220),
    [anon_sym_out] = ACTIONS(2220),
    [anon_sym_inout] = ACTIONS(2220),
    [anon_sym_extern] = ACTIONS(2220),
    [anon_sym___attribute__] = ACTIONS(2220),
    [anon_sym_COLON_COLON] = ACTIONS(2222),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2222),
    [anon_sym___declspec] = ACTIONS(2220),
    [anon_sym_LBRACE] = ACTIONS(2222),
    [anon_sym_signed] = ACTIONS(2220),
    [anon_sym_unsigned] = ACTIONS(2220),
    [anon_sym_long] = ACTIONS(2220),
    [anon_sym_short] = ACTIONS(2220),
    [anon_sym_LBRACK] = ACTIONS(2220),
    [anon_sym_static] = ACTIONS(2220),
    [anon_sym_register] = ACTIONS(2220),
    [anon_sym_inline] = ACTIONS(2220),
    [anon_sym___inline] = ACTIONS(2220),
    [anon_sym___inline__] = ACTIONS(2220),
    [anon_sym___forceinline] = ACTIONS(2220),
    [anon_sym_thread_local] = ACTIONS(2220),
    [anon_sym___thread] = ACTIONS(2220),
    [anon_sym_const] = ACTIONS(2220),
    [anon_sym_constexpr] = ACTIONS(2220),
    [anon_sym_volatile] = ACTIONS(2220),
    [anon_sym_restrict] = ACTIONS(2220),
    [anon_sym___restrict__] = ACTIONS(2220),
    [anon_sym__Atomic] = ACTIONS(2220),
    [anon_sym__Noreturn] = ACTIONS(2220),
    [anon_sym_noreturn] = ACTIONS(2220),
    [anon_sym_mutable] = ACTIONS(2220),
    [anon_sym_constinit] = ACTIONS(2220),
    [anon_sym_consteval] = ACTIONS(2220),
    [anon_sym_alignas] = ACTIONS(2220),
    [anon_sym__Alignas] = ACTIONS(2220),
    [sym_primitive_type] = ACTIONS(2220),
    [anon_sym_enum] = ACTIONS(2220),
    [anon_sym_class] = ACTIONS(2220),
    [anon_sym_struct] = ACTIONS(2220),
    [anon_sym_union] = ACTIONS(2220),
    [anon_sym_if] = ACTIONS(2220),
    [anon_sym_else] = ACTIONS(2220),
    [anon_sym_switch] = ACTIONS(2220),
    [anon_sym_while] = ACTIONS(2220),
    [anon_sym_do] = ACTIONS(2220),
    [anon_sym_for] = ACTIONS(2220),
    [anon_sym_return] = ACTIONS(2220),
    [anon_sym_break] = ACTIONS(2220),
    [anon_sym_continue] = ACTIONS(2220),
    [anon_sym_goto] = ACTIONS(2220),
    [anon_sym___try] = ACTIONS(2220),
    [anon_sym___leave] = ACTIONS(2220),
    [anon_sym_not] = ACTIONS(2220),
    [anon_sym_compl] = ACTIONS(2220),
    [anon_sym_DASH_DASH] = ACTIONS(2222),
    [anon_sym_PLUS_PLUS] = ACTIONS(2222),
    [anon_sym_sizeof] = ACTIONS(2220),
    [anon_sym___alignof__] = ACTIONS(2220),
    [anon_sym___alignof] = ACTIONS(2220),
    [anon_sym__alignof] = ACTIONS(2220),
    [anon_sym_alignof] = ACTIONS(2220),
    [anon_sym__Alignof] = ACTIONS(2220),
    [anon_sym_offsetof] = ACTIONS(2220),
    [anon_sym__Generic] = ACTIONS(2220),
    [anon_sym_asm] = ACTIONS(2220),
    [anon_sym___asm__] = ACTIONS(2220),
    [sym_number_literal] = ACTIONS(2222),
    [anon_sym_L_SQUOTE] = ACTIONS(2222),
    [anon_sym_u_SQUOTE] = ACTIONS(2222),
    [anon_sym_U_SQUOTE] = ACTIONS(2222),
    [anon_sym_u8_SQUOTE] = ACTIONS(2222),
    [anon_sym_SQUOTE] = ACTIONS(2222),
    [anon_sym_L_DQUOTE] = ACTIONS(2222),
    [anon_sym_u_DQUOTE] = ACTIONS(2222),
    [anon_sym_U_DQUOTE] = ACTIONS(2222),
    [anon_sym_u8_DQUOTE] = ACTIONS(2222),
    [anon_sym_DQUOTE] = ACTIONS(2222),
    [sym_true] = ACTIONS(2220),
    [sym_false] = ACTIONS(2220),
    [anon_sym_NULL] = ACTIONS(2220),
    [anon_sym_nullptr] = ACTIONS(2220),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2220),
    [anon_sym_decltype] = ACTIONS(2220),
    [sym_virtual] = ACTIONS(2220),
    [anon_sym_typename] = ACTIONS(2220),
    [anon_sym_template] = ACTIONS(2220),
    [anon_sym_try] = ACTIONS(2220),
    [anon_sym_delete] = ACTIONS(2220),
    [anon_sym_throw] = ACTIONS(2220),
    [anon_sym_co_return] = ACTIONS(2220),
    [anon_sym_co_yield] = ACTIONS(2220),
    [anon_sym_R_DQUOTE] = ACTIONS(2222),
    [anon_sym_LR_DQUOTE] = ACTIONS(2222),
    [anon_sym_uR_DQUOTE] = ACTIONS(2222),
    [anon_sym_UR_DQUOTE] = ACTIONS(2222),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2222),
    [anon_sym_co_await] = ACTIONS(2220),
    [anon_sym_new] = ACTIONS(2220),
    [anon_sym_requires] = ACTIONS(2220),
    [sym_this] = ACTIONS(2220),
    [anon_sym_discard] = ACTIONS(2220),
    [anon_sym_precise] = ACTIONS(2220),
    [anon_sym_shared] = ACTIONS(2220),
    [anon_sym_groupshared] = ACTIONS(2220),
    [anon_sym_uniform] = ACTIONS(2220),
    [anon_sym_row_major] = ACTIONS(2220),
    [anon_sym_column_major] = ACTIONS(2220),
    [anon_sym_globallycoherent] = ACTIONS(2220),
    [anon_sym_centroid] = ACTIONS(2220),
    [anon_sym_noperspective] = ACTIONS(2220),
    [anon_sym_nointerpolation] = ACTIONS(2220),
    [anon_sym_sample] = ACTIONS(2220),
    [anon_sym_linear] = ACTIONS(2220),
    [anon_sym_snorm] = ACTIONS(2220),
    [anon_sym_unorm] = ACTIONS(2220),
    [anon_sym_point] = ACTIONS(2220),
    [anon_sym_line] = ACTIONS(2220),
    [anon_sym_triangleadj] = ACTIONS(2220),
    [anon_sym_lineadj] = ACTIONS(2220),
    [anon_sym_triangle] = ACTIONS(2220),
    [anon_sym_cbuffer] = ACTIONS(2220),
  },
  [1013] = {
    [sym_identifier] = ACTIONS(2190),
    [anon_sym_LPAREN2] = ACTIONS(2192),
    [anon_sym_BANG] = ACTIONS(2192),
    [anon_sym_TILDE] = ACTIONS(2192),
    [anon_sym_DASH] = ACTIONS(2190),
    [anon_sym_PLUS] = ACTIONS(2190),
    [anon_sym_STAR] = ACTIONS(2192),
    [anon_sym_AMP] = ACTIONS(2192),
    [anon_sym_SEMI] = ACTIONS(2192),
    [anon_sym___extension__] = ACTIONS(2190),
    [anon_sym_typedef] = ACTIONS(2190),
    [anon_sym_in] = ACTIONS(2190),
    [anon_sym_out] = ACTIONS(2190),
    [anon_sym_inout] = ACTIONS(2190),
    [anon_sym_extern] = ACTIONS(2190),
    [anon_sym___attribute__] = ACTIONS(2190),
    [anon_sym_COLON_COLON] = ACTIONS(2192),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2192),
    [anon_sym___declspec] = ACTIONS(2190),
    [anon_sym_LBRACE] = ACTIONS(2192),
    [anon_sym_signed] = ACTIONS(2190),
    [anon_sym_unsigned] = ACTIONS(2190),
    [anon_sym_long] = ACTIONS(2190),
    [anon_sym_short] = ACTIONS(2190),
    [anon_sym_LBRACK] = ACTIONS(2190),
    [anon_sym_static] = ACTIONS(2190),
    [anon_sym_register] = ACTIONS(2190),
    [anon_sym_inline] = ACTIONS(2190),
    [anon_sym___inline] = ACTIONS(2190),
    [anon_sym___inline__] = ACTIONS(2190),
    [anon_sym___forceinline] = ACTIONS(2190),
    [anon_sym_thread_local] = ACTIONS(2190),
    [anon_sym___thread] = ACTIONS(2190),
    [anon_sym_const] = ACTIONS(2190),
    [anon_sym_constexpr] = ACTIONS(2190),
    [anon_sym_volatile] = ACTIONS(2190),
    [anon_sym_restrict] = ACTIONS(2190),
    [anon_sym___restrict__] = ACTIONS(2190),
    [anon_sym__Atomic] = ACTIONS(2190),
    [anon_sym__Noreturn] = ACTIONS(2190),
    [anon_sym_noreturn] = ACTIONS(2190),
    [anon_sym_mutable] = ACTIONS(2190),
    [anon_sym_constinit] = ACTIONS(2190),
    [anon_sym_consteval] = ACTIONS(2190),
    [anon_sym_alignas] = ACTIONS(2190),
    [anon_sym__Alignas] = ACTIONS(2190),
    [sym_primitive_type] = ACTIONS(2190),
    [anon_sym_enum] = ACTIONS(2190),
    [anon_sym_class] = ACTIONS(2190),
    [anon_sym_struct] = ACTIONS(2190),
    [anon_sym_union] = ACTIONS(2190),
    [anon_sym_if] = ACTIONS(2190),
    [anon_sym_else] = ACTIONS(2190),
    [anon_sym_switch] = ACTIONS(2190),
    [anon_sym_while] = ACTIONS(2190),
    [anon_sym_do] = ACTIONS(2190),
    [anon_sym_for] = ACTIONS(2190),
    [anon_sym_return] = ACTIONS(2190),
    [anon_sym_break] = ACTIONS(2190),
    [anon_sym_continue] = ACTIONS(2190),
    [anon_sym_goto] = ACTIONS(2190),
    [anon_sym___try] = ACTIONS(2190),
    [anon_sym___leave] = ACTIONS(2190),
    [anon_sym_not] = ACTIONS(2190),
    [anon_sym_compl] = ACTIONS(2190),
    [anon_sym_DASH_DASH] = ACTIONS(2192),
    [anon_sym_PLUS_PLUS] = ACTIONS(2192),
    [anon_sym_sizeof] = ACTIONS(2190),
    [anon_sym___alignof__] = ACTIONS(2190),
    [anon_sym___alignof] = ACTIONS(2190),
    [anon_sym__alignof] = ACTIONS(2190),
    [anon_sym_alignof] = ACTIONS(2190),
    [anon_sym__Alignof] = ACTIONS(2190),
    [anon_sym_offsetof] = ACTIONS(2190),
    [anon_sym__Generic] = ACTIONS(2190),
    [anon_sym_asm] = ACTIONS(2190),
    [anon_sym___asm__] = ACTIONS(2190),
    [sym_number_literal] = ACTIONS(2192),
    [anon_sym_L_SQUOTE] = ACTIONS(2192),
    [anon_sym_u_SQUOTE] = ACTIONS(2192),
    [anon_sym_U_SQUOTE] = ACTIONS(2192),
    [anon_sym_u8_SQUOTE] = ACTIONS(2192),
    [anon_sym_SQUOTE] = ACTIONS(2192),
    [anon_sym_L_DQUOTE] = ACTIONS(2192),
    [anon_sym_u_DQUOTE] = ACTIONS(2192),
    [anon_sym_U_DQUOTE] = ACTIONS(2192),
    [anon_sym_u8_DQUOTE] = ACTIONS(2192),
    [anon_sym_DQUOTE] = ACTIONS(2192),
    [sym_true] = ACTIONS(2190),
    [sym_false] = ACTIONS(2190),
    [anon_sym_NULL] = ACTIONS(2190),
    [anon_sym_nullptr] = ACTIONS(2190),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2190),
    [anon_sym_decltype] = ACTIONS(2190),
    [sym_virtual] = ACTIONS(2190),
    [anon_sym_typename] = ACTIONS(2190),
    [anon_sym_template] = ACTIONS(2190),
    [anon_sym_try] = ACTIONS(2190),
    [anon_sym_delete] = ACTIONS(2190),
    [anon_sym_throw] = ACTIONS(2190),
    [anon_sym_co_return] = ACTIONS(2190),
    [anon_sym_co_yield] = ACTIONS(2190),
    [anon_sym_R_DQUOTE] = ACTIONS(2192),
    [anon_sym_LR_DQUOTE] = ACTIONS(2192),
    [anon_sym_uR_DQUOTE] = ACTIONS(2192),
    [anon_sym_UR_DQUOTE] = ACTIONS(2192),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2192),
    [anon_sym_co_await] = ACTIONS(2190),
    [anon_sym_new] = ACTIONS(2190),
    [anon_sym_requires] = ACTIONS(2190),
    [sym_this] = ACTIONS(2190),
    [anon_sym_discard] = ACTIONS(2190),
    [anon_sym_precise] = ACTIONS(2190),
    [anon_sym_shared] = ACTIONS(2190),
    [anon_sym_groupshared] = ACTIONS(2190),
    [anon_sym_uniform] = ACTIONS(2190),
    [anon_sym_row_major] = ACTIONS(2190),
    [anon_sym_column_major] = ACTIONS(2190),
    [anon_sym_globallycoherent] = ACTIONS(2190),
    [anon_sym_centroid] = ACTIONS(2190),
    [anon_sym_noperspective] = ACTIONS(2190),
    [anon_sym_nointerpolation] = ACTIONS(2190),
    [anon_sym_sample] = ACTIONS(2190),
    [anon_sym_linear] = ACTIONS(2190),
    [anon_sym_snorm] = ACTIONS(2190),
    [anon_sym_unorm] = ACTIONS(2190),
    [anon_sym_point] = ACTIONS(2190),
    [anon_sym_line] = ACTIONS(2190),
    [anon_sym_triangleadj] = ACTIONS(2190),
    [anon_sym_lineadj] = ACTIONS(2190),
    [anon_sym_triangle] = ACTIONS(2190),
    [anon_sym_cbuffer] = ACTIONS(2190),
  },
  [1014] = {
    [sym_identifier] = ACTIONS(2186),
    [anon_sym_LPAREN2] = ACTIONS(2188),
    [anon_sym_BANG] = ACTIONS(2188),
    [anon_sym_TILDE] = ACTIONS(2188),
    [anon_sym_DASH] = ACTIONS(2186),
    [anon_sym_PLUS] = ACTIONS(2186),
    [anon_sym_STAR] = ACTIONS(2188),
    [anon_sym_AMP] = ACTIONS(2188),
    [anon_sym_SEMI] = ACTIONS(2188),
    [anon_sym___extension__] = ACTIONS(2186),
    [anon_sym_typedef] = ACTIONS(2186),
    [anon_sym_in] = ACTIONS(2186),
    [anon_sym_out] = ACTIONS(2186),
    [anon_sym_inout] = ACTIONS(2186),
    [anon_sym_extern] = ACTIONS(2186),
    [anon_sym___attribute__] = ACTIONS(2186),
    [anon_sym_COLON_COLON] = ACTIONS(2188),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2188),
    [anon_sym___declspec] = ACTIONS(2186),
    [anon_sym_LBRACE] = ACTIONS(2188),
    [anon_sym_signed] = ACTIONS(2186),
    [anon_sym_unsigned] = ACTIONS(2186),
    [anon_sym_long] = ACTIONS(2186),
    [anon_sym_short] = ACTIONS(2186),
    [anon_sym_LBRACK] = ACTIONS(2186),
    [anon_sym_static] = ACTIONS(2186),
    [anon_sym_register] = ACTIONS(2186),
    [anon_sym_inline] = ACTIONS(2186),
    [anon_sym___inline] = ACTIONS(2186),
    [anon_sym___inline__] = ACTIONS(2186),
    [anon_sym___forceinline] = ACTIONS(2186),
    [anon_sym_thread_local] = ACTIONS(2186),
    [anon_sym___thread] = ACTIONS(2186),
    [anon_sym_const] = ACTIONS(2186),
    [anon_sym_constexpr] = ACTIONS(2186),
    [anon_sym_volatile] = ACTIONS(2186),
    [anon_sym_restrict] = ACTIONS(2186),
    [anon_sym___restrict__] = ACTIONS(2186),
    [anon_sym__Atomic] = ACTIONS(2186),
    [anon_sym__Noreturn] = ACTIONS(2186),
    [anon_sym_noreturn] = ACTIONS(2186),
    [anon_sym_mutable] = ACTIONS(2186),
    [anon_sym_constinit] = ACTIONS(2186),
    [anon_sym_consteval] = ACTIONS(2186),
    [anon_sym_alignas] = ACTIONS(2186),
    [anon_sym__Alignas] = ACTIONS(2186),
    [sym_primitive_type] = ACTIONS(2186),
    [anon_sym_enum] = ACTIONS(2186),
    [anon_sym_class] = ACTIONS(2186),
    [anon_sym_struct] = ACTIONS(2186),
    [anon_sym_union] = ACTIONS(2186),
    [anon_sym_if] = ACTIONS(2186),
    [anon_sym_else] = ACTIONS(2186),
    [anon_sym_switch] = ACTIONS(2186),
    [anon_sym_while] = ACTIONS(2186),
    [anon_sym_do] = ACTIONS(2186),
    [anon_sym_for] = ACTIONS(2186),
    [anon_sym_return] = ACTIONS(2186),
    [anon_sym_break] = ACTIONS(2186),
    [anon_sym_continue] = ACTIONS(2186),
    [anon_sym_goto] = ACTIONS(2186),
    [anon_sym___try] = ACTIONS(2186),
    [anon_sym___leave] = ACTIONS(2186),
    [anon_sym_not] = ACTIONS(2186),
    [anon_sym_compl] = ACTIONS(2186),
    [anon_sym_DASH_DASH] = ACTIONS(2188),
    [anon_sym_PLUS_PLUS] = ACTIONS(2188),
    [anon_sym_sizeof] = ACTIONS(2186),
    [anon_sym___alignof__] = ACTIONS(2186),
    [anon_sym___alignof] = ACTIONS(2186),
    [anon_sym__alignof] = ACTIONS(2186),
    [anon_sym_alignof] = ACTIONS(2186),
    [anon_sym__Alignof] = ACTIONS(2186),
    [anon_sym_offsetof] = ACTIONS(2186),
    [anon_sym__Generic] = ACTIONS(2186),
    [anon_sym_asm] = ACTIONS(2186),
    [anon_sym___asm__] = ACTIONS(2186),
    [sym_number_literal] = ACTIONS(2188),
    [anon_sym_L_SQUOTE] = ACTIONS(2188),
    [anon_sym_u_SQUOTE] = ACTIONS(2188),
    [anon_sym_U_SQUOTE] = ACTIONS(2188),
    [anon_sym_u8_SQUOTE] = ACTIONS(2188),
    [anon_sym_SQUOTE] = ACTIONS(2188),
    [anon_sym_L_DQUOTE] = ACTIONS(2188),
    [anon_sym_u_DQUOTE] = ACTIONS(2188),
    [anon_sym_U_DQUOTE] = ACTIONS(2188),
    [anon_sym_u8_DQUOTE] = ACTIONS(2188),
    [anon_sym_DQUOTE] = ACTIONS(2188),
    [sym_true] = ACTIONS(2186),
    [sym_false] = ACTIONS(2186),
    [anon_sym_NULL] = ACTIONS(2186),
    [anon_sym_nullptr] = ACTIONS(2186),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2186),
    [anon_sym_decltype] = ACTIONS(2186),
    [sym_virtual] = ACTIONS(2186),
    [anon_sym_typename] = ACTIONS(2186),
    [anon_sym_template] = ACTIONS(2186),
    [anon_sym_try] = ACTIONS(2186),
    [anon_sym_delete] = ACTIONS(2186),
    [anon_sym_throw] = ACTIONS(2186),
    [anon_sym_co_return] = ACTIONS(2186),
    [anon_sym_co_yield] = ACTIONS(2186),
    [anon_sym_R_DQUOTE] = ACTIONS(2188),
    [anon_sym_LR_DQUOTE] = ACTIONS(2188),
    [anon_sym_uR_DQUOTE] = ACTIONS(2188),
    [anon_sym_UR_DQUOTE] = ACTIONS(2188),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2188),
    [anon_sym_co_await] = ACTIONS(2186),
    [anon_sym_new] = ACTIONS(2186),
    [anon_sym_requires] = ACTIONS(2186),
    [sym_this] = ACTIONS(2186),
    [anon_sym_discard] = ACTIONS(2186),
    [anon_sym_precise] = ACTIONS(2186),
    [anon_sym_shared] = ACTIONS(2186),
    [anon_sym_groupshared] = ACTIONS(2186),
    [anon_sym_uniform] = ACTIONS(2186),
    [anon_sym_row_major] = ACTIONS(2186),
    [anon_sym_column_major] = ACTIONS(2186),
    [anon_sym_globallycoherent] = ACTIONS(2186),
    [anon_sym_centroid] = ACTIONS(2186),
    [anon_sym_noperspective] = ACTIONS(2186),
    [anon_sym_nointerpolation] = ACTIONS(2186),
    [anon_sym_sample] = ACTIONS(2186),
    [anon_sym_linear] = ACTIONS(2186),
    [anon_sym_snorm] = ACTIONS(2186),
    [anon_sym_unorm] = ACTIONS(2186),
    [anon_sym_point] = ACTIONS(2186),
    [anon_sym_line] = ACTIONS(2186),
    [anon_sym_triangleadj] = ACTIONS(2186),
    [anon_sym_lineadj] = ACTIONS(2186),
    [anon_sym_triangle] = ACTIONS(2186),
    [anon_sym_cbuffer] = ACTIONS(2186),
  },
  [1015] = {
    [sym_identifier] = ACTIONS(2264),
    [anon_sym_LPAREN2] = ACTIONS(2266),
    [anon_sym_BANG] = ACTIONS(2266),
    [anon_sym_TILDE] = ACTIONS(2266),
    [anon_sym_DASH] = ACTIONS(2264),
    [anon_sym_PLUS] = ACTIONS(2264),
    [anon_sym_STAR] = ACTIONS(2266),
    [anon_sym_AMP] = ACTIONS(2266),
    [anon_sym_SEMI] = ACTIONS(2266),
    [anon_sym___extension__] = ACTIONS(2264),
    [anon_sym_typedef] = ACTIONS(2264),
    [anon_sym_in] = ACTIONS(2264),
    [anon_sym_out] = ACTIONS(2264),
    [anon_sym_inout] = ACTIONS(2264),
    [anon_sym_extern] = ACTIONS(2264),
    [anon_sym___attribute__] = ACTIONS(2264),
    [anon_sym_COLON_COLON] = ACTIONS(2266),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2266),
    [anon_sym___declspec] = ACTIONS(2264),
    [anon_sym_LBRACE] = ACTIONS(2266),
    [anon_sym_signed] = ACTIONS(2264),
    [anon_sym_unsigned] = ACTIONS(2264),
    [anon_sym_long] = ACTIONS(2264),
    [anon_sym_short] = ACTIONS(2264),
    [anon_sym_LBRACK] = ACTIONS(2264),
    [anon_sym_static] = ACTIONS(2264),
    [anon_sym_register] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(2264),
    [anon_sym___inline] = ACTIONS(2264),
    [anon_sym___inline__] = ACTIONS(2264),
    [anon_sym___forceinline] = ACTIONS(2264),
    [anon_sym_thread_local] = ACTIONS(2264),
    [anon_sym___thread] = ACTIONS(2264),
    [anon_sym_const] = ACTIONS(2264),
    [anon_sym_constexpr] = ACTIONS(2264),
    [anon_sym_volatile] = ACTIONS(2264),
    [anon_sym_restrict] = ACTIONS(2264),
    [anon_sym___restrict__] = ACTIONS(2264),
    [anon_sym__Atomic] = ACTIONS(2264),
    [anon_sym__Noreturn] = ACTIONS(2264),
    [anon_sym_noreturn] = ACTIONS(2264),
    [anon_sym_mutable] = ACTIONS(2264),
    [anon_sym_constinit] = ACTIONS(2264),
    [anon_sym_consteval] = ACTIONS(2264),
    [anon_sym_alignas] = ACTIONS(2264),
    [anon_sym__Alignas] = ACTIONS(2264),
    [sym_primitive_type] = ACTIONS(2264),
    [anon_sym_enum] = ACTIONS(2264),
    [anon_sym_class] = ACTIONS(2264),
    [anon_sym_struct] = ACTIONS(2264),
    [anon_sym_union] = ACTIONS(2264),
    [anon_sym_if] = ACTIONS(2264),
    [anon_sym_else] = ACTIONS(2264),
    [anon_sym_switch] = ACTIONS(2264),
    [anon_sym_while] = ACTIONS(2264),
    [anon_sym_do] = ACTIONS(2264),
    [anon_sym_for] = ACTIONS(2264),
    [anon_sym_return] = ACTIONS(2264),
    [anon_sym_break] = ACTIONS(2264),
    [anon_sym_continue] = ACTIONS(2264),
    [anon_sym_goto] = ACTIONS(2264),
    [anon_sym___try] = ACTIONS(2264),
    [anon_sym___leave] = ACTIONS(2264),
    [anon_sym_not] = ACTIONS(2264),
    [anon_sym_compl] = ACTIONS(2264),
    [anon_sym_DASH_DASH] = ACTIONS(2266),
    [anon_sym_PLUS_PLUS] = ACTIONS(2266),
    [anon_sym_sizeof] = ACTIONS(2264),
    [anon_sym___alignof__] = ACTIONS(2264),
    [anon_sym___alignof] = ACTIONS(2264),
    [anon_sym__alignof] = ACTIONS(2264),
    [anon_sym_alignof] = ACTIONS(2264),
    [anon_sym__Alignof] = ACTIONS(2264),
    [anon_sym_offsetof] = ACTIONS(2264),
    [anon_sym__Generic] = ACTIONS(2264),
    [anon_sym_asm] = ACTIONS(2264),
    [anon_sym___asm__] = ACTIONS(2264),
    [sym_number_literal] = ACTIONS(2266),
    [anon_sym_L_SQUOTE] = ACTIONS(2266),
    [anon_sym_u_SQUOTE] = ACTIONS(2266),
    [anon_sym_U_SQUOTE] = ACTIONS(2266),
    [anon_sym_u8_SQUOTE] = ACTIONS(2266),
    [anon_sym_SQUOTE] = ACTIONS(2266),
    [anon_sym_L_DQUOTE] = ACTIONS(2266),
    [anon_sym_u_DQUOTE] = ACTIONS(2266),
    [anon_sym_U_DQUOTE] = ACTIONS(2266),
    [anon_sym_u8_DQUOTE] = ACTIONS(2266),
    [anon_sym_DQUOTE] = ACTIONS(2266),
    [sym_true] = ACTIONS(2264),
    [sym_false] = ACTIONS(2264),
    [anon_sym_NULL] = ACTIONS(2264),
    [anon_sym_nullptr] = ACTIONS(2264),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2264),
    [anon_sym_decltype] = ACTIONS(2264),
    [sym_virtual] = ACTIONS(2264),
    [anon_sym_typename] = ACTIONS(2264),
    [anon_sym_template] = ACTIONS(2264),
    [anon_sym_try] = ACTIONS(2264),
    [anon_sym_delete] = ACTIONS(2264),
    [anon_sym_throw] = ACTIONS(2264),
    [anon_sym_co_return] = ACTIONS(2264),
    [anon_sym_co_yield] = ACTIONS(2264),
    [anon_sym_R_DQUOTE] = ACTIONS(2266),
    [anon_sym_LR_DQUOTE] = ACTIONS(2266),
    [anon_sym_uR_DQUOTE] = ACTIONS(2266),
    [anon_sym_UR_DQUOTE] = ACTIONS(2266),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2266),
    [anon_sym_co_await] = ACTIONS(2264),
    [anon_sym_new] = ACTIONS(2264),
    [anon_sym_requires] = ACTIONS(2264),
    [sym_this] = ACTIONS(2264),
    [anon_sym_discard] = ACTIONS(2264),
    [anon_sym_precise] = ACTIONS(2264),
    [anon_sym_shared] = ACTIONS(2264),
    [anon_sym_groupshared] = ACTIONS(2264),
    [anon_sym_uniform] = ACTIONS(2264),
    [anon_sym_row_major] = ACTIONS(2264),
    [anon_sym_column_major] = ACTIONS(2264),
    [anon_sym_globallycoherent] = ACTIONS(2264),
    [anon_sym_centroid] = ACTIONS(2264),
    [anon_sym_noperspective] = ACTIONS(2264),
    [anon_sym_nointerpolation] = ACTIONS(2264),
    [anon_sym_sample] = ACTIONS(2264),
    [anon_sym_linear] = ACTIONS(2264),
    [anon_sym_snorm] = ACTIONS(2264),
    [anon_sym_unorm] = ACTIONS(2264),
    [anon_sym_point] = ACTIONS(2264),
    [anon_sym_line] = ACTIONS(2264),
    [anon_sym_triangleadj] = ACTIONS(2264),
    [anon_sym_lineadj] = ACTIONS(2264),
    [anon_sym_triangle] = ACTIONS(2264),
    [anon_sym_cbuffer] = ACTIONS(2264),
  },
  [1016] = {
    [sym_identifier] = ACTIONS(2224),
    [anon_sym_LPAREN2] = ACTIONS(2226),
    [anon_sym_BANG] = ACTIONS(2226),
    [anon_sym_TILDE] = ACTIONS(2226),
    [anon_sym_DASH] = ACTIONS(2224),
    [anon_sym_PLUS] = ACTIONS(2224),
    [anon_sym_STAR] = ACTIONS(2226),
    [anon_sym_AMP] = ACTIONS(2226),
    [anon_sym_SEMI] = ACTIONS(2226),
    [anon_sym___extension__] = ACTIONS(2224),
    [anon_sym_typedef] = ACTIONS(2224),
    [anon_sym_in] = ACTIONS(2224),
    [anon_sym_out] = ACTIONS(2224),
    [anon_sym_inout] = ACTIONS(2224),
    [anon_sym_extern] = ACTIONS(2224),
    [anon_sym___attribute__] = ACTIONS(2224),
    [anon_sym_COLON_COLON] = ACTIONS(2226),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2226),
    [anon_sym___declspec] = ACTIONS(2224),
    [anon_sym_LBRACE] = ACTIONS(2226),
    [anon_sym_signed] = ACTIONS(2224),
    [anon_sym_unsigned] = ACTIONS(2224),
    [anon_sym_long] = ACTIONS(2224),
    [anon_sym_short] = ACTIONS(2224),
    [anon_sym_LBRACK] = ACTIONS(2224),
    [anon_sym_static] = ACTIONS(2224),
    [anon_sym_register] = ACTIONS(2224),
    [anon_sym_inline] = ACTIONS(2224),
    [anon_sym___inline] = ACTIONS(2224),
    [anon_sym___inline__] = ACTIONS(2224),
    [anon_sym___forceinline] = ACTIONS(2224),
    [anon_sym_thread_local] = ACTIONS(2224),
    [anon_sym___thread] = ACTIONS(2224),
    [anon_sym_const] = ACTIONS(2224),
    [anon_sym_constexpr] = ACTIONS(2224),
    [anon_sym_volatile] = ACTIONS(2224),
    [anon_sym_restrict] = ACTIONS(2224),
    [anon_sym___restrict__] = ACTIONS(2224),
    [anon_sym__Atomic] = ACTIONS(2224),
    [anon_sym__Noreturn] = ACTIONS(2224),
    [anon_sym_noreturn] = ACTIONS(2224),
    [anon_sym_mutable] = ACTIONS(2224),
    [anon_sym_constinit] = ACTIONS(2224),
    [anon_sym_consteval] = ACTIONS(2224),
    [anon_sym_alignas] = ACTIONS(2224),
    [anon_sym__Alignas] = ACTIONS(2224),
    [sym_primitive_type] = ACTIONS(2224),
    [anon_sym_enum] = ACTIONS(2224),
    [anon_sym_class] = ACTIONS(2224),
    [anon_sym_struct] = ACTIONS(2224),
    [anon_sym_union] = ACTIONS(2224),
    [anon_sym_if] = ACTIONS(2224),
    [anon_sym_else] = ACTIONS(2224),
    [anon_sym_switch] = ACTIONS(2224),
    [anon_sym_while] = ACTIONS(2224),
    [anon_sym_do] = ACTIONS(2224),
    [anon_sym_for] = ACTIONS(2224),
    [anon_sym_return] = ACTIONS(2224),
    [anon_sym_break] = ACTIONS(2224),
    [anon_sym_continue] = ACTIONS(2224),
    [anon_sym_goto] = ACTIONS(2224),
    [anon_sym___try] = ACTIONS(2224),
    [anon_sym___leave] = ACTIONS(2224),
    [anon_sym_not] = ACTIONS(2224),
    [anon_sym_compl] = ACTIONS(2224),
    [anon_sym_DASH_DASH] = ACTIONS(2226),
    [anon_sym_PLUS_PLUS] = ACTIONS(2226),
    [anon_sym_sizeof] = ACTIONS(2224),
    [anon_sym___alignof__] = ACTIONS(2224),
    [anon_sym___alignof] = ACTIONS(2224),
    [anon_sym__alignof] = ACTIONS(2224),
    [anon_sym_alignof] = ACTIONS(2224),
    [anon_sym__Alignof] = ACTIONS(2224),
    [anon_sym_offsetof] = ACTIONS(2224),
    [anon_sym__Generic] = ACTIONS(2224),
    [anon_sym_asm] = ACTIONS(2224),
    [anon_sym___asm__] = ACTIONS(2224),
    [sym_number_literal] = ACTIONS(2226),
    [anon_sym_L_SQUOTE] = ACTIONS(2226),
    [anon_sym_u_SQUOTE] = ACTIONS(2226),
    [anon_sym_U_SQUOTE] = ACTIONS(2226),
    [anon_sym_u8_SQUOTE] = ACTIONS(2226),
    [anon_sym_SQUOTE] = ACTIONS(2226),
    [anon_sym_L_DQUOTE] = ACTIONS(2226),
    [anon_sym_u_DQUOTE] = ACTIONS(2226),
    [anon_sym_U_DQUOTE] = ACTIONS(2226),
    [anon_sym_u8_DQUOTE] = ACTIONS(2226),
    [anon_sym_DQUOTE] = ACTIONS(2226),
    [sym_true] = ACTIONS(2224),
    [sym_false] = ACTIONS(2224),
    [anon_sym_NULL] = ACTIONS(2224),
    [anon_sym_nullptr] = ACTIONS(2224),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2224),
    [anon_sym_decltype] = ACTIONS(2224),
    [sym_virtual] = ACTIONS(2224),
    [anon_sym_typename] = ACTIONS(2224),
    [anon_sym_template] = ACTIONS(2224),
    [anon_sym_try] = ACTIONS(2224),
    [anon_sym_delete] = ACTIONS(2224),
    [anon_sym_throw] = ACTIONS(2224),
    [anon_sym_co_return] = ACTIONS(2224),
    [anon_sym_co_yield] = ACTIONS(2224),
    [anon_sym_R_DQUOTE] = ACTIONS(2226),
    [anon_sym_LR_DQUOTE] = ACTIONS(2226),
    [anon_sym_uR_DQUOTE] = ACTIONS(2226),
    [anon_sym_UR_DQUOTE] = ACTIONS(2226),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2226),
    [anon_sym_co_await] = ACTIONS(2224),
    [anon_sym_new] = ACTIONS(2224),
    [anon_sym_requires] = ACTIONS(2224),
    [sym_this] = ACTIONS(2224),
    [anon_sym_discard] = ACTIONS(2224),
    [anon_sym_precise] = ACTIONS(2224),
    [anon_sym_shared] = ACTIONS(2224),
    [anon_sym_groupshared] = ACTIONS(2224),
    [anon_sym_uniform] = ACTIONS(2224),
    [anon_sym_row_major] = ACTIONS(2224),
    [anon_sym_column_major] = ACTIONS(2224),
    [anon_sym_globallycoherent] = ACTIONS(2224),
    [anon_sym_centroid] = ACTIONS(2224),
    [anon_sym_noperspective] = ACTIONS(2224),
    [anon_sym_nointerpolation] = ACTIONS(2224),
    [anon_sym_sample] = ACTIONS(2224),
    [anon_sym_linear] = ACTIONS(2224),
    [anon_sym_snorm] = ACTIONS(2224),
    [anon_sym_unorm] = ACTIONS(2224),
    [anon_sym_point] = ACTIONS(2224),
    [anon_sym_line] = ACTIONS(2224),
    [anon_sym_triangleadj] = ACTIONS(2224),
    [anon_sym_lineadj] = ACTIONS(2224),
    [anon_sym_triangle] = ACTIONS(2224),
    [anon_sym_cbuffer] = ACTIONS(2224),
  },
  [1017] = {
    [sym_identifier] = ACTIONS(2272),
    [anon_sym_LPAREN2] = ACTIONS(2274),
    [anon_sym_BANG] = ACTIONS(2274),
    [anon_sym_TILDE] = ACTIONS(2274),
    [anon_sym_DASH] = ACTIONS(2272),
    [anon_sym_PLUS] = ACTIONS(2272),
    [anon_sym_STAR] = ACTIONS(2274),
    [anon_sym_AMP] = ACTIONS(2274),
    [anon_sym_SEMI] = ACTIONS(2274),
    [anon_sym___extension__] = ACTIONS(2272),
    [anon_sym_typedef] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2272),
    [anon_sym_out] = ACTIONS(2272),
    [anon_sym_inout] = ACTIONS(2272),
    [anon_sym_extern] = ACTIONS(2272),
    [anon_sym___attribute__] = ACTIONS(2272),
    [anon_sym_COLON_COLON] = ACTIONS(2274),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2274),
    [anon_sym___declspec] = ACTIONS(2272),
    [anon_sym_LBRACE] = ACTIONS(2274),
    [anon_sym_signed] = ACTIONS(2272),
    [anon_sym_unsigned] = ACTIONS(2272),
    [anon_sym_long] = ACTIONS(2272),
    [anon_sym_short] = ACTIONS(2272),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(2272),
    [anon_sym_register] = ACTIONS(2272),
    [anon_sym_inline] = ACTIONS(2272),
    [anon_sym___inline] = ACTIONS(2272),
    [anon_sym___inline__] = ACTIONS(2272),
    [anon_sym___forceinline] = ACTIONS(2272),
    [anon_sym_thread_local] = ACTIONS(2272),
    [anon_sym___thread] = ACTIONS(2272),
    [anon_sym_const] = ACTIONS(2272),
    [anon_sym_constexpr] = ACTIONS(2272),
    [anon_sym_volatile] = ACTIONS(2272),
    [anon_sym_restrict] = ACTIONS(2272),
    [anon_sym___restrict__] = ACTIONS(2272),
    [anon_sym__Atomic] = ACTIONS(2272),
    [anon_sym__Noreturn] = ACTIONS(2272),
    [anon_sym_noreturn] = ACTIONS(2272),
    [anon_sym_mutable] = ACTIONS(2272),
    [anon_sym_constinit] = ACTIONS(2272),
    [anon_sym_consteval] = ACTIONS(2272),
    [anon_sym_alignas] = ACTIONS(2272),
    [anon_sym__Alignas] = ACTIONS(2272),
    [sym_primitive_type] = ACTIONS(2272),
    [anon_sym_enum] = ACTIONS(2272),
    [anon_sym_class] = ACTIONS(2272),
    [anon_sym_struct] = ACTIONS(2272),
    [anon_sym_union] = ACTIONS(2272),
    [anon_sym_if] = ACTIONS(2272),
    [anon_sym_else] = ACTIONS(2272),
    [anon_sym_switch] = ACTIONS(2272),
    [anon_sym_while] = ACTIONS(2272),
    [anon_sym_do] = ACTIONS(2272),
    [anon_sym_for] = ACTIONS(2272),
    [anon_sym_return] = ACTIONS(2272),
    [anon_sym_break] = ACTIONS(2272),
    [anon_sym_continue] = ACTIONS(2272),
    [anon_sym_goto] = ACTIONS(2272),
    [anon_sym___try] = ACTIONS(2272),
    [anon_sym___leave] = ACTIONS(2272),
    [anon_sym_not] = ACTIONS(2272),
    [anon_sym_compl] = ACTIONS(2272),
    [anon_sym_DASH_DASH] = ACTIONS(2274),
    [anon_sym_PLUS_PLUS] = ACTIONS(2274),
    [anon_sym_sizeof] = ACTIONS(2272),
    [anon_sym___alignof__] = ACTIONS(2272),
    [anon_sym___alignof] = ACTIONS(2272),
    [anon_sym__alignof] = ACTIONS(2272),
    [anon_sym_alignof] = ACTIONS(2272),
    [anon_sym__Alignof] = ACTIONS(2272),
    [anon_sym_offsetof] = ACTIONS(2272),
    [anon_sym__Generic] = ACTIONS(2272),
    [anon_sym_asm] = ACTIONS(2272),
    [anon_sym___asm__] = ACTIONS(2272),
    [sym_number_literal] = ACTIONS(2274),
    [anon_sym_L_SQUOTE] = ACTIONS(2274),
    [anon_sym_u_SQUOTE] = ACTIONS(2274),
    [anon_sym_U_SQUOTE] = ACTIONS(2274),
    [anon_sym_u8_SQUOTE] = ACTIONS(2274),
    [anon_sym_SQUOTE] = ACTIONS(2274),
    [anon_sym_L_DQUOTE] = ACTIONS(2274),
    [anon_sym_u_DQUOTE] = ACTIONS(2274),
    [anon_sym_U_DQUOTE] = ACTIONS(2274),
    [anon_sym_u8_DQUOTE] = ACTIONS(2274),
    [anon_sym_DQUOTE] = ACTIONS(2274),
    [sym_true] = ACTIONS(2272),
    [sym_false] = ACTIONS(2272),
    [anon_sym_NULL] = ACTIONS(2272),
    [anon_sym_nullptr] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2272),
    [anon_sym_decltype] = ACTIONS(2272),
    [sym_virtual] = ACTIONS(2272),
    [anon_sym_typename] = ACTIONS(2272),
    [anon_sym_template] = ACTIONS(2272),
    [anon_sym_try] = ACTIONS(2272),
    [anon_sym_delete] = ACTIONS(2272),
    [anon_sym_throw] = ACTIONS(2272),
    [anon_sym_co_return] = ACTIONS(2272),
    [anon_sym_co_yield] = ACTIONS(2272),
    [anon_sym_R_DQUOTE] = ACTIONS(2274),
    [anon_sym_LR_DQUOTE] = ACTIONS(2274),
    [anon_sym_uR_DQUOTE] = ACTIONS(2274),
    [anon_sym_UR_DQUOTE] = ACTIONS(2274),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2274),
    [anon_sym_co_await] = ACTIONS(2272),
    [anon_sym_new] = ACTIONS(2272),
    [anon_sym_requires] = ACTIONS(2272),
    [sym_this] = ACTIONS(2272),
    [anon_sym_discard] = ACTIONS(2272),
    [anon_sym_precise] = ACTIONS(2272),
    [anon_sym_shared] = ACTIONS(2272),
    [anon_sym_groupshared] = ACTIONS(2272),
    [anon_sym_uniform] = ACTIONS(2272),
    [anon_sym_row_major] = ACTIONS(2272),
    [anon_sym_column_major] = ACTIONS(2272),
    [anon_sym_globallycoherent] = ACTIONS(2272),
    [anon_sym_centroid] = ACTIONS(2272),
    [anon_sym_noperspective] = ACTIONS(2272),
    [anon_sym_nointerpolation] = ACTIONS(2272),
    [anon_sym_sample] = ACTIONS(2272),
    [anon_sym_linear] = ACTIONS(2272),
    [anon_sym_snorm] = ACTIONS(2272),
    [anon_sym_unorm] = ACTIONS(2272),
    [anon_sym_point] = ACTIONS(2272),
    [anon_sym_line] = ACTIONS(2272),
    [anon_sym_triangleadj] = ACTIONS(2272),
    [anon_sym_lineadj] = ACTIONS(2272),
    [anon_sym_triangle] = ACTIONS(2272),
    [anon_sym_cbuffer] = ACTIONS(2272),
  },
  [1018] = {
    [sym_identifier] = ACTIONS(2130),
    [anon_sym_LPAREN2] = ACTIONS(2132),
    [anon_sym_BANG] = ACTIONS(2132),
    [anon_sym_TILDE] = ACTIONS(2132),
    [anon_sym_DASH] = ACTIONS(2130),
    [anon_sym_PLUS] = ACTIONS(2130),
    [anon_sym_STAR] = ACTIONS(2132),
    [anon_sym_AMP] = ACTIONS(2132),
    [anon_sym_SEMI] = ACTIONS(2132),
    [anon_sym___extension__] = ACTIONS(2130),
    [anon_sym_typedef] = ACTIONS(2130),
    [anon_sym_in] = ACTIONS(2130),
    [anon_sym_out] = ACTIONS(2130),
    [anon_sym_inout] = ACTIONS(2130),
    [anon_sym_extern] = ACTIONS(2130),
    [anon_sym___attribute__] = ACTIONS(2130),
    [anon_sym_COLON_COLON] = ACTIONS(2132),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2132),
    [anon_sym___declspec] = ACTIONS(2130),
    [anon_sym_LBRACE] = ACTIONS(2132),
    [anon_sym_signed] = ACTIONS(2130),
    [anon_sym_unsigned] = ACTIONS(2130),
    [anon_sym_long] = ACTIONS(2130),
    [anon_sym_short] = ACTIONS(2130),
    [anon_sym_LBRACK] = ACTIONS(2130),
    [anon_sym_static] = ACTIONS(2130),
    [anon_sym_register] = ACTIONS(2130),
    [anon_sym_inline] = ACTIONS(2130),
    [anon_sym___inline] = ACTIONS(2130),
    [anon_sym___inline__] = ACTIONS(2130),
    [anon_sym___forceinline] = ACTIONS(2130),
    [anon_sym_thread_local] = ACTIONS(2130),
    [anon_sym___thread] = ACTIONS(2130),
    [anon_sym_const] = ACTIONS(2130),
    [anon_sym_constexpr] = ACTIONS(2130),
    [anon_sym_volatile] = ACTIONS(2130),
    [anon_sym_restrict] = ACTIONS(2130),
    [anon_sym___restrict__] = ACTIONS(2130),
    [anon_sym__Atomic] = ACTIONS(2130),
    [anon_sym__Noreturn] = ACTIONS(2130),
    [anon_sym_noreturn] = ACTIONS(2130),
    [anon_sym_mutable] = ACTIONS(2130),
    [anon_sym_constinit] = ACTIONS(2130),
    [anon_sym_consteval] = ACTIONS(2130),
    [anon_sym_alignas] = ACTIONS(2130),
    [anon_sym__Alignas] = ACTIONS(2130),
    [sym_primitive_type] = ACTIONS(2130),
    [anon_sym_enum] = ACTIONS(2130),
    [anon_sym_class] = ACTIONS(2130),
    [anon_sym_struct] = ACTIONS(2130),
    [anon_sym_union] = ACTIONS(2130),
    [anon_sym_if] = ACTIONS(2130),
    [anon_sym_else] = ACTIONS(2130),
    [anon_sym_switch] = ACTIONS(2130),
    [anon_sym_while] = ACTIONS(2130),
    [anon_sym_do] = ACTIONS(2130),
    [anon_sym_for] = ACTIONS(2130),
    [anon_sym_return] = ACTIONS(2130),
    [anon_sym_break] = ACTIONS(2130),
    [anon_sym_continue] = ACTIONS(2130),
    [anon_sym_goto] = ACTIONS(2130),
    [anon_sym___try] = ACTIONS(2130),
    [anon_sym___leave] = ACTIONS(2130),
    [anon_sym_not] = ACTIONS(2130),
    [anon_sym_compl] = ACTIONS(2130),
    [anon_sym_DASH_DASH] = ACTIONS(2132),
    [anon_sym_PLUS_PLUS] = ACTIONS(2132),
    [anon_sym_sizeof] = ACTIONS(2130),
    [anon_sym___alignof__] = ACTIONS(2130),
    [anon_sym___alignof] = ACTIONS(2130),
    [anon_sym__alignof] = ACTIONS(2130),
    [anon_sym_alignof] = ACTIONS(2130),
    [anon_sym__Alignof] = ACTIONS(2130),
    [anon_sym_offsetof] = ACTIONS(2130),
    [anon_sym__Generic] = ACTIONS(2130),
    [anon_sym_asm] = ACTIONS(2130),
    [anon_sym___asm__] = ACTIONS(2130),
    [sym_number_literal] = ACTIONS(2132),
    [anon_sym_L_SQUOTE] = ACTIONS(2132),
    [anon_sym_u_SQUOTE] = ACTIONS(2132),
    [anon_sym_U_SQUOTE] = ACTIONS(2132),
    [anon_sym_u8_SQUOTE] = ACTIONS(2132),
    [anon_sym_SQUOTE] = ACTIONS(2132),
    [anon_sym_L_DQUOTE] = ACTIONS(2132),
    [anon_sym_u_DQUOTE] = ACTIONS(2132),
    [anon_sym_U_DQUOTE] = ACTIONS(2132),
    [anon_sym_u8_DQUOTE] = ACTIONS(2132),
    [anon_sym_DQUOTE] = ACTIONS(2132),
    [sym_true] = ACTIONS(2130),
    [sym_false] = ACTIONS(2130),
    [anon_sym_NULL] = ACTIONS(2130),
    [anon_sym_nullptr] = ACTIONS(2130),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2130),
    [anon_sym_decltype] = ACTIONS(2130),
    [sym_virtual] = ACTIONS(2130),
    [anon_sym_typename] = ACTIONS(2130),
    [anon_sym_template] = ACTIONS(2130),
    [anon_sym_try] = ACTIONS(2130),
    [anon_sym_delete] = ACTIONS(2130),
    [anon_sym_throw] = ACTIONS(2130),
    [anon_sym_co_return] = ACTIONS(2130),
    [anon_sym_co_yield] = ACTIONS(2130),
    [anon_sym_R_DQUOTE] = ACTIONS(2132),
    [anon_sym_LR_DQUOTE] = ACTIONS(2132),
    [anon_sym_uR_DQUOTE] = ACTIONS(2132),
    [anon_sym_UR_DQUOTE] = ACTIONS(2132),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2132),
    [anon_sym_co_await] = ACTIONS(2130),
    [anon_sym_new] = ACTIONS(2130),
    [anon_sym_requires] = ACTIONS(2130),
    [sym_this] = ACTIONS(2130),
    [anon_sym_discard] = ACTIONS(2130),
    [anon_sym_precise] = ACTIONS(2130),
    [anon_sym_shared] = ACTIONS(2130),
    [anon_sym_groupshared] = ACTIONS(2130),
    [anon_sym_uniform] = ACTIONS(2130),
    [anon_sym_row_major] = ACTIONS(2130),
    [anon_sym_column_major] = ACTIONS(2130),
    [anon_sym_globallycoherent] = ACTIONS(2130),
    [anon_sym_centroid] = ACTIONS(2130),
    [anon_sym_noperspective] = ACTIONS(2130),
    [anon_sym_nointerpolation] = ACTIONS(2130),
    [anon_sym_sample] = ACTIONS(2130),
    [anon_sym_linear] = ACTIONS(2130),
    [anon_sym_snorm] = ACTIONS(2130),
    [anon_sym_unorm] = ACTIONS(2130),
    [anon_sym_point] = ACTIONS(2130),
    [anon_sym_line] = ACTIONS(2130),
    [anon_sym_triangleadj] = ACTIONS(2130),
    [anon_sym_lineadj] = ACTIONS(2130),
    [anon_sym_triangle] = ACTIONS(2130),
    [anon_sym_cbuffer] = ACTIONS(2130),
  },
  [1019] = {
    [sym_identifier] = ACTIONS(2114),
    [anon_sym_LPAREN2] = ACTIONS(2116),
    [anon_sym_BANG] = ACTIONS(2116),
    [anon_sym_TILDE] = ACTIONS(2116),
    [anon_sym_DASH] = ACTIONS(2114),
    [anon_sym_PLUS] = ACTIONS(2114),
    [anon_sym_STAR] = ACTIONS(2116),
    [anon_sym_AMP] = ACTIONS(2116),
    [anon_sym_SEMI] = ACTIONS(2116),
    [anon_sym___extension__] = ACTIONS(2114),
    [anon_sym_typedef] = ACTIONS(2114),
    [anon_sym_in] = ACTIONS(2114),
    [anon_sym_out] = ACTIONS(2114),
    [anon_sym_inout] = ACTIONS(2114),
    [anon_sym_extern] = ACTIONS(2114),
    [anon_sym___attribute__] = ACTIONS(2114),
    [anon_sym_COLON_COLON] = ACTIONS(2116),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2116),
    [anon_sym___declspec] = ACTIONS(2114),
    [anon_sym_LBRACE] = ACTIONS(2116),
    [anon_sym_signed] = ACTIONS(2114),
    [anon_sym_unsigned] = ACTIONS(2114),
    [anon_sym_long] = ACTIONS(2114),
    [anon_sym_short] = ACTIONS(2114),
    [anon_sym_LBRACK] = ACTIONS(2114),
    [anon_sym_static] = ACTIONS(2114),
    [anon_sym_register] = ACTIONS(2114),
    [anon_sym_inline] = ACTIONS(2114),
    [anon_sym___inline] = ACTIONS(2114),
    [anon_sym___inline__] = ACTIONS(2114),
    [anon_sym___forceinline] = ACTIONS(2114),
    [anon_sym_thread_local] = ACTIONS(2114),
    [anon_sym___thread] = ACTIONS(2114),
    [anon_sym_const] = ACTIONS(2114),
    [anon_sym_constexpr] = ACTIONS(2114),
    [anon_sym_volatile] = ACTIONS(2114),
    [anon_sym_restrict] = ACTIONS(2114),
    [anon_sym___restrict__] = ACTIONS(2114),
    [anon_sym__Atomic] = ACTIONS(2114),
    [anon_sym__Noreturn] = ACTIONS(2114),
    [anon_sym_noreturn] = ACTIONS(2114),
    [anon_sym_mutable] = ACTIONS(2114),
    [anon_sym_constinit] = ACTIONS(2114),
    [anon_sym_consteval] = ACTIONS(2114),
    [anon_sym_alignas] = ACTIONS(2114),
    [anon_sym__Alignas] = ACTIONS(2114),
    [sym_primitive_type] = ACTIONS(2114),
    [anon_sym_enum] = ACTIONS(2114),
    [anon_sym_class] = ACTIONS(2114),
    [anon_sym_struct] = ACTIONS(2114),
    [anon_sym_union] = ACTIONS(2114),
    [anon_sym_if] = ACTIONS(2114),
    [anon_sym_else] = ACTIONS(2114),
    [anon_sym_switch] = ACTIONS(2114),
    [anon_sym_while] = ACTIONS(2114),
    [anon_sym_do] = ACTIONS(2114),
    [anon_sym_for] = ACTIONS(2114),
    [anon_sym_return] = ACTIONS(2114),
    [anon_sym_break] = ACTIONS(2114),
    [anon_sym_continue] = ACTIONS(2114),
    [anon_sym_goto] = ACTIONS(2114),
    [anon_sym___try] = ACTIONS(2114),
    [anon_sym___leave] = ACTIONS(2114),
    [anon_sym_not] = ACTIONS(2114),
    [anon_sym_compl] = ACTIONS(2114),
    [anon_sym_DASH_DASH] = ACTIONS(2116),
    [anon_sym_PLUS_PLUS] = ACTIONS(2116),
    [anon_sym_sizeof] = ACTIONS(2114),
    [anon_sym___alignof__] = ACTIONS(2114),
    [anon_sym___alignof] = ACTIONS(2114),
    [anon_sym__alignof] = ACTIONS(2114),
    [anon_sym_alignof] = ACTIONS(2114),
    [anon_sym__Alignof] = ACTIONS(2114),
    [anon_sym_offsetof] = ACTIONS(2114),
    [anon_sym__Generic] = ACTIONS(2114),
    [anon_sym_asm] = ACTIONS(2114),
    [anon_sym___asm__] = ACTIONS(2114),
    [sym_number_literal] = ACTIONS(2116),
    [anon_sym_L_SQUOTE] = ACTIONS(2116),
    [anon_sym_u_SQUOTE] = ACTIONS(2116),
    [anon_sym_U_SQUOTE] = ACTIONS(2116),
    [anon_sym_u8_SQUOTE] = ACTIONS(2116),
    [anon_sym_SQUOTE] = ACTIONS(2116),
    [anon_sym_L_DQUOTE] = ACTIONS(2116),
    [anon_sym_u_DQUOTE] = ACTIONS(2116),
    [anon_sym_U_DQUOTE] = ACTIONS(2116),
    [anon_sym_u8_DQUOTE] = ACTIONS(2116),
    [anon_sym_DQUOTE] = ACTIONS(2116),
    [sym_true] = ACTIONS(2114),
    [sym_false] = ACTIONS(2114),
    [anon_sym_NULL] = ACTIONS(2114),
    [anon_sym_nullptr] = ACTIONS(2114),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2114),
    [anon_sym_decltype] = ACTIONS(2114),
    [sym_virtual] = ACTIONS(2114),
    [anon_sym_typename] = ACTIONS(2114),
    [anon_sym_template] = ACTIONS(2114),
    [anon_sym_try] = ACTIONS(2114),
    [anon_sym_delete] = ACTIONS(2114),
    [anon_sym_throw] = ACTIONS(2114),
    [anon_sym_co_return] = ACTIONS(2114),
    [anon_sym_co_yield] = ACTIONS(2114),
    [anon_sym_R_DQUOTE] = ACTIONS(2116),
    [anon_sym_LR_DQUOTE] = ACTIONS(2116),
    [anon_sym_uR_DQUOTE] = ACTIONS(2116),
    [anon_sym_UR_DQUOTE] = ACTIONS(2116),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2116),
    [anon_sym_co_await] = ACTIONS(2114),
    [anon_sym_new] = ACTIONS(2114),
    [anon_sym_requires] = ACTIONS(2114),
    [sym_this] = ACTIONS(2114),
    [anon_sym_discard] = ACTIONS(2114),
    [anon_sym_precise] = ACTIONS(2114),
    [anon_sym_shared] = ACTIONS(2114),
    [anon_sym_groupshared] = ACTIONS(2114),
    [anon_sym_uniform] = ACTIONS(2114),
    [anon_sym_row_major] = ACTIONS(2114),
    [anon_sym_column_major] = ACTIONS(2114),
    [anon_sym_globallycoherent] = ACTIONS(2114),
    [anon_sym_centroid] = ACTIONS(2114),
    [anon_sym_noperspective] = ACTIONS(2114),
    [anon_sym_nointerpolation] = ACTIONS(2114),
    [anon_sym_sample] = ACTIONS(2114),
    [anon_sym_linear] = ACTIONS(2114),
    [anon_sym_snorm] = ACTIONS(2114),
    [anon_sym_unorm] = ACTIONS(2114),
    [anon_sym_point] = ACTIONS(2114),
    [anon_sym_line] = ACTIONS(2114),
    [anon_sym_triangleadj] = ACTIONS(2114),
    [anon_sym_lineadj] = ACTIONS(2114),
    [anon_sym_triangle] = ACTIONS(2114),
    [anon_sym_cbuffer] = ACTIONS(2114),
  },
  [1020] = {
    [sym_identifier] = ACTIONS(2170),
    [anon_sym_LPAREN2] = ACTIONS(2172),
    [anon_sym_BANG] = ACTIONS(2172),
    [anon_sym_TILDE] = ACTIONS(2172),
    [anon_sym_DASH] = ACTIONS(2170),
    [anon_sym_PLUS] = ACTIONS(2170),
    [anon_sym_STAR] = ACTIONS(2172),
    [anon_sym_AMP] = ACTIONS(2172),
    [anon_sym_SEMI] = ACTIONS(2172),
    [anon_sym___extension__] = ACTIONS(2170),
    [anon_sym_typedef] = ACTIONS(2170),
    [anon_sym_in] = ACTIONS(2170),
    [anon_sym_out] = ACTIONS(2170),
    [anon_sym_inout] = ACTIONS(2170),
    [anon_sym_extern] = ACTIONS(2170),
    [anon_sym___attribute__] = ACTIONS(2170),
    [anon_sym_COLON_COLON] = ACTIONS(2172),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2172),
    [anon_sym___declspec] = ACTIONS(2170),
    [anon_sym_LBRACE] = ACTIONS(2172),
    [anon_sym_signed] = ACTIONS(2170),
    [anon_sym_unsigned] = ACTIONS(2170),
    [anon_sym_long] = ACTIONS(2170),
    [anon_sym_short] = ACTIONS(2170),
    [anon_sym_LBRACK] = ACTIONS(2170),
    [anon_sym_static] = ACTIONS(2170),
    [anon_sym_register] = ACTIONS(2170),
    [anon_sym_inline] = ACTIONS(2170),
    [anon_sym___inline] = ACTIONS(2170),
    [anon_sym___inline__] = ACTIONS(2170),
    [anon_sym___forceinline] = ACTIONS(2170),
    [anon_sym_thread_local] = ACTIONS(2170),
    [anon_sym___thread] = ACTIONS(2170),
    [anon_sym_const] = ACTIONS(2170),
    [anon_sym_constexpr] = ACTIONS(2170),
    [anon_sym_volatile] = ACTIONS(2170),
    [anon_sym_restrict] = ACTIONS(2170),
    [anon_sym___restrict__] = ACTIONS(2170),
    [anon_sym__Atomic] = ACTIONS(2170),
    [anon_sym__Noreturn] = ACTIONS(2170),
    [anon_sym_noreturn] = ACTIONS(2170),
    [anon_sym_mutable] = ACTIONS(2170),
    [anon_sym_constinit] = ACTIONS(2170),
    [anon_sym_consteval] = ACTIONS(2170),
    [anon_sym_alignas] = ACTIONS(2170),
    [anon_sym__Alignas] = ACTIONS(2170),
    [sym_primitive_type] = ACTIONS(2170),
    [anon_sym_enum] = ACTIONS(2170),
    [anon_sym_class] = ACTIONS(2170),
    [anon_sym_struct] = ACTIONS(2170),
    [anon_sym_union] = ACTIONS(2170),
    [anon_sym_if] = ACTIONS(2170),
    [anon_sym_else] = ACTIONS(2170),
    [anon_sym_switch] = ACTIONS(2170),
    [anon_sym_while] = ACTIONS(2170),
    [anon_sym_do] = ACTIONS(2170),
    [anon_sym_for] = ACTIONS(2170),
    [anon_sym_return] = ACTIONS(2170),
    [anon_sym_break] = ACTIONS(2170),
    [anon_sym_continue] = ACTIONS(2170),
    [anon_sym_goto] = ACTIONS(2170),
    [anon_sym___try] = ACTIONS(2170),
    [anon_sym___leave] = ACTIONS(2170),
    [anon_sym_not] = ACTIONS(2170),
    [anon_sym_compl] = ACTIONS(2170),
    [anon_sym_DASH_DASH] = ACTIONS(2172),
    [anon_sym_PLUS_PLUS] = ACTIONS(2172),
    [anon_sym_sizeof] = ACTIONS(2170),
    [anon_sym___alignof__] = ACTIONS(2170),
    [anon_sym___alignof] = ACTIONS(2170),
    [anon_sym__alignof] = ACTIONS(2170),
    [anon_sym_alignof] = ACTIONS(2170),
    [anon_sym__Alignof] = ACTIONS(2170),
    [anon_sym_offsetof] = ACTIONS(2170),
    [anon_sym__Generic] = ACTIONS(2170),
    [anon_sym_asm] = ACTIONS(2170),
    [anon_sym___asm__] = ACTIONS(2170),
    [sym_number_literal] = ACTIONS(2172),
    [anon_sym_L_SQUOTE] = ACTIONS(2172),
    [anon_sym_u_SQUOTE] = ACTIONS(2172),
    [anon_sym_U_SQUOTE] = ACTIONS(2172),
    [anon_sym_u8_SQUOTE] = ACTIONS(2172),
    [anon_sym_SQUOTE] = ACTIONS(2172),
    [anon_sym_L_DQUOTE] = ACTIONS(2172),
    [anon_sym_u_DQUOTE] = ACTIONS(2172),
    [anon_sym_U_DQUOTE] = ACTIONS(2172),
    [anon_sym_u8_DQUOTE] = ACTIONS(2172),
    [anon_sym_DQUOTE] = ACTIONS(2172),
    [sym_true] = ACTIONS(2170),
    [sym_false] = ACTIONS(2170),
    [anon_sym_NULL] = ACTIONS(2170),
    [anon_sym_nullptr] = ACTIONS(2170),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2170),
    [anon_sym_decltype] = ACTIONS(2170),
    [sym_virtual] = ACTIONS(2170),
    [anon_sym_typename] = ACTIONS(2170),
    [anon_sym_template] = ACTIONS(2170),
    [anon_sym_try] = ACTIONS(2170),
    [anon_sym_delete] = ACTIONS(2170),
    [anon_sym_throw] = ACTIONS(2170),
    [anon_sym_co_return] = ACTIONS(2170),
    [anon_sym_co_yield] = ACTIONS(2170),
    [anon_sym_R_DQUOTE] = ACTIONS(2172),
    [anon_sym_LR_DQUOTE] = ACTIONS(2172),
    [anon_sym_uR_DQUOTE] = ACTIONS(2172),
    [anon_sym_UR_DQUOTE] = ACTIONS(2172),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2172),
    [anon_sym_co_await] = ACTIONS(2170),
    [anon_sym_new] = ACTIONS(2170),
    [anon_sym_requires] = ACTIONS(2170),
    [sym_this] = ACTIONS(2170),
    [anon_sym_discard] = ACTIONS(2170),
    [anon_sym_precise] = ACTIONS(2170),
    [anon_sym_shared] = ACTIONS(2170),
    [anon_sym_groupshared] = ACTIONS(2170),
    [anon_sym_uniform] = ACTIONS(2170),
    [anon_sym_row_major] = ACTIONS(2170),
    [anon_sym_column_major] = ACTIONS(2170),
    [anon_sym_globallycoherent] = ACTIONS(2170),
    [anon_sym_centroid] = ACTIONS(2170),
    [anon_sym_noperspective] = ACTIONS(2170),
    [anon_sym_nointerpolation] = ACTIONS(2170),
    [anon_sym_sample] = ACTIONS(2170),
    [anon_sym_linear] = ACTIONS(2170),
    [anon_sym_snorm] = ACTIONS(2170),
    [anon_sym_unorm] = ACTIONS(2170),
    [anon_sym_point] = ACTIONS(2170),
    [anon_sym_line] = ACTIONS(2170),
    [anon_sym_triangleadj] = ACTIONS(2170),
    [anon_sym_lineadj] = ACTIONS(2170),
    [anon_sym_triangle] = ACTIONS(2170),
    [anon_sym_cbuffer] = ACTIONS(2170),
  },
  [1021] = {
    [sym_identifier] = ACTIONS(2090),
    [anon_sym_LPAREN2] = ACTIONS(2092),
    [anon_sym_BANG] = ACTIONS(2092),
    [anon_sym_TILDE] = ACTIONS(2092),
    [anon_sym_DASH] = ACTIONS(2090),
    [anon_sym_PLUS] = ACTIONS(2090),
    [anon_sym_STAR] = ACTIONS(2092),
    [anon_sym_AMP] = ACTIONS(2092),
    [anon_sym_SEMI] = ACTIONS(2092),
    [anon_sym___extension__] = ACTIONS(2090),
    [anon_sym_typedef] = ACTIONS(2090),
    [anon_sym_in] = ACTIONS(2090),
    [anon_sym_out] = ACTIONS(2090),
    [anon_sym_inout] = ACTIONS(2090),
    [anon_sym_extern] = ACTIONS(2090),
    [anon_sym___attribute__] = ACTIONS(2090),
    [anon_sym_COLON_COLON] = ACTIONS(2092),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2092),
    [anon_sym___declspec] = ACTIONS(2090),
    [anon_sym_LBRACE] = ACTIONS(2092),
    [anon_sym_signed] = ACTIONS(2090),
    [anon_sym_unsigned] = ACTIONS(2090),
    [anon_sym_long] = ACTIONS(2090),
    [anon_sym_short] = ACTIONS(2090),
    [anon_sym_LBRACK] = ACTIONS(2090),
    [anon_sym_static] = ACTIONS(2090),
    [anon_sym_register] = ACTIONS(2090),
    [anon_sym_inline] = ACTIONS(2090),
    [anon_sym___inline] = ACTIONS(2090),
    [anon_sym___inline__] = ACTIONS(2090),
    [anon_sym___forceinline] = ACTIONS(2090),
    [anon_sym_thread_local] = ACTIONS(2090),
    [anon_sym___thread] = ACTIONS(2090),
    [anon_sym_const] = ACTIONS(2090),
    [anon_sym_constexpr] = ACTIONS(2090),
    [anon_sym_volatile] = ACTIONS(2090),
    [anon_sym_restrict] = ACTIONS(2090),
    [anon_sym___restrict__] = ACTIONS(2090),
    [anon_sym__Atomic] = ACTIONS(2090),
    [anon_sym__Noreturn] = ACTIONS(2090),
    [anon_sym_noreturn] = ACTIONS(2090),
    [anon_sym_mutable] = ACTIONS(2090),
    [anon_sym_constinit] = ACTIONS(2090),
    [anon_sym_consteval] = ACTIONS(2090),
    [anon_sym_alignas] = ACTIONS(2090),
    [anon_sym__Alignas] = ACTIONS(2090),
    [sym_primitive_type] = ACTIONS(2090),
    [anon_sym_enum] = ACTIONS(2090),
    [anon_sym_class] = ACTIONS(2090),
    [anon_sym_struct] = ACTIONS(2090),
    [anon_sym_union] = ACTIONS(2090),
    [anon_sym_if] = ACTIONS(2090),
    [anon_sym_else] = ACTIONS(2090),
    [anon_sym_switch] = ACTIONS(2090),
    [anon_sym_while] = ACTIONS(2090),
    [anon_sym_do] = ACTIONS(2090),
    [anon_sym_for] = ACTIONS(2090),
    [anon_sym_return] = ACTIONS(2090),
    [anon_sym_break] = ACTIONS(2090),
    [anon_sym_continue] = ACTIONS(2090),
    [anon_sym_goto] = ACTIONS(2090),
    [anon_sym___try] = ACTIONS(2090),
    [anon_sym___leave] = ACTIONS(2090),
    [anon_sym_not] = ACTIONS(2090),
    [anon_sym_compl] = ACTIONS(2090),
    [anon_sym_DASH_DASH] = ACTIONS(2092),
    [anon_sym_PLUS_PLUS] = ACTIONS(2092),
    [anon_sym_sizeof] = ACTIONS(2090),
    [anon_sym___alignof__] = ACTIONS(2090),
    [anon_sym___alignof] = ACTIONS(2090),
    [anon_sym__alignof] = ACTIONS(2090),
    [anon_sym_alignof] = ACTIONS(2090),
    [anon_sym__Alignof] = ACTIONS(2090),
    [anon_sym_offsetof] = ACTIONS(2090),
    [anon_sym__Generic] = ACTIONS(2090),
    [anon_sym_asm] = ACTIONS(2090),
    [anon_sym___asm__] = ACTIONS(2090),
    [sym_number_literal] = ACTIONS(2092),
    [anon_sym_L_SQUOTE] = ACTIONS(2092),
    [anon_sym_u_SQUOTE] = ACTIONS(2092),
    [anon_sym_U_SQUOTE] = ACTIONS(2092),
    [anon_sym_u8_SQUOTE] = ACTIONS(2092),
    [anon_sym_SQUOTE] = ACTIONS(2092),
    [anon_sym_L_DQUOTE] = ACTIONS(2092),
    [anon_sym_u_DQUOTE] = ACTIONS(2092),
    [anon_sym_U_DQUOTE] = ACTIONS(2092),
    [anon_sym_u8_DQUOTE] = ACTIONS(2092),
    [anon_sym_DQUOTE] = ACTIONS(2092),
    [sym_true] = ACTIONS(2090),
    [sym_false] = ACTIONS(2090),
    [anon_sym_NULL] = ACTIONS(2090),
    [anon_sym_nullptr] = ACTIONS(2090),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2090),
    [anon_sym_decltype] = ACTIONS(2090),
    [sym_virtual] = ACTIONS(2090),
    [anon_sym_typename] = ACTIONS(2090),
    [anon_sym_template] = ACTIONS(2090),
    [anon_sym_try] = ACTIONS(2090),
    [anon_sym_delete] = ACTIONS(2090),
    [anon_sym_throw] = ACTIONS(2090),
    [anon_sym_co_return] = ACTIONS(2090),
    [anon_sym_co_yield] = ACTIONS(2090),
    [anon_sym_R_DQUOTE] = ACTIONS(2092),
    [anon_sym_LR_DQUOTE] = ACTIONS(2092),
    [anon_sym_uR_DQUOTE] = ACTIONS(2092),
    [anon_sym_UR_DQUOTE] = ACTIONS(2092),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2092),
    [anon_sym_co_await] = ACTIONS(2090),
    [anon_sym_new] = ACTIONS(2090),
    [anon_sym_requires] = ACTIONS(2090),
    [sym_this] = ACTIONS(2090),
    [anon_sym_discard] = ACTIONS(2090),
    [anon_sym_precise] = ACTIONS(2090),
    [anon_sym_shared] = ACTIONS(2090),
    [anon_sym_groupshared] = ACTIONS(2090),
    [anon_sym_uniform] = ACTIONS(2090),
    [anon_sym_row_major] = ACTIONS(2090),
    [anon_sym_column_major] = ACTIONS(2090),
    [anon_sym_globallycoherent] = ACTIONS(2090),
    [anon_sym_centroid] = ACTIONS(2090),
    [anon_sym_noperspective] = ACTIONS(2090),
    [anon_sym_nointerpolation] = ACTIONS(2090),
    [anon_sym_sample] = ACTIONS(2090),
    [anon_sym_linear] = ACTIONS(2090),
    [anon_sym_snorm] = ACTIONS(2090),
    [anon_sym_unorm] = ACTIONS(2090),
    [anon_sym_point] = ACTIONS(2090),
    [anon_sym_line] = ACTIONS(2090),
    [anon_sym_triangleadj] = ACTIONS(2090),
    [anon_sym_lineadj] = ACTIONS(2090),
    [anon_sym_triangle] = ACTIONS(2090),
    [anon_sym_cbuffer] = ACTIONS(2090),
  },
  [1022] = {
    [sym_identifier] = ACTIONS(2166),
    [anon_sym_LPAREN2] = ACTIONS(2168),
    [anon_sym_BANG] = ACTIONS(2168),
    [anon_sym_TILDE] = ACTIONS(2168),
    [anon_sym_DASH] = ACTIONS(2166),
    [anon_sym_PLUS] = ACTIONS(2166),
    [anon_sym_STAR] = ACTIONS(2168),
    [anon_sym_AMP] = ACTIONS(2168),
    [anon_sym_SEMI] = ACTIONS(2168),
    [anon_sym___extension__] = ACTIONS(2166),
    [anon_sym_typedef] = ACTIONS(2166),
    [anon_sym_in] = ACTIONS(2166),
    [anon_sym_out] = ACTIONS(2166),
    [anon_sym_inout] = ACTIONS(2166),
    [anon_sym_extern] = ACTIONS(2166),
    [anon_sym___attribute__] = ACTIONS(2166),
    [anon_sym_COLON_COLON] = ACTIONS(2168),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2168),
    [anon_sym___declspec] = ACTIONS(2166),
    [anon_sym_LBRACE] = ACTIONS(2168),
    [anon_sym_signed] = ACTIONS(2166),
    [anon_sym_unsigned] = ACTIONS(2166),
    [anon_sym_long] = ACTIONS(2166),
    [anon_sym_short] = ACTIONS(2166),
    [anon_sym_LBRACK] = ACTIONS(2166),
    [anon_sym_static] = ACTIONS(2166),
    [anon_sym_register] = ACTIONS(2166),
    [anon_sym_inline] = ACTIONS(2166),
    [anon_sym___inline] = ACTIONS(2166),
    [anon_sym___inline__] = ACTIONS(2166),
    [anon_sym___forceinline] = ACTIONS(2166),
    [anon_sym_thread_local] = ACTIONS(2166),
    [anon_sym___thread] = ACTIONS(2166),
    [anon_sym_const] = ACTIONS(2166),
    [anon_sym_constexpr] = ACTIONS(2166),
    [anon_sym_volatile] = ACTIONS(2166),
    [anon_sym_restrict] = ACTIONS(2166),
    [anon_sym___restrict__] = ACTIONS(2166),
    [anon_sym__Atomic] = ACTIONS(2166),
    [anon_sym__Noreturn] = ACTIONS(2166),
    [anon_sym_noreturn] = ACTIONS(2166),
    [anon_sym_mutable] = ACTIONS(2166),
    [anon_sym_constinit] = ACTIONS(2166),
    [anon_sym_consteval] = ACTIONS(2166),
    [anon_sym_alignas] = ACTIONS(2166),
    [anon_sym__Alignas] = ACTIONS(2166),
    [sym_primitive_type] = ACTIONS(2166),
    [anon_sym_enum] = ACTIONS(2166),
    [anon_sym_class] = ACTIONS(2166),
    [anon_sym_struct] = ACTIONS(2166),
    [anon_sym_union] = ACTIONS(2166),
    [anon_sym_if] = ACTIONS(2166),
    [anon_sym_else] = ACTIONS(2166),
    [anon_sym_switch] = ACTIONS(2166),
    [anon_sym_while] = ACTIONS(2166),
    [anon_sym_do] = ACTIONS(2166),
    [anon_sym_for] = ACTIONS(2166),
    [anon_sym_return] = ACTIONS(2166),
    [anon_sym_break] = ACTIONS(2166),
    [anon_sym_continue] = ACTIONS(2166),
    [anon_sym_goto] = ACTIONS(2166),
    [anon_sym___try] = ACTIONS(2166),
    [anon_sym___leave] = ACTIONS(2166),
    [anon_sym_not] = ACTIONS(2166),
    [anon_sym_compl] = ACTIONS(2166),
    [anon_sym_DASH_DASH] = ACTIONS(2168),
    [anon_sym_PLUS_PLUS] = ACTIONS(2168),
    [anon_sym_sizeof] = ACTIONS(2166),
    [anon_sym___alignof__] = ACTIONS(2166),
    [anon_sym___alignof] = ACTIONS(2166),
    [anon_sym__alignof] = ACTIONS(2166),
    [anon_sym_alignof] = ACTIONS(2166),
    [anon_sym__Alignof] = ACTIONS(2166),
    [anon_sym_offsetof] = ACTIONS(2166),
    [anon_sym__Generic] = ACTIONS(2166),
    [anon_sym_asm] = ACTIONS(2166),
    [anon_sym___asm__] = ACTIONS(2166),
    [sym_number_literal] = ACTIONS(2168),
    [anon_sym_L_SQUOTE] = ACTIONS(2168),
    [anon_sym_u_SQUOTE] = ACTIONS(2168),
    [anon_sym_U_SQUOTE] = ACTIONS(2168),
    [anon_sym_u8_SQUOTE] = ACTIONS(2168),
    [anon_sym_SQUOTE] = ACTIONS(2168),
    [anon_sym_L_DQUOTE] = ACTIONS(2168),
    [anon_sym_u_DQUOTE] = ACTIONS(2168),
    [anon_sym_U_DQUOTE] = ACTIONS(2168),
    [anon_sym_u8_DQUOTE] = ACTIONS(2168),
    [anon_sym_DQUOTE] = ACTIONS(2168),
    [sym_true] = ACTIONS(2166),
    [sym_false] = ACTIONS(2166),
    [anon_sym_NULL] = ACTIONS(2166),
    [anon_sym_nullptr] = ACTIONS(2166),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2166),
    [anon_sym_decltype] = ACTIONS(2166),
    [sym_virtual] = ACTIONS(2166),
    [anon_sym_typename] = ACTIONS(2166),
    [anon_sym_template] = ACTIONS(2166),
    [anon_sym_try] = ACTIONS(2166),
    [anon_sym_delete] = ACTIONS(2166),
    [anon_sym_throw] = ACTIONS(2166),
    [anon_sym_co_return] = ACTIONS(2166),
    [anon_sym_co_yield] = ACTIONS(2166),
    [anon_sym_R_DQUOTE] = ACTIONS(2168),
    [anon_sym_LR_DQUOTE] = ACTIONS(2168),
    [anon_sym_uR_DQUOTE] = ACTIONS(2168),
    [anon_sym_UR_DQUOTE] = ACTIONS(2168),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2168),
    [anon_sym_co_await] = ACTIONS(2166),
    [anon_sym_new] = ACTIONS(2166),
    [anon_sym_requires] = ACTIONS(2166),
    [sym_this] = ACTIONS(2166),
    [anon_sym_discard] = ACTIONS(2166),
    [anon_sym_precise] = ACTIONS(2166),
    [anon_sym_shared] = ACTIONS(2166),
    [anon_sym_groupshared] = ACTIONS(2166),
    [anon_sym_uniform] = ACTIONS(2166),
    [anon_sym_row_major] = ACTIONS(2166),
    [anon_sym_column_major] = ACTIONS(2166),
    [anon_sym_globallycoherent] = ACTIONS(2166),
    [anon_sym_centroid] = ACTIONS(2166),
    [anon_sym_noperspective] = ACTIONS(2166),
    [anon_sym_nointerpolation] = ACTIONS(2166),
    [anon_sym_sample] = ACTIONS(2166),
    [anon_sym_linear] = ACTIONS(2166),
    [anon_sym_snorm] = ACTIONS(2166),
    [anon_sym_unorm] = ACTIONS(2166),
    [anon_sym_point] = ACTIONS(2166),
    [anon_sym_line] = ACTIONS(2166),
    [anon_sym_triangleadj] = ACTIONS(2166),
    [anon_sym_lineadj] = ACTIONS(2166),
    [anon_sym_triangle] = ACTIONS(2166),
    [anon_sym_cbuffer] = ACTIONS(2166),
  },
  [1023] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(1189),
    [sym_raw_string_literal] = STATE(2868),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2233),
    [sym_identifier] = ACTIONS(3822),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3826),
    [anon_sym_TILDE] = ACTIONS(3830),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3834),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3837),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3834),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(3840),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON] = ACTIONS(3926),
    [anon_sym_SEMI] = ACTIONS(3928),
    [anon_sym___extension__] = ACTIONS(3822),
    [anon_sym_in] = ACTIONS(3822),
    [anon_sym_out] = ACTIONS(3822),
    [anon_sym_inout] = ACTIONS(3822),
    [anon_sym_extern] = ACTIONS(3822),
    [anon_sym___attribute__] = ACTIONS(3822),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3845),
    [anon_sym___declspec] = ACTIONS(3822),
    [anon_sym___based] = ACTIONS(3822),
    [anon_sym___cdecl] = ACTIONS(3822),
    [anon_sym___clrcall] = ACTIONS(3822),
    [anon_sym___stdcall] = ACTIONS(3822),
    [anon_sym___fastcall] = ACTIONS(3822),
    [anon_sym___thiscall] = ACTIONS(3822),
    [anon_sym___vectorcall] = ACTIONS(3822),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_signed] = ACTIONS(3848),
    [anon_sym_unsigned] = ACTIONS(3848),
    [anon_sym_long] = ACTIONS(3848),
    [anon_sym_short] = ACTIONS(3848),
    [anon_sym_LBRACK] = ACTIONS(3850),
    [anon_sym_static] = ACTIONS(3822),
    [anon_sym_EQ] = ACTIONS(3854),
    [anon_sym_register] = ACTIONS(3822),
    [anon_sym_inline] = ACTIONS(3822),
    [anon_sym___inline] = ACTIONS(3822),
    [anon_sym___inline__] = ACTIONS(3822),
    [anon_sym___forceinline] = ACTIONS(3822),
    [anon_sym_thread_local] = ACTIONS(3822),
    [anon_sym___thread] = ACTIONS(3822),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3822),
    [anon_sym_volatile] = ACTIONS(3822),
    [anon_sym_restrict] = ACTIONS(3822),
    [anon_sym___restrict__] = ACTIONS(3822),
    [anon_sym__Atomic] = ACTIONS(3822),
    [anon_sym__Noreturn] = ACTIONS(3822),
    [anon_sym_noreturn] = ACTIONS(3822),
    [anon_sym_mutable] = ACTIONS(3822),
    [anon_sym_constinit] = ACTIONS(3822),
    [anon_sym_consteval] = ACTIONS(3822),
    [anon_sym_alignas] = ACTIONS(3822),
    [anon_sym__Alignas] = ACTIONS(3822),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3856),
    [anon_sym_SLASH_EQ] = ACTIONS(3856),
    [anon_sym_PERCENT_EQ] = ACTIONS(3856),
    [anon_sym_PLUS_EQ] = ACTIONS(3856),
    [anon_sym_DASH_EQ] = ACTIONS(3856),
    [anon_sym_LT_LT_EQ] = ACTIONS(3856),
    [anon_sym_GT_GT_EQ] = ACTIONS(3856),
    [anon_sym_AMP_EQ] = ACTIONS(3856),
    [anon_sym_CARET_EQ] = ACTIONS(3856),
    [anon_sym_PIPE_EQ] = ACTIONS(3856),
    [anon_sym_and_eq] = ACTIONS(3854),
    [anon_sym_or_eq] = ACTIONS(3854),
    [anon_sym_xor_eq] = ACTIONS(3854),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3832),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3832),
    [anon_sym_not_eq] = ACTIONS(3832),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3822),
    [anon_sym_decltype] = ACTIONS(3822),
    [sym_virtual] = ACTIONS(3822),
    [anon_sym_template] = ACTIONS(3822),
    [anon_sym_operator] = ACTIONS(3822),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_precise] = ACTIONS(3822),
    [anon_sym_shared] = ACTIONS(3822),
    [anon_sym_groupshared] = ACTIONS(3822),
    [anon_sym_uniform] = ACTIONS(3822),
    [anon_sym_row_major] = ACTIONS(3822),
    [anon_sym_column_major] = ACTIONS(3822),
    [anon_sym_globallycoherent] = ACTIONS(3822),
    [anon_sym_centroid] = ACTIONS(3822),
    [anon_sym_noperspective] = ACTIONS(3822),
    [anon_sym_nointerpolation] = ACTIONS(3822),
    [anon_sym_sample] = ACTIONS(3822),
    [anon_sym_linear] = ACTIONS(3822),
    [anon_sym_snorm] = ACTIONS(3822),
    [anon_sym_unorm] = ACTIONS(3822),
    [anon_sym_point] = ACTIONS(3822),
    [anon_sym_line] = ACTIONS(3822),
    [anon_sym_triangleadj] = ACTIONS(3822),
    [anon_sym_lineadj] = ACTIONS(3822),
    [anon_sym_triangle] = ACTIONS(3822),
  },
  [1024] = {
    [sym_identifier] = ACTIONS(2178),
    [anon_sym_LPAREN2] = ACTIONS(2180),
    [anon_sym_BANG] = ACTIONS(2180),
    [anon_sym_TILDE] = ACTIONS(2180),
    [anon_sym_DASH] = ACTIONS(2178),
    [anon_sym_PLUS] = ACTIONS(2178),
    [anon_sym_STAR] = ACTIONS(2180),
    [anon_sym_AMP] = ACTIONS(2180),
    [anon_sym_SEMI] = ACTIONS(2180),
    [anon_sym___extension__] = ACTIONS(2178),
    [anon_sym_typedef] = ACTIONS(2178),
    [anon_sym_in] = ACTIONS(2178),
    [anon_sym_out] = ACTIONS(2178),
    [anon_sym_inout] = ACTIONS(2178),
    [anon_sym_extern] = ACTIONS(2178),
    [anon_sym___attribute__] = ACTIONS(2178),
    [anon_sym_COLON_COLON] = ACTIONS(2180),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2180),
    [anon_sym___declspec] = ACTIONS(2178),
    [anon_sym_LBRACE] = ACTIONS(2180),
    [anon_sym_signed] = ACTIONS(2178),
    [anon_sym_unsigned] = ACTIONS(2178),
    [anon_sym_long] = ACTIONS(2178),
    [anon_sym_short] = ACTIONS(2178),
    [anon_sym_LBRACK] = ACTIONS(2178),
    [anon_sym_static] = ACTIONS(2178),
    [anon_sym_register] = ACTIONS(2178),
    [anon_sym_inline] = ACTIONS(2178),
    [anon_sym___inline] = ACTIONS(2178),
    [anon_sym___inline__] = ACTIONS(2178),
    [anon_sym___forceinline] = ACTIONS(2178),
    [anon_sym_thread_local] = ACTIONS(2178),
    [anon_sym___thread] = ACTIONS(2178),
    [anon_sym_const] = ACTIONS(2178),
    [anon_sym_constexpr] = ACTIONS(2178),
    [anon_sym_volatile] = ACTIONS(2178),
    [anon_sym_restrict] = ACTIONS(2178),
    [anon_sym___restrict__] = ACTIONS(2178),
    [anon_sym__Atomic] = ACTIONS(2178),
    [anon_sym__Noreturn] = ACTIONS(2178),
    [anon_sym_noreturn] = ACTIONS(2178),
    [anon_sym_mutable] = ACTIONS(2178),
    [anon_sym_constinit] = ACTIONS(2178),
    [anon_sym_consteval] = ACTIONS(2178),
    [anon_sym_alignas] = ACTIONS(2178),
    [anon_sym__Alignas] = ACTIONS(2178),
    [sym_primitive_type] = ACTIONS(2178),
    [anon_sym_enum] = ACTIONS(2178),
    [anon_sym_class] = ACTIONS(2178),
    [anon_sym_struct] = ACTIONS(2178),
    [anon_sym_union] = ACTIONS(2178),
    [anon_sym_if] = ACTIONS(2178),
    [anon_sym_else] = ACTIONS(2178),
    [anon_sym_switch] = ACTIONS(2178),
    [anon_sym_while] = ACTIONS(2178),
    [anon_sym_do] = ACTIONS(2178),
    [anon_sym_for] = ACTIONS(2178),
    [anon_sym_return] = ACTIONS(2178),
    [anon_sym_break] = ACTIONS(2178),
    [anon_sym_continue] = ACTIONS(2178),
    [anon_sym_goto] = ACTIONS(2178),
    [anon_sym___try] = ACTIONS(2178),
    [anon_sym___leave] = ACTIONS(2178),
    [anon_sym_not] = ACTIONS(2178),
    [anon_sym_compl] = ACTIONS(2178),
    [anon_sym_DASH_DASH] = ACTIONS(2180),
    [anon_sym_PLUS_PLUS] = ACTIONS(2180),
    [anon_sym_sizeof] = ACTIONS(2178),
    [anon_sym___alignof__] = ACTIONS(2178),
    [anon_sym___alignof] = ACTIONS(2178),
    [anon_sym__alignof] = ACTIONS(2178),
    [anon_sym_alignof] = ACTIONS(2178),
    [anon_sym__Alignof] = ACTIONS(2178),
    [anon_sym_offsetof] = ACTIONS(2178),
    [anon_sym__Generic] = ACTIONS(2178),
    [anon_sym_asm] = ACTIONS(2178),
    [anon_sym___asm__] = ACTIONS(2178),
    [sym_number_literal] = ACTIONS(2180),
    [anon_sym_L_SQUOTE] = ACTIONS(2180),
    [anon_sym_u_SQUOTE] = ACTIONS(2180),
    [anon_sym_U_SQUOTE] = ACTIONS(2180),
    [anon_sym_u8_SQUOTE] = ACTIONS(2180),
    [anon_sym_SQUOTE] = ACTIONS(2180),
    [anon_sym_L_DQUOTE] = ACTIONS(2180),
    [anon_sym_u_DQUOTE] = ACTIONS(2180),
    [anon_sym_U_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8_DQUOTE] = ACTIONS(2180),
    [anon_sym_DQUOTE] = ACTIONS(2180),
    [sym_true] = ACTIONS(2178),
    [sym_false] = ACTIONS(2178),
    [anon_sym_NULL] = ACTIONS(2178),
    [anon_sym_nullptr] = ACTIONS(2178),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2178),
    [anon_sym_decltype] = ACTIONS(2178),
    [sym_virtual] = ACTIONS(2178),
    [anon_sym_typename] = ACTIONS(2178),
    [anon_sym_template] = ACTIONS(2178),
    [anon_sym_try] = ACTIONS(2178),
    [anon_sym_delete] = ACTIONS(2178),
    [anon_sym_throw] = ACTIONS(2178),
    [anon_sym_co_return] = ACTIONS(2178),
    [anon_sym_co_yield] = ACTIONS(2178),
    [anon_sym_R_DQUOTE] = ACTIONS(2180),
    [anon_sym_LR_DQUOTE] = ACTIONS(2180),
    [anon_sym_uR_DQUOTE] = ACTIONS(2180),
    [anon_sym_UR_DQUOTE] = ACTIONS(2180),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2180),
    [anon_sym_co_await] = ACTIONS(2178),
    [anon_sym_new] = ACTIONS(2178),
    [anon_sym_requires] = ACTIONS(2178),
    [sym_this] = ACTIONS(2178),
    [anon_sym_discard] = ACTIONS(2178),
    [anon_sym_precise] = ACTIONS(2178),
    [anon_sym_shared] = ACTIONS(2178),
    [anon_sym_groupshared] = ACTIONS(2178),
    [anon_sym_uniform] = ACTIONS(2178),
    [anon_sym_row_major] = ACTIONS(2178),
    [anon_sym_column_major] = ACTIONS(2178),
    [anon_sym_globallycoherent] = ACTIONS(2178),
    [anon_sym_centroid] = ACTIONS(2178),
    [anon_sym_noperspective] = ACTIONS(2178),
    [anon_sym_nointerpolation] = ACTIONS(2178),
    [anon_sym_sample] = ACTIONS(2178),
    [anon_sym_linear] = ACTIONS(2178),
    [anon_sym_snorm] = ACTIONS(2178),
    [anon_sym_unorm] = ACTIONS(2178),
    [anon_sym_point] = ACTIONS(2178),
    [anon_sym_line] = ACTIONS(2178),
    [anon_sym_triangleadj] = ACTIONS(2178),
    [anon_sym_lineadj] = ACTIONS(2178),
    [anon_sym_triangle] = ACTIONS(2178),
    [anon_sym_cbuffer] = ACTIONS(2178),
  },
  [1025] = {
    [sym_identifier] = ACTIONS(2146),
    [anon_sym_LPAREN2] = ACTIONS(2148),
    [anon_sym_BANG] = ACTIONS(2148),
    [anon_sym_TILDE] = ACTIONS(2148),
    [anon_sym_DASH] = ACTIONS(2146),
    [anon_sym_PLUS] = ACTIONS(2146),
    [anon_sym_STAR] = ACTIONS(2148),
    [anon_sym_AMP] = ACTIONS(2148),
    [anon_sym_SEMI] = ACTIONS(2148),
    [anon_sym___extension__] = ACTIONS(2146),
    [anon_sym_typedef] = ACTIONS(2146),
    [anon_sym_in] = ACTIONS(2146),
    [anon_sym_out] = ACTIONS(2146),
    [anon_sym_inout] = ACTIONS(2146),
    [anon_sym_extern] = ACTIONS(2146),
    [anon_sym___attribute__] = ACTIONS(2146),
    [anon_sym_COLON_COLON] = ACTIONS(2148),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2148),
    [anon_sym___declspec] = ACTIONS(2146),
    [anon_sym_LBRACE] = ACTIONS(2148),
    [anon_sym_signed] = ACTIONS(2146),
    [anon_sym_unsigned] = ACTIONS(2146),
    [anon_sym_long] = ACTIONS(2146),
    [anon_sym_short] = ACTIONS(2146),
    [anon_sym_LBRACK] = ACTIONS(2146),
    [anon_sym_static] = ACTIONS(2146),
    [anon_sym_register] = ACTIONS(2146),
    [anon_sym_inline] = ACTIONS(2146),
    [anon_sym___inline] = ACTIONS(2146),
    [anon_sym___inline__] = ACTIONS(2146),
    [anon_sym___forceinline] = ACTIONS(2146),
    [anon_sym_thread_local] = ACTIONS(2146),
    [anon_sym___thread] = ACTIONS(2146),
    [anon_sym_const] = ACTIONS(2146),
    [anon_sym_constexpr] = ACTIONS(2146),
    [anon_sym_volatile] = ACTIONS(2146),
    [anon_sym_restrict] = ACTIONS(2146),
    [anon_sym___restrict__] = ACTIONS(2146),
    [anon_sym__Atomic] = ACTIONS(2146),
    [anon_sym__Noreturn] = ACTIONS(2146),
    [anon_sym_noreturn] = ACTIONS(2146),
    [anon_sym_mutable] = ACTIONS(2146),
    [anon_sym_constinit] = ACTIONS(2146),
    [anon_sym_consteval] = ACTIONS(2146),
    [anon_sym_alignas] = ACTIONS(2146),
    [anon_sym__Alignas] = ACTIONS(2146),
    [sym_primitive_type] = ACTIONS(2146),
    [anon_sym_enum] = ACTIONS(2146),
    [anon_sym_class] = ACTIONS(2146),
    [anon_sym_struct] = ACTIONS(2146),
    [anon_sym_union] = ACTIONS(2146),
    [anon_sym_if] = ACTIONS(2146),
    [anon_sym_else] = ACTIONS(2146),
    [anon_sym_switch] = ACTIONS(2146),
    [anon_sym_while] = ACTIONS(2146),
    [anon_sym_do] = ACTIONS(2146),
    [anon_sym_for] = ACTIONS(2146),
    [anon_sym_return] = ACTIONS(2146),
    [anon_sym_break] = ACTIONS(2146),
    [anon_sym_continue] = ACTIONS(2146),
    [anon_sym_goto] = ACTIONS(2146),
    [anon_sym___try] = ACTIONS(2146),
    [anon_sym___leave] = ACTIONS(2146),
    [anon_sym_not] = ACTIONS(2146),
    [anon_sym_compl] = ACTIONS(2146),
    [anon_sym_DASH_DASH] = ACTIONS(2148),
    [anon_sym_PLUS_PLUS] = ACTIONS(2148),
    [anon_sym_sizeof] = ACTIONS(2146),
    [anon_sym___alignof__] = ACTIONS(2146),
    [anon_sym___alignof] = ACTIONS(2146),
    [anon_sym__alignof] = ACTIONS(2146),
    [anon_sym_alignof] = ACTIONS(2146),
    [anon_sym__Alignof] = ACTIONS(2146),
    [anon_sym_offsetof] = ACTIONS(2146),
    [anon_sym__Generic] = ACTIONS(2146),
    [anon_sym_asm] = ACTIONS(2146),
    [anon_sym___asm__] = ACTIONS(2146),
    [sym_number_literal] = ACTIONS(2148),
    [anon_sym_L_SQUOTE] = ACTIONS(2148),
    [anon_sym_u_SQUOTE] = ACTIONS(2148),
    [anon_sym_U_SQUOTE] = ACTIONS(2148),
    [anon_sym_u8_SQUOTE] = ACTIONS(2148),
    [anon_sym_SQUOTE] = ACTIONS(2148),
    [anon_sym_L_DQUOTE] = ACTIONS(2148),
    [anon_sym_u_DQUOTE] = ACTIONS(2148),
    [anon_sym_U_DQUOTE] = ACTIONS(2148),
    [anon_sym_u8_DQUOTE] = ACTIONS(2148),
    [anon_sym_DQUOTE] = ACTIONS(2148),
    [sym_true] = ACTIONS(2146),
    [sym_false] = ACTIONS(2146),
    [anon_sym_NULL] = ACTIONS(2146),
    [anon_sym_nullptr] = ACTIONS(2146),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2146),
    [anon_sym_decltype] = ACTIONS(2146),
    [sym_virtual] = ACTIONS(2146),
    [anon_sym_typename] = ACTIONS(2146),
    [anon_sym_template] = ACTIONS(2146),
    [anon_sym_try] = ACTIONS(2146),
    [anon_sym_delete] = ACTIONS(2146),
    [anon_sym_throw] = ACTIONS(2146),
    [anon_sym_co_return] = ACTIONS(2146),
    [anon_sym_co_yield] = ACTIONS(2146),
    [anon_sym_R_DQUOTE] = ACTIONS(2148),
    [anon_sym_LR_DQUOTE] = ACTIONS(2148),
    [anon_sym_uR_DQUOTE] = ACTIONS(2148),
    [anon_sym_UR_DQUOTE] = ACTIONS(2148),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2148),
    [anon_sym_co_await] = ACTIONS(2146),
    [anon_sym_new] = ACTIONS(2146),
    [anon_sym_requires] = ACTIONS(2146),
    [sym_this] = ACTIONS(2146),
    [anon_sym_discard] = ACTIONS(2146),
    [anon_sym_precise] = ACTIONS(2146),
    [anon_sym_shared] = ACTIONS(2146),
    [anon_sym_groupshared] = ACTIONS(2146),
    [anon_sym_uniform] = ACTIONS(2146),
    [anon_sym_row_major] = ACTIONS(2146),
    [anon_sym_column_major] = ACTIONS(2146),
    [anon_sym_globallycoherent] = ACTIONS(2146),
    [anon_sym_centroid] = ACTIONS(2146),
    [anon_sym_noperspective] = ACTIONS(2146),
    [anon_sym_nointerpolation] = ACTIONS(2146),
    [anon_sym_sample] = ACTIONS(2146),
    [anon_sym_linear] = ACTIONS(2146),
    [anon_sym_snorm] = ACTIONS(2146),
    [anon_sym_unorm] = ACTIONS(2146),
    [anon_sym_point] = ACTIONS(2146),
    [anon_sym_line] = ACTIONS(2146),
    [anon_sym_triangleadj] = ACTIONS(2146),
    [anon_sym_lineadj] = ACTIONS(2146),
    [anon_sym_triangle] = ACTIONS(2146),
    [anon_sym_cbuffer] = ACTIONS(2146),
  },
  [1026] = {
    [sym_identifier] = ACTIONS(2268),
    [anon_sym_LPAREN2] = ACTIONS(2270),
    [anon_sym_BANG] = ACTIONS(2270),
    [anon_sym_TILDE] = ACTIONS(2270),
    [anon_sym_DASH] = ACTIONS(2268),
    [anon_sym_PLUS] = ACTIONS(2268),
    [anon_sym_STAR] = ACTIONS(2270),
    [anon_sym_AMP] = ACTIONS(2270),
    [anon_sym_SEMI] = ACTIONS(2270),
    [anon_sym___extension__] = ACTIONS(2268),
    [anon_sym_typedef] = ACTIONS(2268),
    [anon_sym_in] = ACTIONS(2268),
    [anon_sym_out] = ACTIONS(2268),
    [anon_sym_inout] = ACTIONS(2268),
    [anon_sym_extern] = ACTIONS(2268),
    [anon_sym___attribute__] = ACTIONS(2268),
    [anon_sym_COLON_COLON] = ACTIONS(2270),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2270),
    [anon_sym___declspec] = ACTIONS(2268),
    [anon_sym_LBRACE] = ACTIONS(2270),
    [anon_sym_signed] = ACTIONS(2268),
    [anon_sym_unsigned] = ACTIONS(2268),
    [anon_sym_long] = ACTIONS(2268),
    [anon_sym_short] = ACTIONS(2268),
    [anon_sym_LBRACK] = ACTIONS(2268),
    [anon_sym_static] = ACTIONS(2268),
    [anon_sym_register] = ACTIONS(2268),
    [anon_sym_inline] = ACTIONS(2268),
    [anon_sym___inline] = ACTIONS(2268),
    [anon_sym___inline__] = ACTIONS(2268),
    [anon_sym___forceinline] = ACTIONS(2268),
    [anon_sym_thread_local] = ACTIONS(2268),
    [anon_sym___thread] = ACTIONS(2268),
    [anon_sym_const] = ACTIONS(2268),
    [anon_sym_constexpr] = ACTIONS(2268),
    [anon_sym_volatile] = ACTIONS(2268),
    [anon_sym_restrict] = ACTIONS(2268),
    [anon_sym___restrict__] = ACTIONS(2268),
    [anon_sym__Atomic] = ACTIONS(2268),
    [anon_sym__Noreturn] = ACTIONS(2268),
    [anon_sym_noreturn] = ACTIONS(2268),
    [anon_sym_mutable] = ACTIONS(2268),
    [anon_sym_constinit] = ACTIONS(2268),
    [anon_sym_consteval] = ACTIONS(2268),
    [anon_sym_alignas] = ACTIONS(2268),
    [anon_sym__Alignas] = ACTIONS(2268),
    [sym_primitive_type] = ACTIONS(2268),
    [anon_sym_enum] = ACTIONS(2268),
    [anon_sym_class] = ACTIONS(2268),
    [anon_sym_struct] = ACTIONS(2268),
    [anon_sym_union] = ACTIONS(2268),
    [anon_sym_if] = ACTIONS(2268),
    [anon_sym_else] = ACTIONS(2268),
    [anon_sym_switch] = ACTIONS(2268),
    [anon_sym_while] = ACTIONS(2268),
    [anon_sym_do] = ACTIONS(2268),
    [anon_sym_for] = ACTIONS(2268),
    [anon_sym_return] = ACTIONS(2268),
    [anon_sym_break] = ACTIONS(2268),
    [anon_sym_continue] = ACTIONS(2268),
    [anon_sym_goto] = ACTIONS(2268),
    [anon_sym___try] = ACTIONS(2268),
    [anon_sym___leave] = ACTIONS(2268),
    [anon_sym_not] = ACTIONS(2268),
    [anon_sym_compl] = ACTIONS(2268),
    [anon_sym_DASH_DASH] = ACTIONS(2270),
    [anon_sym_PLUS_PLUS] = ACTIONS(2270),
    [anon_sym_sizeof] = ACTIONS(2268),
    [anon_sym___alignof__] = ACTIONS(2268),
    [anon_sym___alignof] = ACTIONS(2268),
    [anon_sym__alignof] = ACTIONS(2268),
    [anon_sym_alignof] = ACTIONS(2268),
    [anon_sym__Alignof] = ACTIONS(2268),
    [anon_sym_offsetof] = ACTIONS(2268),
    [anon_sym__Generic] = ACTIONS(2268),
    [anon_sym_asm] = ACTIONS(2268),
    [anon_sym___asm__] = ACTIONS(2268),
    [sym_number_literal] = ACTIONS(2270),
    [anon_sym_L_SQUOTE] = ACTIONS(2270),
    [anon_sym_u_SQUOTE] = ACTIONS(2270),
    [anon_sym_U_SQUOTE] = ACTIONS(2270),
    [anon_sym_u8_SQUOTE] = ACTIONS(2270),
    [anon_sym_SQUOTE] = ACTIONS(2270),
    [anon_sym_L_DQUOTE] = ACTIONS(2270),
    [anon_sym_u_DQUOTE] = ACTIONS(2270),
    [anon_sym_U_DQUOTE] = ACTIONS(2270),
    [anon_sym_u8_DQUOTE] = ACTIONS(2270),
    [anon_sym_DQUOTE] = ACTIONS(2270),
    [sym_true] = ACTIONS(2268),
    [sym_false] = ACTIONS(2268),
    [anon_sym_NULL] = ACTIONS(2268),
    [anon_sym_nullptr] = ACTIONS(2268),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2268),
    [anon_sym_decltype] = ACTIONS(2268),
    [sym_virtual] = ACTIONS(2268),
    [anon_sym_typename] = ACTIONS(2268),
    [anon_sym_template] = ACTIONS(2268),
    [anon_sym_try] = ACTIONS(2268),
    [anon_sym_delete] = ACTIONS(2268),
    [anon_sym_throw] = ACTIONS(2268),
    [anon_sym_co_return] = ACTIONS(2268),
    [anon_sym_co_yield] = ACTIONS(2268),
    [anon_sym_R_DQUOTE] = ACTIONS(2270),
    [anon_sym_LR_DQUOTE] = ACTIONS(2270),
    [anon_sym_uR_DQUOTE] = ACTIONS(2270),
    [anon_sym_UR_DQUOTE] = ACTIONS(2270),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2270),
    [anon_sym_co_await] = ACTIONS(2268),
    [anon_sym_new] = ACTIONS(2268),
    [anon_sym_requires] = ACTIONS(2268),
    [sym_this] = ACTIONS(2268),
    [anon_sym_discard] = ACTIONS(2268),
    [anon_sym_precise] = ACTIONS(2268),
    [anon_sym_shared] = ACTIONS(2268),
    [anon_sym_groupshared] = ACTIONS(2268),
    [anon_sym_uniform] = ACTIONS(2268),
    [anon_sym_row_major] = ACTIONS(2268),
    [anon_sym_column_major] = ACTIONS(2268),
    [anon_sym_globallycoherent] = ACTIONS(2268),
    [anon_sym_centroid] = ACTIONS(2268),
    [anon_sym_noperspective] = ACTIONS(2268),
    [anon_sym_nointerpolation] = ACTIONS(2268),
    [anon_sym_sample] = ACTIONS(2268),
    [anon_sym_linear] = ACTIONS(2268),
    [anon_sym_snorm] = ACTIONS(2268),
    [anon_sym_unorm] = ACTIONS(2268),
    [anon_sym_point] = ACTIONS(2268),
    [anon_sym_line] = ACTIONS(2268),
    [anon_sym_triangleadj] = ACTIONS(2268),
    [anon_sym_lineadj] = ACTIONS(2268),
    [anon_sym_triangle] = ACTIONS(2268),
    [anon_sym_cbuffer] = ACTIONS(2268),
  },
  [1027] = {
    [sym_identifier] = ACTIONS(2162),
    [anon_sym_LPAREN2] = ACTIONS(2164),
    [anon_sym_BANG] = ACTIONS(2164),
    [anon_sym_TILDE] = ACTIONS(2164),
    [anon_sym_DASH] = ACTIONS(2162),
    [anon_sym_PLUS] = ACTIONS(2162),
    [anon_sym_STAR] = ACTIONS(2164),
    [anon_sym_AMP] = ACTIONS(2164),
    [anon_sym_SEMI] = ACTIONS(2164),
    [anon_sym___extension__] = ACTIONS(2162),
    [anon_sym_typedef] = ACTIONS(2162),
    [anon_sym_in] = ACTIONS(2162),
    [anon_sym_out] = ACTIONS(2162),
    [anon_sym_inout] = ACTIONS(2162),
    [anon_sym_extern] = ACTIONS(2162),
    [anon_sym___attribute__] = ACTIONS(2162),
    [anon_sym_COLON_COLON] = ACTIONS(2164),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2164),
    [anon_sym___declspec] = ACTIONS(2162),
    [anon_sym_LBRACE] = ACTIONS(2164),
    [anon_sym_signed] = ACTIONS(2162),
    [anon_sym_unsigned] = ACTIONS(2162),
    [anon_sym_long] = ACTIONS(2162),
    [anon_sym_short] = ACTIONS(2162),
    [anon_sym_LBRACK] = ACTIONS(2162),
    [anon_sym_static] = ACTIONS(2162),
    [anon_sym_register] = ACTIONS(2162),
    [anon_sym_inline] = ACTIONS(2162),
    [anon_sym___inline] = ACTIONS(2162),
    [anon_sym___inline__] = ACTIONS(2162),
    [anon_sym___forceinline] = ACTIONS(2162),
    [anon_sym_thread_local] = ACTIONS(2162),
    [anon_sym___thread] = ACTIONS(2162),
    [anon_sym_const] = ACTIONS(2162),
    [anon_sym_constexpr] = ACTIONS(2162),
    [anon_sym_volatile] = ACTIONS(2162),
    [anon_sym_restrict] = ACTIONS(2162),
    [anon_sym___restrict__] = ACTIONS(2162),
    [anon_sym__Atomic] = ACTIONS(2162),
    [anon_sym__Noreturn] = ACTIONS(2162),
    [anon_sym_noreturn] = ACTIONS(2162),
    [anon_sym_mutable] = ACTIONS(2162),
    [anon_sym_constinit] = ACTIONS(2162),
    [anon_sym_consteval] = ACTIONS(2162),
    [anon_sym_alignas] = ACTIONS(2162),
    [anon_sym__Alignas] = ACTIONS(2162),
    [sym_primitive_type] = ACTIONS(2162),
    [anon_sym_enum] = ACTIONS(2162),
    [anon_sym_class] = ACTIONS(2162),
    [anon_sym_struct] = ACTIONS(2162),
    [anon_sym_union] = ACTIONS(2162),
    [anon_sym_if] = ACTIONS(2162),
    [anon_sym_else] = ACTIONS(2162),
    [anon_sym_switch] = ACTIONS(2162),
    [anon_sym_while] = ACTIONS(2162),
    [anon_sym_do] = ACTIONS(2162),
    [anon_sym_for] = ACTIONS(2162),
    [anon_sym_return] = ACTIONS(2162),
    [anon_sym_break] = ACTIONS(2162),
    [anon_sym_continue] = ACTIONS(2162),
    [anon_sym_goto] = ACTIONS(2162),
    [anon_sym___try] = ACTIONS(2162),
    [anon_sym___leave] = ACTIONS(2162),
    [anon_sym_not] = ACTIONS(2162),
    [anon_sym_compl] = ACTIONS(2162),
    [anon_sym_DASH_DASH] = ACTIONS(2164),
    [anon_sym_PLUS_PLUS] = ACTIONS(2164),
    [anon_sym_sizeof] = ACTIONS(2162),
    [anon_sym___alignof__] = ACTIONS(2162),
    [anon_sym___alignof] = ACTIONS(2162),
    [anon_sym__alignof] = ACTIONS(2162),
    [anon_sym_alignof] = ACTIONS(2162),
    [anon_sym__Alignof] = ACTIONS(2162),
    [anon_sym_offsetof] = ACTIONS(2162),
    [anon_sym__Generic] = ACTIONS(2162),
    [anon_sym_asm] = ACTIONS(2162),
    [anon_sym___asm__] = ACTIONS(2162),
    [sym_number_literal] = ACTIONS(2164),
    [anon_sym_L_SQUOTE] = ACTIONS(2164),
    [anon_sym_u_SQUOTE] = ACTIONS(2164),
    [anon_sym_U_SQUOTE] = ACTIONS(2164),
    [anon_sym_u8_SQUOTE] = ACTIONS(2164),
    [anon_sym_SQUOTE] = ACTIONS(2164),
    [anon_sym_L_DQUOTE] = ACTIONS(2164),
    [anon_sym_u_DQUOTE] = ACTIONS(2164),
    [anon_sym_U_DQUOTE] = ACTIONS(2164),
    [anon_sym_u8_DQUOTE] = ACTIONS(2164),
    [anon_sym_DQUOTE] = ACTIONS(2164),
    [sym_true] = ACTIONS(2162),
    [sym_false] = ACTIONS(2162),
    [anon_sym_NULL] = ACTIONS(2162),
    [anon_sym_nullptr] = ACTIONS(2162),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2162),
    [anon_sym_decltype] = ACTIONS(2162),
    [sym_virtual] = ACTIONS(2162),
    [anon_sym_typename] = ACTIONS(2162),
    [anon_sym_template] = ACTIONS(2162),
    [anon_sym_try] = ACTIONS(2162),
    [anon_sym_delete] = ACTIONS(2162),
    [anon_sym_throw] = ACTIONS(2162),
    [anon_sym_co_return] = ACTIONS(2162),
    [anon_sym_co_yield] = ACTIONS(2162),
    [anon_sym_R_DQUOTE] = ACTIONS(2164),
    [anon_sym_LR_DQUOTE] = ACTIONS(2164),
    [anon_sym_uR_DQUOTE] = ACTIONS(2164),
    [anon_sym_UR_DQUOTE] = ACTIONS(2164),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2164),
    [anon_sym_co_await] = ACTIONS(2162),
    [anon_sym_new] = ACTIONS(2162),
    [anon_sym_requires] = ACTIONS(2162),
    [sym_this] = ACTIONS(2162),
    [anon_sym_discard] = ACTIONS(2162),
    [anon_sym_precise] = ACTIONS(2162),
    [anon_sym_shared] = ACTIONS(2162),
    [anon_sym_groupshared] = ACTIONS(2162),
    [anon_sym_uniform] = ACTIONS(2162),
    [anon_sym_row_major] = ACTIONS(2162),
    [anon_sym_column_major] = ACTIONS(2162),
    [anon_sym_globallycoherent] = ACTIONS(2162),
    [anon_sym_centroid] = ACTIONS(2162),
    [anon_sym_noperspective] = ACTIONS(2162),
    [anon_sym_nointerpolation] = ACTIONS(2162),
    [anon_sym_sample] = ACTIONS(2162),
    [anon_sym_linear] = ACTIONS(2162),
    [anon_sym_snorm] = ACTIONS(2162),
    [anon_sym_unorm] = ACTIONS(2162),
    [anon_sym_point] = ACTIONS(2162),
    [anon_sym_line] = ACTIONS(2162),
    [anon_sym_triangleadj] = ACTIONS(2162),
    [anon_sym_lineadj] = ACTIONS(2162),
    [anon_sym_triangle] = ACTIONS(2162),
    [anon_sym_cbuffer] = ACTIONS(2162),
  },
  [1028] = {
    [sym_identifier] = ACTIONS(3725),
    [anon_sym_LPAREN2] = ACTIONS(3731),
    [anon_sym_BANG] = ACTIONS(3731),
    [anon_sym_TILDE] = ACTIONS(3731),
    [anon_sym_DASH] = ACTIONS(3733),
    [anon_sym_PLUS] = ACTIONS(3733),
    [anon_sym_STAR] = ACTIONS(3731),
    [anon_sym_AMP] = ACTIONS(3731),
    [anon_sym_SEMI] = ACTIONS(3731),
    [anon_sym___extension__] = ACTIONS(3737),
    [anon_sym_in] = ACTIONS(3737),
    [anon_sym_out] = ACTIONS(3737),
    [anon_sym_inout] = ACTIONS(3737),
    [anon_sym_extern] = ACTIONS(3737),
    [anon_sym___attribute__] = ACTIONS(3737),
    [anon_sym_COLON_COLON] = ACTIONS(3728),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3728),
    [anon_sym___declspec] = ACTIONS(3737),
    [anon_sym_LBRACE] = ACTIONS(3731),
    [anon_sym_signed] = ACTIONS(3737),
    [anon_sym_unsigned] = ACTIONS(3737),
    [anon_sym_long] = ACTIONS(3737),
    [anon_sym_short] = ACTIONS(3737),
    [anon_sym_LBRACK] = ACTIONS(3733),
    [anon_sym_static] = ACTIONS(3737),
    [anon_sym_register] = ACTIONS(3737),
    [anon_sym_inline] = ACTIONS(3737),
    [anon_sym___inline] = ACTIONS(3737),
    [anon_sym___inline__] = ACTIONS(3737),
    [anon_sym___forceinline] = ACTIONS(3737),
    [anon_sym_thread_local] = ACTIONS(3737),
    [anon_sym___thread] = ACTIONS(3737),
    [anon_sym_const] = ACTIONS(3737),
    [anon_sym_constexpr] = ACTIONS(3737),
    [anon_sym_volatile] = ACTIONS(3737),
    [anon_sym_restrict] = ACTIONS(3737),
    [anon_sym___restrict__] = ACTIONS(3737),
    [anon_sym__Atomic] = ACTIONS(3737),
    [anon_sym__Noreturn] = ACTIONS(3737),
    [anon_sym_noreturn] = ACTIONS(3737),
    [anon_sym_mutable] = ACTIONS(3737),
    [anon_sym_constinit] = ACTIONS(3737),
    [anon_sym_consteval] = ACTIONS(3737),
    [anon_sym_alignas] = ACTIONS(3737),
    [anon_sym__Alignas] = ACTIONS(3737),
    [sym_primitive_type] = ACTIONS(3725),
    [anon_sym_enum] = ACTIONS(3737),
    [anon_sym_class] = ACTIONS(3737),
    [anon_sym_struct] = ACTIONS(3737),
    [anon_sym_union] = ACTIONS(3737),
    [anon_sym_if] = ACTIONS(3733),
    [anon_sym_switch] = ACTIONS(3733),
    [anon_sym_case] = ACTIONS(3733),
    [anon_sym_default] = ACTIONS(3733),
    [anon_sym_while] = ACTIONS(3733),
    [anon_sym_do] = ACTIONS(3733),
    [anon_sym_for] = ACTIONS(3733),
    [anon_sym_return] = ACTIONS(3733),
    [anon_sym_break] = ACTIONS(3733),
    [anon_sym_continue] = ACTIONS(3733),
    [anon_sym_goto] = ACTIONS(3733),
    [anon_sym___try] = ACTIONS(3733),
    [anon_sym___leave] = ACTIONS(3733),
    [anon_sym_not] = ACTIONS(3733),
    [anon_sym_compl] = ACTIONS(3733),
    [anon_sym_DASH_DASH] = ACTIONS(3731),
    [anon_sym_PLUS_PLUS] = ACTIONS(3731),
    [anon_sym_sizeof] = ACTIONS(3733),
    [anon_sym___alignof__] = ACTIONS(3733),
    [anon_sym___alignof] = ACTIONS(3733),
    [anon_sym__alignof] = ACTIONS(3733),
    [anon_sym_alignof] = ACTIONS(3733),
    [anon_sym__Alignof] = ACTIONS(3733),
    [anon_sym_offsetof] = ACTIONS(3733),
    [anon_sym__Generic] = ACTIONS(3733),
    [anon_sym_asm] = ACTIONS(3733),
    [anon_sym___asm__] = ACTIONS(3733),
    [sym_number_literal] = ACTIONS(3731),
    [anon_sym_L_SQUOTE] = ACTIONS(3731),
    [anon_sym_u_SQUOTE] = ACTIONS(3731),
    [anon_sym_U_SQUOTE] = ACTIONS(3731),
    [anon_sym_u8_SQUOTE] = ACTIONS(3731),
    [anon_sym_SQUOTE] = ACTIONS(3731),
    [anon_sym_L_DQUOTE] = ACTIONS(3731),
    [anon_sym_u_DQUOTE] = ACTIONS(3731),
    [anon_sym_U_DQUOTE] = ACTIONS(3731),
    [anon_sym_u8_DQUOTE] = ACTIONS(3731),
    [anon_sym_DQUOTE] = ACTIONS(3731),
    [sym_true] = ACTIONS(3733),
    [sym_false] = ACTIONS(3733),
    [anon_sym_NULL] = ACTIONS(3733),
    [anon_sym_nullptr] = ACTIONS(3733),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3737),
    [anon_sym_decltype] = ACTIONS(3725),
    [sym_virtual] = ACTIONS(3737),
    [anon_sym_typename] = ACTIONS(3737),
    [anon_sym_template] = ACTIONS(3725),
    [anon_sym_try] = ACTIONS(3733),
    [anon_sym_delete] = ACTIONS(3733),
    [anon_sym_throw] = ACTIONS(3733),
    [anon_sym_co_return] = ACTIONS(3733),
    [anon_sym_co_yield] = ACTIONS(3733),
    [anon_sym_R_DQUOTE] = ACTIONS(3731),
    [anon_sym_LR_DQUOTE] = ACTIONS(3731),
    [anon_sym_uR_DQUOTE] = ACTIONS(3731),
    [anon_sym_UR_DQUOTE] = ACTIONS(3731),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3731),
    [anon_sym_co_await] = ACTIONS(3733),
    [anon_sym_new] = ACTIONS(3733),
    [anon_sym_requires] = ACTIONS(3733),
    [sym_this] = ACTIONS(3733),
    [anon_sym_discard] = ACTIONS(3733),
    [anon_sym_precise] = ACTIONS(3737),
    [anon_sym_shared] = ACTIONS(3737),
    [anon_sym_groupshared] = ACTIONS(3737),
    [anon_sym_uniform] = ACTIONS(3737),
    [anon_sym_row_major] = ACTIONS(3737),
    [anon_sym_column_major] = ACTIONS(3737),
    [anon_sym_globallycoherent] = ACTIONS(3737),
    [anon_sym_centroid] = ACTIONS(3737),
    [anon_sym_noperspective] = ACTIONS(3737),
    [anon_sym_nointerpolation] = ACTIONS(3737),
    [anon_sym_sample] = ACTIONS(3737),
    [anon_sym_linear] = ACTIONS(3737),
    [anon_sym_snorm] = ACTIONS(3737),
    [anon_sym_unorm] = ACTIONS(3737),
    [anon_sym_point] = ACTIONS(3737),
    [anon_sym_line] = ACTIONS(3737),
    [anon_sym_triangleadj] = ACTIONS(3737),
    [anon_sym_lineadj] = ACTIONS(3737),
    [anon_sym_triangle] = ACTIONS(3737),
    [anon_sym_cbuffer] = ACTIONS(3733),
  },
  [1029] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(4608),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_type_descriptor] = STATE(8031),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5574),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3922),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3924),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1030] = {
    [sym_identifier] = ACTIONS(2276),
    [anon_sym_LPAREN2] = ACTIONS(2278),
    [anon_sym_BANG] = ACTIONS(2278),
    [anon_sym_TILDE] = ACTIONS(2278),
    [anon_sym_DASH] = ACTIONS(2276),
    [anon_sym_PLUS] = ACTIONS(2276),
    [anon_sym_STAR] = ACTIONS(2278),
    [anon_sym_AMP] = ACTIONS(2278),
    [anon_sym_SEMI] = ACTIONS(2278),
    [anon_sym___extension__] = ACTIONS(2276),
    [anon_sym_typedef] = ACTIONS(2276),
    [anon_sym_in] = ACTIONS(2276),
    [anon_sym_out] = ACTIONS(2276),
    [anon_sym_inout] = ACTIONS(2276),
    [anon_sym_extern] = ACTIONS(2276),
    [anon_sym___attribute__] = ACTIONS(2276),
    [anon_sym_COLON_COLON] = ACTIONS(2278),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2278),
    [anon_sym___declspec] = ACTIONS(2276),
    [anon_sym_LBRACE] = ACTIONS(2278),
    [anon_sym_signed] = ACTIONS(2276),
    [anon_sym_unsigned] = ACTIONS(2276),
    [anon_sym_long] = ACTIONS(2276),
    [anon_sym_short] = ACTIONS(2276),
    [anon_sym_LBRACK] = ACTIONS(2276),
    [anon_sym_static] = ACTIONS(2276),
    [anon_sym_register] = ACTIONS(2276),
    [anon_sym_inline] = ACTIONS(2276),
    [anon_sym___inline] = ACTIONS(2276),
    [anon_sym___inline__] = ACTIONS(2276),
    [anon_sym___forceinline] = ACTIONS(2276),
    [anon_sym_thread_local] = ACTIONS(2276),
    [anon_sym___thread] = ACTIONS(2276),
    [anon_sym_const] = ACTIONS(2276),
    [anon_sym_constexpr] = ACTIONS(2276),
    [anon_sym_volatile] = ACTIONS(2276),
    [anon_sym_restrict] = ACTIONS(2276),
    [anon_sym___restrict__] = ACTIONS(2276),
    [anon_sym__Atomic] = ACTIONS(2276),
    [anon_sym__Noreturn] = ACTIONS(2276),
    [anon_sym_noreturn] = ACTIONS(2276),
    [anon_sym_mutable] = ACTIONS(2276),
    [anon_sym_constinit] = ACTIONS(2276),
    [anon_sym_consteval] = ACTIONS(2276),
    [anon_sym_alignas] = ACTIONS(2276),
    [anon_sym__Alignas] = ACTIONS(2276),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2276),
    [anon_sym_class] = ACTIONS(2276),
    [anon_sym_struct] = ACTIONS(2276),
    [anon_sym_union] = ACTIONS(2276),
    [anon_sym_if] = ACTIONS(2276),
    [anon_sym_else] = ACTIONS(2276),
    [anon_sym_switch] = ACTIONS(2276),
    [anon_sym_while] = ACTIONS(2276),
    [anon_sym_do] = ACTIONS(2276),
    [anon_sym_for] = ACTIONS(2276),
    [anon_sym_return] = ACTIONS(2276),
    [anon_sym_break] = ACTIONS(2276),
    [anon_sym_continue] = ACTIONS(2276),
    [anon_sym_goto] = ACTIONS(2276),
    [anon_sym___try] = ACTIONS(2276),
    [anon_sym___leave] = ACTIONS(2276),
    [anon_sym_not] = ACTIONS(2276),
    [anon_sym_compl] = ACTIONS(2276),
    [anon_sym_DASH_DASH] = ACTIONS(2278),
    [anon_sym_PLUS_PLUS] = ACTIONS(2278),
    [anon_sym_sizeof] = ACTIONS(2276),
    [anon_sym___alignof__] = ACTIONS(2276),
    [anon_sym___alignof] = ACTIONS(2276),
    [anon_sym__alignof] = ACTIONS(2276),
    [anon_sym_alignof] = ACTIONS(2276),
    [anon_sym__Alignof] = ACTIONS(2276),
    [anon_sym_offsetof] = ACTIONS(2276),
    [anon_sym__Generic] = ACTIONS(2276),
    [anon_sym_asm] = ACTIONS(2276),
    [anon_sym___asm__] = ACTIONS(2276),
    [sym_number_literal] = ACTIONS(2278),
    [anon_sym_L_SQUOTE] = ACTIONS(2278),
    [anon_sym_u_SQUOTE] = ACTIONS(2278),
    [anon_sym_U_SQUOTE] = ACTIONS(2278),
    [anon_sym_u8_SQUOTE] = ACTIONS(2278),
    [anon_sym_SQUOTE] = ACTIONS(2278),
    [anon_sym_L_DQUOTE] = ACTIONS(2278),
    [anon_sym_u_DQUOTE] = ACTIONS(2278),
    [anon_sym_U_DQUOTE] = ACTIONS(2278),
    [anon_sym_u8_DQUOTE] = ACTIONS(2278),
    [anon_sym_DQUOTE] = ACTIONS(2278),
    [sym_true] = ACTIONS(2276),
    [sym_false] = ACTIONS(2276),
    [anon_sym_NULL] = ACTIONS(2276),
    [anon_sym_nullptr] = ACTIONS(2276),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2276),
    [anon_sym_decltype] = ACTIONS(2276),
    [sym_virtual] = ACTIONS(2276),
    [anon_sym_typename] = ACTIONS(2276),
    [anon_sym_template] = ACTIONS(2276),
    [anon_sym_try] = ACTIONS(2276),
    [anon_sym_delete] = ACTIONS(2276),
    [anon_sym_throw] = ACTIONS(2276),
    [anon_sym_co_return] = ACTIONS(2276),
    [anon_sym_co_yield] = ACTIONS(2276),
    [anon_sym_R_DQUOTE] = ACTIONS(2278),
    [anon_sym_LR_DQUOTE] = ACTIONS(2278),
    [anon_sym_uR_DQUOTE] = ACTIONS(2278),
    [anon_sym_UR_DQUOTE] = ACTIONS(2278),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2278),
    [anon_sym_co_await] = ACTIONS(2276),
    [anon_sym_new] = ACTIONS(2276),
    [anon_sym_requires] = ACTIONS(2276),
    [sym_this] = ACTIONS(2276),
    [anon_sym_discard] = ACTIONS(2276),
    [anon_sym_precise] = ACTIONS(2276),
    [anon_sym_shared] = ACTIONS(2276),
    [anon_sym_groupshared] = ACTIONS(2276),
    [anon_sym_uniform] = ACTIONS(2276),
    [anon_sym_row_major] = ACTIONS(2276),
    [anon_sym_column_major] = ACTIONS(2276),
    [anon_sym_globallycoherent] = ACTIONS(2276),
    [anon_sym_centroid] = ACTIONS(2276),
    [anon_sym_noperspective] = ACTIONS(2276),
    [anon_sym_nointerpolation] = ACTIONS(2276),
    [anon_sym_sample] = ACTIONS(2276),
    [anon_sym_linear] = ACTIONS(2276),
    [anon_sym_snorm] = ACTIONS(2276),
    [anon_sym_unorm] = ACTIONS(2276),
    [anon_sym_point] = ACTIONS(2276),
    [anon_sym_line] = ACTIONS(2276),
    [anon_sym_triangleadj] = ACTIONS(2276),
    [anon_sym_lineadj] = ACTIONS(2276),
    [anon_sym_triangle] = ACTIONS(2276),
    [anon_sym_cbuffer] = ACTIONS(2276),
  },
  [1031] = {
    [sym_identifier] = ACTIONS(3657),
    [anon_sym_LPAREN2] = ACTIONS(3659),
    [anon_sym_BANG] = ACTIONS(3659),
    [anon_sym_TILDE] = ACTIONS(3659),
    [anon_sym_DASH] = ACTIONS(3657),
    [anon_sym_PLUS] = ACTIONS(3657),
    [anon_sym_STAR] = ACTIONS(3659),
    [anon_sym_AMP] = ACTIONS(3659),
    [anon_sym_SEMI] = ACTIONS(3659),
    [anon_sym___extension__] = ACTIONS(3657),
    [anon_sym_in] = ACTIONS(3657),
    [anon_sym_out] = ACTIONS(3657),
    [anon_sym_inout] = ACTIONS(3657),
    [anon_sym_extern] = ACTIONS(3657),
    [anon_sym___attribute__] = ACTIONS(3657),
    [anon_sym_COLON_COLON] = ACTIONS(3659),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3659),
    [anon_sym___declspec] = ACTIONS(3657),
    [anon_sym_LBRACE] = ACTIONS(3659),
    [anon_sym_signed] = ACTIONS(3657),
    [anon_sym_unsigned] = ACTIONS(3657),
    [anon_sym_long] = ACTIONS(3657),
    [anon_sym_short] = ACTIONS(3657),
    [anon_sym_LBRACK] = ACTIONS(3657),
    [anon_sym_static] = ACTIONS(3657),
    [anon_sym_register] = ACTIONS(3657),
    [anon_sym_inline] = ACTIONS(3657),
    [anon_sym___inline] = ACTIONS(3657),
    [anon_sym___inline__] = ACTIONS(3657),
    [anon_sym___forceinline] = ACTIONS(3657),
    [anon_sym_thread_local] = ACTIONS(3657),
    [anon_sym___thread] = ACTIONS(3657),
    [anon_sym_const] = ACTIONS(3657),
    [anon_sym_constexpr] = ACTIONS(3657),
    [anon_sym_volatile] = ACTIONS(3657),
    [anon_sym_restrict] = ACTIONS(3657),
    [anon_sym___restrict__] = ACTIONS(3657),
    [anon_sym__Atomic] = ACTIONS(3657),
    [anon_sym__Noreturn] = ACTIONS(3657),
    [anon_sym_noreturn] = ACTIONS(3657),
    [anon_sym_mutable] = ACTIONS(3657),
    [anon_sym_constinit] = ACTIONS(3657),
    [anon_sym_consteval] = ACTIONS(3657),
    [anon_sym_alignas] = ACTIONS(3657),
    [anon_sym__Alignas] = ACTIONS(3657),
    [sym_primitive_type] = ACTIONS(3657),
    [anon_sym_enum] = ACTIONS(3657),
    [anon_sym_class] = ACTIONS(3657),
    [anon_sym_struct] = ACTIONS(3657),
    [anon_sym_union] = ACTIONS(3657),
    [anon_sym_if] = ACTIONS(3657),
    [anon_sym_switch] = ACTIONS(3657),
    [anon_sym_case] = ACTIONS(3657),
    [anon_sym_default] = ACTIONS(3657),
    [anon_sym_while] = ACTIONS(3657),
    [anon_sym_do] = ACTIONS(3657),
    [anon_sym_for] = ACTIONS(3657),
    [anon_sym_return] = ACTIONS(3657),
    [anon_sym_break] = ACTIONS(3657),
    [anon_sym_continue] = ACTIONS(3657),
    [anon_sym_goto] = ACTIONS(3657),
    [anon_sym___try] = ACTIONS(3657),
    [anon_sym___leave] = ACTIONS(3657),
    [anon_sym_not] = ACTIONS(3657),
    [anon_sym_compl] = ACTIONS(3657),
    [anon_sym_DASH_DASH] = ACTIONS(3659),
    [anon_sym_PLUS_PLUS] = ACTIONS(3659),
    [anon_sym_sizeof] = ACTIONS(3657),
    [anon_sym___alignof__] = ACTIONS(3657),
    [anon_sym___alignof] = ACTIONS(3657),
    [anon_sym__alignof] = ACTIONS(3657),
    [anon_sym_alignof] = ACTIONS(3657),
    [anon_sym__Alignof] = ACTIONS(3657),
    [anon_sym_offsetof] = ACTIONS(3657),
    [anon_sym__Generic] = ACTIONS(3657),
    [anon_sym_asm] = ACTIONS(3657),
    [anon_sym___asm__] = ACTIONS(3657),
    [sym_number_literal] = ACTIONS(3659),
    [anon_sym_L_SQUOTE] = ACTIONS(3659),
    [anon_sym_u_SQUOTE] = ACTIONS(3659),
    [anon_sym_U_SQUOTE] = ACTIONS(3659),
    [anon_sym_u8_SQUOTE] = ACTIONS(3659),
    [anon_sym_SQUOTE] = ACTIONS(3659),
    [anon_sym_L_DQUOTE] = ACTIONS(3659),
    [anon_sym_u_DQUOTE] = ACTIONS(3659),
    [anon_sym_U_DQUOTE] = ACTIONS(3659),
    [anon_sym_u8_DQUOTE] = ACTIONS(3659),
    [anon_sym_DQUOTE] = ACTIONS(3659),
    [sym_true] = ACTIONS(3657),
    [sym_false] = ACTIONS(3657),
    [anon_sym_NULL] = ACTIONS(3657),
    [anon_sym_nullptr] = ACTIONS(3657),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3657),
    [anon_sym_decltype] = ACTIONS(3657),
    [sym_virtual] = ACTIONS(3657),
    [anon_sym_typename] = ACTIONS(3657),
    [anon_sym_template] = ACTIONS(3657),
    [anon_sym_try] = ACTIONS(3657),
    [anon_sym_delete] = ACTIONS(3657),
    [anon_sym_throw] = ACTIONS(3657),
    [anon_sym_co_return] = ACTIONS(3657),
    [anon_sym_co_yield] = ACTIONS(3657),
    [anon_sym_R_DQUOTE] = ACTIONS(3659),
    [anon_sym_LR_DQUOTE] = ACTIONS(3659),
    [anon_sym_uR_DQUOTE] = ACTIONS(3659),
    [anon_sym_UR_DQUOTE] = ACTIONS(3659),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3659),
    [anon_sym_co_await] = ACTIONS(3657),
    [anon_sym_new] = ACTIONS(3657),
    [anon_sym_requires] = ACTIONS(3657),
    [sym_this] = ACTIONS(3657),
    [anon_sym_discard] = ACTIONS(3657),
    [anon_sym_precise] = ACTIONS(3657),
    [anon_sym_shared] = ACTIONS(3657),
    [anon_sym_groupshared] = ACTIONS(3657),
    [anon_sym_uniform] = ACTIONS(3657),
    [anon_sym_row_major] = ACTIONS(3657),
    [anon_sym_column_major] = ACTIONS(3657),
    [anon_sym_globallycoherent] = ACTIONS(3657),
    [anon_sym_centroid] = ACTIONS(3657),
    [anon_sym_noperspective] = ACTIONS(3657),
    [anon_sym_nointerpolation] = ACTIONS(3657),
    [anon_sym_sample] = ACTIONS(3657),
    [anon_sym_linear] = ACTIONS(3657),
    [anon_sym_snorm] = ACTIONS(3657),
    [anon_sym_unorm] = ACTIONS(3657),
    [anon_sym_point] = ACTIONS(3657),
    [anon_sym_line] = ACTIONS(3657),
    [anon_sym_triangleadj] = ACTIONS(3657),
    [anon_sym_lineadj] = ACTIONS(3657),
    [anon_sym_triangle] = ACTIONS(3657),
    [anon_sym_cbuffer] = ACTIONS(3657),
  },
  [1032] = {
    [sym_identifier] = ACTIONS(2138),
    [anon_sym_LPAREN2] = ACTIONS(2140),
    [anon_sym_BANG] = ACTIONS(2140),
    [anon_sym_TILDE] = ACTIONS(2140),
    [anon_sym_DASH] = ACTIONS(2138),
    [anon_sym_PLUS] = ACTIONS(2138),
    [anon_sym_STAR] = ACTIONS(2140),
    [anon_sym_AMP] = ACTIONS(2140),
    [anon_sym_SEMI] = ACTIONS(2140),
    [anon_sym___extension__] = ACTIONS(2138),
    [anon_sym_typedef] = ACTIONS(2138),
    [anon_sym_in] = ACTIONS(2138),
    [anon_sym_out] = ACTIONS(2138),
    [anon_sym_inout] = ACTIONS(2138),
    [anon_sym_extern] = ACTIONS(2138),
    [anon_sym___attribute__] = ACTIONS(2138),
    [anon_sym_COLON_COLON] = ACTIONS(2140),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2140),
    [anon_sym___declspec] = ACTIONS(2138),
    [anon_sym_LBRACE] = ACTIONS(2140),
    [anon_sym_signed] = ACTIONS(2138),
    [anon_sym_unsigned] = ACTIONS(2138),
    [anon_sym_long] = ACTIONS(2138),
    [anon_sym_short] = ACTIONS(2138),
    [anon_sym_LBRACK] = ACTIONS(2138),
    [anon_sym_static] = ACTIONS(2138),
    [anon_sym_register] = ACTIONS(2138),
    [anon_sym_inline] = ACTIONS(2138),
    [anon_sym___inline] = ACTIONS(2138),
    [anon_sym___inline__] = ACTIONS(2138),
    [anon_sym___forceinline] = ACTIONS(2138),
    [anon_sym_thread_local] = ACTIONS(2138),
    [anon_sym___thread] = ACTIONS(2138),
    [anon_sym_const] = ACTIONS(2138),
    [anon_sym_constexpr] = ACTIONS(2138),
    [anon_sym_volatile] = ACTIONS(2138),
    [anon_sym_restrict] = ACTIONS(2138),
    [anon_sym___restrict__] = ACTIONS(2138),
    [anon_sym__Atomic] = ACTIONS(2138),
    [anon_sym__Noreturn] = ACTIONS(2138),
    [anon_sym_noreturn] = ACTIONS(2138),
    [anon_sym_mutable] = ACTIONS(2138),
    [anon_sym_constinit] = ACTIONS(2138),
    [anon_sym_consteval] = ACTIONS(2138),
    [anon_sym_alignas] = ACTIONS(2138),
    [anon_sym__Alignas] = ACTIONS(2138),
    [sym_primitive_type] = ACTIONS(2138),
    [anon_sym_enum] = ACTIONS(2138),
    [anon_sym_class] = ACTIONS(2138),
    [anon_sym_struct] = ACTIONS(2138),
    [anon_sym_union] = ACTIONS(2138),
    [anon_sym_if] = ACTIONS(2138),
    [anon_sym_else] = ACTIONS(2138),
    [anon_sym_switch] = ACTIONS(2138),
    [anon_sym_while] = ACTIONS(2138),
    [anon_sym_do] = ACTIONS(2138),
    [anon_sym_for] = ACTIONS(2138),
    [anon_sym_return] = ACTIONS(2138),
    [anon_sym_break] = ACTIONS(2138),
    [anon_sym_continue] = ACTIONS(2138),
    [anon_sym_goto] = ACTIONS(2138),
    [anon_sym___try] = ACTIONS(2138),
    [anon_sym___leave] = ACTIONS(2138),
    [anon_sym_not] = ACTIONS(2138),
    [anon_sym_compl] = ACTIONS(2138),
    [anon_sym_DASH_DASH] = ACTIONS(2140),
    [anon_sym_PLUS_PLUS] = ACTIONS(2140),
    [anon_sym_sizeof] = ACTIONS(2138),
    [anon_sym___alignof__] = ACTIONS(2138),
    [anon_sym___alignof] = ACTIONS(2138),
    [anon_sym__alignof] = ACTIONS(2138),
    [anon_sym_alignof] = ACTIONS(2138),
    [anon_sym__Alignof] = ACTIONS(2138),
    [anon_sym_offsetof] = ACTIONS(2138),
    [anon_sym__Generic] = ACTIONS(2138),
    [anon_sym_asm] = ACTIONS(2138),
    [anon_sym___asm__] = ACTIONS(2138),
    [sym_number_literal] = ACTIONS(2140),
    [anon_sym_L_SQUOTE] = ACTIONS(2140),
    [anon_sym_u_SQUOTE] = ACTIONS(2140),
    [anon_sym_U_SQUOTE] = ACTIONS(2140),
    [anon_sym_u8_SQUOTE] = ACTIONS(2140),
    [anon_sym_SQUOTE] = ACTIONS(2140),
    [anon_sym_L_DQUOTE] = ACTIONS(2140),
    [anon_sym_u_DQUOTE] = ACTIONS(2140),
    [anon_sym_U_DQUOTE] = ACTIONS(2140),
    [anon_sym_u8_DQUOTE] = ACTIONS(2140),
    [anon_sym_DQUOTE] = ACTIONS(2140),
    [sym_true] = ACTIONS(2138),
    [sym_false] = ACTIONS(2138),
    [anon_sym_NULL] = ACTIONS(2138),
    [anon_sym_nullptr] = ACTIONS(2138),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2138),
    [anon_sym_decltype] = ACTIONS(2138),
    [sym_virtual] = ACTIONS(2138),
    [anon_sym_typename] = ACTIONS(2138),
    [anon_sym_template] = ACTIONS(2138),
    [anon_sym_try] = ACTIONS(2138),
    [anon_sym_delete] = ACTIONS(2138),
    [anon_sym_throw] = ACTIONS(2138),
    [anon_sym_co_return] = ACTIONS(2138),
    [anon_sym_co_yield] = ACTIONS(2138),
    [anon_sym_R_DQUOTE] = ACTIONS(2140),
    [anon_sym_LR_DQUOTE] = ACTIONS(2140),
    [anon_sym_uR_DQUOTE] = ACTIONS(2140),
    [anon_sym_UR_DQUOTE] = ACTIONS(2140),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2140),
    [anon_sym_co_await] = ACTIONS(2138),
    [anon_sym_new] = ACTIONS(2138),
    [anon_sym_requires] = ACTIONS(2138),
    [sym_this] = ACTIONS(2138),
    [anon_sym_discard] = ACTIONS(2138),
    [anon_sym_precise] = ACTIONS(2138),
    [anon_sym_shared] = ACTIONS(2138),
    [anon_sym_groupshared] = ACTIONS(2138),
    [anon_sym_uniform] = ACTIONS(2138),
    [anon_sym_row_major] = ACTIONS(2138),
    [anon_sym_column_major] = ACTIONS(2138),
    [anon_sym_globallycoherent] = ACTIONS(2138),
    [anon_sym_centroid] = ACTIONS(2138),
    [anon_sym_noperspective] = ACTIONS(2138),
    [anon_sym_nointerpolation] = ACTIONS(2138),
    [anon_sym_sample] = ACTIONS(2138),
    [anon_sym_linear] = ACTIONS(2138),
    [anon_sym_snorm] = ACTIONS(2138),
    [anon_sym_unorm] = ACTIONS(2138),
    [anon_sym_point] = ACTIONS(2138),
    [anon_sym_line] = ACTIONS(2138),
    [anon_sym_triangleadj] = ACTIONS(2138),
    [anon_sym_lineadj] = ACTIONS(2138),
    [anon_sym_triangle] = ACTIONS(2138),
    [anon_sym_cbuffer] = ACTIONS(2138),
  },
  [1033] = {
    [sym_identifier] = ACTIONS(2134),
    [anon_sym_LPAREN2] = ACTIONS(2136),
    [anon_sym_BANG] = ACTIONS(2136),
    [anon_sym_TILDE] = ACTIONS(2136),
    [anon_sym_DASH] = ACTIONS(2134),
    [anon_sym_PLUS] = ACTIONS(2134),
    [anon_sym_STAR] = ACTIONS(2136),
    [anon_sym_AMP] = ACTIONS(2136),
    [anon_sym_SEMI] = ACTIONS(2136),
    [anon_sym___extension__] = ACTIONS(2134),
    [anon_sym_typedef] = ACTIONS(2134),
    [anon_sym_in] = ACTIONS(2134),
    [anon_sym_out] = ACTIONS(2134),
    [anon_sym_inout] = ACTIONS(2134),
    [anon_sym_extern] = ACTIONS(2134),
    [anon_sym___attribute__] = ACTIONS(2134),
    [anon_sym_COLON_COLON] = ACTIONS(2136),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2136),
    [anon_sym___declspec] = ACTIONS(2134),
    [anon_sym_LBRACE] = ACTIONS(2136),
    [anon_sym_signed] = ACTIONS(2134),
    [anon_sym_unsigned] = ACTIONS(2134),
    [anon_sym_long] = ACTIONS(2134),
    [anon_sym_short] = ACTIONS(2134),
    [anon_sym_LBRACK] = ACTIONS(2134),
    [anon_sym_static] = ACTIONS(2134),
    [anon_sym_register] = ACTIONS(2134),
    [anon_sym_inline] = ACTIONS(2134),
    [anon_sym___inline] = ACTIONS(2134),
    [anon_sym___inline__] = ACTIONS(2134),
    [anon_sym___forceinline] = ACTIONS(2134),
    [anon_sym_thread_local] = ACTIONS(2134),
    [anon_sym___thread] = ACTIONS(2134),
    [anon_sym_const] = ACTIONS(2134),
    [anon_sym_constexpr] = ACTIONS(2134),
    [anon_sym_volatile] = ACTIONS(2134),
    [anon_sym_restrict] = ACTIONS(2134),
    [anon_sym___restrict__] = ACTIONS(2134),
    [anon_sym__Atomic] = ACTIONS(2134),
    [anon_sym__Noreturn] = ACTIONS(2134),
    [anon_sym_noreturn] = ACTIONS(2134),
    [anon_sym_mutable] = ACTIONS(2134),
    [anon_sym_constinit] = ACTIONS(2134),
    [anon_sym_consteval] = ACTIONS(2134),
    [anon_sym_alignas] = ACTIONS(2134),
    [anon_sym__Alignas] = ACTIONS(2134),
    [sym_primitive_type] = ACTIONS(2134),
    [anon_sym_enum] = ACTIONS(2134),
    [anon_sym_class] = ACTIONS(2134),
    [anon_sym_struct] = ACTIONS(2134),
    [anon_sym_union] = ACTIONS(2134),
    [anon_sym_if] = ACTIONS(2134),
    [anon_sym_else] = ACTIONS(2134),
    [anon_sym_switch] = ACTIONS(2134),
    [anon_sym_while] = ACTIONS(2134),
    [anon_sym_do] = ACTIONS(2134),
    [anon_sym_for] = ACTIONS(2134),
    [anon_sym_return] = ACTIONS(2134),
    [anon_sym_break] = ACTIONS(2134),
    [anon_sym_continue] = ACTIONS(2134),
    [anon_sym_goto] = ACTIONS(2134),
    [anon_sym___try] = ACTIONS(2134),
    [anon_sym___leave] = ACTIONS(2134),
    [anon_sym_not] = ACTIONS(2134),
    [anon_sym_compl] = ACTIONS(2134),
    [anon_sym_DASH_DASH] = ACTIONS(2136),
    [anon_sym_PLUS_PLUS] = ACTIONS(2136),
    [anon_sym_sizeof] = ACTIONS(2134),
    [anon_sym___alignof__] = ACTIONS(2134),
    [anon_sym___alignof] = ACTIONS(2134),
    [anon_sym__alignof] = ACTIONS(2134),
    [anon_sym_alignof] = ACTIONS(2134),
    [anon_sym__Alignof] = ACTIONS(2134),
    [anon_sym_offsetof] = ACTIONS(2134),
    [anon_sym__Generic] = ACTIONS(2134),
    [anon_sym_asm] = ACTIONS(2134),
    [anon_sym___asm__] = ACTIONS(2134),
    [sym_number_literal] = ACTIONS(2136),
    [anon_sym_L_SQUOTE] = ACTIONS(2136),
    [anon_sym_u_SQUOTE] = ACTIONS(2136),
    [anon_sym_U_SQUOTE] = ACTIONS(2136),
    [anon_sym_u8_SQUOTE] = ACTIONS(2136),
    [anon_sym_SQUOTE] = ACTIONS(2136),
    [anon_sym_L_DQUOTE] = ACTIONS(2136),
    [anon_sym_u_DQUOTE] = ACTIONS(2136),
    [anon_sym_U_DQUOTE] = ACTIONS(2136),
    [anon_sym_u8_DQUOTE] = ACTIONS(2136),
    [anon_sym_DQUOTE] = ACTIONS(2136),
    [sym_true] = ACTIONS(2134),
    [sym_false] = ACTIONS(2134),
    [anon_sym_NULL] = ACTIONS(2134),
    [anon_sym_nullptr] = ACTIONS(2134),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2134),
    [anon_sym_decltype] = ACTIONS(2134),
    [sym_virtual] = ACTIONS(2134),
    [anon_sym_typename] = ACTIONS(2134),
    [anon_sym_template] = ACTIONS(2134),
    [anon_sym_try] = ACTIONS(2134),
    [anon_sym_delete] = ACTIONS(2134),
    [anon_sym_throw] = ACTIONS(2134),
    [anon_sym_co_return] = ACTIONS(2134),
    [anon_sym_co_yield] = ACTIONS(2134),
    [anon_sym_R_DQUOTE] = ACTIONS(2136),
    [anon_sym_LR_DQUOTE] = ACTIONS(2136),
    [anon_sym_uR_DQUOTE] = ACTIONS(2136),
    [anon_sym_UR_DQUOTE] = ACTIONS(2136),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2136),
    [anon_sym_co_await] = ACTIONS(2134),
    [anon_sym_new] = ACTIONS(2134),
    [anon_sym_requires] = ACTIONS(2134),
    [sym_this] = ACTIONS(2134),
    [anon_sym_discard] = ACTIONS(2134),
    [anon_sym_precise] = ACTIONS(2134),
    [anon_sym_shared] = ACTIONS(2134),
    [anon_sym_groupshared] = ACTIONS(2134),
    [anon_sym_uniform] = ACTIONS(2134),
    [anon_sym_row_major] = ACTIONS(2134),
    [anon_sym_column_major] = ACTIONS(2134),
    [anon_sym_globallycoherent] = ACTIONS(2134),
    [anon_sym_centroid] = ACTIONS(2134),
    [anon_sym_noperspective] = ACTIONS(2134),
    [anon_sym_nointerpolation] = ACTIONS(2134),
    [anon_sym_sample] = ACTIONS(2134),
    [anon_sym_linear] = ACTIONS(2134),
    [anon_sym_snorm] = ACTIONS(2134),
    [anon_sym_unorm] = ACTIONS(2134),
    [anon_sym_point] = ACTIONS(2134),
    [anon_sym_line] = ACTIONS(2134),
    [anon_sym_triangleadj] = ACTIONS(2134),
    [anon_sym_lineadj] = ACTIONS(2134),
    [anon_sym_triangle] = ACTIONS(2134),
    [anon_sym_cbuffer] = ACTIONS(2134),
  },
  [1034] = {
    [sym_identifier] = ACTIONS(2182),
    [anon_sym_LPAREN2] = ACTIONS(2184),
    [anon_sym_BANG] = ACTIONS(2184),
    [anon_sym_TILDE] = ACTIONS(2184),
    [anon_sym_DASH] = ACTIONS(2182),
    [anon_sym_PLUS] = ACTIONS(2182),
    [anon_sym_STAR] = ACTIONS(2184),
    [anon_sym_AMP] = ACTIONS(2184),
    [anon_sym_SEMI] = ACTIONS(2184),
    [anon_sym___extension__] = ACTIONS(2182),
    [anon_sym_typedef] = ACTIONS(2182),
    [anon_sym_in] = ACTIONS(2182),
    [anon_sym_out] = ACTIONS(2182),
    [anon_sym_inout] = ACTIONS(2182),
    [anon_sym_extern] = ACTIONS(2182),
    [anon_sym___attribute__] = ACTIONS(2182),
    [anon_sym_COLON_COLON] = ACTIONS(2184),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2184),
    [anon_sym___declspec] = ACTIONS(2182),
    [anon_sym_LBRACE] = ACTIONS(2184),
    [anon_sym_signed] = ACTIONS(2182),
    [anon_sym_unsigned] = ACTIONS(2182),
    [anon_sym_long] = ACTIONS(2182),
    [anon_sym_short] = ACTIONS(2182),
    [anon_sym_LBRACK] = ACTIONS(2182),
    [anon_sym_static] = ACTIONS(2182),
    [anon_sym_register] = ACTIONS(2182),
    [anon_sym_inline] = ACTIONS(2182),
    [anon_sym___inline] = ACTIONS(2182),
    [anon_sym___inline__] = ACTIONS(2182),
    [anon_sym___forceinline] = ACTIONS(2182),
    [anon_sym_thread_local] = ACTIONS(2182),
    [anon_sym___thread] = ACTIONS(2182),
    [anon_sym_const] = ACTIONS(2182),
    [anon_sym_constexpr] = ACTIONS(2182),
    [anon_sym_volatile] = ACTIONS(2182),
    [anon_sym_restrict] = ACTIONS(2182),
    [anon_sym___restrict__] = ACTIONS(2182),
    [anon_sym__Atomic] = ACTIONS(2182),
    [anon_sym__Noreturn] = ACTIONS(2182),
    [anon_sym_noreturn] = ACTIONS(2182),
    [anon_sym_mutable] = ACTIONS(2182),
    [anon_sym_constinit] = ACTIONS(2182),
    [anon_sym_consteval] = ACTIONS(2182),
    [anon_sym_alignas] = ACTIONS(2182),
    [anon_sym__Alignas] = ACTIONS(2182),
    [sym_primitive_type] = ACTIONS(2182),
    [anon_sym_enum] = ACTIONS(2182),
    [anon_sym_class] = ACTIONS(2182),
    [anon_sym_struct] = ACTIONS(2182),
    [anon_sym_union] = ACTIONS(2182),
    [anon_sym_if] = ACTIONS(2182),
    [anon_sym_else] = ACTIONS(2182),
    [anon_sym_switch] = ACTIONS(2182),
    [anon_sym_while] = ACTIONS(2182),
    [anon_sym_do] = ACTIONS(2182),
    [anon_sym_for] = ACTIONS(2182),
    [anon_sym_return] = ACTIONS(2182),
    [anon_sym_break] = ACTIONS(2182),
    [anon_sym_continue] = ACTIONS(2182),
    [anon_sym_goto] = ACTIONS(2182),
    [anon_sym___try] = ACTIONS(2182),
    [anon_sym___leave] = ACTIONS(2182),
    [anon_sym_not] = ACTIONS(2182),
    [anon_sym_compl] = ACTIONS(2182),
    [anon_sym_DASH_DASH] = ACTIONS(2184),
    [anon_sym_PLUS_PLUS] = ACTIONS(2184),
    [anon_sym_sizeof] = ACTIONS(2182),
    [anon_sym___alignof__] = ACTIONS(2182),
    [anon_sym___alignof] = ACTIONS(2182),
    [anon_sym__alignof] = ACTIONS(2182),
    [anon_sym_alignof] = ACTIONS(2182),
    [anon_sym__Alignof] = ACTIONS(2182),
    [anon_sym_offsetof] = ACTIONS(2182),
    [anon_sym__Generic] = ACTIONS(2182),
    [anon_sym_asm] = ACTIONS(2182),
    [anon_sym___asm__] = ACTIONS(2182),
    [sym_number_literal] = ACTIONS(2184),
    [anon_sym_L_SQUOTE] = ACTIONS(2184),
    [anon_sym_u_SQUOTE] = ACTIONS(2184),
    [anon_sym_U_SQUOTE] = ACTIONS(2184),
    [anon_sym_u8_SQUOTE] = ACTIONS(2184),
    [anon_sym_SQUOTE] = ACTIONS(2184),
    [anon_sym_L_DQUOTE] = ACTIONS(2184),
    [anon_sym_u_DQUOTE] = ACTIONS(2184),
    [anon_sym_U_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8_DQUOTE] = ACTIONS(2184),
    [anon_sym_DQUOTE] = ACTIONS(2184),
    [sym_true] = ACTIONS(2182),
    [sym_false] = ACTIONS(2182),
    [anon_sym_NULL] = ACTIONS(2182),
    [anon_sym_nullptr] = ACTIONS(2182),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2182),
    [anon_sym_decltype] = ACTIONS(2182),
    [sym_virtual] = ACTIONS(2182),
    [anon_sym_typename] = ACTIONS(2182),
    [anon_sym_template] = ACTIONS(2182),
    [anon_sym_try] = ACTIONS(2182),
    [anon_sym_delete] = ACTIONS(2182),
    [anon_sym_throw] = ACTIONS(2182),
    [anon_sym_co_return] = ACTIONS(2182),
    [anon_sym_co_yield] = ACTIONS(2182),
    [anon_sym_R_DQUOTE] = ACTIONS(2184),
    [anon_sym_LR_DQUOTE] = ACTIONS(2184),
    [anon_sym_uR_DQUOTE] = ACTIONS(2184),
    [anon_sym_UR_DQUOTE] = ACTIONS(2184),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2184),
    [anon_sym_co_await] = ACTIONS(2182),
    [anon_sym_new] = ACTIONS(2182),
    [anon_sym_requires] = ACTIONS(2182),
    [sym_this] = ACTIONS(2182),
    [anon_sym_discard] = ACTIONS(2182),
    [anon_sym_precise] = ACTIONS(2182),
    [anon_sym_shared] = ACTIONS(2182),
    [anon_sym_groupshared] = ACTIONS(2182),
    [anon_sym_uniform] = ACTIONS(2182),
    [anon_sym_row_major] = ACTIONS(2182),
    [anon_sym_column_major] = ACTIONS(2182),
    [anon_sym_globallycoherent] = ACTIONS(2182),
    [anon_sym_centroid] = ACTIONS(2182),
    [anon_sym_noperspective] = ACTIONS(2182),
    [anon_sym_nointerpolation] = ACTIONS(2182),
    [anon_sym_sample] = ACTIONS(2182),
    [anon_sym_linear] = ACTIONS(2182),
    [anon_sym_snorm] = ACTIONS(2182),
    [anon_sym_unorm] = ACTIONS(2182),
    [anon_sym_point] = ACTIONS(2182),
    [anon_sym_line] = ACTIONS(2182),
    [anon_sym_triangleadj] = ACTIONS(2182),
    [anon_sym_lineadj] = ACTIONS(2182),
    [anon_sym_triangle] = ACTIONS(2182),
    [anon_sym_cbuffer] = ACTIONS(2182),
  },
  [1035] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(4731),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_type_descriptor] = STATE(7989),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5574),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3922),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3924),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1036] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(4617),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_type_descriptor] = STATE(8462),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5574),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3922),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3924),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1037] = {
    [sym_identifier] = ACTIONS(2118),
    [anon_sym_LPAREN2] = ACTIONS(2120),
    [anon_sym_BANG] = ACTIONS(2120),
    [anon_sym_TILDE] = ACTIONS(2120),
    [anon_sym_DASH] = ACTIONS(2118),
    [anon_sym_PLUS] = ACTIONS(2118),
    [anon_sym_STAR] = ACTIONS(2120),
    [anon_sym_AMP] = ACTIONS(2120),
    [anon_sym_SEMI] = ACTIONS(2120),
    [anon_sym___extension__] = ACTIONS(2118),
    [anon_sym_typedef] = ACTIONS(2118),
    [anon_sym_in] = ACTIONS(2118),
    [anon_sym_out] = ACTIONS(2118),
    [anon_sym_inout] = ACTIONS(2118),
    [anon_sym_extern] = ACTIONS(2118),
    [anon_sym___attribute__] = ACTIONS(2118),
    [anon_sym_COLON_COLON] = ACTIONS(2120),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2120),
    [anon_sym___declspec] = ACTIONS(2118),
    [anon_sym_LBRACE] = ACTIONS(2120),
    [anon_sym_signed] = ACTIONS(2118),
    [anon_sym_unsigned] = ACTIONS(2118),
    [anon_sym_long] = ACTIONS(2118),
    [anon_sym_short] = ACTIONS(2118),
    [anon_sym_LBRACK] = ACTIONS(2118),
    [anon_sym_static] = ACTIONS(2118),
    [anon_sym_register] = ACTIONS(2118),
    [anon_sym_inline] = ACTIONS(2118),
    [anon_sym___inline] = ACTIONS(2118),
    [anon_sym___inline__] = ACTIONS(2118),
    [anon_sym___forceinline] = ACTIONS(2118),
    [anon_sym_thread_local] = ACTIONS(2118),
    [anon_sym___thread] = ACTIONS(2118),
    [anon_sym_const] = ACTIONS(2118),
    [anon_sym_constexpr] = ACTIONS(2118),
    [anon_sym_volatile] = ACTIONS(2118),
    [anon_sym_restrict] = ACTIONS(2118),
    [anon_sym___restrict__] = ACTIONS(2118),
    [anon_sym__Atomic] = ACTIONS(2118),
    [anon_sym__Noreturn] = ACTIONS(2118),
    [anon_sym_noreturn] = ACTIONS(2118),
    [anon_sym_mutable] = ACTIONS(2118),
    [anon_sym_constinit] = ACTIONS(2118),
    [anon_sym_consteval] = ACTIONS(2118),
    [anon_sym_alignas] = ACTIONS(2118),
    [anon_sym__Alignas] = ACTIONS(2118),
    [sym_primitive_type] = ACTIONS(2118),
    [anon_sym_enum] = ACTIONS(2118),
    [anon_sym_class] = ACTIONS(2118),
    [anon_sym_struct] = ACTIONS(2118),
    [anon_sym_union] = ACTIONS(2118),
    [anon_sym_if] = ACTIONS(2118),
    [anon_sym_else] = ACTIONS(2118),
    [anon_sym_switch] = ACTIONS(2118),
    [anon_sym_while] = ACTIONS(2118),
    [anon_sym_do] = ACTIONS(2118),
    [anon_sym_for] = ACTIONS(2118),
    [anon_sym_return] = ACTIONS(2118),
    [anon_sym_break] = ACTIONS(2118),
    [anon_sym_continue] = ACTIONS(2118),
    [anon_sym_goto] = ACTIONS(2118),
    [anon_sym___try] = ACTIONS(2118),
    [anon_sym___leave] = ACTIONS(2118),
    [anon_sym_not] = ACTIONS(2118),
    [anon_sym_compl] = ACTIONS(2118),
    [anon_sym_DASH_DASH] = ACTIONS(2120),
    [anon_sym_PLUS_PLUS] = ACTIONS(2120),
    [anon_sym_sizeof] = ACTIONS(2118),
    [anon_sym___alignof__] = ACTIONS(2118),
    [anon_sym___alignof] = ACTIONS(2118),
    [anon_sym__alignof] = ACTIONS(2118),
    [anon_sym_alignof] = ACTIONS(2118),
    [anon_sym__Alignof] = ACTIONS(2118),
    [anon_sym_offsetof] = ACTIONS(2118),
    [anon_sym__Generic] = ACTIONS(2118),
    [anon_sym_asm] = ACTIONS(2118),
    [anon_sym___asm__] = ACTIONS(2118),
    [sym_number_literal] = ACTIONS(2120),
    [anon_sym_L_SQUOTE] = ACTIONS(2120),
    [anon_sym_u_SQUOTE] = ACTIONS(2120),
    [anon_sym_U_SQUOTE] = ACTIONS(2120),
    [anon_sym_u8_SQUOTE] = ACTIONS(2120),
    [anon_sym_SQUOTE] = ACTIONS(2120),
    [anon_sym_L_DQUOTE] = ACTIONS(2120),
    [anon_sym_u_DQUOTE] = ACTIONS(2120),
    [anon_sym_U_DQUOTE] = ACTIONS(2120),
    [anon_sym_u8_DQUOTE] = ACTIONS(2120),
    [anon_sym_DQUOTE] = ACTIONS(2120),
    [sym_true] = ACTIONS(2118),
    [sym_false] = ACTIONS(2118),
    [anon_sym_NULL] = ACTIONS(2118),
    [anon_sym_nullptr] = ACTIONS(2118),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2118),
    [anon_sym_decltype] = ACTIONS(2118),
    [sym_virtual] = ACTIONS(2118),
    [anon_sym_typename] = ACTIONS(2118),
    [anon_sym_template] = ACTIONS(2118),
    [anon_sym_try] = ACTIONS(2118),
    [anon_sym_delete] = ACTIONS(2118),
    [anon_sym_throw] = ACTIONS(2118),
    [anon_sym_co_return] = ACTIONS(2118),
    [anon_sym_co_yield] = ACTIONS(2118),
    [anon_sym_R_DQUOTE] = ACTIONS(2120),
    [anon_sym_LR_DQUOTE] = ACTIONS(2120),
    [anon_sym_uR_DQUOTE] = ACTIONS(2120),
    [anon_sym_UR_DQUOTE] = ACTIONS(2120),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2120),
    [anon_sym_co_await] = ACTIONS(2118),
    [anon_sym_new] = ACTIONS(2118),
    [anon_sym_requires] = ACTIONS(2118),
    [sym_this] = ACTIONS(2118),
    [anon_sym_discard] = ACTIONS(2118),
    [anon_sym_precise] = ACTIONS(2118),
    [anon_sym_shared] = ACTIONS(2118),
    [anon_sym_groupshared] = ACTIONS(2118),
    [anon_sym_uniform] = ACTIONS(2118),
    [anon_sym_row_major] = ACTIONS(2118),
    [anon_sym_column_major] = ACTIONS(2118),
    [anon_sym_globallycoherent] = ACTIONS(2118),
    [anon_sym_centroid] = ACTIONS(2118),
    [anon_sym_noperspective] = ACTIONS(2118),
    [anon_sym_nointerpolation] = ACTIONS(2118),
    [anon_sym_sample] = ACTIONS(2118),
    [anon_sym_linear] = ACTIONS(2118),
    [anon_sym_snorm] = ACTIONS(2118),
    [anon_sym_unorm] = ACTIONS(2118),
    [anon_sym_point] = ACTIONS(2118),
    [anon_sym_line] = ACTIONS(2118),
    [anon_sym_triangleadj] = ACTIONS(2118),
    [anon_sym_lineadj] = ACTIONS(2118),
    [anon_sym_triangle] = ACTIONS(2118),
    [anon_sym_cbuffer] = ACTIONS(2118),
  },
  [1038] = {
    [sym_identifier] = ACTIONS(2122),
    [anon_sym_LPAREN2] = ACTIONS(2124),
    [anon_sym_BANG] = ACTIONS(2124),
    [anon_sym_TILDE] = ACTIONS(2124),
    [anon_sym_DASH] = ACTIONS(2122),
    [anon_sym_PLUS] = ACTIONS(2122),
    [anon_sym_STAR] = ACTIONS(2124),
    [anon_sym_AMP] = ACTIONS(2124),
    [anon_sym_SEMI] = ACTIONS(2124),
    [anon_sym___extension__] = ACTIONS(2122),
    [anon_sym_typedef] = ACTIONS(2122),
    [anon_sym_in] = ACTIONS(2122),
    [anon_sym_out] = ACTIONS(2122),
    [anon_sym_inout] = ACTIONS(2122),
    [anon_sym_extern] = ACTIONS(2122),
    [anon_sym___attribute__] = ACTIONS(2122),
    [anon_sym_COLON_COLON] = ACTIONS(2124),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2124),
    [anon_sym___declspec] = ACTIONS(2122),
    [anon_sym_LBRACE] = ACTIONS(2124),
    [anon_sym_signed] = ACTIONS(2122),
    [anon_sym_unsigned] = ACTIONS(2122),
    [anon_sym_long] = ACTIONS(2122),
    [anon_sym_short] = ACTIONS(2122),
    [anon_sym_LBRACK] = ACTIONS(2122),
    [anon_sym_static] = ACTIONS(2122),
    [anon_sym_register] = ACTIONS(2122),
    [anon_sym_inline] = ACTIONS(2122),
    [anon_sym___inline] = ACTIONS(2122),
    [anon_sym___inline__] = ACTIONS(2122),
    [anon_sym___forceinline] = ACTIONS(2122),
    [anon_sym_thread_local] = ACTIONS(2122),
    [anon_sym___thread] = ACTIONS(2122),
    [anon_sym_const] = ACTIONS(2122),
    [anon_sym_constexpr] = ACTIONS(2122),
    [anon_sym_volatile] = ACTIONS(2122),
    [anon_sym_restrict] = ACTIONS(2122),
    [anon_sym___restrict__] = ACTIONS(2122),
    [anon_sym__Atomic] = ACTIONS(2122),
    [anon_sym__Noreturn] = ACTIONS(2122),
    [anon_sym_noreturn] = ACTIONS(2122),
    [anon_sym_mutable] = ACTIONS(2122),
    [anon_sym_constinit] = ACTIONS(2122),
    [anon_sym_consteval] = ACTIONS(2122),
    [anon_sym_alignas] = ACTIONS(2122),
    [anon_sym__Alignas] = ACTIONS(2122),
    [sym_primitive_type] = ACTIONS(2122),
    [anon_sym_enum] = ACTIONS(2122),
    [anon_sym_class] = ACTIONS(2122),
    [anon_sym_struct] = ACTIONS(2122),
    [anon_sym_union] = ACTIONS(2122),
    [anon_sym_if] = ACTIONS(2122),
    [anon_sym_else] = ACTIONS(2122),
    [anon_sym_switch] = ACTIONS(2122),
    [anon_sym_while] = ACTIONS(2122),
    [anon_sym_do] = ACTIONS(2122),
    [anon_sym_for] = ACTIONS(2122),
    [anon_sym_return] = ACTIONS(2122),
    [anon_sym_break] = ACTIONS(2122),
    [anon_sym_continue] = ACTIONS(2122),
    [anon_sym_goto] = ACTIONS(2122),
    [anon_sym___try] = ACTIONS(2122),
    [anon_sym___leave] = ACTIONS(2122),
    [anon_sym_not] = ACTIONS(2122),
    [anon_sym_compl] = ACTIONS(2122),
    [anon_sym_DASH_DASH] = ACTIONS(2124),
    [anon_sym_PLUS_PLUS] = ACTIONS(2124),
    [anon_sym_sizeof] = ACTIONS(2122),
    [anon_sym___alignof__] = ACTIONS(2122),
    [anon_sym___alignof] = ACTIONS(2122),
    [anon_sym__alignof] = ACTIONS(2122),
    [anon_sym_alignof] = ACTIONS(2122),
    [anon_sym__Alignof] = ACTIONS(2122),
    [anon_sym_offsetof] = ACTIONS(2122),
    [anon_sym__Generic] = ACTIONS(2122),
    [anon_sym_asm] = ACTIONS(2122),
    [anon_sym___asm__] = ACTIONS(2122),
    [sym_number_literal] = ACTIONS(2124),
    [anon_sym_L_SQUOTE] = ACTIONS(2124),
    [anon_sym_u_SQUOTE] = ACTIONS(2124),
    [anon_sym_U_SQUOTE] = ACTIONS(2124),
    [anon_sym_u8_SQUOTE] = ACTIONS(2124),
    [anon_sym_SQUOTE] = ACTIONS(2124),
    [anon_sym_L_DQUOTE] = ACTIONS(2124),
    [anon_sym_u_DQUOTE] = ACTIONS(2124),
    [anon_sym_U_DQUOTE] = ACTIONS(2124),
    [anon_sym_u8_DQUOTE] = ACTIONS(2124),
    [anon_sym_DQUOTE] = ACTIONS(2124),
    [sym_true] = ACTIONS(2122),
    [sym_false] = ACTIONS(2122),
    [anon_sym_NULL] = ACTIONS(2122),
    [anon_sym_nullptr] = ACTIONS(2122),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2122),
    [anon_sym_decltype] = ACTIONS(2122),
    [sym_virtual] = ACTIONS(2122),
    [anon_sym_typename] = ACTIONS(2122),
    [anon_sym_template] = ACTIONS(2122),
    [anon_sym_try] = ACTIONS(2122),
    [anon_sym_delete] = ACTIONS(2122),
    [anon_sym_throw] = ACTIONS(2122),
    [anon_sym_co_return] = ACTIONS(2122),
    [anon_sym_co_yield] = ACTIONS(2122),
    [anon_sym_R_DQUOTE] = ACTIONS(2124),
    [anon_sym_LR_DQUOTE] = ACTIONS(2124),
    [anon_sym_uR_DQUOTE] = ACTIONS(2124),
    [anon_sym_UR_DQUOTE] = ACTIONS(2124),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2124),
    [anon_sym_co_await] = ACTIONS(2122),
    [anon_sym_new] = ACTIONS(2122),
    [anon_sym_requires] = ACTIONS(2122),
    [sym_this] = ACTIONS(2122),
    [anon_sym_discard] = ACTIONS(2122),
    [anon_sym_precise] = ACTIONS(2122),
    [anon_sym_shared] = ACTIONS(2122),
    [anon_sym_groupshared] = ACTIONS(2122),
    [anon_sym_uniform] = ACTIONS(2122),
    [anon_sym_row_major] = ACTIONS(2122),
    [anon_sym_column_major] = ACTIONS(2122),
    [anon_sym_globallycoherent] = ACTIONS(2122),
    [anon_sym_centroid] = ACTIONS(2122),
    [anon_sym_noperspective] = ACTIONS(2122),
    [anon_sym_nointerpolation] = ACTIONS(2122),
    [anon_sym_sample] = ACTIONS(2122),
    [anon_sym_linear] = ACTIONS(2122),
    [anon_sym_snorm] = ACTIONS(2122),
    [anon_sym_unorm] = ACTIONS(2122),
    [anon_sym_point] = ACTIONS(2122),
    [anon_sym_line] = ACTIONS(2122),
    [anon_sym_triangleadj] = ACTIONS(2122),
    [anon_sym_lineadj] = ACTIONS(2122),
    [anon_sym_triangle] = ACTIONS(2122),
    [anon_sym_cbuffer] = ACTIONS(2122),
  },
  [1039] = {
    [sym_identifier] = ACTIONS(2126),
    [anon_sym_LPAREN2] = ACTIONS(2128),
    [anon_sym_BANG] = ACTIONS(2128),
    [anon_sym_TILDE] = ACTIONS(2128),
    [anon_sym_DASH] = ACTIONS(2126),
    [anon_sym_PLUS] = ACTIONS(2126),
    [anon_sym_STAR] = ACTIONS(2128),
    [anon_sym_AMP] = ACTIONS(2128),
    [anon_sym_SEMI] = ACTIONS(2128),
    [anon_sym___extension__] = ACTIONS(2126),
    [anon_sym_typedef] = ACTIONS(2126),
    [anon_sym_in] = ACTIONS(2126),
    [anon_sym_out] = ACTIONS(2126),
    [anon_sym_inout] = ACTIONS(2126),
    [anon_sym_extern] = ACTIONS(2126),
    [anon_sym___attribute__] = ACTIONS(2126),
    [anon_sym_COLON_COLON] = ACTIONS(2128),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2128),
    [anon_sym___declspec] = ACTIONS(2126),
    [anon_sym_LBRACE] = ACTIONS(2128),
    [anon_sym_signed] = ACTIONS(2126),
    [anon_sym_unsigned] = ACTIONS(2126),
    [anon_sym_long] = ACTIONS(2126),
    [anon_sym_short] = ACTIONS(2126),
    [anon_sym_LBRACK] = ACTIONS(2126),
    [anon_sym_static] = ACTIONS(2126),
    [anon_sym_register] = ACTIONS(2126),
    [anon_sym_inline] = ACTIONS(2126),
    [anon_sym___inline] = ACTIONS(2126),
    [anon_sym___inline__] = ACTIONS(2126),
    [anon_sym___forceinline] = ACTIONS(2126),
    [anon_sym_thread_local] = ACTIONS(2126),
    [anon_sym___thread] = ACTIONS(2126),
    [anon_sym_const] = ACTIONS(2126),
    [anon_sym_constexpr] = ACTIONS(2126),
    [anon_sym_volatile] = ACTIONS(2126),
    [anon_sym_restrict] = ACTIONS(2126),
    [anon_sym___restrict__] = ACTIONS(2126),
    [anon_sym__Atomic] = ACTIONS(2126),
    [anon_sym__Noreturn] = ACTIONS(2126),
    [anon_sym_noreturn] = ACTIONS(2126),
    [anon_sym_mutable] = ACTIONS(2126),
    [anon_sym_constinit] = ACTIONS(2126),
    [anon_sym_consteval] = ACTIONS(2126),
    [anon_sym_alignas] = ACTIONS(2126),
    [anon_sym__Alignas] = ACTIONS(2126),
    [sym_primitive_type] = ACTIONS(2126),
    [anon_sym_enum] = ACTIONS(2126),
    [anon_sym_class] = ACTIONS(2126),
    [anon_sym_struct] = ACTIONS(2126),
    [anon_sym_union] = ACTIONS(2126),
    [anon_sym_if] = ACTIONS(2126),
    [anon_sym_else] = ACTIONS(2126),
    [anon_sym_switch] = ACTIONS(2126),
    [anon_sym_while] = ACTIONS(2126),
    [anon_sym_do] = ACTIONS(2126),
    [anon_sym_for] = ACTIONS(2126),
    [anon_sym_return] = ACTIONS(2126),
    [anon_sym_break] = ACTIONS(2126),
    [anon_sym_continue] = ACTIONS(2126),
    [anon_sym_goto] = ACTIONS(2126),
    [anon_sym___try] = ACTIONS(2126),
    [anon_sym___leave] = ACTIONS(2126),
    [anon_sym_not] = ACTIONS(2126),
    [anon_sym_compl] = ACTIONS(2126),
    [anon_sym_DASH_DASH] = ACTIONS(2128),
    [anon_sym_PLUS_PLUS] = ACTIONS(2128),
    [anon_sym_sizeof] = ACTIONS(2126),
    [anon_sym___alignof__] = ACTIONS(2126),
    [anon_sym___alignof] = ACTIONS(2126),
    [anon_sym__alignof] = ACTIONS(2126),
    [anon_sym_alignof] = ACTIONS(2126),
    [anon_sym__Alignof] = ACTIONS(2126),
    [anon_sym_offsetof] = ACTIONS(2126),
    [anon_sym__Generic] = ACTIONS(2126),
    [anon_sym_asm] = ACTIONS(2126),
    [anon_sym___asm__] = ACTIONS(2126),
    [sym_number_literal] = ACTIONS(2128),
    [anon_sym_L_SQUOTE] = ACTIONS(2128),
    [anon_sym_u_SQUOTE] = ACTIONS(2128),
    [anon_sym_U_SQUOTE] = ACTIONS(2128),
    [anon_sym_u8_SQUOTE] = ACTIONS(2128),
    [anon_sym_SQUOTE] = ACTIONS(2128),
    [anon_sym_L_DQUOTE] = ACTIONS(2128),
    [anon_sym_u_DQUOTE] = ACTIONS(2128),
    [anon_sym_U_DQUOTE] = ACTIONS(2128),
    [anon_sym_u8_DQUOTE] = ACTIONS(2128),
    [anon_sym_DQUOTE] = ACTIONS(2128),
    [sym_true] = ACTIONS(2126),
    [sym_false] = ACTIONS(2126),
    [anon_sym_NULL] = ACTIONS(2126),
    [anon_sym_nullptr] = ACTIONS(2126),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2126),
    [anon_sym_decltype] = ACTIONS(2126),
    [sym_virtual] = ACTIONS(2126),
    [anon_sym_typename] = ACTIONS(2126),
    [anon_sym_template] = ACTIONS(2126),
    [anon_sym_try] = ACTIONS(2126),
    [anon_sym_delete] = ACTIONS(2126),
    [anon_sym_throw] = ACTIONS(2126),
    [anon_sym_co_return] = ACTIONS(2126),
    [anon_sym_co_yield] = ACTIONS(2126),
    [anon_sym_R_DQUOTE] = ACTIONS(2128),
    [anon_sym_LR_DQUOTE] = ACTIONS(2128),
    [anon_sym_uR_DQUOTE] = ACTIONS(2128),
    [anon_sym_UR_DQUOTE] = ACTIONS(2128),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2128),
    [anon_sym_co_await] = ACTIONS(2126),
    [anon_sym_new] = ACTIONS(2126),
    [anon_sym_requires] = ACTIONS(2126),
    [sym_this] = ACTIONS(2126),
    [anon_sym_discard] = ACTIONS(2126),
    [anon_sym_precise] = ACTIONS(2126),
    [anon_sym_shared] = ACTIONS(2126),
    [anon_sym_groupshared] = ACTIONS(2126),
    [anon_sym_uniform] = ACTIONS(2126),
    [anon_sym_row_major] = ACTIONS(2126),
    [anon_sym_column_major] = ACTIONS(2126),
    [anon_sym_globallycoherent] = ACTIONS(2126),
    [anon_sym_centroid] = ACTIONS(2126),
    [anon_sym_noperspective] = ACTIONS(2126),
    [anon_sym_nointerpolation] = ACTIONS(2126),
    [anon_sym_sample] = ACTIONS(2126),
    [anon_sym_linear] = ACTIONS(2126),
    [anon_sym_snorm] = ACTIONS(2126),
    [anon_sym_unorm] = ACTIONS(2126),
    [anon_sym_point] = ACTIONS(2126),
    [anon_sym_line] = ACTIONS(2126),
    [anon_sym_triangleadj] = ACTIONS(2126),
    [anon_sym_lineadj] = ACTIONS(2126),
    [anon_sym_triangle] = ACTIONS(2126),
    [anon_sym_cbuffer] = ACTIONS(2126),
  },
  [1040] = {
    [sym_identifier] = ACTIONS(2154),
    [anon_sym_LPAREN2] = ACTIONS(2156),
    [anon_sym_BANG] = ACTIONS(2156),
    [anon_sym_TILDE] = ACTIONS(2156),
    [anon_sym_DASH] = ACTIONS(2154),
    [anon_sym_PLUS] = ACTIONS(2154),
    [anon_sym_STAR] = ACTIONS(2156),
    [anon_sym_AMP] = ACTIONS(2156),
    [anon_sym_SEMI] = ACTIONS(2156),
    [anon_sym___extension__] = ACTIONS(2154),
    [anon_sym_typedef] = ACTIONS(2154),
    [anon_sym_in] = ACTIONS(2154),
    [anon_sym_out] = ACTIONS(2154),
    [anon_sym_inout] = ACTIONS(2154),
    [anon_sym_extern] = ACTIONS(2154),
    [anon_sym___attribute__] = ACTIONS(2154),
    [anon_sym_COLON_COLON] = ACTIONS(2156),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2156),
    [anon_sym___declspec] = ACTIONS(2154),
    [anon_sym_LBRACE] = ACTIONS(2156),
    [anon_sym_signed] = ACTIONS(2154),
    [anon_sym_unsigned] = ACTIONS(2154),
    [anon_sym_long] = ACTIONS(2154),
    [anon_sym_short] = ACTIONS(2154),
    [anon_sym_LBRACK] = ACTIONS(2154),
    [anon_sym_static] = ACTIONS(2154),
    [anon_sym_register] = ACTIONS(2154),
    [anon_sym_inline] = ACTIONS(2154),
    [anon_sym___inline] = ACTIONS(2154),
    [anon_sym___inline__] = ACTIONS(2154),
    [anon_sym___forceinline] = ACTIONS(2154),
    [anon_sym_thread_local] = ACTIONS(2154),
    [anon_sym___thread] = ACTIONS(2154),
    [anon_sym_const] = ACTIONS(2154),
    [anon_sym_constexpr] = ACTIONS(2154),
    [anon_sym_volatile] = ACTIONS(2154),
    [anon_sym_restrict] = ACTIONS(2154),
    [anon_sym___restrict__] = ACTIONS(2154),
    [anon_sym__Atomic] = ACTIONS(2154),
    [anon_sym__Noreturn] = ACTIONS(2154),
    [anon_sym_noreturn] = ACTIONS(2154),
    [anon_sym_mutable] = ACTIONS(2154),
    [anon_sym_constinit] = ACTIONS(2154),
    [anon_sym_consteval] = ACTIONS(2154),
    [anon_sym_alignas] = ACTIONS(2154),
    [anon_sym__Alignas] = ACTIONS(2154),
    [sym_primitive_type] = ACTIONS(2154),
    [anon_sym_enum] = ACTIONS(2154),
    [anon_sym_class] = ACTIONS(2154),
    [anon_sym_struct] = ACTIONS(2154),
    [anon_sym_union] = ACTIONS(2154),
    [anon_sym_if] = ACTIONS(2154),
    [anon_sym_else] = ACTIONS(2154),
    [anon_sym_switch] = ACTIONS(2154),
    [anon_sym_while] = ACTIONS(2154),
    [anon_sym_do] = ACTIONS(2154),
    [anon_sym_for] = ACTIONS(2154),
    [anon_sym_return] = ACTIONS(2154),
    [anon_sym_break] = ACTIONS(2154),
    [anon_sym_continue] = ACTIONS(2154),
    [anon_sym_goto] = ACTIONS(2154),
    [anon_sym___try] = ACTIONS(2154),
    [anon_sym___leave] = ACTIONS(2154),
    [anon_sym_not] = ACTIONS(2154),
    [anon_sym_compl] = ACTIONS(2154),
    [anon_sym_DASH_DASH] = ACTIONS(2156),
    [anon_sym_PLUS_PLUS] = ACTIONS(2156),
    [anon_sym_sizeof] = ACTIONS(2154),
    [anon_sym___alignof__] = ACTIONS(2154),
    [anon_sym___alignof] = ACTIONS(2154),
    [anon_sym__alignof] = ACTIONS(2154),
    [anon_sym_alignof] = ACTIONS(2154),
    [anon_sym__Alignof] = ACTIONS(2154),
    [anon_sym_offsetof] = ACTIONS(2154),
    [anon_sym__Generic] = ACTIONS(2154),
    [anon_sym_asm] = ACTIONS(2154),
    [anon_sym___asm__] = ACTIONS(2154),
    [sym_number_literal] = ACTIONS(2156),
    [anon_sym_L_SQUOTE] = ACTIONS(2156),
    [anon_sym_u_SQUOTE] = ACTIONS(2156),
    [anon_sym_U_SQUOTE] = ACTIONS(2156),
    [anon_sym_u8_SQUOTE] = ACTIONS(2156),
    [anon_sym_SQUOTE] = ACTIONS(2156),
    [anon_sym_L_DQUOTE] = ACTIONS(2156),
    [anon_sym_u_DQUOTE] = ACTIONS(2156),
    [anon_sym_U_DQUOTE] = ACTIONS(2156),
    [anon_sym_u8_DQUOTE] = ACTIONS(2156),
    [anon_sym_DQUOTE] = ACTIONS(2156),
    [sym_true] = ACTIONS(2154),
    [sym_false] = ACTIONS(2154),
    [anon_sym_NULL] = ACTIONS(2154),
    [anon_sym_nullptr] = ACTIONS(2154),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2154),
    [anon_sym_decltype] = ACTIONS(2154),
    [sym_virtual] = ACTIONS(2154),
    [anon_sym_typename] = ACTIONS(2154),
    [anon_sym_template] = ACTIONS(2154),
    [anon_sym_try] = ACTIONS(2154),
    [anon_sym_delete] = ACTIONS(2154),
    [anon_sym_throw] = ACTIONS(2154),
    [anon_sym_co_return] = ACTIONS(2154),
    [anon_sym_co_yield] = ACTIONS(2154),
    [anon_sym_R_DQUOTE] = ACTIONS(2156),
    [anon_sym_LR_DQUOTE] = ACTIONS(2156),
    [anon_sym_uR_DQUOTE] = ACTIONS(2156),
    [anon_sym_UR_DQUOTE] = ACTIONS(2156),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2156),
    [anon_sym_co_await] = ACTIONS(2154),
    [anon_sym_new] = ACTIONS(2154),
    [anon_sym_requires] = ACTIONS(2154),
    [sym_this] = ACTIONS(2154),
    [anon_sym_discard] = ACTIONS(2154),
    [anon_sym_precise] = ACTIONS(2154),
    [anon_sym_shared] = ACTIONS(2154),
    [anon_sym_groupshared] = ACTIONS(2154),
    [anon_sym_uniform] = ACTIONS(2154),
    [anon_sym_row_major] = ACTIONS(2154),
    [anon_sym_column_major] = ACTIONS(2154),
    [anon_sym_globallycoherent] = ACTIONS(2154),
    [anon_sym_centroid] = ACTIONS(2154),
    [anon_sym_noperspective] = ACTIONS(2154),
    [anon_sym_nointerpolation] = ACTIONS(2154),
    [anon_sym_sample] = ACTIONS(2154),
    [anon_sym_linear] = ACTIONS(2154),
    [anon_sym_snorm] = ACTIONS(2154),
    [anon_sym_unorm] = ACTIONS(2154),
    [anon_sym_point] = ACTIONS(2154),
    [anon_sym_line] = ACTIONS(2154),
    [anon_sym_triangleadj] = ACTIONS(2154),
    [anon_sym_lineadj] = ACTIONS(2154),
    [anon_sym_triangle] = ACTIONS(2154),
    [anon_sym_cbuffer] = ACTIONS(2154),
  },
  [1041] = {
    [sym_identifier] = ACTIONS(2158),
    [anon_sym_LPAREN2] = ACTIONS(2160),
    [anon_sym_BANG] = ACTIONS(2160),
    [anon_sym_TILDE] = ACTIONS(2160),
    [anon_sym_DASH] = ACTIONS(2158),
    [anon_sym_PLUS] = ACTIONS(2158),
    [anon_sym_STAR] = ACTIONS(2160),
    [anon_sym_AMP] = ACTIONS(2160),
    [anon_sym_SEMI] = ACTIONS(2160),
    [anon_sym___extension__] = ACTIONS(2158),
    [anon_sym_typedef] = ACTIONS(2158),
    [anon_sym_in] = ACTIONS(2158),
    [anon_sym_out] = ACTIONS(2158),
    [anon_sym_inout] = ACTIONS(2158),
    [anon_sym_extern] = ACTIONS(2158),
    [anon_sym___attribute__] = ACTIONS(2158),
    [anon_sym_COLON_COLON] = ACTIONS(2160),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2160),
    [anon_sym___declspec] = ACTIONS(2158),
    [anon_sym_LBRACE] = ACTIONS(2160),
    [anon_sym_signed] = ACTIONS(2158),
    [anon_sym_unsigned] = ACTIONS(2158),
    [anon_sym_long] = ACTIONS(2158),
    [anon_sym_short] = ACTIONS(2158),
    [anon_sym_LBRACK] = ACTIONS(2158),
    [anon_sym_static] = ACTIONS(2158),
    [anon_sym_register] = ACTIONS(2158),
    [anon_sym_inline] = ACTIONS(2158),
    [anon_sym___inline] = ACTIONS(2158),
    [anon_sym___inline__] = ACTIONS(2158),
    [anon_sym___forceinline] = ACTIONS(2158),
    [anon_sym_thread_local] = ACTIONS(2158),
    [anon_sym___thread] = ACTIONS(2158),
    [anon_sym_const] = ACTIONS(2158),
    [anon_sym_constexpr] = ACTIONS(2158),
    [anon_sym_volatile] = ACTIONS(2158),
    [anon_sym_restrict] = ACTIONS(2158),
    [anon_sym___restrict__] = ACTIONS(2158),
    [anon_sym__Atomic] = ACTIONS(2158),
    [anon_sym__Noreturn] = ACTIONS(2158),
    [anon_sym_noreturn] = ACTIONS(2158),
    [anon_sym_mutable] = ACTIONS(2158),
    [anon_sym_constinit] = ACTIONS(2158),
    [anon_sym_consteval] = ACTIONS(2158),
    [anon_sym_alignas] = ACTIONS(2158),
    [anon_sym__Alignas] = ACTIONS(2158),
    [sym_primitive_type] = ACTIONS(2158),
    [anon_sym_enum] = ACTIONS(2158),
    [anon_sym_class] = ACTIONS(2158),
    [anon_sym_struct] = ACTIONS(2158),
    [anon_sym_union] = ACTIONS(2158),
    [anon_sym_if] = ACTIONS(2158),
    [anon_sym_else] = ACTIONS(2158),
    [anon_sym_switch] = ACTIONS(2158),
    [anon_sym_while] = ACTIONS(2158),
    [anon_sym_do] = ACTIONS(2158),
    [anon_sym_for] = ACTIONS(2158),
    [anon_sym_return] = ACTIONS(2158),
    [anon_sym_break] = ACTIONS(2158),
    [anon_sym_continue] = ACTIONS(2158),
    [anon_sym_goto] = ACTIONS(2158),
    [anon_sym___try] = ACTIONS(2158),
    [anon_sym___leave] = ACTIONS(2158),
    [anon_sym_not] = ACTIONS(2158),
    [anon_sym_compl] = ACTIONS(2158),
    [anon_sym_DASH_DASH] = ACTIONS(2160),
    [anon_sym_PLUS_PLUS] = ACTIONS(2160),
    [anon_sym_sizeof] = ACTIONS(2158),
    [anon_sym___alignof__] = ACTIONS(2158),
    [anon_sym___alignof] = ACTIONS(2158),
    [anon_sym__alignof] = ACTIONS(2158),
    [anon_sym_alignof] = ACTIONS(2158),
    [anon_sym__Alignof] = ACTIONS(2158),
    [anon_sym_offsetof] = ACTIONS(2158),
    [anon_sym__Generic] = ACTIONS(2158),
    [anon_sym_asm] = ACTIONS(2158),
    [anon_sym___asm__] = ACTIONS(2158),
    [sym_number_literal] = ACTIONS(2160),
    [anon_sym_L_SQUOTE] = ACTIONS(2160),
    [anon_sym_u_SQUOTE] = ACTIONS(2160),
    [anon_sym_U_SQUOTE] = ACTIONS(2160),
    [anon_sym_u8_SQUOTE] = ACTIONS(2160),
    [anon_sym_SQUOTE] = ACTIONS(2160),
    [anon_sym_L_DQUOTE] = ACTIONS(2160),
    [anon_sym_u_DQUOTE] = ACTIONS(2160),
    [anon_sym_U_DQUOTE] = ACTIONS(2160),
    [anon_sym_u8_DQUOTE] = ACTIONS(2160),
    [anon_sym_DQUOTE] = ACTIONS(2160),
    [sym_true] = ACTIONS(2158),
    [sym_false] = ACTIONS(2158),
    [anon_sym_NULL] = ACTIONS(2158),
    [anon_sym_nullptr] = ACTIONS(2158),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2158),
    [anon_sym_decltype] = ACTIONS(2158),
    [sym_virtual] = ACTIONS(2158),
    [anon_sym_typename] = ACTIONS(2158),
    [anon_sym_template] = ACTIONS(2158),
    [anon_sym_try] = ACTIONS(2158),
    [anon_sym_delete] = ACTIONS(2158),
    [anon_sym_throw] = ACTIONS(2158),
    [anon_sym_co_return] = ACTIONS(2158),
    [anon_sym_co_yield] = ACTIONS(2158),
    [anon_sym_R_DQUOTE] = ACTIONS(2160),
    [anon_sym_LR_DQUOTE] = ACTIONS(2160),
    [anon_sym_uR_DQUOTE] = ACTIONS(2160),
    [anon_sym_UR_DQUOTE] = ACTIONS(2160),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2160),
    [anon_sym_co_await] = ACTIONS(2158),
    [anon_sym_new] = ACTIONS(2158),
    [anon_sym_requires] = ACTIONS(2158),
    [sym_this] = ACTIONS(2158),
    [anon_sym_discard] = ACTIONS(2158),
    [anon_sym_precise] = ACTIONS(2158),
    [anon_sym_shared] = ACTIONS(2158),
    [anon_sym_groupshared] = ACTIONS(2158),
    [anon_sym_uniform] = ACTIONS(2158),
    [anon_sym_row_major] = ACTIONS(2158),
    [anon_sym_column_major] = ACTIONS(2158),
    [anon_sym_globallycoherent] = ACTIONS(2158),
    [anon_sym_centroid] = ACTIONS(2158),
    [anon_sym_noperspective] = ACTIONS(2158),
    [anon_sym_nointerpolation] = ACTIONS(2158),
    [anon_sym_sample] = ACTIONS(2158),
    [anon_sym_linear] = ACTIONS(2158),
    [anon_sym_snorm] = ACTIONS(2158),
    [anon_sym_unorm] = ACTIONS(2158),
    [anon_sym_point] = ACTIONS(2158),
    [anon_sym_line] = ACTIONS(2158),
    [anon_sym_triangleadj] = ACTIONS(2158),
    [anon_sym_lineadj] = ACTIONS(2158),
    [anon_sym_triangle] = ACTIONS(2158),
    [anon_sym_cbuffer] = ACTIONS(2158),
  },
  [1042] = {
    [sym_identifier] = ACTIONS(2208),
    [anon_sym_LPAREN2] = ACTIONS(2210),
    [anon_sym_BANG] = ACTIONS(2210),
    [anon_sym_TILDE] = ACTIONS(2210),
    [anon_sym_DASH] = ACTIONS(2208),
    [anon_sym_PLUS] = ACTIONS(2208),
    [anon_sym_STAR] = ACTIONS(2210),
    [anon_sym_AMP] = ACTIONS(2210),
    [anon_sym_SEMI] = ACTIONS(2210),
    [anon_sym___extension__] = ACTIONS(2208),
    [anon_sym_typedef] = ACTIONS(2208),
    [anon_sym_in] = ACTIONS(2208),
    [anon_sym_out] = ACTIONS(2208),
    [anon_sym_inout] = ACTIONS(2208),
    [anon_sym_extern] = ACTIONS(2208),
    [anon_sym___attribute__] = ACTIONS(2208),
    [anon_sym_COLON_COLON] = ACTIONS(2210),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2210),
    [anon_sym___declspec] = ACTIONS(2208),
    [anon_sym_LBRACE] = ACTIONS(2210),
    [anon_sym_signed] = ACTIONS(2208),
    [anon_sym_unsigned] = ACTIONS(2208),
    [anon_sym_long] = ACTIONS(2208),
    [anon_sym_short] = ACTIONS(2208),
    [anon_sym_LBRACK] = ACTIONS(2208),
    [anon_sym_static] = ACTIONS(2208),
    [anon_sym_register] = ACTIONS(2208),
    [anon_sym_inline] = ACTIONS(2208),
    [anon_sym___inline] = ACTIONS(2208),
    [anon_sym___inline__] = ACTIONS(2208),
    [anon_sym___forceinline] = ACTIONS(2208),
    [anon_sym_thread_local] = ACTIONS(2208),
    [anon_sym___thread] = ACTIONS(2208),
    [anon_sym_const] = ACTIONS(2208),
    [anon_sym_constexpr] = ACTIONS(2208),
    [anon_sym_volatile] = ACTIONS(2208),
    [anon_sym_restrict] = ACTIONS(2208),
    [anon_sym___restrict__] = ACTIONS(2208),
    [anon_sym__Atomic] = ACTIONS(2208),
    [anon_sym__Noreturn] = ACTIONS(2208),
    [anon_sym_noreturn] = ACTIONS(2208),
    [anon_sym_mutable] = ACTIONS(2208),
    [anon_sym_constinit] = ACTIONS(2208),
    [anon_sym_consteval] = ACTIONS(2208),
    [anon_sym_alignas] = ACTIONS(2208),
    [anon_sym__Alignas] = ACTIONS(2208),
    [sym_primitive_type] = ACTIONS(2208),
    [anon_sym_enum] = ACTIONS(2208),
    [anon_sym_class] = ACTIONS(2208),
    [anon_sym_struct] = ACTIONS(2208),
    [anon_sym_union] = ACTIONS(2208),
    [anon_sym_if] = ACTIONS(2208),
    [anon_sym_else] = ACTIONS(2208),
    [anon_sym_switch] = ACTIONS(2208),
    [anon_sym_while] = ACTIONS(2208),
    [anon_sym_do] = ACTIONS(2208),
    [anon_sym_for] = ACTIONS(2208),
    [anon_sym_return] = ACTIONS(2208),
    [anon_sym_break] = ACTIONS(2208),
    [anon_sym_continue] = ACTIONS(2208),
    [anon_sym_goto] = ACTIONS(2208),
    [anon_sym___try] = ACTIONS(2208),
    [anon_sym___leave] = ACTIONS(2208),
    [anon_sym_not] = ACTIONS(2208),
    [anon_sym_compl] = ACTIONS(2208),
    [anon_sym_DASH_DASH] = ACTIONS(2210),
    [anon_sym_PLUS_PLUS] = ACTIONS(2210),
    [anon_sym_sizeof] = ACTIONS(2208),
    [anon_sym___alignof__] = ACTIONS(2208),
    [anon_sym___alignof] = ACTIONS(2208),
    [anon_sym__alignof] = ACTIONS(2208),
    [anon_sym_alignof] = ACTIONS(2208),
    [anon_sym__Alignof] = ACTIONS(2208),
    [anon_sym_offsetof] = ACTIONS(2208),
    [anon_sym__Generic] = ACTIONS(2208),
    [anon_sym_asm] = ACTIONS(2208),
    [anon_sym___asm__] = ACTIONS(2208),
    [sym_number_literal] = ACTIONS(2210),
    [anon_sym_L_SQUOTE] = ACTIONS(2210),
    [anon_sym_u_SQUOTE] = ACTIONS(2210),
    [anon_sym_U_SQUOTE] = ACTIONS(2210),
    [anon_sym_u8_SQUOTE] = ACTIONS(2210),
    [anon_sym_SQUOTE] = ACTIONS(2210),
    [anon_sym_L_DQUOTE] = ACTIONS(2210),
    [anon_sym_u_DQUOTE] = ACTIONS(2210),
    [anon_sym_U_DQUOTE] = ACTIONS(2210),
    [anon_sym_u8_DQUOTE] = ACTIONS(2210),
    [anon_sym_DQUOTE] = ACTIONS(2210),
    [sym_true] = ACTIONS(2208),
    [sym_false] = ACTIONS(2208),
    [anon_sym_NULL] = ACTIONS(2208),
    [anon_sym_nullptr] = ACTIONS(2208),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2208),
    [anon_sym_decltype] = ACTIONS(2208),
    [sym_virtual] = ACTIONS(2208),
    [anon_sym_typename] = ACTIONS(2208),
    [anon_sym_template] = ACTIONS(2208),
    [anon_sym_try] = ACTIONS(2208),
    [anon_sym_delete] = ACTIONS(2208),
    [anon_sym_throw] = ACTIONS(2208),
    [anon_sym_co_return] = ACTIONS(2208),
    [anon_sym_co_yield] = ACTIONS(2208),
    [anon_sym_R_DQUOTE] = ACTIONS(2210),
    [anon_sym_LR_DQUOTE] = ACTIONS(2210),
    [anon_sym_uR_DQUOTE] = ACTIONS(2210),
    [anon_sym_UR_DQUOTE] = ACTIONS(2210),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2210),
    [anon_sym_co_await] = ACTIONS(2208),
    [anon_sym_new] = ACTIONS(2208),
    [anon_sym_requires] = ACTIONS(2208),
    [sym_this] = ACTIONS(2208),
    [anon_sym_discard] = ACTIONS(2208),
    [anon_sym_precise] = ACTIONS(2208),
    [anon_sym_shared] = ACTIONS(2208),
    [anon_sym_groupshared] = ACTIONS(2208),
    [anon_sym_uniform] = ACTIONS(2208),
    [anon_sym_row_major] = ACTIONS(2208),
    [anon_sym_column_major] = ACTIONS(2208),
    [anon_sym_globallycoherent] = ACTIONS(2208),
    [anon_sym_centroid] = ACTIONS(2208),
    [anon_sym_noperspective] = ACTIONS(2208),
    [anon_sym_nointerpolation] = ACTIONS(2208),
    [anon_sym_sample] = ACTIONS(2208),
    [anon_sym_linear] = ACTIONS(2208),
    [anon_sym_snorm] = ACTIONS(2208),
    [anon_sym_unorm] = ACTIONS(2208),
    [anon_sym_point] = ACTIONS(2208),
    [anon_sym_line] = ACTIONS(2208),
    [anon_sym_triangleadj] = ACTIONS(2208),
    [anon_sym_lineadj] = ACTIONS(2208),
    [anon_sym_triangle] = ACTIONS(2208),
    [anon_sym_cbuffer] = ACTIONS(2208),
  },
  [1043] = {
    [sym_identifier] = ACTIONS(2150),
    [anon_sym_LPAREN2] = ACTIONS(2152),
    [anon_sym_BANG] = ACTIONS(2152),
    [anon_sym_TILDE] = ACTIONS(2152),
    [anon_sym_DASH] = ACTIONS(2150),
    [anon_sym_PLUS] = ACTIONS(2150),
    [anon_sym_STAR] = ACTIONS(2152),
    [anon_sym_AMP] = ACTIONS(2152),
    [anon_sym_SEMI] = ACTIONS(2152),
    [anon_sym___extension__] = ACTIONS(2150),
    [anon_sym_typedef] = ACTIONS(2150),
    [anon_sym_in] = ACTIONS(2150),
    [anon_sym_out] = ACTIONS(2150),
    [anon_sym_inout] = ACTIONS(2150),
    [anon_sym_extern] = ACTIONS(2150),
    [anon_sym___attribute__] = ACTIONS(2150),
    [anon_sym_COLON_COLON] = ACTIONS(2152),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2152),
    [anon_sym___declspec] = ACTIONS(2150),
    [anon_sym_LBRACE] = ACTIONS(2152),
    [anon_sym_signed] = ACTIONS(2150),
    [anon_sym_unsigned] = ACTIONS(2150),
    [anon_sym_long] = ACTIONS(2150),
    [anon_sym_short] = ACTIONS(2150),
    [anon_sym_LBRACK] = ACTIONS(2150),
    [anon_sym_static] = ACTIONS(2150),
    [anon_sym_register] = ACTIONS(2150),
    [anon_sym_inline] = ACTIONS(2150),
    [anon_sym___inline] = ACTIONS(2150),
    [anon_sym___inline__] = ACTIONS(2150),
    [anon_sym___forceinline] = ACTIONS(2150),
    [anon_sym_thread_local] = ACTIONS(2150),
    [anon_sym___thread] = ACTIONS(2150),
    [anon_sym_const] = ACTIONS(2150),
    [anon_sym_constexpr] = ACTIONS(2150),
    [anon_sym_volatile] = ACTIONS(2150),
    [anon_sym_restrict] = ACTIONS(2150),
    [anon_sym___restrict__] = ACTIONS(2150),
    [anon_sym__Atomic] = ACTIONS(2150),
    [anon_sym__Noreturn] = ACTIONS(2150),
    [anon_sym_noreturn] = ACTIONS(2150),
    [anon_sym_mutable] = ACTIONS(2150),
    [anon_sym_constinit] = ACTIONS(2150),
    [anon_sym_consteval] = ACTIONS(2150),
    [anon_sym_alignas] = ACTIONS(2150),
    [anon_sym__Alignas] = ACTIONS(2150),
    [sym_primitive_type] = ACTIONS(2150),
    [anon_sym_enum] = ACTIONS(2150),
    [anon_sym_class] = ACTIONS(2150),
    [anon_sym_struct] = ACTIONS(2150),
    [anon_sym_union] = ACTIONS(2150),
    [anon_sym_if] = ACTIONS(2150),
    [anon_sym_else] = ACTIONS(2150),
    [anon_sym_switch] = ACTIONS(2150),
    [anon_sym_while] = ACTIONS(2150),
    [anon_sym_do] = ACTIONS(2150),
    [anon_sym_for] = ACTIONS(2150),
    [anon_sym_return] = ACTIONS(2150),
    [anon_sym_break] = ACTIONS(2150),
    [anon_sym_continue] = ACTIONS(2150),
    [anon_sym_goto] = ACTIONS(2150),
    [anon_sym___try] = ACTIONS(2150),
    [anon_sym___leave] = ACTIONS(2150),
    [anon_sym_not] = ACTIONS(2150),
    [anon_sym_compl] = ACTIONS(2150),
    [anon_sym_DASH_DASH] = ACTIONS(2152),
    [anon_sym_PLUS_PLUS] = ACTIONS(2152),
    [anon_sym_sizeof] = ACTIONS(2150),
    [anon_sym___alignof__] = ACTIONS(2150),
    [anon_sym___alignof] = ACTIONS(2150),
    [anon_sym__alignof] = ACTIONS(2150),
    [anon_sym_alignof] = ACTIONS(2150),
    [anon_sym__Alignof] = ACTIONS(2150),
    [anon_sym_offsetof] = ACTIONS(2150),
    [anon_sym__Generic] = ACTIONS(2150),
    [anon_sym_asm] = ACTIONS(2150),
    [anon_sym___asm__] = ACTIONS(2150),
    [sym_number_literal] = ACTIONS(2152),
    [anon_sym_L_SQUOTE] = ACTIONS(2152),
    [anon_sym_u_SQUOTE] = ACTIONS(2152),
    [anon_sym_U_SQUOTE] = ACTIONS(2152),
    [anon_sym_u8_SQUOTE] = ACTIONS(2152),
    [anon_sym_SQUOTE] = ACTIONS(2152),
    [anon_sym_L_DQUOTE] = ACTIONS(2152),
    [anon_sym_u_DQUOTE] = ACTIONS(2152),
    [anon_sym_U_DQUOTE] = ACTIONS(2152),
    [anon_sym_u8_DQUOTE] = ACTIONS(2152),
    [anon_sym_DQUOTE] = ACTIONS(2152),
    [sym_true] = ACTIONS(2150),
    [sym_false] = ACTIONS(2150),
    [anon_sym_NULL] = ACTIONS(2150),
    [anon_sym_nullptr] = ACTIONS(2150),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2150),
    [anon_sym_decltype] = ACTIONS(2150),
    [sym_virtual] = ACTIONS(2150),
    [anon_sym_typename] = ACTIONS(2150),
    [anon_sym_template] = ACTIONS(2150),
    [anon_sym_try] = ACTIONS(2150),
    [anon_sym_delete] = ACTIONS(2150),
    [anon_sym_throw] = ACTIONS(2150),
    [anon_sym_co_return] = ACTIONS(2150),
    [anon_sym_co_yield] = ACTIONS(2150),
    [anon_sym_R_DQUOTE] = ACTIONS(2152),
    [anon_sym_LR_DQUOTE] = ACTIONS(2152),
    [anon_sym_uR_DQUOTE] = ACTIONS(2152),
    [anon_sym_UR_DQUOTE] = ACTIONS(2152),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2152),
    [anon_sym_co_await] = ACTIONS(2150),
    [anon_sym_new] = ACTIONS(2150),
    [anon_sym_requires] = ACTIONS(2150),
    [sym_this] = ACTIONS(2150),
    [anon_sym_discard] = ACTIONS(2150),
    [anon_sym_precise] = ACTIONS(2150),
    [anon_sym_shared] = ACTIONS(2150),
    [anon_sym_groupshared] = ACTIONS(2150),
    [anon_sym_uniform] = ACTIONS(2150),
    [anon_sym_row_major] = ACTIONS(2150),
    [anon_sym_column_major] = ACTIONS(2150),
    [anon_sym_globallycoherent] = ACTIONS(2150),
    [anon_sym_centroid] = ACTIONS(2150),
    [anon_sym_noperspective] = ACTIONS(2150),
    [anon_sym_nointerpolation] = ACTIONS(2150),
    [anon_sym_sample] = ACTIONS(2150),
    [anon_sym_linear] = ACTIONS(2150),
    [anon_sym_snorm] = ACTIONS(2150),
    [anon_sym_unorm] = ACTIONS(2150),
    [anon_sym_point] = ACTIONS(2150),
    [anon_sym_line] = ACTIONS(2150),
    [anon_sym_triangleadj] = ACTIONS(2150),
    [anon_sym_lineadj] = ACTIONS(2150),
    [anon_sym_triangle] = ACTIONS(2150),
    [anon_sym_cbuffer] = ACTIONS(2150),
  },
  [1044] = {
    [sym_identifier] = ACTIONS(2212),
    [anon_sym_LPAREN2] = ACTIONS(2214),
    [anon_sym_BANG] = ACTIONS(2214),
    [anon_sym_TILDE] = ACTIONS(2214),
    [anon_sym_DASH] = ACTIONS(2212),
    [anon_sym_PLUS] = ACTIONS(2212),
    [anon_sym_STAR] = ACTIONS(2214),
    [anon_sym_AMP] = ACTIONS(2214),
    [anon_sym_SEMI] = ACTIONS(2214),
    [anon_sym___extension__] = ACTIONS(2212),
    [anon_sym_typedef] = ACTIONS(2212),
    [anon_sym_in] = ACTIONS(2212),
    [anon_sym_out] = ACTIONS(2212),
    [anon_sym_inout] = ACTIONS(2212),
    [anon_sym_extern] = ACTIONS(2212),
    [anon_sym___attribute__] = ACTIONS(2212),
    [anon_sym_COLON_COLON] = ACTIONS(2214),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2214),
    [anon_sym___declspec] = ACTIONS(2212),
    [anon_sym_LBRACE] = ACTIONS(2214),
    [anon_sym_signed] = ACTIONS(2212),
    [anon_sym_unsigned] = ACTIONS(2212),
    [anon_sym_long] = ACTIONS(2212),
    [anon_sym_short] = ACTIONS(2212),
    [anon_sym_LBRACK] = ACTIONS(2212),
    [anon_sym_static] = ACTIONS(2212),
    [anon_sym_register] = ACTIONS(2212),
    [anon_sym_inline] = ACTIONS(2212),
    [anon_sym___inline] = ACTIONS(2212),
    [anon_sym___inline__] = ACTIONS(2212),
    [anon_sym___forceinline] = ACTIONS(2212),
    [anon_sym_thread_local] = ACTIONS(2212),
    [anon_sym___thread] = ACTIONS(2212),
    [anon_sym_const] = ACTIONS(2212),
    [anon_sym_constexpr] = ACTIONS(2212),
    [anon_sym_volatile] = ACTIONS(2212),
    [anon_sym_restrict] = ACTIONS(2212),
    [anon_sym___restrict__] = ACTIONS(2212),
    [anon_sym__Atomic] = ACTIONS(2212),
    [anon_sym__Noreturn] = ACTIONS(2212),
    [anon_sym_noreturn] = ACTIONS(2212),
    [anon_sym_mutable] = ACTIONS(2212),
    [anon_sym_constinit] = ACTIONS(2212),
    [anon_sym_consteval] = ACTIONS(2212),
    [anon_sym_alignas] = ACTIONS(2212),
    [anon_sym__Alignas] = ACTIONS(2212),
    [sym_primitive_type] = ACTIONS(2212),
    [anon_sym_enum] = ACTIONS(2212),
    [anon_sym_class] = ACTIONS(2212),
    [anon_sym_struct] = ACTIONS(2212),
    [anon_sym_union] = ACTIONS(2212),
    [anon_sym_if] = ACTIONS(2212),
    [anon_sym_else] = ACTIONS(2212),
    [anon_sym_switch] = ACTIONS(2212),
    [anon_sym_while] = ACTIONS(2212),
    [anon_sym_do] = ACTIONS(2212),
    [anon_sym_for] = ACTIONS(2212),
    [anon_sym_return] = ACTIONS(2212),
    [anon_sym_break] = ACTIONS(2212),
    [anon_sym_continue] = ACTIONS(2212),
    [anon_sym_goto] = ACTIONS(2212),
    [anon_sym___try] = ACTIONS(2212),
    [anon_sym___leave] = ACTIONS(2212),
    [anon_sym_not] = ACTIONS(2212),
    [anon_sym_compl] = ACTIONS(2212),
    [anon_sym_DASH_DASH] = ACTIONS(2214),
    [anon_sym_PLUS_PLUS] = ACTIONS(2214),
    [anon_sym_sizeof] = ACTIONS(2212),
    [anon_sym___alignof__] = ACTIONS(2212),
    [anon_sym___alignof] = ACTIONS(2212),
    [anon_sym__alignof] = ACTIONS(2212),
    [anon_sym_alignof] = ACTIONS(2212),
    [anon_sym__Alignof] = ACTIONS(2212),
    [anon_sym_offsetof] = ACTIONS(2212),
    [anon_sym__Generic] = ACTIONS(2212),
    [anon_sym_asm] = ACTIONS(2212),
    [anon_sym___asm__] = ACTIONS(2212),
    [sym_number_literal] = ACTIONS(2214),
    [anon_sym_L_SQUOTE] = ACTIONS(2214),
    [anon_sym_u_SQUOTE] = ACTIONS(2214),
    [anon_sym_U_SQUOTE] = ACTIONS(2214),
    [anon_sym_u8_SQUOTE] = ACTIONS(2214),
    [anon_sym_SQUOTE] = ACTIONS(2214),
    [anon_sym_L_DQUOTE] = ACTIONS(2214),
    [anon_sym_u_DQUOTE] = ACTIONS(2214),
    [anon_sym_U_DQUOTE] = ACTIONS(2214),
    [anon_sym_u8_DQUOTE] = ACTIONS(2214),
    [anon_sym_DQUOTE] = ACTIONS(2214),
    [sym_true] = ACTIONS(2212),
    [sym_false] = ACTIONS(2212),
    [anon_sym_NULL] = ACTIONS(2212),
    [anon_sym_nullptr] = ACTIONS(2212),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2212),
    [anon_sym_decltype] = ACTIONS(2212),
    [sym_virtual] = ACTIONS(2212),
    [anon_sym_typename] = ACTIONS(2212),
    [anon_sym_template] = ACTIONS(2212),
    [anon_sym_try] = ACTIONS(2212),
    [anon_sym_delete] = ACTIONS(2212),
    [anon_sym_throw] = ACTIONS(2212),
    [anon_sym_co_return] = ACTIONS(2212),
    [anon_sym_co_yield] = ACTIONS(2212),
    [anon_sym_R_DQUOTE] = ACTIONS(2214),
    [anon_sym_LR_DQUOTE] = ACTIONS(2214),
    [anon_sym_uR_DQUOTE] = ACTIONS(2214),
    [anon_sym_UR_DQUOTE] = ACTIONS(2214),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2214),
    [anon_sym_co_await] = ACTIONS(2212),
    [anon_sym_new] = ACTIONS(2212),
    [anon_sym_requires] = ACTIONS(2212),
    [sym_this] = ACTIONS(2212),
    [anon_sym_discard] = ACTIONS(2212),
    [anon_sym_precise] = ACTIONS(2212),
    [anon_sym_shared] = ACTIONS(2212),
    [anon_sym_groupshared] = ACTIONS(2212),
    [anon_sym_uniform] = ACTIONS(2212),
    [anon_sym_row_major] = ACTIONS(2212),
    [anon_sym_column_major] = ACTIONS(2212),
    [anon_sym_globallycoherent] = ACTIONS(2212),
    [anon_sym_centroid] = ACTIONS(2212),
    [anon_sym_noperspective] = ACTIONS(2212),
    [anon_sym_nointerpolation] = ACTIONS(2212),
    [anon_sym_sample] = ACTIONS(2212),
    [anon_sym_linear] = ACTIONS(2212),
    [anon_sym_snorm] = ACTIONS(2212),
    [anon_sym_unorm] = ACTIONS(2212),
    [anon_sym_point] = ACTIONS(2212),
    [anon_sym_line] = ACTIONS(2212),
    [anon_sym_triangleadj] = ACTIONS(2212),
    [anon_sym_lineadj] = ACTIONS(2212),
    [anon_sym_triangle] = ACTIONS(2212),
    [anon_sym_cbuffer] = ACTIONS(2212),
  },
  [1045] = {
    [sym_identifier] = ACTIONS(2102),
    [anon_sym_LPAREN2] = ACTIONS(2104),
    [anon_sym_BANG] = ACTIONS(2104),
    [anon_sym_TILDE] = ACTIONS(2104),
    [anon_sym_DASH] = ACTIONS(2102),
    [anon_sym_PLUS] = ACTIONS(2102),
    [anon_sym_STAR] = ACTIONS(2104),
    [anon_sym_AMP] = ACTIONS(2104),
    [anon_sym_SEMI] = ACTIONS(2104),
    [anon_sym___extension__] = ACTIONS(2102),
    [anon_sym_typedef] = ACTIONS(2102),
    [anon_sym_in] = ACTIONS(2102),
    [anon_sym_out] = ACTIONS(2102),
    [anon_sym_inout] = ACTIONS(2102),
    [anon_sym_extern] = ACTIONS(2102),
    [anon_sym___attribute__] = ACTIONS(2102),
    [anon_sym_COLON_COLON] = ACTIONS(2104),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2104),
    [anon_sym___declspec] = ACTIONS(2102),
    [anon_sym_LBRACE] = ACTIONS(2104),
    [anon_sym_signed] = ACTIONS(2102),
    [anon_sym_unsigned] = ACTIONS(2102),
    [anon_sym_long] = ACTIONS(2102),
    [anon_sym_short] = ACTIONS(2102),
    [anon_sym_LBRACK] = ACTIONS(2102),
    [anon_sym_static] = ACTIONS(2102),
    [anon_sym_register] = ACTIONS(2102),
    [anon_sym_inline] = ACTIONS(2102),
    [anon_sym___inline] = ACTIONS(2102),
    [anon_sym___inline__] = ACTIONS(2102),
    [anon_sym___forceinline] = ACTIONS(2102),
    [anon_sym_thread_local] = ACTIONS(2102),
    [anon_sym___thread] = ACTIONS(2102),
    [anon_sym_const] = ACTIONS(2102),
    [anon_sym_constexpr] = ACTIONS(2102),
    [anon_sym_volatile] = ACTIONS(2102),
    [anon_sym_restrict] = ACTIONS(2102),
    [anon_sym___restrict__] = ACTIONS(2102),
    [anon_sym__Atomic] = ACTIONS(2102),
    [anon_sym__Noreturn] = ACTIONS(2102),
    [anon_sym_noreturn] = ACTIONS(2102),
    [anon_sym_mutable] = ACTIONS(2102),
    [anon_sym_constinit] = ACTIONS(2102),
    [anon_sym_consteval] = ACTIONS(2102),
    [anon_sym_alignas] = ACTIONS(2102),
    [anon_sym__Alignas] = ACTIONS(2102),
    [sym_primitive_type] = ACTIONS(2102),
    [anon_sym_enum] = ACTIONS(2102),
    [anon_sym_class] = ACTIONS(2102),
    [anon_sym_struct] = ACTIONS(2102),
    [anon_sym_union] = ACTIONS(2102),
    [anon_sym_if] = ACTIONS(2102),
    [anon_sym_else] = ACTIONS(2102),
    [anon_sym_switch] = ACTIONS(2102),
    [anon_sym_while] = ACTIONS(2102),
    [anon_sym_do] = ACTIONS(2102),
    [anon_sym_for] = ACTIONS(2102),
    [anon_sym_return] = ACTIONS(2102),
    [anon_sym_break] = ACTIONS(2102),
    [anon_sym_continue] = ACTIONS(2102),
    [anon_sym_goto] = ACTIONS(2102),
    [anon_sym___try] = ACTIONS(2102),
    [anon_sym___leave] = ACTIONS(2102),
    [anon_sym_not] = ACTIONS(2102),
    [anon_sym_compl] = ACTIONS(2102),
    [anon_sym_DASH_DASH] = ACTIONS(2104),
    [anon_sym_PLUS_PLUS] = ACTIONS(2104),
    [anon_sym_sizeof] = ACTIONS(2102),
    [anon_sym___alignof__] = ACTIONS(2102),
    [anon_sym___alignof] = ACTIONS(2102),
    [anon_sym__alignof] = ACTIONS(2102),
    [anon_sym_alignof] = ACTIONS(2102),
    [anon_sym__Alignof] = ACTIONS(2102),
    [anon_sym_offsetof] = ACTIONS(2102),
    [anon_sym__Generic] = ACTIONS(2102),
    [anon_sym_asm] = ACTIONS(2102),
    [anon_sym___asm__] = ACTIONS(2102),
    [sym_number_literal] = ACTIONS(2104),
    [anon_sym_L_SQUOTE] = ACTIONS(2104),
    [anon_sym_u_SQUOTE] = ACTIONS(2104),
    [anon_sym_U_SQUOTE] = ACTIONS(2104),
    [anon_sym_u8_SQUOTE] = ACTIONS(2104),
    [anon_sym_SQUOTE] = ACTIONS(2104),
    [anon_sym_L_DQUOTE] = ACTIONS(2104),
    [anon_sym_u_DQUOTE] = ACTIONS(2104),
    [anon_sym_U_DQUOTE] = ACTIONS(2104),
    [anon_sym_u8_DQUOTE] = ACTIONS(2104),
    [anon_sym_DQUOTE] = ACTIONS(2104),
    [sym_true] = ACTIONS(2102),
    [sym_false] = ACTIONS(2102),
    [anon_sym_NULL] = ACTIONS(2102),
    [anon_sym_nullptr] = ACTIONS(2102),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2102),
    [anon_sym_decltype] = ACTIONS(2102),
    [sym_virtual] = ACTIONS(2102),
    [anon_sym_typename] = ACTIONS(2102),
    [anon_sym_template] = ACTIONS(2102),
    [anon_sym_try] = ACTIONS(2102),
    [anon_sym_delete] = ACTIONS(2102),
    [anon_sym_throw] = ACTIONS(2102),
    [anon_sym_co_return] = ACTIONS(2102),
    [anon_sym_co_yield] = ACTIONS(2102),
    [anon_sym_R_DQUOTE] = ACTIONS(2104),
    [anon_sym_LR_DQUOTE] = ACTIONS(2104),
    [anon_sym_uR_DQUOTE] = ACTIONS(2104),
    [anon_sym_UR_DQUOTE] = ACTIONS(2104),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2104),
    [anon_sym_co_await] = ACTIONS(2102),
    [anon_sym_new] = ACTIONS(2102),
    [anon_sym_requires] = ACTIONS(2102),
    [sym_this] = ACTIONS(2102),
    [anon_sym_discard] = ACTIONS(2102),
    [anon_sym_precise] = ACTIONS(2102),
    [anon_sym_shared] = ACTIONS(2102),
    [anon_sym_groupshared] = ACTIONS(2102),
    [anon_sym_uniform] = ACTIONS(2102),
    [anon_sym_row_major] = ACTIONS(2102),
    [anon_sym_column_major] = ACTIONS(2102),
    [anon_sym_globallycoherent] = ACTIONS(2102),
    [anon_sym_centroid] = ACTIONS(2102),
    [anon_sym_noperspective] = ACTIONS(2102),
    [anon_sym_nointerpolation] = ACTIONS(2102),
    [anon_sym_sample] = ACTIONS(2102),
    [anon_sym_linear] = ACTIONS(2102),
    [anon_sym_snorm] = ACTIONS(2102),
    [anon_sym_unorm] = ACTIONS(2102),
    [anon_sym_point] = ACTIONS(2102),
    [anon_sym_line] = ACTIONS(2102),
    [anon_sym_triangleadj] = ACTIONS(2102),
    [anon_sym_lineadj] = ACTIONS(2102),
    [anon_sym_triangle] = ACTIONS(2102),
    [anon_sym_cbuffer] = ACTIONS(2102),
  },
  [1046] = {
    [sym_identifier] = ACTIONS(2280),
    [anon_sym_LPAREN2] = ACTIONS(2282),
    [anon_sym_BANG] = ACTIONS(2282),
    [anon_sym_TILDE] = ACTIONS(2282),
    [anon_sym_DASH] = ACTIONS(2280),
    [anon_sym_PLUS] = ACTIONS(2280),
    [anon_sym_STAR] = ACTIONS(2282),
    [anon_sym_AMP] = ACTIONS(2282),
    [anon_sym_SEMI] = ACTIONS(2282),
    [anon_sym___extension__] = ACTIONS(2280),
    [anon_sym_typedef] = ACTIONS(2280),
    [anon_sym_in] = ACTIONS(2280),
    [anon_sym_out] = ACTIONS(2280),
    [anon_sym_inout] = ACTIONS(2280),
    [anon_sym_extern] = ACTIONS(2280),
    [anon_sym___attribute__] = ACTIONS(2280),
    [anon_sym_COLON_COLON] = ACTIONS(2282),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2282),
    [anon_sym___declspec] = ACTIONS(2280),
    [anon_sym_LBRACE] = ACTIONS(2282),
    [anon_sym_signed] = ACTIONS(2280),
    [anon_sym_unsigned] = ACTIONS(2280),
    [anon_sym_long] = ACTIONS(2280),
    [anon_sym_short] = ACTIONS(2280),
    [anon_sym_LBRACK] = ACTIONS(2280),
    [anon_sym_static] = ACTIONS(2280),
    [anon_sym_register] = ACTIONS(2280),
    [anon_sym_inline] = ACTIONS(2280),
    [anon_sym___inline] = ACTIONS(2280),
    [anon_sym___inline__] = ACTIONS(2280),
    [anon_sym___forceinline] = ACTIONS(2280),
    [anon_sym_thread_local] = ACTIONS(2280),
    [anon_sym___thread] = ACTIONS(2280),
    [anon_sym_const] = ACTIONS(2280),
    [anon_sym_constexpr] = ACTIONS(2280),
    [anon_sym_volatile] = ACTIONS(2280),
    [anon_sym_restrict] = ACTIONS(2280),
    [anon_sym___restrict__] = ACTIONS(2280),
    [anon_sym__Atomic] = ACTIONS(2280),
    [anon_sym__Noreturn] = ACTIONS(2280),
    [anon_sym_noreturn] = ACTIONS(2280),
    [anon_sym_mutable] = ACTIONS(2280),
    [anon_sym_constinit] = ACTIONS(2280),
    [anon_sym_consteval] = ACTIONS(2280),
    [anon_sym_alignas] = ACTIONS(2280),
    [anon_sym__Alignas] = ACTIONS(2280),
    [sym_primitive_type] = ACTIONS(2280),
    [anon_sym_enum] = ACTIONS(2280),
    [anon_sym_class] = ACTIONS(2280),
    [anon_sym_struct] = ACTIONS(2280),
    [anon_sym_union] = ACTIONS(2280),
    [anon_sym_if] = ACTIONS(2280),
    [anon_sym_else] = ACTIONS(2280),
    [anon_sym_switch] = ACTIONS(2280),
    [anon_sym_while] = ACTIONS(2280),
    [anon_sym_do] = ACTIONS(2280),
    [anon_sym_for] = ACTIONS(2280),
    [anon_sym_return] = ACTIONS(2280),
    [anon_sym_break] = ACTIONS(2280),
    [anon_sym_continue] = ACTIONS(2280),
    [anon_sym_goto] = ACTIONS(2280),
    [anon_sym___try] = ACTIONS(2280),
    [anon_sym___leave] = ACTIONS(2280),
    [anon_sym_not] = ACTIONS(2280),
    [anon_sym_compl] = ACTIONS(2280),
    [anon_sym_DASH_DASH] = ACTIONS(2282),
    [anon_sym_PLUS_PLUS] = ACTIONS(2282),
    [anon_sym_sizeof] = ACTIONS(2280),
    [anon_sym___alignof__] = ACTIONS(2280),
    [anon_sym___alignof] = ACTIONS(2280),
    [anon_sym__alignof] = ACTIONS(2280),
    [anon_sym_alignof] = ACTIONS(2280),
    [anon_sym__Alignof] = ACTIONS(2280),
    [anon_sym_offsetof] = ACTIONS(2280),
    [anon_sym__Generic] = ACTIONS(2280),
    [anon_sym_asm] = ACTIONS(2280),
    [anon_sym___asm__] = ACTIONS(2280),
    [sym_number_literal] = ACTIONS(2282),
    [anon_sym_L_SQUOTE] = ACTIONS(2282),
    [anon_sym_u_SQUOTE] = ACTIONS(2282),
    [anon_sym_U_SQUOTE] = ACTIONS(2282),
    [anon_sym_u8_SQUOTE] = ACTIONS(2282),
    [anon_sym_SQUOTE] = ACTIONS(2282),
    [anon_sym_L_DQUOTE] = ACTIONS(2282),
    [anon_sym_u_DQUOTE] = ACTIONS(2282),
    [anon_sym_U_DQUOTE] = ACTIONS(2282),
    [anon_sym_u8_DQUOTE] = ACTIONS(2282),
    [anon_sym_DQUOTE] = ACTIONS(2282),
    [sym_true] = ACTIONS(2280),
    [sym_false] = ACTIONS(2280),
    [anon_sym_NULL] = ACTIONS(2280),
    [anon_sym_nullptr] = ACTIONS(2280),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2280),
    [anon_sym_decltype] = ACTIONS(2280),
    [sym_virtual] = ACTIONS(2280),
    [anon_sym_typename] = ACTIONS(2280),
    [anon_sym_template] = ACTIONS(2280),
    [anon_sym_try] = ACTIONS(2280),
    [anon_sym_delete] = ACTIONS(2280),
    [anon_sym_throw] = ACTIONS(2280),
    [anon_sym_co_return] = ACTIONS(2280),
    [anon_sym_co_yield] = ACTIONS(2280),
    [anon_sym_R_DQUOTE] = ACTIONS(2282),
    [anon_sym_LR_DQUOTE] = ACTIONS(2282),
    [anon_sym_uR_DQUOTE] = ACTIONS(2282),
    [anon_sym_UR_DQUOTE] = ACTIONS(2282),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2282),
    [anon_sym_co_await] = ACTIONS(2280),
    [anon_sym_new] = ACTIONS(2280),
    [anon_sym_requires] = ACTIONS(2280),
    [sym_this] = ACTIONS(2280),
    [anon_sym_discard] = ACTIONS(2280),
    [anon_sym_precise] = ACTIONS(2280),
    [anon_sym_shared] = ACTIONS(2280),
    [anon_sym_groupshared] = ACTIONS(2280),
    [anon_sym_uniform] = ACTIONS(2280),
    [anon_sym_row_major] = ACTIONS(2280),
    [anon_sym_column_major] = ACTIONS(2280),
    [anon_sym_globallycoherent] = ACTIONS(2280),
    [anon_sym_centroid] = ACTIONS(2280),
    [anon_sym_noperspective] = ACTIONS(2280),
    [anon_sym_nointerpolation] = ACTIONS(2280),
    [anon_sym_sample] = ACTIONS(2280),
    [anon_sym_linear] = ACTIONS(2280),
    [anon_sym_snorm] = ACTIONS(2280),
    [anon_sym_unorm] = ACTIONS(2280),
    [anon_sym_point] = ACTIONS(2280),
    [anon_sym_line] = ACTIONS(2280),
    [anon_sym_triangleadj] = ACTIONS(2280),
    [anon_sym_lineadj] = ACTIONS(2280),
    [anon_sym_triangle] = ACTIONS(2280),
    [anon_sym_cbuffer] = ACTIONS(2280),
  },
  [1047] = {
    [sym_identifier] = ACTIONS(2228),
    [anon_sym_LPAREN2] = ACTIONS(2230),
    [anon_sym_BANG] = ACTIONS(2230),
    [anon_sym_TILDE] = ACTIONS(2230),
    [anon_sym_DASH] = ACTIONS(2228),
    [anon_sym_PLUS] = ACTIONS(2228),
    [anon_sym_STAR] = ACTIONS(2230),
    [anon_sym_AMP] = ACTIONS(2230),
    [anon_sym_SEMI] = ACTIONS(2230),
    [anon_sym___extension__] = ACTIONS(2228),
    [anon_sym_typedef] = ACTIONS(2228),
    [anon_sym_in] = ACTIONS(2228),
    [anon_sym_out] = ACTIONS(2228),
    [anon_sym_inout] = ACTIONS(2228),
    [anon_sym_extern] = ACTIONS(2228),
    [anon_sym___attribute__] = ACTIONS(2228),
    [anon_sym_COLON_COLON] = ACTIONS(2230),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2230),
    [anon_sym___declspec] = ACTIONS(2228),
    [anon_sym_LBRACE] = ACTIONS(2230),
    [anon_sym_signed] = ACTIONS(2228),
    [anon_sym_unsigned] = ACTIONS(2228),
    [anon_sym_long] = ACTIONS(2228),
    [anon_sym_short] = ACTIONS(2228),
    [anon_sym_LBRACK] = ACTIONS(2228),
    [anon_sym_static] = ACTIONS(2228),
    [anon_sym_register] = ACTIONS(2228),
    [anon_sym_inline] = ACTIONS(2228),
    [anon_sym___inline] = ACTIONS(2228),
    [anon_sym___inline__] = ACTIONS(2228),
    [anon_sym___forceinline] = ACTIONS(2228),
    [anon_sym_thread_local] = ACTIONS(2228),
    [anon_sym___thread] = ACTIONS(2228),
    [anon_sym_const] = ACTIONS(2228),
    [anon_sym_constexpr] = ACTIONS(2228),
    [anon_sym_volatile] = ACTIONS(2228),
    [anon_sym_restrict] = ACTIONS(2228),
    [anon_sym___restrict__] = ACTIONS(2228),
    [anon_sym__Atomic] = ACTIONS(2228),
    [anon_sym__Noreturn] = ACTIONS(2228),
    [anon_sym_noreturn] = ACTIONS(2228),
    [anon_sym_mutable] = ACTIONS(2228),
    [anon_sym_constinit] = ACTIONS(2228),
    [anon_sym_consteval] = ACTIONS(2228),
    [anon_sym_alignas] = ACTIONS(2228),
    [anon_sym__Alignas] = ACTIONS(2228),
    [sym_primitive_type] = ACTIONS(2228),
    [anon_sym_enum] = ACTIONS(2228),
    [anon_sym_class] = ACTIONS(2228),
    [anon_sym_struct] = ACTIONS(2228),
    [anon_sym_union] = ACTIONS(2228),
    [anon_sym_if] = ACTIONS(2228),
    [anon_sym_else] = ACTIONS(2228),
    [anon_sym_switch] = ACTIONS(2228),
    [anon_sym_while] = ACTIONS(2228),
    [anon_sym_do] = ACTIONS(2228),
    [anon_sym_for] = ACTIONS(2228),
    [anon_sym_return] = ACTIONS(2228),
    [anon_sym_break] = ACTIONS(2228),
    [anon_sym_continue] = ACTIONS(2228),
    [anon_sym_goto] = ACTIONS(2228),
    [anon_sym___try] = ACTIONS(2228),
    [anon_sym___leave] = ACTIONS(2228),
    [anon_sym_not] = ACTIONS(2228),
    [anon_sym_compl] = ACTIONS(2228),
    [anon_sym_DASH_DASH] = ACTIONS(2230),
    [anon_sym_PLUS_PLUS] = ACTIONS(2230),
    [anon_sym_sizeof] = ACTIONS(2228),
    [anon_sym___alignof__] = ACTIONS(2228),
    [anon_sym___alignof] = ACTIONS(2228),
    [anon_sym__alignof] = ACTIONS(2228),
    [anon_sym_alignof] = ACTIONS(2228),
    [anon_sym__Alignof] = ACTIONS(2228),
    [anon_sym_offsetof] = ACTIONS(2228),
    [anon_sym__Generic] = ACTIONS(2228),
    [anon_sym_asm] = ACTIONS(2228),
    [anon_sym___asm__] = ACTIONS(2228),
    [sym_number_literal] = ACTIONS(2230),
    [anon_sym_L_SQUOTE] = ACTIONS(2230),
    [anon_sym_u_SQUOTE] = ACTIONS(2230),
    [anon_sym_U_SQUOTE] = ACTIONS(2230),
    [anon_sym_u8_SQUOTE] = ACTIONS(2230),
    [anon_sym_SQUOTE] = ACTIONS(2230),
    [anon_sym_L_DQUOTE] = ACTIONS(2230),
    [anon_sym_u_DQUOTE] = ACTIONS(2230),
    [anon_sym_U_DQUOTE] = ACTIONS(2230),
    [anon_sym_u8_DQUOTE] = ACTIONS(2230),
    [anon_sym_DQUOTE] = ACTIONS(2230),
    [sym_true] = ACTIONS(2228),
    [sym_false] = ACTIONS(2228),
    [anon_sym_NULL] = ACTIONS(2228),
    [anon_sym_nullptr] = ACTIONS(2228),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2228),
    [anon_sym_decltype] = ACTIONS(2228),
    [sym_virtual] = ACTIONS(2228),
    [anon_sym_typename] = ACTIONS(2228),
    [anon_sym_template] = ACTIONS(2228),
    [anon_sym_try] = ACTIONS(2228),
    [anon_sym_delete] = ACTIONS(2228),
    [anon_sym_throw] = ACTIONS(2228),
    [anon_sym_co_return] = ACTIONS(2228),
    [anon_sym_co_yield] = ACTIONS(2228),
    [anon_sym_R_DQUOTE] = ACTIONS(2230),
    [anon_sym_LR_DQUOTE] = ACTIONS(2230),
    [anon_sym_uR_DQUOTE] = ACTIONS(2230),
    [anon_sym_UR_DQUOTE] = ACTIONS(2230),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2230),
    [anon_sym_co_await] = ACTIONS(2228),
    [anon_sym_new] = ACTIONS(2228),
    [anon_sym_requires] = ACTIONS(2228),
    [sym_this] = ACTIONS(2228),
    [anon_sym_discard] = ACTIONS(2228),
    [anon_sym_precise] = ACTIONS(2228),
    [anon_sym_shared] = ACTIONS(2228),
    [anon_sym_groupshared] = ACTIONS(2228),
    [anon_sym_uniform] = ACTIONS(2228),
    [anon_sym_row_major] = ACTIONS(2228),
    [anon_sym_column_major] = ACTIONS(2228),
    [anon_sym_globallycoherent] = ACTIONS(2228),
    [anon_sym_centroid] = ACTIONS(2228),
    [anon_sym_noperspective] = ACTIONS(2228),
    [anon_sym_nointerpolation] = ACTIONS(2228),
    [anon_sym_sample] = ACTIONS(2228),
    [anon_sym_linear] = ACTIONS(2228),
    [anon_sym_snorm] = ACTIONS(2228),
    [anon_sym_unorm] = ACTIONS(2228),
    [anon_sym_point] = ACTIONS(2228),
    [anon_sym_line] = ACTIONS(2228),
    [anon_sym_triangleadj] = ACTIONS(2228),
    [anon_sym_lineadj] = ACTIONS(2228),
    [anon_sym_triangle] = ACTIONS(2228),
    [anon_sym_cbuffer] = ACTIONS(2228),
  },
  [1048] = {
    [sym_identifier] = ACTIONS(2236),
    [anon_sym_LPAREN2] = ACTIONS(2238),
    [anon_sym_BANG] = ACTIONS(2238),
    [anon_sym_TILDE] = ACTIONS(2238),
    [anon_sym_DASH] = ACTIONS(2236),
    [anon_sym_PLUS] = ACTIONS(2236),
    [anon_sym_STAR] = ACTIONS(2238),
    [anon_sym_AMP] = ACTIONS(2238),
    [anon_sym_SEMI] = ACTIONS(2238),
    [anon_sym___extension__] = ACTIONS(2236),
    [anon_sym_typedef] = ACTIONS(2236),
    [anon_sym_in] = ACTIONS(2236),
    [anon_sym_out] = ACTIONS(2236),
    [anon_sym_inout] = ACTIONS(2236),
    [anon_sym_extern] = ACTIONS(2236),
    [anon_sym___attribute__] = ACTIONS(2236),
    [anon_sym_COLON_COLON] = ACTIONS(2238),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2238),
    [anon_sym___declspec] = ACTIONS(2236),
    [anon_sym_LBRACE] = ACTIONS(2238),
    [anon_sym_signed] = ACTIONS(2236),
    [anon_sym_unsigned] = ACTIONS(2236),
    [anon_sym_long] = ACTIONS(2236),
    [anon_sym_short] = ACTIONS(2236),
    [anon_sym_LBRACK] = ACTIONS(2236),
    [anon_sym_static] = ACTIONS(2236),
    [anon_sym_register] = ACTIONS(2236),
    [anon_sym_inline] = ACTIONS(2236),
    [anon_sym___inline] = ACTIONS(2236),
    [anon_sym___inline__] = ACTIONS(2236),
    [anon_sym___forceinline] = ACTIONS(2236),
    [anon_sym_thread_local] = ACTIONS(2236),
    [anon_sym___thread] = ACTIONS(2236),
    [anon_sym_const] = ACTIONS(2236),
    [anon_sym_constexpr] = ACTIONS(2236),
    [anon_sym_volatile] = ACTIONS(2236),
    [anon_sym_restrict] = ACTIONS(2236),
    [anon_sym___restrict__] = ACTIONS(2236),
    [anon_sym__Atomic] = ACTIONS(2236),
    [anon_sym__Noreturn] = ACTIONS(2236),
    [anon_sym_noreturn] = ACTIONS(2236),
    [anon_sym_mutable] = ACTIONS(2236),
    [anon_sym_constinit] = ACTIONS(2236),
    [anon_sym_consteval] = ACTIONS(2236),
    [anon_sym_alignas] = ACTIONS(2236),
    [anon_sym__Alignas] = ACTIONS(2236),
    [sym_primitive_type] = ACTIONS(2236),
    [anon_sym_enum] = ACTIONS(2236),
    [anon_sym_class] = ACTIONS(2236),
    [anon_sym_struct] = ACTIONS(2236),
    [anon_sym_union] = ACTIONS(2236),
    [anon_sym_if] = ACTIONS(2236),
    [anon_sym_else] = ACTIONS(2236),
    [anon_sym_switch] = ACTIONS(2236),
    [anon_sym_while] = ACTIONS(2236),
    [anon_sym_do] = ACTIONS(2236),
    [anon_sym_for] = ACTIONS(2236),
    [anon_sym_return] = ACTIONS(2236),
    [anon_sym_break] = ACTIONS(2236),
    [anon_sym_continue] = ACTIONS(2236),
    [anon_sym_goto] = ACTIONS(2236),
    [anon_sym___try] = ACTIONS(2236),
    [anon_sym___leave] = ACTIONS(2236),
    [anon_sym_not] = ACTIONS(2236),
    [anon_sym_compl] = ACTIONS(2236),
    [anon_sym_DASH_DASH] = ACTIONS(2238),
    [anon_sym_PLUS_PLUS] = ACTIONS(2238),
    [anon_sym_sizeof] = ACTIONS(2236),
    [anon_sym___alignof__] = ACTIONS(2236),
    [anon_sym___alignof] = ACTIONS(2236),
    [anon_sym__alignof] = ACTIONS(2236),
    [anon_sym_alignof] = ACTIONS(2236),
    [anon_sym__Alignof] = ACTIONS(2236),
    [anon_sym_offsetof] = ACTIONS(2236),
    [anon_sym__Generic] = ACTIONS(2236),
    [anon_sym_asm] = ACTIONS(2236),
    [anon_sym___asm__] = ACTIONS(2236),
    [sym_number_literal] = ACTIONS(2238),
    [anon_sym_L_SQUOTE] = ACTIONS(2238),
    [anon_sym_u_SQUOTE] = ACTIONS(2238),
    [anon_sym_U_SQUOTE] = ACTIONS(2238),
    [anon_sym_u8_SQUOTE] = ACTIONS(2238),
    [anon_sym_SQUOTE] = ACTIONS(2238),
    [anon_sym_L_DQUOTE] = ACTIONS(2238),
    [anon_sym_u_DQUOTE] = ACTIONS(2238),
    [anon_sym_U_DQUOTE] = ACTIONS(2238),
    [anon_sym_u8_DQUOTE] = ACTIONS(2238),
    [anon_sym_DQUOTE] = ACTIONS(2238),
    [sym_true] = ACTIONS(2236),
    [sym_false] = ACTIONS(2236),
    [anon_sym_NULL] = ACTIONS(2236),
    [anon_sym_nullptr] = ACTIONS(2236),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2236),
    [anon_sym_decltype] = ACTIONS(2236),
    [sym_virtual] = ACTIONS(2236),
    [anon_sym_typename] = ACTIONS(2236),
    [anon_sym_template] = ACTIONS(2236),
    [anon_sym_try] = ACTIONS(2236),
    [anon_sym_delete] = ACTIONS(2236),
    [anon_sym_throw] = ACTIONS(2236),
    [anon_sym_co_return] = ACTIONS(2236),
    [anon_sym_co_yield] = ACTIONS(2236),
    [anon_sym_R_DQUOTE] = ACTIONS(2238),
    [anon_sym_LR_DQUOTE] = ACTIONS(2238),
    [anon_sym_uR_DQUOTE] = ACTIONS(2238),
    [anon_sym_UR_DQUOTE] = ACTIONS(2238),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2238),
    [anon_sym_co_await] = ACTIONS(2236),
    [anon_sym_new] = ACTIONS(2236),
    [anon_sym_requires] = ACTIONS(2236),
    [sym_this] = ACTIONS(2236),
    [anon_sym_discard] = ACTIONS(2236),
    [anon_sym_precise] = ACTIONS(2236),
    [anon_sym_shared] = ACTIONS(2236),
    [anon_sym_groupshared] = ACTIONS(2236),
    [anon_sym_uniform] = ACTIONS(2236),
    [anon_sym_row_major] = ACTIONS(2236),
    [anon_sym_column_major] = ACTIONS(2236),
    [anon_sym_globallycoherent] = ACTIONS(2236),
    [anon_sym_centroid] = ACTIONS(2236),
    [anon_sym_noperspective] = ACTIONS(2236),
    [anon_sym_nointerpolation] = ACTIONS(2236),
    [anon_sym_sample] = ACTIONS(2236),
    [anon_sym_linear] = ACTIONS(2236),
    [anon_sym_snorm] = ACTIONS(2236),
    [anon_sym_unorm] = ACTIONS(2236),
    [anon_sym_point] = ACTIONS(2236),
    [anon_sym_line] = ACTIONS(2236),
    [anon_sym_triangleadj] = ACTIONS(2236),
    [anon_sym_lineadj] = ACTIONS(2236),
    [anon_sym_triangle] = ACTIONS(2236),
    [anon_sym_cbuffer] = ACTIONS(2236),
  },
  [1049] = {
    [sym_identifier] = ACTIONS(2288),
    [anon_sym_LPAREN2] = ACTIONS(2290),
    [anon_sym_BANG] = ACTIONS(2290),
    [anon_sym_TILDE] = ACTIONS(2290),
    [anon_sym_DASH] = ACTIONS(2288),
    [anon_sym_PLUS] = ACTIONS(2288),
    [anon_sym_STAR] = ACTIONS(2290),
    [anon_sym_AMP] = ACTIONS(2290),
    [anon_sym_SEMI] = ACTIONS(2290),
    [anon_sym___extension__] = ACTIONS(2288),
    [anon_sym_typedef] = ACTIONS(2288),
    [anon_sym_in] = ACTIONS(2288),
    [anon_sym_out] = ACTIONS(2288),
    [anon_sym_inout] = ACTIONS(2288),
    [anon_sym_extern] = ACTIONS(2288),
    [anon_sym___attribute__] = ACTIONS(2288),
    [anon_sym_COLON_COLON] = ACTIONS(2290),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2290),
    [anon_sym___declspec] = ACTIONS(2288),
    [anon_sym_LBRACE] = ACTIONS(2290),
    [anon_sym_signed] = ACTIONS(2288),
    [anon_sym_unsigned] = ACTIONS(2288),
    [anon_sym_long] = ACTIONS(2288),
    [anon_sym_short] = ACTIONS(2288),
    [anon_sym_LBRACK] = ACTIONS(2288),
    [anon_sym_static] = ACTIONS(2288),
    [anon_sym_register] = ACTIONS(2288),
    [anon_sym_inline] = ACTIONS(2288),
    [anon_sym___inline] = ACTIONS(2288),
    [anon_sym___inline__] = ACTIONS(2288),
    [anon_sym___forceinline] = ACTIONS(2288),
    [anon_sym_thread_local] = ACTIONS(2288),
    [anon_sym___thread] = ACTIONS(2288),
    [anon_sym_const] = ACTIONS(2288),
    [anon_sym_constexpr] = ACTIONS(2288),
    [anon_sym_volatile] = ACTIONS(2288),
    [anon_sym_restrict] = ACTIONS(2288),
    [anon_sym___restrict__] = ACTIONS(2288),
    [anon_sym__Atomic] = ACTIONS(2288),
    [anon_sym__Noreturn] = ACTIONS(2288),
    [anon_sym_noreturn] = ACTIONS(2288),
    [anon_sym_mutable] = ACTIONS(2288),
    [anon_sym_constinit] = ACTIONS(2288),
    [anon_sym_consteval] = ACTIONS(2288),
    [anon_sym_alignas] = ACTIONS(2288),
    [anon_sym__Alignas] = ACTIONS(2288),
    [sym_primitive_type] = ACTIONS(2288),
    [anon_sym_enum] = ACTIONS(2288),
    [anon_sym_class] = ACTIONS(2288),
    [anon_sym_struct] = ACTIONS(2288),
    [anon_sym_union] = ACTIONS(2288),
    [anon_sym_if] = ACTIONS(2288),
    [anon_sym_else] = ACTIONS(2288),
    [anon_sym_switch] = ACTIONS(2288),
    [anon_sym_while] = ACTIONS(2288),
    [anon_sym_do] = ACTIONS(2288),
    [anon_sym_for] = ACTIONS(2288),
    [anon_sym_return] = ACTIONS(2288),
    [anon_sym_break] = ACTIONS(2288),
    [anon_sym_continue] = ACTIONS(2288),
    [anon_sym_goto] = ACTIONS(2288),
    [anon_sym___try] = ACTIONS(2288),
    [anon_sym___leave] = ACTIONS(2288),
    [anon_sym_not] = ACTIONS(2288),
    [anon_sym_compl] = ACTIONS(2288),
    [anon_sym_DASH_DASH] = ACTIONS(2290),
    [anon_sym_PLUS_PLUS] = ACTIONS(2290),
    [anon_sym_sizeof] = ACTIONS(2288),
    [anon_sym___alignof__] = ACTIONS(2288),
    [anon_sym___alignof] = ACTIONS(2288),
    [anon_sym__alignof] = ACTIONS(2288),
    [anon_sym_alignof] = ACTIONS(2288),
    [anon_sym__Alignof] = ACTIONS(2288),
    [anon_sym_offsetof] = ACTIONS(2288),
    [anon_sym__Generic] = ACTIONS(2288),
    [anon_sym_asm] = ACTIONS(2288),
    [anon_sym___asm__] = ACTIONS(2288),
    [sym_number_literal] = ACTIONS(2290),
    [anon_sym_L_SQUOTE] = ACTIONS(2290),
    [anon_sym_u_SQUOTE] = ACTIONS(2290),
    [anon_sym_U_SQUOTE] = ACTIONS(2290),
    [anon_sym_u8_SQUOTE] = ACTIONS(2290),
    [anon_sym_SQUOTE] = ACTIONS(2290),
    [anon_sym_L_DQUOTE] = ACTIONS(2290),
    [anon_sym_u_DQUOTE] = ACTIONS(2290),
    [anon_sym_U_DQUOTE] = ACTIONS(2290),
    [anon_sym_u8_DQUOTE] = ACTIONS(2290),
    [anon_sym_DQUOTE] = ACTIONS(2290),
    [sym_true] = ACTIONS(2288),
    [sym_false] = ACTIONS(2288),
    [anon_sym_NULL] = ACTIONS(2288),
    [anon_sym_nullptr] = ACTIONS(2288),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2288),
    [anon_sym_decltype] = ACTIONS(2288),
    [sym_virtual] = ACTIONS(2288),
    [anon_sym_typename] = ACTIONS(2288),
    [anon_sym_template] = ACTIONS(2288),
    [anon_sym_try] = ACTIONS(2288),
    [anon_sym_delete] = ACTIONS(2288),
    [anon_sym_throw] = ACTIONS(2288),
    [anon_sym_co_return] = ACTIONS(2288),
    [anon_sym_co_yield] = ACTIONS(2288),
    [anon_sym_R_DQUOTE] = ACTIONS(2290),
    [anon_sym_LR_DQUOTE] = ACTIONS(2290),
    [anon_sym_uR_DQUOTE] = ACTIONS(2290),
    [anon_sym_UR_DQUOTE] = ACTIONS(2290),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2290),
    [anon_sym_co_await] = ACTIONS(2288),
    [anon_sym_new] = ACTIONS(2288),
    [anon_sym_requires] = ACTIONS(2288),
    [sym_this] = ACTIONS(2288),
    [anon_sym_discard] = ACTIONS(2288),
    [anon_sym_precise] = ACTIONS(2288),
    [anon_sym_shared] = ACTIONS(2288),
    [anon_sym_groupshared] = ACTIONS(2288),
    [anon_sym_uniform] = ACTIONS(2288),
    [anon_sym_row_major] = ACTIONS(2288),
    [anon_sym_column_major] = ACTIONS(2288),
    [anon_sym_globallycoherent] = ACTIONS(2288),
    [anon_sym_centroid] = ACTIONS(2288),
    [anon_sym_noperspective] = ACTIONS(2288),
    [anon_sym_nointerpolation] = ACTIONS(2288),
    [anon_sym_sample] = ACTIONS(2288),
    [anon_sym_linear] = ACTIONS(2288),
    [anon_sym_snorm] = ACTIONS(2288),
    [anon_sym_unorm] = ACTIONS(2288),
    [anon_sym_point] = ACTIONS(2288),
    [anon_sym_line] = ACTIONS(2288),
    [anon_sym_triangleadj] = ACTIONS(2288),
    [anon_sym_lineadj] = ACTIONS(2288),
    [anon_sym_triangle] = ACTIONS(2288),
    [anon_sym_cbuffer] = ACTIONS(2288),
  },
  [1050] = {
    [sym_identifier] = ACTIONS(2106),
    [anon_sym_LPAREN2] = ACTIONS(2108),
    [anon_sym_BANG] = ACTIONS(2108),
    [anon_sym_TILDE] = ACTIONS(2108),
    [anon_sym_DASH] = ACTIONS(2106),
    [anon_sym_PLUS] = ACTIONS(2106),
    [anon_sym_STAR] = ACTIONS(2108),
    [anon_sym_AMP] = ACTIONS(2108),
    [anon_sym_SEMI] = ACTIONS(2108),
    [anon_sym___extension__] = ACTIONS(2106),
    [anon_sym_typedef] = ACTIONS(2106),
    [anon_sym_in] = ACTIONS(2106),
    [anon_sym_out] = ACTIONS(2106),
    [anon_sym_inout] = ACTIONS(2106),
    [anon_sym_extern] = ACTIONS(2106),
    [anon_sym___attribute__] = ACTIONS(2106),
    [anon_sym_COLON_COLON] = ACTIONS(2108),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2108),
    [anon_sym___declspec] = ACTIONS(2106),
    [anon_sym_LBRACE] = ACTIONS(2108),
    [anon_sym_signed] = ACTIONS(2106),
    [anon_sym_unsigned] = ACTIONS(2106),
    [anon_sym_long] = ACTIONS(2106),
    [anon_sym_short] = ACTIONS(2106),
    [anon_sym_LBRACK] = ACTIONS(2106),
    [anon_sym_static] = ACTIONS(2106),
    [anon_sym_register] = ACTIONS(2106),
    [anon_sym_inline] = ACTIONS(2106),
    [anon_sym___inline] = ACTIONS(2106),
    [anon_sym___inline__] = ACTIONS(2106),
    [anon_sym___forceinline] = ACTIONS(2106),
    [anon_sym_thread_local] = ACTIONS(2106),
    [anon_sym___thread] = ACTIONS(2106),
    [anon_sym_const] = ACTIONS(2106),
    [anon_sym_constexpr] = ACTIONS(2106),
    [anon_sym_volatile] = ACTIONS(2106),
    [anon_sym_restrict] = ACTIONS(2106),
    [anon_sym___restrict__] = ACTIONS(2106),
    [anon_sym__Atomic] = ACTIONS(2106),
    [anon_sym__Noreturn] = ACTIONS(2106),
    [anon_sym_noreturn] = ACTIONS(2106),
    [anon_sym_mutable] = ACTIONS(2106),
    [anon_sym_constinit] = ACTIONS(2106),
    [anon_sym_consteval] = ACTIONS(2106),
    [anon_sym_alignas] = ACTIONS(2106),
    [anon_sym__Alignas] = ACTIONS(2106),
    [sym_primitive_type] = ACTIONS(2106),
    [anon_sym_enum] = ACTIONS(2106),
    [anon_sym_class] = ACTIONS(2106),
    [anon_sym_struct] = ACTIONS(2106),
    [anon_sym_union] = ACTIONS(2106),
    [anon_sym_if] = ACTIONS(2106),
    [anon_sym_else] = ACTIONS(2106),
    [anon_sym_switch] = ACTIONS(2106),
    [anon_sym_while] = ACTIONS(2106),
    [anon_sym_do] = ACTIONS(2106),
    [anon_sym_for] = ACTIONS(2106),
    [anon_sym_return] = ACTIONS(2106),
    [anon_sym_break] = ACTIONS(2106),
    [anon_sym_continue] = ACTIONS(2106),
    [anon_sym_goto] = ACTIONS(2106),
    [anon_sym___try] = ACTIONS(2106),
    [anon_sym___leave] = ACTIONS(2106),
    [anon_sym_not] = ACTIONS(2106),
    [anon_sym_compl] = ACTIONS(2106),
    [anon_sym_DASH_DASH] = ACTIONS(2108),
    [anon_sym_PLUS_PLUS] = ACTIONS(2108),
    [anon_sym_sizeof] = ACTIONS(2106),
    [anon_sym___alignof__] = ACTIONS(2106),
    [anon_sym___alignof] = ACTIONS(2106),
    [anon_sym__alignof] = ACTIONS(2106),
    [anon_sym_alignof] = ACTIONS(2106),
    [anon_sym__Alignof] = ACTIONS(2106),
    [anon_sym_offsetof] = ACTIONS(2106),
    [anon_sym__Generic] = ACTIONS(2106),
    [anon_sym_asm] = ACTIONS(2106),
    [anon_sym___asm__] = ACTIONS(2106),
    [sym_number_literal] = ACTIONS(2108),
    [anon_sym_L_SQUOTE] = ACTIONS(2108),
    [anon_sym_u_SQUOTE] = ACTIONS(2108),
    [anon_sym_U_SQUOTE] = ACTIONS(2108),
    [anon_sym_u8_SQUOTE] = ACTIONS(2108),
    [anon_sym_SQUOTE] = ACTIONS(2108),
    [anon_sym_L_DQUOTE] = ACTIONS(2108),
    [anon_sym_u_DQUOTE] = ACTIONS(2108),
    [anon_sym_U_DQUOTE] = ACTIONS(2108),
    [anon_sym_u8_DQUOTE] = ACTIONS(2108),
    [anon_sym_DQUOTE] = ACTIONS(2108),
    [sym_true] = ACTIONS(2106),
    [sym_false] = ACTIONS(2106),
    [anon_sym_NULL] = ACTIONS(2106),
    [anon_sym_nullptr] = ACTIONS(2106),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2106),
    [anon_sym_decltype] = ACTIONS(2106),
    [sym_virtual] = ACTIONS(2106),
    [anon_sym_typename] = ACTIONS(2106),
    [anon_sym_template] = ACTIONS(2106),
    [anon_sym_try] = ACTIONS(2106),
    [anon_sym_delete] = ACTIONS(2106),
    [anon_sym_throw] = ACTIONS(2106),
    [anon_sym_co_return] = ACTIONS(2106),
    [anon_sym_co_yield] = ACTIONS(2106),
    [anon_sym_R_DQUOTE] = ACTIONS(2108),
    [anon_sym_LR_DQUOTE] = ACTIONS(2108),
    [anon_sym_uR_DQUOTE] = ACTIONS(2108),
    [anon_sym_UR_DQUOTE] = ACTIONS(2108),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2108),
    [anon_sym_co_await] = ACTIONS(2106),
    [anon_sym_new] = ACTIONS(2106),
    [anon_sym_requires] = ACTIONS(2106),
    [sym_this] = ACTIONS(2106),
    [anon_sym_discard] = ACTIONS(2106),
    [anon_sym_precise] = ACTIONS(2106),
    [anon_sym_shared] = ACTIONS(2106),
    [anon_sym_groupshared] = ACTIONS(2106),
    [anon_sym_uniform] = ACTIONS(2106),
    [anon_sym_row_major] = ACTIONS(2106),
    [anon_sym_column_major] = ACTIONS(2106),
    [anon_sym_globallycoherent] = ACTIONS(2106),
    [anon_sym_centroid] = ACTIONS(2106),
    [anon_sym_noperspective] = ACTIONS(2106),
    [anon_sym_nointerpolation] = ACTIONS(2106),
    [anon_sym_sample] = ACTIONS(2106),
    [anon_sym_linear] = ACTIONS(2106),
    [anon_sym_snorm] = ACTIONS(2106),
    [anon_sym_unorm] = ACTIONS(2106),
    [anon_sym_point] = ACTIONS(2106),
    [anon_sym_line] = ACTIONS(2106),
    [anon_sym_triangleadj] = ACTIONS(2106),
    [anon_sym_lineadj] = ACTIONS(2106),
    [anon_sym_triangle] = ACTIONS(2106),
    [anon_sym_cbuffer] = ACTIONS(2106),
  },
  [1051] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(4591),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_type_descriptor] = STATE(8211),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5574),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3922),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3924),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1052] = {
    [sym_identifier] = ACTIONS(2232),
    [anon_sym_LPAREN2] = ACTIONS(2234),
    [anon_sym_BANG] = ACTIONS(2234),
    [anon_sym_TILDE] = ACTIONS(2234),
    [anon_sym_DASH] = ACTIONS(2232),
    [anon_sym_PLUS] = ACTIONS(2232),
    [anon_sym_STAR] = ACTIONS(2234),
    [anon_sym_AMP] = ACTIONS(2234),
    [anon_sym_SEMI] = ACTIONS(2234),
    [anon_sym___extension__] = ACTIONS(2232),
    [anon_sym_typedef] = ACTIONS(2232),
    [anon_sym_in] = ACTIONS(2232),
    [anon_sym_out] = ACTIONS(2232),
    [anon_sym_inout] = ACTIONS(2232),
    [anon_sym_extern] = ACTIONS(2232),
    [anon_sym___attribute__] = ACTIONS(2232),
    [anon_sym_COLON_COLON] = ACTIONS(2234),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2234),
    [anon_sym___declspec] = ACTIONS(2232),
    [anon_sym_LBRACE] = ACTIONS(2234),
    [anon_sym_signed] = ACTIONS(2232),
    [anon_sym_unsigned] = ACTIONS(2232),
    [anon_sym_long] = ACTIONS(2232),
    [anon_sym_short] = ACTIONS(2232),
    [anon_sym_LBRACK] = ACTIONS(2232),
    [anon_sym_static] = ACTIONS(2232),
    [anon_sym_register] = ACTIONS(2232),
    [anon_sym_inline] = ACTIONS(2232),
    [anon_sym___inline] = ACTIONS(2232),
    [anon_sym___inline__] = ACTIONS(2232),
    [anon_sym___forceinline] = ACTIONS(2232),
    [anon_sym_thread_local] = ACTIONS(2232),
    [anon_sym___thread] = ACTIONS(2232),
    [anon_sym_const] = ACTIONS(2232),
    [anon_sym_constexpr] = ACTIONS(2232),
    [anon_sym_volatile] = ACTIONS(2232),
    [anon_sym_restrict] = ACTIONS(2232),
    [anon_sym___restrict__] = ACTIONS(2232),
    [anon_sym__Atomic] = ACTIONS(2232),
    [anon_sym__Noreturn] = ACTIONS(2232),
    [anon_sym_noreturn] = ACTIONS(2232),
    [anon_sym_mutable] = ACTIONS(2232),
    [anon_sym_constinit] = ACTIONS(2232),
    [anon_sym_consteval] = ACTIONS(2232),
    [anon_sym_alignas] = ACTIONS(2232),
    [anon_sym__Alignas] = ACTIONS(2232),
    [sym_primitive_type] = ACTIONS(2232),
    [anon_sym_enum] = ACTIONS(2232),
    [anon_sym_class] = ACTIONS(2232),
    [anon_sym_struct] = ACTIONS(2232),
    [anon_sym_union] = ACTIONS(2232),
    [anon_sym_if] = ACTIONS(2232),
    [anon_sym_else] = ACTIONS(2232),
    [anon_sym_switch] = ACTIONS(2232),
    [anon_sym_while] = ACTIONS(2232),
    [anon_sym_do] = ACTIONS(2232),
    [anon_sym_for] = ACTIONS(2232),
    [anon_sym_return] = ACTIONS(2232),
    [anon_sym_break] = ACTIONS(2232),
    [anon_sym_continue] = ACTIONS(2232),
    [anon_sym_goto] = ACTIONS(2232),
    [anon_sym___try] = ACTIONS(2232),
    [anon_sym___leave] = ACTIONS(2232),
    [anon_sym_not] = ACTIONS(2232),
    [anon_sym_compl] = ACTIONS(2232),
    [anon_sym_DASH_DASH] = ACTIONS(2234),
    [anon_sym_PLUS_PLUS] = ACTIONS(2234),
    [anon_sym_sizeof] = ACTIONS(2232),
    [anon_sym___alignof__] = ACTIONS(2232),
    [anon_sym___alignof] = ACTIONS(2232),
    [anon_sym__alignof] = ACTIONS(2232),
    [anon_sym_alignof] = ACTIONS(2232),
    [anon_sym__Alignof] = ACTIONS(2232),
    [anon_sym_offsetof] = ACTIONS(2232),
    [anon_sym__Generic] = ACTIONS(2232),
    [anon_sym_asm] = ACTIONS(2232),
    [anon_sym___asm__] = ACTIONS(2232),
    [sym_number_literal] = ACTIONS(2234),
    [anon_sym_L_SQUOTE] = ACTIONS(2234),
    [anon_sym_u_SQUOTE] = ACTIONS(2234),
    [anon_sym_U_SQUOTE] = ACTIONS(2234),
    [anon_sym_u8_SQUOTE] = ACTIONS(2234),
    [anon_sym_SQUOTE] = ACTIONS(2234),
    [anon_sym_L_DQUOTE] = ACTIONS(2234),
    [anon_sym_u_DQUOTE] = ACTIONS(2234),
    [anon_sym_U_DQUOTE] = ACTIONS(2234),
    [anon_sym_u8_DQUOTE] = ACTIONS(2234),
    [anon_sym_DQUOTE] = ACTIONS(2234),
    [sym_true] = ACTIONS(2232),
    [sym_false] = ACTIONS(2232),
    [anon_sym_NULL] = ACTIONS(2232),
    [anon_sym_nullptr] = ACTIONS(2232),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2232),
    [anon_sym_decltype] = ACTIONS(2232),
    [sym_virtual] = ACTIONS(2232),
    [anon_sym_typename] = ACTIONS(2232),
    [anon_sym_template] = ACTIONS(2232),
    [anon_sym_try] = ACTIONS(2232),
    [anon_sym_delete] = ACTIONS(2232),
    [anon_sym_throw] = ACTIONS(2232),
    [anon_sym_co_return] = ACTIONS(2232),
    [anon_sym_co_yield] = ACTIONS(2232),
    [anon_sym_R_DQUOTE] = ACTIONS(2234),
    [anon_sym_LR_DQUOTE] = ACTIONS(2234),
    [anon_sym_uR_DQUOTE] = ACTIONS(2234),
    [anon_sym_UR_DQUOTE] = ACTIONS(2234),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2234),
    [anon_sym_co_await] = ACTIONS(2232),
    [anon_sym_new] = ACTIONS(2232),
    [anon_sym_requires] = ACTIONS(2232),
    [sym_this] = ACTIONS(2232),
    [anon_sym_discard] = ACTIONS(2232),
    [anon_sym_precise] = ACTIONS(2232),
    [anon_sym_shared] = ACTIONS(2232),
    [anon_sym_groupshared] = ACTIONS(2232),
    [anon_sym_uniform] = ACTIONS(2232),
    [anon_sym_row_major] = ACTIONS(2232),
    [anon_sym_column_major] = ACTIONS(2232),
    [anon_sym_globallycoherent] = ACTIONS(2232),
    [anon_sym_centroid] = ACTIONS(2232),
    [anon_sym_noperspective] = ACTIONS(2232),
    [anon_sym_nointerpolation] = ACTIONS(2232),
    [anon_sym_sample] = ACTIONS(2232),
    [anon_sym_linear] = ACTIONS(2232),
    [anon_sym_snorm] = ACTIONS(2232),
    [anon_sym_unorm] = ACTIONS(2232),
    [anon_sym_point] = ACTIONS(2232),
    [anon_sym_line] = ACTIONS(2232),
    [anon_sym_triangleadj] = ACTIONS(2232),
    [anon_sym_lineadj] = ACTIONS(2232),
    [anon_sym_triangle] = ACTIONS(2232),
    [anon_sym_cbuffer] = ACTIONS(2232),
  },
  [1053] = {
    [sym_identifier] = ACTIONS(2244),
    [anon_sym_LPAREN2] = ACTIONS(2246),
    [anon_sym_BANG] = ACTIONS(2246),
    [anon_sym_TILDE] = ACTIONS(2246),
    [anon_sym_DASH] = ACTIONS(2244),
    [anon_sym_PLUS] = ACTIONS(2244),
    [anon_sym_STAR] = ACTIONS(2246),
    [anon_sym_AMP] = ACTIONS(2246),
    [anon_sym_SEMI] = ACTIONS(2246),
    [anon_sym___extension__] = ACTIONS(2244),
    [anon_sym_typedef] = ACTIONS(2244),
    [anon_sym_in] = ACTIONS(2244),
    [anon_sym_out] = ACTIONS(2244),
    [anon_sym_inout] = ACTIONS(2244),
    [anon_sym_extern] = ACTIONS(2244),
    [anon_sym___attribute__] = ACTIONS(2244),
    [anon_sym_COLON_COLON] = ACTIONS(2246),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2246),
    [anon_sym___declspec] = ACTIONS(2244),
    [anon_sym_LBRACE] = ACTIONS(2246),
    [anon_sym_signed] = ACTIONS(2244),
    [anon_sym_unsigned] = ACTIONS(2244),
    [anon_sym_long] = ACTIONS(2244),
    [anon_sym_short] = ACTIONS(2244),
    [anon_sym_LBRACK] = ACTIONS(2244),
    [anon_sym_static] = ACTIONS(2244),
    [anon_sym_register] = ACTIONS(2244),
    [anon_sym_inline] = ACTIONS(2244),
    [anon_sym___inline] = ACTIONS(2244),
    [anon_sym___inline__] = ACTIONS(2244),
    [anon_sym___forceinline] = ACTIONS(2244),
    [anon_sym_thread_local] = ACTIONS(2244),
    [anon_sym___thread] = ACTIONS(2244),
    [anon_sym_const] = ACTIONS(2244),
    [anon_sym_constexpr] = ACTIONS(2244),
    [anon_sym_volatile] = ACTIONS(2244),
    [anon_sym_restrict] = ACTIONS(2244),
    [anon_sym___restrict__] = ACTIONS(2244),
    [anon_sym__Atomic] = ACTIONS(2244),
    [anon_sym__Noreturn] = ACTIONS(2244),
    [anon_sym_noreturn] = ACTIONS(2244),
    [anon_sym_mutable] = ACTIONS(2244),
    [anon_sym_constinit] = ACTIONS(2244),
    [anon_sym_consteval] = ACTIONS(2244),
    [anon_sym_alignas] = ACTIONS(2244),
    [anon_sym__Alignas] = ACTIONS(2244),
    [sym_primitive_type] = ACTIONS(2244),
    [anon_sym_enum] = ACTIONS(2244),
    [anon_sym_class] = ACTIONS(2244),
    [anon_sym_struct] = ACTIONS(2244),
    [anon_sym_union] = ACTIONS(2244),
    [anon_sym_if] = ACTIONS(2244),
    [anon_sym_else] = ACTIONS(2244),
    [anon_sym_switch] = ACTIONS(2244),
    [anon_sym_while] = ACTIONS(2244),
    [anon_sym_do] = ACTIONS(2244),
    [anon_sym_for] = ACTIONS(2244),
    [anon_sym_return] = ACTIONS(2244),
    [anon_sym_break] = ACTIONS(2244),
    [anon_sym_continue] = ACTIONS(2244),
    [anon_sym_goto] = ACTIONS(2244),
    [anon_sym___try] = ACTIONS(2244),
    [anon_sym___leave] = ACTIONS(2244),
    [anon_sym_not] = ACTIONS(2244),
    [anon_sym_compl] = ACTIONS(2244),
    [anon_sym_DASH_DASH] = ACTIONS(2246),
    [anon_sym_PLUS_PLUS] = ACTIONS(2246),
    [anon_sym_sizeof] = ACTIONS(2244),
    [anon_sym___alignof__] = ACTIONS(2244),
    [anon_sym___alignof] = ACTIONS(2244),
    [anon_sym__alignof] = ACTIONS(2244),
    [anon_sym_alignof] = ACTIONS(2244),
    [anon_sym__Alignof] = ACTIONS(2244),
    [anon_sym_offsetof] = ACTIONS(2244),
    [anon_sym__Generic] = ACTIONS(2244),
    [anon_sym_asm] = ACTIONS(2244),
    [anon_sym___asm__] = ACTIONS(2244),
    [sym_number_literal] = ACTIONS(2246),
    [anon_sym_L_SQUOTE] = ACTIONS(2246),
    [anon_sym_u_SQUOTE] = ACTIONS(2246),
    [anon_sym_U_SQUOTE] = ACTIONS(2246),
    [anon_sym_u8_SQUOTE] = ACTIONS(2246),
    [anon_sym_SQUOTE] = ACTIONS(2246),
    [anon_sym_L_DQUOTE] = ACTIONS(2246),
    [anon_sym_u_DQUOTE] = ACTIONS(2246),
    [anon_sym_U_DQUOTE] = ACTIONS(2246),
    [anon_sym_u8_DQUOTE] = ACTIONS(2246),
    [anon_sym_DQUOTE] = ACTIONS(2246),
    [sym_true] = ACTIONS(2244),
    [sym_false] = ACTIONS(2244),
    [anon_sym_NULL] = ACTIONS(2244),
    [anon_sym_nullptr] = ACTIONS(2244),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2244),
    [anon_sym_decltype] = ACTIONS(2244),
    [sym_virtual] = ACTIONS(2244),
    [anon_sym_typename] = ACTIONS(2244),
    [anon_sym_template] = ACTIONS(2244),
    [anon_sym_try] = ACTIONS(2244),
    [anon_sym_delete] = ACTIONS(2244),
    [anon_sym_throw] = ACTIONS(2244),
    [anon_sym_co_return] = ACTIONS(2244),
    [anon_sym_co_yield] = ACTIONS(2244),
    [anon_sym_R_DQUOTE] = ACTIONS(2246),
    [anon_sym_LR_DQUOTE] = ACTIONS(2246),
    [anon_sym_uR_DQUOTE] = ACTIONS(2246),
    [anon_sym_UR_DQUOTE] = ACTIONS(2246),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2246),
    [anon_sym_co_await] = ACTIONS(2244),
    [anon_sym_new] = ACTIONS(2244),
    [anon_sym_requires] = ACTIONS(2244),
    [sym_this] = ACTIONS(2244),
    [anon_sym_discard] = ACTIONS(2244),
    [anon_sym_precise] = ACTIONS(2244),
    [anon_sym_shared] = ACTIONS(2244),
    [anon_sym_groupshared] = ACTIONS(2244),
    [anon_sym_uniform] = ACTIONS(2244),
    [anon_sym_row_major] = ACTIONS(2244),
    [anon_sym_column_major] = ACTIONS(2244),
    [anon_sym_globallycoherent] = ACTIONS(2244),
    [anon_sym_centroid] = ACTIONS(2244),
    [anon_sym_noperspective] = ACTIONS(2244),
    [anon_sym_nointerpolation] = ACTIONS(2244),
    [anon_sym_sample] = ACTIONS(2244),
    [anon_sym_linear] = ACTIONS(2244),
    [anon_sym_snorm] = ACTIONS(2244),
    [anon_sym_unorm] = ACTIONS(2244),
    [anon_sym_point] = ACTIONS(2244),
    [anon_sym_line] = ACTIONS(2244),
    [anon_sym_triangleadj] = ACTIONS(2244),
    [anon_sym_lineadj] = ACTIONS(2244),
    [anon_sym_triangle] = ACTIONS(2244),
    [anon_sym_cbuffer] = ACTIONS(2244),
  },
  [1054] = {
    [sym_identifier] = ACTIONS(2110),
    [anon_sym_LPAREN2] = ACTIONS(2112),
    [anon_sym_BANG] = ACTIONS(2112),
    [anon_sym_TILDE] = ACTIONS(2112),
    [anon_sym_DASH] = ACTIONS(2110),
    [anon_sym_PLUS] = ACTIONS(2110),
    [anon_sym_STAR] = ACTIONS(2112),
    [anon_sym_AMP] = ACTIONS(2112),
    [anon_sym_SEMI] = ACTIONS(2112),
    [anon_sym___extension__] = ACTIONS(2110),
    [anon_sym_typedef] = ACTIONS(2110),
    [anon_sym_in] = ACTIONS(2110),
    [anon_sym_out] = ACTIONS(2110),
    [anon_sym_inout] = ACTIONS(2110),
    [anon_sym_extern] = ACTIONS(2110),
    [anon_sym___attribute__] = ACTIONS(2110),
    [anon_sym_COLON_COLON] = ACTIONS(2112),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2112),
    [anon_sym___declspec] = ACTIONS(2110),
    [anon_sym_LBRACE] = ACTIONS(2112),
    [anon_sym_signed] = ACTIONS(2110),
    [anon_sym_unsigned] = ACTIONS(2110),
    [anon_sym_long] = ACTIONS(2110),
    [anon_sym_short] = ACTIONS(2110),
    [anon_sym_LBRACK] = ACTIONS(2110),
    [anon_sym_static] = ACTIONS(2110),
    [anon_sym_register] = ACTIONS(2110),
    [anon_sym_inline] = ACTIONS(2110),
    [anon_sym___inline] = ACTIONS(2110),
    [anon_sym___inline__] = ACTIONS(2110),
    [anon_sym___forceinline] = ACTIONS(2110),
    [anon_sym_thread_local] = ACTIONS(2110),
    [anon_sym___thread] = ACTIONS(2110),
    [anon_sym_const] = ACTIONS(2110),
    [anon_sym_constexpr] = ACTIONS(2110),
    [anon_sym_volatile] = ACTIONS(2110),
    [anon_sym_restrict] = ACTIONS(2110),
    [anon_sym___restrict__] = ACTIONS(2110),
    [anon_sym__Atomic] = ACTIONS(2110),
    [anon_sym__Noreturn] = ACTIONS(2110),
    [anon_sym_noreturn] = ACTIONS(2110),
    [anon_sym_mutable] = ACTIONS(2110),
    [anon_sym_constinit] = ACTIONS(2110),
    [anon_sym_consteval] = ACTIONS(2110),
    [anon_sym_alignas] = ACTIONS(2110),
    [anon_sym__Alignas] = ACTIONS(2110),
    [sym_primitive_type] = ACTIONS(2110),
    [anon_sym_enum] = ACTIONS(2110),
    [anon_sym_class] = ACTIONS(2110),
    [anon_sym_struct] = ACTIONS(2110),
    [anon_sym_union] = ACTIONS(2110),
    [anon_sym_if] = ACTIONS(2110),
    [anon_sym_else] = ACTIONS(2110),
    [anon_sym_switch] = ACTIONS(2110),
    [anon_sym_while] = ACTIONS(2110),
    [anon_sym_do] = ACTIONS(2110),
    [anon_sym_for] = ACTIONS(2110),
    [anon_sym_return] = ACTIONS(2110),
    [anon_sym_break] = ACTIONS(2110),
    [anon_sym_continue] = ACTIONS(2110),
    [anon_sym_goto] = ACTIONS(2110),
    [anon_sym___try] = ACTIONS(2110),
    [anon_sym___leave] = ACTIONS(2110),
    [anon_sym_not] = ACTIONS(2110),
    [anon_sym_compl] = ACTIONS(2110),
    [anon_sym_DASH_DASH] = ACTIONS(2112),
    [anon_sym_PLUS_PLUS] = ACTIONS(2112),
    [anon_sym_sizeof] = ACTIONS(2110),
    [anon_sym___alignof__] = ACTIONS(2110),
    [anon_sym___alignof] = ACTIONS(2110),
    [anon_sym__alignof] = ACTIONS(2110),
    [anon_sym_alignof] = ACTIONS(2110),
    [anon_sym__Alignof] = ACTIONS(2110),
    [anon_sym_offsetof] = ACTIONS(2110),
    [anon_sym__Generic] = ACTIONS(2110),
    [anon_sym_asm] = ACTIONS(2110),
    [anon_sym___asm__] = ACTIONS(2110),
    [sym_number_literal] = ACTIONS(2112),
    [anon_sym_L_SQUOTE] = ACTIONS(2112),
    [anon_sym_u_SQUOTE] = ACTIONS(2112),
    [anon_sym_U_SQUOTE] = ACTIONS(2112),
    [anon_sym_u8_SQUOTE] = ACTIONS(2112),
    [anon_sym_SQUOTE] = ACTIONS(2112),
    [anon_sym_L_DQUOTE] = ACTIONS(2112),
    [anon_sym_u_DQUOTE] = ACTIONS(2112),
    [anon_sym_U_DQUOTE] = ACTIONS(2112),
    [anon_sym_u8_DQUOTE] = ACTIONS(2112),
    [anon_sym_DQUOTE] = ACTIONS(2112),
    [sym_true] = ACTIONS(2110),
    [sym_false] = ACTIONS(2110),
    [anon_sym_NULL] = ACTIONS(2110),
    [anon_sym_nullptr] = ACTIONS(2110),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2110),
    [anon_sym_decltype] = ACTIONS(2110),
    [sym_virtual] = ACTIONS(2110),
    [anon_sym_typename] = ACTIONS(2110),
    [anon_sym_template] = ACTIONS(2110),
    [anon_sym_try] = ACTIONS(2110),
    [anon_sym_delete] = ACTIONS(2110),
    [anon_sym_throw] = ACTIONS(2110),
    [anon_sym_co_return] = ACTIONS(2110),
    [anon_sym_co_yield] = ACTIONS(2110),
    [anon_sym_R_DQUOTE] = ACTIONS(2112),
    [anon_sym_LR_DQUOTE] = ACTIONS(2112),
    [anon_sym_uR_DQUOTE] = ACTIONS(2112),
    [anon_sym_UR_DQUOTE] = ACTIONS(2112),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2112),
    [anon_sym_co_await] = ACTIONS(2110),
    [anon_sym_new] = ACTIONS(2110),
    [anon_sym_requires] = ACTIONS(2110),
    [sym_this] = ACTIONS(2110),
    [anon_sym_discard] = ACTIONS(2110),
    [anon_sym_precise] = ACTIONS(2110),
    [anon_sym_shared] = ACTIONS(2110),
    [anon_sym_groupshared] = ACTIONS(2110),
    [anon_sym_uniform] = ACTIONS(2110),
    [anon_sym_row_major] = ACTIONS(2110),
    [anon_sym_column_major] = ACTIONS(2110),
    [anon_sym_globallycoherent] = ACTIONS(2110),
    [anon_sym_centroid] = ACTIONS(2110),
    [anon_sym_noperspective] = ACTIONS(2110),
    [anon_sym_nointerpolation] = ACTIONS(2110),
    [anon_sym_sample] = ACTIONS(2110),
    [anon_sym_linear] = ACTIONS(2110),
    [anon_sym_snorm] = ACTIONS(2110),
    [anon_sym_unorm] = ACTIONS(2110),
    [anon_sym_point] = ACTIONS(2110),
    [anon_sym_line] = ACTIONS(2110),
    [anon_sym_triangleadj] = ACTIONS(2110),
    [anon_sym_lineadj] = ACTIONS(2110),
    [anon_sym_triangle] = ACTIONS(2110),
    [anon_sym_cbuffer] = ACTIONS(2110),
  },
  [1055] = {
    [sym_identifier] = ACTIONS(2240),
    [anon_sym_LPAREN2] = ACTIONS(2242),
    [anon_sym_BANG] = ACTIONS(2242),
    [anon_sym_TILDE] = ACTIONS(2242),
    [anon_sym_DASH] = ACTIONS(2240),
    [anon_sym_PLUS] = ACTIONS(2240),
    [anon_sym_STAR] = ACTIONS(2242),
    [anon_sym_AMP] = ACTIONS(2242),
    [anon_sym_SEMI] = ACTIONS(2242),
    [anon_sym___extension__] = ACTIONS(2240),
    [anon_sym_typedef] = ACTIONS(2240),
    [anon_sym_in] = ACTIONS(2240),
    [anon_sym_out] = ACTIONS(2240),
    [anon_sym_inout] = ACTIONS(2240),
    [anon_sym_extern] = ACTIONS(2240),
    [anon_sym___attribute__] = ACTIONS(2240),
    [anon_sym_COLON_COLON] = ACTIONS(2242),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2242),
    [anon_sym___declspec] = ACTIONS(2240),
    [anon_sym_LBRACE] = ACTIONS(2242),
    [anon_sym_signed] = ACTIONS(2240),
    [anon_sym_unsigned] = ACTIONS(2240),
    [anon_sym_long] = ACTIONS(2240),
    [anon_sym_short] = ACTIONS(2240),
    [anon_sym_LBRACK] = ACTIONS(2240),
    [anon_sym_static] = ACTIONS(2240),
    [anon_sym_register] = ACTIONS(2240),
    [anon_sym_inline] = ACTIONS(2240),
    [anon_sym___inline] = ACTIONS(2240),
    [anon_sym___inline__] = ACTIONS(2240),
    [anon_sym___forceinline] = ACTIONS(2240),
    [anon_sym_thread_local] = ACTIONS(2240),
    [anon_sym___thread] = ACTIONS(2240),
    [anon_sym_const] = ACTIONS(2240),
    [anon_sym_constexpr] = ACTIONS(2240),
    [anon_sym_volatile] = ACTIONS(2240),
    [anon_sym_restrict] = ACTIONS(2240),
    [anon_sym___restrict__] = ACTIONS(2240),
    [anon_sym__Atomic] = ACTIONS(2240),
    [anon_sym__Noreturn] = ACTIONS(2240),
    [anon_sym_noreturn] = ACTIONS(2240),
    [anon_sym_mutable] = ACTIONS(2240),
    [anon_sym_constinit] = ACTIONS(2240),
    [anon_sym_consteval] = ACTIONS(2240),
    [anon_sym_alignas] = ACTIONS(2240),
    [anon_sym__Alignas] = ACTIONS(2240),
    [sym_primitive_type] = ACTIONS(2240),
    [anon_sym_enum] = ACTIONS(2240),
    [anon_sym_class] = ACTIONS(2240),
    [anon_sym_struct] = ACTIONS(2240),
    [anon_sym_union] = ACTIONS(2240),
    [anon_sym_if] = ACTIONS(2240),
    [anon_sym_else] = ACTIONS(2240),
    [anon_sym_switch] = ACTIONS(2240),
    [anon_sym_while] = ACTIONS(2240),
    [anon_sym_do] = ACTIONS(2240),
    [anon_sym_for] = ACTIONS(2240),
    [anon_sym_return] = ACTIONS(2240),
    [anon_sym_break] = ACTIONS(2240),
    [anon_sym_continue] = ACTIONS(2240),
    [anon_sym_goto] = ACTIONS(2240),
    [anon_sym___try] = ACTIONS(2240),
    [anon_sym___leave] = ACTIONS(2240),
    [anon_sym_not] = ACTIONS(2240),
    [anon_sym_compl] = ACTIONS(2240),
    [anon_sym_DASH_DASH] = ACTIONS(2242),
    [anon_sym_PLUS_PLUS] = ACTIONS(2242),
    [anon_sym_sizeof] = ACTIONS(2240),
    [anon_sym___alignof__] = ACTIONS(2240),
    [anon_sym___alignof] = ACTIONS(2240),
    [anon_sym__alignof] = ACTIONS(2240),
    [anon_sym_alignof] = ACTIONS(2240),
    [anon_sym__Alignof] = ACTIONS(2240),
    [anon_sym_offsetof] = ACTIONS(2240),
    [anon_sym__Generic] = ACTIONS(2240),
    [anon_sym_asm] = ACTIONS(2240),
    [anon_sym___asm__] = ACTIONS(2240),
    [sym_number_literal] = ACTIONS(2242),
    [anon_sym_L_SQUOTE] = ACTIONS(2242),
    [anon_sym_u_SQUOTE] = ACTIONS(2242),
    [anon_sym_U_SQUOTE] = ACTIONS(2242),
    [anon_sym_u8_SQUOTE] = ACTIONS(2242),
    [anon_sym_SQUOTE] = ACTIONS(2242),
    [anon_sym_L_DQUOTE] = ACTIONS(2242),
    [anon_sym_u_DQUOTE] = ACTIONS(2242),
    [anon_sym_U_DQUOTE] = ACTIONS(2242),
    [anon_sym_u8_DQUOTE] = ACTIONS(2242),
    [anon_sym_DQUOTE] = ACTIONS(2242),
    [sym_true] = ACTIONS(2240),
    [sym_false] = ACTIONS(2240),
    [anon_sym_NULL] = ACTIONS(2240),
    [anon_sym_nullptr] = ACTIONS(2240),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2240),
    [anon_sym_decltype] = ACTIONS(2240),
    [sym_virtual] = ACTIONS(2240),
    [anon_sym_typename] = ACTIONS(2240),
    [anon_sym_template] = ACTIONS(2240),
    [anon_sym_try] = ACTIONS(2240),
    [anon_sym_delete] = ACTIONS(2240),
    [anon_sym_throw] = ACTIONS(2240),
    [anon_sym_co_return] = ACTIONS(2240),
    [anon_sym_co_yield] = ACTIONS(2240),
    [anon_sym_R_DQUOTE] = ACTIONS(2242),
    [anon_sym_LR_DQUOTE] = ACTIONS(2242),
    [anon_sym_uR_DQUOTE] = ACTIONS(2242),
    [anon_sym_UR_DQUOTE] = ACTIONS(2242),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2242),
    [anon_sym_co_await] = ACTIONS(2240),
    [anon_sym_new] = ACTIONS(2240),
    [anon_sym_requires] = ACTIONS(2240),
    [sym_this] = ACTIONS(2240),
    [anon_sym_discard] = ACTIONS(2240),
    [anon_sym_precise] = ACTIONS(2240),
    [anon_sym_shared] = ACTIONS(2240),
    [anon_sym_groupshared] = ACTIONS(2240),
    [anon_sym_uniform] = ACTIONS(2240),
    [anon_sym_row_major] = ACTIONS(2240),
    [anon_sym_column_major] = ACTIONS(2240),
    [anon_sym_globallycoherent] = ACTIONS(2240),
    [anon_sym_centroid] = ACTIONS(2240),
    [anon_sym_noperspective] = ACTIONS(2240),
    [anon_sym_nointerpolation] = ACTIONS(2240),
    [anon_sym_sample] = ACTIONS(2240),
    [anon_sym_linear] = ACTIONS(2240),
    [anon_sym_snorm] = ACTIONS(2240),
    [anon_sym_unorm] = ACTIONS(2240),
    [anon_sym_point] = ACTIONS(2240),
    [anon_sym_line] = ACTIONS(2240),
    [anon_sym_triangleadj] = ACTIONS(2240),
    [anon_sym_lineadj] = ACTIONS(2240),
    [anon_sym_triangle] = ACTIONS(2240),
    [anon_sym_cbuffer] = ACTIONS(2240),
  },
  [1056] = {
    [sym_identifier] = ACTIONS(2094),
    [anon_sym_LPAREN2] = ACTIONS(2096),
    [anon_sym_BANG] = ACTIONS(2096),
    [anon_sym_TILDE] = ACTIONS(2096),
    [anon_sym_DASH] = ACTIONS(2094),
    [anon_sym_PLUS] = ACTIONS(2094),
    [anon_sym_STAR] = ACTIONS(2096),
    [anon_sym_AMP] = ACTIONS(2096),
    [anon_sym_SEMI] = ACTIONS(2096),
    [anon_sym___extension__] = ACTIONS(2094),
    [anon_sym_typedef] = ACTIONS(2094),
    [anon_sym_in] = ACTIONS(2094),
    [anon_sym_out] = ACTIONS(2094),
    [anon_sym_inout] = ACTIONS(2094),
    [anon_sym_extern] = ACTIONS(2094),
    [anon_sym___attribute__] = ACTIONS(2094),
    [anon_sym_COLON_COLON] = ACTIONS(2096),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2096),
    [anon_sym___declspec] = ACTIONS(2094),
    [anon_sym_LBRACE] = ACTIONS(2096),
    [anon_sym_signed] = ACTIONS(2094),
    [anon_sym_unsigned] = ACTIONS(2094),
    [anon_sym_long] = ACTIONS(2094),
    [anon_sym_short] = ACTIONS(2094),
    [anon_sym_LBRACK] = ACTIONS(2094),
    [anon_sym_static] = ACTIONS(2094),
    [anon_sym_register] = ACTIONS(2094),
    [anon_sym_inline] = ACTIONS(2094),
    [anon_sym___inline] = ACTIONS(2094),
    [anon_sym___inline__] = ACTIONS(2094),
    [anon_sym___forceinline] = ACTIONS(2094),
    [anon_sym_thread_local] = ACTIONS(2094),
    [anon_sym___thread] = ACTIONS(2094),
    [anon_sym_const] = ACTIONS(2094),
    [anon_sym_constexpr] = ACTIONS(2094),
    [anon_sym_volatile] = ACTIONS(2094),
    [anon_sym_restrict] = ACTIONS(2094),
    [anon_sym___restrict__] = ACTIONS(2094),
    [anon_sym__Atomic] = ACTIONS(2094),
    [anon_sym__Noreturn] = ACTIONS(2094),
    [anon_sym_noreturn] = ACTIONS(2094),
    [anon_sym_mutable] = ACTIONS(2094),
    [anon_sym_constinit] = ACTIONS(2094),
    [anon_sym_consteval] = ACTIONS(2094),
    [anon_sym_alignas] = ACTIONS(2094),
    [anon_sym__Alignas] = ACTIONS(2094),
    [sym_primitive_type] = ACTIONS(2094),
    [anon_sym_enum] = ACTIONS(2094),
    [anon_sym_class] = ACTIONS(2094),
    [anon_sym_struct] = ACTIONS(2094),
    [anon_sym_union] = ACTIONS(2094),
    [anon_sym_if] = ACTIONS(2094),
    [anon_sym_else] = ACTIONS(2094),
    [anon_sym_switch] = ACTIONS(2094),
    [anon_sym_while] = ACTIONS(2094),
    [anon_sym_do] = ACTIONS(2094),
    [anon_sym_for] = ACTIONS(2094),
    [anon_sym_return] = ACTIONS(2094),
    [anon_sym_break] = ACTIONS(2094),
    [anon_sym_continue] = ACTIONS(2094),
    [anon_sym_goto] = ACTIONS(2094),
    [anon_sym___try] = ACTIONS(2094),
    [anon_sym___leave] = ACTIONS(2094),
    [anon_sym_not] = ACTIONS(2094),
    [anon_sym_compl] = ACTIONS(2094),
    [anon_sym_DASH_DASH] = ACTIONS(2096),
    [anon_sym_PLUS_PLUS] = ACTIONS(2096),
    [anon_sym_sizeof] = ACTIONS(2094),
    [anon_sym___alignof__] = ACTIONS(2094),
    [anon_sym___alignof] = ACTIONS(2094),
    [anon_sym__alignof] = ACTIONS(2094),
    [anon_sym_alignof] = ACTIONS(2094),
    [anon_sym__Alignof] = ACTIONS(2094),
    [anon_sym_offsetof] = ACTIONS(2094),
    [anon_sym__Generic] = ACTIONS(2094),
    [anon_sym_asm] = ACTIONS(2094),
    [anon_sym___asm__] = ACTIONS(2094),
    [sym_number_literal] = ACTIONS(2096),
    [anon_sym_L_SQUOTE] = ACTIONS(2096),
    [anon_sym_u_SQUOTE] = ACTIONS(2096),
    [anon_sym_U_SQUOTE] = ACTIONS(2096),
    [anon_sym_u8_SQUOTE] = ACTIONS(2096),
    [anon_sym_SQUOTE] = ACTIONS(2096),
    [anon_sym_L_DQUOTE] = ACTIONS(2096),
    [anon_sym_u_DQUOTE] = ACTIONS(2096),
    [anon_sym_U_DQUOTE] = ACTIONS(2096),
    [anon_sym_u8_DQUOTE] = ACTIONS(2096),
    [anon_sym_DQUOTE] = ACTIONS(2096),
    [sym_true] = ACTIONS(2094),
    [sym_false] = ACTIONS(2094),
    [anon_sym_NULL] = ACTIONS(2094),
    [anon_sym_nullptr] = ACTIONS(2094),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2094),
    [anon_sym_decltype] = ACTIONS(2094),
    [sym_virtual] = ACTIONS(2094),
    [anon_sym_typename] = ACTIONS(2094),
    [anon_sym_template] = ACTIONS(2094),
    [anon_sym_try] = ACTIONS(2094),
    [anon_sym_delete] = ACTIONS(2094),
    [anon_sym_throw] = ACTIONS(2094),
    [anon_sym_co_return] = ACTIONS(2094),
    [anon_sym_co_yield] = ACTIONS(2094),
    [anon_sym_R_DQUOTE] = ACTIONS(2096),
    [anon_sym_LR_DQUOTE] = ACTIONS(2096),
    [anon_sym_uR_DQUOTE] = ACTIONS(2096),
    [anon_sym_UR_DQUOTE] = ACTIONS(2096),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2096),
    [anon_sym_co_await] = ACTIONS(2094),
    [anon_sym_new] = ACTIONS(2094),
    [anon_sym_requires] = ACTIONS(2094),
    [sym_this] = ACTIONS(2094),
    [anon_sym_discard] = ACTIONS(2094),
    [anon_sym_precise] = ACTIONS(2094),
    [anon_sym_shared] = ACTIONS(2094),
    [anon_sym_groupshared] = ACTIONS(2094),
    [anon_sym_uniform] = ACTIONS(2094),
    [anon_sym_row_major] = ACTIONS(2094),
    [anon_sym_column_major] = ACTIONS(2094),
    [anon_sym_globallycoherent] = ACTIONS(2094),
    [anon_sym_centroid] = ACTIONS(2094),
    [anon_sym_noperspective] = ACTIONS(2094),
    [anon_sym_nointerpolation] = ACTIONS(2094),
    [anon_sym_sample] = ACTIONS(2094),
    [anon_sym_linear] = ACTIONS(2094),
    [anon_sym_snorm] = ACTIONS(2094),
    [anon_sym_unorm] = ACTIONS(2094),
    [anon_sym_point] = ACTIONS(2094),
    [anon_sym_line] = ACTIONS(2094),
    [anon_sym_triangleadj] = ACTIONS(2094),
    [anon_sym_lineadj] = ACTIONS(2094),
    [anon_sym_triangle] = ACTIONS(2094),
    [anon_sym_cbuffer] = ACTIONS(2094),
  },
  [1057] = {
    [sym_type_qualifier] = STATE(4004),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(4751),
    [sym_sized_type_specifier] = STATE(2475),
    [sym_enum_specifier] = STATE(2475),
    [sym_struct_specifier] = STATE(2475),
    [sym_union_specifier] = STATE(2475),
    [sym_expression] = STATE(4692),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_type_descriptor] = STATE(7896),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_placeholder_type_specifier] = STATE(2475),
    [sym_decltype_auto] = STATE(2468),
    [sym_decltype] = STATE(2429),
    [sym_class_specifier] = STATE(2475),
    [sym__class_name] = STATE(7510),
    [sym_dependent_type] = STATE(2475),
    [sym_template_type] = STATE(5317),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5574),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(5339),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym__type_definition_type_repeat1] = STATE(4004),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2443),
    [sym_identifier] = ACTIONS(3922),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_signed] = ACTIONS(2036),
    [anon_sym_unsigned] = ACTIONS(2036),
    [anon_sym_long] = ACTIONS(2036),
    [anon_sym_short] = ACTIONS(2036),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(3924),
    [anon_sym_enum] = ACTIONS(2042),
    [anon_sym_class] = ACTIONS(2044),
    [anon_sym_struct] = ACTIONS(2046),
    [anon_sym_union] = ACTIONS(2048),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2072),
    [anon_sym_decltype] = ACTIONS(2074),
    [anon_sym_typename] = ACTIONS(2076),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1058] = {
    [sym_identifier] = ACTIONS(2284),
    [anon_sym_LPAREN2] = ACTIONS(2286),
    [anon_sym_BANG] = ACTIONS(2286),
    [anon_sym_TILDE] = ACTIONS(2286),
    [anon_sym_DASH] = ACTIONS(2284),
    [anon_sym_PLUS] = ACTIONS(2284),
    [anon_sym_STAR] = ACTIONS(2286),
    [anon_sym_AMP] = ACTIONS(2286),
    [anon_sym_SEMI] = ACTIONS(2286),
    [anon_sym___extension__] = ACTIONS(2284),
    [anon_sym_typedef] = ACTIONS(2284),
    [anon_sym_in] = ACTIONS(2284),
    [anon_sym_out] = ACTIONS(2284),
    [anon_sym_inout] = ACTIONS(2284),
    [anon_sym_extern] = ACTIONS(2284),
    [anon_sym___attribute__] = ACTIONS(2284),
    [anon_sym_COLON_COLON] = ACTIONS(2286),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2286),
    [anon_sym___declspec] = ACTIONS(2284),
    [anon_sym_LBRACE] = ACTIONS(2286),
    [anon_sym_signed] = ACTIONS(2284),
    [anon_sym_unsigned] = ACTIONS(2284),
    [anon_sym_long] = ACTIONS(2284),
    [anon_sym_short] = ACTIONS(2284),
    [anon_sym_LBRACK] = ACTIONS(2284),
    [anon_sym_static] = ACTIONS(2284),
    [anon_sym_register] = ACTIONS(2284),
    [anon_sym_inline] = ACTIONS(2284),
    [anon_sym___inline] = ACTIONS(2284),
    [anon_sym___inline__] = ACTIONS(2284),
    [anon_sym___forceinline] = ACTIONS(2284),
    [anon_sym_thread_local] = ACTIONS(2284),
    [anon_sym___thread] = ACTIONS(2284),
    [anon_sym_const] = ACTIONS(2284),
    [anon_sym_constexpr] = ACTIONS(2284),
    [anon_sym_volatile] = ACTIONS(2284),
    [anon_sym_restrict] = ACTIONS(2284),
    [anon_sym___restrict__] = ACTIONS(2284),
    [anon_sym__Atomic] = ACTIONS(2284),
    [anon_sym__Noreturn] = ACTIONS(2284),
    [anon_sym_noreturn] = ACTIONS(2284),
    [anon_sym_mutable] = ACTIONS(2284),
    [anon_sym_constinit] = ACTIONS(2284),
    [anon_sym_consteval] = ACTIONS(2284),
    [anon_sym_alignas] = ACTIONS(2284),
    [anon_sym__Alignas] = ACTIONS(2284),
    [sym_primitive_type] = ACTIONS(2284),
    [anon_sym_enum] = ACTIONS(2284),
    [anon_sym_class] = ACTIONS(2284),
    [anon_sym_struct] = ACTIONS(2284),
    [anon_sym_union] = ACTIONS(2284),
    [anon_sym_if] = ACTIONS(2284),
    [anon_sym_else] = ACTIONS(2284),
    [anon_sym_switch] = ACTIONS(2284),
    [anon_sym_while] = ACTIONS(2284),
    [anon_sym_do] = ACTIONS(2284),
    [anon_sym_for] = ACTIONS(2284),
    [anon_sym_return] = ACTIONS(2284),
    [anon_sym_break] = ACTIONS(2284),
    [anon_sym_continue] = ACTIONS(2284),
    [anon_sym_goto] = ACTIONS(2284),
    [anon_sym___try] = ACTIONS(2284),
    [anon_sym___leave] = ACTIONS(2284),
    [anon_sym_not] = ACTIONS(2284),
    [anon_sym_compl] = ACTIONS(2284),
    [anon_sym_DASH_DASH] = ACTIONS(2286),
    [anon_sym_PLUS_PLUS] = ACTIONS(2286),
    [anon_sym_sizeof] = ACTIONS(2284),
    [anon_sym___alignof__] = ACTIONS(2284),
    [anon_sym___alignof] = ACTIONS(2284),
    [anon_sym__alignof] = ACTIONS(2284),
    [anon_sym_alignof] = ACTIONS(2284),
    [anon_sym__Alignof] = ACTIONS(2284),
    [anon_sym_offsetof] = ACTIONS(2284),
    [anon_sym__Generic] = ACTIONS(2284),
    [anon_sym_asm] = ACTIONS(2284),
    [anon_sym___asm__] = ACTIONS(2284),
    [sym_number_literal] = ACTIONS(2286),
    [anon_sym_L_SQUOTE] = ACTIONS(2286),
    [anon_sym_u_SQUOTE] = ACTIONS(2286),
    [anon_sym_U_SQUOTE] = ACTIONS(2286),
    [anon_sym_u8_SQUOTE] = ACTIONS(2286),
    [anon_sym_SQUOTE] = ACTIONS(2286),
    [anon_sym_L_DQUOTE] = ACTIONS(2286),
    [anon_sym_u_DQUOTE] = ACTIONS(2286),
    [anon_sym_U_DQUOTE] = ACTIONS(2286),
    [anon_sym_u8_DQUOTE] = ACTIONS(2286),
    [anon_sym_DQUOTE] = ACTIONS(2286),
    [sym_true] = ACTIONS(2284),
    [sym_false] = ACTIONS(2284),
    [anon_sym_NULL] = ACTIONS(2284),
    [anon_sym_nullptr] = ACTIONS(2284),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2284),
    [anon_sym_decltype] = ACTIONS(2284),
    [sym_virtual] = ACTIONS(2284),
    [anon_sym_typename] = ACTIONS(2284),
    [anon_sym_template] = ACTIONS(2284),
    [anon_sym_try] = ACTIONS(2284),
    [anon_sym_delete] = ACTIONS(2284),
    [anon_sym_throw] = ACTIONS(2284),
    [anon_sym_co_return] = ACTIONS(2284),
    [anon_sym_co_yield] = ACTIONS(2284),
    [anon_sym_R_DQUOTE] = ACTIONS(2286),
    [anon_sym_LR_DQUOTE] = ACTIONS(2286),
    [anon_sym_uR_DQUOTE] = ACTIONS(2286),
    [anon_sym_UR_DQUOTE] = ACTIONS(2286),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2286),
    [anon_sym_co_await] = ACTIONS(2284),
    [anon_sym_new] = ACTIONS(2284),
    [anon_sym_requires] = ACTIONS(2284),
    [sym_this] = ACTIONS(2284),
    [anon_sym_discard] = ACTIONS(2284),
    [anon_sym_precise] = ACTIONS(2284),
    [anon_sym_shared] = ACTIONS(2284),
    [anon_sym_groupshared] = ACTIONS(2284),
    [anon_sym_uniform] = ACTIONS(2284),
    [anon_sym_row_major] = ACTIONS(2284),
    [anon_sym_column_major] = ACTIONS(2284),
    [anon_sym_globallycoherent] = ACTIONS(2284),
    [anon_sym_centroid] = ACTIONS(2284),
    [anon_sym_noperspective] = ACTIONS(2284),
    [anon_sym_nointerpolation] = ACTIONS(2284),
    [anon_sym_sample] = ACTIONS(2284),
    [anon_sym_linear] = ACTIONS(2284),
    [anon_sym_snorm] = ACTIONS(2284),
    [anon_sym_unorm] = ACTIONS(2284),
    [anon_sym_point] = ACTIONS(2284),
    [anon_sym_line] = ACTIONS(2284),
    [anon_sym_triangleadj] = ACTIONS(2284),
    [anon_sym_lineadj] = ACTIONS(2284),
    [anon_sym_triangle] = ACTIONS(2284),
    [anon_sym_cbuffer] = ACTIONS(2284),
  },
  [1059] = {
    [sym_identifier] = ACTIONS(2142),
    [anon_sym_LPAREN2] = ACTIONS(2144),
    [anon_sym_BANG] = ACTIONS(2144),
    [anon_sym_TILDE] = ACTIONS(2144),
    [anon_sym_DASH] = ACTIONS(2142),
    [anon_sym_PLUS] = ACTIONS(2142),
    [anon_sym_STAR] = ACTIONS(2144),
    [anon_sym_AMP] = ACTIONS(2144),
    [anon_sym_SEMI] = ACTIONS(2144),
    [anon_sym___extension__] = ACTIONS(2142),
    [anon_sym_typedef] = ACTIONS(2142),
    [anon_sym_in] = ACTIONS(2142),
    [anon_sym_out] = ACTIONS(2142),
    [anon_sym_inout] = ACTIONS(2142),
    [anon_sym_extern] = ACTIONS(2142),
    [anon_sym___attribute__] = ACTIONS(2142),
    [anon_sym_COLON_COLON] = ACTIONS(2144),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2144),
    [anon_sym___declspec] = ACTIONS(2142),
    [anon_sym_LBRACE] = ACTIONS(2144),
    [anon_sym_signed] = ACTIONS(2142),
    [anon_sym_unsigned] = ACTIONS(2142),
    [anon_sym_long] = ACTIONS(2142),
    [anon_sym_short] = ACTIONS(2142),
    [anon_sym_LBRACK] = ACTIONS(2142),
    [anon_sym_static] = ACTIONS(2142),
    [anon_sym_register] = ACTIONS(2142),
    [anon_sym_inline] = ACTIONS(2142),
    [anon_sym___inline] = ACTIONS(2142),
    [anon_sym___inline__] = ACTIONS(2142),
    [anon_sym___forceinline] = ACTIONS(2142),
    [anon_sym_thread_local] = ACTIONS(2142),
    [anon_sym___thread] = ACTIONS(2142),
    [anon_sym_const] = ACTIONS(2142),
    [anon_sym_constexpr] = ACTIONS(2142),
    [anon_sym_volatile] = ACTIONS(2142),
    [anon_sym_restrict] = ACTIONS(2142),
    [anon_sym___restrict__] = ACTIONS(2142),
    [anon_sym__Atomic] = ACTIONS(2142),
    [anon_sym__Noreturn] = ACTIONS(2142),
    [anon_sym_noreturn] = ACTIONS(2142),
    [anon_sym_mutable] = ACTIONS(2142),
    [anon_sym_constinit] = ACTIONS(2142),
    [anon_sym_consteval] = ACTIONS(2142),
    [anon_sym_alignas] = ACTIONS(2142),
    [anon_sym__Alignas] = ACTIONS(2142),
    [sym_primitive_type] = ACTIONS(2142),
    [anon_sym_enum] = ACTIONS(2142),
    [anon_sym_class] = ACTIONS(2142),
    [anon_sym_struct] = ACTIONS(2142),
    [anon_sym_union] = ACTIONS(2142),
    [anon_sym_if] = ACTIONS(2142),
    [anon_sym_else] = ACTIONS(2142),
    [anon_sym_switch] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2142),
    [anon_sym_do] = ACTIONS(2142),
    [anon_sym_for] = ACTIONS(2142),
    [anon_sym_return] = ACTIONS(2142),
    [anon_sym_break] = ACTIONS(2142),
    [anon_sym_continue] = ACTIONS(2142),
    [anon_sym_goto] = ACTIONS(2142),
    [anon_sym___try] = ACTIONS(2142),
    [anon_sym___leave] = ACTIONS(2142),
    [anon_sym_not] = ACTIONS(2142),
    [anon_sym_compl] = ACTIONS(2142),
    [anon_sym_DASH_DASH] = ACTIONS(2144),
    [anon_sym_PLUS_PLUS] = ACTIONS(2144),
    [anon_sym_sizeof] = ACTIONS(2142),
    [anon_sym___alignof__] = ACTIONS(2142),
    [anon_sym___alignof] = ACTIONS(2142),
    [anon_sym__alignof] = ACTIONS(2142),
    [anon_sym_alignof] = ACTIONS(2142),
    [anon_sym__Alignof] = ACTIONS(2142),
    [anon_sym_offsetof] = ACTIONS(2142),
    [anon_sym__Generic] = ACTIONS(2142),
    [anon_sym_asm] = ACTIONS(2142),
    [anon_sym___asm__] = ACTIONS(2142),
    [sym_number_literal] = ACTIONS(2144),
    [anon_sym_L_SQUOTE] = ACTIONS(2144),
    [anon_sym_u_SQUOTE] = ACTIONS(2144),
    [anon_sym_U_SQUOTE] = ACTIONS(2144),
    [anon_sym_u8_SQUOTE] = ACTIONS(2144),
    [anon_sym_SQUOTE] = ACTIONS(2144),
    [anon_sym_L_DQUOTE] = ACTIONS(2144),
    [anon_sym_u_DQUOTE] = ACTIONS(2144),
    [anon_sym_U_DQUOTE] = ACTIONS(2144),
    [anon_sym_u8_DQUOTE] = ACTIONS(2144),
    [anon_sym_DQUOTE] = ACTIONS(2144),
    [sym_true] = ACTIONS(2142),
    [sym_false] = ACTIONS(2142),
    [anon_sym_NULL] = ACTIONS(2142),
    [anon_sym_nullptr] = ACTIONS(2142),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2142),
    [anon_sym_decltype] = ACTIONS(2142),
    [sym_virtual] = ACTIONS(2142),
    [anon_sym_typename] = ACTIONS(2142),
    [anon_sym_template] = ACTIONS(2142),
    [anon_sym_try] = ACTIONS(2142),
    [anon_sym_delete] = ACTIONS(2142),
    [anon_sym_throw] = ACTIONS(2142),
    [anon_sym_co_return] = ACTIONS(2142),
    [anon_sym_co_yield] = ACTIONS(2142),
    [anon_sym_R_DQUOTE] = ACTIONS(2144),
    [anon_sym_LR_DQUOTE] = ACTIONS(2144),
    [anon_sym_uR_DQUOTE] = ACTIONS(2144),
    [anon_sym_UR_DQUOTE] = ACTIONS(2144),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2144),
    [anon_sym_co_await] = ACTIONS(2142),
    [anon_sym_new] = ACTIONS(2142),
    [anon_sym_requires] = ACTIONS(2142),
    [sym_this] = ACTIONS(2142),
    [anon_sym_discard] = ACTIONS(2142),
    [anon_sym_precise] = ACTIONS(2142),
    [anon_sym_shared] = ACTIONS(2142),
    [anon_sym_groupshared] = ACTIONS(2142),
    [anon_sym_uniform] = ACTIONS(2142),
    [anon_sym_row_major] = ACTIONS(2142),
    [anon_sym_column_major] = ACTIONS(2142),
    [anon_sym_globallycoherent] = ACTIONS(2142),
    [anon_sym_centroid] = ACTIONS(2142),
    [anon_sym_noperspective] = ACTIONS(2142),
    [anon_sym_nointerpolation] = ACTIONS(2142),
    [anon_sym_sample] = ACTIONS(2142),
    [anon_sym_linear] = ACTIONS(2142),
    [anon_sym_snorm] = ACTIONS(2142),
    [anon_sym_unorm] = ACTIONS(2142),
    [anon_sym_point] = ACTIONS(2142),
    [anon_sym_line] = ACTIONS(2142),
    [anon_sym_triangleadj] = ACTIONS(2142),
    [anon_sym_lineadj] = ACTIONS(2142),
    [anon_sym_triangle] = ACTIONS(2142),
    [anon_sym_cbuffer] = ACTIONS(2142),
  },
  [1060] = {
    [sym__declaration_modifiers] = STATE(1984),
    [sym__declaration_specifiers] = STATE(4097),
    [sym_attribute_specifier] = STATE(1984),
    [sym_attribute_declaration] = STATE(1984),
    [sym_ms_declspec_modifier] = STATE(1984),
    [sym_ms_based_modifier] = STATE(8582),
    [sym_ms_call_modifier] = STATE(4606),
    [sym__declarator] = STATE(6515),
    [sym__abstract_declarator] = STATE(6683),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_abstract_parenthesized_declarator] = STATE(6033),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_abstract_pointer_declarator] = STATE(6033),
    [sym_function_declarator] = STATE(6270),
    [sym_abstract_function_declarator] = STATE(6033),
    [sym_array_declarator] = STATE(6270),
    [sym_abstract_array_declarator] = STATE(6033),
    [sym_storage_class_specifier] = STATE(1984),
    [sym_type_qualifier] = STATE(1984),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_parameter_list] = STATE(3525),
    [sym_parameter_declaration] = STATE(7178),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_optional_parameter_declaration] = STATE(7178),
    [sym_variadic_parameter_declaration] = STATE(7178),
    [sym_reference_declarator] = STATE(6270),
    [sym_abstract_reference_declarator] = STATE(6033),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym__function_declarator_seq] = STATE(6076),
    [sym_template_type] = STATE(2252),
    [sym_template_function] = STATE(6270),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5571),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(1984),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1984),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3930),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1877),
    [anon_sym_RPAREN] = ACTIONS(3932),
    [anon_sym_LPAREN2] = ACTIONS(3934),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(3936),
    [anon_sym_AMP_AMP] = ACTIONS(3938),
    [anon_sym_AMP] = ACTIONS(3940),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1827),
    [anon_sym_out] = ACTIONS(1827),
    [anon_sym_inout] = ACTIONS(1827),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3942),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym___cdecl] = ACTIONS(2034),
    [anon_sym___clrcall] = ACTIONS(2034),
    [anon_sym___stdcall] = ACTIONS(2034),
    [anon_sym___fastcall] = ACTIONS(2034),
    [anon_sym___thiscall] = ACTIONS(2034),
    [anon_sym___vectorcall] = ACTIONS(2034),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(3944),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(1833),
    [anon_sym_class] = ACTIONS(1835),
    [anon_sym_struct] = ACTIONS(1837),
    [anon_sym_union] = ACTIONS(1839),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1827),
    [anon_sym_typename] = ACTIONS(1863),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(2078),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1061] = {
    [sym_expression] = STATE(3905),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_initializer_list] = STATE(4009),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(3513),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3515),
    [anon_sym_COMMA] = ACTIONS(3515),
    [aux_sym_preproc_if_token2] = ACTIONS(3515),
    [aux_sym_preproc_else_token1] = ACTIONS(3515),
    [aux_sym_preproc_elif_token1] = ACTIONS(3513),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(3515),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(3515),
    [anon_sym_LPAREN2] = ACTIONS(3515),
    [anon_sym_BANG] = ACTIONS(3946),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3513),
    [anon_sym_PLUS] = ACTIONS(3513),
    [anon_sym_STAR] = ACTIONS(3515),
    [anon_sym_SLASH] = ACTIONS(3513),
    [anon_sym_PERCENT] = ACTIONS(3515),
    [anon_sym_PIPE_PIPE] = ACTIONS(3515),
    [anon_sym_AMP_AMP] = ACTIONS(3515),
    [anon_sym_PIPE] = ACTIONS(3513),
    [anon_sym_CARET] = ACTIONS(3515),
    [anon_sym_AMP] = ACTIONS(3513),
    [anon_sym_EQ_EQ] = ACTIONS(3515),
    [anon_sym_BANG_EQ] = ACTIONS(3515),
    [anon_sym_GT] = ACTIONS(3513),
    [anon_sym_GT_EQ] = ACTIONS(3515),
    [anon_sym_LT_EQ] = ACTIONS(3513),
    [anon_sym_LT] = ACTIONS(3513),
    [anon_sym_LT_LT] = ACTIONS(3515),
    [anon_sym_GT_GT] = ACTIONS(3515),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3515),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_QMARK] = ACTIONS(3515),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_LT_EQ_GT] = ACTIONS(3515),
    [anon_sym_or] = ACTIONS(3513),
    [anon_sym_and] = ACTIONS(3513),
    [anon_sym_bitor] = ACTIONS(3513),
    [anon_sym_xor] = ACTIONS(3513),
    [anon_sym_bitand] = ACTIONS(3513),
    [anon_sym_not_eq] = ACTIONS(3513),
    [anon_sym_DASH_DASH] = ACTIONS(3515),
    [anon_sym_PLUS_PLUS] = ACTIONS(3515),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(3513),
    [anon_sym_DOT_STAR] = ACTIONS(3515),
    [anon_sym_DASH_GT] = ACTIONS(3515),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1062] = {
    [sym_string_literal] = STATE(2674),
    [sym_template_argument_list] = STATE(1141),
    [sym_raw_string_literal] = STATE(2674),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2233),
    [sym_identifier] = ACTIONS(3822),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3837),
    [anon_sym_COMMA] = ACTIONS(3837),
    [anon_sym_RPAREN] = ACTIONS(3837),
    [anon_sym_LPAREN2] = ACTIONS(3837),
    [anon_sym_TILDE] = ACTIONS(3830),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3834),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3837),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3834),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(3968),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON] = ACTIONS(3822),
    [anon_sym___extension__] = ACTIONS(3822),
    [anon_sym_in] = ACTIONS(3822),
    [anon_sym_out] = ACTIONS(3822),
    [anon_sym_inout] = ACTIONS(3822),
    [anon_sym_extern] = ACTIONS(3822),
    [anon_sym___attribute__] = ACTIONS(3822),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3830),
    [anon_sym___declspec] = ACTIONS(3822),
    [anon_sym___based] = ACTIONS(3822),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_signed] = ACTIONS(3848),
    [anon_sym_unsigned] = ACTIONS(3848),
    [anon_sym_long] = ACTIONS(3848),
    [anon_sym_short] = ACTIONS(3848),
    [anon_sym_LBRACK] = ACTIONS(3834),
    [anon_sym_static] = ACTIONS(3822),
    [anon_sym_EQ] = ACTIONS(3834),
    [anon_sym_register] = ACTIONS(3822),
    [anon_sym_inline] = ACTIONS(3822),
    [anon_sym___inline] = ACTIONS(3822),
    [anon_sym___inline__] = ACTIONS(3822),
    [anon_sym___forceinline] = ACTIONS(3822),
    [anon_sym_thread_local] = ACTIONS(3822),
    [anon_sym___thread] = ACTIONS(3822),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3822),
    [anon_sym_volatile] = ACTIONS(3822),
    [anon_sym_restrict] = ACTIONS(3822),
    [anon_sym___restrict__] = ACTIONS(3822),
    [anon_sym__Atomic] = ACTIONS(3822),
    [anon_sym__Noreturn] = ACTIONS(3822),
    [anon_sym_noreturn] = ACTIONS(3822),
    [anon_sym_mutable] = ACTIONS(3822),
    [anon_sym_constinit] = ACTIONS(3822),
    [anon_sym_consteval] = ACTIONS(3822),
    [anon_sym_alignas] = ACTIONS(3822),
    [anon_sym__Alignas] = ACTIONS(3822),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3824),
    [anon_sym_SLASH_EQ] = ACTIONS(3824),
    [anon_sym_PERCENT_EQ] = ACTIONS(3824),
    [anon_sym_PLUS_EQ] = ACTIONS(3824),
    [anon_sym_DASH_EQ] = ACTIONS(3824),
    [anon_sym_LT_LT_EQ] = ACTIONS(3824),
    [anon_sym_GT_GT_EQ] = ACTIONS(3824),
    [anon_sym_AMP_EQ] = ACTIONS(3824),
    [anon_sym_CARET_EQ] = ACTIONS(3824),
    [anon_sym_PIPE_EQ] = ACTIONS(3824),
    [anon_sym_and_eq] = ACTIONS(3971),
    [anon_sym_or_eq] = ACTIONS(3971),
    [anon_sym_xor_eq] = ACTIONS(3971),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3832),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3832),
    [anon_sym_not_eq] = ACTIONS(3832),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3832),
    [anon_sym_L_DQUOTE] = ACTIONS(3973),
    [anon_sym_u_DQUOTE] = ACTIONS(3973),
    [anon_sym_U_DQUOTE] = ACTIONS(3973),
    [anon_sym_u8_DQUOTE] = ACTIONS(3973),
    [anon_sym_DQUOTE] = ACTIONS(3973),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3822),
    [anon_sym_decltype] = ACTIONS(3822),
    [sym_virtual] = ACTIONS(3822),
    [anon_sym_template] = ACTIONS(3822),
    [anon_sym_operator] = ACTIONS(3822),
    [anon_sym_R_DQUOTE] = ACTIONS(3975),
    [anon_sym_LR_DQUOTE] = ACTIONS(3975),
    [anon_sym_uR_DQUOTE] = ACTIONS(3975),
    [anon_sym_UR_DQUOTE] = ACTIONS(3975),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3975),
    [anon_sym_DASH_GT_STAR] = ACTIONS(3824),
    [anon_sym_precise] = ACTIONS(3822),
    [anon_sym_shared] = ACTIONS(3822),
    [anon_sym_groupshared] = ACTIONS(3822),
    [anon_sym_uniform] = ACTIONS(3822),
    [anon_sym_row_major] = ACTIONS(3822),
    [anon_sym_column_major] = ACTIONS(3822),
    [anon_sym_globallycoherent] = ACTIONS(3822),
    [anon_sym_centroid] = ACTIONS(3822),
    [anon_sym_noperspective] = ACTIONS(3822),
    [anon_sym_nointerpolation] = ACTIONS(3822),
    [anon_sym_sample] = ACTIONS(3822),
    [anon_sym_linear] = ACTIONS(3822),
    [anon_sym_snorm] = ACTIONS(3822),
    [anon_sym_unorm] = ACTIONS(3822),
    [anon_sym_point] = ACTIONS(3822),
    [anon_sym_line] = ACTIONS(3822),
    [anon_sym_triangleadj] = ACTIONS(3822),
    [anon_sym_lineadj] = ACTIONS(3822),
    [anon_sym_triangle] = ACTIONS(3822),
  },
  [1063] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(1456),
    [sym_raw_string_literal] = STATE(2868),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2233),
    [sym_identifier] = ACTIONS(3822),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3837),
    [anon_sym_TILDE] = ACTIONS(3830),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3834),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3837),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3834),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(3840),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON] = ACTIONS(3896),
    [anon_sym_SEMI] = ACTIONS(3824),
    [anon_sym___extension__] = ACTIONS(3822),
    [anon_sym_in] = ACTIONS(3822),
    [anon_sym_out] = ACTIONS(3822),
    [anon_sym_inout] = ACTIONS(3822),
    [anon_sym_extern] = ACTIONS(3822),
    [anon_sym___attribute__] = ACTIONS(3822),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3830),
    [anon_sym___declspec] = ACTIONS(3822),
    [anon_sym___based] = ACTIONS(3822),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_signed] = ACTIONS(3848),
    [anon_sym_unsigned] = ACTIONS(3848),
    [anon_sym_long] = ACTIONS(3848),
    [anon_sym_short] = ACTIONS(3848),
    [anon_sym_LBRACK] = ACTIONS(3834),
    [anon_sym_static] = ACTIONS(3822),
    [anon_sym_EQ] = ACTIONS(3854),
    [anon_sym_register] = ACTIONS(3822),
    [anon_sym_inline] = ACTIONS(3822),
    [anon_sym___inline] = ACTIONS(3822),
    [anon_sym___inline__] = ACTIONS(3822),
    [anon_sym___forceinline] = ACTIONS(3822),
    [anon_sym_thread_local] = ACTIONS(3822),
    [anon_sym___thread] = ACTIONS(3822),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3822),
    [anon_sym_volatile] = ACTIONS(3822),
    [anon_sym_restrict] = ACTIONS(3822),
    [anon_sym___restrict__] = ACTIONS(3822),
    [anon_sym__Atomic] = ACTIONS(3822),
    [anon_sym__Noreturn] = ACTIONS(3822),
    [anon_sym_noreturn] = ACTIONS(3822),
    [anon_sym_mutable] = ACTIONS(3822),
    [anon_sym_constinit] = ACTIONS(3822),
    [anon_sym_consteval] = ACTIONS(3822),
    [anon_sym_alignas] = ACTIONS(3822),
    [anon_sym__Alignas] = ACTIONS(3822),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3856),
    [anon_sym_SLASH_EQ] = ACTIONS(3856),
    [anon_sym_PERCENT_EQ] = ACTIONS(3856),
    [anon_sym_PLUS_EQ] = ACTIONS(3856),
    [anon_sym_DASH_EQ] = ACTIONS(3856),
    [anon_sym_LT_LT_EQ] = ACTIONS(3856),
    [anon_sym_GT_GT_EQ] = ACTIONS(3856),
    [anon_sym_AMP_EQ] = ACTIONS(3856),
    [anon_sym_CARET_EQ] = ACTIONS(3856),
    [anon_sym_PIPE_EQ] = ACTIONS(3856),
    [anon_sym_and_eq] = ACTIONS(3854),
    [anon_sym_or_eq] = ACTIONS(3854),
    [anon_sym_xor_eq] = ACTIONS(3854),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3832),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3832),
    [anon_sym_not_eq] = ACTIONS(3832),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3822),
    [anon_sym_decltype] = ACTIONS(3822),
    [sym_virtual] = ACTIONS(3822),
    [anon_sym_template] = ACTIONS(3822),
    [anon_sym_operator] = ACTIONS(3822),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_precise] = ACTIONS(3822),
    [anon_sym_shared] = ACTIONS(3822),
    [anon_sym_groupshared] = ACTIONS(3822),
    [anon_sym_uniform] = ACTIONS(3822),
    [anon_sym_row_major] = ACTIONS(3822),
    [anon_sym_column_major] = ACTIONS(3822),
    [anon_sym_globallycoherent] = ACTIONS(3822),
    [anon_sym_centroid] = ACTIONS(3822),
    [anon_sym_noperspective] = ACTIONS(3822),
    [anon_sym_nointerpolation] = ACTIONS(3822),
    [anon_sym_sample] = ACTIONS(3822),
    [anon_sym_linear] = ACTIONS(3822),
    [anon_sym_snorm] = ACTIONS(3822),
    [anon_sym_unorm] = ACTIONS(3822),
    [anon_sym_point] = ACTIONS(3822),
    [anon_sym_line] = ACTIONS(3822),
    [anon_sym_triangleadj] = ACTIONS(3822),
    [anon_sym_lineadj] = ACTIONS(3822),
    [anon_sym_triangle] = ACTIONS(3822),
  },
  [1064] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(1456),
    [sym_raw_string_literal] = STATE(2868),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2233),
    [sym_identifier] = ACTIONS(3822),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_RPAREN] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3837),
    [anon_sym_TILDE] = ACTIONS(3830),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3834),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3837),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3834),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(3840),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_SEMI] = ACTIONS(3824),
    [anon_sym___extension__] = ACTIONS(3822),
    [anon_sym_in] = ACTIONS(3822),
    [anon_sym_out] = ACTIONS(3822),
    [anon_sym_inout] = ACTIONS(3822),
    [anon_sym_extern] = ACTIONS(3822),
    [anon_sym___attribute__] = ACTIONS(3822),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3830),
    [anon_sym___declspec] = ACTIONS(3822),
    [anon_sym___based] = ACTIONS(3822),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_signed] = ACTIONS(3848),
    [anon_sym_unsigned] = ACTIONS(3848),
    [anon_sym_long] = ACTIONS(3848),
    [anon_sym_short] = ACTIONS(3848),
    [anon_sym_LBRACK] = ACTIONS(3834),
    [anon_sym_static] = ACTIONS(3822),
    [anon_sym_EQ] = ACTIONS(3854),
    [anon_sym_register] = ACTIONS(3822),
    [anon_sym_inline] = ACTIONS(3822),
    [anon_sym___inline] = ACTIONS(3822),
    [anon_sym___inline__] = ACTIONS(3822),
    [anon_sym___forceinline] = ACTIONS(3822),
    [anon_sym_thread_local] = ACTIONS(3822),
    [anon_sym___thread] = ACTIONS(3822),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3822),
    [anon_sym_volatile] = ACTIONS(3822),
    [anon_sym_restrict] = ACTIONS(3822),
    [anon_sym___restrict__] = ACTIONS(3822),
    [anon_sym__Atomic] = ACTIONS(3822),
    [anon_sym__Noreturn] = ACTIONS(3822),
    [anon_sym_noreturn] = ACTIONS(3822),
    [anon_sym_mutable] = ACTIONS(3822),
    [anon_sym_constinit] = ACTIONS(3822),
    [anon_sym_consteval] = ACTIONS(3822),
    [anon_sym_alignas] = ACTIONS(3822),
    [anon_sym__Alignas] = ACTIONS(3822),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3856),
    [anon_sym_SLASH_EQ] = ACTIONS(3856),
    [anon_sym_PERCENT_EQ] = ACTIONS(3856),
    [anon_sym_PLUS_EQ] = ACTIONS(3856),
    [anon_sym_DASH_EQ] = ACTIONS(3856),
    [anon_sym_LT_LT_EQ] = ACTIONS(3856),
    [anon_sym_GT_GT_EQ] = ACTIONS(3856),
    [anon_sym_AMP_EQ] = ACTIONS(3856),
    [anon_sym_CARET_EQ] = ACTIONS(3856),
    [anon_sym_PIPE_EQ] = ACTIONS(3856),
    [anon_sym_and_eq] = ACTIONS(3854),
    [anon_sym_or_eq] = ACTIONS(3854),
    [anon_sym_xor_eq] = ACTIONS(3854),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3832),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3832),
    [anon_sym_not_eq] = ACTIONS(3832),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3822),
    [anon_sym_decltype] = ACTIONS(3822),
    [sym_virtual] = ACTIONS(3822),
    [anon_sym_template] = ACTIONS(3822),
    [anon_sym_operator] = ACTIONS(3822),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_precise] = ACTIONS(3822),
    [anon_sym_shared] = ACTIONS(3822),
    [anon_sym_groupshared] = ACTIONS(3822),
    [anon_sym_uniform] = ACTIONS(3822),
    [anon_sym_row_major] = ACTIONS(3822),
    [anon_sym_column_major] = ACTIONS(3822),
    [anon_sym_globallycoherent] = ACTIONS(3822),
    [anon_sym_centroid] = ACTIONS(3822),
    [anon_sym_noperspective] = ACTIONS(3822),
    [anon_sym_nointerpolation] = ACTIONS(3822),
    [anon_sym_sample] = ACTIONS(3822),
    [anon_sym_linear] = ACTIONS(3822),
    [anon_sym_snorm] = ACTIONS(3822),
    [anon_sym_unorm] = ACTIONS(3822),
    [anon_sym_point] = ACTIONS(3822),
    [anon_sym_line] = ACTIONS(3822),
    [anon_sym_triangleadj] = ACTIONS(3822),
    [anon_sym_lineadj] = ACTIONS(3822),
    [anon_sym_triangle] = ACTIONS(3822),
  },
  [1065] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(1456),
    [sym_raw_string_literal] = STATE(2868),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2233),
    [sym_identifier] = ACTIONS(3822),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3837),
    [anon_sym_TILDE] = ACTIONS(3830),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3834),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3837),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3834),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(3840),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON] = ACTIONS(3977),
    [anon_sym_SEMI] = ACTIONS(3824),
    [anon_sym___extension__] = ACTIONS(3822),
    [anon_sym_in] = ACTIONS(3822),
    [anon_sym_out] = ACTIONS(3822),
    [anon_sym_inout] = ACTIONS(3822),
    [anon_sym_extern] = ACTIONS(3822),
    [anon_sym___attribute__] = ACTIONS(3822),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3830),
    [anon_sym___declspec] = ACTIONS(3822),
    [anon_sym___based] = ACTIONS(3822),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_signed] = ACTIONS(3848),
    [anon_sym_unsigned] = ACTIONS(3848),
    [anon_sym_long] = ACTIONS(3848),
    [anon_sym_short] = ACTIONS(3848),
    [anon_sym_LBRACK] = ACTIONS(3834),
    [anon_sym_static] = ACTIONS(3822),
    [anon_sym_EQ] = ACTIONS(3854),
    [anon_sym_register] = ACTIONS(3822),
    [anon_sym_inline] = ACTIONS(3822),
    [anon_sym___inline] = ACTIONS(3822),
    [anon_sym___inline__] = ACTIONS(3822),
    [anon_sym___forceinline] = ACTIONS(3822),
    [anon_sym_thread_local] = ACTIONS(3822),
    [anon_sym___thread] = ACTIONS(3822),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3822),
    [anon_sym_volatile] = ACTIONS(3822),
    [anon_sym_restrict] = ACTIONS(3822),
    [anon_sym___restrict__] = ACTIONS(3822),
    [anon_sym__Atomic] = ACTIONS(3822),
    [anon_sym__Noreturn] = ACTIONS(3822),
    [anon_sym_noreturn] = ACTIONS(3822),
    [anon_sym_mutable] = ACTIONS(3822),
    [anon_sym_constinit] = ACTIONS(3822),
    [anon_sym_consteval] = ACTIONS(3822),
    [anon_sym_alignas] = ACTIONS(3822),
    [anon_sym__Alignas] = ACTIONS(3822),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3856),
    [anon_sym_SLASH_EQ] = ACTIONS(3856),
    [anon_sym_PERCENT_EQ] = ACTIONS(3856),
    [anon_sym_PLUS_EQ] = ACTIONS(3856),
    [anon_sym_DASH_EQ] = ACTIONS(3856),
    [anon_sym_LT_LT_EQ] = ACTIONS(3856),
    [anon_sym_GT_GT_EQ] = ACTIONS(3856),
    [anon_sym_AMP_EQ] = ACTIONS(3856),
    [anon_sym_CARET_EQ] = ACTIONS(3856),
    [anon_sym_PIPE_EQ] = ACTIONS(3856),
    [anon_sym_and_eq] = ACTIONS(3854),
    [anon_sym_or_eq] = ACTIONS(3854),
    [anon_sym_xor_eq] = ACTIONS(3854),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3832),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3832),
    [anon_sym_not_eq] = ACTIONS(3832),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3822),
    [anon_sym_decltype] = ACTIONS(3822),
    [sym_virtual] = ACTIONS(3822),
    [anon_sym_template] = ACTIONS(3822),
    [anon_sym_operator] = ACTIONS(3822),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_precise] = ACTIONS(3822),
    [anon_sym_shared] = ACTIONS(3822),
    [anon_sym_groupshared] = ACTIONS(3822),
    [anon_sym_uniform] = ACTIONS(3822),
    [anon_sym_row_major] = ACTIONS(3822),
    [anon_sym_column_major] = ACTIONS(3822),
    [anon_sym_globallycoherent] = ACTIONS(3822),
    [anon_sym_centroid] = ACTIONS(3822),
    [anon_sym_noperspective] = ACTIONS(3822),
    [anon_sym_nointerpolation] = ACTIONS(3822),
    [anon_sym_sample] = ACTIONS(3822),
    [anon_sym_linear] = ACTIONS(3822),
    [anon_sym_snorm] = ACTIONS(3822),
    [anon_sym_unorm] = ACTIONS(3822),
    [anon_sym_point] = ACTIONS(3822),
    [anon_sym_line] = ACTIONS(3822),
    [anon_sym_triangleadj] = ACTIONS(3822),
    [anon_sym_lineadj] = ACTIONS(3822),
    [anon_sym_triangle] = ACTIONS(3822),
  },
  [1066] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(1456),
    [sym_raw_string_literal] = STATE(2868),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2233),
    [sym_identifier] = ACTIONS(3822),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3837),
    [anon_sym_TILDE] = ACTIONS(3830),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3834),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3837),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3834),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(3840),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON] = ACTIONS(3920),
    [anon_sym_SEMI] = ACTIONS(3824),
    [anon_sym___extension__] = ACTIONS(3822),
    [anon_sym_in] = ACTIONS(3822),
    [anon_sym_out] = ACTIONS(3822),
    [anon_sym_inout] = ACTIONS(3822),
    [anon_sym_extern] = ACTIONS(3822),
    [anon_sym___attribute__] = ACTIONS(3822),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3830),
    [anon_sym___declspec] = ACTIONS(3822),
    [anon_sym___based] = ACTIONS(3822),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_signed] = ACTIONS(3848),
    [anon_sym_unsigned] = ACTIONS(3848),
    [anon_sym_long] = ACTIONS(3848),
    [anon_sym_short] = ACTIONS(3848),
    [anon_sym_LBRACK] = ACTIONS(3834),
    [anon_sym_static] = ACTIONS(3822),
    [anon_sym_EQ] = ACTIONS(3854),
    [anon_sym_register] = ACTIONS(3822),
    [anon_sym_inline] = ACTIONS(3822),
    [anon_sym___inline] = ACTIONS(3822),
    [anon_sym___inline__] = ACTIONS(3822),
    [anon_sym___forceinline] = ACTIONS(3822),
    [anon_sym_thread_local] = ACTIONS(3822),
    [anon_sym___thread] = ACTIONS(3822),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3822),
    [anon_sym_volatile] = ACTIONS(3822),
    [anon_sym_restrict] = ACTIONS(3822),
    [anon_sym___restrict__] = ACTIONS(3822),
    [anon_sym__Atomic] = ACTIONS(3822),
    [anon_sym__Noreturn] = ACTIONS(3822),
    [anon_sym_noreturn] = ACTIONS(3822),
    [anon_sym_mutable] = ACTIONS(3822),
    [anon_sym_constinit] = ACTIONS(3822),
    [anon_sym_consteval] = ACTIONS(3822),
    [anon_sym_alignas] = ACTIONS(3822),
    [anon_sym__Alignas] = ACTIONS(3822),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3856),
    [anon_sym_SLASH_EQ] = ACTIONS(3856),
    [anon_sym_PERCENT_EQ] = ACTIONS(3856),
    [anon_sym_PLUS_EQ] = ACTIONS(3856),
    [anon_sym_DASH_EQ] = ACTIONS(3856),
    [anon_sym_LT_LT_EQ] = ACTIONS(3856),
    [anon_sym_GT_GT_EQ] = ACTIONS(3856),
    [anon_sym_AMP_EQ] = ACTIONS(3856),
    [anon_sym_CARET_EQ] = ACTIONS(3856),
    [anon_sym_PIPE_EQ] = ACTIONS(3856),
    [anon_sym_and_eq] = ACTIONS(3854),
    [anon_sym_or_eq] = ACTIONS(3854),
    [anon_sym_xor_eq] = ACTIONS(3854),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3832),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3832),
    [anon_sym_not_eq] = ACTIONS(3832),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3822),
    [anon_sym_decltype] = ACTIONS(3822),
    [sym_virtual] = ACTIONS(3822),
    [anon_sym_template] = ACTIONS(3822),
    [anon_sym_operator] = ACTIONS(3822),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_precise] = ACTIONS(3822),
    [anon_sym_shared] = ACTIONS(3822),
    [anon_sym_groupshared] = ACTIONS(3822),
    [anon_sym_uniform] = ACTIONS(3822),
    [anon_sym_row_major] = ACTIONS(3822),
    [anon_sym_column_major] = ACTIONS(3822),
    [anon_sym_globallycoherent] = ACTIONS(3822),
    [anon_sym_centroid] = ACTIONS(3822),
    [anon_sym_noperspective] = ACTIONS(3822),
    [anon_sym_nointerpolation] = ACTIONS(3822),
    [anon_sym_sample] = ACTIONS(3822),
    [anon_sym_linear] = ACTIONS(3822),
    [anon_sym_snorm] = ACTIONS(3822),
    [anon_sym_unorm] = ACTIONS(3822),
    [anon_sym_point] = ACTIONS(3822),
    [anon_sym_line] = ACTIONS(3822),
    [anon_sym_triangleadj] = ACTIONS(3822),
    [anon_sym_lineadj] = ACTIONS(3822),
    [anon_sym_triangle] = ACTIONS(3822),
  },
  [1067] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(1314),
    [sym_raw_string_literal] = STATE(2868),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2233),
    [sym_identifier] = ACTIONS(3822),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3837),
    [anon_sym_COMMA] = ACTIONS(3837),
    [anon_sym_RPAREN] = ACTIONS(3837),
    [anon_sym_LPAREN2] = ACTIONS(3837),
    [anon_sym_TILDE] = ACTIONS(3830),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3834),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3837),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3834),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(3840),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON] = ACTIONS(3822),
    [anon_sym___extension__] = ACTIONS(3822),
    [anon_sym_in] = ACTIONS(3822),
    [anon_sym_out] = ACTIONS(3822),
    [anon_sym_inout] = ACTIONS(3822),
    [anon_sym_extern] = ACTIONS(3822),
    [anon_sym___attribute__] = ACTIONS(3822),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3830),
    [anon_sym___declspec] = ACTIONS(3822),
    [anon_sym___based] = ACTIONS(3822),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_signed] = ACTIONS(3848),
    [anon_sym_unsigned] = ACTIONS(3848),
    [anon_sym_long] = ACTIONS(3848),
    [anon_sym_short] = ACTIONS(3848),
    [anon_sym_LBRACK] = ACTIONS(3834),
    [anon_sym_static] = ACTIONS(3822),
    [anon_sym_EQ] = ACTIONS(3822),
    [anon_sym_register] = ACTIONS(3822),
    [anon_sym_inline] = ACTIONS(3822),
    [anon_sym___inline] = ACTIONS(3822),
    [anon_sym___inline__] = ACTIONS(3822),
    [anon_sym___forceinline] = ACTIONS(3822),
    [anon_sym_thread_local] = ACTIONS(3822),
    [anon_sym___thread] = ACTIONS(3822),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3822),
    [anon_sym_volatile] = ACTIONS(3822),
    [anon_sym_restrict] = ACTIONS(3822),
    [anon_sym___restrict__] = ACTIONS(3822),
    [anon_sym__Atomic] = ACTIONS(3822),
    [anon_sym__Noreturn] = ACTIONS(3822),
    [anon_sym_noreturn] = ACTIONS(3822),
    [anon_sym_mutable] = ACTIONS(3822),
    [anon_sym_constinit] = ACTIONS(3822),
    [anon_sym_consteval] = ACTIONS(3822),
    [anon_sym_alignas] = ACTIONS(3822),
    [anon_sym__Alignas] = ACTIONS(3822),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3856),
    [anon_sym_SLASH_EQ] = ACTIONS(3856),
    [anon_sym_PERCENT_EQ] = ACTIONS(3856),
    [anon_sym_PLUS_EQ] = ACTIONS(3856),
    [anon_sym_DASH_EQ] = ACTIONS(3856),
    [anon_sym_LT_LT_EQ] = ACTIONS(3856),
    [anon_sym_GT_GT_EQ] = ACTIONS(3856),
    [anon_sym_AMP_EQ] = ACTIONS(3856),
    [anon_sym_CARET_EQ] = ACTIONS(3856),
    [anon_sym_PIPE_EQ] = ACTIONS(3856),
    [anon_sym_and_eq] = ACTIONS(3854),
    [anon_sym_or_eq] = ACTIONS(3854),
    [anon_sym_xor_eq] = ACTIONS(3854),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3832),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3832),
    [anon_sym_not_eq] = ACTIONS(3832),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3822),
    [anon_sym_decltype] = ACTIONS(3822),
    [sym_virtual] = ACTIONS(3822),
    [anon_sym_template] = ACTIONS(3822),
    [anon_sym_operator] = ACTIONS(3822),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_precise] = ACTIONS(3822),
    [anon_sym_shared] = ACTIONS(3822),
    [anon_sym_groupshared] = ACTIONS(3822),
    [anon_sym_uniform] = ACTIONS(3822),
    [anon_sym_row_major] = ACTIONS(3822),
    [anon_sym_column_major] = ACTIONS(3822),
    [anon_sym_globallycoherent] = ACTIONS(3822),
    [anon_sym_centroid] = ACTIONS(3822),
    [anon_sym_noperspective] = ACTIONS(3822),
    [anon_sym_nointerpolation] = ACTIONS(3822),
    [anon_sym_sample] = ACTIONS(3822),
    [anon_sym_linear] = ACTIONS(3822),
    [anon_sym_snorm] = ACTIONS(3822),
    [anon_sym_unorm] = ACTIONS(3822),
    [anon_sym_point] = ACTIONS(3822),
    [anon_sym_line] = ACTIONS(3822),
    [anon_sym_triangleadj] = ACTIONS(3822),
    [anon_sym_lineadj] = ACTIONS(3822),
    [anon_sym_triangle] = ACTIONS(3822),
  },
  [1068] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(1456),
    [sym_raw_string_literal] = STATE(2868),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2233),
    [sym_identifier] = ACTIONS(3822),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3837),
    [anon_sym_TILDE] = ACTIONS(3830),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3834),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3837),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3834),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(3840),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON] = ACTIONS(3926),
    [anon_sym_SEMI] = ACTIONS(3824),
    [anon_sym___extension__] = ACTIONS(3822),
    [anon_sym_in] = ACTIONS(3822),
    [anon_sym_out] = ACTIONS(3822),
    [anon_sym_inout] = ACTIONS(3822),
    [anon_sym_extern] = ACTIONS(3822),
    [anon_sym___attribute__] = ACTIONS(3822),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3830),
    [anon_sym___declspec] = ACTIONS(3822),
    [anon_sym___based] = ACTIONS(3822),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_signed] = ACTIONS(3848),
    [anon_sym_unsigned] = ACTIONS(3848),
    [anon_sym_long] = ACTIONS(3848),
    [anon_sym_short] = ACTIONS(3848),
    [anon_sym_LBRACK] = ACTIONS(3834),
    [anon_sym_static] = ACTIONS(3822),
    [anon_sym_EQ] = ACTIONS(3854),
    [anon_sym_register] = ACTIONS(3822),
    [anon_sym_inline] = ACTIONS(3822),
    [anon_sym___inline] = ACTIONS(3822),
    [anon_sym___inline__] = ACTIONS(3822),
    [anon_sym___forceinline] = ACTIONS(3822),
    [anon_sym_thread_local] = ACTIONS(3822),
    [anon_sym___thread] = ACTIONS(3822),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3822),
    [anon_sym_volatile] = ACTIONS(3822),
    [anon_sym_restrict] = ACTIONS(3822),
    [anon_sym___restrict__] = ACTIONS(3822),
    [anon_sym__Atomic] = ACTIONS(3822),
    [anon_sym__Noreturn] = ACTIONS(3822),
    [anon_sym_noreturn] = ACTIONS(3822),
    [anon_sym_mutable] = ACTIONS(3822),
    [anon_sym_constinit] = ACTIONS(3822),
    [anon_sym_consteval] = ACTIONS(3822),
    [anon_sym_alignas] = ACTIONS(3822),
    [anon_sym__Alignas] = ACTIONS(3822),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3856),
    [anon_sym_SLASH_EQ] = ACTIONS(3856),
    [anon_sym_PERCENT_EQ] = ACTIONS(3856),
    [anon_sym_PLUS_EQ] = ACTIONS(3856),
    [anon_sym_DASH_EQ] = ACTIONS(3856),
    [anon_sym_LT_LT_EQ] = ACTIONS(3856),
    [anon_sym_GT_GT_EQ] = ACTIONS(3856),
    [anon_sym_AMP_EQ] = ACTIONS(3856),
    [anon_sym_CARET_EQ] = ACTIONS(3856),
    [anon_sym_PIPE_EQ] = ACTIONS(3856),
    [anon_sym_and_eq] = ACTIONS(3854),
    [anon_sym_or_eq] = ACTIONS(3854),
    [anon_sym_xor_eq] = ACTIONS(3854),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3832),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3832),
    [anon_sym_not_eq] = ACTIONS(3832),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3822),
    [anon_sym_decltype] = ACTIONS(3822),
    [sym_virtual] = ACTIONS(3822),
    [anon_sym_template] = ACTIONS(3822),
    [anon_sym_operator] = ACTIONS(3822),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_precise] = ACTIONS(3822),
    [anon_sym_shared] = ACTIONS(3822),
    [anon_sym_groupshared] = ACTIONS(3822),
    [anon_sym_uniform] = ACTIONS(3822),
    [anon_sym_row_major] = ACTIONS(3822),
    [anon_sym_column_major] = ACTIONS(3822),
    [anon_sym_globallycoherent] = ACTIONS(3822),
    [anon_sym_centroid] = ACTIONS(3822),
    [anon_sym_noperspective] = ACTIONS(3822),
    [anon_sym_nointerpolation] = ACTIONS(3822),
    [anon_sym_sample] = ACTIONS(3822),
    [anon_sym_linear] = ACTIONS(3822),
    [anon_sym_snorm] = ACTIONS(3822),
    [anon_sym_unorm] = ACTIONS(3822),
    [anon_sym_point] = ACTIONS(3822),
    [anon_sym_line] = ACTIONS(3822),
    [anon_sym_triangleadj] = ACTIONS(3822),
    [anon_sym_lineadj] = ACTIONS(3822),
    [anon_sym_triangle] = ACTIONS(3822),
  },
  [1069] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(1456),
    [sym_raw_string_literal] = STATE(2868),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2233),
    [sym_identifier] = ACTIONS(3822),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3837),
    [anon_sym_TILDE] = ACTIONS(3830),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3834),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3837),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3834),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(3840),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON] = ACTIONS(3916),
    [anon_sym_SEMI] = ACTIONS(3824),
    [anon_sym___extension__] = ACTIONS(3822),
    [anon_sym_in] = ACTIONS(3822),
    [anon_sym_out] = ACTIONS(3822),
    [anon_sym_inout] = ACTIONS(3822),
    [anon_sym_extern] = ACTIONS(3822),
    [anon_sym___attribute__] = ACTIONS(3822),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3830),
    [anon_sym___declspec] = ACTIONS(3822),
    [anon_sym___based] = ACTIONS(3822),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_signed] = ACTIONS(3848),
    [anon_sym_unsigned] = ACTIONS(3848),
    [anon_sym_long] = ACTIONS(3848),
    [anon_sym_short] = ACTIONS(3848),
    [anon_sym_LBRACK] = ACTIONS(3834),
    [anon_sym_static] = ACTIONS(3822),
    [anon_sym_EQ] = ACTIONS(3854),
    [anon_sym_register] = ACTIONS(3822),
    [anon_sym_inline] = ACTIONS(3822),
    [anon_sym___inline] = ACTIONS(3822),
    [anon_sym___inline__] = ACTIONS(3822),
    [anon_sym___forceinline] = ACTIONS(3822),
    [anon_sym_thread_local] = ACTIONS(3822),
    [anon_sym___thread] = ACTIONS(3822),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3822),
    [anon_sym_volatile] = ACTIONS(3822),
    [anon_sym_restrict] = ACTIONS(3822),
    [anon_sym___restrict__] = ACTIONS(3822),
    [anon_sym__Atomic] = ACTIONS(3822),
    [anon_sym__Noreturn] = ACTIONS(3822),
    [anon_sym_noreturn] = ACTIONS(3822),
    [anon_sym_mutable] = ACTIONS(3822),
    [anon_sym_constinit] = ACTIONS(3822),
    [anon_sym_consteval] = ACTIONS(3822),
    [anon_sym_alignas] = ACTIONS(3822),
    [anon_sym__Alignas] = ACTIONS(3822),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3856),
    [anon_sym_SLASH_EQ] = ACTIONS(3856),
    [anon_sym_PERCENT_EQ] = ACTIONS(3856),
    [anon_sym_PLUS_EQ] = ACTIONS(3856),
    [anon_sym_DASH_EQ] = ACTIONS(3856),
    [anon_sym_LT_LT_EQ] = ACTIONS(3856),
    [anon_sym_GT_GT_EQ] = ACTIONS(3856),
    [anon_sym_AMP_EQ] = ACTIONS(3856),
    [anon_sym_CARET_EQ] = ACTIONS(3856),
    [anon_sym_PIPE_EQ] = ACTIONS(3856),
    [anon_sym_and_eq] = ACTIONS(3854),
    [anon_sym_or_eq] = ACTIONS(3854),
    [anon_sym_xor_eq] = ACTIONS(3854),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3832),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3832),
    [anon_sym_not_eq] = ACTIONS(3832),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3822),
    [anon_sym_decltype] = ACTIONS(3822),
    [sym_virtual] = ACTIONS(3822),
    [anon_sym_template] = ACTIONS(3822),
    [anon_sym_operator] = ACTIONS(3822),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_precise] = ACTIONS(3822),
    [anon_sym_shared] = ACTIONS(3822),
    [anon_sym_groupshared] = ACTIONS(3822),
    [anon_sym_uniform] = ACTIONS(3822),
    [anon_sym_row_major] = ACTIONS(3822),
    [anon_sym_column_major] = ACTIONS(3822),
    [anon_sym_globallycoherent] = ACTIONS(3822),
    [anon_sym_centroid] = ACTIONS(3822),
    [anon_sym_noperspective] = ACTIONS(3822),
    [anon_sym_nointerpolation] = ACTIONS(3822),
    [anon_sym_sample] = ACTIONS(3822),
    [anon_sym_linear] = ACTIONS(3822),
    [anon_sym_snorm] = ACTIONS(3822),
    [anon_sym_unorm] = ACTIONS(3822),
    [anon_sym_point] = ACTIONS(3822),
    [anon_sym_line] = ACTIONS(3822),
    [anon_sym_triangleadj] = ACTIONS(3822),
    [anon_sym_lineadj] = ACTIONS(3822),
    [anon_sym_triangle] = ACTIONS(3822),
  },
  [1070] = {
    [sym_expression] = STATE(3905),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(4009),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3515),
    [anon_sym_COMMA] = ACTIONS(3515),
    [anon_sym_RPAREN] = ACTIONS(3515),
    [anon_sym_LPAREN2] = ACTIONS(3515),
    [anon_sym_BANG] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(3513),
    [anon_sym_PLUS] = ACTIONS(3513),
    [anon_sym_STAR] = ACTIONS(3515),
    [anon_sym_SLASH] = ACTIONS(3513),
    [anon_sym_PERCENT] = ACTIONS(3515),
    [anon_sym_PIPE_PIPE] = ACTIONS(3515),
    [anon_sym_AMP_AMP] = ACTIONS(3515),
    [anon_sym_PIPE] = ACTIONS(3513),
    [anon_sym_CARET] = ACTIONS(3515),
    [anon_sym_AMP] = ACTIONS(3513),
    [anon_sym_EQ_EQ] = ACTIONS(3515),
    [anon_sym_BANG_EQ] = ACTIONS(3515),
    [anon_sym_GT] = ACTIONS(3513),
    [anon_sym_GT_EQ] = ACTIONS(3515),
    [anon_sym_LT_EQ] = ACTIONS(3513),
    [anon_sym_LT] = ACTIONS(3513),
    [anon_sym_LT_LT] = ACTIONS(3515),
    [anon_sym_GT_GT] = ACTIONS(3515),
    [anon_sym_SEMI] = ACTIONS(3515),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_RBRACE] = ACTIONS(3515),
    [anon_sym_LBRACK] = ACTIONS(3515),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_QMARK] = ACTIONS(3515),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_LT_EQ_GT] = ACTIONS(3515),
    [anon_sym_or] = ACTIONS(3513),
    [anon_sym_and] = ACTIONS(3513),
    [anon_sym_bitor] = ACTIONS(3513),
    [anon_sym_xor] = ACTIONS(3513),
    [anon_sym_bitand] = ACTIONS(3513),
    [anon_sym_not_eq] = ACTIONS(3513),
    [anon_sym_DASH_DASH] = ACTIONS(3515),
    [anon_sym_PLUS_PLUS] = ACTIONS(3515),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(3513),
    [anon_sym_DOT_STAR] = ACTIONS(3515),
    [anon_sym_DASH_GT] = ACTIONS(3515),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1071] = {
    [sym_expression] = STATE(3905),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_initializer_list] = STATE(4009),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3515),
    [anon_sym_COMMA] = ACTIONS(3515),
    [anon_sym_LPAREN2] = ACTIONS(3515),
    [anon_sym_BANG] = ACTIONS(3981),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3513),
    [anon_sym_PLUS] = ACTIONS(3513),
    [anon_sym_STAR] = ACTIONS(3515),
    [anon_sym_SLASH] = ACTIONS(3513),
    [anon_sym_PERCENT] = ACTIONS(3515),
    [anon_sym_PIPE_PIPE] = ACTIONS(3515),
    [anon_sym_AMP_AMP] = ACTIONS(3515),
    [anon_sym_PIPE] = ACTIONS(3513),
    [anon_sym_CARET] = ACTIONS(3515),
    [anon_sym_AMP] = ACTIONS(3513),
    [anon_sym_EQ_EQ] = ACTIONS(3515),
    [anon_sym_BANG_EQ] = ACTIONS(3515),
    [anon_sym_GT] = ACTIONS(3513),
    [anon_sym_GT_EQ] = ACTIONS(3515),
    [anon_sym_LT_EQ] = ACTIONS(3513),
    [anon_sym_LT] = ACTIONS(3513),
    [anon_sym_LT_LT] = ACTIONS(3515),
    [anon_sym_GT_GT] = ACTIONS(3515),
    [anon_sym_SEMI] = ACTIONS(3515),
    [anon_sym___attribute__] = ACTIONS(3513),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3515),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_QMARK] = ACTIONS(3515),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_LT_EQ_GT] = ACTIONS(3515),
    [anon_sym_or] = ACTIONS(3513),
    [anon_sym_and] = ACTIONS(3513),
    [anon_sym_bitor] = ACTIONS(3513),
    [anon_sym_xor] = ACTIONS(3513),
    [anon_sym_bitand] = ACTIONS(3513),
    [anon_sym_not_eq] = ACTIONS(3513),
    [anon_sym_DASH_DASH] = ACTIONS(3515),
    [anon_sym_PLUS_PLUS] = ACTIONS(3515),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(3513),
    [anon_sym_DOT_STAR] = ACTIONS(3515),
    [anon_sym_DASH_GT] = ACTIONS(3515),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1072] = {
    [sym_expression] = STATE(4528),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_initializer_list] = STATE(4009),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3515),
    [anon_sym_COMMA] = ACTIONS(3515),
    [anon_sym_LPAREN2] = ACTIONS(3515),
    [anon_sym_BANG] = ACTIONS(4003),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(3513),
    [anon_sym_PLUS] = ACTIONS(3513),
    [anon_sym_STAR] = ACTIONS(3515),
    [anon_sym_SLASH] = ACTIONS(3513),
    [anon_sym_PERCENT] = ACTIONS(3515),
    [anon_sym_PIPE_PIPE] = ACTIONS(3515),
    [anon_sym_AMP_AMP] = ACTIONS(3515),
    [anon_sym_PIPE] = ACTIONS(3513),
    [anon_sym_CARET] = ACTIONS(3515),
    [anon_sym_AMP] = ACTIONS(3513),
    [anon_sym_EQ_EQ] = ACTIONS(3515),
    [anon_sym_BANG_EQ] = ACTIONS(3515),
    [anon_sym_GT] = ACTIONS(3513),
    [anon_sym_GT_EQ] = ACTIONS(3515),
    [anon_sym_LT_EQ] = ACTIONS(3513),
    [anon_sym_LT] = ACTIONS(3513),
    [anon_sym_LT_LT] = ACTIONS(3515),
    [anon_sym_GT_GT] = ACTIONS(3515),
    [anon_sym_COLON] = ACTIONS(3513),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3515),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_QMARK] = ACTIONS(3515),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_LT_EQ_GT] = ACTIONS(3515),
    [anon_sym_or] = ACTIONS(3513),
    [anon_sym_and] = ACTIONS(3513),
    [anon_sym_bitor] = ACTIONS(3513),
    [anon_sym_xor] = ACTIONS(3513),
    [anon_sym_bitand] = ACTIONS(3513),
    [anon_sym_not_eq] = ACTIONS(3513),
    [anon_sym_DASH_DASH] = ACTIONS(3515),
    [anon_sym_PLUS_PLUS] = ACTIONS(3515),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(3513),
    [anon_sym_DOT_STAR] = ACTIONS(3515),
    [anon_sym_DASH_GT] = ACTIONS(3515),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1073] = {
    [sym_expression] = STATE(4557),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_initializer_list] = STATE(4828),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3515),
    [anon_sym_COMMA] = ACTIONS(3515),
    [anon_sym_LPAREN2] = ACTIONS(3515),
    [anon_sym_BANG] = ACTIONS(3756),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3513),
    [anon_sym_PLUS] = ACTIONS(3513),
    [anon_sym_STAR] = ACTIONS(3515),
    [anon_sym_SLASH] = ACTIONS(3513),
    [anon_sym_PERCENT] = ACTIONS(3515),
    [anon_sym_PIPE_PIPE] = ACTIONS(3515),
    [anon_sym_AMP_AMP] = ACTIONS(3515),
    [anon_sym_PIPE] = ACTIONS(3513),
    [anon_sym_CARET] = ACTIONS(3515),
    [anon_sym_AMP] = ACTIONS(3513),
    [anon_sym_EQ_EQ] = ACTIONS(3515),
    [anon_sym_BANG_EQ] = ACTIONS(3515),
    [anon_sym_GT] = ACTIONS(3513),
    [anon_sym_GT_EQ] = ACTIONS(3513),
    [anon_sym_LT_EQ] = ACTIONS(3513),
    [anon_sym_LT] = ACTIONS(3513),
    [anon_sym_LT_LT] = ACTIONS(3515),
    [anon_sym_GT_GT] = ACTIONS(3513),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACE] = ACTIONS(4019),
    [anon_sym_LBRACK] = ACTIONS(3515),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_QMARK] = ACTIONS(3515),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_LT_EQ_GT] = ACTIONS(3515),
    [anon_sym_or] = ACTIONS(3513),
    [anon_sym_and] = ACTIONS(3513),
    [anon_sym_bitor] = ACTIONS(3513),
    [anon_sym_xor] = ACTIONS(3513),
    [anon_sym_bitand] = ACTIONS(3513),
    [anon_sym_not_eq] = ACTIONS(3513),
    [anon_sym_DASH_DASH] = ACTIONS(3515),
    [anon_sym_PLUS_PLUS] = ACTIONS(3515),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [anon_sym_DOT] = ACTIONS(3513),
    [anon_sym_DOT_STAR] = ACTIONS(3515),
    [anon_sym_DASH_GT] = ACTIONS(3515),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(3515),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1074] = {
    [sym_expression] = STATE(3905),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_initializer_list] = STATE(4009),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3515),
    [anon_sym_COMMA] = ACTIONS(3515),
    [anon_sym_LPAREN2] = ACTIONS(3515),
    [anon_sym_BANG] = ACTIONS(4025),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(3513),
    [anon_sym_PLUS] = ACTIONS(3513),
    [anon_sym_STAR] = ACTIONS(3515),
    [anon_sym_SLASH] = ACTIONS(3513),
    [anon_sym_PERCENT] = ACTIONS(3515),
    [anon_sym_PIPE_PIPE] = ACTIONS(3515),
    [anon_sym_AMP_AMP] = ACTIONS(3515),
    [anon_sym_PIPE] = ACTIONS(3513),
    [anon_sym_CARET] = ACTIONS(3515),
    [anon_sym_AMP] = ACTIONS(3513),
    [anon_sym_EQ_EQ] = ACTIONS(3515),
    [anon_sym_BANG_EQ] = ACTIONS(3515),
    [anon_sym_GT] = ACTIONS(3513),
    [anon_sym_GT_EQ] = ACTIONS(3515),
    [anon_sym_LT_EQ] = ACTIONS(3513),
    [anon_sym_LT] = ACTIONS(3513),
    [anon_sym_LT_LT] = ACTIONS(3515),
    [anon_sym_GT_GT] = ACTIONS(3515),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3515),
    [anon_sym_RBRACK] = ACTIONS(3515),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_QMARK] = ACTIONS(3515),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_LT_EQ_GT] = ACTIONS(3515),
    [anon_sym_or] = ACTIONS(3513),
    [anon_sym_and] = ACTIONS(3513),
    [anon_sym_bitor] = ACTIONS(3513),
    [anon_sym_xor] = ACTIONS(3513),
    [anon_sym_bitand] = ACTIONS(3513),
    [anon_sym_not_eq] = ACTIONS(3513),
    [anon_sym_DASH_DASH] = ACTIONS(3515),
    [anon_sym_PLUS_PLUS] = ACTIONS(3515),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(3513),
    [anon_sym_DOT_STAR] = ACTIONS(3515),
    [anon_sym_DASH_GT] = ACTIONS(3515),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1075] = {
    [sym_expression] = STATE(4716),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4037),
    [anon_sym_COMMA] = ACTIONS(4037),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4025),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_SLASH] = ACTIONS(4041),
    [anon_sym_PERCENT] = ACTIONS(4037),
    [anon_sym_PIPE_PIPE] = ACTIONS(4037),
    [anon_sym_AMP_AMP] = ACTIONS(4037),
    [anon_sym_PIPE] = ACTIONS(4041),
    [anon_sym_CARET] = ACTIONS(4037),
    [anon_sym_AMP] = ACTIONS(1258),
    [anon_sym_EQ_EQ] = ACTIONS(4037),
    [anon_sym_BANG_EQ] = ACTIONS(4037),
    [anon_sym_GT] = ACTIONS(4041),
    [anon_sym_GT_EQ] = ACTIONS(4037),
    [anon_sym_LT_EQ] = ACTIONS(4041),
    [anon_sym_LT] = ACTIONS(4041),
    [anon_sym_LT_LT] = ACTIONS(4037),
    [anon_sym_GT_GT] = ACTIONS(4037),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4037),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_QMARK] = ACTIONS(4037),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_LT_EQ_GT] = ACTIONS(4037),
    [anon_sym_or] = ACTIONS(4041),
    [anon_sym_and] = ACTIONS(4041),
    [anon_sym_bitor] = ACTIONS(4041),
    [anon_sym_xor] = ACTIONS(4041),
    [anon_sym_bitand] = ACTIONS(4041),
    [anon_sym_not_eq] = ACTIONS(4041),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(4041),
    [anon_sym_DOT_STAR] = ACTIONS(4037),
    [anon_sym_DASH_GT] = ACTIONS(4037),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1076] = {
    [sym_identifier] = ACTIONS(1925),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1927),
    [anon_sym_COMMA] = ACTIONS(1927),
    [anon_sym_RPAREN] = ACTIONS(1927),
    [anon_sym_LPAREN2] = ACTIONS(1927),
    [anon_sym_TILDE] = ACTIONS(1927),
    [anon_sym_DASH] = ACTIONS(1925),
    [anon_sym_PLUS] = ACTIONS(1925),
    [anon_sym_STAR] = ACTIONS(1925),
    [anon_sym_SLASH] = ACTIONS(1925),
    [anon_sym_PERCENT] = ACTIONS(1925),
    [anon_sym_PIPE_PIPE] = ACTIONS(1927),
    [anon_sym_AMP_AMP] = ACTIONS(1927),
    [anon_sym_PIPE] = ACTIONS(1925),
    [anon_sym_CARET] = ACTIONS(1925),
    [anon_sym_AMP] = ACTIONS(1925),
    [anon_sym_EQ_EQ] = ACTIONS(1927),
    [anon_sym_BANG_EQ] = ACTIONS(1927),
    [anon_sym_GT] = ACTIONS(1925),
    [anon_sym_GT_EQ] = ACTIONS(1927),
    [anon_sym_LT_EQ] = ACTIONS(1925),
    [anon_sym_LT] = ACTIONS(1925),
    [anon_sym_LT_LT] = ACTIONS(1925),
    [anon_sym_GT_GT] = ACTIONS(1925),
    [anon_sym_COLON] = ACTIONS(1925),
    [anon_sym_SEMI] = ACTIONS(1927),
    [anon_sym___extension__] = ACTIONS(1925),
    [anon_sym_in] = ACTIONS(1925),
    [anon_sym_out] = ACTIONS(1925),
    [anon_sym_inout] = ACTIONS(1925),
    [anon_sym_extern] = ACTIONS(1925),
    [anon_sym___attribute__] = ACTIONS(1925),
    [anon_sym_COLON_COLON] = ACTIONS(1927),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1927),
    [anon_sym___declspec] = ACTIONS(1925),
    [anon_sym___based] = ACTIONS(1925),
    [anon_sym___cdecl] = ACTIONS(1925),
    [anon_sym___clrcall] = ACTIONS(1925),
    [anon_sym___stdcall] = ACTIONS(1925),
    [anon_sym___fastcall] = ACTIONS(1925),
    [anon_sym___thiscall] = ACTIONS(1925),
    [anon_sym___vectorcall] = ACTIONS(1925),
    [anon_sym_LBRACE] = ACTIONS(1927),
    [anon_sym_RBRACE] = ACTIONS(1927),
    [anon_sym_LBRACK] = ACTIONS(1925),
    [anon_sym_static] = ACTIONS(1925),
    [anon_sym_EQ] = ACTIONS(1925),
    [anon_sym_register] = ACTIONS(1925),
    [anon_sym_inline] = ACTIONS(1925),
    [anon_sym___inline] = ACTIONS(1925),
    [anon_sym___inline__] = ACTIONS(1925),
    [anon_sym___forceinline] = ACTIONS(1925),
    [anon_sym_thread_local] = ACTIONS(1925),
    [anon_sym___thread] = ACTIONS(1925),
    [anon_sym_const] = ACTIONS(1925),
    [anon_sym_constexpr] = ACTIONS(1925),
    [anon_sym_volatile] = ACTIONS(1925),
    [anon_sym_restrict] = ACTIONS(1925),
    [anon_sym___restrict__] = ACTIONS(1925),
    [anon_sym__Atomic] = ACTIONS(1925),
    [anon_sym__Noreturn] = ACTIONS(1925),
    [anon_sym_noreturn] = ACTIONS(1925),
    [anon_sym_mutable] = ACTIONS(1925),
    [anon_sym_constinit] = ACTIONS(1925),
    [anon_sym_consteval] = ACTIONS(1925),
    [anon_sym_alignas] = ACTIONS(1925),
    [anon_sym__Alignas] = ACTIONS(1925),
    [anon_sym_QMARK] = ACTIONS(1927),
    [anon_sym_STAR_EQ] = ACTIONS(1927),
    [anon_sym_SLASH_EQ] = ACTIONS(1927),
    [anon_sym_PERCENT_EQ] = ACTIONS(1927),
    [anon_sym_PLUS_EQ] = ACTIONS(1927),
    [anon_sym_DASH_EQ] = ACTIONS(1927),
    [anon_sym_LT_LT_EQ] = ACTIONS(1927),
    [anon_sym_GT_GT_EQ] = ACTIONS(1927),
    [anon_sym_AMP_EQ] = ACTIONS(1927),
    [anon_sym_CARET_EQ] = ACTIONS(1927),
    [anon_sym_PIPE_EQ] = ACTIONS(1927),
    [anon_sym_and_eq] = ACTIONS(1925),
    [anon_sym_or_eq] = ACTIONS(1925),
    [anon_sym_xor_eq] = ACTIONS(1925),
    [anon_sym_LT_EQ_GT] = ACTIONS(1927),
    [anon_sym_or] = ACTIONS(1925),
    [anon_sym_and] = ACTIONS(1925),
    [anon_sym_bitor] = ACTIONS(1925),
    [anon_sym_xor] = ACTIONS(1925),
    [anon_sym_bitand] = ACTIONS(1925),
    [anon_sym_not_eq] = ACTIONS(1925),
    [anon_sym_DASH_DASH] = ACTIONS(1927),
    [anon_sym_PLUS_PLUS] = ACTIONS(1927),
    [anon_sym_DOT] = ACTIONS(1925),
    [anon_sym_DOT_STAR] = ACTIONS(1927),
    [anon_sym_DASH_GT] = ACTIONS(1927),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1925),
    [anon_sym_decltype] = ACTIONS(1925),
    [sym_virtual] = ACTIONS(1925),
    [anon_sym_template] = ACTIONS(1925),
    [anon_sym_operator] = ACTIONS(1925),
    [anon_sym_precise] = ACTIONS(1925),
    [anon_sym_shared] = ACTIONS(1925),
    [anon_sym_groupshared] = ACTIONS(1925),
    [anon_sym_uniform] = ACTIONS(1925),
    [anon_sym_row_major] = ACTIONS(1925),
    [anon_sym_column_major] = ACTIONS(1925),
    [anon_sym_globallycoherent] = ACTIONS(1925),
    [anon_sym_centroid] = ACTIONS(1925),
    [anon_sym_noperspective] = ACTIONS(1925),
    [anon_sym_nointerpolation] = ACTIONS(1925),
    [anon_sym_sample] = ACTIONS(1925),
    [anon_sym_linear] = ACTIONS(1925),
    [anon_sym_snorm] = ACTIONS(1925),
    [anon_sym_unorm] = ACTIONS(1925),
    [anon_sym_point] = ACTIONS(1925),
    [anon_sym_line] = ACTIONS(1925),
    [anon_sym_triangleadj] = ACTIONS(1925),
    [anon_sym_lineadj] = ACTIONS(1925),
    [anon_sym_triangle] = ACTIONS(1925),
  },
  [1077] = {
    [sym_identifier] = ACTIONS(1891),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1893),
    [anon_sym_COMMA] = ACTIONS(1893),
    [anon_sym_RPAREN] = ACTIONS(1893),
    [anon_sym_LPAREN2] = ACTIONS(1893),
    [anon_sym_TILDE] = ACTIONS(1893),
    [anon_sym_DASH] = ACTIONS(1891),
    [anon_sym_PLUS] = ACTIONS(1891),
    [anon_sym_STAR] = ACTIONS(1891),
    [anon_sym_SLASH] = ACTIONS(1891),
    [anon_sym_PERCENT] = ACTIONS(1891),
    [anon_sym_PIPE_PIPE] = ACTIONS(1893),
    [anon_sym_AMP_AMP] = ACTIONS(1893),
    [anon_sym_PIPE] = ACTIONS(1891),
    [anon_sym_CARET] = ACTIONS(1891),
    [anon_sym_AMP] = ACTIONS(1891),
    [anon_sym_EQ_EQ] = ACTIONS(1893),
    [anon_sym_BANG_EQ] = ACTIONS(1893),
    [anon_sym_GT] = ACTIONS(1891),
    [anon_sym_GT_EQ] = ACTIONS(1893),
    [anon_sym_LT_EQ] = ACTIONS(1891),
    [anon_sym_LT] = ACTIONS(1891),
    [anon_sym_LT_LT] = ACTIONS(1891),
    [anon_sym_GT_GT] = ACTIONS(1891),
    [anon_sym_COLON] = ACTIONS(1891),
    [anon_sym_SEMI] = ACTIONS(1893),
    [anon_sym___extension__] = ACTIONS(1891),
    [anon_sym_in] = ACTIONS(1891),
    [anon_sym_out] = ACTIONS(1891),
    [anon_sym_inout] = ACTIONS(1891),
    [anon_sym_extern] = ACTIONS(1891),
    [anon_sym___attribute__] = ACTIONS(1891),
    [anon_sym_COLON_COLON] = ACTIONS(1893),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1893),
    [anon_sym___declspec] = ACTIONS(1891),
    [anon_sym___based] = ACTIONS(1891),
    [anon_sym___cdecl] = ACTIONS(1891),
    [anon_sym___clrcall] = ACTIONS(1891),
    [anon_sym___stdcall] = ACTIONS(1891),
    [anon_sym___fastcall] = ACTIONS(1891),
    [anon_sym___thiscall] = ACTIONS(1891),
    [anon_sym___vectorcall] = ACTIONS(1891),
    [anon_sym_LBRACE] = ACTIONS(1893),
    [anon_sym_RBRACE] = ACTIONS(1893),
    [anon_sym_LBRACK] = ACTIONS(1891),
    [anon_sym_static] = ACTIONS(1891),
    [anon_sym_EQ] = ACTIONS(1891),
    [anon_sym_register] = ACTIONS(1891),
    [anon_sym_inline] = ACTIONS(1891),
    [anon_sym___inline] = ACTIONS(1891),
    [anon_sym___inline__] = ACTIONS(1891),
    [anon_sym___forceinline] = ACTIONS(1891),
    [anon_sym_thread_local] = ACTIONS(1891),
    [anon_sym___thread] = ACTIONS(1891),
    [anon_sym_const] = ACTIONS(1891),
    [anon_sym_constexpr] = ACTIONS(1891),
    [anon_sym_volatile] = ACTIONS(1891),
    [anon_sym_restrict] = ACTIONS(1891),
    [anon_sym___restrict__] = ACTIONS(1891),
    [anon_sym__Atomic] = ACTIONS(1891),
    [anon_sym__Noreturn] = ACTIONS(1891),
    [anon_sym_noreturn] = ACTIONS(1891),
    [anon_sym_mutable] = ACTIONS(1891),
    [anon_sym_constinit] = ACTIONS(1891),
    [anon_sym_consteval] = ACTIONS(1891),
    [anon_sym_alignas] = ACTIONS(1891),
    [anon_sym__Alignas] = ACTIONS(1891),
    [anon_sym_QMARK] = ACTIONS(1893),
    [anon_sym_STAR_EQ] = ACTIONS(1893),
    [anon_sym_SLASH_EQ] = ACTIONS(1893),
    [anon_sym_PERCENT_EQ] = ACTIONS(1893),
    [anon_sym_PLUS_EQ] = ACTIONS(1893),
    [anon_sym_DASH_EQ] = ACTIONS(1893),
    [anon_sym_LT_LT_EQ] = ACTIONS(1893),
    [anon_sym_GT_GT_EQ] = ACTIONS(1893),
    [anon_sym_AMP_EQ] = ACTIONS(1893),
    [anon_sym_CARET_EQ] = ACTIONS(1893),
    [anon_sym_PIPE_EQ] = ACTIONS(1893),
    [anon_sym_and_eq] = ACTIONS(1891),
    [anon_sym_or_eq] = ACTIONS(1891),
    [anon_sym_xor_eq] = ACTIONS(1891),
    [anon_sym_LT_EQ_GT] = ACTIONS(1893),
    [anon_sym_or] = ACTIONS(1891),
    [anon_sym_and] = ACTIONS(1891),
    [anon_sym_bitor] = ACTIONS(1891),
    [anon_sym_xor] = ACTIONS(1891),
    [anon_sym_bitand] = ACTIONS(1891),
    [anon_sym_not_eq] = ACTIONS(1891),
    [anon_sym_DASH_DASH] = ACTIONS(1893),
    [anon_sym_PLUS_PLUS] = ACTIONS(1893),
    [anon_sym_DOT] = ACTIONS(1891),
    [anon_sym_DOT_STAR] = ACTIONS(1893),
    [anon_sym_DASH_GT] = ACTIONS(1893),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1891),
    [anon_sym_decltype] = ACTIONS(1891),
    [sym_virtual] = ACTIONS(1891),
    [anon_sym_template] = ACTIONS(1891),
    [anon_sym_operator] = ACTIONS(1891),
    [anon_sym_precise] = ACTIONS(1891),
    [anon_sym_shared] = ACTIONS(1891),
    [anon_sym_groupshared] = ACTIONS(1891),
    [anon_sym_uniform] = ACTIONS(1891),
    [anon_sym_row_major] = ACTIONS(1891),
    [anon_sym_column_major] = ACTIONS(1891),
    [anon_sym_globallycoherent] = ACTIONS(1891),
    [anon_sym_centroid] = ACTIONS(1891),
    [anon_sym_noperspective] = ACTIONS(1891),
    [anon_sym_nointerpolation] = ACTIONS(1891),
    [anon_sym_sample] = ACTIONS(1891),
    [anon_sym_linear] = ACTIONS(1891),
    [anon_sym_snorm] = ACTIONS(1891),
    [anon_sym_unorm] = ACTIONS(1891),
    [anon_sym_point] = ACTIONS(1891),
    [anon_sym_line] = ACTIONS(1891),
    [anon_sym_triangleadj] = ACTIONS(1891),
    [anon_sym_lineadj] = ACTIONS(1891),
    [anon_sym_triangle] = ACTIONS(1891),
  },
  [1078] = {
    [sym_identifier] = ACTIONS(1903),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1905),
    [anon_sym_COMMA] = ACTIONS(1905),
    [anon_sym_RPAREN] = ACTIONS(1905),
    [anon_sym_LPAREN2] = ACTIONS(1905),
    [anon_sym_TILDE] = ACTIONS(1905),
    [anon_sym_DASH] = ACTIONS(1903),
    [anon_sym_PLUS] = ACTIONS(1903),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_SLASH] = ACTIONS(1903),
    [anon_sym_PERCENT] = ACTIONS(1903),
    [anon_sym_PIPE_PIPE] = ACTIONS(1905),
    [anon_sym_AMP_AMP] = ACTIONS(1905),
    [anon_sym_PIPE] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1903),
    [anon_sym_AMP] = ACTIONS(1903),
    [anon_sym_EQ_EQ] = ACTIONS(1905),
    [anon_sym_BANG_EQ] = ACTIONS(1905),
    [anon_sym_GT] = ACTIONS(1903),
    [anon_sym_GT_EQ] = ACTIONS(1905),
    [anon_sym_LT_EQ] = ACTIONS(1903),
    [anon_sym_LT] = ACTIONS(1903),
    [anon_sym_LT_LT] = ACTIONS(1903),
    [anon_sym_GT_GT] = ACTIONS(1903),
    [anon_sym_COLON] = ACTIONS(1903),
    [anon_sym_SEMI] = ACTIONS(1905),
    [anon_sym___extension__] = ACTIONS(1903),
    [anon_sym_in] = ACTIONS(1903),
    [anon_sym_out] = ACTIONS(1903),
    [anon_sym_inout] = ACTIONS(1903),
    [anon_sym_extern] = ACTIONS(1903),
    [anon_sym___attribute__] = ACTIONS(1903),
    [anon_sym_COLON_COLON] = ACTIONS(1905),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1905),
    [anon_sym___declspec] = ACTIONS(1903),
    [anon_sym___based] = ACTIONS(1903),
    [anon_sym___cdecl] = ACTIONS(1903),
    [anon_sym___clrcall] = ACTIONS(1903),
    [anon_sym___stdcall] = ACTIONS(1903),
    [anon_sym___fastcall] = ACTIONS(1903),
    [anon_sym___thiscall] = ACTIONS(1903),
    [anon_sym___vectorcall] = ACTIONS(1903),
    [anon_sym_LBRACE] = ACTIONS(1905),
    [anon_sym_RBRACE] = ACTIONS(1905),
    [anon_sym_LBRACK] = ACTIONS(1903),
    [anon_sym_static] = ACTIONS(1903),
    [anon_sym_EQ] = ACTIONS(1903),
    [anon_sym_register] = ACTIONS(1903),
    [anon_sym_inline] = ACTIONS(1903),
    [anon_sym___inline] = ACTIONS(1903),
    [anon_sym___inline__] = ACTIONS(1903),
    [anon_sym___forceinline] = ACTIONS(1903),
    [anon_sym_thread_local] = ACTIONS(1903),
    [anon_sym___thread] = ACTIONS(1903),
    [anon_sym_const] = ACTIONS(1903),
    [anon_sym_constexpr] = ACTIONS(1903),
    [anon_sym_volatile] = ACTIONS(1903),
    [anon_sym_restrict] = ACTIONS(1903),
    [anon_sym___restrict__] = ACTIONS(1903),
    [anon_sym__Atomic] = ACTIONS(1903),
    [anon_sym__Noreturn] = ACTIONS(1903),
    [anon_sym_noreturn] = ACTIONS(1903),
    [anon_sym_mutable] = ACTIONS(1903),
    [anon_sym_constinit] = ACTIONS(1903),
    [anon_sym_consteval] = ACTIONS(1903),
    [anon_sym_alignas] = ACTIONS(1903),
    [anon_sym__Alignas] = ACTIONS(1903),
    [anon_sym_QMARK] = ACTIONS(1905),
    [anon_sym_STAR_EQ] = ACTIONS(1905),
    [anon_sym_SLASH_EQ] = ACTIONS(1905),
    [anon_sym_PERCENT_EQ] = ACTIONS(1905),
    [anon_sym_PLUS_EQ] = ACTIONS(1905),
    [anon_sym_DASH_EQ] = ACTIONS(1905),
    [anon_sym_LT_LT_EQ] = ACTIONS(1905),
    [anon_sym_GT_GT_EQ] = ACTIONS(1905),
    [anon_sym_AMP_EQ] = ACTIONS(1905),
    [anon_sym_CARET_EQ] = ACTIONS(1905),
    [anon_sym_PIPE_EQ] = ACTIONS(1905),
    [anon_sym_and_eq] = ACTIONS(1903),
    [anon_sym_or_eq] = ACTIONS(1903),
    [anon_sym_xor_eq] = ACTIONS(1903),
    [anon_sym_LT_EQ_GT] = ACTIONS(1905),
    [anon_sym_or] = ACTIONS(1903),
    [anon_sym_and] = ACTIONS(1903),
    [anon_sym_bitor] = ACTIONS(1903),
    [anon_sym_xor] = ACTIONS(1903),
    [anon_sym_bitand] = ACTIONS(1903),
    [anon_sym_not_eq] = ACTIONS(1903),
    [anon_sym_DASH_DASH] = ACTIONS(1905),
    [anon_sym_PLUS_PLUS] = ACTIONS(1905),
    [anon_sym_DOT] = ACTIONS(1903),
    [anon_sym_DOT_STAR] = ACTIONS(1905),
    [anon_sym_DASH_GT] = ACTIONS(1905),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1903),
    [anon_sym_decltype] = ACTIONS(1903),
    [sym_virtual] = ACTIONS(1903),
    [anon_sym_template] = ACTIONS(1903),
    [anon_sym_operator] = ACTIONS(1903),
    [anon_sym_precise] = ACTIONS(1903),
    [anon_sym_shared] = ACTIONS(1903),
    [anon_sym_groupshared] = ACTIONS(1903),
    [anon_sym_uniform] = ACTIONS(1903),
    [anon_sym_row_major] = ACTIONS(1903),
    [anon_sym_column_major] = ACTIONS(1903),
    [anon_sym_globallycoherent] = ACTIONS(1903),
    [anon_sym_centroid] = ACTIONS(1903),
    [anon_sym_noperspective] = ACTIONS(1903),
    [anon_sym_nointerpolation] = ACTIONS(1903),
    [anon_sym_sample] = ACTIONS(1903),
    [anon_sym_linear] = ACTIONS(1903),
    [anon_sym_snorm] = ACTIONS(1903),
    [anon_sym_unorm] = ACTIONS(1903),
    [anon_sym_point] = ACTIONS(1903),
    [anon_sym_line] = ACTIONS(1903),
    [anon_sym_triangleadj] = ACTIONS(1903),
    [anon_sym_lineadj] = ACTIONS(1903),
    [anon_sym_triangle] = ACTIONS(1903),
  },
  [1079] = {
    [sym_identifier] = ACTIONS(1899),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1901),
    [anon_sym_COMMA] = ACTIONS(1901),
    [anon_sym_RPAREN] = ACTIONS(1901),
    [anon_sym_LPAREN2] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1899),
    [anon_sym_SLASH] = ACTIONS(1899),
    [anon_sym_PERCENT] = ACTIONS(1899),
    [anon_sym_PIPE_PIPE] = ACTIONS(1901),
    [anon_sym_AMP_AMP] = ACTIONS(1901),
    [anon_sym_PIPE] = ACTIONS(1899),
    [anon_sym_CARET] = ACTIONS(1899),
    [anon_sym_AMP] = ACTIONS(1899),
    [anon_sym_EQ_EQ] = ACTIONS(1901),
    [anon_sym_BANG_EQ] = ACTIONS(1901),
    [anon_sym_GT] = ACTIONS(1899),
    [anon_sym_GT_EQ] = ACTIONS(1901),
    [anon_sym_LT_EQ] = ACTIONS(1899),
    [anon_sym_LT] = ACTIONS(1899),
    [anon_sym_LT_LT] = ACTIONS(1899),
    [anon_sym_GT_GT] = ACTIONS(1899),
    [anon_sym_COLON] = ACTIONS(1899),
    [anon_sym_SEMI] = ACTIONS(1901),
    [anon_sym___extension__] = ACTIONS(1899),
    [anon_sym_in] = ACTIONS(1899),
    [anon_sym_out] = ACTIONS(1899),
    [anon_sym_inout] = ACTIONS(1899),
    [anon_sym_extern] = ACTIONS(1899),
    [anon_sym___attribute__] = ACTIONS(1899),
    [anon_sym_COLON_COLON] = ACTIONS(1901),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1901),
    [anon_sym___declspec] = ACTIONS(1899),
    [anon_sym___based] = ACTIONS(1899),
    [anon_sym___cdecl] = ACTIONS(1899),
    [anon_sym___clrcall] = ACTIONS(1899),
    [anon_sym___stdcall] = ACTIONS(1899),
    [anon_sym___fastcall] = ACTIONS(1899),
    [anon_sym___thiscall] = ACTIONS(1899),
    [anon_sym___vectorcall] = ACTIONS(1899),
    [anon_sym_LBRACE] = ACTIONS(1901),
    [anon_sym_RBRACE] = ACTIONS(1901),
    [anon_sym_LBRACK] = ACTIONS(1899),
    [anon_sym_static] = ACTIONS(1899),
    [anon_sym_EQ] = ACTIONS(1899),
    [anon_sym_register] = ACTIONS(1899),
    [anon_sym_inline] = ACTIONS(1899),
    [anon_sym___inline] = ACTIONS(1899),
    [anon_sym___inline__] = ACTIONS(1899),
    [anon_sym___forceinline] = ACTIONS(1899),
    [anon_sym_thread_local] = ACTIONS(1899),
    [anon_sym___thread] = ACTIONS(1899),
    [anon_sym_const] = ACTIONS(1899),
    [anon_sym_constexpr] = ACTIONS(1899),
    [anon_sym_volatile] = ACTIONS(1899),
    [anon_sym_restrict] = ACTIONS(1899),
    [anon_sym___restrict__] = ACTIONS(1899),
    [anon_sym__Atomic] = ACTIONS(1899),
    [anon_sym__Noreturn] = ACTIONS(1899),
    [anon_sym_noreturn] = ACTIONS(1899),
    [anon_sym_mutable] = ACTIONS(1899),
    [anon_sym_constinit] = ACTIONS(1899),
    [anon_sym_consteval] = ACTIONS(1899),
    [anon_sym_alignas] = ACTIONS(1899),
    [anon_sym__Alignas] = ACTIONS(1899),
    [anon_sym_QMARK] = ACTIONS(1901),
    [anon_sym_STAR_EQ] = ACTIONS(1901),
    [anon_sym_SLASH_EQ] = ACTIONS(1901),
    [anon_sym_PERCENT_EQ] = ACTIONS(1901),
    [anon_sym_PLUS_EQ] = ACTIONS(1901),
    [anon_sym_DASH_EQ] = ACTIONS(1901),
    [anon_sym_LT_LT_EQ] = ACTIONS(1901),
    [anon_sym_GT_GT_EQ] = ACTIONS(1901),
    [anon_sym_AMP_EQ] = ACTIONS(1901),
    [anon_sym_CARET_EQ] = ACTIONS(1901),
    [anon_sym_PIPE_EQ] = ACTIONS(1901),
    [anon_sym_and_eq] = ACTIONS(1899),
    [anon_sym_or_eq] = ACTIONS(1899),
    [anon_sym_xor_eq] = ACTIONS(1899),
    [anon_sym_LT_EQ_GT] = ACTIONS(1901),
    [anon_sym_or] = ACTIONS(1899),
    [anon_sym_and] = ACTIONS(1899),
    [anon_sym_bitor] = ACTIONS(1899),
    [anon_sym_xor] = ACTIONS(1899),
    [anon_sym_bitand] = ACTIONS(1899),
    [anon_sym_not_eq] = ACTIONS(1899),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DOT] = ACTIONS(1899),
    [anon_sym_DOT_STAR] = ACTIONS(1901),
    [anon_sym_DASH_GT] = ACTIONS(1901),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1899),
    [anon_sym_decltype] = ACTIONS(1899),
    [sym_virtual] = ACTIONS(1899),
    [anon_sym_template] = ACTIONS(1899),
    [anon_sym_operator] = ACTIONS(1899),
    [anon_sym_precise] = ACTIONS(1899),
    [anon_sym_shared] = ACTIONS(1899),
    [anon_sym_groupshared] = ACTIONS(1899),
    [anon_sym_uniform] = ACTIONS(1899),
    [anon_sym_row_major] = ACTIONS(1899),
    [anon_sym_column_major] = ACTIONS(1899),
    [anon_sym_globallycoherent] = ACTIONS(1899),
    [anon_sym_centroid] = ACTIONS(1899),
    [anon_sym_noperspective] = ACTIONS(1899),
    [anon_sym_nointerpolation] = ACTIONS(1899),
    [anon_sym_sample] = ACTIONS(1899),
    [anon_sym_linear] = ACTIONS(1899),
    [anon_sym_snorm] = ACTIONS(1899),
    [anon_sym_unorm] = ACTIONS(1899),
    [anon_sym_point] = ACTIONS(1899),
    [anon_sym_line] = ACTIONS(1899),
    [anon_sym_triangleadj] = ACTIONS(1899),
    [anon_sym_lineadj] = ACTIONS(1899),
    [anon_sym_triangle] = ACTIONS(1899),
  },
  [1080] = {
    [sym_identifier] = ACTIONS(1895),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1897),
    [anon_sym_COMMA] = ACTIONS(1897),
    [anon_sym_RPAREN] = ACTIONS(1897),
    [anon_sym_LPAREN2] = ACTIONS(1897),
    [anon_sym_TILDE] = ACTIONS(1897),
    [anon_sym_DASH] = ACTIONS(1895),
    [anon_sym_PLUS] = ACTIONS(1895),
    [anon_sym_STAR] = ACTIONS(1895),
    [anon_sym_SLASH] = ACTIONS(1895),
    [anon_sym_PERCENT] = ACTIONS(1895),
    [anon_sym_PIPE_PIPE] = ACTIONS(1897),
    [anon_sym_AMP_AMP] = ACTIONS(1897),
    [anon_sym_PIPE] = ACTIONS(1895),
    [anon_sym_CARET] = ACTIONS(1895),
    [anon_sym_AMP] = ACTIONS(1895),
    [anon_sym_EQ_EQ] = ACTIONS(1897),
    [anon_sym_BANG_EQ] = ACTIONS(1897),
    [anon_sym_GT] = ACTIONS(1895),
    [anon_sym_GT_EQ] = ACTIONS(1897),
    [anon_sym_LT_EQ] = ACTIONS(1895),
    [anon_sym_LT] = ACTIONS(1895),
    [anon_sym_LT_LT] = ACTIONS(1895),
    [anon_sym_GT_GT] = ACTIONS(1895),
    [anon_sym_COLON] = ACTIONS(1895),
    [anon_sym_SEMI] = ACTIONS(1897),
    [anon_sym___extension__] = ACTIONS(1895),
    [anon_sym_in] = ACTIONS(1895),
    [anon_sym_out] = ACTIONS(1895),
    [anon_sym_inout] = ACTIONS(1895),
    [anon_sym_extern] = ACTIONS(1895),
    [anon_sym___attribute__] = ACTIONS(1895),
    [anon_sym_COLON_COLON] = ACTIONS(1897),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1897),
    [anon_sym___declspec] = ACTIONS(1895),
    [anon_sym___based] = ACTIONS(1895),
    [anon_sym___cdecl] = ACTIONS(1895),
    [anon_sym___clrcall] = ACTIONS(1895),
    [anon_sym___stdcall] = ACTIONS(1895),
    [anon_sym___fastcall] = ACTIONS(1895),
    [anon_sym___thiscall] = ACTIONS(1895),
    [anon_sym___vectorcall] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1897),
    [anon_sym_RBRACE] = ACTIONS(1897),
    [anon_sym_LBRACK] = ACTIONS(1895),
    [anon_sym_static] = ACTIONS(1895),
    [anon_sym_EQ] = ACTIONS(1895),
    [anon_sym_register] = ACTIONS(1895),
    [anon_sym_inline] = ACTIONS(1895),
    [anon_sym___inline] = ACTIONS(1895),
    [anon_sym___inline__] = ACTIONS(1895),
    [anon_sym___forceinline] = ACTIONS(1895),
    [anon_sym_thread_local] = ACTIONS(1895),
    [anon_sym___thread] = ACTIONS(1895),
    [anon_sym_const] = ACTIONS(1895),
    [anon_sym_constexpr] = ACTIONS(1895),
    [anon_sym_volatile] = ACTIONS(1895),
    [anon_sym_restrict] = ACTIONS(1895),
    [anon_sym___restrict__] = ACTIONS(1895),
    [anon_sym__Atomic] = ACTIONS(1895),
    [anon_sym__Noreturn] = ACTIONS(1895),
    [anon_sym_noreturn] = ACTIONS(1895),
    [anon_sym_mutable] = ACTIONS(1895),
    [anon_sym_constinit] = ACTIONS(1895),
    [anon_sym_consteval] = ACTIONS(1895),
    [anon_sym_alignas] = ACTIONS(1895),
    [anon_sym__Alignas] = ACTIONS(1895),
    [anon_sym_QMARK] = ACTIONS(1897),
    [anon_sym_STAR_EQ] = ACTIONS(1897),
    [anon_sym_SLASH_EQ] = ACTIONS(1897),
    [anon_sym_PERCENT_EQ] = ACTIONS(1897),
    [anon_sym_PLUS_EQ] = ACTIONS(1897),
    [anon_sym_DASH_EQ] = ACTIONS(1897),
    [anon_sym_LT_LT_EQ] = ACTIONS(1897),
    [anon_sym_GT_GT_EQ] = ACTIONS(1897),
    [anon_sym_AMP_EQ] = ACTIONS(1897),
    [anon_sym_CARET_EQ] = ACTIONS(1897),
    [anon_sym_PIPE_EQ] = ACTIONS(1897),
    [anon_sym_and_eq] = ACTIONS(1895),
    [anon_sym_or_eq] = ACTIONS(1895),
    [anon_sym_xor_eq] = ACTIONS(1895),
    [anon_sym_LT_EQ_GT] = ACTIONS(1897),
    [anon_sym_or] = ACTIONS(1895),
    [anon_sym_and] = ACTIONS(1895),
    [anon_sym_bitor] = ACTIONS(1895),
    [anon_sym_xor] = ACTIONS(1895),
    [anon_sym_bitand] = ACTIONS(1895),
    [anon_sym_not_eq] = ACTIONS(1895),
    [anon_sym_DASH_DASH] = ACTIONS(1897),
    [anon_sym_PLUS_PLUS] = ACTIONS(1897),
    [anon_sym_DOT] = ACTIONS(1895),
    [anon_sym_DOT_STAR] = ACTIONS(1897),
    [anon_sym_DASH_GT] = ACTIONS(1897),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1895),
    [anon_sym_decltype] = ACTIONS(1895),
    [sym_virtual] = ACTIONS(1895),
    [anon_sym_template] = ACTIONS(1895),
    [anon_sym_operator] = ACTIONS(1895),
    [anon_sym_precise] = ACTIONS(1895),
    [anon_sym_shared] = ACTIONS(1895),
    [anon_sym_groupshared] = ACTIONS(1895),
    [anon_sym_uniform] = ACTIONS(1895),
    [anon_sym_row_major] = ACTIONS(1895),
    [anon_sym_column_major] = ACTIONS(1895),
    [anon_sym_globallycoherent] = ACTIONS(1895),
    [anon_sym_centroid] = ACTIONS(1895),
    [anon_sym_noperspective] = ACTIONS(1895),
    [anon_sym_nointerpolation] = ACTIONS(1895),
    [anon_sym_sample] = ACTIONS(1895),
    [anon_sym_linear] = ACTIONS(1895),
    [anon_sym_snorm] = ACTIONS(1895),
    [anon_sym_unorm] = ACTIONS(1895),
    [anon_sym_point] = ACTIONS(1895),
    [anon_sym_line] = ACTIONS(1895),
    [anon_sym_triangleadj] = ACTIONS(1895),
    [anon_sym_lineadj] = ACTIONS(1895),
    [anon_sym_triangle] = ACTIONS(1895),
  },
  [1081] = {
    [sym_identifier] = ACTIONS(1917),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1919),
    [anon_sym_COMMA] = ACTIONS(1919),
    [anon_sym_RPAREN] = ACTIONS(1919),
    [anon_sym_LPAREN2] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1917),
    [anon_sym_SLASH] = ACTIONS(1917),
    [anon_sym_PERCENT] = ACTIONS(1917),
    [anon_sym_PIPE_PIPE] = ACTIONS(1919),
    [anon_sym_AMP_AMP] = ACTIONS(1919),
    [anon_sym_PIPE] = ACTIONS(1917),
    [anon_sym_CARET] = ACTIONS(1917),
    [anon_sym_AMP] = ACTIONS(1917),
    [anon_sym_EQ_EQ] = ACTIONS(1919),
    [anon_sym_BANG_EQ] = ACTIONS(1919),
    [anon_sym_GT] = ACTIONS(1917),
    [anon_sym_GT_EQ] = ACTIONS(1919),
    [anon_sym_LT_EQ] = ACTIONS(1917),
    [anon_sym_LT] = ACTIONS(1917),
    [anon_sym_LT_LT] = ACTIONS(1917),
    [anon_sym_GT_GT] = ACTIONS(1917),
    [anon_sym_COLON] = ACTIONS(1917),
    [anon_sym_SEMI] = ACTIONS(1919),
    [anon_sym___extension__] = ACTIONS(1917),
    [anon_sym_in] = ACTIONS(1917),
    [anon_sym_out] = ACTIONS(1917),
    [anon_sym_inout] = ACTIONS(1917),
    [anon_sym_extern] = ACTIONS(1917),
    [anon_sym___attribute__] = ACTIONS(1917),
    [anon_sym_COLON_COLON] = ACTIONS(1919),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1919),
    [anon_sym___declspec] = ACTIONS(1917),
    [anon_sym___based] = ACTIONS(1917),
    [anon_sym___cdecl] = ACTIONS(1917),
    [anon_sym___clrcall] = ACTIONS(1917),
    [anon_sym___stdcall] = ACTIONS(1917),
    [anon_sym___fastcall] = ACTIONS(1917),
    [anon_sym___thiscall] = ACTIONS(1917),
    [anon_sym___vectorcall] = ACTIONS(1917),
    [anon_sym_LBRACE] = ACTIONS(1919),
    [anon_sym_RBRACE] = ACTIONS(1919),
    [anon_sym_LBRACK] = ACTIONS(1917),
    [anon_sym_static] = ACTIONS(1917),
    [anon_sym_EQ] = ACTIONS(1917),
    [anon_sym_register] = ACTIONS(1917),
    [anon_sym_inline] = ACTIONS(1917),
    [anon_sym___inline] = ACTIONS(1917),
    [anon_sym___inline__] = ACTIONS(1917),
    [anon_sym___forceinline] = ACTIONS(1917),
    [anon_sym_thread_local] = ACTIONS(1917),
    [anon_sym___thread] = ACTIONS(1917),
    [anon_sym_const] = ACTIONS(1917),
    [anon_sym_constexpr] = ACTIONS(1917),
    [anon_sym_volatile] = ACTIONS(1917),
    [anon_sym_restrict] = ACTIONS(1917),
    [anon_sym___restrict__] = ACTIONS(1917),
    [anon_sym__Atomic] = ACTIONS(1917),
    [anon_sym__Noreturn] = ACTIONS(1917),
    [anon_sym_noreturn] = ACTIONS(1917),
    [anon_sym_mutable] = ACTIONS(1917),
    [anon_sym_constinit] = ACTIONS(1917),
    [anon_sym_consteval] = ACTIONS(1917),
    [anon_sym_alignas] = ACTIONS(1917),
    [anon_sym__Alignas] = ACTIONS(1917),
    [anon_sym_QMARK] = ACTIONS(1919),
    [anon_sym_STAR_EQ] = ACTIONS(1919),
    [anon_sym_SLASH_EQ] = ACTIONS(1919),
    [anon_sym_PERCENT_EQ] = ACTIONS(1919),
    [anon_sym_PLUS_EQ] = ACTIONS(1919),
    [anon_sym_DASH_EQ] = ACTIONS(1919),
    [anon_sym_LT_LT_EQ] = ACTIONS(1919),
    [anon_sym_GT_GT_EQ] = ACTIONS(1919),
    [anon_sym_AMP_EQ] = ACTIONS(1919),
    [anon_sym_CARET_EQ] = ACTIONS(1919),
    [anon_sym_PIPE_EQ] = ACTIONS(1919),
    [anon_sym_and_eq] = ACTIONS(1917),
    [anon_sym_or_eq] = ACTIONS(1917),
    [anon_sym_xor_eq] = ACTIONS(1917),
    [anon_sym_LT_EQ_GT] = ACTIONS(1919),
    [anon_sym_or] = ACTIONS(1917),
    [anon_sym_and] = ACTIONS(1917),
    [anon_sym_bitor] = ACTIONS(1917),
    [anon_sym_xor] = ACTIONS(1917),
    [anon_sym_bitand] = ACTIONS(1917),
    [anon_sym_not_eq] = ACTIONS(1917),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DOT] = ACTIONS(1917),
    [anon_sym_DOT_STAR] = ACTIONS(1919),
    [anon_sym_DASH_GT] = ACTIONS(1919),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1917),
    [anon_sym_decltype] = ACTIONS(1917),
    [sym_virtual] = ACTIONS(1917),
    [anon_sym_template] = ACTIONS(1917),
    [anon_sym_operator] = ACTIONS(1917),
    [anon_sym_precise] = ACTIONS(1917),
    [anon_sym_shared] = ACTIONS(1917),
    [anon_sym_groupshared] = ACTIONS(1917),
    [anon_sym_uniform] = ACTIONS(1917),
    [anon_sym_row_major] = ACTIONS(1917),
    [anon_sym_column_major] = ACTIONS(1917),
    [anon_sym_globallycoherent] = ACTIONS(1917),
    [anon_sym_centroid] = ACTIONS(1917),
    [anon_sym_noperspective] = ACTIONS(1917),
    [anon_sym_nointerpolation] = ACTIONS(1917),
    [anon_sym_sample] = ACTIONS(1917),
    [anon_sym_linear] = ACTIONS(1917),
    [anon_sym_snorm] = ACTIONS(1917),
    [anon_sym_unorm] = ACTIONS(1917),
    [anon_sym_point] = ACTIONS(1917),
    [anon_sym_line] = ACTIONS(1917),
    [anon_sym_triangleadj] = ACTIONS(1917),
    [anon_sym_lineadj] = ACTIONS(1917),
    [anon_sym_triangle] = ACTIONS(1917),
  },
  [1082] = {
    [sym_identifier] = ACTIONS(1887),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1889),
    [anon_sym_COMMA] = ACTIONS(1889),
    [anon_sym_RPAREN] = ACTIONS(1889),
    [anon_sym_LPAREN2] = ACTIONS(1889),
    [anon_sym_TILDE] = ACTIONS(1889),
    [anon_sym_DASH] = ACTIONS(1887),
    [anon_sym_PLUS] = ACTIONS(1887),
    [anon_sym_STAR] = ACTIONS(1887),
    [anon_sym_SLASH] = ACTIONS(1887),
    [anon_sym_PERCENT] = ACTIONS(1887),
    [anon_sym_PIPE_PIPE] = ACTIONS(1889),
    [anon_sym_AMP_AMP] = ACTIONS(1889),
    [anon_sym_PIPE] = ACTIONS(1887),
    [anon_sym_CARET] = ACTIONS(1887),
    [anon_sym_AMP] = ACTIONS(1887),
    [anon_sym_EQ_EQ] = ACTIONS(1889),
    [anon_sym_BANG_EQ] = ACTIONS(1889),
    [anon_sym_GT] = ACTIONS(1887),
    [anon_sym_GT_EQ] = ACTIONS(1889),
    [anon_sym_LT_EQ] = ACTIONS(1887),
    [anon_sym_LT] = ACTIONS(1887),
    [anon_sym_LT_LT] = ACTIONS(1887),
    [anon_sym_GT_GT] = ACTIONS(1887),
    [anon_sym_COLON] = ACTIONS(1887),
    [anon_sym_SEMI] = ACTIONS(1889),
    [anon_sym___extension__] = ACTIONS(1887),
    [anon_sym_in] = ACTIONS(1887),
    [anon_sym_out] = ACTIONS(1887),
    [anon_sym_inout] = ACTIONS(1887),
    [anon_sym_extern] = ACTIONS(1887),
    [anon_sym___attribute__] = ACTIONS(1887),
    [anon_sym_COLON_COLON] = ACTIONS(1889),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1889),
    [anon_sym___declspec] = ACTIONS(1887),
    [anon_sym___based] = ACTIONS(1887),
    [anon_sym___cdecl] = ACTIONS(1887),
    [anon_sym___clrcall] = ACTIONS(1887),
    [anon_sym___stdcall] = ACTIONS(1887),
    [anon_sym___fastcall] = ACTIONS(1887),
    [anon_sym___thiscall] = ACTIONS(1887),
    [anon_sym___vectorcall] = ACTIONS(1887),
    [anon_sym_LBRACE] = ACTIONS(1889),
    [anon_sym_RBRACE] = ACTIONS(1889),
    [anon_sym_LBRACK] = ACTIONS(1887),
    [anon_sym_static] = ACTIONS(1887),
    [anon_sym_EQ] = ACTIONS(1887),
    [anon_sym_register] = ACTIONS(1887),
    [anon_sym_inline] = ACTIONS(1887),
    [anon_sym___inline] = ACTIONS(1887),
    [anon_sym___inline__] = ACTIONS(1887),
    [anon_sym___forceinline] = ACTIONS(1887),
    [anon_sym_thread_local] = ACTIONS(1887),
    [anon_sym___thread] = ACTIONS(1887),
    [anon_sym_const] = ACTIONS(1887),
    [anon_sym_constexpr] = ACTIONS(1887),
    [anon_sym_volatile] = ACTIONS(1887),
    [anon_sym_restrict] = ACTIONS(1887),
    [anon_sym___restrict__] = ACTIONS(1887),
    [anon_sym__Atomic] = ACTIONS(1887),
    [anon_sym__Noreturn] = ACTIONS(1887),
    [anon_sym_noreturn] = ACTIONS(1887),
    [anon_sym_mutable] = ACTIONS(1887),
    [anon_sym_constinit] = ACTIONS(1887),
    [anon_sym_consteval] = ACTIONS(1887),
    [anon_sym_alignas] = ACTIONS(1887),
    [anon_sym__Alignas] = ACTIONS(1887),
    [anon_sym_QMARK] = ACTIONS(1889),
    [anon_sym_STAR_EQ] = ACTIONS(1889),
    [anon_sym_SLASH_EQ] = ACTIONS(1889),
    [anon_sym_PERCENT_EQ] = ACTIONS(1889),
    [anon_sym_PLUS_EQ] = ACTIONS(1889),
    [anon_sym_DASH_EQ] = ACTIONS(1889),
    [anon_sym_LT_LT_EQ] = ACTIONS(1889),
    [anon_sym_GT_GT_EQ] = ACTIONS(1889),
    [anon_sym_AMP_EQ] = ACTIONS(1889),
    [anon_sym_CARET_EQ] = ACTIONS(1889),
    [anon_sym_PIPE_EQ] = ACTIONS(1889),
    [anon_sym_and_eq] = ACTIONS(1887),
    [anon_sym_or_eq] = ACTIONS(1887),
    [anon_sym_xor_eq] = ACTIONS(1887),
    [anon_sym_LT_EQ_GT] = ACTIONS(1889),
    [anon_sym_or] = ACTIONS(1887),
    [anon_sym_and] = ACTIONS(1887),
    [anon_sym_bitor] = ACTIONS(1887),
    [anon_sym_xor] = ACTIONS(1887),
    [anon_sym_bitand] = ACTIONS(1887),
    [anon_sym_not_eq] = ACTIONS(1887),
    [anon_sym_DASH_DASH] = ACTIONS(1889),
    [anon_sym_PLUS_PLUS] = ACTIONS(1889),
    [anon_sym_DOT] = ACTIONS(1887),
    [anon_sym_DOT_STAR] = ACTIONS(1889),
    [anon_sym_DASH_GT] = ACTIONS(1889),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1887),
    [anon_sym_decltype] = ACTIONS(1887),
    [sym_virtual] = ACTIONS(1887),
    [anon_sym_template] = ACTIONS(1887),
    [anon_sym_operator] = ACTIONS(1887),
    [anon_sym_precise] = ACTIONS(1887),
    [anon_sym_shared] = ACTIONS(1887),
    [anon_sym_groupshared] = ACTIONS(1887),
    [anon_sym_uniform] = ACTIONS(1887),
    [anon_sym_row_major] = ACTIONS(1887),
    [anon_sym_column_major] = ACTIONS(1887),
    [anon_sym_globallycoherent] = ACTIONS(1887),
    [anon_sym_centroid] = ACTIONS(1887),
    [anon_sym_noperspective] = ACTIONS(1887),
    [anon_sym_nointerpolation] = ACTIONS(1887),
    [anon_sym_sample] = ACTIONS(1887),
    [anon_sym_linear] = ACTIONS(1887),
    [anon_sym_snorm] = ACTIONS(1887),
    [anon_sym_unorm] = ACTIONS(1887),
    [anon_sym_point] = ACTIONS(1887),
    [anon_sym_line] = ACTIONS(1887),
    [anon_sym_triangleadj] = ACTIONS(1887),
    [anon_sym_lineadj] = ACTIONS(1887),
    [anon_sym_triangle] = ACTIONS(1887),
  },
  [1083] = {
    [sym_template_argument_list] = STATE(1084),
    [sym_identifier] = ACTIONS(1933),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4045),
    [anon_sym_COMMA] = ACTIONS(4045),
    [anon_sym_LPAREN2] = ACTIONS(4047),
    [anon_sym_TILDE] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(4050),
    [anon_sym_PLUS] = ACTIONS(4050),
    [anon_sym_STAR] = ACTIONS(4052),
    [anon_sym_SLASH] = ACTIONS(4050),
    [anon_sym_PERCENT] = ACTIONS(4050),
    [anon_sym_PIPE_PIPE] = ACTIONS(4045),
    [anon_sym_AMP_AMP] = ACTIONS(4047),
    [anon_sym_PIPE] = ACTIONS(4050),
    [anon_sym_CARET] = ACTIONS(4050),
    [anon_sym_AMP] = ACTIONS(4052),
    [anon_sym_EQ_EQ] = ACTIONS(4045),
    [anon_sym_BANG_EQ] = ACTIONS(4045),
    [anon_sym_GT] = ACTIONS(4050),
    [anon_sym_GT_EQ] = ACTIONS(4045),
    [anon_sym_LT_EQ] = ACTIONS(4050),
    [anon_sym_LT] = ACTIONS(4055),
    [anon_sym_LT_LT] = ACTIONS(4050),
    [anon_sym_GT_GT] = ACTIONS(4050),
    [anon_sym_SEMI] = ACTIONS(4047),
    [anon_sym___extension__] = ACTIONS(1933),
    [anon_sym_in] = ACTIONS(1933),
    [anon_sym_out] = ACTIONS(1933),
    [anon_sym_inout] = ACTIONS(1933),
    [anon_sym_extern] = ACTIONS(1933),
    [anon_sym___attribute__] = ACTIONS(1933),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4047),
    [anon_sym___declspec] = ACTIONS(1933),
    [anon_sym___based] = ACTIONS(1933),
    [anon_sym___cdecl] = ACTIONS(1933),
    [anon_sym___clrcall] = ACTIONS(1933),
    [anon_sym___stdcall] = ACTIONS(1933),
    [anon_sym___fastcall] = ACTIONS(1933),
    [anon_sym___thiscall] = ACTIONS(1933),
    [anon_sym___vectorcall] = ACTIONS(1933),
    [anon_sym_LBRACE] = ACTIONS(1935),
    [anon_sym_RBRACE] = ACTIONS(4045),
    [anon_sym_LBRACK] = ACTIONS(4052),
    [anon_sym_static] = ACTIONS(1933),
    [anon_sym_EQ] = ACTIONS(4050),
    [anon_sym_register] = ACTIONS(1933),
    [anon_sym_inline] = ACTIONS(1933),
    [anon_sym___inline] = ACTIONS(1933),
    [anon_sym___inline__] = ACTIONS(1933),
    [anon_sym___forceinline] = ACTIONS(1933),
    [anon_sym_thread_local] = ACTIONS(1933),
    [anon_sym___thread] = ACTIONS(1933),
    [anon_sym_const] = ACTIONS(1933),
    [anon_sym_constexpr] = ACTIONS(1933),
    [anon_sym_volatile] = ACTIONS(1933),
    [anon_sym_restrict] = ACTIONS(1933),
    [anon_sym___restrict__] = ACTIONS(1933),
    [anon_sym__Atomic] = ACTIONS(1933),
    [anon_sym__Noreturn] = ACTIONS(1933),
    [anon_sym_noreturn] = ACTIONS(1933),
    [anon_sym_mutable] = ACTIONS(1933),
    [anon_sym_constinit] = ACTIONS(1933),
    [anon_sym_consteval] = ACTIONS(1933),
    [anon_sym_alignas] = ACTIONS(1933),
    [anon_sym__Alignas] = ACTIONS(1933),
    [anon_sym_QMARK] = ACTIONS(4045),
    [anon_sym_STAR_EQ] = ACTIONS(4045),
    [anon_sym_SLASH_EQ] = ACTIONS(4045),
    [anon_sym_PERCENT_EQ] = ACTIONS(4045),
    [anon_sym_PLUS_EQ] = ACTIONS(4045),
    [anon_sym_DASH_EQ] = ACTIONS(4045),
    [anon_sym_LT_LT_EQ] = ACTIONS(4045),
    [anon_sym_GT_GT_EQ] = ACTIONS(4045),
    [anon_sym_AMP_EQ] = ACTIONS(4045),
    [anon_sym_CARET_EQ] = ACTIONS(4045),
    [anon_sym_PIPE_EQ] = ACTIONS(4045),
    [anon_sym_and_eq] = ACTIONS(4050),
    [anon_sym_or_eq] = ACTIONS(4050),
    [anon_sym_xor_eq] = ACTIONS(4050),
    [anon_sym_LT_EQ_GT] = ACTIONS(4045),
    [anon_sym_or] = ACTIONS(4050),
    [anon_sym_and] = ACTIONS(4050),
    [anon_sym_bitor] = ACTIONS(4050),
    [anon_sym_xor] = ACTIONS(4050),
    [anon_sym_bitand] = ACTIONS(4050),
    [anon_sym_not_eq] = ACTIONS(4050),
    [anon_sym_DASH_DASH] = ACTIONS(4045),
    [anon_sym_PLUS_PLUS] = ACTIONS(4045),
    [anon_sym_DOT] = ACTIONS(4050),
    [anon_sym_DOT_STAR] = ACTIONS(4045),
    [anon_sym_DASH_GT] = ACTIONS(4045),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1933),
    [anon_sym_decltype] = ACTIONS(1933),
    [sym_virtual] = ACTIONS(1933),
    [anon_sym_template] = ACTIONS(1933),
    [anon_sym_operator] = ACTIONS(1933),
    [anon_sym_precise] = ACTIONS(1933),
    [anon_sym_shared] = ACTIONS(1933),
    [anon_sym_groupshared] = ACTIONS(1933),
    [anon_sym_uniform] = ACTIONS(1933),
    [anon_sym_row_major] = ACTIONS(1933),
    [anon_sym_column_major] = ACTIONS(1933),
    [anon_sym_globallycoherent] = ACTIONS(1933),
    [anon_sym_centroid] = ACTIONS(1933),
    [anon_sym_noperspective] = ACTIONS(1933),
    [anon_sym_nointerpolation] = ACTIONS(1933),
    [anon_sym_sample] = ACTIONS(1933),
    [anon_sym_linear] = ACTIONS(1933),
    [anon_sym_snorm] = ACTIONS(1933),
    [anon_sym_unorm] = ACTIONS(1933),
    [anon_sym_point] = ACTIONS(1933),
    [anon_sym_line] = ACTIONS(1933),
    [anon_sym_triangleadj] = ACTIONS(1933),
    [anon_sym_lineadj] = ACTIONS(1933),
    [anon_sym_triangle] = ACTIONS(1933),
  },
  [1084] = {
    [sym_identifier] = ACTIONS(1959),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4058),
    [anon_sym_COMMA] = ACTIONS(4058),
    [anon_sym_LPAREN2] = ACTIONS(4060),
    [anon_sym_TILDE] = ACTIONS(1961),
    [anon_sym_DASH] = ACTIONS(4063),
    [anon_sym_PLUS] = ACTIONS(4063),
    [anon_sym_STAR] = ACTIONS(4065),
    [anon_sym_SLASH] = ACTIONS(4063),
    [anon_sym_PERCENT] = ACTIONS(4063),
    [anon_sym_PIPE_PIPE] = ACTIONS(4058),
    [anon_sym_AMP_AMP] = ACTIONS(4060),
    [anon_sym_PIPE] = ACTIONS(4063),
    [anon_sym_CARET] = ACTIONS(4063),
    [anon_sym_AMP] = ACTIONS(4065),
    [anon_sym_EQ_EQ] = ACTIONS(4058),
    [anon_sym_BANG_EQ] = ACTIONS(4058),
    [anon_sym_GT] = ACTIONS(4063),
    [anon_sym_GT_EQ] = ACTIONS(4058),
    [anon_sym_LT_EQ] = ACTIONS(4063),
    [anon_sym_LT] = ACTIONS(4063),
    [anon_sym_LT_LT] = ACTIONS(4063),
    [anon_sym_GT_GT] = ACTIONS(4063),
    [anon_sym_SEMI] = ACTIONS(4060),
    [anon_sym___extension__] = ACTIONS(1959),
    [anon_sym_in] = ACTIONS(1959),
    [anon_sym_out] = ACTIONS(1959),
    [anon_sym_inout] = ACTIONS(1959),
    [anon_sym_extern] = ACTIONS(1959),
    [anon_sym___attribute__] = ACTIONS(1959),
    [anon_sym_COLON_COLON] = ACTIONS(1961),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4060),
    [anon_sym___declspec] = ACTIONS(1959),
    [anon_sym___based] = ACTIONS(1959),
    [anon_sym___cdecl] = ACTIONS(1959),
    [anon_sym___clrcall] = ACTIONS(1959),
    [anon_sym___stdcall] = ACTIONS(1959),
    [anon_sym___fastcall] = ACTIONS(1959),
    [anon_sym___thiscall] = ACTIONS(1959),
    [anon_sym___vectorcall] = ACTIONS(1959),
    [anon_sym_LBRACE] = ACTIONS(1961),
    [anon_sym_RBRACE] = ACTIONS(4058),
    [anon_sym_LBRACK] = ACTIONS(4065),
    [anon_sym_static] = ACTIONS(1959),
    [anon_sym_EQ] = ACTIONS(4063),
    [anon_sym_register] = ACTIONS(1959),
    [anon_sym_inline] = ACTIONS(1959),
    [anon_sym___inline] = ACTIONS(1959),
    [anon_sym___inline__] = ACTIONS(1959),
    [anon_sym___forceinline] = ACTIONS(1959),
    [anon_sym_thread_local] = ACTIONS(1959),
    [anon_sym___thread] = ACTIONS(1959),
    [anon_sym_const] = ACTIONS(1959),
    [anon_sym_constexpr] = ACTIONS(1959),
    [anon_sym_volatile] = ACTIONS(1959),
    [anon_sym_restrict] = ACTIONS(1959),
    [anon_sym___restrict__] = ACTIONS(1959),
    [anon_sym__Atomic] = ACTIONS(1959),
    [anon_sym__Noreturn] = ACTIONS(1959),
    [anon_sym_noreturn] = ACTIONS(1959),
    [anon_sym_mutable] = ACTIONS(1959),
    [anon_sym_constinit] = ACTIONS(1959),
    [anon_sym_consteval] = ACTIONS(1959),
    [anon_sym_alignas] = ACTIONS(1959),
    [anon_sym__Alignas] = ACTIONS(1959),
    [anon_sym_QMARK] = ACTIONS(4058),
    [anon_sym_STAR_EQ] = ACTIONS(4058),
    [anon_sym_SLASH_EQ] = ACTIONS(4058),
    [anon_sym_PERCENT_EQ] = ACTIONS(4058),
    [anon_sym_PLUS_EQ] = ACTIONS(4058),
    [anon_sym_DASH_EQ] = ACTIONS(4058),
    [anon_sym_LT_LT_EQ] = ACTIONS(4058),
    [anon_sym_GT_GT_EQ] = ACTIONS(4058),
    [anon_sym_AMP_EQ] = ACTIONS(4058),
    [anon_sym_CARET_EQ] = ACTIONS(4058),
    [anon_sym_PIPE_EQ] = ACTIONS(4058),
    [anon_sym_and_eq] = ACTIONS(4063),
    [anon_sym_or_eq] = ACTIONS(4063),
    [anon_sym_xor_eq] = ACTIONS(4063),
    [anon_sym_LT_EQ_GT] = ACTIONS(4058),
    [anon_sym_or] = ACTIONS(4063),
    [anon_sym_and] = ACTIONS(4063),
    [anon_sym_bitor] = ACTIONS(4063),
    [anon_sym_xor] = ACTIONS(4063),
    [anon_sym_bitand] = ACTIONS(4063),
    [anon_sym_not_eq] = ACTIONS(4063),
    [anon_sym_DASH_DASH] = ACTIONS(4058),
    [anon_sym_PLUS_PLUS] = ACTIONS(4058),
    [anon_sym_DOT] = ACTIONS(4063),
    [anon_sym_DOT_STAR] = ACTIONS(4058),
    [anon_sym_DASH_GT] = ACTIONS(4058),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1959),
    [anon_sym_decltype] = ACTIONS(1959),
    [sym_virtual] = ACTIONS(1959),
    [anon_sym_template] = ACTIONS(1959),
    [anon_sym_operator] = ACTIONS(1959),
    [anon_sym_precise] = ACTIONS(1959),
    [anon_sym_shared] = ACTIONS(1959),
    [anon_sym_groupshared] = ACTIONS(1959),
    [anon_sym_uniform] = ACTIONS(1959),
    [anon_sym_row_major] = ACTIONS(1959),
    [anon_sym_column_major] = ACTIONS(1959),
    [anon_sym_globallycoherent] = ACTIONS(1959),
    [anon_sym_centroid] = ACTIONS(1959),
    [anon_sym_noperspective] = ACTIONS(1959),
    [anon_sym_nointerpolation] = ACTIONS(1959),
    [anon_sym_sample] = ACTIONS(1959),
    [anon_sym_linear] = ACTIONS(1959),
    [anon_sym_snorm] = ACTIONS(1959),
    [anon_sym_unorm] = ACTIONS(1959),
    [anon_sym_point] = ACTIONS(1959),
    [anon_sym_line] = ACTIONS(1959),
    [anon_sym_triangleadj] = ACTIONS(1959),
    [anon_sym_lineadj] = ACTIONS(1959),
    [anon_sym_triangle] = ACTIONS(1959),
  },
  [1085] = {
    [sym__declaration_modifiers] = STATE(1984),
    [sym__declaration_specifiers] = STATE(4097),
    [sym_attribute_specifier] = STATE(1984),
    [sym_attribute_declaration] = STATE(1984),
    [sym_ms_declspec_modifier] = STATE(1984),
    [sym_ms_call_modifier] = STATE(6158),
    [sym__abstract_declarator] = STATE(6698),
    [sym_abstract_parenthesized_declarator] = STATE(6033),
    [sym_abstract_pointer_declarator] = STATE(6033),
    [sym_abstract_function_declarator] = STATE(6033),
    [sym_abstract_array_declarator] = STATE(6033),
    [sym_storage_class_specifier] = STATE(1984),
    [sym_type_qualifier] = STATE(1984),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_parameter_list] = STATE(3525),
    [sym_parameter_declaration] = STATE(7178),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_optional_parameter_declaration] = STATE(7178),
    [sym_variadic_parameter_declaration] = STATE(7178),
    [sym_abstract_reference_declarator] = STATE(6033),
    [sym__function_declarator_seq] = STATE(6076),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6449),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1984),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1984),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(4068),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1877),
    [anon_sym_RPAREN] = ACTIONS(3932),
    [anon_sym_LPAREN2] = ACTIONS(4070),
    [anon_sym_STAR] = ACTIONS(4072),
    [anon_sym_AMP_AMP] = ACTIONS(4074),
    [anon_sym_AMP] = ACTIONS(4076),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1827),
    [anon_sym_out] = ACTIONS(1827),
    [anon_sym_inout] = ACTIONS(1827),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(4078),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___cdecl] = ACTIONS(2034),
    [anon_sym___clrcall] = ACTIONS(2034),
    [anon_sym___stdcall] = ACTIONS(2034),
    [anon_sym___fastcall] = ACTIONS(2034),
    [anon_sym___thiscall] = ACTIONS(2034),
    [anon_sym___vectorcall] = ACTIONS(2034),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(4080),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(1833),
    [anon_sym_class] = ACTIONS(1835),
    [anon_sym_struct] = ACTIONS(1837),
    [anon_sym_union] = ACTIONS(1839),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1827),
    [anon_sym_typename] = ACTIONS(1863),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1086] = {
    [sym__declaration_modifiers] = STATE(1984),
    [sym__declaration_specifiers] = STATE(4097),
    [sym_attribute_specifier] = STATE(1984),
    [sym_attribute_declaration] = STATE(1984),
    [sym_ms_declspec_modifier] = STATE(1984),
    [sym_ms_call_modifier] = STATE(6119),
    [sym__abstract_declarator] = STATE(6683),
    [sym_abstract_parenthesized_declarator] = STATE(6033),
    [sym_abstract_pointer_declarator] = STATE(6033),
    [sym_abstract_function_declarator] = STATE(6033),
    [sym_abstract_array_declarator] = STATE(6033),
    [sym_storage_class_specifier] = STATE(1984),
    [sym_type_qualifier] = STATE(1984),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_parameter_list] = STATE(3525),
    [sym_parameter_declaration] = STATE(7178),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_optional_parameter_declaration] = STATE(7178),
    [sym_variadic_parameter_declaration] = STATE(7178),
    [sym_abstract_reference_declarator] = STATE(6033),
    [sym__function_declarator_seq] = STATE(6076),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6449),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1984),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1984),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(4068),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1877),
    [anon_sym_RPAREN] = ACTIONS(3932),
    [anon_sym_LPAREN2] = ACTIONS(4070),
    [anon_sym_STAR] = ACTIONS(4072),
    [anon_sym_AMP_AMP] = ACTIONS(4074),
    [anon_sym_AMP] = ACTIONS(4076),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1827),
    [anon_sym_out] = ACTIONS(1827),
    [anon_sym_inout] = ACTIONS(1827),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(4078),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___cdecl] = ACTIONS(2034),
    [anon_sym___clrcall] = ACTIONS(2034),
    [anon_sym___stdcall] = ACTIONS(2034),
    [anon_sym___fastcall] = ACTIONS(2034),
    [anon_sym___thiscall] = ACTIONS(2034),
    [anon_sym___vectorcall] = ACTIONS(2034),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(4080),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(1833),
    [anon_sym_class] = ACTIONS(1835),
    [anon_sym_struct] = ACTIONS(1837),
    [anon_sym_union] = ACTIONS(1839),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1827),
    [anon_sym_typename] = ACTIONS(1863),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1087] = {
    [sym_type_qualifier] = STATE(1095),
    [sym_alignas_qualifier] = STATE(2435),
    [sym_expression] = STATE(4699),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [aux_sym_array_declarator_repeat1] = STATE(1095),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(4082),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4084),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_static] = ACTIONS(4086),
    [anon_sym_RBRACK] = ACTIONS(4088),
    [anon_sym_const] = ACTIONS(4084),
    [anon_sym_constexpr] = ACTIONS(4084),
    [anon_sym_volatile] = ACTIONS(4084),
    [anon_sym_restrict] = ACTIONS(4084),
    [anon_sym___restrict__] = ACTIONS(4084),
    [anon_sym__Atomic] = ACTIONS(4084),
    [anon_sym__Noreturn] = ACTIONS(4084),
    [anon_sym_noreturn] = ACTIONS(4084),
    [anon_sym_mutable] = ACTIONS(4084),
    [anon_sym_constinit] = ACTIONS(4084),
    [anon_sym_consteval] = ACTIONS(4084),
    [anon_sym_alignas] = ACTIONS(4090),
    [anon_sym__Alignas] = ACTIONS(4090),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1088] = {
    [sym_type_qualifier] = STATE(2399),
    [sym_alignas_qualifier] = STATE(2435),
    [sym_expression] = STATE(4687),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [aux_sym_array_declarator_repeat1] = STATE(2399),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(4092),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4084),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_static] = ACTIONS(4094),
    [anon_sym_RBRACK] = ACTIONS(4096),
    [anon_sym_const] = ACTIONS(4084),
    [anon_sym_constexpr] = ACTIONS(4084),
    [anon_sym_volatile] = ACTIONS(4084),
    [anon_sym_restrict] = ACTIONS(4084),
    [anon_sym___restrict__] = ACTIONS(4084),
    [anon_sym__Atomic] = ACTIONS(4084),
    [anon_sym__Noreturn] = ACTIONS(4084),
    [anon_sym_noreturn] = ACTIONS(4084),
    [anon_sym_mutable] = ACTIONS(4084),
    [anon_sym_constinit] = ACTIONS(4084),
    [anon_sym_consteval] = ACTIONS(4084),
    [anon_sym_alignas] = ACTIONS(4090),
    [anon_sym__Alignas] = ACTIONS(4090),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1089] = {
    [sym_type_qualifier] = STATE(1103),
    [sym_alignas_qualifier] = STATE(2435),
    [sym_expression] = STATE(4714),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [aux_sym_array_declarator_repeat1] = STATE(1103),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(4098),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4084),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_static] = ACTIONS(4100),
    [anon_sym_RBRACK] = ACTIONS(4102),
    [anon_sym_const] = ACTIONS(4084),
    [anon_sym_constexpr] = ACTIONS(4084),
    [anon_sym_volatile] = ACTIONS(4084),
    [anon_sym_restrict] = ACTIONS(4084),
    [anon_sym___restrict__] = ACTIONS(4084),
    [anon_sym__Atomic] = ACTIONS(4084),
    [anon_sym__Noreturn] = ACTIONS(4084),
    [anon_sym_noreturn] = ACTIONS(4084),
    [anon_sym_mutable] = ACTIONS(4084),
    [anon_sym_constinit] = ACTIONS(4084),
    [anon_sym_consteval] = ACTIONS(4084),
    [anon_sym_alignas] = ACTIONS(4090),
    [anon_sym__Alignas] = ACTIONS(4090),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1090] = {
    [sym_type_qualifier] = STATE(2399),
    [sym_alignas_qualifier] = STATE(2435),
    [sym_expression] = STATE(4661),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [aux_sym_array_declarator_repeat1] = STATE(2399),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(4104),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4084),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_static] = ACTIONS(4094),
    [anon_sym_RBRACK] = ACTIONS(4106),
    [anon_sym_const] = ACTIONS(4084),
    [anon_sym_constexpr] = ACTIONS(4084),
    [anon_sym_volatile] = ACTIONS(4084),
    [anon_sym_restrict] = ACTIONS(4084),
    [anon_sym___restrict__] = ACTIONS(4084),
    [anon_sym__Atomic] = ACTIONS(4084),
    [anon_sym__Noreturn] = ACTIONS(4084),
    [anon_sym_noreturn] = ACTIONS(4084),
    [anon_sym_mutable] = ACTIONS(4084),
    [anon_sym_constinit] = ACTIONS(4084),
    [anon_sym_consteval] = ACTIONS(4084),
    [anon_sym_alignas] = ACTIONS(4090),
    [anon_sym__Alignas] = ACTIONS(4090),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1091] = {
    [sym_type_qualifier] = STATE(1096),
    [sym_alignas_qualifier] = STATE(2435),
    [sym_expression] = STATE(4690),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [aux_sym_array_declarator_repeat1] = STATE(1096),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(4108),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4084),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_static] = ACTIONS(4110),
    [anon_sym_RBRACK] = ACTIONS(4112),
    [anon_sym_const] = ACTIONS(4084),
    [anon_sym_constexpr] = ACTIONS(4084),
    [anon_sym_volatile] = ACTIONS(4084),
    [anon_sym_restrict] = ACTIONS(4084),
    [anon_sym___restrict__] = ACTIONS(4084),
    [anon_sym__Atomic] = ACTIONS(4084),
    [anon_sym__Noreturn] = ACTIONS(4084),
    [anon_sym_noreturn] = ACTIONS(4084),
    [anon_sym_mutable] = ACTIONS(4084),
    [anon_sym_constinit] = ACTIONS(4084),
    [anon_sym_consteval] = ACTIONS(4084),
    [anon_sym_alignas] = ACTIONS(4090),
    [anon_sym__Alignas] = ACTIONS(4090),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1092] = {
    [sym_type_qualifier] = STATE(1104),
    [sym_alignas_qualifier] = STATE(2435),
    [sym_expression] = STATE(4653),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [aux_sym_array_declarator_repeat1] = STATE(1104),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(4114),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4084),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_static] = ACTIONS(4116),
    [anon_sym_RBRACK] = ACTIONS(4118),
    [anon_sym_const] = ACTIONS(4084),
    [anon_sym_constexpr] = ACTIONS(4084),
    [anon_sym_volatile] = ACTIONS(4084),
    [anon_sym_restrict] = ACTIONS(4084),
    [anon_sym___restrict__] = ACTIONS(4084),
    [anon_sym__Atomic] = ACTIONS(4084),
    [anon_sym__Noreturn] = ACTIONS(4084),
    [anon_sym_noreturn] = ACTIONS(4084),
    [anon_sym_mutable] = ACTIONS(4084),
    [anon_sym_constinit] = ACTIONS(4084),
    [anon_sym_consteval] = ACTIONS(4084),
    [anon_sym_alignas] = ACTIONS(4090),
    [anon_sym__Alignas] = ACTIONS(4090),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1093] = {
    [sym_type_qualifier] = STATE(1090),
    [sym_alignas_qualifier] = STATE(2435),
    [sym_expression] = STATE(4647),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [aux_sym_array_declarator_repeat1] = STATE(1090),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(4120),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4084),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_static] = ACTIONS(4122),
    [anon_sym_RBRACK] = ACTIONS(4124),
    [anon_sym_const] = ACTIONS(4084),
    [anon_sym_constexpr] = ACTIONS(4084),
    [anon_sym_volatile] = ACTIONS(4084),
    [anon_sym_restrict] = ACTIONS(4084),
    [anon_sym___restrict__] = ACTIONS(4084),
    [anon_sym__Atomic] = ACTIONS(4084),
    [anon_sym__Noreturn] = ACTIONS(4084),
    [anon_sym_noreturn] = ACTIONS(4084),
    [anon_sym_mutable] = ACTIONS(4084),
    [anon_sym_constinit] = ACTIONS(4084),
    [anon_sym_consteval] = ACTIONS(4084),
    [anon_sym_alignas] = ACTIONS(4090),
    [anon_sym__Alignas] = ACTIONS(4090),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1094] = {
    [sym_type_qualifier] = STATE(1097),
    [sym_alignas_qualifier] = STATE(2435),
    [sym_expression] = STATE(4705),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [aux_sym_array_declarator_repeat1] = STATE(1097),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(4126),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4084),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_static] = ACTIONS(4128),
    [anon_sym_RBRACK] = ACTIONS(4130),
    [anon_sym_const] = ACTIONS(4084),
    [anon_sym_constexpr] = ACTIONS(4084),
    [anon_sym_volatile] = ACTIONS(4084),
    [anon_sym_restrict] = ACTIONS(4084),
    [anon_sym___restrict__] = ACTIONS(4084),
    [anon_sym__Atomic] = ACTIONS(4084),
    [anon_sym__Noreturn] = ACTIONS(4084),
    [anon_sym_noreturn] = ACTIONS(4084),
    [anon_sym_mutable] = ACTIONS(4084),
    [anon_sym_constinit] = ACTIONS(4084),
    [anon_sym_consteval] = ACTIONS(4084),
    [anon_sym_alignas] = ACTIONS(4090),
    [anon_sym__Alignas] = ACTIONS(4090),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1095] = {
    [sym_type_qualifier] = STATE(2399),
    [sym_alignas_qualifier] = STATE(2435),
    [sym_expression] = STATE(4727),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [aux_sym_array_declarator_repeat1] = STATE(2399),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(4132),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4084),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_static] = ACTIONS(4094),
    [anon_sym_RBRACK] = ACTIONS(4134),
    [anon_sym_const] = ACTIONS(4084),
    [anon_sym_constexpr] = ACTIONS(4084),
    [anon_sym_volatile] = ACTIONS(4084),
    [anon_sym_restrict] = ACTIONS(4084),
    [anon_sym___restrict__] = ACTIONS(4084),
    [anon_sym__Atomic] = ACTIONS(4084),
    [anon_sym__Noreturn] = ACTIONS(4084),
    [anon_sym_noreturn] = ACTIONS(4084),
    [anon_sym_mutable] = ACTIONS(4084),
    [anon_sym_constinit] = ACTIONS(4084),
    [anon_sym_consteval] = ACTIONS(4084),
    [anon_sym_alignas] = ACTIONS(4090),
    [anon_sym__Alignas] = ACTIONS(4090),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1096] = {
    [sym_type_qualifier] = STATE(2399),
    [sym_alignas_qualifier] = STATE(2435),
    [sym_expression] = STATE(4724),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [aux_sym_array_declarator_repeat1] = STATE(2399),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(4136),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4084),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_static] = ACTIONS(4094),
    [anon_sym_RBRACK] = ACTIONS(4138),
    [anon_sym_const] = ACTIONS(4084),
    [anon_sym_constexpr] = ACTIONS(4084),
    [anon_sym_volatile] = ACTIONS(4084),
    [anon_sym_restrict] = ACTIONS(4084),
    [anon_sym___restrict__] = ACTIONS(4084),
    [anon_sym__Atomic] = ACTIONS(4084),
    [anon_sym__Noreturn] = ACTIONS(4084),
    [anon_sym_noreturn] = ACTIONS(4084),
    [anon_sym_mutable] = ACTIONS(4084),
    [anon_sym_constinit] = ACTIONS(4084),
    [anon_sym_consteval] = ACTIONS(4084),
    [anon_sym_alignas] = ACTIONS(4090),
    [anon_sym__Alignas] = ACTIONS(4090),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1097] = {
    [sym_type_qualifier] = STATE(2399),
    [sym_alignas_qualifier] = STATE(2435),
    [sym_expression] = STATE(4728),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [aux_sym_array_declarator_repeat1] = STATE(2399),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(4140),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4084),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_static] = ACTIONS(4094),
    [anon_sym_RBRACK] = ACTIONS(4142),
    [anon_sym_const] = ACTIONS(4084),
    [anon_sym_constexpr] = ACTIONS(4084),
    [anon_sym_volatile] = ACTIONS(4084),
    [anon_sym_restrict] = ACTIONS(4084),
    [anon_sym___restrict__] = ACTIONS(4084),
    [anon_sym__Atomic] = ACTIONS(4084),
    [anon_sym__Noreturn] = ACTIONS(4084),
    [anon_sym_noreturn] = ACTIONS(4084),
    [anon_sym_mutable] = ACTIONS(4084),
    [anon_sym_constinit] = ACTIONS(4084),
    [anon_sym_consteval] = ACTIONS(4084),
    [anon_sym_alignas] = ACTIONS(4090),
    [anon_sym__Alignas] = ACTIONS(4090),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1098] = {
    [sym_type_qualifier] = STATE(1101),
    [sym_alignas_qualifier] = STATE(2435),
    [sym_expression] = STATE(4680),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [aux_sym_array_declarator_repeat1] = STATE(1101),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(4144),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4084),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_static] = ACTIONS(4146),
    [anon_sym_RBRACK] = ACTIONS(4148),
    [anon_sym_const] = ACTIONS(4084),
    [anon_sym_constexpr] = ACTIONS(4084),
    [anon_sym_volatile] = ACTIONS(4084),
    [anon_sym_restrict] = ACTIONS(4084),
    [anon_sym___restrict__] = ACTIONS(4084),
    [anon_sym__Atomic] = ACTIONS(4084),
    [anon_sym__Noreturn] = ACTIONS(4084),
    [anon_sym_noreturn] = ACTIONS(4084),
    [anon_sym_mutable] = ACTIONS(4084),
    [anon_sym_constinit] = ACTIONS(4084),
    [anon_sym_consteval] = ACTIONS(4084),
    [anon_sym_alignas] = ACTIONS(4090),
    [anon_sym__Alignas] = ACTIONS(4090),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1099] = {
    [sym_type_qualifier] = STATE(1103),
    [sym_alignas_qualifier] = STATE(2435),
    [sym_expression] = STATE(4714),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [aux_sym_array_declarator_repeat1] = STATE(1103),
    [sym_identifier] = ACTIONS(4150),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(4098),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4084),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_static] = ACTIONS(4100),
    [anon_sym_RBRACK] = ACTIONS(4102),
    [anon_sym_const] = ACTIONS(4084),
    [anon_sym_constexpr] = ACTIONS(4084),
    [anon_sym_volatile] = ACTIONS(4084),
    [anon_sym_restrict] = ACTIONS(4084),
    [anon_sym___restrict__] = ACTIONS(4084),
    [anon_sym__Atomic] = ACTIONS(4084),
    [anon_sym__Noreturn] = ACTIONS(4084),
    [anon_sym_noreturn] = ACTIONS(4084),
    [anon_sym_mutable] = ACTIONS(4084),
    [anon_sym_constinit] = ACTIONS(4084),
    [anon_sym_consteval] = ACTIONS(4084),
    [anon_sym_alignas] = ACTIONS(4090),
    [anon_sym__Alignas] = ACTIONS(4090),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1100] = {
    [sym_type_qualifier] = STATE(1088),
    [sym_alignas_qualifier] = STATE(2435),
    [sym_expression] = STATE(4677),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [aux_sym_array_declarator_repeat1] = STATE(1088),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(4152),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4084),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_static] = ACTIONS(4154),
    [anon_sym_RBRACK] = ACTIONS(4156),
    [anon_sym_const] = ACTIONS(4084),
    [anon_sym_constexpr] = ACTIONS(4084),
    [anon_sym_volatile] = ACTIONS(4084),
    [anon_sym_restrict] = ACTIONS(4084),
    [anon_sym___restrict__] = ACTIONS(4084),
    [anon_sym__Atomic] = ACTIONS(4084),
    [anon_sym__Noreturn] = ACTIONS(4084),
    [anon_sym_noreturn] = ACTIONS(4084),
    [anon_sym_mutable] = ACTIONS(4084),
    [anon_sym_constinit] = ACTIONS(4084),
    [anon_sym_consteval] = ACTIONS(4084),
    [anon_sym_alignas] = ACTIONS(4090),
    [anon_sym__Alignas] = ACTIONS(4090),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1101] = {
    [sym_type_qualifier] = STATE(2399),
    [sym_alignas_qualifier] = STATE(2435),
    [sym_expression] = STATE(4637),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [aux_sym_array_declarator_repeat1] = STATE(2399),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(4158),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4084),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_static] = ACTIONS(4094),
    [anon_sym_RBRACK] = ACTIONS(4160),
    [anon_sym_const] = ACTIONS(4084),
    [anon_sym_constexpr] = ACTIONS(4084),
    [anon_sym_volatile] = ACTIONS(4084),
    [anon_sym_restrict] = ACTIONS(4084),
    [anon_sym___restrict__] = ACTIONS(4084),
    [anon_sym__Atomic] = ACTIONS(4084),
    [anon_sym__Noreturn] = ACTIONS(4084),
    [anon_sym_noreturn] = ACTIONS(4084),
    [anon_sym_mutable] = ACTIONS(4084),
    [anon_sym_constinit] = ACTIONS(4084),
    [anon_sym_consteval] = ACTIONS(4084),
    [anon_sym_alignas] = ACTIONS(4090),
    [anon_sym__Alignas] = ACTIONS(4090),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1102] = {
    [sym_type_qualifier] = STATE(1105),
    [sym_alignas_qualifier] = STATE(2435),
    [sym_expression] = STATE(4702),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [aux_sym_array_declarator_repeat1] = STATE(1105),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4084),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_static] = ACTIONS(4164),
    [anon_sym_RBRACK] = ACTIONS(4166),
    [anon_sym_const] = ACTIONS(4084),
    [anon_sym_constexpr] = ACTIONS(4084),
    [anon_sym_volatile] = ACTIONS(4084),
    [anon_sym_restrict] = ACTIONS(4084),
    [anon_sym___restrict__] = ACTIONS(4084),
    [anon_sym__Atomic] = ACTIONS(4084),
    [anon_sym__Noreturn] = ACTIONS(4084),
    [anon_sym_noreturn] = ACTIONS(4084),
    [anon_sym_mutable] = ACTIONS(4084),
    [anon_sym_constinit] = ACTIONS(4084),
    [anon_sym_consteval] = ACTIONS(4084),
    [anon_sym_alignas] = ACTIONS(4090),
    [anon_sym__Alignas] = ACTIONS(4090),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1103] = {
    [sym_type_qualifier] = STATE(2399),
    [sym_alignas_qualifier] = STATE(2435),
    [sym_expression] = STATE(4689),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [aux_sym_array_declarator_repeat1] = STATE(2399),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(4168),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4084),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_static] = ACTIONS(4094),
    [anon_sym_RBRACK] = ACTIONS(4170),
    [anon_sym_const] = ACTIONS(4084),
    [anon_sym_constexpr] = ACTIONS(4084),
    [anon_sym_volatile] = ACTIONS(4084),
    [anon_sym_restrict] = ACTIONS(4084),
    [anon_sym___restrict__] = ACTIONS(4084),
    [anon_sym__Atomic] = ACTIONS(4084),
    [anon_sym__Noreturn] = ACTIONS(4084),
    [anon_sym_noreturn] = ACTIONS(4084),
    [anon_sym_mutable] = ACTIONS(4084),
    [anon_sym_constinit] = ACTIONS(4084),
    [anon_sym_consteval] = ACTIONS(4084),
    [anon_sym_alignas] = ACTIONS(4090),
    [anon_sym__Alignas] = ACTIONS(4090),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1104] = {
    [sym_type_qualifier] = STATE(2399),
    [sym_alignas_qualifier] = STATE(2435),
    [sym_expression] = STATE(4712),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [aux_sym_array_declarator_repeat1] = STATE(2399),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(4172),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4084),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_static] = ACTIONS(4094),
    [anon_sym_RBRACK] = ACTIONS(4174),
    [anon_sym_const] = ACTIONS(4084),
    [anon_sym_constexpr] = ACTIONS(4084),
    [anon_sym_volatile] = ACTIONS(4084),
    [anon_sym_restrict] = ACTIONS(4084),
    [anon_sym___restrict__] = ACTIONS(4084),
    [anon_sym__Atomic] = ACTIONS(4084),
    [anon_sym__Noreturn] = ACTIONS(4084),
    [anon_sym_noreturn] = ACTIONS(4084),
    [anon_sym_mutable] = ACTIONS(4084),
    [anon_sym_constinit] = ACTIONS(4084),
    [anon_sym_consteval] = ACTIONS(4084),
    [anon_sym_alignas] = ACTIONS(4090),
    [anon_sym__Alignas] = ACTIONS(4090),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1105] = {
    [sym_type_qualifier] = STATE(2399),
    [sym_alignas_qualifier] = STATE(2435),
    [sym_expression] = STATE(4697),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [aux_sym_array_declarator_repeat1] = STATE(2399),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(4176),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4084),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_static] = ACTIONS(4094),
    [anon_sym_RBRACK] = ACTIONS(4178),
    [anon_sym_const] = ACTIONS(4084),
    [anon_sym_constexpr] = ACTIONS(4084),
    [anon_sym_volatile] = ACTIONS(4084),
    [anon_sym_restrict] = ACTIONS(4084),
    [anon_sym___restrict__] = ACTIONS(4084),
    [anon_sym__Atomic] = ACTIONS(4084),
    [anon_sym__Noreturn] = ACTIONS(4084),
    [anon_sym_noreturn] = ACTIONS(4084),
    [anon_sym_mutable] = ACTIONS(4084),
    [anon_sym_constinit] = ACTIONS(4084),
    [anon_sym_consteval] = ACTIONS(4084),
    [anon_sym_alignas] = ACTIONS(4090),
    [anon_sym__Alignas] = ACTIONS(4090),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1106] = {
    [sym_type_qualifier] = STATE(1107),
    [sym_alignas_qualifier] = STATE(2435),
    [sym_expression] = STATE(4651),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [aux_sym_array_declarator_repeat1] = STATE(1107),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(4180),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4084),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_static] = ACTIONS(4182),
    [anon_sym_RBRACK] = ACTIONS(4184),
    [anon_sym_const] = ACTIONS(4084),
    [anon_sym_constexpr] = ACTIONS(4084),
    [anon_sym_volatile] = ACTIONS(4084),
    [anon_sym_restrict] = ACTIONS(4084),
    [anon_sym___restrict__] = ACTIONS(4084),
    [anon_sym__Atomic] = ACTIONS(4084),
    [anon_sym__Noreturn] = ACTIONS(4084),
    [anon_sym_noreturn] = ACTIONS(4084),
    [anon_sym_mutable] = ACTIONS(4084),
    [anon_sym_constinit] = ACTIONS(4084),
    [anon_sym_consteval] = ACTIONS(4084),
    [anon_sym_alignas] = ACTIONS(4090),
    [anon_sym__Alignas] = ACTIONS(4090),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1107] = {
    [sym_type_qualifier] = STATE(2399),
    [sym_alignas_qualifier] = STATE(2435),
    [sym_expression] = STATE(4688),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [aux_sym_array_declarator_repeat1] = STATE(2399),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(4186),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4084),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_static] = ACTIONS(4094),
    [anon_sym_RBRACK] = ACTIONS(4188),
    [anon_sym_const] = ACTIONS(4084),
    [anon_sym_constexpr] = ACTIONS(4084),
    [anon_sym_volatile] = ACTIONS(4084),
    [anon_sym_restrict] = ACTIONS(4084),
    [anon_sym___restrict__] = ACTIONS(4084),
    [anon_sym__Atomic] = ACTIONS(4084),
    [anon_sym__Noreturn] = ACTIONS(4084),
    [anon_sym_noreturn] = ACTIONS(4084),
    [anon_sym_mutable] = ACTIONS(4084),
    [anon_sym_constinit] = ACTIONS(4084),
    [anon_sym_consteval] = ACTIONS(4084),
    [anon_sym_alignas] = ACTIONS(4090),
    [anon_sym__Alignas] = ACTIONS(4090),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1108] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5268),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6527),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6270),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_parameter_list] = STATE(897),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2726),
    [sym_template_function] = STATE(6270),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5602),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(4190),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym_LT] = ACTIONS(4192),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(4194),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(2078),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1109] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5290),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6540),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6270),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_parameter_list] = STATE(902),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2726),
    [sym_template_function] = STATE(6270),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5602),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(4190),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym_LT] = ACTIONS(4192),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(4194),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(2078),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1110] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5242),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6556),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6270),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_parameter_list] = STATE(896),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2726),
    [sym_template_function] = STATE(6270),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5602),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(4190),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym_LT] = ACTIONS(4192),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(4194),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(2078),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1111] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5297),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6524),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6270),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_parameter_list] = STATE(901),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2726),
    [sym_template_function] = STATE(6270),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5602),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(4190),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym_LT] = ACTIONS(4192),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(4194),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(2078),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1112] = {
    [sym_identifier] = ACTIONS(2502),
    [anon_sym_LPAREN2] = ACTIONS(2504),
    [anon_sym_BANG] = ACTIONS(2504),
    [anon_sym_TILDE] = ACTIONS(2504),
    [anon_sym_DASH] = ACTIONS(2502),
    [anon_sym_PLUS] = ACTIONS(2502),
    [anon_sym_STAR] = ACTIONS(2504),
    [anon_sym_AMP] = ACTIONS(2504),
    [anon_sym___extension__] = ACTIONS(2502),
    [anon_sym_in] = ACTIONS(2502),
    [anon_sym_out] = ACTIONS(2502),
    [anon_sym_inout] = ACTIONS(2502),
    [anon_sym_extern] = ACTIONS(2502),
    [anon_sym___attribute__] = ACTIONS(2502),
    [anon_sym_COLON_COLON] = ACTIONS(2504),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2504),
    [anon_sym___declspec] = ACTIONS(2502),
    [anon_sym_signed] = ACTIONS(2502),
    [anon_sym_unsigned] = ACTIONS(2502),
    [anon_sym_long] = ACTIONS(2502),
    [anon_sym_short] = ACTIONS(2502),
    [anon_sym_LBRACK] = ACTIONS(2502),
    [anon_sym_static] = ACTIONS(2502),
    [anon_sym_register] = ACTIONS(2502),
    [anon_sym_inline] = ACTIONS(2502),
    [anon_sym___inline] = ACTIONS(2502),
    [anon_sym___inline__] = ACTIONS(2502),
    [anon_sym___forceinline] = ACTIONS(2502),
    [anon_sym_thread_local] = ACTIONS(2502),
    [anon_sym___thread] = ACTIONS(2502),
    [anon_sym_const] = ACTIONS(2502),
    [anon_sym_constexpr] = ACTIONS(2502),
    [anon_sym_volatile] = ACTIONS(2502),
    [anon_sym_restrict] = ACTIONS(2502),
    [anon_sym___restrict__] = ACTIONS(2502),
    [anon_sym__Atomic] = ACTIONS(2502),
    [anon_sym__Noreturn] = ACTIONS(2502),
    [anon_sym_noreturn] = ACTIONS(2502),
    [anon_sym_mutable] = ACTIONS(2502),
    [anon_sym_constinit] = ACTIONS(2502),
    [anon_sym_consteval] = ACTIONS(2502),
    [anon_sym_alignas] = ACTIONS(2502),
    [anon_sym__Alignas] = ACTIONS(2502),
    [sym_primitive_type] = ACTIONS(2502),
    [anon_sym_enum] = ACTIONS(2502),
    [anon_sym_class] = ACTIONS(2502),
    [anon_sym_struct] = ACTIONS(2502),
    [anon_sym_union] = ACTIONS(2502),
    [anon_sym_not] = ACTIONS(2502),
    [anon_sym_compl] = ACTIONS(2502),
    [anon_sym_DASH_DASH] = ACTIONS(2504),
    [anon_sym_PLUS_PLUS] = ACTIONS(2504),
    [anon_sym_sizeof] = ACTIONS(2502),
    [anon_sym___alignof__] = ACTIONS(2502),
    [anon_sym___alignof] = ACTIONS(2502),
    [anon_sym__alignof] = ACTIONS(2502),
    [anon_sym_alignof] = ACTIONS(2502),
    [anon_sym__Alignof] = ACTIONS(2502),
    [anon_sym_offsetof] = ACTIONS(2502),
    [anon_sym__Generic] = ACTIONS(2502),
    [anon_sym_asm] = ACTIONS(2502),
    [anon_sym___asm__] = ACTIONS(2502),
    [sym_number_literal] = ACTIONS(2504),
    [anon_sym_L_SQUOTE] = ACTIONS(2504),
    [anon_sym_u_SQUOTE] = ACTIONS(2504),
    [anon_sym_U_SQUOTE] = ACTIONS(2504),
    [anon_sym_u8_SQUOTE] = ACTIONS(2504),
    [anon_sym_SQUOTE] = ACTIONS(2504),
    [anon_sym_L_DQUOTE] = ACTIONS(2504),
    [anon_sym_u_DQUOTE] = ACTIONS(2504),
    [anon_sym_U_DQUOTE] = ACTIONS(2504),
    [anon_sym_u8_DQUOTE] = ACTIONS(2504),
    [anon_sym_DQUOTE] = ACTIONS(2504),
    [sym_true] = ACTIONS(2502),
    [sym_false] = ACTIONS(2502),
    [anon_sym_NULL] = ACTIONS(2502),
    [anon_sym_nullptr] = ACTIONS(2502),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2502),
    [anon_sym_decltype] = ACTIONS(2502),
    [sym_virtual] = ACTIONS(2502),
    [anon_sym_typename] = ACTIONS(2502),
    [anon_sym_template] = ACTIONS(2502),
    [anon_sym_delete] = ACTIONS(2502),
    [anon_sym_R_DQUOTE] = ACTIONS(2504),
    [anon_sym_LR_DQUOTE] = ACTIONS(2504),
    [anon_sym_uR_DQUOTE] = ACTIONS(2504),
    [anon_sym_UR_DQUOTE] = ACTIONS(2504),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2504),
    [anon_sym_co_await] = ACTIONS(2502),
    [anon_sym_new] = ACTIONS(2502),
    [anon_sym_requires] = ACTIONS(2502),
    [sym_this] = ACTIONS(2502),
    [anon_sym_precise] = ACTIONS(2502),
    [anon_sym_shared] = ACTIONS(2502),
    [anon_sym_groupshared] = ACTIONS(2502),
    [anon_sym_uniform] = ACTIONS(2502),
    [anon_sym_row_major] = ACTIONS(2502),
    [anon_sym_column_major] = ACTIONS(2502),
    [anon_sym_globallycoherent] = ACTIONS(2502),
    [anon_sym_centroid] = ACTIONS(2502),
    [anon_sym_noperspective] = ACTIONS(2502),
    [anon_sym_nointerpolation] = ACTIONS(2502),
    [anon_sym_sample] = ACTIONS(2502),
    [anon_sym_linear] = ACTIONS(2502),
    [anon_sym_snorm] = ACTIONS(2502),
    [anon_sym_unorm] = ACTIONS(2502),
    [anon_sym_point] = ACTIONS(2502),
    [anon_sym_line] = ACTIONS(2502),
    [anon_sym_triangleadj] = ACTIONS(2502),
    [anon_sym_lineadj] = ACTIONS(2502),
    [anon_sym_triangle] = ACTIONS(2502),
  },
  [1113] = {
    [sym_identifier] = ACTIONS(2308),
    [anon_sym_LPAREN2] = ACTIONS(2310),
    [anon_sym_BANG] = ACTIONS(2310),
    [anon_sym_TILDE] = ACTIONS(2310),
    [anon_sym_DASH] = ACTIONS(2308),
    [anon_sym_PLUS] = ACTIONS(2308),
    [anon_sym_STAR] = ACTIONS(2310),
    [anon_sym_AMP] = ACTIONS(2310),
    [anon_sym___extension__] = ACTIONS(2308),
    [anon_sym_in] = ACTIONS(2308),
    [anon_sym_out] = ACTIONS(2308),
    [anon_sym_inout] = ACTIONS(2308),
    [anon_sym_extern] = ACTIONS(2308),
    [anon_sym___attribute__] = ACTIONS(2308),
    [anon_sym_COLON_COLON] = ACTIONS(2310),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2310),
    [anon_sym___declspec] = ACTIONS(2308),
    [anon_sym_signed] = ACTIONS(2308),
    [anon_sym_unsigned] = ACTIONS(2308),
    [anon_sym_long] = ACTIONS(2308),
    [anon_sym_short] = ACTIONS(2308),
    [anon_sym_LBRACK] = ACTIONS(2308),
    [anon_sym_static] = ACTIONS(2308),
    [anon_sym_register] = ACTIONS(2308),
    [anon_sym_inline] = ACTIONS(2308),
    [anon_sym___inline] = ACTIONS(2308),
    [anon_sym___inline__] = ACTIONS(2308),
    [anon_sym___forceinline] = ACTIONS(2308),
    [anon_sym_thread_local] = ACTIONS(2308),
    [anon_sym___thread] = ACTIONS(2308),
    [anon_sym_const] = ACTIONS(2308),
    [anon_sym_constexpr] = ACTIONS(2308),
    [anon_sym_volatile] = ACTIONS(2308),
    [anon_sym_restrict] = ACTIONS(2308),
    [anon_sym___restrict__] = ACTIONS(2308),
    [anon_sym__Atomic] = ACTIONS(2308),
    [anon_sym__Noreturn] = ACTIONS(2308),
    [anon_sym_noreturn] = ACTIONS(2308),
    [anon_sym_mutable] = ACTIONS(2308),
    [anon_sym_constinit] = ACTIONS(2308),
    [anon_sym_consteval] = ACTIONS(2308),
    [anon_sym_alignas] = ACTIONS(2308),
    [anon_sym__Alignas] = ACTIONS(2308),
    [sym_primitive_type] = ACTIONS(2308),
    [anon_sym_enum] = ACTIONS(2308),
    [anon_sym_class] = ACTIONS(2308),
    [anon_sym_struct] = ACTIONS(2308),
    [anon_sym_union] = ACTIONS(2308),
    [anon_sym_not] = ACTIONS(2308),
    [anon_sym_compl] = ACTIONS(2308),
    [anon_sym_DASH_DASH] = ACTIONS(2310),
    [anon_sym_PLUS_PLUS] = ACTIONS(2310),
    [anon_sym_sizeof] = ACTIONS(2308),
    [anon_sym___alignof__] = ACTIONS(2308),
    [anon_sym___alignof] = ACTIONS(2308),
    [anon_sym__alignof] = ACTIONS(2308),
    [anon_sym_alignof] = ACTIONS(2308),
    [anon_sym__Alignof] = ACTIONS(2308),
    [anon_sym_offsetof] = ACTIONS(2308),
    [anon_sym__Generic] = ACTIONS(2308),
    [anon_sym_asm] = ACTIONS(2308),
    [anon_sym___asm__] = ACTIONS(2308),
    [sym_number_literal] = ACTIONS(2310),
    [anon_sym_L_SQUOTE] = ACTIONS(2310),
    [anon_sym_u_SQUOTE] = ACTIONS(2310),
    [anon_sym_U_SQUOTE] = ACTIONS(2310),
    [anon_sym_u8_SQUOTE] = ACTIONS(2310),
    [anon_sym_SQUOTE] = ACTIONS(2310),
    [anon_sym_L_DQUOTE] = ACTIONS(2310),
    [anon_sym_u_DQUOTE] = ACTIONS(2310),
    [anon_sym_U_DQUOTE] = ACTIONS(2310),
    [anon_sym_u8_DQUOTE] = ACTIONS(2310),
    [anon_sym_DQUOTE] = ACTIONS(2310),
    [sym_true] = ACTIONS(2308),
    [sym_false] = ACTIONS(2308),
    [anon_sym_NULL] = ACTIONS(2308),
    [anon_sym_nullptr] = ACTIONS(2308),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2308),
    [anon_sym_decltype] = ACTIONS(2308),
    [sym_virtual] = ACTIONS(2308),
    [anon_sym_typename] = ACTIONS(2308),
    [anon_sym_template] = ACTIONS(2308),
    [anon_sym_delete] = ACTIONS(2308),
    [anon_sym_R_DQUOTE] = ACTIONS(2310),
    [anon_sym_LR_DQUOTE] = ACTIONS(2310),
    [anon_sym_uR_DQUOTE] = ACTIONS(2310),
    [anon_sym_UR_DQUOTE] = ACTIONS(2310),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2310),
    [anon_sym_co_await] = ACTIONS(2308),
    [anon_sym_new] = ACTIONS(2308),
    [anon_sym_requires] = ACTIONS(2308),
    [sym_this] = ACTIONS(2308),
    [anon_sym_precise] = ACTIONS(2308),
    [anon_sym_shared] = ACTIONS(2308),
    [anon_sym_groupshared] = ACTIONS(2308),
    [anon_sym_uniform] = ACTIONS(2308),
    [anon_sym_row_major] = ACTIONS(2308),
    [anon_sym_column_major] = ACTIONS(2308),
    [anon_sym_globallycoherent] = ACTIONS(2308),
    [anon_sym_centroid] = ACTIONS(2308),
    [anon_sym_noperspective] = ACTIONS(2308),
    [anon_sym_nointerpolation] = ACTIONS(2308),
    [anon_sym_sample] = ACTIONS(2308),
    [anon_sym_linear] = ACTIONS(2308),
    [anon_sym_snorm] = ACTIONS(2308),
    [anon_sym_unorm] = ACTIONS(2308),
    [anon_sym_point] = ACTIONS(2308),
    [anon_sym_line] = ACTIONS(2308),
    [anon_sym_triangleadj] = ACTIONS(2308),
    [anon_sym_lineadj] = ACTIONS(2308),
    [anon_sym_triangle] = ACTIONS(2308),
  },
  [1114] = {
    [sym_template_argument_list] = STATE(1130),
    [sym_identifier] = ACTIONS(1933),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4047),
    [anon_sym_COMMA] = ACTIONS(4047),
    [anon_sym_RPAREN] = ACTIONS(4047),
    [anon_sym_LPAREN2] = ACTIONS(4047),
    [anon_sym_TILDE] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(4050),
    [anon_sym_PLUS] = ACTIONS(4050),
    [anon_sym_STAR] = ACTIONS(4052),
    [anon_sym_SLASH] = ACTIONS(4050),
    [anon_sym_PERCENT] = ACTIONS(4050),
    [anon_sym_PIPE_PIPE] = ACTIONS(4045),
    [anon_sym_AMP_AMP] = ACTIONS(4047),
    [anon_sym_PIPE] = ACTIONS(4050),
    [anon_sym_CARET] = ACTIONS(4050),
    [anon_sym_AMP] = ACTIONS(4052),
    [anon_sym_EQ_EQ] = ACTIONS(4045),
    [anon_sym_BANG_EQ] = ACTIONS(4045),
    [anon_sym_GT] = ACTIONS(4050),
    [anon_sym_GT_EQ] = ACTIONS(4045),
    [anon_sym_LT_EQ] = ACTIONS(4050),
    [anon_sym_LT] = ACTIONS(4196),
    [anon_sym_LT_LT] = ACTIONS(4050),
    [anon_sym_GT_GT] = ACTIONS(4050),
    [anon_sym_COLON] = ACTIONS(1933),
    [anon_sym___extension__] = ACTIONS(1933),
    [anon_sym_in] = ACTIONS(1933),
    [anon_sym_out] = ACTIONS(1933),
    [anon_sym_inout] = ACTIONS(1933),
    [anon_sym_extern] = ACTIONS(1933),
    [anon_sym___attribute__] = ACTIONS(1933),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1935),
    [anon_sym___declspec] = ACTIONS(1933),
    [anon_sym___based] = ACTIONS(1933),
    [anon_sym_LBRACE] = ACTIONS(1935),
    [anon_sym_LBRACK] = ACTIONS(4052),
    [anon_sym_static] = ACTIONS(1933),
    [anon_sym_EQ] = ACTIONS(4052),
    [anon_sym_register] = ACTIONS(1933),
    [anon_sym_inline] = ACTIONS(1933),
    [anon_sym___inline] = ACTIONS(1933),
    [anon_sym___inline__] = ACTIONS(1933),
    [anon_sym___forceinline] = ACTIONS(1933),
    [anon_sym_thread_local] = ACTIONS(1933),
    [anon_sym___thread] = ACTIONS(1933),
    [anon_sym_const] = ACTIONS(1933),
    [anon_sym_constexpr] = ACTIONS(1933),
    [anon_sym_volatile] = ACTIONS(1933),
    [anon_sym_restrict] = ACTIONS(1933),
    [anon_sym___restrict__] = ACTIONS(1933),
    [anon_sym__Atomic] = ACTIONS(1933),
    [anon_sym__Noreturn] = ACTIONS(1933),
    [anon_sym_noreturn] = ACTIONS(1933),
    [anon_sym_mutable] = ACTIONS(1933),
    [anon_sym_constinit] = ACTIONS(1933),
    [anon_sym_consteval] = ACTIONS(1933),
    [anon_sym_alignas] = ACTIONS(1933),
    [anon_sym__Alignas] = ACTIONS(1933),
    [anon_sym_QMARK] = ACTIONS(4045),
    [anon_sym_STAR_EQ] = ACTIONS(4045),
    [anon_sym_SLASH_EQ] = ACTIONS(4045),
    [anon_sym_PERCENT_EQ] = ACTIONS(4045),
    [anon_sym_PLUS_EQ] = ACTIONS(4045),
    [anon_sym_DASH_EQ] = ACTIONS(4045),
    [anon_sym_LT_LT_EQ] = ACTIONS(4045),
    [anon_sym_GT_GT_EQ] = ACTIONS(4045),
    [anon_sym_AMP_EQ] = ACTIONS(4045),
    [anon_sym_CARET_EQ] = ACTIONS(4045),
    [anon_sym_PIPE_EQ] = ACTIONS(4045),
    [anon_sym_and_eq] = ACTIONS(4050),
    [anon_sym_or_eq] = ACTIONS(4050),
    [anon_sym_xor_eq] = ACTIONS(4050),
    [anon_sym_LT_EQ_GT] = ACTIONS(4045),
    [anon_sym_or] = ACTIONS(4050),
    [anon_sym_and] = ACTIONS(4050),
    [anon_sym_bitor] = ACTIONS(4050),
    [anon_sym_xor] = ACTIONS(4050),
    [anon_sym_bitand] = ACTIONS(4050),
    [anon_sym_not_eq] = ACTIONS(4050),
    [anon_sym_DASH_DASH] = ACTIONS(4045),
    [anon_sym_PLUS_PLUS] = ACTIONS(4045),
    [anon_sym_DOT] = ACTIONS(4050),
    [anon_sym_DOT_STAR] = ACTIONS(4045),
    [anon_sym_DASH_GT] = ACTIONS(4050),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1933),
    [anon_sym_decltype] = ACTIONS(1933),
    [sym_virtual] = ACTIONS(1933),
    [anon_sym_template] = ACTIONS(1933),
    [anon_sym_operator] = ACTIONS(1933),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4045),
    [anon_sym_precise] = ACTIONS(1933),
    [anon_sym_shared] = ACTIONS(1933),
    [anon_sym_groupshared] = ACTIONS(1933),
    [anon_sym_uniform] = ACTIONS(1933),
    [anon_sym_row_major] = ACTIONS(1933),
    [anon_sym_column_major] = ACTIONS(1933),
    [anon_sym_globallycoherent] = ACTIONS(1933),
    [anon_sym_centroid] = ACTIONS(1933),
    [anon_sym_noperspective] = ACTIONS(1933),
    [anon_sym_nointerpolation] = ACTIONS(1933),
    [anon_sym_sample] = ACTIONS(1933),
    [anon_sym_linear] = ACTIONS(1933),
    [anon_sym_snorm] = ACTIONS(1933),
    [anon_sym_unorm] = ACTIONS(1933),
    [anon_sym_point] = ACTIONS(1933),
    [anon_sym_line] = ACTIONS(1933),
    [anon_sym_triangleadj] = ACTIONS(1933),
    [anon_sym_lineadj] = ACTIONS(1933),
    [anon_sym_triangle] = ACTIONS(1933),
  },
  [1115] = {
    [sym_identifier] = ACTIONS(2712),
    [anon_sym_LPAREN2] = ACTIONS(2717),
    [anon_sym_BANG] = ACTIONS(2717),
    [anon_sym_TILDE] = ACTIONS(2717),
    [anon_sym_DASH] = ACTIONS(2712),
    [anon_sym_PLUS] = ACTIONS(2712),
    [anon_sym_STAR] = ACTIONS(2717),
    [anon_sym_AMP] = ACTIONS(2717),
    [anon_sym___extension__] = ACTIONS(2712),
    [anon_sym_in] = ACTIONS(2712),
    [anon_sym_out] = ACTIONS(2712),
    [anon_sym_inout] = ACTIONS(2712),
    [anon_sym_extern] = ACTIONS(2712),
    [anon_sym___attribute__] = ACTIONS(2712),
    [anon_sym_COLON_COLON] = ACTIONS(2717),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2717),
    [anon_sym___declspec] = ACTIONS(2712),
    [anon_sym_signed] = ACTIONS(2712),
    [anon_sym_unsigned] = ACTIONS(2712),
    [anon_sym_long] = ACTIONS(2712),
    [anon_sym_short] = ACTIONS(2712),
    [anon_sym_LBRACK] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(2712),
    [anon_sym_register] = ACTIONS(2712),
    [anon_sym_inline] = ACTIONS(2712),
    [anon_sym___inline] = ACTIONS(2712),
    [anon_sym___inline__] = ACTIONS(2712),
    [anon_sym___forceinline] = ACTIONS(2712),
    [anon_sym_thread_local] = ACTIONS(2712),
    [anon_sym___thread] = ACTIONS(2712),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_constexpr] = ACTIONS(2712),
    [anon_sym_volatile] = ACTIONS(2712),
    [anon_sym_restrict] = ACTIONS(2712),
    [anon_sym___restrict__] = ACTIONS(2712),
    [anon_sym__Atomic] = ACTIONS(2712),
    [anon_sym__Noreturn] = ACTIONS(2712),
    [anon_sym_noreturn] = ACTIONS(2712),
    [anon_sym_mutable] = ACTIONS(2712),
    [anon_sym_constinit] = ACTIONS(2712),
    [anon_sym_consteval] = ACTIONS(2712),
    [anon_sym_alignas] = ACTIONS(2712),
    [anon_sym__Alignas] = ACTIONS(2712),
    [sym_primitive_type] = ACTIONS(2712),
    [anon_sym_enum] = ACTIONS(2712),
    [anon_sym_class] = ACTIONS(2712),
    [anon_sym_struct] = ACTIONS(2712),
    [anon_sym_union] = ACTIONS(2712),
    [anon_sym_not] = ACTIONS(2712),
    [anon_sym_compl] = ACTIONS(2712),
    [anon_sym_DASH_DASH] = ACTIONS(2717),
    [anon_sym_PLUS_PLUS] = ACTIONS(2717),
    [anon_sym_sizeof] = ACTIONS(2712),
    [anon_sym___alignof__] = ACTIONS(2712),
    [anon_sym___alignof] = ACTIONS(2712),
    [anon_sym__alignof] = ACTIONS(2712),
    [anon_sym_alignof] = ACTIONS(2712),
    [anon_sym__Alignof] = ACTIONS(2712),
    [anon_sym_offsetof] = ACTIONS(2712),
    [anon_sym__Generic] = ACTIONS(2712),
    [anon_sym_asm] = ACTIONS(2712),
    [anon_sym___asm__] = ACTIONS(2712),
    [sym_number_literal] = ACTIONS(2717),
    [anon_sym_L_SQUOTE] = ACTIONS(2717),
    [anon_sym_u_SQUOTE] = ACTIONS(2717),
    [anon_sym_U_SQUOTE] = ACTIONS(2717),
    [anon_sym_u8_SQUOTE] = ACTIONS(2717),
    [anon_sym_SQUOTE] = ACTIONS(2717),
    [anon_sym_L_DQUOTE] = ACTIONS(2717),
    [anon_sym_u_DQUOTE] = ACTIONS(2717),
    [anon_sym_U_DQUOTE] = ACTIONS(2717),
    [anon_sym_u8_DQUOTE] = ACTIONS(2717),
    [anon_sym_DQUOTE] = ACTIONS(2717),
    [sym_true] = ACTIONS(2712),
    [sym_false] = ACTIONS(2712),
    [anon_sym_NULL] = ACTIONS(2712),
    [anon_sym_nullptr] = ACTIONS(2712),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2712),
    [anon_sym_decltype] = ACTIONS(2712),
    [sym_virtual] = ACTIONS(2712),
    [anon_sym_typename] = ACTIONS(2712),
    [anon_sym_template] = ACTIONS(2712),
    [anon_sym_delete] = ACTIONS(2712),
    [anon_sym_R_DQUOTE] = ACTIONS(2717),
    [anon_sym_LR_DQUOTE] = ACTIONS(2717),
    [anon_sym_uR_DQUOTE] = ACTIONS(2717),
    [anon_sym_UR_DQUOTE] = ACTIONS(2717),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2717),
    [anon_sym_co_await] = ACTIONS(2712),
    [anon_sym_new] = ACTIONS(2712),
    [anon_sym_requires] = ACTIONS(2712),
    [sym_this] = ACTIONS(2712),
    [anon_sym_precise] = ACTIONS(2712),
    [anon_sym_shared] = ACTIONS(2712),
    [anon_sym_groupshared] = ACTIONS(2712),
    [anon_sym_uniform] = ACTIONS(2712),
    [anon_sym_row_major] = ACTIONS(2712),
    [anon_sym_column_major] = ACTIONS(2712),
    [anon_sym_globallycoherent] = ACTIONS(2712),
    [anon_sym_centroid] = ACTIONS(2712),
    [anon_sym_noperspective] = ACTIONS(2712),
    [anon_sym_nointerpolation] = ACTIONS(2712),
    [anon_sym_sample] = ACTIONS(2712),
    [anon_sym_linear] = ACTIONS(2712),
    [anon_sym_snorm] = ACTIONS(2712),
    [anon_sym_unorm] = ACTIONS(2712),
    [anon_sym_point] = ACTIONS(2712),
    [anon_sym_line] = ACTIONS(2712),
    [anon_sym_triangleadj] = ACTIONS(2712),
    [anon_sym_lineadj] = ACTIONS(2712),
    [anon_sym_triangle] = ACTIONS(2712),
  },
  [1116] = {
    [sym_identifier] = ACTIONS(1891),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1893),
    [anon_sym_COMMA] = ACTIONS(1893),
    [anon_sym_RPAREN] = ACTIONS(1893),
    [anon_sym_LPAREN2] = ACTIONS(1893),
    [anon_sym_TILDE] = ACTIONS(1893),
    [anon_sym_DASH] = ACTIONS(1891),
    [anon_sym_PLUS] = ACTIONS(1891),
    [anon_sym_STAR] = ACTIONS(1893),
    [anon_sym_SLASH] = ACTIONS(1891),
    [anon_sym_PERCENT] = ACTIONS(1893),
    [anon_sym_PIPE_PIPE] = ACTIONS(1893),
    [anon_sym_AMP_AMP] = ACTIONS(1893),
    [anon_sym_PIPE] = ACTIONS(1891),
    [anon_sym_CARET] = ACTIONS(1893),
    [anon_sym_AMP] = ACTIONS(1891),
    [anon_sym_EQ_EQ] = ACTIONS(1893),
    [anon_sym_BANG_EQ] = ACTIONS(1893),
    [anon_sym_GT] = ACTIONS(1891),
    [anon_sym_GT_EQ] = ACTIONS(1893),
    [anon_sym_LT_EQ] = ACTIONS(1891),
    [anon_sym_LT] = ACTIONS(1891),
    [anon_sym_LT_LT] = ACTIONS(1893),
    [anon_sym_GT_GT] = ACTIONS(1893),
    [anon_sym_COLON] = ACTIONS(1891),
    [anon_sym_SEMI] = ACTIONS(1893),
    [anon_sym___extension__] = ACTIONS(1891),
    [anon_sym_in] = ACTIONS(1891),
    [anon_sym_out] = ACTIONS(1891),
    [anon_sym_inout] = ACTIONS(1891),
    [anon_sym_extern] = ACTIONS(1891),
    [anon_sym___attribute__] = ACTIONS(1891),
    [anon_sym_COLON_COLON] = ACTIONS(1893),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1893),
    [anon_sym___declspec] = ACTIONS(1891),
    [anon_sym___based] = ACTIONS(1891),
    [anon_sym___cdecl] = ACTIONS(1891),
    [anon_sym___clrcall] = ACTIONS(1891),
    [anon_sym___stdcall] = ACTIONS(1891),
    [anon_sym___fastcall] = ACTIONS(1891),
    [anon_sym___thiscall] = ACTIONS(1891),
    [anon_sym___vectorcall] = ACTIONS(1891),
    [anon_sym_LBRACE] = ACTIONS(1893),
    [anon_sym_RBRACE] = ACTIONS(1893),
    [anon_sym_LBRACK] = ACTIONS(1891),
    [anon_sym_static] = ACTIONS(1891),
    [anon_sym_EQ] = ACTIONS(1891),
    [anon_sym_register] = ACTIONS(1891),
    [anon_sym_inline] = ACTIONS(1891),
    [anon_sym___inline] = ACTIONS(1891),
    [anon_sym___inline__] = ACTIONS(1891),
    [anon_sym___forceinline] = ACTIONS(1891),
    [anon_sym_thread_local] = ACTIONS(1891),
    [anon_sym___thread] = ACTIONS(1891),
    [anon_sym_const] = ACTIONS(1891),
    [anon_sym_constexpr] = ACTIONS(1891),
    [anon_sym_volatile] = ACTIONS(1891),
    [anon_sym_restrict] = ACTIONS(1891),
    [anon_sym___restrict__] = ACTIONS(1891),
    [anon_sym__Atomic] = ACTIONS(1891),
    [anon_sym__Noreturn] = ACTIONS(1891),
    [anon_sym_noreturn] = ACTIONS(1891),
    [anon_sym_mutable] = ACTIONS(1891),
    [anon_sym_constinit] = ACTIONS(1891),
    [anon_sym_consteval] = ACTIONS(1891),
    [anon_sym_alignas] = ACTIONS(1891),
    [anon_sym__Alignas] = ACTIONS(1891),
    [anon_sym_else] = ACTIONS(1891),
    [anon_sym_while] = ACTIONS(1891),
    [anon_sym_QMARK] = ACTIONS(1893),
    [anon_sym_LT_EQ_GT] = ACTIONS(1893),
    [anon_sym_or] = ACTIONS(1891),
    [anon_sym_and] = ACTIONS(1891),
    [anon_sym_bitor] = ACTIONS(1891),
    [anon_sym_xor] = ACTIONS(1891),
    [anon_sym_bitand] = ACTIONS(1891),
    [anon_sym_not_eq] = ACTIONS(1891),
    [anon_sym_DASH_DASH] = ACTIONS(1893),
    [anon_sym_PLUS_PLUS] = ACTIONS(1893),
    [anon_sym_DOT] = ACTIONS(1891),
    [anon_sym_DOT_STAR] = ACTIONS(1893),
    [anon_sym_DASH_GT] = ACTIONS(1893),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1891),
    [anon_sym_decltype] = ACTIONS(1891),
    [anon_sym_final] = ACTIONS(1891),
    [anon_sym_override] = ACTIONS(1891),
    [sym_virtual] = ACTIONS(1891),
    [anon_sym_template] = ACTIONS(1891),
    [anon_sym_operator] = ACTIONS(1891),
    [anon_sym_try] = ACTIONS(1891),
    [anon_sym_requires] = ACTIONS(1891),
    [anon_sym_precise] = ACTIONS(1891),
    [anon_sym_shared] = ACTIONS(1891),
    [anon_sym_groupshared] = ACTIONS(1891),
    [anon_sym_uniform] = ACTIONS(1891),
    [anon_sym_row_major] = ACTIONS(1891),
    [anon_sym_column_major] = ACTIONS(1891),
    [anon_sym_globallycoherent] = ACTIONS(1891),
    [anon_sym_centroid] = ACTIONS(1891),
    [anon_sym_noperspective] = ACTIONS(1891),
    [anon_sym_nointerpolation] = ACTIONS(1891),
    [anon_sym_sample] = ACTIONS(1891),
    [anon_sym_linear] = ACTIONS(1891),
    [anon_sym_snorm] = ACTIONS(1891),
    [anon_sym_unorm] = ACTIONS(1891),
    [anon_sym_point] = ACTIONS(1891),
    [anon_sym_line] = ACTIONS(1891),
    [anon_sym_triangleadj] = ACTIONS(1891),
    [anon_sym_lineadj] = ACTIONS(1891),
    [anon_sym_triangle] = ACTIONS(1891),
  },
  [1117] = {
    [sym_identifier] = ACTIONS(1917),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1919),
    [anon_sym_COMMA] = ACTIONS(1919),
    [anon_sym_RPAREN] = ACTIONS(1919),
    [anon_sym_LPAREN2] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1919),
    [anon_sym_SLASH] = ACTIONS(1917),
    [anon_sym_PERCENT] = ACTIONS(1919),
    [anon_sym_PIPE_PIPE] = ACTIONS(1919),
    [anon_sym_AMP_AMP] = ACTIONS(1919),
    [anon_sym_PIPE] = ACTIONS(1917),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1917),
    [anon_sym_EQ_EQ] = ACTIONS(1919),
    [anon_sym_BANG_EQ] = ACTIONS(1919),
    [anon_sym_GT] = ACTIONS(1917),
    [anon_sym_GT_EQ] = ACTIONS(1919),
    [anon_sym_LT_EQ] = ACTIONS(1917),
    [anon_sym_LT] = ACTIONS(1917),
    [anon_sym_LT_LT] = ACTIONS(1919),
    [anon_sym_GT_GT] = ACTIONS(1919),
    [anon_sym_COLON] = ACTIONS(1917),
    [anon_sym_SEMI] = ACTIONS(1919),
    [anon_sym___extension__] = ACTIONS(1917),
    [anon_sym_in] = ACTIONS(1917),
    [anon_sym_out] = ACTIONS(1917),
    [anon_sym_inout] = ACTIONS(1917),
    [anon_sym_extern] = ACTIONS(1917),
    [anon_sym___attribute__] = ACTIONS(1917),
    [anon_sym_COLON_COLON] = ACTIONS(1919),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1919),
    [anon_sym___declspec] = ACTIONS(1917),
    [anon_sym___based] = ACTIONS(1917),
    [anon_sym___cdecl] = ACTIONS(1917),
    [anon_sym___clrcall] = ACTIONS(1917),
    [anon_sym___stdcall] = ACTIONS(1917),
    [anon_sym___fastcall] = ACTIONS(1917),
    [anon_sym___thiscall] = ACTIONS(1917),
    [anon_sym___vectorcall] = ACTIONS(1917),
    [anon_sym_LBRACE] = ACTIONS(1919),
    [anon_sym_RBRACE] = ACTIONS(1919),
    [anon_sym_LBRACK] = ACTIONS(1917),
    [anon_sym_static] = ACTIONS(1917),
    [anon_sym_EQ] = ACTIONS(1917),
    [anon_sym_register] = ACTIONS(1917),
    [anon_sym_inline] = ACTIONS(1917),
    [anon_sym___inline] = ACTIONS(1917),
    [anon_sym___inline__] = ACTIONS(1917),
    [anon_sym___forceinline] = ACTIONS(1917),
    [anon_sym_thread_local] = ACTIONS(1917),
    [anon_sym___thread] = ACTIONS(1917),
    [anon_sym_const] = ACTIONS(1917),
    [anon_sym_constexpr] = ACTIONS(1917),
    [anon_sym_volatile] = ACTIONS(1917),
    [anon_sym_restrict] = ACTIONS(1917),
    [anon_sym___restrict__] = ACTIONS(1917),
    [anon_sym__Atomic] = ACTIONS(1917),
    [anon_sym__Noreturn] = ACTIONS(1917),
    [anon_sym_noreturn] = ACTIONS(1917),
    [anon_sym_mutable] = ACTIONS(1917),
    [anon_sym_constinit] = ACTIONS(1917),
    [anon_sym_consteval] = ACTIONS(1917),
    [anon_sym_alignas] = ACTIONS(1917),
    [anon_sym__Alignas] = ACTIONS(1917),
    [anon_sym_else] = ACTIONS(1917),
    [anon_sym_while] = ACTIONS(1917),
    [anon_sym_QMARK] = ACTIONS(1919),
    [anon_sym_LT_EQ_GT] = ACTIONS(1919),
    [anon_sym_or] = ACTIONS(1917),
    [anon_sym_and] = ACTIONS(1917),
    [anon_sym_bitor] = ACTIONS(1917),
    [anon_sym_xor] = ACTIONS(1917),
    [anon_sym_bitand] = ACTIONS(1917),
    [anon_sym_not_eq] = ACTIONS(1917),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DOT] = ACTIONS(1917),
    [anon_sym_DOT_STAR] = ACTIONS(1919),
    [anon_sym_DASH_GT] = ACTIONS(1919),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1917),
    [anon_sym_decltype] = ACTIONS(1917),
    [anon_sym_final] = ACTIONS(1917),
    [anon_sym_override] = ACTIONS(1917),
    [sym_virtual] = ACTIONS(1917),
    [anon_sym_template] = ACTIONS(1917),
    [anon_sym_operator] = ACTIONS(1917),
    [anon_sym_try] = ACTIONS(1917),
    [anon_sym_requires] = ACTIONS(1917),
    [anon_sym_precise] = ACTIONS(1917),
    [anon_sym_shared] = ACTIONS(1917),
    [anon_sym_groupshared] = ACTIONS(1917),
    [anon_sym_uniform] = ACTIONS(1917),
    [anon_sym_row_major] = ACTIONS(1917),
    [anon_sym_column_major] = ACTIONS(1917),
    [anon_sym_globallycoherent] = ACTIONS(1917),
    [anon_sym_centroid] = ACTIONS(1917),
    [anon_sym_noperspective] = ACTIONS(1917),
    [anon_sym_nointerpolation] = ACTIONS(1917),
    [anon_sym_sample] = ACTIONS(1917),
    [anon_sym_linear] = ACTIONS(1917),
    [anon_sym_snorm] = ACTIONS(1917),
    [anon_sym_unorm] = ACTIONS(1917),
    [anon_sym_point] = ACTIONS(1917),
    [anon_sym_line] = ACTIONS(1917),
    [anon_sym_triangleadj] = ACTIONS(1917),
    [anon_sym_lineadj] = ACTIONS(1917),
    [anon_sym_triangle] = ACTIONS(1917),
  },
  [1118] = {
    [sym_identifier] = ACTIONS(1895),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1897),
    [anon_sym_COMMA] = ACTIONS(1897),
    [anon_sym_RPAREN] = ACTIONS(1897),
    [anon_sym_LPAREN2] = ACTIONS(1897),
    [anon_sym_TILDE] = ACTIONS(1897),
    [anon_sym_DASH] = ACTIONS(1895),
    [anon_sym_PLUS] = ACTIONS(1895),
    [anon_sym_STAR] = ACTIONS(1897),
    [anon_sym_SLASH] = ACTIONS(1895),
    [anon_sym_PERCENT] = ACTIONS(1897),
    [anon_sym_PIPE_PIPE] = ACTIONS(1897),
    [anon_sym_AMP_AMP] = ACTIONS(1897),
    [anon_sym_PIPE] = ACTIONS(1895),
    [anon_sym_CARET] = ACTIONS(1897),
    [anon_sym_AMP] = ACTIONS(1895),
    [anon_sym_EQ_EQ] = ACTIONS(1897),
    [anon_sym_BANG_EQ] = ACTIONS(1897),
    [anon_sym_GT] = ACTIONS(1895),
    [anon_sym_GT_EQ] = ACTIONS(1897),
    [anon_sym_LT_EQ] = ACTIONS(1895),
    [anon_sym_LT] = ACTIONS(1895),
    [anon_sym_LT_LT] = ACTIONS(1897),
    [anon_sym_GT_GT] = ACTIONS(1897),
    [anon_sym_COLON] = ACTIONS(1895),
    [anon_sym_SEMI] = ACTIONS(1897),
    [anon_sym___extension__] = ACTIONS(1895),
    [anon_sym_in] = ACTIONS(1895),
    [anon_sym_out] = ACTIONS(1895),
    [anon_sym_inout] = ACTIONS(1895),
    [anon_sym_extern] = ACTIONS(1895),
    [anon_sym___attribute__] = ACTIONS(1895),
    [anon_sym_COLON_COLON] = ACTIONS(1897),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1897),
    [anon_sym___declspec] = ACTIONS(1895),
    [anon_sym___based] = ACTIONS(1895),
    [anon_sym___cdecl] = ACTIONS(1895),
    [anon_sym___clrcall] = ACTIONS(1895),
    [anon_sym___stdcall] = ACTIONS(1895),
    [anon_sym___fastcall] = ACTIONS(1895),
    [anon_sym___thiscall] = ACTIONS(1895),
    [anon_sym___vectorcall] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1897),
    [anon_sym_RBRACE] = ACTIONS(1897),
    [anon_sym_LBRACK] = ACTIONS(1895),
    [anon_sym_static] = ACTIONS(1895),
    [anon_sym_EQ] = ACTIONS(1895),
    [anon_sym_register] = ACTIONS(1895),
    [anon_sym_inline] = ACTIONS(1895),
    [anon_sym___inline] = ACTIONS(1895),
    [anon_sym___inline__] = ACTIONS(1895),
    [anon_sym___forceinline] = ACTIONS(1895),
    [anon_sym_thread_local] = ACTIONS(1895),
    [anon_sym___thread] = ACTIONS(1895),
    [anon_sym_const] = ACTIONS(1895),
    [anon_sym_constexpr] = ACTIONS(1895),
    [anon_sym_volatile] = ACTIONS(1895),
    [anon_sym_restrict] = ACTIONS(1895),
    [anon_sym___restrict__] = ACTIONS(1895),
    [anon_sym__Atomic] = ACTIONS(1895),
    [anon_sym__Noreturn] = ACTIONS(1895),
    [anon_sym_noreturn] = ACTIONS(1895),
    [anon_sym_mutable] = ACTIONS(1895),
    [anon_sym_constinit] = ACTIONS(1895),
    [anon_sym_consteval] = ACTIONS(1895),
    [anon_sym_alignas] = ACTIONS(1895),
    [anon_sym__Alignas] = ACTIONS(1895),
    [anon_sym_else] = ACTIONS(1895),
    [anon_sym_while] = ACTIONS(1895),
    [anon_sym_QMARK] = ACTIONS(1897),
    [anon_sym_LT_EQ_GT] = ACTIONS(1897),
    [anon_sym_or] = ACTIONS(1895),
    [anon_sym_and] = ACTIONS(1895),
    [anon_sym_bitor] = ACTIONS(1895),
    [anon_sym_xor] = ACTIONS(1895),
    [anon_sym_bitand] = ACTIONS(1895),
    [anon_sym_not_eq] = ACTIONS(1895),
    [anon_sym_DASH_DASH] = ACTIONS(1897),
    [anon_sym_PLUS_PLUS] = ACTIONS(1897),
    [anon_sym_DOT] = ACTIONS(1895),
    [anon_sym_DOT_STAR] = ACTIONS(1897),
    [anon_sym_DASH_GT] = ACTIONS(1897),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1895),
    [anon_sym_decltype] = ACTIONS(1895),
    [anon_sym_final] = ACTIONS(1895),
    [anon_sym_override] = ACTIONS(1895),
    [sym_virtual] = ACTIONS(1895),
    [anon_sym_template] = ACTIONS(1895),
    [anon_sym_operator] = ACTIONS(1895),
    [anon_sym_try] = ACTIONS(1895),
    [anon_sym_requires] = ACTIONS(1895),
    [anon_sym_precise] = ACTIONS(1895),
    [anon_sym_shared] = ACTIONS(1895),
    [anon_sym_groupshared] = ACTIONS(1895),
    [anon_sym_uniform] = ACTIONS(1895),
    [anon_sym_row_major] = ACTIONS(1895),
    [anon_sym_column_major] = ACTIONS(1895),
    [anon_sym_globallycoherent] = ACTIONS(1895),
    [anon_sym_centroid] = ACTIONS(1895),
    [anon_sym_noperspective] = ACTIONS(1895),
    [anon_sym_nointerpolation] = ACTIONS(1895),
    [anon_sym_sample] = ACTIONS(1895),
    [anon_sym_linear] = ACTIONS(1895),
    [anon_sym_snorm] = ACTIONS(1895),
    [anon_sym_unorm] = ACTIONS(1895),
    [anon_sym_point] = ACTIONS(1895),
    [anon_sym_line] = ACTIONS(1895),
    [anon_sym_triangleadj] = ACTIONS(1895),
    [anon_sym_lineadj] = ACTIONS(1895),
    [anon_sym_triangle] = ACTIONS(1895),
  },
  [1119] = {
    [sym_identifier] = ACTIONS(1891),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1893),
    [anon_sym_COMMA] = ACTIONS(1893),
    [anon_sym_RPAREN] = ACTIONS(1893),
    [anon_sym_LPAREN2] = ACTIONS(1893),
    [anon_sym_TILDE] = ACTIONS(1893),
    [anon_sym_DASH] = ACTIONS(1891),
    [anon_sym_PLUS] = ACTIONS(1891),
    [anon_sym_STAR] = ACTIONS(1891),
    [anon_sym_SLASH] = ACTIONS(1891),
    [anon_sym_PERCENT] = ACTIONS(1891),
    [anon_sym_PIPE_PIPE] = ACTIONS(1893),
    [anon_sym_AMP_AMP] = ACTIONS(1893),
    [anon_sym_PIPE] = ACTIONS(1891),
    [anon_sym_CARET] = ACTIONS(1891),
    [anon_sym_AMP] = ACTIONS(1891),
    [anon_sym_EQ_EQ] = ACTIONS(1893),
    [anon_sym_BANG_EQ] = ACTIONS(1893),
    [anon_sym_GT] = ACTIONS(1891),
    [anon_sym_GT_EQ] = ACTIONS(1893),
    [anon_sym_LT_EQ] = ACTIONS(1891),
    [anon_sym_LT] = ACTIONS(1891),
    [anon_sym_LT_LT] = ACTIONS(1891),
    [anon_sym_GT_GT] = ACTIONS(1891),
    [anon_sym_COLON] = ACTIONS(1891),
    [anon_sym___extension__] = ACTIONS(1891),
    [anon_sym_in] = ACTIONS(1891),
    [anon_sym_out] = ACTIONS(1891),
    [anon_sym_inout] = ACTIONS(1891),
    [anon_sym_extern] = ACTIONS(1891),
    [anon_sym___attribute__] = ACTIONS(1891),
    [anon_sym_COLON_COLON] = ACTIONS(1893),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1893),
    [anon_sym___declspec] = ACTIONS(1891),
    [anon_sym___based] = ACTIONS(1891),
    [anon_sym_LBRACE] = ACTIONS(1893),
    [anon_sym_LBRACK] = ACTIONS(1891),
    [anon_sym_static] = ACTIONS(1891),
    [anon_sym_EQ] = ACTIONS(1891),
    [anon_sym_register] = ACTIONS(1891),
    [anon_sym_inline] = ACTIONS(1891),
    [anon_sym___inline] = ACTIONS(1891),
    [anon_sym___inline__] = ACTIONS(1891),
    [anon_sym___forceinline] = ACTIONS(1891),
    [anon_sym_thread_local] = ACTIONS(1891),
    [anon_sym___thread] = ACTIONS(1891),
    [anon_sym_const] = ACTIONS(1891),
    [anon_sym_constexpr] = ACTIONS(1891),
    [anon_sym_volatile] = ACTIONS(1891),
    [anon_sym_restrict] = ACTIONS(1891),
    [anon_sym___restrict__] = ACTIONS(1891),
    [anon_sym__Atomic] = ACTIONS(1891),
    [anon_sym__Noreturn] = ACTIONS(1891),
    [anon_sym_noreturn] = ACTIONS(1891),
    [anon_sym_mutable] = ACTIONS(1891),
    [anon_sym_constinit] = ACTIONS(1891),
    [anon_sym_consteval] = ACTIONS(1891),
    [anon_sym_alignas] = ACTIONS(1891),
    [anon_sym__Alignas] = ACTIONS(1891),
    [anon_sym_QMARK] = ACTIONS(1893),
    [anon_sym_STAR_EQ] = ACTIONS(1893),
    [anon_sym_SLASH_EQ] = ACTIONS(1893),
    [anon_sym_PERCENT_EQ] = ACTIONS(1893),
    [anon_sym_PLUS_EQ] = ACTIONS(1893),
    [anon_sym_DASH_EQ] = ACTIONS(1893),
    [anon_sym_LT_LT_EQ] = ACTIONS(1893),
    [anon_sym_GT_GT_EQ] = ACTIONS(1893),
    [anon_sym_AMP_EQ] = ACTIONS(1893),
    [anon_sym_CARET_EQ] = ACTIONS(1893),
    [anon_sym_PIPE_EQ] = ACTIONS(1893),
    [anon_sym_and_eq] = ACTIONS(1891),
    [anon_sym_or_eq] = ACTIONS(1891),
    [anon_sym_xor_eq] = ACTIONS(1891),
    [anon_sym_LT_EQ_GT] = ACTIONS(1893),
    [anon_sym_or] = ACTIONS(1891),
    [anon_sym_and] = ACTIONS(1891),
    [anon_sym_bitor] = ACTIONS(1891),
    [anon_sym_xor] = ACTIONS(1891),
    [anon_sym_bitand] = ACTIONS(1891),
    [anon_sym_not_eq] = ACTIONS(1891),
    [anon_sym_DASH_DASH] = ACTIONS(1893),
    [anon_sym_PLUS_PLUS] = ACTIONS(1893),
    [anon_sym_DOT] = ACTIONS(1891),
    [anon_sym_DOT_STAR] = ACTIONS(1893),
    [anon_sym_DASH_GT] = ACTIONS(1891),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1891),
    [anon_sym_decltype] = ACTIONS(1891),
    [sym_virtual] = ACTIONS(1891),
    [anon_sym_template] = ACTIONS(1891),
    [anon_sym_operator] = ACTIONS(1891),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1893),
    [anon_sym_precise] = ACTIONS(1891),
    [anon_sym_shared] = ACTIONS(1891),
    [anon_sym_groupshared] = ACTIONS(1891),
    [anon_sym_uniform] = ACTIONS(1891),
    [anon_sym_row_major] = ACTIONS(1891),
    [anon_sym_column_major] = ACTIONS(1891),
    [anon_sym_globallycoherent] = ACTIONS(1891),
    [anon_sym_centroid] = ACTIONS(1891),
    [anon_sym_noperspective] = ACTIONS(1891),
    [anon_sym_nointerpolation] = ACTIONS(1891),
    [anon_sym_sample] = ACTIONS(1891),
    [anon_sym_linear] = ACTIONS(1891),
    [anon_sym_snorm] = ACTIONS(1891),
    [anon_sym_unorm] = ACTIONS(1891),
    [anon_sym_point] = ACTIONS(1891),
    [anon_sym_line] = ACTIONS(1891),
    [anon_sym_triangleadj] = ACTIONS(1891),
    [anon_sym_lineadj] = ACTIONS(1891),
    [anon_sym_triangle] = ACTIONS(1891),
  },
  [1120] = {
    [sym_template_argument_list] = STATE(1134),
    [sym_identifier] = ACTIONS(1933),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4045),
    [anon_sym_COMMA] = ACTIONS(4045),
    [anon_sym_RPAREN] = ACTIONS(4045),
    [anon_sym_LPAREN2] = ACTIONS(4047),
    [anon_sym_TILDE] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(4050),
    [anon_sym_PLUS] = ACTIONS(4050),
    [anon_sym_STAR] = ACTIONS(4052),
    [anon_sym_SLASH] = ACTIONS(4050),
    [anon_sym_PERCENT] = ACTIONS(4050),
    [anon_sym_PIPE_PIPE] = ACTIONS(4045),
    [anon_sym_AMP_AMP] = ACTIONS(4047),
    [anon_sym_PIPE] = ACTIONS(4050),
    [anon_sym_CARET] = ACTIONS(4050),
    [anon_sym_AMP] = ACTIONS(4052),
    [anon_sym_EQ_EQ] = ACTIONS(4045),
    [anon_sym_BANG_EQ] = ACTIONS(4045),
    [anon_sym_GT] = ACTIONS(4050),
    [anon_sym_GT_EQ] = ACTIONS(4045),
    [anon_sym_LT_EQ] = ACTIONS(4050),
    [anon_sym_LT] = ACTIONS(4055),
    [anon_sym_LT_LT] = ACTIONS(4050),
    [anon_sym_GT_GT] = ACTIONS(4050),
    [anon_sym_SEMI] = ACTIONS(4045),
    [anon_sym___extension__] = ACTIONS(1933),
    [anon_sym_in] = ACTIONS(1933),
    [anon_sym_out] = ACTIONS(1933),
    [anon_sym_inout] = ACTIONS(1933),
    [anon_sym_extern] = ACTIONS(1933),
    [anon_sym___attribute__] = ACTIONS(1933),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1935),
    [anon_sym___declspec] = ACTIONS(1933),
    [anon_sym___based] = ACTIONS(1933),
    [anon_sym_LBRACE] = ACTIONS(1935),
    [anon_sym_LBRACK] = ACTIONS(4052),
    [anon_sym_static] = ACTIONS(1933),
    [anon_sym_EQ] = ACTIONS(4050),
    [anon_sym_register] = ACTIONS(1933),
    [anon_sym_inline] = ACTIONS(1933),
    [anon_sym___inline] = ACTIONS(1933),
    [anon_sym___inline__] = ACTIONS(1933),
    [anon_sym___forceinline] = ACTIONS(1933),
    [anon_sym_thread_local] = ACTIONS(1933),
    [anon_sym___thread] = ACTIONS(1933),
    [anon_sym_const] = ACTIONS(1933),
    [anon_sym_constexpr] = ACTIONS(1933),
    [anon_sym_volatile] = ACTIONS(1933),
    [anon_sym_restrict] = ACTIONS(1933),
    [anon_sym___restrict__] = ACTIONS(1933),
    [anon_sym__Atomic] = ACTIONS(1933),
    [anon_sym__Noreturn] = ACTIONS(1933),
    [anon_sym_noreturn] = ACTIONS(1933),
    [anon_sym_mutable] = ACTIONS(1933),
    [anon_sym_constinit] = ACTIONS(1933),
    [anon_sym_consteval] = ACTIONS(1933),
    [anon_sym_alignas] = ACTIONS(1933),
    [anon_sym__Alignas] = ACTIONS(1933),
    [anon_sym_QMARK] = ACTIONS(4045),
    [anon_sym_STAR_EQ] = ACTIONS(4045),
    [anon_sym_SLASH_EQ] = ACTIONS(4045),
    [anon_sym_PERCENT_EQ] = ACTIONS(4045),
    [anon_sym_PLUS_EQ] = ACTIONS(4045),
    [anon_sym_DASH_EQ] = ACTIONS(4045),
    [anon_sym_LT_LT_EQ] = ACTIONS(4045),
    [anon_sym_GT_GT_EQ] = ACTIONS(4045),
    [anon_sym_AMP_EQ] = ACTIONS(4045),
    [anon_sym_CARET_EQ] = ACTIONS(4045),
    [anon_sym_PIPE_EQ] = ACTIONS(4045),
    [anon_sym_and_eq] = ACTIONS(4050),
    [anon_sym_or_eq] = ACTIONS(4050),
    [anon_sym_xor_eq] = ACTIONS(4050),
    [anon_sym_LT_EQ_GT] = ACTIONS(4045),
    [anon_sym_or] = ACTIONS(4050),
    [anon_sym_and] = ACTIONS(4050),
    [anon_sym_bitor] = ACTIONS(4050),
    [anon_sym_xor] = ACTIONS(4050),
    [anon_sym_bitand] = ACTIONS(4050),
    [anon_sym_not_eq] = ACTIONS(4050),
    [anon_sym_DASH_DASH] = ACTIONS(4045),
    [anon_sym_PLUS_PLUS] = ACTIONS(4045),
    [anon_sym_DOT] = ACTIONS(4050),
    [anon_sym_DOT_STAR] = ACTIONS(4045),
    [anon_sym_DASH_GT] = ACTIONS(4045),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1933),
    [anon_sym_decltype] = ACTIONS(1933),
    [sym_virtual] = ACTIONS(1933),
    [anon_sym_template] = ACTIONS(1933),
    [anon_sym_operator] = ACTIONS(1933),
    [anon_sym_precise] = ACTIONS(1933),
    [anon_sym_shared] = ACTIONS(1933),
    [anon_sym_groupshared] = ACTIONS(1933),
    [anon_sym_uniform] = ACTIONS(1933),
    [anon_sym_row_major] = ACTIONS(1933),
    [anon_sym_column_major] = ACTIONS(1933),
    [anon_sym_globallycoherent] = ACTIONS(1933),
    [anon_sym_centroid] = ACTIONS(1933),
    [anon_sym_noperspective] = ACTIONS(1933),
    [anon_sym_nointerpolation] = ACTIONS(1933),
    [anon_sym_sample] = ACTIONS(1933),
    [anon_sym_linear] = ACTIONS(1933),
    [anon_sym_snorm] = ACTIONS(1933),
    [anon_sym_unorm] = ACTIONS(1933),
    [anon_sym_point] = ACTIONS(1933),
    [anon_sym_line] = ACTIONS(1933),
    [anon_sym_triangleadj] = ACTIONS(1933),
    [anon_sym_lineadj] = ACTIONS(1933),
    [anon_sym_triangle] = ACTIONS(1933),
  },
  [1121] = {
    [sym_identifier] = ACTIONS(1895),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1897),
    [anon_sym_COMMA] = ACTIONS(1897),
    [anon_sym_RPAREN] = ACTIONS(1897),
    [anon_sym_LPAREN2] = ACTIONS(1897),
    [anon_sym_TILDE] = ACTIONS(1897),
    [anon_sym_DASH] = ACTIONS(1895),
    [anon_sym_PLUS] = ACTIONS(1895),
    [anon_sym_STAR] = ACTIONS(1895),
    [anon_sym_SLASH] = ACTIONS(1895),
    [anon_sym_PERCENT] = ACTIONS(1895),
    [anon_sym_PIPE_PIPE] = ACTIONS(1897),
    [anon_sym_AMP_AMP] = ACTIONS(1897),
    [anon_sym_PIPE] = ACTIONS(1895),
    [anon_sym_CARET] = ACTIONS(1895),
    [anon_sym_AMP] = ACTIONS(1895),
    [anon_sym_EQ_EQ] = ACTIONS(1897),
    [anon_sym_BANG_EQ] = ACTIONS(1897),
    [anon_sym_GT] = ACTIONS(1895),
    [anon_sym_GT_EQ] = ACTIONS(1897),
    [anon_sym_LT_EQ] = ACTIONS(1895),
    [anon_sym_LT] = ACTIONS(1895),
    [anon_sym_LT_LT] = ACTIONS(1895),
    [anon_sym_GT_GT] = ACTIONS(1895),
    [anon_sym_COLON] = ACTIONS(1895),
    [anon_sym___extension__] = ACTIONS(1895),
    [anon_sym_in] = ACTIONS(1895),
    [anon_sym_out] = ACTIONS(1895),
    [anon_sym_inout] = ACTIONS(1895),
    [anon_sym_extern] = ACTIONS(1895),
    [anon_sym___attribute__] = ACTIONS(1895),
    [anon_sym_COLON_COLON] = ACTIONS(1897),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1897),
    [anon_sym___declspec] = ACTIONS(1895),
    [anon_sym___based] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1897),
    [anon_sym_LBRACK] = ACTIONS(1895),
    [anon_sym_static] = ACTIONS(1895),
    [anon_sym_EQ] = ACTIONS(1895),
    [anon_sym_register] = ACTIONS(1895),
    [anon_sym_inline] = ACTIONS(1895),
    [anon_sym___inline] = ACTIONS(1895),
    [anon_sym___inline__] = ACTIONS(1895),
    [anon_sym___forceinline] = ACTIONS(1895),
    [anon_sym_thread_local] = ACTIONS(1895),
    [anon_sym___thread] = ACTIONS(1895),
    [anon_sym_const] = ACTIONS(1895),
    [anon_sym_constexpr] = ACTIONS(1895),
    [anon_sym_volatile] = ACTIONS(1895),
    [anon_sym_restrict] = ACTIONS(1895),
    [anon_sym___restrict__] = ACTIONS(1895),
    [anon_sym__Atomic] = ACTIONS(1895),
    [anon_sym__Noreturn] = ACTIONS(1895),
    [anon_sym_noreturn] = ACTIONS(1895),
    [anon_sym_mutable] = ACTIONS(1895),
    [anon_sym_constinit] = ACTIONS(1895),
    [anon_sym_consteval] = ACTIONS(1895),
    [anon_sym_alignas] = ACTIONS(1895),
    [anon_sym__Alignas] = ACTIONS(1895),
    [anon_sym_QMARK] = ACTIONS(1897),
    [anon_sym_STAR_EQ] = ACTIONS(1897),
    [anon_sym_SLASH_EQ] = ACTIONS(1897),
    [anon_sym_PERCENT_EQ] = ACTIONS(1897),
    [anon_sym_PLUS_EQ] = ACTIONS(1897),
    [anon_sym_DASH_EQ] = ACTIONS(1897),
    [anon_sym_LT_LT_EQ] = ACTIONS(1897),
    [anon_sym_GT_GT_EQ] = ACTIONS(1897),
    [anon_sym_AMP_EQ] = ACTIONS(1897),
    [anon_sym_CARET_EQ] = ACTIONS(1897),
    [anon_sym_PIPE_EQ] = ACTIONS(1897),
    [anon_sym_and_eq] = ACTIONS(1895),
    [anon_sym_or_eq] = ACTIONS(1895),
    [anon_sym_xor_eq] = ACTIONS(1895),
    [anon_sym_LT_EQ_GT] = ACTIONS(1897),
    [anon_sym_or] = ACTIONS(1895),
    [anon_sym_and] = ACTIONS(1895),
    [anon_sym_bitor] = ACTIONS(1895),
    [anon_sym_xor] = ACTIONS(1895),
    [anon_sym_bitand] = ACTIONS(1895),
    [anon_sym_not_eq] = ACTIONS(1895),
    [anon_sym_DASH_DASH] = ACTIONS(1897),
    [anon_sym_PLUS_PLUS] = ACTIONS(1897),
    [anon_sym_DOT] = ACTIONS(1895),
    [anon_sym_DOT_STAR] = ACTIONS(1897),
    [anon_sym_DASH_GT] = ACTIONS(1895),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1895),
    [anon_sym_decltype] = ACTIONS(1895),
    [sym_virtual] = ACTIONS(1895),
    [anon_sym_template] = ACTIONS(1895),
    [anon_sym_operator] = ACTIONS(1895),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1897),
    [anon_sym_precise] = ACTIONS(1895),
    [anon_sym_shared] = ACTIONS(1895),
    [anon_sym_groupshared] = ACTIONS(1895),
    [anon_sym_uniform] = ACTIONS(1895),
    [anon_sym_row_major] = ACTIONS(1895),
    [anon_sym_column_major] = ACTIONS(1895),
    [anon_sym_globallycoherent] = ACTIONS(1895),
    [anon_sym_centroid] = ACTIONS(1895),
    [anon_sym_noperspective] = ACTIONS(1895),
    [anon_sym_nointerpolation] = ACTIONS(1895),
    [anon_sym_sample] = ACTIONS(1895),
    [anon_sym_linear] = ACTIONS(1895),
    [anon_sym_snorm] = ACTIONS(1895),
    [anon_sym_unorm] = ACTIONS(1895),
    [anon_sym_point] = ACTIONS(1895),
    [anon_sym_line] = ACTIONS(1895),
    [anon_sym_triangleadj] = ACTIONS(1895),
    [anon_sym_lineadj] = ACTIONS(1895),
    [anon_sym_triangle] = ACTIONS(1895),
  },
  [1122] = {
    [sym_identifier] = ACTIONS(1925),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1927),
    [anon_sym_COMMA] = ACTIONS(1927),
    [anon_sym_RPAREN] = ACTIONS(1927),
    [anon_sym_LPAREN2] = ACTIONS(1927),
    [anon_sym_TILDE] = ACTIONS(1927),
    [anon_sym_DASH] = ACTIONS(1925),
    [anon_sym_PLUS] = ACTIONS(1925),
    [anon_sym_STAR] = ACTIONS(1925),
    [anon_sym_SLASH] = ACTIONS(1925),
    [anon_sym_PERCENT] = ACTIONS(1925),
    [anon_sym_PIPE_PIPE] = ACTIONS(1927),
    [anon_sym_AMP_AMP] = ACTIONS(1927),
    [anon_sym_PIPE] = ACTIONS(1925),
    [anon_sym_CARET] = ACTIONS(1925),
    [anon_sym_AMP] = ACTIONS(1925),
    [anon_sym_EQ_EQ] = ACTIONS(1927),
    [anon_sym_BANG_EQ] = ACTIONS(1927),
    [anon_sym_GT] = ACTIONS(1925),
    [anon_sym_GT_EQ] = ACTIONS(1927),
    [anon_sym_LT_EQ] = ACTIONS(1925),
    [anon_sym_LT] = ACTIONS(1925),
    [anon_sym_LT_LT] = ACTIONS(1925),
    [anon_sym_GT_GT] = ACTIONS(1925),
    [anon_sym_COLON] = ACTIONS(1925),
    [anon_sym___extension__] = ACTIONS(1925),
    [anon_sym_in] = ACTIONS(1925),
    [anon_sym_out] = ACTIONS(1925),
    [anon_sym_inout] = ACTIONS(1925),
    [anon_sym_extern] = ACTIONS(1925),
    [anon_sym___attribute__] = ACTIONS(1925),
    [anon_sym_COLON_COLON] = ACTIONS(1927),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1927),
    [anon_sym___declspec] = ACTIONS(1925),
    [anon_sym___based] = ACTIONS(1925),
    [anon_sym_LBRACE] = ACTIONS(1927),
    [anon_sym_LBRACK] = ACTIONS(1925),
    [anon_sym_static] = ACTIONS(1925),
    [anon_sym_EQ] = ACTIONS(1925),
    [anon_sym_register] = ACTIONS(1925),
    [anon_sym_inline] = ACTIONS(1925),
    [anon_sym___inline] = ACTIONS(1925),
    [anon_sym___inline__] = ACTIONS(1925),
    [anon_sym___forceinline] = ACTIONS(1925),
    [anon_sym_thread_local] = ACTIONS(1925),
    [anon_sym___thread] = ACTIONS(1925),
    [anon_sym_const] = ACTIONS(1925),
    [anon_sym_constexpr] = ACTIONS(1925),
    [anon_sym_volatile] = ACTIONS(1925),
    [anon_sym_restrict] = ACTIONS(1925),
    [anon_sym___restrict__] = ACTIONS(1925),
    [anon_sym__Atomic] = ACTIONS(1925),
    [anon_sym__Noreturn] = ACTIONS(1925),
    [anon_sym_noreturn] = ACTIONS(1925),
    [anon_sym_mutable] = ACTIONS(1925),
    [anon_sym_constinit] = ACTIONS(1925),
    [anon_sym_consteval] = ACTIONS(1925),
    [anon_sym_alignas] = ACTIONS(1925),
    [anon_sym__Alignas] = ACTIONS(1925),
    [anon_sym_QMARK] = ACTIONS(1927),
    [anon_sym_STAR_EQ] = ACTIONS(1927),
    [anon_sym_SLASH_EQ] = ACTIONS(1927),
    [anon_sym_PERCENT_EQ] = ACTIONS(1927),
    [anon_sym_PLUS_EQ] = ACTIONS(1927),
    [anon_sym_DASH_EQ] = ACTIONS(1927),
    [anon_sym_LT_LT_EQ] = ACTIONS(1927),
    [anon_sym_GT_GT_EQ] = ACTIONS(1927),
    [anon_sym_AMP_EQ] = ACTIONS(1927),
    [anon_sym_CARET_EQ] = ACTIONS(1927),
    [anon_sym_PIPE_EQ] = ACTIONS(1927),
    [anon_sym_and_eq] = ACTIONS(1925),
    [anon_sym_or_eq] = ACTIONS(1925),
    [anon_sym_xor_eq] = ACTIONS(1925),
    [anon_sym_LT_EQ_GT] = ACTIONS(1927),
    [anon_sym_or] = ACTIONS(1925),
    [anon_sym_and] = ACTIONS(1925),
    [anon_sym_bitor] = ACTIONS(1925),
    [anon_sym_xor] = ACTIONS(1925),
    [anon_sym_bitand] = ACTIONS(1925),
    [anon_sym_not_eq] = ACTIONS(1925),
    [anon_sym_DASH_DASH] = ACTIONS(1927),
    [anon_sym_PLUS_PLUS] = ACTIONS(1927),
    [anon_sym_DOT] = ACTIONS(1925),
    [anon_sym_DOT_STAR] = ACTIONS(1927),
    [anon_sym_DASH_GT] = ACTIONS(1925),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1925),
    [anon_sym_decltype] = ACTIONS(1925),
    [sym_virtual] = ACTIONS(1925),
    [anon_sym_template] = ACTIONS(1925),
    [anon_sym_operator] = ACTIONS(1925),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1927),
    [anon_sym_precise] = ACTIONS(1925),
    [anon_sym_shared] = ACTIONS(1925),
    [anon_sym_groupshared] = ACTIONS(1925),
    [anon_sym_uniform] = ACTIONS(1925),
    [anon_sym_row_major] = ACTIONS(1925),
    [anon_sym_column_major] = ACTIONS(1925),
    [anon_sym_globallycoherent] = ACTIONS(1925),
    [anon_sym_centroid] = ACTIONS(1925),
    [anon_sym_noperspective] = ACTIONS(1925),
    [anon_sym_nointerpolation] = ACTIONS(1925),
    [anon_sym_sample] = ACTIONS(1925),
    [anon_sym_linear] = ACTIONS(1925),
    [anon_sym_snorm] = ACTIONS(1925),
    [anon_sym_unorm] = ACTIONS(1925),
    [anon_sym_point] = ACTIONS(1925),
    [anon_sym_line] = ACTIONS(1925),
    [anon_sym_triangleadj] = ACTIONS(1925),
    [anon_sym_lineadj] = ACTIONS(1925),
    [anon_sym_triangle] = ACTIONS(1925),
  },
  [1123] = {
    [sym_identifier] = ACTIONS(1899),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1901),
    [anon_sym_COMMA] = ACTIONS(1901),
    [anon_sym_RPAREN] = ACTIONS(1901),
    [anon_sym_LPAREN2] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1899),
    [anon_sym_SLASH] = ACTIONS(1899),
    [anon_sym_PERCENT] = ACTIONS(1899),
    [anon_sym_PIPE_PIPE] = ACTIONS(1901),
    [anon_sym_AMP_AMP] = ACTIONS(1901),
    [anon_sym_PIPE] = ACTIONS(1899),
    [anon_sym_CARET] = ACTIONS(1899),
    [anon_sym_AMP] = ACTIONS(1899),
    [anon_sym_EQ_EQ] = ACTIONS(1901),
    [anon_sym_BANG_EQ] = ACTIONS(1901),
    [anon_sym_GT] = ACTIONS(1899),
    [anon_sym_GT_EQ] = ACTIONS(1901),
    [anon_sym_LT_EQ] = ACTIONS(1899),
    [anon_sym_LT] = ACTIONS(1899),
    [anon_sym_LT_LT] = ACTIONS(1899),
    [anon_sym_GT_GT] = ACTIONS(1899),
    [anon_sym_COLON] = ACTIONS(1899),
    [anon_sym___extension__] = ACTIONS(1899),
    [anon_sym_in] = ACTIONS(1899),
    [anon_sym_out] = ACTIONS(1899),
    [anon_sym_inout] = ACTIONS(1899),
    [anon_sym_extern] = ACTIONS(1899),
    [anon_sym___attribute__] = ACTIONS(1899),
    [anon_sym_COLON_COLON] = ACTIONS(1901),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1901),
    [anon_sym___declspec] = ACTIONS(1899),
    [anon_sym___based] = ACTIONS(1899),
    [anon_sym_LBRACE] = ACTIONS(1901),
    [anon_sym_LBRACK] = ACTIONS(1899),
    [anon_sym_static] = ACTIONS(1899),
    [anon_sym_EQ] = ACTIONS(1899),
    [anon_sym_register] = ACTIONS(1899),
    [anon_sym_inline] = ACTIONS(1899),
    [anon_sym___inline] = ACTIONS(1899),
    [anon_sym___inline__] = ACTIONS(1899),
    [anon_sym___forceinline] = ACTIONS(1899),
    [anon_sym_thread_local] = ACTIONS(1899),
    [anon_sym___thread] = ACTIONS(1899),
    [anon_sym_const] = ACTIONS(1899),
    [anon_sym_constexpr] = ACTIONS(1899),
    [anon_sym_volatile] = ACTIONS(1899),
    [anon_sym_restrict] = ACTIONS(1899),
    [anon_sym___restrict__] = ACTIONS(1899),
    [anon_sym__Atomic] = ACTIONS(1899),
    [anon_sym__Noreturn] = ACTIONS(1899),
    [anon_sym_noreturn] = ACTIONS(1899),
    [anon_sym_mutable] = ACTIONS(1899),
    [anon_sym_constinit] = ACTIONS(1899),
    [anon_sym_consteval] = ACTIONS(1899),
    [anon_sym_alignas] = ACTIONS(1899),
    [anon_sym__Alignas] = ACTIONS(1899),
    [anon_sym_QMARK] = ACTIONS(1901),
    [anon_sym_STAR_EQ] = ACTIONS(1901),
    [anon_sym_SLASH_EQ] = ACTIONS(1901),
    [anon_sym_PERCENT_EQ] = ACTIONS(1901),
    [anon_sym_PLUS_EQ] = ACTIONS(1901),
    [anon_sym_DASH_EQ] = ACTIONS(1901),
    [anon_sym_LT_LT_EQ] = ACTIONS(1901),
    [anon_sym_GT_GT_EQ] = ACTIONS(1901),
    [anon_sym_AMP_EQ] = ACTIONS(1901),
    [anon_sym_CARET_EQ] = ACTIONS(1901),
    [anon_sym_PIPE_EQ] = ACTIONS(1901),
    [anon_sym_and_eq] = ACTIONS(1899),
    [anon_sym_or_eq] = ACTIONS(1899),
    [anon_sym_xor_eq] = ACTIONS(1899),
    [anon_sym_LT_EQ_GT] = ACTIONS(1901),
    [anon_sym_or] = ACTIONS(1899),
    [anon_sym_and] = ACTIONS(1899),
    [anon_sym_bitor] = ACTIONS(1899),
    [anon_sym_xor] = ACTIONS(1899),
    [anon_sym_bitand] = ACTIONS(1899),
    [anon_sym_not_eq] = ACTIONS(1899),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DOT] = ACTIONS(1899),
    [anon_sym_DOT_STAR] = ACTIONS(1901),
    [anon_sym_DASH_GT] = ACTIONS(1899),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1899),
    [anon_sym_decltype] = ACTIONS(1899),
    [sym_virtual] = ACTIONS(1899),
    [anon_sym_template] = ACTIONS(1899),
    [anon_sym_operator] = ACTIONS(1899),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1901),
    [anon_sym_precise] = ACTIONS(1899),
    [anon_sym_shared] = ACTIONS(1899),
    [anon_sym_groupshared] = ACTIONS(1899),
    [anon_sym_uniform] = ACTIONS(1899),
    [anon_sym_row_major] = ACTIONS(1899),
    [anon_sym_column_major] = ACTIONS(1899),
    [anon_sym_globallycoherent] = ACTIONS(1899),
    [anon_sym_centroid] = ACTIONS(1899),
    [anon_sym_noperspective] = ACTIONS(1899),
    [anon_sym_nointerpolation] = ACTIONS(1899),
    [anon_sym_sample] = ACTIONS(1899),
    [anon_sym_linear] = ACTIONS(1899),
    [anon_sym_snorm] = ACTIONS(1899),
    [anon_sym_unorm] = ACTIONS(1899),
    [anon_sym_point] = ACTIONS(1899),
    [anon_sym_line] = ACTIONS(1899),
    [anon_sym_triangleadj] = ACTIONS(1899),
    [anon_sym_lineadj] = ACTIONS(1899),
    [anon_sym_triangle] = ACTIONS(1899),
  },
  [1124] = {
    [sym_identifier] = ACTIONS(1917),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1919),
    [anon_sym_COMMA] = ACTIONS(1919),
    [anon_sym_RPAREN] = ACTIONS(1919),
    [anon_sym_LPAREN2] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1917),
    [anon_sym_SLASH] = ACTIONS(1917),
    [anon_sym_PERCENT] = ACTIONS(1917),
    [anon_sym_PIPE_PIPE] = ACTIONS(1919),
    [anon_sym_AMP_AMP] = ACTIONS(1919),
    [anon_sym_PIPE] = ACTIONS(1917),
    [anon_sym_CARET] = ACTIONS(1917),
    [anon_sym_AMP] = ACTIONS(1917),
    [anon_sym_EQ_EQ] = ACTIONS(1919),
    [anon_sym_BANG_EQ] = ACTIONS(1919),
    [anon_sym_GT] = ACTIONS(1917),
    [anon_sym_GT_EQ] = ACTIONS(1919),
    [anon_sym_LT_EQ] = ACTIONS(1917),
    [anon_sym_LT] = ACTIONS(1917),
    [anon_sym_LT_LT] = ACTIONS(1917),
    [anon_sym_GT_GT] = ACTIONS(1917),
    [anon_sym_COLON] = ACTIONS(1917),
    [anon_sym___extension__] = ACTIONS(1917),
    [anon_sym_in] = ACTIONS(1917),
    [anon_sym_out] = ACTIONS(1917),
    [anon_sym_inout] = ACTIONS(1917),
    [anon_sym_extern] = ACTIONS(1917),
    [anon_sym___attribute__] = ACTIONS(1917),
    [anon_sym_COLON_COLON] = ACTIONS(1919),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1919),
    [anon_sym___declspec] = ACTIONS(1917),
    [anon_sym___based] = ACTIONS(1917),
    [anon_sym_LBRACE] = ACTIONS(1919),
    [anon_sym_LBRACK] = ACTIONS(1917),
    [anon_sym_static] = ACTIONS(1917),
    [anon_sym_EQ] = ACTIONS(1917),
    [anon_sym_register] = ACTIONS(1917),
    [anon_sym_inline] = ACTIONS(1917),
    [anon_sym___inline] = ACTIONS(1917),
    [anon_sym___inline__] = ACTIONS(1917),
    [anon_sym___forceinline] = ACTIONS(1917),
    [anon_sym_thread_local] = ACTIONS(1917),
    [anon_sym___thread] = ACTIONS(1917),
    [anon_sym_const] = ACTIONS(1917),
    [anon_sym_constexpr] = ACTIONS(1917),
    [anon_sym_volatile] = ACTIONS(1917),
    [anon_sym_restrict] = ACTIONS(1917),
    [anon_sym___restrict__] = ACTIONS(1917),
    [anon_sym__Atomic] = ACTIONS(1917),
    [anon_sym__Noreturn] = ACTIONS(1917),
    [anon_sym_noreturn] = ACTIONS(1917),
    [anon_sym_mutable] = ACTIONS(1917),
    [anon_sym_constinit] = ACTIONS(1917),
    [anon_sym_consteval] = ACTIONS(1917),
    [anon_sym_alignas] = ACTIONS(1917),
    [anon_sym__Alignas] = ACTIONS(1917),
    [anon_sym_QMARK] = ACTIONS(1919),
    [anon_sym_STAR_EQ] = ACTIONS(1919),
    [anon_sym_SLASH_EQ] = ACTIONS(1919),
    [anon_sym_PERCENT_EQ] = ACTIONS(1919),
    [anon_sym_PLUS_EQ] = ACTIONS(1919),
    [anon_sym_DASH_EQ] = ACTIONS(1919),
    [anon_sym_LT_LT_EQ] = ACTIONS(1919),
    [anon_sym_GT_GT_EQ] = ACTIONS(1919),
    [anon_sym_AMP_EQ] = ACTIONS(1919),
    [anon_sym_CARET_EQ] = ACTIONS(1919),
    [anon_sym_PIPE_EQ] = ACTIONS(1919),
    [anon_sym_and_eq] = ACTIONS(1917),
    [anon_sym_or_eq] = ACTIONS(1917),
    [anon_sym_xor_eq] = ACTIONS(1917),
    [anon_sym_LT_EQ_GT] = ACTIONS(1919),
    [anon_sym_or] = ACTIONS(1917),
    [anon_sym_and] = ACTIONS(1917),
    [anon_sym_bitor] = ACTIONS(1917),
    [anon_sym_xor] = ACTIONS(1917),
    [anon_sym_bitand] = ACTIONS(1917),
    [anon_sym_not_eq] = ACTIONS(1917),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DOT] = ACTIONS(1917),
    [anon_sym_DOT_STAR] = ACTIONS(1919),
    [anon_sym_DASH_GT] = ACTIONS(1917),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1917),
    [anon_sym_decltype] = ACTIONS(1917),
    [sym_virtual] = ACTIONS(1917),
    [anon_sym_template] = ACTIONS(1917),
    [anon_sym_operator] = ACTIONS(1917),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1919),
    [anon_sym_precise] = ACTIONS(1917),
    [anon_sym_shared] = ACTIONS(1917),
    [anon_sym_groupshared] = ACTIONS(1917),
    [anon_sym_uniform] = ACTIONS(1917),
    [anon_sym_row_major] = ACTIONS(1917),
    [anon_sym_column_major] = ACTIONS(1917),
    [anon_sym_globallycoherent] = ACTIONS(1917),
    [anon_sym_centroid] = ACTIONS(1917),
    [anon_sym_noperspective] = ACTIONS(1917),
    [anon_sym_nointerpolation] = ACTIONS(1917),
    [anon_sym_sample] = ACTIONS(1917),
    [anon_sym_linear] = ACTIONS(1917),
    [anon_sym_snorm] = ACTIONS(1917),
    [anon_sym_unorm] = ACTIONS(1917),
    [anon_sym_point] = ACTIONS(1917),
    [anon_sym_line] = ACTIONS(1917),
    [anon_sym_triangleadj] = ACTIONS(1917),
    [anon_sym_lineadj] = ACTIONS(1917),
    [anon_sym_triangle] = ACTIONS(1917),
  },
  [1125] = {
    [sym_identifier] = ACTIONS(1925),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1927),
    [anon_sym_COMMA] = ACTIONS(1927),
    [anon_sym_RPAREN] = ACTIONS(1927),
    [anon_sym_LPAREN2] = ACTIONS(1927),
    [anon_sym_TILDE] = ACTIONS(1927),
    [anon_sym_DASH] = ACTIONS(1925),
    [anon_sym_PLUS] = ACTIONS(1925),
    [anon_sym_STAR] = ACTIONS(1927),
    [anon_sym_SLASH] = ACTIONS(1925),
    [anon_sym_PERCENT] = ACTIONS(1927),
    [anon_sym_PIPE_PIPE] = ACTIONS(1927),
    [anon_sym_AMP_AMP] = ACTIONS(1927),
    [anon_sym_PIPE] = ACTIONS(1925),
    [anon_sym_CARET] = ACTIONS(1927),
    [anon_sym_AMP] = ACTIONS(1925),
    [anon_sym_EQ_EQ] = ACTIONS(1927),
    [anon_sym_BANG_EQ] = ACTIONS(1927),
    [anon_sym_GT] = ACTIONS(1925),
    [anon_sym_GT_EQ] = ACTIONS(1927),
    [anon_sym_LT_EQ] = ACTIONS(1925),
    [anon_sym_LT] = ACTIONS(1925),
    [anon_sym_LT_LT] = ACTIONS(1927),
    [anon_sym_GT_GT] = ACTIONS(1927),
    [anon_sym_COLON] = ACTIONS(1925),
    [anon_sym_SEMI] = ACTIONS(1927),
    [anon_sym___extension__] = ACTIONS(1925),
    [anon_sym_in] = ACTIONS(1925),
    [anon_sym_out] = ACTIONS(1925),
    [anon_sym_inout] = ACTIONS(1925),
    [anon_sym_extern] = ACTIONS(1925),
    [anon_sym___attribute__] = ACTIONS(1925),
    [anon_sym_COLON_COLON] = ACTIONS(1927),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1927),
    [anon_sym___declspec] = ACTIONS(1925),
    [anon_sym___based] = ACTIONS(1925),
    [anon_sym___cdecl] = ACTIONS(1925),
    [anon_sym___clrcall] = ACTIONS(1925),
    [anon_sym___stdcall] = ACTIONS(1925),
    [anon_sym___fastcall] = ACTIONS(1925),
    [anon_sym___thiscall] = ACTIONS(1925),
    [anon_sym___vectorcall] = ACTIONS(1925),
    [anon_sym_LBRACE] = ACTIONS(1927),
    [anon_sym_RBRACE] = ACTIONS(1927),
    [anon_sym_LBRACK] = ACTIONS(1925),
    [anon_sym_static] = ACTIONS(1925),
    [anon_sym_EQ] = ACTIONS(1925),
    [anon_sym_register] = ACTIONS(1925),
    [anon_sym_inline] = ACTIONS(1925),
    [anon_sym___inline] = ACTIONS(1925),
    [anon_sym___inline__] = ACTIONS(1925),
    [anon_sym___forceinline] = ACTIONS(1925),
    [anon_sym_thread_local] = ACTIONS(1925),
    [anon_sym___thread] = ACTIONS(1925),
    [anon_sym_const] = ACTIONS(1925),
    [anon_sym_constexpr] = ACTIONS(1925),
    [anon_sym_volatile] = ACTIONS(1925),
    [anon_sym_restrict] = ACTIONS(1925),
    [anon_sym___restrict__] = ACTIONS(1925),
    [anon_sym__Atomic] = ACTIONS(1925),
    [anon_sym__Noreturn] = ACTIONS(1925),
    [anon_sym_noreturn] = ACTIONS(1925),
    [anon_sym_mutable] = ACTIONS(1925),
    [anon_sym_constinit] = ACTIONS(1925),
    [anon_sym_consteval] = ACTIONS(1925),
    [anon_sym_alignas] = ACTIONS(1925),
    [anon_sym__Alignas] = ACTIONS(1925),
    [anon_sym_else] = ACTIONS(1925),
    [anon_sym_while] = ACTIONS(1925),
    [anon_sym_QMARK] = ACTIONS(1927),
    [anon_sym_LT_EQ_GT] = ACTIONS(1927),
    [anon_sym_or] = ACTIONS(1925),
    [anon_sym_and] = ACTIONS(1925),
    [anon_sym_bitor] = ACTIONS(1925),
    [anon_sym_xor] = ACTIONS(1925),
    [anon_sym_bitand] = ACTIONS(1925),
    [anon_sym_not_eq] = ACTIONS(1925),
    [anon_sym_DASH_DASH] = ACTIONS(1927),
    [anon_sym_PLUS_PLUS] = ACTIONS(1927),
    [anon_sym_DOT] = ACTIONS(1925),
    [anon_sym_DOT_STAR] = ACTIONS(1927),
    [anon_sym_DASH_GT] = ACTIONS(1927),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1925),
    [anon_sym_decltype] = ACTIONS(1925),
    [anon_sym_final] = ACTIONS(1925),
    [anon_sym_override] = ACTIONS(1925),
    [sym_virtual] = ACTIONS(1925),
    [anon_sym_template] = ACTIONS(1925),
    [anon_sym_operator] = ACTIONS(1925),
    [anon_sym_try] = ACTIONS(1925),
    [anon_sym_requires] = ACTIONS(1925),
    [anon_sym_precise] = ACTIONS(1925),
    [anon_sym_shared] = ACTIONS(1925),
    [anon_sym_groupshared] = ACTIONS(1925),
    [anon_sym_uniform] = ACTIONS(1925),
    [anon_sym_row_major] = ACTIONS(1925),
    [anon_sym_column_major] = ACTIONS(1925),
    [anon_sym_globallycoherent] = ACTIONS(1925),
    [anon_sym_centroid] = ACTIONS(1925),
    [anon_sym_noperspective] = ACTIONS(1925),
    [anon_sym_nointerpolation] = ACTIONS(1925),
    [anon_sym_sample] = ACTIONS(1925),
    [anon_sym_linear] = ACTIONS(1925),
    [anon_sym_snorm] = ACTIONS(1925),
    [anon_sym_unorm] = ACTIONS(1925),
    [anon_sym_point] = ACTIONS(1925),
    [anon_sym_line] = ACTIONS(1925),
    [anon_sym_triangleadj] = ACTIONS(1925),
    [anon_sym_lineadj] = ACTIONS(1925),
    [anon_sym_triangle] = ACTIONS(1925),
  },
  [1126] = {
    [sym_identifier] = ACTIONS(1899),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1901),
    [anon_sym_COMMA] = ACTIONS(1901),
    [anon_sym_RPAREN] = ACTIONS(1901),
    [anon_sym_LPAREN2] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1901),
    [anon_sym_SLASH] = ACTIONS(1899),
    [anon_sym_PERCENT] = ACTIONS(1901),
    [anon_sym_PIPE_PIPE] = ACTIONS(1901),
    [anon_sym_AMP_AMP] = ACTIONS(1901),
    [anon_sym_PIPE] = ACTIONS(1899),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1899),
    [anon_sym_EQ_EQ] = ACTIONS(1901),
    [anon_sym_BANG_EQ] = ACTIONS(1901),
    [anon_sym_GT] = ACTIONS(1899),
    [anon_sym_GT_EQ] = ACTIONS(1901),
    [anon_sym_LT_EQ] = ACTIONS(1899),
    [anon_sym_LT] = ACTIONS(1899),
    [anon_sym_LT_LT] = ACTIONS(1901),
    [anon_sym_GT_GT] = ACTIONS(1901),
    [anon_sym_COLON] = ACTIONS(1899),
    [anon_sym_SEMI] = ACTIONS(1901),
    [anon_sym___extension__] = ACTIONS(1899),
    [anon_sym_in] = ACTIONS(1899),
    [anon_sym_out] = ACTIONS(1899),
    [anon_sym_inout] = ACTIONS(1899),
    [anon_sym_extern] = ACTIONS(1899),
    [anon_sym___attribute__] = ACTIONS(1899),
    [anon_sym_COLON_COLON] = ACTIONS(1901),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1901),
    [anon_sym___declspec] = ACTIONS(1899),
    [anon_sym___based] = ACTIONS(1899),
    [anon_sym___cdecl] = ACTIONS(1899),
    [anon_sym___clrcall] = ACTIONS(1899),
    [anon_sym___stdcall] = ACTIONS(1899),
    [anon_sym___fastcall] = ACTIONS(1899),
    [anon_sym___thiscall] = ACTIONS(1899),
    [anon_sym___vectorcall] = ACTIONS(1899),
    [anon_sym_LBRACE] = ACTIONS(1901),
    [anon_sym_RBRACE] = ACTIONS(1901),
    [anon_sym_LBRACK] = ACTIONS(1899),
    [anon_sym_static] = ACTIONS(1899),
    [anon_sym_EQ] = ACTIONS(1899),
    [anon_sym_register] = ACTIONS(1899),
    [anon_sym_inline] = ACTIONS(1899),
    [anon_sym___inline] = ACTIONS(1899),
    [anon_sym___inline__] = ACTIONS(1899),
    [anon_sym___forceinline] = ACTIONS(1899),
    [anon_sym_thread_local] = ACTIONS(1899),
    [anon_sym___thread] = ACTIONS(1899),
    [anon_sym_const] = ACTIONS(1899),
    [anon_sym_constexpr] = ACTIONS(1899),
    [anon_sym_volatile] = ACTIONS(1899),
    [anon_sym_restrict] = ACTIONS(1899),
    [anon_sym___restrict__] = ACTIONS(1899),
    [anon_sym__Atomic] = ACTIONS(1899),
    [anon_sym__Noreturn] = ACTIONS(1899),
    [anon_sym_noreturn] = ACTIONS(1899),
    [anon_sym_mutable] = ACTIONS(1899),
    [anon_sym_constinit] = ACTIONS(1899),
    [anon_sym_consteval] = ACTIONS(1899),
    [anon_sym_alignas] = ACTIONS(1899),
    [anon_sym__Alignas] = ACTIONS(1899),
    [anon_sym_else] = ACTIONS(1899),
    [anon_sym_while] = ACTIONS(1899),
    [anon_sym_QMARK] = ACTIONS(1901),
    [anon_sym_LT_EQ_GT] = ACTIONS(1901),
    [anon_sym_or] = ACTIONS(1899),
    [anon_sym_and] = ACTIONS(1899),
    [anon_sym_bitor] = ACTIONS(1899),
    [anon_sym_xor] = ACTIONS(1899),
    [anon_sym_bitand] = ACTIONS(1899),
    [anon_sym_not_eq] = ACTIONS(1899),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DOT] = ACTIONS(1899),
    [anon_sym_DOT_STAR] = ACTIONS(1901),
    [anon_sym_DASH_GT] = ACTIONS(1901),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1899),
    [anon_sym_decltype] = ACTIONS(1899),
    [anon_sym_final] = ACTIONS(1899),
    [anon_sym_override] = ACTIONS(1899),
    [sym_virtual] = ACTIONS(1899),
    [anon_sym_template] = ACTIONS(1899),
    [anon_sym_operator] = ACTIONS(1899),
    [anon_sym_try] = ACTIONS(1899),
    [anon_sym_requires] = ACTIONS(1899),
    [anon_sym_precise] = ACTIONS(1899),
    [anon_sym_shared] = ACTIONS(1899),
    [anon_sym_groupshared] = ACTIONS(1899),
    [anon_sym_uniform] = ACTIONS(1899),
    [anon_sym_row_major] = ACTIONS(1899),
    [anon_sym_column_major] = ACTIONS(1899),
    [anon_sym_globallycoherent] = ACTIONS(1899),
    [anon_sym_centroid] = ACTIONS(1899),
    [anon_sym_noperspective] = ACTIONS(1899),
    [anon_sym_nointerpolation] = ACTIONS(1899),
    [anon_sym_sample] = ACTIONS(1899),
    [anon_sym_linear] = ACTIONS(1899),
    [anon_sym_snorm] = ACTIONS(1899),
    [anon_sym_unorm] = ACTIONS(1899),
    [anon_sym_point] = ACTIONS(1899),
    [anon_sym_line] = ACTIONS(1899),
    [anon_sym_triangleadj] = ACTIONS(1899),
    [anon_sym_lineadj] = ACTIONS(1899),
    [anon_sym_triangle] = ACTIONS(1899),
  },
  [1127] = {
    [sym_identifier] = ACTIONS(1887),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1889),
    [anon_sym_COMMA] = ACTIONS(1889),
    [anon_sym_RPAREN] = ACTIONS(1889),
    [anon_sym_LPAREN2] = ACTIONS(1889),
    [anon_sym_TILDE] = ACTIONS(1889),
    [anon_sym_DASH] = ACTIONS(1887),
    [anon_sym_PLUS] = ACTIONS(1887),
    [anon_sym_STAR] = ACTIONS(1887),
    [anon_sym_SLASH] = ACTIONS(1887),
    [anon_sym_PERCENT] = ACTIONS(1887),
    [anon_sym_PIPE_PIPE] = ACTIONS(1889),
    [anon_sym_AMP_AMP] = ACTIONS(1889),
    [anon_sym_PIPE] = ACTIONS(1887),
    [anon_sym_CARET] = ACTIONS(1887),
    [anon_sym_AMP] = ACTIONS(1887),
    [anon_sym_EQ_EQ] = ACTIONS(1889),
    [anon_sym_BANG_EQ] = ACTIONS(1889),
    [anon_sym_GT] = ACTIONS(1887),
    [anon_sym_GT_EQ] = ACTIONS(1889),
    [anon_sym_LT_EQ] = ACTIONS(1887),
    [anon_sym_LT] = ACTIONS(1887),
    [anon_sym_LT_LT] = ACTIONS(1887),
    [anon_sym_GT_GT] = ACTIONS(1887),
    [anon_sym_COLON] = ACTIONS(1887),
    [anon_sym___extension__] = ACTIONS(1887),
    [anon_sym_in] = ACTIONS(1887),
    [anon_sym_out] = ACTIONS(1887),
    [anon_sym_inout] = ACTIONS(1887),
    [anon_sym_extern] = ACTIONS(1887),
    [anon_sym___attribute__] = ACTIONS(1887),
    [anon_sym_COLON_COLON] = ACTIONS(1889),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1889),
    [anon_sym___declspec] = ACTIONS(1887),
    [anon_sym___based] = ACTIONS(1887),
    [anon_sym_LBRACE] = ACTIONS(1889),
    [anon_sym_LBRACK] = ACTIONS(1887),
    [anon_sym_static] = ACTIONS(1887),
    [anon_sym_EQ] = ACTIONS(1887),
    [anon_sym_register] = ACTIONS(1887),
    [anon_sym_inline] = ACTIONS(1887),
    [anon_sym___inline] = ACTIONS(1887),
    [anon_sym___inline__] = ACTIONS(1887),
    [anon_sym___forceinline] = ACTIONS(1887),
    [anon_sym_thread_local] = ACTIONS(1887),
    [anon_sym___thread] = ACTIONS(1887),
    [anon_sym_const] = ACTIONS(1887),
    [anon_sym_constexpr] = ACTIONS(1887),
    [anon_sym_volatile] = ACTIONS(1887),
    [anon_sym_restrict] = ACTIONS(1887),
    [anon_sym___restrict__] = ACTIONS(1887),
    [anon_sym__Atomic] = ACTIONS(1887),
    [anon_sym__Noreturn] = ACTIONS(1887),
    [anon_sym_noreturn] = ACTIONS(1887),
    [anon_sym_mutable] = ACTIONS(1887),
    [anon_sym_constinit] = ACTIONS(1887),
    [anon_sym_consteval] = ACTIONS(1887),
    [anon_sym_alignas] = ACTIONS(1887),
    [anon_sym__Alignas] = ACTIONS(1887),
    [anon_sym_QMARK] = ACTIONS(1889),
    [anon_sym_STAR_EQ] = ACTIONS(1889),
    [anon_sym_SLASH_EQ] = ACTIONS(1889),
    [anon_sym_PERCENT_EQ] = ACTIONS(1889),
    [anon_sym_PLUS_EQ] = ACTIONS(1889),
    [anon_sym_DASH_EQ] = ACTIONS(1889),
    [anon_sym_LT_LT_EQ] = ACTIONS(1889),
    [anon_sym_GT_GT_EQ] = ACTIONS(1889),
    [anon_sym_AMP_EQ] = ACTIONS(1889),
    [anon_sym_CARET_EQ] = ACTIONS(1889),
    [anon_sym_PIPE_EQ] = ACTIONS(1889),
    [anon_sym_and_eq] = ACTIONS(1887),
    [anon_sym_or_eq] = ACTIONS(1887),
    [anon_sym_xor_eq] = ACTIONS(1887),
    [anon_sym_LT_EQ_GT] = ACTIONS(1889),
    [anon_sym_or] = ACTIONS(1887),
    [anon_sym_and] = ACTIONS(1887),
    [anon_sym_bitor] = ACTIONS(1887),
    [anon_sym_xor] = ACTIONS(1887),
    [anon_sym_bitand] = ACTIONS(1887),
    [anon_sym_not_eq] = ACTIONS(1887),
    [anon_sym_DASH_DASH] = ACTIONS(1889),
    [anon_sym_PLUS_PLUS] = ACTIONS(1889),
    [anon_sym_DOT] = ACTIONS(1887),
    [anon_sym_DOT_STAR] = ACTIONS(1889),
    [anon_sym_DASH_GT] = ACTIONS(1887),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1887),
    [anon_sym_decltype] = ACTIONS(1887),
    [sym_virtual] = ACTIONS(1887),
    [anon_sym_template] = ACTIONS(1887),
    [anon_sym_operator] = ACTIONS(1887),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1889),
    [anon_sym_precise] = ACTIONS(1887),
    [anon_sym_shared] = ACTIONS(1887),
    [anon_sym_groupshared] = ACTIONS(1887),
    [anon_sym_uniform] = ACTIONS(1887),
    [anon_sym_row_major] = ACTIONS(1887),
    [anon_sym_column_major] = ACTIONS(1887),
    [anon_sym_globallycoherent] = ACTIONS(1887),
    [anon_sym_centroid] = ACTIONS(1887),
    [anon_sym_noperspective] = ACTIONS(1887),
    [anon_sym_nointerpolation] = ACTIONS(1887),
    [anon_sym_sample] = ACTIONS(1887),
    [anon_sym_linear] = ACTIONS(1887),
    [anon_sym_snorm] = ACTIONS(1887),
    [anon_sym_unorm] = ACTIONS(1887),
    [anon_sym_point] = ACTIONS(1887),
    [anon_sym_line] = ACTIONS(1887),
    [anon_sym_triangleadj] = ACTIONS(1887),
    [anon_sym_lineadj] = ACTIONS(1887),
    [anon_sym_triangle] = ACTIONS(1887),
  },
  [1128] = {
    [sym_identifier] = ACTIONS(1887),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1889),
    [anon_sym_COMMA] = ACTIONS(1889),
    [anon_sym_RPAREN] = ACTIONS(1889),
    [anon_sym_LPAREN2] = ACTIONS(1889),
    [anon_sym_TILDE] = ACTIONS(1889),
    [anon_sym_DASH] = ACTIONS(1887),
    [anon_sym_PLUS] = ACTIONS(1887),
    [anon_sym_STAR] = ACTIONS(1889),
    [anon_sym_SLASH] = ACTIONS(1887),
    [anon_sym_PERCENT] = ACTIONS(1889),
    [anon_sym_PIPE_PIPE] = ACTIONS(1889),
    [anon_sym_AMP_AMP] = ACTIONS(1889),
    [anon_sym_PIPE] = ACTIONS(1887),
    [anon_sym_CARET] = ACTIONS(1889),
    [anon_sym_AMP] = ACTIONS(1887),
    [anon_sym_EQ_EQ] = ACTIONS(1889),
    [anon_sym_BANG_EQ] = ACTIONS(1889),
    [anon_sym_GT] = ACTIONS(1887),
    [anon_sym_GT_EQ] = ACTIONS(1889),
    [anon_sym_LT_EQ] = ACTIONS(1887),
    [anon_sym_LT] = ACTIONS(1887),
    [anon_sym_LT_LT] = ACTIONS(1889),
    [anon_sym_GT_GT] = ACTIONS(1889),
    [anon_sym_COLON] = ACTIONS(1887),
    [anon_sym_SEMI] = ACTIONS(1889),
    [anon_sym___extension__] = ACTIONS(1887),
    [anon_sym_in] = ACTIONS(1887),
    [anon_sym_out] = ACTIONS(1887),
    [anon_sym_inout] = ACTIONS(1887),
    [anon_sym_extern] = ACTIONS(1887),
    [anon_sym___attribute__] = ACTIONS(1887),
    [anon_sym_COLON_COLON] = ACTIONS(1889),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1889),
    [anon_sym___declspec] = ACTIONS(1887),
    [anon_sym___based] = ACTIONS(1887),
    [anon_sym___cdecl] = ACTIONS(1887),
    [anon_sym___clrcall] = ACTIONS(1887),
    [anon_sym___stdcall] = ACTIONS(1887),
    [anon_sym___fastcall] = ACTIONS(1887),
    [anon_sym___thiscall] = ACTIONS(1887),
    [anon_sym___vectorcall] = ACTIONS(1887),
    [anon_sym_LBRACE] = ACTIONS(1889),
    [anon_sym_RBRACE] = ACTIONS(1889),
    [anon_sym_LBRACK] = ACTIONS(1887),
    [anon_sym_static] = ACTIONS(1887),
    [anon_sym_EQ] = ACTIONS(1887),
    [anon_sym_register] = ACTIONS(1887),
    [anon_sym_inline] = ACTIONS(1887),
    [anon_sym___inline] = ACTIONS(1887),
    [anon_sym___inline__] = ACTIONS(1887),
    [anon_sym___forceinline] = ACTIONS(1887),
    [anon_sym_thread_local] = ACTIONS(1887),
    [anon_sym___thread] = ACTIONS(1887),
    [anon_sym_const] = ACTIONS(1887),
    [anon_sym_constexpr] = ACTIONS(1887),
    [anon_sym_volatile] = ACTIONS(1887),
    [anon_sym_restrict] = ACTIONS(1887),
    [anon_sym___restrict__] = ACTIONS(1887),
    [anon_sym__Atomic] = ACTIONS(1887),
    [anon_sym__Noreturn] = ACTIONS(1887),
    [anon_sym_noreturn] = ACTIONS(1887),
    [anon_sym_mutable] = ACTIONS(1887),
    [anon_sym_constinit] = ACTIONS(1887),
    [anon_sym_consteval] = ACTIONS(1887),
    [anon_sym_alignas] = ACTIONS(1887),
    [anon_sym__Alignas] = ACTIONS(1887),
    [anon_sym_else] = ACTIONS(1887),
    [anon_sym_while] = ACTIONS(1887),
    [anon_sym_QMARK] = ACTIONS(1889),
    [anon_sym_LT_EQ_GT] = ACTIONS(1889),
    [anon_sym_or] = ACTIONS(1887),
    [anon_sym_and] = ACTIONS(1887),
    [anon_sym_bitor] = ACTIONS(1887),
    [anon_sym_xor] = ACTIONS(1887),
    [anon_sym_bitand] = ACTIONS(1887),
    [anon_sym_not_eq] = ACTIONS(1887),
    [anon_sym_DASH_DASH] = ACTIONS(1889),
    [anon_sym_PLUS_PLUS] = ACTIONS(1889),
    [anon_sym_DOT] = ACTIONS(1887),
    [anon_sym_DOT_STAR] = ACTIONS(1889),
    [anon_sym_DASH_GT] = ACTIONS(1889),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1887),
    [anon_sym_decltype] = ACTIONS(1887),
    [anon_sym_final] = ACTIONS(1887),
    [anon_sym_override] = ACTIONS(1887),
    [sym_virtual] = ACTIONS(1887),
    [anon_sym_template] = ACTIONS(1887),
    [anon_sym_operator] = ACTIONS(1887),
    [anon_sym_try] = ACTIONS(1887),
    [anon_sym_requires] = ACTIONS(1887),
    [anon_sym_precise] = ACTIONS(1887),
    [anon_sym_shared] = ACTIONS(1887),
    [anon_sym_groupshared] = ACTIONS(1887),
    [anon_sym_uniform] = ACTIONS(1887),
    [anon_sym_row_major] = ACTIONS(1887),
    [anon_sym_column_major] = ACTIONS(1887),
    [anon_sym_globallycoherent] = ACTIONS(1887),
    [anon_sym_centroid] = ACTIONS(1887),
    [anon_sym_noperspective] = ACTIONS(1887),
    [anon_sym_nointerpolation] = ACTIONS(1887),
    [anon_sym_sample] = ACTIONS(1887),
    [anon_sym_linear] = ACTIONS(1887),
    [anon_sym_snorm] = ACTIONS(1887),
    [anon_sym_unorm] = ACTIONS(1887),
    [anon_sym_point] = ACTIONS(1887),
    [anon_sym_line] = ACTIONS(1887),
    [anon_sym_triangleadj] = ACTIONS(1887),
    [anon_sym_lineadj] = ACTIONS(1887),
    [anon_sym_triangle] = ACTIONS(1887),
  },
  [1129] = {
    [sym_template_argument_list] = STATE(1133),
    [sym_identifier] = ACTIONS(1933),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4047),
    [anon_sym_COMMA] = ACTIONS(4047),
    [anon_sym_RPAREN] = ACTIONS(4047),
    [anon_sym_LPAREN2] = ACTIONS(4047),
    [anon_sym_TILDE] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(4050),
    [anon_sym_PLUS] = ACTIONS(4050),
    [anon_sym_STAR] = ACTIONS(4052),
    [anon_sym_SLASH] = ACTIONS(4050),
    [anon_sym_PERCENT] = ACTIONS(4050),
    [anon_sym_PIPE_PIPE] = ACTIONS(4045),
    [anon_sym_AMP_AMP] = ACTIONS(4047),
    [anon_sym_PIPE] = ACTIONS(4050),
    [anon_sym_CARET] = ACTIONS(4050),
    [anon_sym_AMP] = ACTIONS(4052),
    [anon_sym_EQ_EQ] = ACTIONS(4045),
    [anon_sym_BANG_EQ] = ACTIONS(4045),
    [anon_sym_GT] = ACTIONS(4050),
    [anon_sym_GT_EQ] = ACTIONS(4045),
    [anon_sym_LT_EQ] = ACTIONS(4050),
    [anon_sym_LT] = ACTIONS(4055),
    [anon_sym_LT_LT] = ACTIONS(4050),
    [anon_sym_GT_GT] = ACTIONS(4050),
    [anon_sym_COLON] = ACTIONS(1933),
    [anon_sym___extension__] = ACTIONS(1933),
    [anon_sym_in] = ACTIONS(1933),
    [anon_sym_out] = ACTIONS(1933),
    [anon_sym_inout] = ACTIONS(1933),
    [anon_sym_extern] = ACTIONS(1933),
    [anon_sym___attribute__] = ACTIONS(1933),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1935),
    [anon_sym___declspec] = ACTIONS(1933),
    [anon_sym___based] = ACTIONS(1933),
    [anon_sym_LBRACE] = ACTIONS(1935),
    [anon_sym_LBRACK] = ACTIONS(4052),
    [anon_sym_static] = ACTIONS(1933),
    [anon_sym_EQ] = ACTIONS(4052),
    [anon_sym_register] = ACTIONS(1933),
    [anon_sym_inline] = ACTIONS(1933),
    [anon_sym___inline] = ACTIONS(1933),
    [anon_sym___inline__] = ACTIONS(1933),
    [anon_sym___forceinline] = ACTIONS(1933),
    [anon_sym_thread_local] = ACTIONS(1933),
    [anon_sym___thread] = ACTIONS(1933),
    [anon_sym_const] = ACTIONS(1933),
    [anon_sym_constexpr] = ACTIONS(1933),
    [anon_sym_volatile] = ACTIONS(1933),
    [anon_sym_restrict] = ACTIONS(1933),
    [anon_sym___restrict__] = ACTIONS(1933),
    [anon_sym__Atomic] = ACTIONS(1933),
    [anon_sym__Noreturn] = ACTIONS(1933),
    [anon_sym_noreturn] = ACTIONS(1933),
    [anon_sym_mutable] = ACTIONS(1933),
    [anon_sym_constinit] = ACTIONS(1933),
    [anon_sym_consteval] = ACTIONS(1933),
    [anon_sym_alignas] = ACTIONS(1933),
    [anon_sym__Alignas] = ACTIONS(1933),
    [anon_sym_QMARK] = ACTIONS(4045),
    [anon_sym_STAR_EQ] = ACTIONS(4045),
    [anon_sym_SLASH_EQ] = ACTIONS(4045),
    [anon_sym_PERCENT_EQ] = ACTIONS(4045),
    [anon_sym_PLUS_EQ] = ACTIONS(4045),
    [anon_sym_DASH_EQ] = ACTIONS(4045),
    [anon_sym_LT_LT_EQ] = ACTIONS(4045),
    [anon_sym_GT_GT_EQ] = ACTIONS(4045),
    [anon_sym_AMP_EQ] = ACTIONS(4045),
    [anon_sym_CARET_EQ] = ACTIONS(4045),
    [anon_sym_PIPE_EQ] = ACTIONS(4045),
    [anon_sym_and_eq] = ACTIONS(4050),
    [anon_sym_or_eq] = ACTIONS(4050),
    [anon_sym_xor_eq] = ACTIONS(4050),
    [anon_sym_LT_EQ_GT] = ACTIONS(4045),
    [anon_sym_or] = ACTIONS(4050),
    [anon_sym_and] = ACTIONS(4050),
    [anon_sym_bitor] = ACTIONS(4050),
    [anon_sym_xor] = ACTIONS(4050),
    [anon_sym_bitand] = ACTIONS(4050),
    [anon_sym_not_eq] = ACTIONS(4050),
    [anon_sym_DASH_DASH] = ACTIONS(4045),
    [anon_sym_PLUS_PLUS] = ACTIONS(4045),
    [anon_sym_DOT] = ACTIONS(4050),
    [anon_sym_DOT_STAR] = ACTIONS(4045),
    [anon_sym_DASH_GT] = ACTIONS(4045),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1933),
    [anon_sym_decltype] = ACTIONS(1933),
    [sym_virtual] = ACTIONS(1933),
    [anon_sym_template] = ACTIONS(1933),
    [anon_sym_operator] = ACTIONS(1933),
    [anon_sym_precise] = ACTIONS(1933),
    [anon_sym_shared] = ACTIONS(1933),
    [anon_sym_groupshared] = ACTIONS(1933),
    [anon_sym_uniform] = ACTIONS(1933),
    [anon_sym_row_major] = ACTIONS(1933),
    [anon_sym_column_major] = ACTIONS(1933),
    [anon_sym_globallycoherent] = ACTIONS(1933),
    [anon_sym_centroid] = ACTIONS(1933),
    [anon_sym_noperspective] = ACTIONS(1933),
    [anon_sym_nointerpolation] = ACTIONS(1933),
    [anon_sym_sample] = ACTIONS(1933),
    [anon_sym_linear] = ACTIONS(1933),
    [anon_sym_snorm] = ACTIONS(1933),
    [anon_sym_unorm] = ACTIONS(1933),
    [anon_sym_point] = ACTIONS(1933),
    [anon_sym_line] = ACTIONS(1933),
    [anon_sym_triangleadj] = ACTIONS(1933),
    [anon_sym_lineadj] = ACTIONS(1933),
    [anon_sym_triangle] = ACTIONS(1933),
  },
  [1130] = {
    [sym_identifier] = ACTIONS(1959),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4060),
    [anon_sym_COMMA] = ACTIONS(4060),
    [anon_sym_RPAREN] = ACTIONS(4060),
    [anon_sym_LPAREN2] = ACTIONS(4060),
    [anon_sym_TILDE] = ACTIONS(1961),
    [anon_sym_DASH] = ACTIONS(4063),
    [anon_sym_PLUS] = ACTIONS(4063),
    [anon_sym_STAR] = ACTIONS(4065),
    [anon_sym_SLASH] = ACTIONS(4063),
    [anon_sym_PERCENT] = ACTIONS(4063),
    [anon_sym_PIPE_PIPE] = ACTIONS(4058),
    [anon_sym_AMP_AMP] = ACTIONS(4060),
    [anon_sym_PIPE] = ACTIONS(4063),
    [anon_sym_CARET] = ACTIONS(4063),
    [anon_sym_AMP] = ACTIONS(4065),
    [anon_sym_EQ_EQ] = ACTIONS(4058),
    [anon_sym_BANG_EQ] = ACTIONS(4058),
    [anon_sym_GT] = ACTIONS(4063),
    [anon_sym_GT_EQ] = ACTIONS(4058),
    [anon_sym_LT_EQ] = ACTIONS(4063),
    [anon_sym_LT] = ACTIONS(4063),
    [anon_sym_LT_LT] = ACTIONS(4063),
    [anon_sym_GT_GT] = ACTIONS(4063),
    [anon_sym_COLON] = ACTIONS(1959),
    [anon_sym___extension__] = ACTIONS(1959),
    [anon_sym_in] = ACTIONS(1959),
    [anon_sym_out] = ACTIONS(1959),
    [anon_sym_inout] = ACTIONS(1959),
    [anon_sym_extern] = ACTIONS(1959),
    [anon_sym___attribute__] = ACTIONS(1959),
    [anon_sym_COLON_COLON] = ACTIONS(1961),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1961),
    [anon_sym___declspec] = ACTIONS(1959),
    [anon_sym___based] = ACTIONS(1959),
    [anon_sym_LBRACE] = ACTIONS(1961),
    [anon_sym_LBRACK] = ACTIONS(4065),
    [anon_sym_static] = ACTIONS(1959),
    [anon_sym_EQ] = ACTIONS(4065),
    [anon_sym_register] = ACTIONS(1959),
    [anon_sym_inline] = ACTIONS(1959),
    [anon_sym___inline] = ACTIONS(1959),
    [anon_sym___inline__] = ACTIONS(1959),
    [anon_sym___forceinline] = ACTIONS(1959),
    [anon_sym_thread_local] = ACTIONS(1959),
    [anon_sym___thread] = ACTIONS(1959),
    [anon_sym_const] = ACTIONS(1959),
    [anon_sym_constexpr] = ACTIONS(1959),
    [anon_sym_volatile] = ACTIONS(1959),
    [anon_sym_restrict] = ACTIONS(1959),
    [anon_sym___restrict__] = ACTIONS(1959),
    [anon_sym__Atomic] = ACTIONS(1959),
    [anon_sym__Noreturn] = ACTIONS(1959),
    [anon_sym_noreturn] = ACTIONS(1959),
    [anon_sym_mutable] = ACTIONS(1959),
    [anon_sym_constinit] = ACTIONS(1959),
    [anon_sym_consteval] = ACTIONS(1959),
    [anon_sym_alignas] = ACTIONS(1959),
    [anon_sym__Alignas] = ACTIONS(1959),
    [anon_sym_QMARK] = ACTIONS(4058),
    [anon_sym_STAR_EQ] = ACTIONS(4058),
    [anon_sym_SLASH_EQ] = ACTIONS(4058),
    [anon_sym_PERCENT_EQ] = ACTIONS(4058),
    [anon_sym_PLUS_EQ] = ACTIONS(4058),
    [anon_sym_DASH_EQ] = ACTIONS(4058),
    [anon_sym_LT_LT_EQ] = ACTIONS(4058),
    [anon_sym_GT_GT_EQ] = ACTIONS(4058),
    [anon_sym_AMP_EQ] = ACTIONS(4058),
    [anon_sym_CARET_EQ] = ACTIONS(4058),
    [anon_sym_PIPE_EQ] = ACTIONS(4058),
    [anon_sym_and_eq] = ACTIONS(4063),
    [anon_sym_or_eq] = ACTIONS(4063),
    [anon_sym_xor_eq] = ACTIONS(4063),
    [anon_sym_LT_EQ_GT] = ACTIONS(4058),
    [anon_sym_or] = ACTIONS(4063),
    [anon_sym_and] = ACTIONS(4063),
    [anon_sym_bitor] = ACTIONS(4063),
    [anon_sym_xor] = ACTIONS(4063),
    [anon_sym_bitand] = ACTIONS(4063),
    [anon_sym_not_eq] = ACTIONS(4063),
    [anon_sym_DASH_DASH] = ACTIONS(4058),
    [anon_sym_PLUS_PLUS] = ACTIONS(4058),
    [anon_sym_DOT] = ACTIONS(4063),
    [anon_sym_DOT_STAR] = ACTIONS(4058),
    [anon_sym_DASH_GT] = ACTIONS(4063),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1959),
    [anon_sym_decltype] = ACTIONS(1959),
    [sym_virtual] = ACTIONS(1959),
    [anon_sym_template] = ACTIONS(1959),
    [anon_sym_operator] = ACTIONS(1959),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4058),
    [anon_sym_precise] = ACTIONS(1959),
    [anon_sym_shared] = ACTIONS(1959),
    [anon_sym_groupshared] = ACTIONS(1959),
    [anon_sym_uniform] = ACTIONS(1959),
    [anon_sym_row_major] = ACTIONS(1959),
    [anon_sym_column_major] = ACTIONS(1959),
    [anon_sym_globallycoherent] = ACTIONS(1959),
    [anon_sym_centroid] = ACTIONS(1959),
    [anon_sym_noperspective] = ACTIONS(1959),
    [anon_sym_nointerpolation] = ACTIONS(1959),
    [anon_sym_sample] = ACTIONS(1959),
    [anon_sym_linear] = ACTIONS(1959),
    [anon_sym_snorm] = ACTIONS(1959),
    [anon_sym_unorm] = ACTIONS(1959),
    [anon_sym_point] = ACTIONS(1959),
    [anon_sym_line] = ACTIONS(1959),
    [anon_sym_triangleadj] = ACTIONS(1959),
    [anon_sym_lineadj] = ACTIONS(1959),
    [anon_sym_triangle] = ACTIONS(1959),
  },
  [1131] = {
    [sym_identifier] = ACTIONS(1903),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1905),
    [anon_sym_COMMA] = ACTIONS(1905),
    [anon_sym_RPAREN] = ACTIONS(1905),
    [anon_sym_LPAREN2] = ACTIONS(1905),
    [anon_sym_TILDE] = ACTIONS(1905),
    [anon_sym_DASH] = ACTIONS(1903),
    [anon_sym_PLUS] = ACTIONS(1903),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_SLASH] = ACTIONS(1903),
    [anon_sym_PERCENT] = ACTIONS(1903),
    [anon_sym_PIPE_PIPE] = ACTIONS(1905),
    [anon_sym_AMP_AMP] = ACTIONS(1905),
    [anon_sym_PIPE] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1903),
    [anon_sym_AMP] = ACTIONS(1903),
    [anon_sym_EQ_EQ] = ACTIONS(1905),
    [anon_sym_BANG_EQ] = ACTIONS(1905),
    [anon_sym_GT] = ACTIONS(1903),
    [anon_sym_GT_EQ] = ACTIONS(1905),
    [anon_sym_LT_EQ] = ACTIONS(1903),
    [anon_sym_LT] = ACTIONS(1903),
    [anon_sym_LT_LT] = ACTIONS(1903),
    [anon_sym_GT_GT] = ACTIONS(1903),
    [anon_sym_COLON] = ACTIONS(1903),
    [anon_sym___extension__] = ACTIONS(1903),
    [anon_sym_in] = ACTIONS(1903),
    [anon_sym_out] = ACTIONS(1903),
    [anon_sym_inout] = ACTIONS(1903),
    [anon_sym_extern] = ACTIONS(1903),
    [anon_sym___attribute__] = ACTIONS(1903),
    [anon_sym_COLON_COLON] = ACTIONS(1905),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1905),
    [anon_sym___declspec] = ACTIONS(1903),
    [anon_sym___based] = ACTIONS(1903),
    [anon_sym_LBRACE] = ACTIONS(1905),
    [anon_sym_LBRACK] = ACTIONS(1903),
    [anon_sym_static] = ACTIONS(1903),
    [anon_sym_EQ] = ACTIONS(1903),
    [anon_sym_register] = ACTIONS(1903),
    [anon_sym_inline] = ACTIONS(1903),
    [anon_sym___inline] = ACTIONS(1903),
    [anon_sym___inline__] = ACTIONS(1903),
    [anon_sym___forceinline] = ACTIONS(1903),
    [anon_sym_thread_local] = ACTIONS(1903),
    [anon_sym___thread] = ACTIONS(1903),
    [anon_sym_const] = ACTIONS(1903),
    [anon_sym_constexpr] = ACTIONS(1903),
    [anon_sym_volatile] = ACTIONS(1903),
    [anon_sym_restrict] = ACTIONS(1903),
    [anon_sym___restrict__] = ACTIONS(1903),
    [anon_sym__Atomic] = ACTIONS(1903),
    [anon_sym__Noreturn] = ACTIONS(1903),
    [anon_sym_noreturn] = ACTIONS(1903),
    [anon_sym_mutable] = ACTIONS(1903),
    [anon_sym_constinit] = ACTIONS(1903),
    [anon_sym_consteval] = ACTIONS(1903),
    [anon_sym_alignas] = ACTIONS(1903),
    [anon_sym__Alignas] = ACTIONS(1903),
    [anon_sym_QMARK] = ACTIONS(1905),
    [anon_sym_STAR_EQ] = ACTIONS(1905),
    [anon_sym_SLASH_EQ] = ACTIONS(1905),
    [anon_sym_PERCENT_EQ] = ACTIONS(1905),
    [anon_sym_PLUS_EQ] = ACTIONS(1905),
    [anon_sym_DASH_EQ] = ACTIONS(1905),
    [anon_sym_LT_LT_EQ] = ACTIONS(1905),
    [anon_sym_GT_GT_EQ] = ACTIONS(1905),
    [anon_sym_AMP_EQ] = ACTIONS(1905),
    [anon_sym_CARET_EQ] = ACTIONS(1905),
    [anon_sym_PIPE_EQ] = ACTIONS(1905),
    [anon_sym_and_eq] = ACTIONS(1903),
    [anon_sym_or_eq] = ACTIONS(1903),
    [anon_sym_xor_eq] = ACTIONS(1903),
    [anon_sym_LT_EQ_GT] = ACTIONS(1905),
    [anon_sym_or] = ACTIONS(1903),
    [anon_sym_and] = ACTIONS(1903),
    [anon_sym_bitor] = ACTIONS(1903),
    [anon_sym_xor] = ACTIONS(1903),
    [anon_sym_bitand] = ACTIONS(1903),
    [anon_sym_not_eq] = ACTIONS(1903),
    [anon_sym_DASH_DASH] = ACTIONS(1905),
    [anon_sym_PLUS_PLUS] = ACTIONS(1905),
    [anon_sym_DOT] = ACTIONS(1903),
    [anon_sym_DOT_STAR] = ACTIONS(1905),
    [anon_sym_DASH_GT] = ACTIONS(1903),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1903),
    [anon_sym_decltype] = ACTIONS(1903),
    [sym_virtual] = ACTIONS(1903),
    [anon_sym_template] = ACTIONS(1903),
    [anon_sym_operator] = ACTIONS(1903),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1905),
    [anon_sym_precise] = ACTIONS(1903),
    [anon_sym_shared] = ACTIONS(1903),
    [anon_sym_groupshared] = ACTIONS(1903),
    [anon_sym_uniform] = ACTIONS(1903),
    [anon_sym_row_major] = ACTIONS(1903),
    [anon_sym_column_major] = ACTIONS(1903),
    [anon_sym_globallycoherent] = ACTIONS(1903),
    [anon_sym_centroid] = ACTIONS(1903),
    [anon_sym_noperspective] = ACTIONS(1903),
    [anon_sym_nointerpolation] = ACTIONS(1903),
    [anon_sym_sample] = ACTIONS(1903),
    [anon_sym_linear] = ACTIONS(1903),
    [anon_sym_snorm] = ACTIONS(1903),
    [anon_sym_unorm] = ACTIONS(1903),
    [anon_sym_point] = ACTIONS(1903),
    [anon_sym_line] = ACTIONS(1903),
    [anon_sym_triangleadj] = ACTIONS(1903),
    [anon_sym_lineadj] = ACTIONS(1903),
    [anon_sym_triangle] = ACTIONS(1903),
  },
  [1132] = {
    [sym_identifier] = ACTIONS(1903),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1905),
    [anon_sym_COMMA] = ACTIONS(1905),
    [anon_sym_RPAREN] = ACTIONS(1905),
    [anon_sym_LPAREN2] = ACTIONS(1905),
    [anon_sym_TILDE] = ACTIONS(1905),
    [anon_sym_DASH] = ACTIONS(1903),
    [anon_sym_PLUS] = ACTIONS(1903),
    [anon_sym_STAR] = ACTIONS(1905),
    [anon_sym_SLASH] = ACTIONS(1903),
    [anon_sym_PERCENT] = ACTIONS(1905),
    [anon_sym_PIPE_PIPE] = ACTIONS(1905),
    [anon_sym_AMP_AMP] = ACTIONS(1905),
    [anon_sym_PIPE] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1905),
    [anon_sym_AMP] = ACTIONS(1903),
    [anon_sym_EQ_EQ] = ACTIONS(1905),
    [anon_sym_BANG_EQ] = ACTIONS(1905),
    [anon_sym_GT] = ACTIONS(1903),
    [anon_sym_GT_EQ] = ACTIONS(1905),
    [anon_sym_LT_EQ] = ACTIONS(1903),
    [anon_sym_LT] = ACTIONS(1903),
    [anon_sym_LT_LT] = ACTIONS(1905),
    [anon_sym_GT_GT] = ACTIONS(1905),
    [anon_sym_COLON] = ACTIONS(1903),
    [anon_sym_SEMI] = ACTIONS(1905),
    [anon_sym___extension__] = ACTIONS(1903),
    [anon_sym_in] = ACTIONS(1903),
    [anon_sym_out] = ACTIONS(1903),
    [anon_sym_inout] = ACTIONS(1903),
    [anon_sym_extern] = ACTIONS(1903),
    [anon_sym___attribute__] = ACTIONS(1903),
    [anon_sym_COLON_COLON] = ACTIONS(1905),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1905),
    [anon_sym___declspec] = ACTIONS(1903),
    [anon_sym___based] = ACTIONS(1903),
    [anon_sym___cdecl] = ACTIONS(1903),
    [anon_sym___clrcall] = ACTIONS(1903),
    [anon_sym___stdcall] = ACTIONS(1903),
    [anon_sym___fastcall] = ACTIONS(1903),
    [anon_sym___thiscall] = ACTIONS(1903),
    [anon_sym___vectorcall] = ACTIONS(1903),
    [anon_sym_LBRACE] = ACTIONS(1905),
    [anon_sym_RBRACE] = ACTIONS(1905),
    [anon_sym_LBRACK] = ACTIONS(1903),
    [anon_sym_static] = ACTIONS(1903),
    [anon_sym_EQ] = ACTIONS(1903),
    [anon_sym_register] = ACTIONS(1903),
    [anon_sym_inline] = ACTIONS(1903),
    [anon_sym___inline] = ACTIONS(1903),
    [anon_sym___inline__] = ACTIONS(1903),
    [anon_sym___forceinline] = ACTIONS(1903),
    [anon_sym_thread_local] = ACTIONS(1903),
    [anon_sym___thread] = ACTIONS(1903),
    [anon_sym_const] = ACTIONS(1903),
    [anon_sym_constexpr] = ACTIONS(1903),
    [anon_sym_volatile] = ACTIONS(1903),
    [anon_sym_restrict] = ACTIONS(1903),
    [anon_sym___restrict__] = ACTIONS(1903),
    [anon_sym__Atomic] = ACTIONS(1903),
    [anon_sym__Noreturn] = ACTIONS(1903),
    [anon_sym_noreturn] = ACTIONS(1903),
    [anon_sym_mutable] = ACTIONS(1903),
    [anon_sym_constinit] = ACTIONS(1903),
    [anon_sym_consteval] = ACTIONS(1903),
    [anon_sym_alignas] = ACTIONS(1903),
    [anon_sym__Alignas] = ACTIONS(1903),
    [anon_sym_else] = ACTIONS(1903),
    [anon_sym_while] = ACTIONS(1903),
    [anon_sym_QMARK] = ACTIONS(1905),
    [anon_sym_LT_EQ_GT] = ACTIONS(1905),
    [anon_sym_or] = ACTIONS(1903),
    [anon_sym_and] = ACTIONS(1903),
    [anon_sym_bitor] = ACTIONS(1903),
    [anon_sym_xor] = ACTIONS(1903),
    [anon_sym_bitand] = ACTIONS(1903),
    [anon_sym_not_eq] = ACTIONS(1903),
    [anon_sym_DASH_DASH] = ACTIONS(1905),
    [anon_sym_PLUS_PLUS] = ACTIONS(1905),
    [anon_sym_DOT] = ACTIONS(1903),
    [anon_sym_DOT_STAR] = ACTIONS(1905),
    [anon_sym_DASH_GT] = ACTIONS(1905),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1903),
    [anon_sym_decltype] = ACTIONS(1903),
    [anon_sym_final] = ACTIONS(1903),
    [anon_sym_override] = ACTIONS(1903),
    [sym_virtual] = ACTIONS(1903),
    [anon_sym_template] = ACTIONS(1903),
    [anon_sym_operator] = ACTIONS(1903),
    [anon_sym_try] = ACTIONS(1903),
    [anon_sym_requires] = ACTIONS(1903),
    [anon_sym_precise] = ACTIONS(1903),
    [anon_sym_shared] = ACTIONS(1903),
    [anon_sym_groupshared] = ACTIONS(1903),
    [anon_sym_uniform] = ACTIONS(1903),
    [anon_sym_row_major] = ACTIONS(1903),
    [anon_sym_column_major] = ACTIONS(1903),
    [anon_sym_globallycoherent] = ACTIONS(1903),
    [anon_sym_centroid] = ACTIONS(1903),
    [anon_sym_noperspective] = ACTIONS(1903),
    [anon_sym_nointerpolation] = ACTIONS(1903),
    [anon_sym_sample] = ACTIONS(1903),
    [anon_sym_linear] = ACTIONS(1903),
    [anon_sym_snorm] = ACTIONS(1903),
    [anon_sym_unorm] = ACTIONS(1903),
    [anon_sym_point] = ACTIONS(1903),
    [anon_sym_line] = ACTIONS(1903),
    [anon_sym_triangleadj] = ACTIONS(1903),
    [anon_sym_lineadj] = ACTIONS(1903),
    [anon_sym_triangle] = ACTIONS(1903),
  },
  [1133] = {
    [sym_identifier] = ACTIONS(1959),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4060),
    [anon_sym_COMMA] = ACTIONS(4060),
    [anon_sym_RPAREN] = ACTIONS(4060),
    [anon_sym_LPAREN2] = ACTIONS(4060),
    [anon_sym_TILDE] = ACTIONS(1961),
    [anon_sym_DASH] = ACTIONS(4063),
    [anon_sym_PLUS] = ACTIONS(4063),
    [anon_sym_STAR] = ACTIONS(4065),
    [anon_sym_SLASH] = ACTIONS(4063),
    [anon_sym_PERCENT] = ACTIONS(4063),
    [anon_sym_PIPE_PIPE] = ACTIONS(4058),
    [anon_sym_AMP_AMP] = ACTIONS(4060),
    [anon_sym_PIPE] = ACTIONS(4063),
    [anon_sym_CARET] = ACTIONS(4063),
    [anon_sym_AMP] = ACTIONS(4065),
    [anon_sym_EQ_EQ] = ACTIONS(4058),
    [anon_sym_BANG_EQ] = ACTIONS(4058),
    [anon_sym_GT] = ACTIONS(4063),
    [anon_sym_GT_EQ] = ACTIONS(4058),
    [anon_sym_LT_EQ] = ACTIONS(4063),
    [anon_sym_LT] = ACTIONS(4063),
    [anon_sym_LT_LT] = ACTIONS(4063),
    [anon_sym_GT_GT] = ACTIONS(4063),
    [anon_sym_COLON] = ACTIONS(1959),
    [anon_sym___extension__] = ACTIONS(1959),
    [anon_sym_in] = ACTIONS(1959),
    [anon_sym_out] = ACTIONS(1959),
    [anon_sym_inout] = ACTIONS(1959),
    [anon_sym_extern] = ACTIONS(1959),
    [anon_sym___attribute__] = ACTIONS(1959),
    [anon_sym_COLON_COLON] = ACTIONS(1961),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1961),
    [anon_sym___declspec] = ACTIONS(1959),
    [anon_sym___based] = ACTIONS(1959),
    [anon_sym_LBRACE] = ACTIONS(1961),
    [anon_sym_LBRACK] = ACTIONS(4065),
    [anon_sym_static] = ACTIONS(1959),
    [anon_sym_EQ] = ACTIONS(4065),
    [anon_sym_register] = ACTIONS(1959),
    [anon_sym_inline] = ACTIONS(1959),
    [anon_sym___inline] = ACTIONS(1959),
    [anon_sym___inline__] = ACTIONS(1959),
    [anon_sym___forceinline] = ACTIONS(1959),
    [anon_sym_thread_local] = ACTIONS(1959),
    [anon_sym___thread] = ACTIONS(1959),
    [anon_sym_const] = ACTIONS(1959),
    [anon_sym_constexpr] = ACTIONS(1959),
    [anon_sym_volatile] = ACTIONS(1959),
    [anon_sym_restrict] = ACTIONS(1959),
    [anon_sym___restrict__] = ACTIONS(1959),
    [anon_sym__Atomic] = ACTIONS(1959),
    [anon_sym__Noreturn] = ACTIONS(1959),
    [anon_sym_noreturn] = ACTIONS(1959),
    [anon_sym_mutable] = ACTIONS(1959),
    [anon_sym_constinit] = ACTIONS(1959),
    [anon_sym_consteval] = ACTIONS(1959),
    [anon_sym_alignas] = ACTIONS(1959),
    [anon_sym__Alignas] = ACTIONS(1959),
    [anon_sym_QMARK] = ACTIONS(4058),
    [anon_sym_STAR_EQ] = ACTIONS(4058),
    [anon_sym_SLASH_EQ] = ACTIONS(4058),
    [anon_sym_PERCENT_EQ] = ACTIONS(4058),
    [anon_sym_PLUS_EQ] = ACTIONS(4058),
    [anon_sym_DASH_EQ] = ACTIONS(4058),
    [anon_sym_LT_LT_EQ] = ACTIONS(4058),
    [anon_sym_GT_GT_EQ] = ACTIONS(4058),
    [anon_sym_AMP_EQ] = ACTIONS(4058),
    [anon_sym_CARET_EQ] = ACTIONS(4058),
    [anon_sym_PIPE_EQ] = ACTIONS(4058),
    [anon_sym_and_eq] = ACTIONS(4063),
    [anon_sym_or_eq] = ACTIONS(4063),
    [anon_sym_xor_eq] = ACTIONS(4063),
    [anon_sym_LT_EQ_GT] = ACTIONS(4058),
    [anon_sym_or] = ACTIONS(4063),
    [anon_sym_and] = ACTIONS(4063),
    [anon_sym_bitor] = ACTIONS(4063),
    [anon_sym_xor] = ACTIONS(4063),
    [anon_sym_bitand] = ACTIONS(4063),
    [anon_sym_not_eq] = ACTIONS(4063),
    [anon_sym_DASH_DASH] = ACTIONS(4058),
    [anon_sym_PLUS_PLUS] = ACTIONS(4058),
    [anon_sym_DOT] = ACTIONS(4063),
    [anon_sym_DOT_STAR] = ACTIONS(4058),
    [anon_sym_DASH_GT] = ACTIONS(4058),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1959),
    [anon_sym_decltype] = ACTIONS(1959),
    [sym_virtual] = ACTIONS(1959),
    [anon_sym_template] = ACTIONS(1959),
    [anon_sym_operator] = ACTIONS(1959),
    [anon_sym_precise] = ACTIONS(1959),
    [anon_sym_shared] = ACTIONS(1959),
    [anon_sym_groupshared] = ACTIONS(1959),
    [anon_sym_uniform] = ACTIONS(1959),
    [anon_sym_row_major] = ACTIONS(1959),
    [anon_sym_column_major] = ACTIONS(1959),
    [anon_sym_globallycoherent] = ACTIONS(1959),
    [anon_sym_centroid] = ACTIONS(1959),
    [anon_sym_noperspective] = ACTIONS(1959),
    [anon_sym_nointerpolation] = ACTIONS(1959),
    [anon_sym_sample] = ACTIONS(1959),
    [anon_sym_linear] = ACTIONS(1959),
    [anon_sym_snorm] = ACTIONS(1959),
    [anon_sym_unorm] = ACTIONS(1959),
    [anon_sym_point] = ACTIONS(1959),
    [anon_sym_line] = ACTIONS(1959),
    [anon_sym_triangleadj] = ACTIONS(1959),
    [anon_sym_lineadj] = ACTIONS(1959),
    [anon_sym_triangle] = ACTIONS(1959),
  },
  [1134] = {
    [sym_identifier] = ACTIONS(1959),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4058),
    [anon_sym_COMMA] = ACTIONS(4058),
    [anon_sym_RPAREN] = ACTIONS(4058),
    [anon_sym_LPAREN2] = ACTIONS(4060),
    [anon_sym_TILDE] = ACTIONS(1961),
    [anon_sym_DASH] = ACTIONS(4063),
    [anon_sym_PLUS] = ACTIONS(4063),
    [anon_sym_STAR] = ACTIONS(4065),
    [anon_sym_SLASH] = ACTIONS(4063),
    [anon_sym_PERCENT] = ACTIONS(4063),
    [anon_sym_PIPE_PIPE] = ACTIONS(4058),
    [anon_sym_AMP_AMP] = ACTIONS(4060),
    [anon_sym_PIPE] = ACTIONS(4063),
    [anon_sym_CARET] = ACTIONS(4063),
    [anon_sym_AMP] = ACTIONS(4065),
    [anon_sym_EQ_EQ] = ACTIONS(4058),
    [anon_sym_BANG_EQ] = ACTIONS(4058),
    [anon_sym_GT] = ACTIONS(4063),
    [anon_sym_GT_EQ] = ACTIONS(4058),
    [anon_sym_LT_EQ] = ACTIONS(4063),
    [anon_sym_LT] = ACTIONS(4063),
    [anon_sym_LT_LT] = ACTIONS(4063),
    [anon_sym_GT_GT] = ACTIONS(4063),
    [anon_sym_SEMI] = ACTIONS(4058),
    [anon_sym___extension__] = ACTIONS(1959),
    [anon_sym_in] = ACTIONS(1959),
    [anon_sym_out] = ACTIONS(1959),
    [anon_sym_inout] = ACTIONS(1959),
    [anon_sym_extern] = ACTIONS(1959),
    [anon_sym___attribute__] = ACTIONS(1959),
    [anon_sym_COLON_COLON] = ACTIONS(1961),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1961),
    [anon_sym___declspec] = ACTIONS(1959),
    [anon_sym___based] = ACTIONS(1959),
    [anon_sym_LBRACE] = ACTIONS(1961),
    [anon_sym_LBRACK] = ACTIONS(4065),
    [anon_sym_static] = ACTIONS(1959),
    [anon_sym_EQ] = ACTIONS(4063),
    [anon_sym_register] = ACTIONS(1959),
    [anon_sym_inline] = ACTIONS(1959),
    [anon_sym___inline] = ACTIONS(1959),
    [anon_sym___inline__] = ACTIONS(1959),
    [anon_sym___forceinline] = ACTIONS(1959),
    [anon_sym_thread_local] = ACTIONS(1959),
    [anon_sym___thread] = ACTIONS(1959),
    [anon_sym_const] = ACTIONS(1959),
    [anon_sym_constexpr] = ACTIONS(1959),
    [anon_sym_volatile] = ACTIONS(1959),
    [anon_sym_restrict] = ACTIONS(1959),
    [anon_sym___restrict__] = ACTIONS(1959),
    [anon_sym__Atomic] = ACTIONS(1959),
    [anon_sym__Noreturn] = ACTIONS(1959),
    [anon_sym_noreturn] = ACTIONS(1959),
    [anon_sym_mutable] = ACTIONS(1959),
    [anon_sym_constinit] = ACTIONS(1959),
    [anon_sym_consteval] = ACTIONS(1959),
    [anon_sym_alignas] = ACTIONS(1959),
    [anon_sym__Alignas] = ACTIONS(1959),
    [anon_sym_QMARK] = ACTIONS(4058),
    [anon_sym_STAR_EQ] = ACTIONS(4058),
    [anon_sym_SLASH_EQ] = ACTIONS(4058),
    [anon_sym_PERCENT_EQ] = ACTIONS(4058),
    [anon_sym_PLUS_EQ] = ACTIONS(4058),
    [anon_sym_DASH_EQ] = ACTIONS(4058),
    [anon_sym_LT_LT_EQ] = ACTIONS(4058),
    [anon_sym_GT_GT_EQ] = ACTIONS(4058),
    [anon_sym_AMP_EQ] = ACTIONS(4058),
    [anon_sym_CARET_EQ] = ACTIONS(4058),
    [anon_sym_PIPE_EQ] = ACTIONS(4058),
    [anon_sym_and_eq] = ACTIONS(4063),
    [anon_sym_or_eq] = ACTIONS(4063),
    [anon_sym_xor_eq] = ACTIONS(4063),
    [anon_sym_LT_EQ_GT] = ACTIONS(4058),
    [anon_sym_or] = ACTIONS(4063),
    [anon_sym_and] = ACTIONS(4063),
    [anon_sym_bitor] = ACTIONS(4063),
    [anon_sym_xor] = ACTIONS(4063),
    [anon_sym_bitand] = ACTIONS(4063),
    [anon_sym_not_eq] = ACTIONS(4063),
    [anon_sym_DASH_DASH] = ACTIONS(4058),
    [anon_sym_PLUS_PLUS] = ACTIONS(4058),
    [anon_sym_DOT] = ACTIONS(4063),
    [anon_sym_DOT_STAR] = ACTIONS(4058),
    [anon_sym_DASH_GT] = ACTIONS(4058),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1959),
    [anon_sym_decltype] = ACTIONS(1959),
    [sym_virtual] = ACTIONS(1959),
    [anon_sym_template] = ACTIONS(1959),
    [anon_sym_operator] = ACTIONS(1959),
    [anon_sym_precise] = ACTIONS(1959),
    [anon_sym_shared] = ACTIONS(1959),
    [anon_sym_groupshared] = ACTIONS(1959),
    [anon_sym_uniform] = ACTIONS(1959),
    [anon_sym_row_major] = ACTIONS(1959),
    [anon_sym_column_major] = ACTIONS(1959),
    [anon_sym_globallycoherent] = ACTIONS(1959),
    [anon_sym_centroid] = ACTIONS(1959),
    [anon_sym_noperspective] = ACTIONS(1959),
    [anon_sym_nointerpolation] = ACTIONS(1959),
    [anon_sym_sample] = ACTIONS(1959),
    [anon_sym_linear] = ACTIONS(1959),
    [anon_sym_snorm] = ACTIONS(1959),
    [anon_sym_unorm] = ACTIONS(1959),
    [anon_sym_point] = ACTIONS(1959),
    [anon_sym_line] = ACTIONS(1959),
    [anon_sym_triangleadj] = ACTIONS(1959),
    [anon_sym_lineadj] = ACTIONS(1959),
    [anon_sym_triangle] = ACTIONS(1959),
  },
  [1135] = {
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6295),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6270),
    [sym_array_declarator] = STATE(6270),
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3391),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5624),
    [sym_qualified_identifier] = STATE(3390),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3898),
    [anon_sym_LPAREN2] = ACTIONS(3900),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3902),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(27),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(31),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_LBRACK] = ACTIONS(2038),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(2078),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1136] = {
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6295),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6270),
    [sym_array_declarator] = STATE(6270),
    [sym_expression] = STATE(3306),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3415),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5636),
    [sym_qualified_identifier] = STATE(3419),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_operator_name] = STATE(6270),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3918),
    [anon_sym_LPAREN2] = ACTIONS(2020),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2024),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(2028),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2030),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_LBRACK] = ACTIONS(2038),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(2078),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1137] = {
    [sym_identifier] = ACTIONS(1899),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1901),
    [anon_sym_COMMA] = ACTIONS(1901),
    [anon_sym_RPAREN] = ACTIONS(1901),
    [anon_sym_LPAREN2] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1899),
    [anon_sym_SLASH] = ACTIONS(1899),
    [anon_sym_PERCENT] = ACTIONS(1899),
    [anon_sym_PIPE_PIPE] = ACTIONS(1901),
    [anon_sym_AMP_AMP] = ACTIONS(1901),
    [anon_sym_PIPE] = ACTIONS(1899),
    [anon_sym_CARET] = ACTIONS(1899),
    [anon_sym_AMP] = ACTIONS(1899),
    [anon_sym_EQ_EQ] = ACTIONS(1901),
    [anon_sym_BANG_EQ] = ACTIONS(1901),
    [anon_sym_GT] = ACTIONS(1899),
    [anon_sym_GT_EQ] = ACTIONS(1901),
    [anon_sym_LT_EQ] = ACTIONS(1899),
    [anon_sym_LT] = ACTIONS(1899),
    [anon_sym_LT_LT] = ACTIONS(1899),
    [anon_sym_GT_GT] = ACTIONS(1899),
    [anon_sym_COLON] = ACTIONS(1899),
    [anon_sym___extension__] = ACTIONS(1899),
    [anon_sym_in] = ACTIONS(1899),
    [anon_sym_out] = ACTIONS(1899),
    [anon_sym_inout] = ACTIONS(1899),
    [anon_sym_extern] = ACTIONS(1899),
    [anon_sym___attribute__] = ACTIONS(1899),
    [anon_sym_COLON_COLON] = ACTIONS(1901),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1901),
    [anon_sym___declspec] = ACTIONS(1899),
    [anon_sym___based] = ACTIONS(1899),
    [anon_sym_LBRACE] = ACTIONS(1901),
    [anon_sym_LBRACK] = ACTIONS(1899),
    [anon_sym_static] = ACTIONS(1899),
    [anon_sym_EQ] = ACTIONS(1899),
    [anon_sym_register] = ACTIONS(1899),
    [anon_sym_inline] = ACTIONS(1899),
    [anon_sym___inline] = ACTIONS(1899),
    [anon_sym___inline__] = ACTIONS(1899),
    [anon_sym___forceinline] = ACTIONS(1899),
    [anon_sym_thread_local] = ACTIONS(1899),
    [anon_sym___thread] = ACTIONS(1899),
    [anon_sym_const] = ACTIONS(1899),
    [anon_sym_constexpr] = ACTIONS(1899),
    [anon_sym_volatile] = ACTIONS(1899),
    [anon_sym_restrict] = ACTIONS(1899),
    [anon_sym___restrict__] = ACTIONS(1899),
    [anon_sym__Atomic] = ACTIONS(1899),
    [anon_sym__Noreturn] = ACTIONS(1899),
    [anon_sym_noreturn] = ACTIONS(1899),
    [anon_sym_mutable] = ACTIONS(1899),
    [anon_sym_constinit] = ACTIONS(1899),
    [anon_sym_consteval] = ACTIONS(1899),
    [anon_sym_alignas] = ACTIONS(1899),
    [anon_sym__Alignas] = ACTIONS(1899),
    [anon_sym_QMARK] = ACTIONS(1901),
    [anon_sym_STAR_EQ] = ACTIONS(1901),
    [anon_sym_SLASH_EQ] = ACTIONS(1901),
    [anon_sym_PERCENT_EQ] = ACTIONS(1901),
    [anon_sym_PLUS_EQ] = ACTIONS(1901),
    [anon_sym_DASH_EQ] = ACTIONS(1901),
    [anon_sym_LT_LT_EQ] = ACTIONS(1901),
    [anon_sym_GT_GT_EQ] = ACTIONS(1901),
    [anon_sym_AMP_EQ] = ACTIONS(1901),
    [anon_sym_CARET_EQ] = ACTIONS(1901),
    [anon_sym_PIPE_EQ] = ACTIONS(1901),
    [anon_sym_LT_EQ_GT] = ACTIONS(1901),
    [anon_sym_or] = ACTIONS(1899),
    [anon_sym_and] = ACTIONS(1899),
    [anon_sym_bitor] = ACTIONS(1899),
    [anon_sym_xor] = ACTIONS(1899),
    [anon_sym_bitand] = ACTIONS(1899),
    [anon_sym_not_eq] = ACTIONS(1899),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DOT] = ACTIONS(1899),
    [anon_sym_DOT_STAR] = ACTIONS(1901),
    [anon_sym_DASH_GT] = ACTIONS(1899),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1899),
    [anon_sym_decltype] = ACTIONS(1899),
    [sym_virtual] = ACTIONS(1899),
    [anon_sym_template] = ACTIONS(1899),
    [anon_sym_operator] = ACTIONS(1899),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1901),
    [anon_sym_precise] = ACTIONS(1899),
    [anon_sym_shared] = ACTIONS(1899),
    [anon_sym_groupshared] = ACTIONS(1899),
    [anon_sym_uniform] = ACTIONS(1899),
    [anon_sym_row_major] = ACTIONS(1899),
    [anon_sym_column_major] = ACTIONS(1899),
    [anon_sym_globallycoherent] = ACTIONS(1899),
    [anon_sym_centroid] = ACTIONS(1899),
    [anon_sym_noperspective] = ACTIONS(1899),
    [anon_sym_nointerpolation] = ACTIONS(1899),
    [anon_sym_sample] = ACTIONS(1899),
    [anon_sym_linear] = ACTIONS(1899),
    [anon_sym_snorm] = ACTIONS(1899),
    [anon_sym_unorm] = ACTIONS(1899),
    [anon_sym_point] = ACTIONS(1899),
    [anon_sym_line] = ACTIONS(1899),
    [anon_sym_triangleadj] = ACTIONS(1899),
    [anon_sym_lineadj] = ACTIONS(1899),
    [anon_sym_triangle] = ACTIONS(1899),
  },
  [1138] = {
    [sym_identifier] = ACTIONS(1925),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1927),
    [anon_sym_COMMA] = ACTIONS(1927),
    [anon_sym_RPAREN] = ACTIONS(1927),
    [anon_sym_LPAREN2] = ACTIONS(1927),
    [anon_sym_TILDE] = ACTIONS(1927),
    [anon_sym_DASH] = ACTIONS(1925),
    [anon_sym_PLUS] = ACTIONS(1925),
    [anon_sym_STAR] = ACTIONS(1925),
    [anon_sym_SLASH] = ACTIONS(1925),
    [anon_sym_PERCENT] = ACTIONS(1925),
    [anon_sym_PIPE_PIPE] = ACTIONS(1927),
    [anon_sym_AMP_AMP] = ACTIONS(1927),
    [anon_sym_PIPE] = ACTIONS(1925),
    [anon_sym_CARET] = ACTIONS(1925),
    [anon_sym_AMP] = ACTIONS(1925),
    [anon_sym_EQ_EQ] = ACTIONS(1927),
    [anon_sym_BANG_EQ] = ACTIONS(1927),
    [anon_sym_GT] = ACTIONS(1925),
    [anon_sym_GT_EQ] = ACTIONS(1927),
    [anon_sym_LT_EQ] = ACTIONS(1925),
    [anon_sym_LT] = ACTIONS(1925),
    [anon_sym_LT_LT] = ACTIONS(1925),
    [anon_sym_GT_GT] = ACTIONS(1925),
    [anon_sym_COLON] = ACTIONS(1925),
    [anon_sym___extension__] = ACTIONS(1925),
    [anon_sym_in] = ACTIONS(1925),
    [anon_sym_out] = ACTIONS(1925),
    [anon_sym_inout] = ACTIONS(1925),
    [anon_sym_extern] = ACTIONS(1925),
    [anon_sym___attribute__] = ACTIONS(1925),
    [anon_sym_COLON_COLON] = ACTIONS(1927),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1927),
    [anon_sym___declspec] = ACTIONS(1925),
    [anon_sym___based] = ACTIONS(1925),
    [anon_sym_LBRACE] = ACTIONS(1927),
    [anon_sym_LBRACK] = ACTIONS(1925),
    [anon_sym_static] = ACTIONS(1925),
    [anon_sym_EQ] = ACTIONS(1925),
    [anon_sym_register] = ACTIONS(1925),
    [anon_sym_inline] = ACTIONS(1925),
    [anon_sym___inline] = ACTIONS(1925),
    [anon_sym___inline__] = ACTIONS(1925),
    [anon_sym___forceinline] = ACTIONS(1925),
    [anon_sym_thread_local] = ACTIONS(1925),
    [anon_sym___thread] = ACTIONS(1925),
    [anon_sym_const] = ACTIONS(1925),
    [anon_sym_constexpr] = ACTIONS(1925),
    [anon_sym_volatile] = ACTIONS(1925),
    [anon_sym_restrict] = ACTIONS(1925),
    [anon_sym___restrict__] = ACTIONS(1925),
    [anon_sym__Atomic] = ACTIONS(1925),
    [anon_sym__Noreturn] = ACTIONS(1925),
    [anon_sym_noreturn] = ACTIONS(1925),
    [anon_sym_mutable] = ACTIONS(1925),
    [anon_sym_constinit] = ACTIONS(1925),
    [anon_sym_consteval] = ACTIONS(1925),
    [anon_sym_alignas] = ACTIONS(1925),
    [anon_sym__Alignas] = ACTIONS(1925),
    [anon_sym_QMARK] = ACTIONS(1927),
    [anon_sym_STAR_EQ] = ACTIONS(1927),
    [anon_sym_SLASH_EQ] = ACTIONS(1927),
    [anon_sym_PERCENT_EQ] = ACTIONS(1927),
    [anon_sym_PLUS_EQ] = ACTIONS(1927),
    [anon_sym_DASH_EQ] = ACTIONS(1927),
    [anon_sym_LT_LT_EQ] = ACTIONS(1927),
    [anon_sym_GT_GT_EQ] = ACTIONS(1927),
    [anon_sym_AMP_EQ] = ACTIONS(1927),
    [anon_sym_CARET_EQ] = ACTIONS(1927),
    [anon_sym_PIPE_EQ] = ACTIONS(1927),
    [anon_sym_LT_EQ_GT] = ACTIONS(1927),
    [anon_sym_or] = ACTIONS(1925),
    [anon_sym_and] = ACTIONS(1925),
    [anon_sym_bitor] = ACTIONS(1925),
    [anon_sym_xor] = ACTIONS(1925),
    [anon_sym_bitand] = ACTIONS(1925),
    [anon_sym_not_eq] = ACTIONS(1925),
    [anon_sym_DASH_DASH] = ACTIONS(1927),
    [anon_sym_PLUS_PLUS] = ACTIONS(1927),
    [anon_sym_DOT] = ACTIONS(1925),
    [anon_sym_DOT_STAR] = ACTIONS(1927),
    [anon_sym_DASH_GT] = ACTIONS(1925),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1925),
    [anon_sym_decltype] = ACTIONS(1925),
    [sym_virtual] = ACTIONS(1925),
    [anon_sym_template] = ACTIONS(1925),
    [anon_sym_operator] = ACTIONS(1925),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1927),
    [anon_sym_precise] = ACTIONS(1925),
    [anon_sym_shared] = ACTIONS(1925),
    [anon_sym_groupshared] = ACTIONS(1925),
    [anon_sym_uniform] = ACTIONS(1925),
    [anon_sym_row_major] = ACTIONS(1925),
    [anon_sym_column_major] = ACTIONS(1925),
    [anon_sym_globallycoherent] = ACTIONS(1925),
    [anon_sym_centroid] = ACTIONS(1925),
    [anon_sym_noperspective] = ACTIONS(1925),
    [anon_sym_nointerpolation] = ACTIONS(1925),
    [anon_sym_sample] = ACTIONS(1925),
    [anon_sym_linear] = ACTIONS(1925),
    [anon_sym_snorm] = ACTIONS(1925),
    [anon_sym_unorm] = ACTIONS(1925),
    [anon_sym_point] = ACTIONS(1925),
    [anon_sym_line] = ACTIONS(1925),
    [anon_sym_triangleadj] = ACTIONS(1925),
    [anon_sym_lineadj] = ACTIONS(1925),
    [anon_sym_triangle] = ACTIONS(1925),
  },
  [1139] = {
    [sym_identifier] = ACTIONS(1903),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1905),
    [anon_sym_COMMA] = ACTIONS(1905),
    [anon_sym_RPAREN] = ACTIONS(1905),
    [anon_sym_LPAREN2] = ACTIONS(1905),
    [anon_sym_TILDE] = ACTIONS(1905),
    [anon_sym_DASH] = ACTIONS(1903),
    [anon_sym_PLUS] = ACTIONS(1903),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_SLASH] = ACTIONS(1903),
    [anon_sym_PERCENT] = ACTIONS(1903),
    [anon_sym_PIPE_PIPE] = ACTIONS(1905),
    [anon_sym_AMP_AMP] = ACTIONS(1905),
    [anon_sym_PIPE] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1903),
    [anon_sym_AMP] = ACTIONS(1903),
    [anon_sym_EQ_EQ] = ACTIONS(1905),
    [anon_sym_BANG_EQ] = ACTIONS(1905),
    [anon_sym_GT] = ACTIONS(1903),
    [anon_sym_GT_EQ] = ACTIONS(1905),
    [anon_sym_LT_EQ] = ACTIONS(1903),
    [anon_sym_LT] = ACTIONS(1903),
    [anon_sym_LT_LT] = ACTIONS(1903),
    [anon_sym_GT_GT] = ACTIONS(1903),
    [anon_sym_COLON] = ACTIONS(1903),
    [anon_sym___extension__] = ACTIONS(1903),
    [anon_sym_in] = ACTIONS(1903),
    [anon_sym_out] = ACTIONS(1903),
    [anon_sym_inout] = ACTIONS(1903),
    [anon_sym_extern] = ACTIONS(1903),
    [anon_sym___attribute__] = ACTIONS(1903),
    [anon_sym_COLON_COLON] = ACTIONS(1905),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1905),
    [anon_sym___declspec] = ACTIONS(1903),
    [anon_sym___based] = ACTIONS(1903),
    [anon_sym_LBRACE] = ACTIONS(1905),
    [anon_sym_LBRACK] = ACTIONS(1903),
    [anon_sym_static] = ACTIONS(1903),
    [anon_sym_EQ] = ACTIONS(1903),
    [anon_sym_register] = ACTIONS(1903),
    [anon_sym_inline] = ACTIONS(1903),
    [anon_sym___inline] = ACTIONS(1903),
    [anon_sym___inline__] = ACTIONS(1903),
    [anon_sym___forceinline] = ACTIONS(1903),
    [anon_sym_thread_local] = ACTIONS(1903),
    [anon_sym___thread] = ACTIONS(1903),
    [anon_sym_const] = ACTIONS(1903),
    [anon_sym_constexpr] = ACTIONS(1903),
    [anon_sym_volatile] = ACTIONS(1903),
    [anon_sym_restrict] = ACTIONS(1903),
    [anon_sym___restrict__] = ACTIONS(1903),
    [anon_sym__Atomic] = ACTIONS(1903),
    [anon_sym__Noreturn] = ACTIONS(1903),
    [anon_sym_noreturn] = ACTIONS(1903),
    [anon_sym_mutable] = ACTIONS(1903),
    [anon_sym_constinit] = ACTIONS(1903),
    [anon_sym_consteval] = ACTIONS(1903),
    [anon_sym_alignas] = ACTIONS(1903),
    [anon_sym__Alignas] = ACTIONS(1903),
    [anon_sym_QMARK] = ACTIONS(1905),
    [anon_sym_STAR_EQ] = ACTIONS(1905),
    [anon_sym_SLASH_EQ] = ACTIONS(1905),
    [anon_sym_PERCENT_EQ] = ACTIONS(1905),
    [anon_sym_PLUS_EQ] = ACTIONS(1905),
    [anon_sym_DASH_EQ] = ACTIONS(1905),
    [anon_sym_LT_LT_EQ] = ACTIONS(1905),
    [anon_sym_GT_GT_EQ] = ACTIONS(1905),
    [anon_sym_AMP_EQ] = ACTIONS(1905),
    [anon_sym_CARET_EQ] = ACTIONS(1905),
    [anon_sym_PIPE_EQ] = ACTIONS(1905),
    [anon_sym_LT_EQ_GT] = ACTIONS(1905),
    [anon_sym_or] = ACTIONS(1903),
    [anon_sym_and] = ACTIONS(1903),
    [anon_sym_bitor] = ACTIONS(1903),
    [anon_sym_xor] = ACTIONS(1903),
    [anon_sym_bitand] = ACTIONS(1903),
    [anon_sym_not_eq] = ACTIONS(1903),
    [anon_sym_DASH_DASH] = ACTIONS(1905),
    [anon_sym_PLUS_PLUS] = ACTIONS(1905),
    [anon_sym_DOT] = ACTIONS(1903),
    [anon_sym_DOT_STAR] = ACTIONS(1905),
    [anon_sym_DASH_GT] = ACTIONS(1903),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1903),
    [anon_sym_decltype] = ACTIONS(1903),
    [sym_virtual] = ACTIONS(1903),
    [anon_sym_template] = ACTIONS(1903),
    [anon_sym_operator] = ACTIONS(1903),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1905),
    [anon_sym_precise] = ACTIONS(1903),
    [anon_sym_shared] = ACTIONS(1903),
    [anon_sym_groupshared] = ACTIONS(1903),
    [anon_sym_uniform] = ACTIONS(1903),
    [anon_sym_row_major] = ACTIONS(1903),
    [anon_sym_column_major] = ACTIONS(1903),
    [anon_sym_globallycoherent] = ACTIONS(1903),
    [anon_sym_centroid] = ACTIONS(1903),
    [anon_sym_noperspective] = ACTIONS(1903),
    [anon_sym_nointerpolation] = ACTIONS(1903),
    [anon_sym_sample] = ACTIONS(1903),
    [anon_sym_linear] = ACTIONS(1903),
    [anon_sym_snorm] = ACTIONS(1903),
    [anon_sym_unorm] = ACTIONS(1903),
    [anon_sym_point] = ACTIONS(1903),
    [anon_sym_line] = ACTIONS(1903),
    [anon_sym_triangleadj] = ACTIONS(1903),
    [anon_sym_lineadj] = ACTIONS(1903),
    [anon_sym_triangle] = ACTIONS(1903),
  },
  [1140] = {
    [sym_identifier] = ACTIONS(1895),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1897),
    [anon_sym_COMMA] = ACTIONS(1897),
    [anon_sym_RPAREN] = ACTIONS(1897),
    [anon_sym_LPAREN2] = ACTIONS(1897),
    [anon_sym_TILDE] = ACTIONS(1897),
    [anon_sym_DASH] = ACTIONS(1895),
    [anon_sym_PLUS] = ACTIONS(1895),
    [anon_sym_STAR] = ACTIONS(1895),
    [anon_sym_SLASH] = ACTIONS(1895),
    [anon_sym_PERCENT] = ACTIONS(1895),
    [anon_sym_PIPE_PIPE] = ACTIONS(1897),
    [anon_sym_AMP_AMP] = ACTIONS(1897),
    [anon_sym_PIPE] = ACTIONS(1895),
    [anon_sym_CARET] = ACTIONS(1895),
    [anon_sym_AMP] = ACTIONS(1895),
    [anon_sym_EQ_EQ] = ACTIONS(1897),
    [anon_sym_BANG_EQ] = ACTIONS(1897),
    [anon_sym_GT] = ACTIONS(1895),
    [anon_sym_GT_EQ] = ACTIONS(1897),
    [anon_sym_LT_EQ] = ACTIONS(1895),
    [anon_sym_LT] = ACTIONS(1895),
    [anon_sym_LT_LT] = ACTIONS(1895),
    [anon_sym_GT_GT] = ACTIONS(1895),
    [anon_sym_COLON] = ACTIONS(1895),
    [anon_sym___extension__] = ACTIONS(1895),
    [anon_sym_in] = ACTIONS(1895),
    [anon_sym_out] = ACTIONS(1895),
    [anon_sym_inout] = ACTIONS(1895),
    [anon_sym_extern] = ACTIONS(1895),
    [anon_sym___attribute__] = ACTIONS(1895),
    [anon_sym_COLON_COLON] = ACTIONS(1897),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1897),
    [anon_sym___declspec] = ACTIONS(1895),
    [anon_sym___based] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1897),
    [anon_sym_LBRACK] = ACTIONS(1895),
    [anon_sym_static] = ACTIONS(1895),
    [anon_sym_EQ] = ACTIONS(1895),
    [anon_sym_register] = ACTIONS(1895),
    [anon_sym_inline] = ACTIONS(1895),
    [anon_sym___inline] = ACTIONS(1895),
    [anon_sym___inline__] = ACTIONS(1895),
    [anon_sym___forceinline] = ACTIONS(1895),
    [anon_sym_thread_local] = ACTIONS(1895),
    [anon_sym___thread] = ACTIONS(1895),
    [anon_sym_const] = ACTIONS(1895),
    [anon_sym_constexpr] = ACTIONS(1895),
    [anon_sym_volatile] = ACTIONS(1895),
    [anon_sym_restrict] = ACTIONS(1895),
    [anon_sym___restrict__] = ACTIONS(1895),
    [anon_sym__Atomic] = ACTIONS(1895),
    [anon_sym__Noreturn] = ACTIONS(1895),
    [anon_sym_noreturn] = ACTIONS(1895),
    [anon_sym_mutable] = ACTIONS(1895),
    [anon_sym_constinit] = ACTIONS(1895),
    [anon_sym_consteval] = ACTIONS(1895),
    [anon_sym_alignas] = ACTIONS(1895),
    [anon_sym__Alignas] = ACTIONS(1895),
    [anon_sym_QMARK] = ACTIONS(1897),
    [anon_sym_STAR_EQ] = ACTIONS(1897),
    [anon_sym_SLASH_EQ] = ACTIONS(1897),
    [anon_sym_PERCENT_EQ] = ACTIONS(1897),
    [anon_sym_PLUS_EQ] = ACTIONS(1897),
    [anon_sym_DASH_EQ] = ACTIONS(1897),
    [anon_sym_LT_LT_EQ] = ACTIONS(1897),
    [anon_sym_GT_GT_EQ] = ACTIONS(1897),
    [anon_sym_AMP_EQ] = ACTIONS(1897),
    [anon_sym_CARET_EQ] = ACTIONS(1897),
    [anon_sym_PIPE_EQ] = ACTIONS(1897),
    [anon_sym_LT_EQ_GT] = ACTIONS(1897),
    [anon_sym_or] = ACTIONS(1895),
    [anon_sym_and] = ACTIONS(1895),
    [anon_sym_bitor] = ACTIONS(1895),
    [anon_sym_xor] = ACTIONS(1895),
    [anon_sym_bitand] = ACTIONS(1895),
    [anon_sym_not_eq] = ACTIONS(1895),
    [anon_sym_DASH_DASH] = ACTIONS(1897),
    [anon_sym_PLUS_PLUS] = ACTIONS(1897),
    [anon_sym_DOT] = ACTIONS(1895),
    [anon_sym_DOT_STAR] = ACTIONS(1897),
    [anon_sym_DASH_GT] = ACTIONS(1895),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1895),
    [anon_sym_decltype] = ACTIONS(1895),
    [sym_virtual] = ACTIONS(1895),
    [anon_sym_template] = ACTIONS(1895),
    [anon_sym_operator] = ACTIONS(1895),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1897),
    [anon_sym_precise] = ACTIONS(1895),
    [anon_sym_shared] = ACTIONS(1895),
    [anon_sym_groupshared] = ACTIONS(1895),
    [anon_sym_uniform] = ACTIONS(1895),
    [anon_sym_row_major] = ACTIONS(1895),
    [anon_sym_column_major] = ACTIONS(1895),
    [anon_sym_globallycoherent] = ACTIONS(1895),
    [anon_sym_centroid] = ACTIONS(1895),
    [anon_sym_noperspective] = ACTIONS(1895),
    [anon_sym_nointerpolation] = ACTIONS(1895),
    [anon_sym_sample] = ACTIONS(1895),
    [anon_sym_linear] = ACTIONS(1895),
    [anon_sym_snorm] = ACTIONS(1895),
    [anon_sym_unorm] = ACTIONS(1895),
    [anon_sym_point] = ACTIONS(1895),
    [anon_sym_line] = ACTIONS(1895),
    [anon_sym_triangleadj] = ACTIONS(1895),
    [anon_sym_lineadj] = ACTIONS(1895),
    [anon_sym_triangle] = ACTIONS(1895),
  },
  [1141] = {
    [sym_identifier] = ACTIONS(1959),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4060),
    [anon_sym_COMMA] = ACTIONS(4060),
    [anon_sym_RPAREN] = ACTIONS(4060),
    [anon_sym_LPAREN2] = ACTIONS(4060),
    [anon_sym_TILDE] = ACTIONS(1961),
    [anon_sym_DASH] = ACTIONS(4063),
    [anon_sym_PLUS] = ACTIONS(4063),
    [anon_sym_STAR] = ACTIONS(4065),
    [anon_sym_SLASH] = ACTIONS(4063),
    [anon_sym_PERCENT] = ACTIONS(4063),
    [anon_sym_PIPE_PIPE] = ACTIONS(4058),
    [anon_sym_AMP_AMP] = ACTIONS(4060),
    [anon_sym_PIPE] = ACTIONS(4063),
    [anon_sym_CARET] = ACTIONS(4063),
    [anon_sym_AMP] = ACTIONS(4065),
    [anon_sym_EQ_EQ] = ACTIONS(4058),
    [anon_sym_BANG_EQ] = ACTIONS(4058),
    [anon_sym_GT] = ACTIONS(4063),
    [anon_sym_GT_EQ] = ACTIONS(4058),
    [anon_sym_LT_EQ] = ACTIONS(4063),
    [anon_sym_LT] = ACTIONS(4063),
    [anon_sym_LT_LT] = ACTIONS(4063),
    [anon_sym_GT_GT] = ACTIONS(4063),
    [anon_sym_COLON] = ACTIONS(1959),
    [anon_sym___extension__] = ACTIONS(1959),
    [anon_sym_in] = ACTIONS(1959),
    [anon_sym_out] = ACTIONS(1959),
    [anon_sym_inout] = ACTIONS(1959),
    [anon_sym_extern] = ACTIONS(1959),
    [anon_sym___attribute__] = ACTIONS(1959),
    [anon_sym_COLON_COLON] = ACTIONS(1961),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1961),
    [anon_sym___declspec] = ACTIONS(1959),
    [anon_sym___based] = ACTIONS(1959),
    [anon_sym_LBRACE] = ACTIONS(1961),
    [anon_sym_LBRACK] = ACTIONS(4065),
    [anon_sym_static] = ACTIONS(1959),
    [anon_sym_EQ] = ACTIONS(4065),
    [anon_sym_register] = ACTIONS(1959),
    [anon_sym_inline] = ACTIONS(1959),
    [anon_sym___inline] = ACTIONS(1959),
    [anon_sym___inline__] = ACTIONS(1959),
    [anon_sym___forceinline] = ACTIONS(1959),
    [anon_sym_thread_local] = ACTIONS(1959),
    [anon_sym___thread] = ACTIONS(1959),
    [anon_sym_const] = ACTIONS(1959),
    [anon_sym_constexpr] = ACTIONS(1959),
    [anon_sym_volatile] = ACTIONS(1959),
    [anon_sym_restrict] = ACTIONS(1959),
    [anon_sym___restrict__] = ACTIONS(1959),
    [anon_sym__Atomic] = ACTIONS(1959),
    [anon_sym__Noreturn] = ACTIONS(1959),
    [anon_sym_noreturn] = ACTIONS(1959),
    [anon_sym_mutable] = ACTIONS(1959),
    [anon_sym_constinit] = ACTIONS(1959),
    [anon_sym_consteval] = ACTIONS(1959),
    [anon_sym_alignas] = ACTIONS(1959),
    [anon_sym__Alignas] = ACTIONS(1959),
    [anon_sym_QMARK] = ACTIONS(4058),
    [anon_sym_STAR_EQ] = ACTIONS(4058),
    [anon_sym_SLASH_EQ] = ACTIONS(4058),
    [anon_sym_PERCENT_EQ] = ACTIONS(4058),
    [anon_sym_PLUS_EQ] = ACTIONS(4058),
    [anon_sym_DASH_EQ] = ACTIONS(4058),
    [anon_sym_LT_LT_EQ] = ACTIONS(4058),
    [anon_sym_GT_GT_EQ] = ACTIONS(4058),
    [anon_sym_AMP_EQ] = ACTIONS(4058),
    [anon_sym_CARET_EQ] = ACTIONS(4058),
    [anon_sym_PIPE_EQ] = ACTIONS(4058),
    [anon_sym_LT_EQ_GT] = ACTIONS(4058),
    [anon_sym_or] = ACTIONS(4063),
    [anon_sym_and] = ACTIONS(4063),
    [anon_sym_bitor] = ACTIONS(4063),
    [anon_sym_xor] = ACTIONS(4063),
    [anon_sym_bitand] = ACTIONS(4063),
    [anon_sym_not_eq] = ACTIONS(4063),
    [anon_sym_DASH_DASH] = ACTIONS(4058),
    [anon_sym_PLUS_PLUS] = ACTIONS(4058),
    [anon_sym_DOT] = ACTIONS(4063),
    [anon_sym_DOT_STAR] = ACTIONS(4058),
    [anon_sym_DASH_GT] = ACTIONS(4063),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1959),
    [anon_sym_decltype] = ACTIONS(1959),
    [sym_virtual] = ACTIONS(1959),
    [anon_sym_template] = ACTIONS(1959),
    [anon_sym_operator] = ACTIONS(1959),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4058),
    [anon_sym_precise] = ACTIONS(1959),
    [anon_sym_shared] = ACTIONS(1959),
    [anon_sym_groupshared] = ACTIONS(1959),
    [anon_sym_uniform] = ACTIONS(1959),
    [anon_sym_row_major] = ACTIONS(1959),
    [anon_sym_column_major] = ACTIONS(1959),
    [anon_sym_globallycoherent] = ACTIONS(1959),
    [anon_sym_centroid] = ACTIONS(1959),
    [anon_sym_noperspective] = ACTIONS(1959),
    [anon_sym_nointerpolation] = ACTIONS(1959),
    [anon_sym_sample] = ACTIONS(1959),
    [anon_sym_linear] = ACTIONS(1959),
    [anon_sym_snorm] = ACTIONS(1959),
    [anon_sym_unorm] = ACTIONS(1959),
    [anon_sym_point] = ACTIONS(1959),
    [anon_sym_line] = ACTIONS(1959),
    [anon_sym_triangleadj] = ACTIONS(1959),
    [anon_sym_lineadj] = ACTIONS(1959),
    [anon_sym_triangle] = ACTIONS(1959),
  },
  [1142] = {
    [sym_identifier] = ACTIONS(1891),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1893),
    [anon_sym_COMMA] = ACTIONS(1893),
    [anon_sym_RPAREN] = ACTIONS(1893),
    [anon_sym_LPAREN2] = ACTIONS(1893),
    [anon_sym_TILDE] = ACTIONS(1893),
    [anon_sym_DASH] = ACTIONS(1891),
    [anon_sym_PLUS] = ACTIONS(1891),
    [anon_sym_STAR] = ACTIONS(1891),
    [anon_sym_SLASH] = ACTIONS(1891),
    [anon_sym_PERCENT] = ACTIONS(1891),
    [anon_sym_PIPE_PIPE] = ACTIONS(1893),
    [anon_sym_AMP_AMP] = ACTIONS(1893),
    [anon_sym_PIPE] = ACTIONS(1891),
    [anon_sym_CARET] = ACTIONS(1891),
    [anon_sym_AMP] = ACTIONS(1891),
    [anon_sym_EQ_EQ] = ACTIONS(1893),
    [anon_sym_BANG_EQ] = ACTIONS(1893),
    [anon_sym_GT] = ACTIONS(1891),
    [anon_sym_GT_EQ] = ACTIONS(1893),
    [anon_sym_LT_EQ] = ACTIONS(1891),
    [anon_sym_LT] = ACTIONS(1891),
    [anon_sym_LT_LT] = ACTIONS(1891),
    [anon_sym_GT_GT] = ACTIONS(1891),
    [anon_sym_COLON] = ACTIONS(1891),
    [anon_sym___extension__] = ACTIONS(1891),
    [anon_sym_in] = ACTIONS(1891),
    [anon_sym_out] = ACTIONS(1891),
    [anon_sym_inout] = ACTIONS(1891),
    [anon_sym_extern] = ACTIONS(1891),
    [anon_sym___attribute__] = ACTIONS(1891),
    [anon_sym_COLON_COLON] = ACTIONS(1893),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1893),
    [anon_sym___declspec] = ACTIONS(1891),
    [anon_sym___based] = ACTIONS(1891),
    [anon_sym_LBRACE] = ACTIONS(1893),
    [anon_sym_LBRACK] = ACTIONS(1891),
    [anon_sym_static] = ACTIONS(1891),
    [anon_sym_EQ] = ACTIONS(1891),
    [anon_sym_register] = ACTIONS(1891),
    [anon_sym_inline] = ACTIONS(1891),
    [anon_sym___inline] = ACTIONS(1891),
    [anon_sym___inline__] = ACTIONS(1891),
    [anon_sym___forceinline] = ACTIONS(1891),
    [anon_sym_thread_local] = ACTIONS(1891),
    [anon_sym___thread] = ACTIONS(1891),
    [anon_sym_const] = ACTIONS(1891),
    [anon_sym_constexpr] = ACTIONS(1891),
    [anon_sym_volatile] = ACTIONS(1891),
    [anon_sym_restrict] = ACTIONS(1891),
    [anon_sym___restrict__] = ACTIONS(1891),
    [anon_sym__Atomic] = ACTIONS(1891),
    [anon_sym__Noreturn] = ACTIONS(1891),
    [anon_sym_noreturn] = ACTIONS(1891),
    [anon_sym_mutable] = ACTIONS(1891),
    [anon_sym_constinit] = ACTIONS(1891),
    [anon_sym_consteval] = ACTIONS(1891),
    [anon_sym_alignas] = ACTIONS(1891),
    [anon_sym__Alignas] = ACTIONS(1891),
    [anon_sym_QMARK] = ACTIONS(1893),
    [anon_sym_STAR_EQ] = ACTIONS(1893),
    [anon_sym_SLASH_EQ] = ACTIONS(1893),
    [anon_sym_PERCENT_EQ] = ACTIONS(1893),
    [anon_sym_PLUS_EQ] = ACTIONS(1893),
    [anon_sym_DASH_EQ] = ACTIONS(1893),
    [anon_sym_LT_LT_EQ] = ACTIONS(1893),
    [anon_sym_GT_GT_EQ] = ACTIONS(1893),
    [anon_sym_AMP_EQ] = ACTIONS(1893),
    [anon_sym_CARET_EQ] = ACTIONS(1893),
    [anon_sym_PIPE_EQ] = ACTIONS(1893),
    [anon_sym_LT_EQ_GT] = ACTIONS(1893),
    [anon_sym_or] = ACTIONS(1891),
    [anon_sym_and] = ACTIONS(1891),
    [anon_sym_bitor] = ACTIONS(1891),
    [anon_sym_xor] = ACTIONS(1891),
    [anon_sym_bitand] = ACTIONS(1891),
    [anon_sym_not_eq] = ACTIONS(1891),
    [anon_sym_DASH_DASH] = ACTIONS(1893),
    [anon_sym_PLUS_PLUS] = ACTIONS(1893),
    [anon_sym_DOT] = ACTIONS(1891),
    [anon_sym_DOT_STAR] = ACTIONS(1893),
    [anon_sym_DASH_GT] = ACTIONS(1891),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1891),
    [anon_sym_decltype] = ACTIONS(1891),
    [sym_virtual] = ACTIONS(1891),
    [anon_sym_template] = ACTIONS(1891),
    [anon_sym_operator] = ACTIONS(1891),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1893),
    [anon_sym_precise] = ACTIONS(1891),
    [anon_sym_shared] = ACTIONS(1891),
    [anon_sym_groupshared] = ACTIONS(1891),
    [anon_sym_uniform] = ACTIONS(1891),
    [anon_sym_row_major] = ACTIONS(1891),
    [anon_sym_column_major] = ACTIONS(1891),
    [anon_sym_globallycoherent] = ACTIONS(1891),
    [anon_sym_centroid] = ACTIONS(1891),
    [anon_sym_noperspective] = ACTIONS(1891),
    [anon_sym_nointerpolation] = ACTIONS(1891),
    [anon_sym_sample] = ACTIONS(1891),
    [anon_sym_linear] = ACTIONS(1891),
    [anon_sym_snorm] = ACTIONS(1891),
    [anon_sym_unorm] = ACTIONS(1891),
    [anon_sym_point] = ACTIONS(1891),
    [anon_sym_line] = ACTIONS(1891),
    [anon_sym_triangleadj] = ACTIONS(1891),
    [anon_sym_lineadj] = ACTIONS(1891),
    [anon_sym_triangle] = ACTIONS(1891),
  },
  [1143] = {
    [sym_identifier] = ACTIONS(1917),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1919),
    [anon_sym_COMMA] = ACTIONS(1919),
    [anon_sym_RPAREN] = ACTIONS(1919),
    [anon_sym_LPAREN2] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1917),
    [anon_sym_SLASH] = ACTIONS(1917),
    [anon_sym_PERCENT] = ACTIONS(1917),
    [anon_sym_PIPE_PIPE] = ACTIONS(1919),
    [anon_sym_AMP_AMP] = ACTIONS(1919),
    [anon_sym_PIPE] = ACTIONS(1917),
    [anon_sym_CARET] = ACTIONS(1917),
    [anon_sym_AMP] = ACTIONS(1917),
    [anon_sym_EQ_EQ] = ACTIONS(1919),
    [anon_sym_BANG_EQ] = ACTIONS(1919),
    [anon_sym_GT] = ACTIONS(1917),
    [anon_sym_GT_EQ] = ACTIONS(1919),
    [anon_sym_LT_EQ] = ACTIONS(1917),
    [anon_sym_LT] = ACTIONS(1917),
    [anon_sym_LT_LT] = ACTIONS(1917),
    [anon_sym_GT_GT] = ACTIONS(1917),
    [anon_sym_COLON] = ACTIONS(1917),
    [anon_sym___extension__] = ACTIONS(1917),
    [anon_sym_in] = ACTIONS(1917),
    [anon_sym_out] = ACTIONS(1917),
    [anon_sym_inout] = ACTIONS(1917),
    [anon_sym_extern] = ACTIONS(1917),
    [anon_sym___attribute__] = ACTIONS(1917),
    [anon_sym_COLON_COLON] = ACTIONS(1919),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1919),
    [anon_sym___declspec] = ACTIONS(1917),
    [anon_sym___based] = ACTIONS(1917),
    [anon_sym_LBRACE] = ACTIONS(1919),
    [anon_sym_LBRACK] = ACTIONS(1917),
    [anon_sym_static] = ACTIONS(1917),
    [anon_sym_EQ] = ACTIONS(1917),
    [anon_sym_register] = ACTIONS(1917),
    [anon_sym_inline] = ACTIONS(1917),
    [anon_sym___inline] = ACTIONS(1917),
    [anon_sym___inline__] = ACTIONS(1917),
    [anon_sym___forceinline] = ACTIONS(1917),
    [anon_sym_thread_local] = ACTIONS(1917),
    [anon_sym___thread] = ACTIONS(1917),
    [anon_sym_const] = ACTIONS(1917),
    [anon_sym_constexpr] = ACTIONS(1917),
    [anon_sym_volatile] = ACTIONS(1917),
    [anon_sym_restrict] = ACTIONS(1917),
    [anon_sym___restrict__] = ACTIONS(1917),
    [anon_sym__Atomic] = ACTIONS(1917),
    [anon_sym__Noreturn] = ACTIONS(1917),
    [anon_sym_noreturn] = ACTIONS(1917),
    [anon_sym_mutable] = ACTIONS(1917),
    [anon_sym_constinit] = ACTIONS(1917),
    [anon_sym_consteval] = ACTIONS(1917),
    [anon_sym_alignas] = ACTIONS(1917),
    [anon_sym__Alignas] = ACTIONS(1917),
    [anon_sym_QMARK] = ACTIONS(1919),
    [anon_sym_STAR_EQ] = ACTIONS(1919),
    [anon_sym_SLASH_EQ] = ACTIONS(1919),
    [anon_sym_PERCENT_EQ] = ACTIONS(1919),
    [anon_sym_PLUS_EQ] = ACTIONS(1919),
    [anon_sym_DASH_EQ] = ACTIONS(1919),
    [anon_sym_LT_LT_EQ] = ACTIONS(1919),
    [anon_sym_GT_GT_EQ] = ACTIONS(1919),
    [anon_sym_AMP_EQ] = ACTIONS(1919),
    [anon_sym_CARET_EQ] = ACTIONS(1919),
    [anon_sym_PIPE_EQ] = ACTIONS(1919),
    [anon_sym_LT_EQ_GT] = ACTIONS(1919),
    [anon_sym_or] = ACTIONS(1917),
    [anon_sym_and] = ACTIONS(1917),
    [anon_sym_bitor] = ACTIONS(1917),
    [anon_sym_xor] = ACTIONS(1917),
    [anon_sym_bitand] = ACTIONS(1917),
    [anon_sym_not_eq] = ACTIONS(1917),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DOT] = ACTIONS(1917),
    [anon_sym_DOT_STAR] = ACTIONS(1919),
    [anon_sym_DASH_GT] = ACTIONS(1917),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1917),
    [anon_sym_decltype] = ACTIONS(1917),
    [sym_virtual] = ACTIONS(1917),
    [anon_sym_template] = ACTIONS(1917),
    [anon_sym_operator] = ACTIONS(1917),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1919),
    [anon_sym_precise] = ACTIONS(1917),
    [anon_sym_shared] = ACTIONS(1917),
    [anon_sym_groupshared] = ACTIONS(1917),
    [anon_sym_uniform] = ACTIONS(1917),
    [anon_sym_row_major] = ACTIONS(1917),
    [anon_sym_column_major] = ACTIONS(1917),
    [anon_sym_globallycoherent] = ACTIONS(1917),
    [anon_sym_centroid] = ACTIONS(1917),
    [anon_sym_noperspective] = ACTIONS(1917),
    [anon_sym_nointerpolation] = ACTIONS(1917),
    [anon_sym_sample] = ACTIONS(1917),
    [anon_sym_linear] = ACTIONS(1917),
    [anon_sym_snorm] = ACTIONS(1917),
    [anon_sym_unorm] = ACTIONS(1917),
    [anon_sym_point] = ACTIONS(1917),
    [anon_sym_line] = ACTIONS(1917),
    [anon_sym_triangleadj] = ACTIONS(1917),
    [anon_sym_lineadj] = ACTIONS(1917),
    [anon_sym_triangle] = ACTIONS(1917),
  },
  [1144] = {
    [sym_identifier] = ACTIONS(1887),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1889),
    [anon_sym_COMMA] = ACTIONS(1889),
    [anon_sym_RPAREN] = ACTIONS(1889),
    [anon_sym_LPAREN2] = ACTIONS(1889),
    [anon_sym_TILDE] = ACTIONS(1889),
    [anon_sym_DASH] = ACTIONS(1887),
    [anon_sym_PLUS] = ACTIONS(1887),
    [anon_sym_STAR] = ACTIONS(1887),
    [anon_sym_SLASH] = ACTIONS(1887),
    [anon_sym_PERCENT] = ACTIONS(1887),
    [anon_sym_PIPE_PIPE] = ACTIONS(1889),
    [anon_sym_AMP_AMP] = ACTIONS(1889),
    [anon_sym_PIPE] = ACTIONS(1887),
    [anon_sym_CARET] = ACTIONS(1887),
    [anon_sym_AMP] = ACTIONS(1887),
    [anon_sym_EQ_EQ] = ACTIONS(1889),
    [anon_sym_BANG_EQ] = ACTIONS(1889),
    [anon_sym_GT] = ACTIONS(1887),
    [anon_sym_GT_EQ] = ACTIONS(1889),
    [anon_sym_LT_EQ] = ACTIONS(1887),
    [anon_sym_LT] = ACTIONS(1887),
    [anon_sym_LT_LT] = ACTIONS(1887),
    [anon_sym_GT_GT] = ACTIONS(1887),
    [anon_sym_COLON] = ACTIONS(1887),
    [anon_sym___extension__] = ACTIONS(1887),
    [anon_sym_in] = ACTIONS(1887),
    [anon_sym_out] = ACTIONS(1887),
    [anon_sym_inout] = ACTIONS(1887),
    [anon_sym_extern] = ACTIONS(1887),
    [anon_sym___attribute__] = ACTIONS(1887),
    [anon_sym_COLON_COLON] = ACTIONS(1889),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1889),
    [anon_sym___declspec] = ACTIONS(1887),
    [anon_sym___based] = ACTIONS(1887),
    [anon_sym_LBRACE] = ACTIONS(1889),
    [anon_sym_LBRACK] = ACTIONS(1887),
    [anon_sym_static] = ACTIONS(1887),
    [anon_sym_EQ] = ACTIONS(1887),
    [anon_sym_register] = ACTIONS(1887),
    [anon_sym_inline] = ACTIONS(1887),
    [anon_sym___inline] = ACTIONS(1887),
    [anon_sym___inline__] = ACTIONS(1887),
    [anon_sym___forceinline] = ACTIONS(1887),
    [anon_sym_thread_local] = ACTIONS(1887),
    [anon_sym___thread] = ACTIONS(1887),
    [anon_sym_const] = ACTIONS(1887),
    [anon_sym_constexpr] = ACTIONS(1887),
    [anon_sym_volatile] = ACTIONS(1887),
    [anon_sym_restrict] = ACTIONS(1887),
    [anon_sym___restrict__] = ACTIONS(1887),
    [anon_sym__Atomic] = ACTIONS(1887),
    [anon_sym__Noreturn] = ACTIONS(1887),
    [anon_sym_noreturn] = ACTIONS(1887),
    [anon_sym_mutable] = ACTIONS(1887),
    [anon_sym_constinit] = ACTIONS(1887),
    [anon_sym_consteval] = ACTIONS(1887),
    [anon_sym_alignas] = ACTIONS(1887),
    [anon_sym__Alignas] = ACTIONS(1887),
    [anon_sym_QMARK] = ACTIONS(1889),
    [anon_sym_STAR_EQ] = ACTIONS(1889),
    [anon_sym_SLASH_EQ] = ACTIONS(1889),
    [anon_sym_PERCENT_EQ] = ACTIONS(1889),
    [anon_sym_PLUS_EQ] = ACTIONS(1889),
    [anon_sym_DASH_EQ] = ACTIONS(1889),
    [anon_sym_LT_LT_EQ] = ACTIONS(1889),
    [anon_sym_GT_GT_EQ] = ACTIONS(1889),
    [anon_sym_AMP_EQ] = ACTIONS(1889),
    [anon_sym_CARET_EQ] = ACTIONS(1889),
    [anon_sym_PIPE_EQ] = ACTIONS(1889),
    [anon_sym_LT_EQ_GT] = ACTIONS(1889),
    [anon_sym_or] = ACTIONS(1887),
    [anon_sym_and] = ACTIONS(1887),
    [anon_sym_bitor] = ACTIONS(1887),
    [anon_sym_xor] = ACTIONS(1887),
    [anon_sym_bitand] = ACTIONS(1887),
    [anon_sym_not_eq] = ACTIONS(1887),
    [anon_sym_DASH_DASH] = ACTIONS(1889),
    [anon_sym_PLUS_PLUS] = ACTIONS(1889),
    [anon_sym_DOT] = ACTIONS(1887),
    [anon_sym_DOT_STAR] = ACTIONS(1889),
    [anon_sym_DASH_GT] = ACTIONS(1887),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1887),
    [anon_sym_decltype] = ACTIONS(1887),
    [sym_virtual] = ACTIONS(1887),
    [anon_sym_template] = ACTIONS(1887),
    [anon_sym_operator] = ACTIONS(1887),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1889),
    [anon_sym_precise] = ACTIONS(1887),
    [anon_sym_shared] = ACTIONS(1887),
    [anon_sym_groupshared] = ACTIONS(1887),
    [anon_sym_uniform] = ACTIONS(1887),
    [anon_sym_row_major] = ACTIONS(1887),
    [anon_sym_column_major] = ACTIONS(1887),
    [anon_sym_globallycoherent] = ACTIONS(1887),
    [anon_sym_centroid] = ACTIONS(1887),
    [anon_sym_noperspective] = ACTIONS(1887),
    [anon_sym_nointerpolation] = ACTIONS(1887),
    [anon_sym_sample] = ACTIONS(1887),
    [anon_sym_linear] = ACTIONS(1887),
    [anon_sym_snorm] = ACTIONS(1887),
    [anon_sym_unorm] = ACTIONS(1887),
    [anon_sym_point] = ACTIONS(1887),
    [anon_sym_line] = ACTIONS(1887),
    [anon_sym_triangleadj] = ACTIONS(1887),
    [anon_sym_lineadj] = ACTIONS(1887),
    [anon_sym_triangle] = ACTIONS(1887),
  },
  [1145] = {
    [sym_expression_statement] = STATE(3033),
    [sym_expression] = STATE(4584),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8015),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_type_requirement] = STATE(1170),
    [sym_compound_requirement] = STATE(1170),
    [sym__requirement] = STATE(1170),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_requirement_seq_repeat1] = STATE(1170),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4199),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(4201),
    [anon_sym_RBRACE] = ACTIONS(4203),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_typename] = ACTIONS(4205),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1146] = {
    [sym_expression] = STATE(4420),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7085),
    [sym_initializer_pair] = STATE(7085),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [sym_identifier] = ACTIONS(4207),
    [anon_sym_COMMA] = ACTIONS(167),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_RBRACE] = ACTIONS(4209),
    [anon_sym_LBRACK] = ACTIONS(4211),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1147] = {
    [sym_expression_statement] = STATE(3033),
    [sym_expression] = STATE(4584),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8015),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_type_requirement] = STATE(1149),
    [sym_compound_requirement] = STATE(1149),
    [sym__requirement] = STATE(1149),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_requirement_seq_repeat1] = STATE(1149),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4199),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(4201),
    [anon_sym_RBRACE] = ACTIONS(4213),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_typename] = ACTIONS(4205),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1148] = {
    [sym_expression] = STATE(4375),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7015),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7681),
    [sym_initializer_pair] = STATE(7681),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [sym_identifier] = ACTIONS(4207),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_RBRACE] = ACTIONS(4215),
    [anon_sym_LBRACK] = ACTIONS(4211),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1149] = {
    [sym_expression_statement] = STATE(3033),
    [sym_expression] = STATE(4584),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8015),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_type_requirement] = STATE(1170),
    [sym_compound_requirement] = STATE(1170),
    [sym__requirement] = STATE(1170),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_requirement_seq_repeat1] = STATE(1170),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4199),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(4201),
    [anon_sym_RBRACE] = ACTIONS(4217),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_typename] = ACTIONS(4205),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1150] = {
    [sym_expression_statement] = STATE(3033),
    [sym_expression] = STATE(4584),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8015),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_type_requirement] = STATE(1154),
    [sym_compound_requirement] = STATE(1154),
    [sym__requirement] = STATE(1154),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_requirement_seq_repeat1] = STATE(1154),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4199),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(4201),
    [anon_sym_RBRACE] = ACTIONS(4219),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_typename] = ACTIONS(4205),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1151] = {
    [sym_expression] = STATE(4411),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7125),
    [sym_initializer_pair] = STATE(7125),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [sym_identifier] = ACTIONS(4207),
    [anon_sym_COMMA] = ACTIONS(4221),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_RBRACE] = ACTIONS(4223),
    [anon_sym_LBRACK] = ACTIONS(4211),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1152] = {
    [sym_expression] = STATE(4317),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7430),
    [sym_initializer_pair] = STATE(7430),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [sym_identifier] = ACTIONS(4207),
    [anon_sym_COMMA] = ACTIONS(4225),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_RBRACE] = ACTIONS(4227),
    [anon_sym_LBRACK] = ACTIONS(4211),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1153] = {
    [sym_expression_statement] = STATE(3033),
    [sym_expression] = STATE(4584),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8015),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_type_requirement] = STATE(1156),
    [sym_compound_requirement] = STATE(1156),
    [sym__requirement] = STATE(1156),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_requirement_seq_repeat1] = STATE(1156),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4199),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(4201),
    [anon_sym_RBRACE] = ACTIONS(4229),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_typename] = ACTIONS(4205),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1154] = {
    [sym_expression_statement] = STATE(3033),
    [sym_expression] = STATE(4584),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8015),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_type_requirement] = STATE(1170),
    [sym_compound_requirement] = STATE(1170),
    [sym__requirement] = STATE(1170),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_requirement_seq_repeat1] = STATE(1170),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4199),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(4201),
    [anon_sym_RBRACE] = ACTIONS(4231),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_typename] = ACTIONS(4205),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1155] = {
    [sym_expression_statement] = STATE(3033),
    [sym_expression] = STATE(4584),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8015),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_type_requirement] = STATE(1145),
    [sym_compound_requirement] = STATE(1145),
    [sym__requirement] = STATE(1145),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_requirement_seq_repeat1] = STATE(1145),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4199),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(4201),
    [anon_sym_RBRACE] = ACTIONS(4233),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_typename] = ACTIONS(4205),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1156] = {
    [sym_expression_statement] = STATE(3033),
    [sym_expression] = STATE(4584),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8015),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_type_requirement] = STATE(1170),
    [sym_compound_requirement] = STATE(1170),
    [sym__requirement] = STATE(1170),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_requirement_seq_repeat1] = STATE(1170),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4199),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(4201),
    [anon_sym_RBRACE] = ACTIONS(4235),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_typename] = ACTIONS(4205),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1157] = {
    [sym_expression] = STATE(4367),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7370),
    [sym_initializer_pair] = STATE(7370),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [sym_identifier] = ACTIONS(4207),
    [anon_sym_COMMA] = ACTIONS(4237),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_RBRACE] = ACTIONS(4239),
    [anon_sym_LBRACK] = ACTIONS(4211),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1158] = {
    [sym_expression_statement] = STATE(3033),
    [sym_expression] = STATE(4584),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8015),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_type_requirement] = STATE(1164),
    [sym_compound_requirement] = STATE(1164),
    [sym__requirement] = STATE(1164),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_requirement_seq_repeat1] = STATE(1164),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4199),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(4201),
    [anon_sym_RBRACE] = ACTIONS(4241),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_typename] = ACTIONS(4205),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1159] = {
    [sym_expression_statement] = STATE(3033),
    [sym_expression] = STATE(4584),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8015),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_type_requirement] = STATE(1163),
    [sym_compound_requirement] = STATE(1163),
    [sym__requirement] = STATE(1163),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_requirement_seq_repeat1] = STATE(1163),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4199),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(4201),
    [anon_sym_RBRACE] = ACTIONS(4243),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_typename] = ACTIONS(4205),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1160] = {
    [sym_expression] = STATE(4345),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7434),
    [sym_initializer_pair] = STATE(7434),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [sym_identifier] = ACTIONS(4207),
    [anon_sym_COMMA] = ACTIONS(4245),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_RBRACE] = ACTIONS(4247),
    [anon_sym_LBRACK] = ACTIONS(4211),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1161] = {
    [sym_expression] = STATE(4346),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7109),
    [sym_initializer_pair] = STATE(7109),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [sym_identifier] = ACTIONS(4207),
    [anon_sym_COMMA] = ACTIONS(4249),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_RBRACE] = ACTIONS(4251),
    [anon_sym_LBRACK] = ACTIONS(4211),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1162] = {
    [sym_expression_statement] = STATE(3033),
    [sym_expression] = STATE(4584),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8015),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_type_requirement] = STATE(1166),
    [sym_compound_requirement] = STATE(1166),
    [sym__requirement] = STATE(1166),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_requirement_seq_repeat1] = STATE(1166),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4199),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(4201),
    [anon_sym_RBRACE] = ACTIONS(4253),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_typename] = ACTIONS(4205),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1163] = {
    [sym_expression_statement] = STATE(3033),
    [sym_expression] = STATE(4584),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8015),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_type_requirement] = STATE(1170),
    [sym_compound_requirement] = STATE(1170),
    [sym__requirement] = STATE(1170),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_requirement_seq_repeat1] = STATE(1170),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4199),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(4201),
    [anon_sym_RBRACE] = ACTIONS(4255),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_typename] = ACTIONS(4205),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1164] = {
    [sym_expression_statement] = STATE(3033),
    [sym_expression] = STATE(4584),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8015),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_type_requirement] = STATE(1170),
    [sym_compound_requirement] = STATE(1170),
    [sym__requirement] = STATE(1170),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_requirement_seq_repeat1] = STATE(1170),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4199),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(4201),
    [anon_sym_RBRACE] = ACTIONS(4257),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_typename] = ACTIONS(4205),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1165] = {
    [sym_expression_statement] = STATE(3033),
    [sym_expression] = STATE(4584),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8015),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_type_requirement] = STATE(1170),
    [sym_compound_requirement] = STATE(1170),
    [sym__requirement] = STATE(1170),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_requirement_seq_repeat1] = STATE(1170),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4199),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(4201),
    [anon_sym_RBRACE] = ACTIONS(4259),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_typename] = ACTIONS(4205),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1166] = {
    [sym_expression_statement] = STATE(3033),
    [sym_expression] = STATE(4584),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8015),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_type_requirement] = STATE(1170),
    [sym_compound_requirement] = STATE(1170),
    [sym__requirement] = STATE(1170),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_requirement_seq_repeat1] = STATE(1170),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4199),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(4201),
    [anon_sym_RBRACE] = ACTIONS(4261),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_typename] = ACTIONS(4205),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1167] = {
    [sym_expression_statement] = STATE(3033),
    [sym_expression] = STATE(4584),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8015),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_type_requirement] = STATE(1168),
    [sym_compound_requirement] = STATE(1168),
    [sym__requirement] = STATE(1168),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_requirement_seq_repeat1] = STATE(1168),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4199),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(4201),
    [anon_sym_RBRACE] = ACTIONS(4263),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_typename] = ACTIONS(4205),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1168] = {
    [sym_expression_statement] = STATE(3033),
    [sym_expression] = STATE(4584),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8015),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_type_requirement] = STATE(1170),
    [sym_compound_requirement] = STATE(1170),
    [sym__requirement] = STATE(1170),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_requirement_seq_repeat1] = STATE(1170),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4199),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(4201),
    [anon_sym_RBRACE] = ACTIONS(4265),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_typename] = ACTIONS(4205),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1169] = {
    [sym_expression_statement] = STATE(3033),
    [sym_expression] = STATE(4584),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8015),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_type_requirement] = STATE(1165),
    [sym_compound_requirement] = STATE(1165),
    [sym__requirement] = STATE(1165),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_requirement_seq_repeat1] = STATE(1165),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4199),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(4201),
    [anon_sym_RBRACE] = ACTIONS(4267),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_typename] = ACTIONS(4205),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1170] = {
    [sym_expression_statement] = STATE(3033),
    [sym_expression] = STATE(4584),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8015),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_type_requirement] = STATE(1170),
    [sym_compound_requirement] = STATE(1170),
    [sym__requirement] = STATE(1170),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_requirement_seq_repeat1] = STATE(1170),
    [sym_identifier] = ACTIONS(4269),
    [anon_sym_LPAREN2] = ACTIONS(4272),
    [anon_sym_BANG] = ACTIONS(4275),
    [anon_sym_TILDE] = ACTIONS(4275),
    [anon_sym_DASH] = ACTIONS(4278),
    [anon_sym_PLUS] = ACTIONS(4278),
    [anon_sym_STAR] = ACTIONS(4281),
    [anon_sym_AMP] = ACTIONS(4281),
    [anon_sym_SEMI] = ACTIONS(4284),
    [anon_sym_COLON_COLON] = ACTIONS(4287),
    [anon_sym_LBRACE] = ACTIONS(4290),
    [anon_sym_RBRACE] = ACTIONS(4293),
    [anon_sym_LBRACK] = ACTIONS(4295),
    [sym_primitive_type] = ACTIONS(4298),
    [anon_sym_not] = ACTIONS(4278),
    [anon_sym_compl] = ACTIONS(4278),
    [anon_sym_DASH_DASH] = ACTIONS(4301),
    [anon_sym_PLUS_PLUS] = ACTIONS(4301),
    [anon_sym_sizeof] = ACTIONS(4304),
    [anon_sym___alignof__] = ACTIONS(4307),
    [anon_sym___alignof] = ACTIONS(4307),
    [anon_sym__alignof] = ACTIONS(4307),
    [anon_sym_alignof] = ACTIONS(4307),
    [anon_sym__Alignof] = ACTIONS(4307),
    [anon_sym_offsetof] = ACTIONS(4310),
    [anon_sym__Generic] = ACTIONS(4313),
    [anon_sym_asm] = ACTIONS(4316),
    [anon_sym___asm__] = ACTIONS(4316),
    [sym_number_literal] = ACTIONS(4319),
    [anon_sym_L_SQUOTE] = ACTIONS(4322),
    [anon_sym_u_SQUOTE] = ACTIONS(4322),
    [anon_sym_U_SQUOTE] = ACTIONS(4322),
    [anon_sym_u8_SQUOTE] = ACTIONS(4322),
    [anon_sym_SQUOTE] = ACTIONS(4322),
    [anon_sym_L_DQUOTE] = ACTIONS(4325),
    [anon_sym_u_DQUOTE] = ACTIONS(4325),
    [anon_sym_U_DQUOTE] = ACTIONS(4325),
    [anon_sym_u8_DQUOTE] = ACTIONS(4325),
    [anon_sym_DQUOTE] = ACTIONS(4325),
    [sym_true] = ACTIONS(4328),
    [sym_false] = ACTIONS(4328),
    [anon_sym_NULL] = ACTIONS(4331),
    [anon_sym_nullptr] = ACTIONS(4331),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(4334),
    [anon_sym_typename] = ACTIONS(4337),
    [anon_sym_template] = ACTIONS(4340),
    [anon_sym_delete] = ACTIONS(4343),
    [anon_sym_R_DQUOTE] = ACTIONS(4346),
    [anon_sym_LR_DQUOTE] = ACTIONS(4346),
    [anon_sym_uR_DQUOTE] = ACTIONS(4346),
    [anon_sym_UR_DQUOTE] = ACTIONS(4346),
    [anon_sym_u8R_DQUOTE] = ACTIONS(4346),
    [anon_sym_co_await] = ACTIONS(4349),
    [anon_sym_new] = ACTIONS(4352),
    [anon_sym_requires] = ACTIONS(4355),
    [sym_this] = ACTIONS(4328),
  },
  [1171] = {
    [sym_expression] = STATE(4457),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7681),
    [sym_initializer_pair] = STATE(7681),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [sym_identifier] = ACTIONS(4207),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_RBRACE] = ACTIONS(4358),
    [anon_sym_LBRACK] = ACTIONS(4211),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1172] = {
    [sym_expression] = STATE(4457),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7681),
    [sym_initializer_pair] = STATE(7681),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [sym_identifier] = ACTIONS(4207),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_RBRACE] = ACTIONS(4360),
    [anon_sym_LBRACK] = ACTIONS(4211),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1173] = {
    [sym_expression] = STATE(4457),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7681),
    [sym_initializer_pair] = STATE(7681),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [sym_identifier] = ACTIONS(4207),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_RBRACE] = ACTIONS(4362),
    [anon_sym_LBRACK] = ACTIONS(4211),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1174] = {
    [sym_expression] = STATE(4457),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7681),
    [sym_initializer_pair] = STATE(7681),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [sym_identifier] = ACTIONS(4207),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_RBRACE] = ACTIONS(4364),
    [anon_sym_LBRACK] = ACTIONS(4211),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1175] = {
    [sym_expression] = STATE(4457),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7681),
    [sym_initializer_pair] = STATE(7681),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [sym_identifier] = ACTIONS(4207),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_RBRACE] = ACTIONS(4366),
    [anon_sym_LBRACK] = ACTIONS(4211),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1176] = {
    [sym_expression] = STATE(4457),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7681),
    [sym_initializer_pair] = STATE(7681),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [sym_identifier] = ACTIONS(4207),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_RBRACE] = ACTIONS(4368),
    [anon_sym_LBRACK] = ACTIONS(4211),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1177] = {
    [sym_expression] = STATE(4457),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7681),
    [sym_initializer_pair] = STATE(7681),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [sym_identifier] = ACTIONS(4207),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_RBRACE] = ACTIONS(4370),
    [anon_sym_LBRACK] = ACTIONS(4211),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1178] = {
    [sym_expression] = STATE(4457),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7681),
    [sym_initializer_pair] = STATE(7681),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [sym_identifier] = ACTIONS(4207),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_RBRACE] = ACTIONS(4215),
    [anon_sym_LBRACK] = ACTIONS(4211),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1179] = {
    [sym_expression] = STATE(4457),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7681),
    [sym_initializer_pair] = STATE(7681),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [sym_identifier] = ACTIONS(4207),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_RBRACE] = ACTIONS(4372),
    [anon_sym_LBRACK] = ACTIONS(4211),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1180] = {
    [sym_expression] = STATE(4457),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7681),
    [sym_initializer_pair] = STATE(7681),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [sym_identifier] = ACTIONS(4207),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_RBRACE] = ACTIONS(4374),
    [anon_sym_LBRACK] = ACTIONS(4211),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1181] = {
    [sym_expression] = STATE(4457),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7681),
    [sym_initializer_pair] = STATE(7681),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [sym_identifier] = ACTIONS(4207),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_RBRACE] = ACTIONS(4376),
    [anon_sym_LBRACK] = ACTIONS(4211),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1182] = {
    [sym_expression] = STATE(4457),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7681),
    [sym_initializer_pair] = STATE(7681),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [sym_identifier] = ACTIONS(4207),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_RBRACE] = ACTIONS(4378),
    [anon_sym_LBRACK] = ACTIONS(4211),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1183] = {
    [sym_function_definition] = STATE(790),
    [sym_declaration] = STATE(790),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4633),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_call_modifier] = STATE(1945),
    [sym_declaration_list] = STATE(790),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [sym_hlsl_attribute] = STATE(1303),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(4380),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(4382),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1184] = {
    [sym_function_definition] = STATE(342),
    [sym_declaration] = STATE(342),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_call_modifier] = STATE(1943),
    [sym_declaration_list] = STATE(342),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [sym_hlsl_attribute] = STATE(1327),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(4384),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(4382),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1185] = {
    [sym_expression] = STATE(4457),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7681),
    [sym_initializer_pair] = STATE(7681),
    [sym_subscript_designator] = STATE(6560),
    [sym_subscript_range_designator] = STATE(6560),
    [sym_field_designator] = STATE(6560),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [aux_sym_initializer_pair_repeat1] = STATE(6560),
    [sym_identifier] = ACTIONS(4207),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(4211),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(217),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1186] = {
    [sym_function_definition] = STATE(701),
    [sym_declaration] = STATE(701),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_call_modifier] = STATE(1955),
    [sym_declaration_list] = STATE(701),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [sym_hlsl_attribute] = STATE(1354),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(4386),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(4382),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1187] = {
    [sym_function_definition] = STATE(660),
    [sym_declaration] = STATE(660),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4694),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_call_modifier] = STATE(1965),
    [sym_declaration_list] = STATE(660),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [sym_hlsl_attribute] = STATE(1361),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_LBRACE] = ACTIONS(4388),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(4382),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1188] = {
    [sym_function_definition] = STATE(2094),
    [sym_declaration] = STATE(2094),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4730),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_call_modifier] = STATE(1947),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7991),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2431),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2432),
    [sym_qualifiers] = STATE(1979),
    [sym_hlsl_attribute] = STATE(1336),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(4390),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(4382),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(4392),
    [anon_sym_struct] = ACTIONS(4394),
    [anon_sym_union] = ACTIONS(4396),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1189] = {
    [sym_identifier] = ACTIONS(1959),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4058),
    [anon_sym_COMMA] = ACTIONS(4058),
    [anon_sym_LPAREN2] = ACTIONS(4060),
    [anon_sym_TILDE] = ACTIONS(1961),
    [anon_sym_DASH] = ACTIONS(4063),
    [anon_sym_PLUS] = ACTIONS(4063),
    [anon_sym_STAR] = ACTIONS(4060),
    [anon_sym_SLASH] = ACTIONS(4063),
    [anon_sym_PERCENT] = ACTIONS(4058),
    [anon_sym_PIPE_PIPE] = ACTIONS(4058),
    [anon_sym_AMP_AMP] = ACTIONS(4060),
    [anon_sym_PIPE] = ACTIONS(4063),
    [anon_sym_CARET] = ACTIONS(4058),
    [anon_sym_AMP] = ACTIONS(4065),
    [anon_sym_EQ_EQ] = ACTIONS(4058),
    [anon_sym_BANG_EQ] = ACTIONS(4058),
    [anon_sym_GT] = ACTIONS(4063),
    [anon_sym_GT_EQ] = ACTIONS(4058),
    [anon_sym_LT_EQ] = ACTIONS(4063),
    [anon_sym_LT] = ACTIONS(4063),
    [anon_sym_LT_LT] = ACTIONS(4058),
    [anon_sym_GT_GT] = ACTIONS(4058),
    [anon_sym_SEMI] = ACTIONS(4060),
    [anon_sym___extension__] = ACTIONS(1959),
    [anon_sym_in] = ACTIONS(1959),
    [anon_sym_out] = ACTIONS(1959),
    [anon_sym_inout] = ACTIONS(1959),
    [anon_sym_extern] = ACTIONS(1959),
    [anon_sym___attribute__] = ACTIONS(1959),
    [anon_sym_COLON_COLON] = ACTIONS(1961),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4060),
    [anon_sym___declspec] = ACTIONS(1959),
    [anon_sym___based] = ACTIONS(1959),
    [anon_sym___cdecl] = ACTIONS(1959),
    [anon_sym___clrcall] = ACTIONS(1959),
    [anon_sym___stdcall] = ACTIONS(1959),
    [anon_sym___fastcall] = ACTIONS(1959),
    [anon_sym___thiscall] = ACTIONS(1959),
    [anon_sym___vectorcall] = ACTIONS(1959),
    [anon_sym_LBRACE] = ACTIONS(1961),
    [anon_sym_RBRACE] = ACTIONS(4058),
    [anon_sym_LBRACK] = ACTIONS(4065),
    [anon_sym_static] = ACTIONS(1959),
    [anon_sym_register] = ACTIONS(1959),
    [anon_sym_inline] = ACTIONS(1959),
    [anon_sym___inline] = ACTIONS(1959),
    [anon_sym___inline__] = ACTIONS(1959),
    [anon_sym___forceinline] = ACTIONS(1959),
    [anon_sym_thread_local] = ACTIONS(1959),
    [anon_sym___thread] = ACTIONS(1959),
    [anon_sym_const] = ACTIONS(1959),
    [anon_sym_constexpr] = ACTIONS(1959),
    [anon_sym_volatile] = ACTIONS(1959),
    [anon_sym_restrict] = ACTIONS(1959),
    [anon_sym___restrict__] = ACTIONS(1959),
    [anon_sym__Atomic] = ACTIONS(1959),
    [anon_sym__Noreturn] = ACTIONS(1959),
    [anon_sym_noreturn] = ACTIONS(1959),
    [anon_sym_mutable] = ACTIONS(1959),
    [anon_sym_constinit] = ACTIONS(1959),
    [anon_sym_consteval] = ACTIONS(1959),
    [anon_sym_alignas] = ACTIONS(1959),
    [anon_sym__Alignas] = ACTIONS(1959),
    [anon_sym_QMARK] = ACTIONS(4058),
    [anon_sym_LT_EQ_GT] = ACTIONS(4058),
    [anon_sym_or] = ACTIONS(4063),
    [anon_sym_and] = ACTIONS(4063),
    [anon_sym_bitor] = ACTIONS(4063),
    [anon_sym_xor] = ACTIONS(4063),
    [anon_sym_bitand] = ACTIONS(4063),
    [anon_sym_not_eq] = ACTIONS(4063),
    [anon_sym_DASH_DASH] = ACTIONS(4058),
    [anon_sym_PLUS_PLUS] = ACTIONS(4058),
    [anon_sym_DOT] = ACTIONS(4063),
    [anon_sym_DOT_STAR] = ACTIONS(4058),
    [anon_sym_DASH_GT] = ACTIONS(4058),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1959),
    [anon_sym_decltype] = ACTIONS(1959),
    [sym_virtual] = ACTIONS(1959),
    [anon_sym_template] = ACTIONS(1959),
    [anon_sym_operator] = ACTIONS(1959),
    [anon_sym_precise] = ACTIONS(1959),
    [anon_sym_shared] = ACTIONS(1959),
    [anon_sym_groupshared] = ACTIONS(1959),
    [anon_sym_uniform] = ACTIONS(1959),
    [anon_sym_row_major] = ACTIONS(1959),
    [anon_sym_column_major] = ACTIONS(1959),
    [anon_sym_globallycoherent] = ACTIONS(1959),
    [anon_sym_centroid] = ACTIONS(1959),
    [anon_sym_noperspective] = ACTIONS(1959),
    [anon_sym_nointerpolation] = ACTIONS(1959),
    [anon_sym_sample] = ACTIONS(1959),
    [anon_sym_linear] = ACTIONS(1959),
    [anon_sym_snorm] = ACTIONS(1959),
    [anon_sym_unorm] = ACTIONS(1959),
    [anon_sym_point] = ACTIONS(1959),
    [anon_sym_line] = ACTIONS(1959),
    [anon_sym_triangleadj] = ACTIONS(1959),
    [anon_sym_lineadj] = ACTIONS(1959),
    [anon_sym_triangle] = ACTIONS(1959),
  },
  [1190] = {
    [sym_function_definition] = STATE(758),
    [sym_declaration] = STATE(758),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4633),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_call_modifier] = STATE(1945),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(8366),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2431),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2432),
    [sym_qualifiers] = STATE(1979),
    [sym_hlsl_attribute] = STATE(1303),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(4390),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(4382),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(4398),
    [anon_sym_struct] = ACTIONS(4400),
    [anon_sym_union] = ACTIONS(4402),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1191] = {
    [sym_function_definition] = STATE(614),
    [sym_declaration] = STATE(614),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4694),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_call_modifier] = STATE(1965),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7936),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2431),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2432),
    [sym_qualifiers] = STATE(1979),
    [sym_hlsl_attribute] = STATE(1361),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(4390),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(4382),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(4404),
    [anon_sym_struct] = ACTIONS(4406),
    [anon_sym_union] = ACTIONS(4408),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1192] = {
    [sym_function_definition] = STATE(325),
    [sym_declaration] = STATE(325),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4639),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_call_modifier] = STATE(1943),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7923),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2431),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2432),
    [sym_qualifiers] = STATE(1979),
    [sym_hlsl_attribute] = STATE(1327),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(4390),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(4382),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(4410),
    [anon_sym_struct] = ACTIONS(4412),
    [anon_sym_union] = ACTIONS(4414),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1193] = {
    [sym_function_definition] = STATE(1874),
    [sym_declaration] = STATE(1874),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4626),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_call_modifier] = STATE(1953),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(7929),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2431),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2432),
    [sym_qualifiers] = STATE(1979),
    [sym_hlsl_attribute] = STATE(1357),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(4390),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(4382),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(4416),
    [anon_sym_struct] = ACTIONS(4418),
    [anon_sym_union] = ACTIONS(4420),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1194] = {
    [sym_function_definition] = STATE(642),
    [sym_declaration] = STATE(642),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4620),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_call_modifier] = STATE(1955),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(8125),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2431),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2432),
    [sym_qualifiers] = STATE(1979),
    [sym_hlsl_attribute] = STATE(1354),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(4390),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(4382),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(4422),
    [anon_sym_struct] = ACTIONS(4424),
    [anon_sym_union] = ACTIONS(4426),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1195] = {
    [sym_function_definition] = STATE(2044),
    [sym_declaration] = STATE(2044),
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4664),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_call_modifier] = STATE(1962),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym__class_name] = STATE(8140),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2431),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2432),
    [sym_qualifiers] = STATE(1979),
    [sym_hlsl_attribute] = STATE(1312),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(4390),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_LBRACK] = ACTIONS(4382),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(4428),
    [anon_sym_struct] = ACTIONS(4430),
    [anon_sym_union] = ACTIONS(4432),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1196] = {
    [sym_compound_statement] = STATE(7435),
    [sym_expression] = STATE(4314),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7435),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_RPAREN] = ACTIONS(4434),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4436),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(1883),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1197] = {
    [sym_compound_statement] = STATE(7066),
    [sym_expression] = STATE(4366),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7066),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_RPAREN] = ACTIONS(4438),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4440),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(1883),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1198] = {
    [sym_compound_statement] = STATE(7312),
    [sym_expression] = STATE(4349),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7312),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_RPAREN] = ACTIONS(4442),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4444),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(1883),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1199] = {
    [sym_compound_statement] = STATE(7173),
    [sym_expression] = STATE(4412),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7173),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_RPAREN] = ACTIONS(4446),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4448),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(1883),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1200] = {
    [sym_compound_statement] = STATE(7189),
    [sym_expression] = STATE(4364),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7189),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_RPAREN] = ACTIONS(4450),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4452),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(1883),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1201] = {
    [sym_compound_statement] = STATE(7117),
    [sym_expression] = STATE(4343),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7117),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_RPAREN] = ACTIONS(4454),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4456),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(1883),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1202] = {
    [sym_compound_statement] = STATE(7393),
    [sym_expression] = STATE(4362),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7393),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_RPAREN] = ACTIONS(4458),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4460),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(1883),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1203] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4813),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_call_modifier] = STATE(1944),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(4462),
    [anon_sym_for] = ACTIONS(4464),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1204] = {
    [sym_expression] = STATE(4246),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_initializer_list] = STATE(6689),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_default] = ACTIONS(4470),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(4474),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4476),
    [anon_sym_0] = ACTIONS(4478),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1205] = {
    [sym_expression] = STATE(4484),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8242),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(8242),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4480),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1206] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4743),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_call_modifier] = STATE(1970),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(4482),
    [anon_sym_for] = ACTIONS(4484),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1207] = {
    [sym_expression] = STATE(3414),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym__unary_left_fold] = STATE(7995),
    [sym__unary_right_fold] = STATE(7997),
    [sym__binary_fold] = STATE(7999),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1208] = {
    [sym_expression] = STATE(3373),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym__unary_left_fold] = STATE(8551),
    [sym__unary_right_fold] = STATE(8550),
    [sym__binary_fold] = STATE(8549),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1209] = {
    [sym_expression] = STATE(4561),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8009),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(8009),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4486),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1210] = {
    [sym_compound_statement] = STATE(7707),
    [sym_expression] = STATE(4502),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7707),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym___extension__] = ACTIONS(4488),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(1883),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1211] = {
    [sym_expression] = STATE(3424),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym__unary_left_fold] = STATE(8102),
    [sym__unary_right_fold] = STATE(8104),
    [sym__binary_fold] = STATE(8108),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1212] = {
    [sym_expression] = STATE(3374),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym__unary_left_fold] = STATE(8259),
    [sym__unary_right_fold] = STATE(8258),
    [sym__binary_fold] = STATE(8257),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1213] = {
    [sym_expression] = STATE(4459),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7912),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7912),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4490),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1214] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4805),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_call_modifier] = STATE(1954),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(4492),
    [anon_sym_for] = ACTIONS(4494),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1215] = {
    [sym_expression] = STATE(4551),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8540),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(8540),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4496),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1216] = {
    [sym_expression] = STATE(4450),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8353),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(8353),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4498),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1217] = {
    [sym_expression] = STATE(3416),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym__unary_left_fold] = STATE(8213),
    [sym__unary_right_fold] = STATE(8216),
    [sym__binary_fold] = STATE(8217),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1218] = {
    [sym_expression] = STATE(3421),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym__unary_left_fold] = STATE(7861),
    [sym__unary_right_fold] = STATE(7859),
    [sym__binary_fold] = STATE(7857),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1219] = {
    [sym_expression] = STATE(3447),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym__unary_left_fold] = STATE(8027),
    [sym__unary_right_fold] = STATE(8025),
    [sym__binary_fold] = STATE(8021),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1220] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4780),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_call_modifier] = STATE(1941),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [anon_sym_if] = ACTIONS(4500),
    [anon_sym_for] = ACTIONS(4502),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1221] = {
    [sym_expression] = STATE(3430),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym__unary_left_fold] = STATE(8570),
    [sym__unary_right_fold] = STATE(8567),
    [sym__binary_fold] = STATE(8566),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1222] = {
    [sym_expression] = STATE(4255),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_initializer_list] = STATE(6713),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_default] = ACTIONS(4504),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(4474),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4506),
    [anon_sym_0] = ACTIONS(4508),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1223] = {
    [sym_expression] = STATE(4253),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_initializer_list] = STATE(6703),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_default] = ACTIONS(4510),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(4474),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4512),
    [anon_sym_0] = ACTIONS(4514),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1224] = {
    [sym_expression] = STATE(3420),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym__unary_left_fold] = STATE(8335),
    [sym__unary_right_fold] = STATE(8336),
    [sym__binary_fold] = STATE(8337),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1815),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1225] = {
    [sym_expression] = STATE(4700),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(8370),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4516),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1226] = {
    [sym_expression] = STATE(4284),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1227] = {
    [sym_expression] = STATE(4700),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(8370),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4523),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1228] = {
    [sym_expression] = STATE(4700),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(8370),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4526),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1229] = {
    [sym_expression] = STATE(4398),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1230] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4531),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1231] = {
    [sym_expression] = STATE(4468),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1232] = {
    [sym_expression] = STATE(4263),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1233] = {
    [sym_expression] = STATE(4199),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(3948),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3946),
    [anon_sym_PLUS] = ACTIONS(3946),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_DASH_DASH] = ACTIONS(4537),
    [anon_sym_PLUS_PLUS] = ACTIONS(4537),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1234] = {
    [sym_expression] = STATE(4526),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1235] = {
    [sym_expression] = STATE(3117),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1236] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4539),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1237] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4541),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1238] = {
    [sym_expression] = STATE(4429),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1239] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4543),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1240] = {
    [sym_expression] = STATE(4700),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(8370),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4545),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1241] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4548),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1242] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4550),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1243] = {
    [sym_expression] = STATE(4407),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_initializer_list] = STATE(7205),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4552),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1244] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4554),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1245] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4556),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1246] = {
    [sym_expression] = STATE(3400),
    [sym__string] = STATE(3729),
    [sym_conditional_expression] = STATE(3729),
    [sym_assignment_expression] = STATE(3729),
    [sym_pointer_expression] = STATE(3736),
    [sym_unary_expression] = STATE(3729),
    [sym_binary_expression] = STATE(3729),
    [sym_update_expression] = STATE(3729),
    [sym_cast_expression] = STATE(3729),
    [sym_sizeof_expression] = STATE(3729),
    [sym_alignof_expression] = STATE(3729),
    [sym_offsetof_expression] = STATE(3729),
    [sym_generic_expression] = STATE(3729),
    [sym_subscript_expression] = STATE(3736),
    [sym_call_expression] = STATE(3736),
    [sym_gnu_asm_expression] = STATE(3729),
    [sym_field_expression] = STATE(3736),
    [sym_compound_literal_expression] = STATE(3729),
    [sym_parenthesized_expression] = STATE(3736),
    [sym_char_literal] = STATE(3602),
    [sym_concatenated_string] = STATE(3610),
    [sym_string_literal] = STATE(2698),
    [sym_null] = STATE(3729),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7745),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3729),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(3729),
    [sym_new_expression] = STATE(3729),
    [sym_delete_expression] = STATE(3729),
    [sym_requires_clause] = STATE(3729),
    [sym_requires_expression] = STATE(3729),
    [sym_lambda_expression] = STATE(3729),
    [sym_lambda_capture_specifier] = STATE(5813),
    [sym_fold_expression] = STATE(3729),
    [sym_parameter_pack_expansion] = STATE(3729),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3736),
    [sym_qualified_type_identifier] = STATE(7745),
    [sym_user_defined_literal] = STATE(3736),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(3673),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3669),
    [anon_sym_compl] = ACTIONS(3669),
    [anon_sym_DASH_DASH] = ACTIONS(4558),
    [anon_sym_PLUS_PLUS] = ACTIONS(4558),
    [anon_sym_sizeof] = ACTIONS(3679),
    [anon_sym___alignof__] = ACTIONS(3681),
    [anon_sym___alignof] = ACTIONS(3681),
    [anon_sym__alignof] = ACTIONS(3681),
    [anon_sym_alignof] = ACTIONS(3681),
    [anon_sym__Alignof] = ACTIONS(3681),
    [anon_sym_offsetof] = ACTIONS(3683),
    [anon_sym__Generic] = ACTIONS(3685),
    [anon_sym_asm] = ACTIONS(3687),
    [anon_sym___asm__] = ACTIONS(3687),
    [sym_number_literal] = ACTIONS(3689),
    [anon_sym_L_SQUOTE] = ACTIONS(3691),
    [anon_sym_u_SQUOTE] = ACTIONS(3691),
    [anon_sym_U_SQUOTE] = ACTIONS(3691),
    [anon_sym_u8_SQUOTE] = ACTIONS(3691),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [anon_sym_L_DQUOTE] = ACTIONS(3693),
    [anon_sym_u_DQUOTE] = ACTIONS(3693),
    [anon_sym_U_DQUOTE] = ACTIONS(3693),
    [anon_sym_u8_DQUOTE] = ACTIONS(3693),
    [anon_sym_DQUOTE] = ACTIONS(3693),
    [sym_true] = ACTIONS(3695),
    [sym_false] = ACTIONS(3695),
    [anon_sym_NULL] = ACTIONS(3697),
    [anon_sym_nullptr] = ACTIONS(3697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3699),
    [anon_sym_R_DQUOTE] = ACTIONS(3701),
    [anon_sym_LR_DQUOTE] = ACTIONS(3701),
    [anon_sym_uR_DQUOTE] = ACTIONS(3701),
    [anon_sym_UR_DQUOTE] = ACTIONS(3701),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3701),
    [anon_sym_co_await] = ACTIONS(3703),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_requires] = ACTIONS(3707),
    [sym_this] = ACTIONS(3695),
  },
  [1247] = {
    [sym_expression] = STATE(2986),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3061),
    [sym_concatenated_string] = STATE(3059),
    [sym_string_literal] = STATE(2449),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2444),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(3521),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3517),
    [anon_sym_compl] = ACTIONS(3517),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_sizeof] = ACTIONS(3527),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3537),
    [anon_sym_L_SQUOTE] = ACTIONS(3539),
    [anon_sym_u_SQUOTE] = ACTIONS(3539),
    [anon_sym_U_SQUOTE] = ACTIONS(3539),
    [anon_sym_u8_SQUOTE] = ACTIONS(3539),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3547),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [anon_sym_co_await] = ACTIONS(3551),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1248] = {
    [sym_expression] = STATE(3466),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(3713),
    [anon_sym_TILDE] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3711),
    [anon_sym_PLUS] = ACTIONS(3711),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(3715),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3711),
    [anon_sym_compl] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(4562),
    [anon_sym_PLUS_PLUS] = ACTIONS(4562),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3719),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1249] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4564),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1250] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4566),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1251] = {
    [sym_expression] = STATE(3005),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3061),
    [sym_concatenated_string] = STATE(3059),
    [sym_string_literal] = STATE(2449),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2444),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(3521),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3517),
    [anon_sym_compl] = ACTIONS(3517),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_sizeof] = ACTIONS(3527),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3537),
    [anon_sym_L_SQUOTE] = ACTIONS(3539),
    [anon_sym_u_SQUOTE] = ACTIONS(3539),
    [anon_sym_U_SQUOTE] = ACTIONS(3539),
    [anon_sym_u8_SQUOTE] = ACTIONS(3539),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3547),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [anon_sym_co_await] = ACTIONS(3551),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1252] = {
    [sym_expression] = STATE(3739),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1253] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4568),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1254] = {
    [sym_expression] = STATE(3464),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(3713),
    [anon_sym_TILDE] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3711),
    [anon_sym_PLUS] = ACTIONS(3711),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(3715),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3711),
    [anon_sym_compl] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(4562),
    [anon_sym_PLUS_PLUS] = ACTIONS(4562),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3719),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1255] = {
    [sym__declaration_modifiers] = STATE(1984),
    [sym__declaration_specifiers] = STATE(4082),
    [sym_attribute_specifier] = STATE(1984),
    [sym_attribute_declaration] = STATE(1984),
    [sym_ms_declspec_modifier] = STATE(1984),
    [sym_storage_class_specifier] = STATE(1984),
    [sym_type_qualifier] = STATE(1984),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_parameter_declaration] = STATE(7194),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_type_parameter_declaration] = STATE(7194),
    [sym_variadic_type_parameter_declaration] = STATE(7194),
    [sym_optional_type_parameter_declaration] = STATE(7194),
    [sym_template_template_parameter_declaration] = STATE(7194),
    [sym_optional_parameter_declaration] = STATE(7194),
    [sym_variadic_parameter_declaration] = STATE(7194),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6449),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1984),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1984),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(4068),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1827),
    [anon_sym_out] = ACTIONS(1827),
    [anon_sym_inout] = ACTIONS(1827),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(4078),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(1833),
    [anon_sym_class] = ACTIONS(4570),
    [anon_sym_struct] = ACTIONS(1837),
    [anon_sym_union] = ACTIONS(1839),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1827),
    [anon_sym_typename] = ACTIONS(4572),
    [anon_sym_template] = ACTIONS(4574),
    [anon_sym_GT2] = ACTIONS(4576),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1256] = {
    [sym_expression] = STATE(4418),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_initializer_list] = STATE(7417),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4578),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1257] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4580),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1258] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4582),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1259] = {
    [sym_expression] = STATE(4700),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(8370),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4584),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1260] = {
    [sym_expression] = STATE(4700),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(8370),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4587),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1261] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4590),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1262] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4592),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1263] = {
    [sym_expression] = STATE(4328),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4594),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1264] = {
    [sym_expression] = STATE(4508),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1265] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4598),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1266] = {
    [sym_expression] = STATE(4435),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1267] = {
    [sym_expression] = STATE(4700),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(8370),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4600),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1268] = {
    [sym_expression] = STATE(4700),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(8370),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4603),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1269] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4606),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1270] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4608),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1271] = {
    [sym_expression] = STATE(3150),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1272] = {
    [sym_expression] = STATE(4355),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4594),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1273] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4610),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1274] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4612),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4594),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1275] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4614),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1276] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4616),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1277] = {
    [sym_expression] = STATE(4370),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4612),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4594),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1278] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4618),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1279] = {
    [sym_expression] = STATE(4700),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(8370),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4620),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1280] = {
    [sym_expression] = STATE(4700),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(8370),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4623),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1281] = {
    [sym_expression] = STATE(3335),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1282] = {
    [sym_expression] = STATE(4374),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4612),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4594),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1283] = {
    [sym_expression] = STATE(4547),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1284] = {
    [sym_expression] = STATE(4198),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(3948),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3946),
    [anon_sym_PLUS] = ACTIONS(3946),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_DASH_DASH] = ACTIONS(4537),
    [anon_sym_PLUS_PLUS] = ACTIONS(4537),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1285] = {
    [sym_expression] = STATE(3238),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3360),
    [sym_concatenated_string] = STATE(3359),
    [sym_string_literal] = STATE(2634),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2625),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3635),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(3641),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3637),
    [anon_sym_compl] = ACTIONS(3637),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_sizeof] = ACTIONS(3643),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3645),
    [anon_sym_L_SQUOTE] = ACTIONS(3647),
    [anon_sym_u_SQUOTE] = ACTIONS(3647),
    [anon_sym_U_SQUOTE] = ACTIONS(3647),
    [anon_sym_u8_SQUOTE] = ACTIONS(3647),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [anon_sym_L_DQUOTE] = ACTIONS(3649),
    [anon_sym_u_DQUOTE] = ACTIONS(3649),
    [anon_sym_U_DQUOTE] = ACTIONS(3649),
    [anon_sym_u8_DQUOTE] = ACTIONS(3649),
    [anon_sym_DQUOTE] = ACTIONS(3649),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3651),
    [anon_sym_R_DQUOTE] = ACTIONS(3653),
    [anon_sym_LR_DQUOTE] = ACTIONS(3653),
    [anon_sym_uR_DQUOTE] = ACTIONS(3653),
    [anon_sym_UR_DQUOTE] = ACTIONS(3653),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3653),
    [anon_sym_co_await] = ACTIONS(3655),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1286] = {
    [sym_expression] = STATE(4337),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_initializer_list] = STATE(7385),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4628),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1287] = {
    [sym_expression] = STATE(3686),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1288] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4630),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1289] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4632),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1290] = {
    [sym_expression] = STATE(3408),
    [sym__string] = STATE(3729),
    [sym_conditional_expression] = STATE(3729),
    [sym_assignment_expression] = STATE(3729),
    [sym_pointer_expression] = STATE(3736),
    [sym_unary_expression] = STATE(3729),
    [sym_binary_expression] = STATE(3729),
    [sym_update_expression] = STATE(3729),
    [sym_cast_expression] = STATE(3729),
    [sym_sizeof_expression] = STATE(3729),
    [sym_alignof_expression] = STATE(3729),
    [sym_offsetof_expression] = STATE(3729),
    [sym_generic_expression] = STATE(3729),
    [sym_subscript_expression] = STATE(3736),
    [sym_call_expression] = STATE(3736),
    [sym_gnu_asm_expression] = STATE(3729),
    [sym_field_expression] = STATE(3736),
    [sym_compound_literal_expression] = STATE(3729),
    [sym_parenthesized_expression] = STATE(3736),
    [sym_char_literal] = STATE(3602),
    [sym_concatenated_string] = STATE(3610),
    [sym_string_literal] = STATE(2698),
    [sym_null] = STATE(3729),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7745),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3729),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(3729),
    [sym_new_expression] = STATE(3729),
    [sym_delete_expression] = STATE(3729),
    [sym_requires_clause] = STATE(3729),
    [sym_requires_expression] = STATE(3729),
    [sym_lambda_expression] = STATE(3729),
    [sym_lambda_capture_specifier] = STATE(5813),
    [sym_fold_expression] = STATE(3729),
    [sym_parameter_pack_expansion] = STATE(3729),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3736),
    [sym_qualified_type_identifier] = STATE(7745),
    [sym_user_defined_literal] = STATE(3736),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(3673),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3669),
    [anon_sym_compl] = ACTIONS(3669),
    [anon_sym_DASH_DASH] = ACTIONS(4558),
    [anon_sym_PLUS_PLUS] = ACTIONS(4558),
    [anon_sym_sizeof] = ACTIONS(3679),
    [anon_sym___alignof__] = ACTIONS(3681),
    [anon_sym___alignof] = ACTIONS(3681),
    [anon_sym__alignof] = ACTIONS(3681),
    [anon_sym_alignof] = ACTIONS(3681),
    [anon_sym__Alignof] = ACTIONS(3681),
    [anon_sym_offsetof] = ACTIONS(3683),
    [anon_sym__Generic] = ACTIONS(3685),
    [anon_sym_asm] = ACTIONS(3687),
    [anon_sym___asm__] = ACTIONS(3687),
    [sym_number_literal] = ACTIONS(3689),
    [anon_sym_L_SQUOTE] = ACTIONS(3691),
    [anon_sym_u_SQUOTE] = ACTIONS(3691),
    [anon_sym_U_SQUOTE] = ACTIONS(3691),
    [anon_sym_u8_SQUOTE] = ACTIONS(3691),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [anon_sym_L_DQUOTE] = ACTIONS(3693),
    [anon_sym_u_DQUOTE] = ACTIONS(3693),
    [anon_sym_U_DQUOTE] = ACTIONS(3693),
    [anon_sym_u8_DQUOTE] = ACTIONS(3693),
    [anon_sym_DQUOTE] = ACTIONS(3693),
    [sym_true] = ACTIONS(3695),
    [sym_false] = ACTIONS(3695),
    [anon_sym_NULL] = ACTIONS(3697),
    [anon_sym_nullptr] = ACTIONS(3697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3699),
    [anon_sym_R_DQUOTE] = ACTIONS(3701),
    [anon_sym_LR_DQUOTE] = ACTIONS(3701),
    [anon_sym_uR_DQUOTE] = ACTIONS(3701),
    [anon_sym_UR_DQUOTE] = ACTIONS(3701),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3701),
    [anon_sym_co_await] = ACTIONS(3703),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_requires] = ACTIONS(3707),
    [sym_this] = ACTIONS(3695),
  },
  [1291] = {
    [sym_expression] = STATE(4700),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(8370),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4634),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1292] = {
    [sym_expression] = STATE(3249),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1293] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4637),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1294] = {
    [sym_expression] = STATE(3286),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3360),
    [sym_concatenated_string] = STATE(3359),
    [sym_string_literal] = STATE(2634),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2625),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3635),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(3641),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3637),
    [anon_sym_compl] = ACTIONS(3637),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_sizeof] = ACTIONS(3643),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3645),
    [anon_sym_L_SQUOTE] = ACTIONS(3647),
    [anon_sym_u_SQUOTE] = ACTIONS(3647),
    [anon_sym_U_SQUOTE] = ACTIONS(3647),
    [anon_sym_u8_SQUOTE] = ACTIONS(3647),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [anon_sym_L_DQUOTE] = ACTIONS(3649),
    [anon_sym_u_DQUOTE] = ACTIONS(3649),
    [anon_sym_U_DQUOTE] = ACTIONS(3649),
    [anon_sym_u8_DQUOTE] = ACTIONS(3649),
    [anon_sym_DQUOTE] = ACTIONS(3649),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3651),
    [anon_sym_R_DQUOTE] = ACTIONS(3653),
    [anon_sym_LR_DQUOTE] = ACTIONS(3653),
    [anon_sym_uR_DQUOTE] = ACTIONS(3653),
    [anon_sym_UR_DQUOTE] = ACTIONS(3653),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3653),
    [anon_sym_co_await] = ACTIONS(3655),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1295] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4639),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1296] = {
    [sym_expression] = STATE(4436),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4519),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(4519),
    [anon_sym_AMP_AMP] = ACTIONS(4519),
    [anon_sym_AMP] = ACTIONS(4521),
    [anon_sym_LT] = ACTIONS(4519),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACE] = ACTIONS(4519),
    [anon_sym_LBRACK] = ACTIONS(4519),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1297] = {
    [sym__declaration_modifiers] = STATE(1984),
    [sym__declaration_specifiers] = STATE(4082),
    [sym_attribute_specifier] = STATE(1984),
    [sym_attribute_declaration] = STATE(1984),
    [sym_ms_declspec_modifier] = STATE(1984),
    [sym_storage_class_specifier] = STATE(1984),
    [sym_type_qualifier] = STATE(1984),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_parameter_declaration] = STATE(7278),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_type_parameter_declaration] = STATE(7278),
    [sym_variadic_type_parameter_declaration] = STATE(7278),
    [sym_optional_type_parameter_declaration] = STATE(7278),
    [sym_template_template_parameter_declaration] = STATE(7278),
    [sym_optional_parameter_declaration] = STATE(7278),
    [sym_variadic_parameter_declaration] = STATE(7278),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6449),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1984),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1984),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(4068),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1827),
    [anon_sym_out] = ACTIONS(1827),
    [anon_sym_inout] = ACTIONS(1827),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(4078),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(1833),
    [anon_sym_class] = ACTIONS(4570),
    [anon_sym_struct] = ACTIONS(1837),
    [anon_sym_union] = ACTIONS(1839),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1827),
    [anon_sym_typename] = ACTIONS(4572),
    [anon_sym_template] = ACTIONS(4574),
    [anon_sym_GT2] = ACTIONS(4641),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1298] = {
    [sym_expression] = STATE(4390),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_lambda_default_capture] = STATE(7548),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(4529),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4594),
    [anon_sym_EQ] = ACTIONS(4533),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1299] = {
    [sym_expression] = STATE(4267),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(4028),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1300] = {
    [sym_expression] = STATE(4471),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7684),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1301] = {
    [sym_expression] = STATE(4557),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_initializer_list] = STATE(4828),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACE] = ACTIONS(4019),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1302] = {
    [sym_expression] = STATE(4460),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7664),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1303] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4743),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_call_modifier] = STATE(1970),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1304] = {
    [sym_expression] = STATE(4448),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7920),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(2693),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1305] = {
    [sym_expression] = STATE(4447),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_initializer_list] = STATE(4028),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1306] = {
    [sym_expression] = STATE(4545),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8304),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_RPAREN] = ACTIONS(4647),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1307] = {
    [sym_expression] = STATE(4329),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7015),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4649),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1308] = {
    [sym_expression] = STATE(4542),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_initializer_list] = STATE(4028),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1309] = {
    [sym_expression] = STATE(4522),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7957),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON] = ACTIONS(4652),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1310] = {
    [sym_expression] = STATE(4550),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_initializer_list] = STATE(4742),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACE] = ACTIONS(4019),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1311] = {
    [sym_expression] = STATE(4541),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8170),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON] = ACTIONS(4654),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1312] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4809),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_call_modifier] = STATE(1972),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1313] = {
    [sym_expression] = STATE(3397),
    [sym__string] = STATE(3729),
    [sym_conditional_expression] = STATE(3729),
    [sym_assignment_expression] = STATE(3729),
    [sym_pointer_expression] = STATE(3736),
    [sym_unary_expression] = STATE(3729),
    [sym_binary_expression] = STATE(3729),
    [sym_update_expression] = STATE(3729),
    [sym_cast_expression] = STATE(3729),
    [sym_sizeof_expression] = STATE(3729),
    [sym_alignof_expression] = STATE(3729),
    [sym_offsetof_expression] = STATE(3729),
    [sym_generic_expression] = STATE(3729),
    [sym_subscript_expression] = STATE(3736),
    [sym_call_expression] = STATE(3736),
    [sym_gnu_asm_expression] = STATE(3729),
    [sym_field_expression] = STATE(3736),
    [sym_compound_literal_expression] = STATE(3729),
    [sym_parenthesized_expression] = STATE(3736),
    [sym_initializer_list] = STATE(3727),
    [sym_char_literal] = STATE(3602),
    [sym_concatenated_string] = STATE(3610),
    [sym_string_literal] = STATE(2698),
    [sym_null] = STATE(3729),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7745),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3729),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(3729),
    [sym_new_expression] = STATE(3729),
    [sym_delete_expression] = STATE(3729),
    [sym_requires_clause] = STATE(3729),
    [sym_requires_expression] = STATE(3729),
    [sym_lambda_expression] = STATE(3729),
    [sym_lambda_capture_specifier] = STATE(5813),
    [sym_fold_expression] = STATE(3729),
    [sym_parameter_pack_expansion] = STATE(3729),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3736),
    [sym_qualified_type_identifier] = STATE(7745),
    [sym_user_defined_literal] = STATE(3736),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_LPAREN2] = ACTIONS(4656),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3673),
    [anon_sym_LBRACE] = ACTIONS(3675),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3669),
    [anon_sym_compl] = ACTIONS(3669),
    [anon_sym_DASH_DASH] = ACTIONS(4558),
    [anon_sym_PLUS_PLUS] = ACTIONS(4558),
    [anon_sym_sizeof] = ACTIONS(3679),
    [anon_sym___alignof__] = ACTIONS(3681),
    [anon_sym___alignof] = ACTIONS(3681),
    [anon_sym__alignof] = ACTIONS(3681),
    [anon_sym_alignof] = ACTIONS(3681),
    [anon_sym__Alignof] = ACTIONS(3681),
    [anon_sym_offsetof] = ACTIONS(3683),
    [anon_sym__Generic] = ACTIONS(3685),
    [anon_sym_asm] = ACTIONS(3687),
    [anon_sym___asm__] = ACTIONS(3687),
    [sym_number_literal] = ACTIONS(3689),
    [anon_sym_L_SQUOTE] = ACTIONS(3691),
    [anon_sym_u_SQUOTE] = ACTIONS(3691),
    [anon_sym_U_SQUOTE] = ACTIONS(3691),
    [anon_sym_u8_SQUOTE] = ACTIONS(3691),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [anon_sym_L_DQUOTE] = ACTIONS(3693),
    [anon_sym_u_DQUOTE] = ACTIONS(3693),
    [anon_sym_U_DQUOTE] = ACTIONS(3693),
    [anon_sym_u8_DQUOTE] = ACTIONS(3693),
    [anon_sym_DQUOTE] = ACTIONS(3693),
    [sym_true] = ACTIONS(3695),
    [sym_false] = ACTIONS(3695),
    [anon_sym_NULL] = ACTIONS(3697),
    [anon_sym_nullptr] = ACTIONS(3697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3699),
    [anon_sym_R_DQUOTE] = ACTIONS(3701),
    [anon_sym_LR_DQUOTE] = ACTIONS(3701),
    [anon_sym_uR_DQUOTE] = ACTIONS(3701),
    [anon_sym_UR_DQUOTE] = ACTIONS(3701),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3701),
    [anon_sym_co_await] = ACTIONS(3703),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_requires] = ACTIONS(3707),
    [sym_this] = ACTIONS(3695),
  },
  [1314] = {
    [sym_identifier] = ACTIONS(1959),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4060),
    [anon_sym_COMMA] = ACTIONS(4060),
    [anon_sym_RPAREN] = ACTIONS(4060),
    [anon_sym_LPAREN2] = ACTIONS(4060),
    [anon_sym_TILDE] = ACTIONS(1961),
    [anon_sym_DASH] = ACTIONS(4063),
    [anon_sym_PLUS] = ACTIONS(4063),
    [anon_sym_STAR] = ACTIONS(4060),
    [anon_sym_SLASH] = ACTIONS(4063),
    [anon_sym_PERCENT] = ACTIONS(4058),
    [anon_sym_PIPE_PIPE] = ACTIONS(4058),
    [anon_sym_AMP_AMP] = ACTIONS(4060),
    [anon_sym_PIPE] = ACTIONS(4063),
    [anon_sym_CARET] = ACTIONS(4058),
    [anon_sym_AMP] = ACTIONS(4065),
    [anon_sym_EQ_EQ] = ACTIONS(4058),
    [anon_sym_BANG_EQ] = ACTIONS(4058),
    [anon_sym_GT] = ACTIONS(4063),
    [anon_sym_GT_EQ] = ACTIONS(4058),
    [anon_sym_LT_EQ] = ACTIONS(4063),
    [anon_sym_LT] = ACTIONS(4063),
    [anon_sym_LT_LT] = ACTIONS(4058),
    [anon_sym_GT_GT] = ACTIONS(4058),
    [anon_sym_COLON] = ACTIONS(1959),
    [anon_sym___extension__] = ACTIONS(1959),
    [anon_sym_in] = ACTIONS(1959),
    [anon_sym_out] = ACTIONS(1959),
    [anon_sym_inout] = ACTIONS(1959),
    [anon_sym_extern] = ACTIONS(1959),
    [anon_sym___attribute__] = ACTIONS(1959),
    [anon_sym_COLON_COLON] = ACTIONS(1961),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1961),
    [anon_sym___declspec] = ACTIONS(1959),
    [anon_sym___based] = ACTIONS(1959),
    [anon_sym_LBRACE] = ACTIONS(1961),
    [anon_sym_LBRACK] = ACTIONS(4065),
    [anon_sym_static] = ACTIONS(1959),
    [anon_sym_EQ] = ACTIONS(1959),
    [anon_sym_register] = ACTIONS(1959),
    [anon_sym_inline] = ACTIONS(1959),
    [anon_sym___inline] = ACTIONS(1959),
    [anon_sym___inline__] = ACTIONS(1959),
    [anon_sym___forceinline] = ACTIONS(1959),
    [anon_sym_thread_local] = ACTIONS(1959),
    [anon_sym___thread] = ACTIONS(1959),
    [anon_sym_const] = ACTIONS(1959),
    [anon_sym_constexpr] = ACTIONS(1959),
    [anon_sym_volatile] = ACTIONS(1959),
    [anon_sym_restrict] = ACTIONS(1959),
    [anon_sym___restrict__] = ACTIONS(1959),
    [anon_sym__Atomic] = ACTIONS(1959),
    [anon_sym__Noreturn] = ACTIONS(1959),
    [anon_sym_noreturn] = ACTIONS(1959),
    [anon_sym_mutable] = ACTIONS(1959),
    [anon_sym_constinit] = ACTIONS(1959),
    [anon_sym_consteval] = ACTIONS(1959),
    [anon_sym_alignas] = ACTIONS(1959),
    [anon_sym__Alignas] = ACTIONS(1959),
    [anon_sym_QMARK] = ACTIONS(4058),
    [anon_sym_LT_EQ_GT] = ACTIONS(4058),
    [anon_sym_or] = ACTIONS(4063),
    [anon_sym_and] = ACTIONS(4063),
    [anon_sym_bitor] = ACTIONS(4063),
    [anon_sym_xor] = ACTIONS(4063),
    [anon_sym_bitand] = ACTIONS(4063),
    [anon_sym_not_eq] = ACTIONS(4063),
    [anon_sym_DASH_DASH] = ACTIONS(4058),
    [anon_sym_PLUS_PLUS] = ACTIONS(4058),
    [anon_sym_DOT] = ACTIONS(4063),
    [anon_sym_DOT_STAR] = ACTIONS(4058),
    [anon_sym_DASH_GT] = ACTIONS(4058),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1959),
    [anon_sym_decltype] = ACTIONS(1959),
    [sym_virtual] = ACTIONS(1959),
    [anon_sym_template] = ACTIONS(1959),
    [anon_sym_operator] = ACTIONS(1959),
    [anon_sym_precise] = ACTIONS(1959),
    [anon_sym_shared] = ACTIONS(1959),
    [anon_sym_groupshared] = ACTIONS(1959),
    [anon_sym_uniform] = ACTIONS(1959),
    [anon_sym_row_major] = ACTIONS(1959),
    [anon_sym_column_major] = ACTIONS(1959),
    [anon_sym_globallycoherent] = ACTIONS(1959),
    [anon_sym_centroid] = ACTIONS(1959),
    [anon_sym_noperspective] = ACTIONS(1959),
    [anon_sym_nointerpolation] = ACTIONS(1959),
    [anon_sym_sample] = ACTIONS(1959),
    [anon_sym_linear] = ACTIONS(1959),
    [anon_sym_snorm] = ACTIONS(1959),
    [anon_sym_unorm] = ACTIONS(1959),
    [anon_sym_point] = ACTIONS(1959),
    [anon_sym_line] = ACTIONS(1959),
    [anon_sym_triangleadj] = ACTIONS(1959),
    [anon_sym_lineadj] = ACTIONS(1959),
    [anon_sym_triangle] = ACTIONS(1959),
  },
  [1315] = {
    [sym_expression] = STATE(2723),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_initializer_list] = STATE(2848),
    [sym_char_literal] = STATE(3360),
    [sym_concatenated_string] = STATE(3359),
    [sym_string_literal] = STATE(2634),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2625),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3635),
    [anon_sym_LPAREN2] = ACTIONS(4658),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3641),
    [anon_sym_LBRACE] = ACTIONS(3523),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3637),
    [anon_sym_compl] = ACTIONS(3637),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_sizeof] = ACTIONS(3643),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3645),
    [anon_sym_L_SQUOTE] = ACTIONS(3647),
    [anon_sym_u_SQUOTE] = ACTIONS(3647),
    [anon_sym_U_SQUOTE] = ACTIONS(3647),
    [anon_sym_u8_SQUOTE] = ACTIONS(3647),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [anon_sym_L_DQUOTE] = ACTIONS(3649),
    [anon_sym_u_DQUOTE] = ACTIONS(3649),
    [anon_sym_U_DQUOTE] = ACTIONS(3649),
    [anon_sym_u8_DQUOTE] = ACTIONS(3649),
    [anon_sym_DQUOTE] = ACTIONS(3649),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3651),
    [anon_sym_R_DQUOTE] = ACTIONS(3653),
    [anon_sym_LR_DQUOTE] = ACTIONS(3653),
    [anon_sym_uR_DQUOTE] = ACTIONS(3653),
    [anon_sym_UR_DQUOTE] = ACTIONS(3653),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3653),
    [anon_sym_co_await] = ACTIONS(3655),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1316] = {
    [sym_expression] = STATE(4578),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8052),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON] = ACTIONS(4660),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1317] = {
    [sym_expression] = STATE(4700),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(8370),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1318] = {
    [sym_expression] = STATE(4528),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_initializer_list] = STATE(4009),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1319] = {
    [sym_expression] = STATE(3905),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_initializer_list] = STATE(4009),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_LPAREN2] = ACTIONS(4662),
    [anon_sym_BANG] = ACTIONS(3948),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3946),
    [anon_sym_PLUS] = ACTIONS(3946),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_DASH_DASH] = ACTIONS(4537),
    [anon_sym_PLUS_PLUS] = ACTIONS(4537),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1320] = {
    [sym_expression] = STATE(4487),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8417),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON] = ACTIONS(4666),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1321] = {
    [sym_expression] = STATE(4455),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_initializer_list] = STATE(7594),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1322] = {
    [sym_expression] = STATE(4612),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(8475),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1323] = {
    [sym_expression] = STATE(4512),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8469),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_RPAREN] = ACTIONS(4668),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1324] = {
    [sym_expression] = STATE(3709),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_initializer_list] = STATE(3939),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACE] = ACTIONS(3741),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1325] = {
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_COMMA] = ACTIONS(4670),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4670),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1326] = {
    [sym_expression] = STATE(3762),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_initializer_list] = STATE(3967),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACE] = ACTIONS(3741),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1327] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4805),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_call_modifier] = STATE(1954),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1328] = {
    [sym_expression] = STATE(4494),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8137),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON] = ACTIONS(4674),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1329] = {
    [sym_expression] = STATE(4178),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_initializer_list] = STATE(4028),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_LPAREN2] = ACTIONS(4662),
    [anon_sym_BANG] = ACTIONS(3948),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3946),
    [anon_sym_PLUS] = ACTIONS(3946),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_DASH_DASH] = ACTIONS(4537),
    [anon_sym_PLUS_PLUS] = ACTIONS(4537),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1330] = {
    [sym__declaration_modifiers] = STATE(1984),
    [sym__declaration_specifiers] = STATE(4082),
    [sym_attribute_specifier] = STATE(1984),
    [sym_attribute_declaration] = STATE(1984),
    [sym_ms_declspec_modifier] = STATE(1984),
    [sym_storage_class_specifier] = STATE(1984),
    [sym_type_qualifier] = STATE(1984),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_parameter_declaration] = STATE(7616),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_type_parameter_declaration] = STATE(7616),
    [sym_variadic_type_parameter_declaration] = STATE(7616),
    [sym_optional_type_parameter_declaration] = STATE(7616),
    [sym_template_template_parameter_declaration] = STATE(7616),
    [sym_optional_parameter_declaration] = STATE(7616),
    [sym_variadic_parameter_declaration] = STATE(7616),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6449),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1984),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1984),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(4068),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1827),
    [anon_sym_out] = ACTIONS(1827),
    [anon_sym_inout] = ACTIONS(1827),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(4078),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(1833),
    [anon_sym_class] = ACTIONS(4570),
    [anon_sym_struct] = ACTIONS(1837),
    [anon_sym_union] = ACTIONS(1839),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1827),
    [anon_sym_typename] = ACTIONS(4572),
    [anon_sym_template] = ACTIONS(4574),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1331] = {
    [sym_expression] = STATE(3462),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_initializer_list] = STATE(2848),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4676),
    [anon_sym_BANG] = ACTIONS(3713),
    [anon_sym_TILDE] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3711),
    [anon_sym_PLUS] = ACTIONS(3711),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(3715),
    [anon_sym_LBRACE] = ACTIONS(3523),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3711),
    [anon_sym_compl] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(4562),
    [anon_sym_PLUS_PLUS] = ACTIONS(4562),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3719),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1332] = {
    [sym_expression] = STATE(4377),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_initializer_list] = STATE(4028),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1333] = {
    [sym_expression] = STATE(4463),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7843),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON] = ACTIONS(4678),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1334] = {
    [sym_expression] = STATE(4501),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8701),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON] = ACTIONS(4680),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1335] = {
    [sym_expression] = STATE(2723),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_initializer_list] = STATE(2848),
    [sym_char_literal] = STATE(3061),
    [sym_concatenated_string] = STATE(3059),
    [sym_string_literal] = STATE(2449),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2444),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4682),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3521),
    [anon_sym_LBRACE] = ACTIONS(3523),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3517),
    [anon_sym_compl] = ACTIONS(3517),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_sizeof] = ACTIONS(3527),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3537),
    [anon_sym_L_SQUOTE] = ACTIONS(3539),
    [anon_sym_u_SQUOTE] = ACTIONS(3539),
    [anon_sym_U_SQUOTE] = ACTIONS(3539),
    [anon_sym_u8_SQUOTE] = ACTIONS(3539),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3547),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [anon_sym_co_await] = ACTIONS(3551),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1336] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4814),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_call_modifier] = STATE(1952),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1337] = {
    [sym_expression] = STATE(4473),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8604),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON] = ACTIONS(4684),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1338] = {
    [sym_expression] = STATE(4532),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8228),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON] = ACTIONS(4686),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1339] = {
    [sym_expression] = STATE(4481),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7917),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON] = ACTIONS(4688),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1340] = {
    [sym_expression] = STATE(4469),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8400),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON] = ACTIONS(4690),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1341] = {
    [sym_expression] = STATE(3905),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(4009),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1342] = {
    [sym_expression] = STATE(3905),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_initializer_list] = STATE(4009),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1343] = {
    [sym_expression] = STATE(2723),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_initializer_list] = STATE(2848),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACE] = ACTIONS(3523),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1344] = {
    [sym_expression] = STATE(4553),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8184),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_RPAREN] = ACTIONS(4692),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1345] = {
    [sym_expression] = STATE(4454),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8255),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON] = ACTIONS(4694),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1346] = {
    [sym_expression] = STATE(3367),
    [sym__string] = STATE(2844),
    [sym_comma_expression] = STATE(8453),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym__assignment_expression_lhs] = STATE(8546),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1347] = {
    [sym_expression] = STATE(4559),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8186),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_RPAREN] = ACTIONS(4696),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1348] = {
    [sym_expression] = STATE(3270),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_initializer_list] = STATE(3608),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACE] = ACTIONS(3627),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1349] = {
    [sym_expression] = STATE(4334),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7780),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1350] = {
    [sym_expression] = STATE(4339),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_initializer_list] = STATE(7256),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1351] = {
    [sym_expression] = STATE(4562),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8189),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(2676),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1352] = {
    [sym_expression] = STATE(3905),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_initializer_list] = STATE(4009),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1353] = {
    [sym_expression] = STATE(4531),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(7780),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1354] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4813),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_call_modifier] = STATE(1944),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1355] = {
    [sym_expression] = STATE(4505),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8575),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON] = ACTIONS(4698),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1356] = {
    [sym_expression] = STATE(4548),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8300),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_RPAREN] = ACTIONS(4700),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1357] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4804),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_call_modifier] = STATE(1958),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1358] = {
    [sym_expression] = STATE(4480),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7941),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(2710),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1359] = {
    [sym_expression] = STATE(4546),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(8301),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_RPAREN] = ACTIONS(4702),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1360] = {
    [sym_expression] = STATE(4260),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_initializer_list] = STATE(8303),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1361] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4780),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_ms_call_modifier] = STATE(1941),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym___cdecl] = ACTIONS(51),
    [anon_sym___clrcall] = ACTIONS(51),
    [anon_sym___stdcall] = ACTIONS(51),
    [anon_sym___fastcall] = ACTIONS(51),
    [anon_sym___thiscall] = ACTIONS(51),
    [anon_sym___vectorcall] = ACTIONS(51),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1362] = {
    [sym_expression] = STATE(3938),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4704),
    [anon_sym_LPAREN2] = ACTIONS(4706),
    [anon_sym_BANG] = ACTIONS(3948),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3946),
    [anon_sym_PLUS] = ACTIONS(3946),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_DASH_DASH] = ACTIONS(4537),
    [anon_sym_PLUS_PLUS] = ACTIONS(4537),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1363] = {
    [sym_expression] = STATE(4660),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4708),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1364] = {
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4710),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1365] = {
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4712),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1366] = {
    [sym_expression] = STATE(3276),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4714),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1367] = {
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4717),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1368] = {
    [sym_expression] = STATE(2760),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3360),
    [sym_concatenated_string] = STATE(3359),
    [sym_string_literal] = STATE(2634),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2625),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3635),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4719),
    [anon_sym_LPAREN2] = ACTIONS(4721),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3641),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3637),
    [anon_sym_compl] = ACTIONS(3637),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_sizeof] = ACTIONS(3643),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3645),
    [anon_sym_L_SQUOTE] = ACTIONS(3647),
    [anon_sym_u_SQUOTE] = ACTIONS(3647),
    [anon_sym_U_SQUOTE] = ACTIONS(3647),
    [anon_sym_u8_SQUOTE] = ACTIONS(3647),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [anon_sym_L_DQUOTE] = ACTIONS(3649),
    [anon_sym_u_DQUOTE] = ACTIONS(3649),
    [anon_sym_U_DQUOTE] = ACTIONS(3649),
    [anon_sym_u8_DQUOTE] = ACTIONS(3649),
    [anon_sym_DQUOTE] = ACTIONS(3649),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3651),
    [anon_sym_R_DQUOTE] = ACTIONS(3653),
    [anon_sym_LR_DQUOTE] = ACTIONS(3653),
    [anon_sym_uR_DQUOTE] = ACTIONS(3653),
    [anon_sym_UR_DQUOTE] = ACTIONS(3653),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3653),
    [anon_sym_co_await] = ACTIONS(3655),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1369] = {
    [sym_expression] = STATE(4329),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7015),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1370] = {
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4723),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1371] = {
    [sym_expression] = STATE(2760),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3061),
    [sym_concatenated_string] = STATE(3059),
    [sym_string_literal] = STATE(2449),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2444),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4719),
    [anon_sym_LPAREN2] = ACTIONS(4725),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3521),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3517),
    [anon_sym_compl] = ACTIONS(3517),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_sizeof] = ACTIONS(3527),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3537),
    [anon_sym_L_SQUOTE] = ACTIONS(3539),
    [anon_sym_u_SQUOTE] = ACTIONS(3539),
    [anon_sym_U_SQUOTE] = ACTIONS(3539),
    [anon_sym_u8_SQUOTE] = ACTIONS(3539),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3547),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [anon_sym_co_await] = ACTIONS(3551),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1372] = {
    [sym_expression] = STATE(3290),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4727),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1373] = {
    [sym_expression] = STATE(3285),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1374] = {
    [sym_expression] = STATE(4709),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4733),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1375] = {
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4735),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1376] = {
    [sym_expression] = STATE(3277),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4737),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1377] = {
    [sym_expression] = STATE(3284),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4740),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1378] = {
    [sym_expression] = STATE(4645),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4743),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1379] = {
    [sym_expression] = STATE(3278),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4745),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1380] = {
    [sym_expression] = STATE(3280),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4748),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1381] = {
    [sym_expression] = STATE(3284),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4751),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1382] = {
    [sym_expression] = STATE(4590),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4754),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1383] = {
    [sym_expression] = STATE(3285),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4756),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1384] = {
    [sym_expression] = STATE(4594),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4759),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1385] = {
    [sym_expression] = STATE(3938),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4704),
    [anon_sym_LPAREN2] = ACTIONS(4761),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1386] = {
    [sym_expression] = STATE(3280),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4763),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1387] = {
    [sym_expression] = STATE(3350),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4766),
    [anon_sym_LPAREN2] = ACTIONS(4768),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1388] = {
    [sym_expression] = STATE(3668),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4770),
    [anon_sym_LPAREN2] = ACTIONS(4772),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1389] = {
    [sym_expression] = STATE(4657),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4774),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1390] = {
    [sym_expression] = STATE(3290),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4776),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1391] = {
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4779),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1392] = {
    [sym_expression] = STATE(3290),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4781),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1393] = {
    [sym_expression] = STATE(3296),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4784),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1394] = {
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4787),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1395] = {
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4789),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1396] = {
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4791),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1397] = {
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4793),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1398] = {
    [sym_expression] = STATE(4640),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_RPAREN] = ACTIONS(4795),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1399] = {
    [sym_expression] = STATE(4593),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4797),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1400] = {
    [sym_expression] = STATE(4627),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4799),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1401] = {
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4801),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1402] = {
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4803),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1403] = {
    [sym_expression] = STATE(4631),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4805),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1404] = {
    [sym_expression] = STATE(3434),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4719),
    [anon_sym_LPAREN2] = ACTIONS(4807),
    [anon_sym_BANG] = ACTIONS(3713),
    [anon_sym_TILDE] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3711),
    [anon_sym_PLUS] = ACTIONS(3711),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(3715),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3711),
    [anon_sym_compl] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(4562),
    [anon_sym_PLUS_PLUS] = ACTIONS(4562),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3719),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1405] = {
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4809),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1406] = {
    [sym_expression] = STATE(4415),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_SEMI] = ACTIONS(4811),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACK] = ACTIONS(4813),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1407] = {
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4815),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1408] = {
    [sym_expression] = STATE(3278),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4817),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1409] = {
    [sym_expression] = STATE(4596),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4820),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1410] = {
    [sym_expression] = STATE(4655),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4822),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1411] = {
    [sym_expression] = STATE(4415),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_SEMI] = ACTIONS(4824),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACK] = ACTIONS(4813),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1412] = {
    [sym_expression] = STATE(4602),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4826),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1413] = {
    [sym_expression] = STATE(4415),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_SEMI] = ACTIONS(4828),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACK] = ACTIONS(4813),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1414] = {
    [sym_expression] = STATE(4585),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4830),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1415] = {
    [sym_expression] = STATE(3277),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4832),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1416] = {
    [sym_expression] = STATE(3276),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4835),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1417] = {
    [sym_expression] = STATE(3276),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4838),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1418] = {
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4841),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1419] = {
    [sym_expression] = STATE(3275),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4843),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1420] = {
    [sym_expression] = STATE(3758),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4846),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1421] = {
    [sym_expression] = STATE(3758),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4784),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1422] = {
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4849),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1423] = {
    [sym_expression] = STATE(3759),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4781),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1424] = {
    [sym_expression] = STATE(3759),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4776),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1425] = {
    [sym_expression] = STATE(3759),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4727),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1426] = {
    [sym_expression] = STATE(4715),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4851),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1427] = {
    [sym_expression] = STATE(3765),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4730),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1428] = {
    [sym_expression] = STATE(4593),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4853),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1429] = {
    [sym_expression] = STATE(3774),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4740),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1430] = {
    [sym_expression] = STATE(3275),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4855),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1431] = {
    [sym_expression] = STATE(3778),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4763),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1432] = {
    [sym_expression] = STATE(3384),
    [sym__string] = STATE(3729),
    [sym_conditional_expression] = STATE(3729),
    [sym_assignment_expression] = STATE(3729),
    [sym_pointer_expression] = STATE(3736),
    [sym_unary_expression] = STATE(3729),
    [sym_binary_expression] = STATE(3729),
    [sym_update_expression] = STATE(3729),
    [sym_cast_expression] = STATE(3729),
    [sym_sizeof_expression] = STATE(3729),
    [sym_alignof_expression] = STATE(3729),
    [sym_offsetof_expression] = STATE(3729),
    [sym_generic_expression] = STATE(3729),
    [sym_subscript_expression] = STATE(3736),
    [sym_call_expression] = STATE(3736),
    [sym_gnu_asm_expression] = STATE(3729),
    [sym_field_expression] = STATE(3736),
    [sym_compound_literal_expression] = STATE(3729),
    [sym_parenthesized_expression] = STATE(3736),
    [sym_char_literal] = STATE(3602),
    [sym_concatenated_string] = STATE(3610),
    [sym_string_literal] = STATE(2698),
    [sym_null] = STATE(3729),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7745),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3729),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(3729),
    [sym_new_expression] = STATE(3729),
    [sym_delete_expression] = STATE(3729),
    [sym_requires_clause] = STATE(3729),
    [sym_requires_expression] = STATE(3729),
    [sym_lambda_expression] = STATE(3729),
    [sym_lambda_capture_specifier] = STATE(5813),
    [sym_fold_expression] = STATE(3729),
    [sym_parameter_pack_expansion] = STATE(3729),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3736),
    [sym_qualified_type_identifier] = STATE(7745),
    [sym_user_defined_literal] = STATE(3736),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4858),
    [anon_sym_LPAREN2] = ACTIONS(4860),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3673),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3669),
    [anon_sym_compl] = ACTIONS(3669),
    [anon_sym_DASH_DASH] = ACTIONS(4558),
    [anon_sym_PLUS_PLUS] = ACTIONS(4558),
    [anon_sym_sizeof] = ACTIONS(3679),
    [anon_sym___alignof__] = ACTIONS(3681),
    [anon_sym___alignof] = ACTIONS(3681),
    [anon_sym__alignof] = ACTIONS(3681),
    [anon_sym_alignof] = ACTIONS(3681),
    [anon_sym__Alignof] = ACTIONS(3681),
    [anon_sym_offsetof] = ACTIONS(3683),
    [anon_sym__Generic] = ACTIONS(3685),
    [anon_sym_asm] = ACTIONS(3687),
    [anon_sym___asm__] = ACTIONS(3687),
    [sym_number_literal] = ACTIONS(3689),
    [anon_sym_L_SQUOTE] = ACTIONS(3691),
    [anon_sym_u_SQUOTE] = ACTIONS(3691),
    [anon_sym_U_SQUOTE] = ACTIONS(3691),
    [anon_sym_u8_SQUOTE] = ACTIONS(3691),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [anon_sym_L_DQUOTE] = ACTIONS(3693),
    [anon_sym_u_DQUOTE] = ACTIONS(3693),
    [anon_sym_U_DQUOTE] = ACTIONS(3693),
    [anon_sym_u8_DQUOTE] = ACTIONS(3693),
    [anon_sym_DQUOTE] = ACTIONS(3693),
    [sym_true] = ACTIONS(3695),
    [sym_false] = ACTIONS(3695),
    [anon_sym_NULL] = ACTIONS(3697),
    [anon_sym_nullptr] = ACTIONS(3697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3699),
    [anon_sym_R_DQUOTE] = ACTIONS(3701),
    [anon_sym_LR_DQUOTE] = ACTIONS(3701),
    [anon_sym_uR_DQUOTE] = ACTIONS(3701),
    [anon_sym_UR_DQUOTE] = ACTIONS(3701),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3701),
    [anon_sym_co_await] = ACTIONS(3703),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_requires] = ACTIONS(3707),
    [sym_this] = ACTIONS(3695),
  },
  [1433] = {
    [sym_expression] = STATE(3783),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4817),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1434] = {
    [sym_expression] = STATE(3785),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4832),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1435] = {
    [sym_expression] = STATE(4564),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4704),
    [anon_sym_LPAREN2] = ACTIONS(4862),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1436] = {
    [sym_expression] = STATE(3799),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4835),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1437] = {
    [sym_expression] = STATE(3275),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4864),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1438] = {
    [sym_expression] = STATE(3799),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4838),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1439] = {
    [sym_expression] = STATE(3789),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4843),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1440] = {
    [sym_expression] = STATE(3789),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4855),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1441] = {
    [sym_expression] = STATE(3789),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4864),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1442] = {
    [sym_expression] = STATE(3789),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4867),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1443] = {
    [sym_expression] = STATE(3780),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4870),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1444] = {
    [sym_expression] = STATE(3780),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4873),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1445] = {
    [sym_expression] = STATE(3765),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4756),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1446] = {
    [sym_expression] = STATE(3774),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4751),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1447] = {
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4876),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1448] = {
    [sym_expression] = STATE(4555),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4878),
    [anon_sym_LPAREN2] = ACTIONS(4880),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1449] = {
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4882),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1450] = {
    [sym_expression] = STATE(4704),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4884),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1451] = {
    [sym_expression] = STATE(3275),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4867),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1452] = {
    [sym_expression] = STATE(3778),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4748),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1453] = {
    [sym_expression] = STATE(3938),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4704),
    [anon_sym_LPAREN2] = ACTIONS(4886),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1454] = {
    [sym_expression] = STATE(3272),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4870),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1455] = {
    [sym_expression] = STATE(3783),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4745),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1456] = {
    [sym_identifier] = ACTIONS(1959),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4058),
    [anon_sym_COMMA] = ACTIONS(4058),
    [anon_sym_RPAREN] = ACTIONS(4058),
    [anon_sym_LPAREN2] = ACTIONS(4060),
    [anon_sym_TILDE] = ACTIONS(1961),
    [anon_sym_DASH] = ACTIONS(4063),
    [anon_sym_PLUS] = ACTIONS(4063),
    [anon_sym_STAR] = ACTIONS(4060),
    [anon_sym_SLASH] = ACTIONS(4063),
    [anon_sym_PERCENT] = ACTIONS(4058),
    [anon_sym_PIPE_PIPE] = ACTIONS(4058),
    [anon_sym_AMP_AMP] = ACTIONS(4060),
    [anon_sym_PIPE] = ACTIONS(4063),
    [anon_sym_CARET] = ACTIONS(4058),
    [anon_sym_AMP] = ACTIONS(4065),
    [anon_sym_EQ_EQ] = ACTIONS(4058),
    [anon_sym_BANG_EQ] = ACTIONS(4058),
    [anon_sym_GT] = ACTIONS(4063),
    [anon_sym_GT_EQ] = ACTIONS(4058),
    [anon_sym_LT_EQ] = ACTIONS(4063),
    [anon_sym_LT] = ACTIONS(4063),
    [anon_sym_LT_LT] = ACTIONS(4058),
    [anon_sym_GT_GT] = ACTIONS(4058),
    [anon_sym_SEMI] = ACTIONS(4058),
    [anon_sym___extension__] = ACTIONS(1959),
    [anon_sym_in] = ACTIONS(1959),
    [anon_sym_out] = ACTIONS(1959),
    [anon_sym_inout] = ACTIONS(1959),
    [anon_sym_extern] = ACTIONS(1959),
    [anon_sym___attribute__] = ACTIONS(1959),
    [anon_sym_COLON_COLON] = ACTIONS(1961),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1961),
    [anon_sym___declspec] = ACTIONS(1959),
    [anon_sym___based] = ACTIONS(1959),
    [anon_sym_LBRACE] = ACTIONS(1961),
    [anon_sym_LBRACK] = ACTIONS(4065),
    [anon_sym_static] = ACTIONS(1959),
    [anon_sym_register] = ACTIONS(1959),
    [anon_sym_inline] = ACTIONS(1959),
    [anon_sym___inline] = ACTIONS(1959),
    [anon_sym___inline__] = ACTIONS(1959),
    [anon_sym___forceinline] = ACTIONS(1959),
    [anon_sym_thread_local] = ACTIONS(1959),
    [anon_sym___thread] = ACTIONS(1959),
    [anon_sym_const] = ACTIONS(1959),
    [anon_sym_constexpr] = ACTIONS(1959),
    [anon_sym_volatile] = ACTIONS(1959),
    [anon_sym_restrict] = ACTIONS(1959),
    [anon_sym___restrict__] = ACTIONS(1959),
    [anon_sym__Atomic] = ACTIONS(1959),
    [anon_sym__Noreturn] = ACTIONS(1959),
    [anon_sym_noreturn] = ACTIONS(1959),
    [anon_sym_mutable] = ACTIONS(1959),
    [anon_sym_constinit] = ACTIONS(1959),
    [anon_sym_consteval] = ACTIONS(1959),
    [anon_sym_alignas] = ACTIONS(1959),
    [anon_sym__Alignas] = ACTIONS(1959),
    [anon_sym_QMARK] = ACTIONS(4058),
    [anon_sym_LT_EQ_GT] = ACTIONS(4058),
    [anon_sym_or] = ACTIONS(4063),
    [anon_sym_and] = ACTIONS(4063),
    [anon_sym_bitor] = ACTIONS(4063),
    [anon_sym_xor] = ACTIONS(4063),
    [anon_sym_bitand] = ACTIONS(4063),
    [anon_sym_not_eq] = ACTIONS(4063),
    [anon_sym_DASH_DASH] = ACTIONS(4058),
    [anon_sym_PLUS_PLUS] = ACTIONS(4058),
    [anon_sym_DOT] = ACTIONS(4063),
    [anon_sym_DOT_STAR] = ACTIONS(4058),
    [anon_sym_DASH_GT] = ACTIONS(4058),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1959),
    [anon_sym_decltype] = ACTIONS(1959),
    [sym_virtual] = ACTIONS(1959),
    [anon_sym_template] = ACTIONS(1959),
    [anon_sym_operator] = ACTIONS(1959),
    [anon_sym_precise] = ACTIONS(1959),
    [anon_sym_shared] = ACTIONS(1959),
    [anon_sym_groupshared] = ACTIONS(1959),
    [anon_sym_uniform] = ACTIONS(1959),
    [anon_sym_row_major] = ACTIONS(1959),
    [anon_sym_column_major] = ACTIONS(1959),
    [anon_sym_globallycoherent] = ACTIONS(1959),
    [anon_sym_centroid] = ACTIONS(1959),
    [anon_sym_noperspective] = ACTIONS(1959),
    [anon_sym_nointerpolation] = ACTIONS(1959),
    [anon_sym_sample] = ACTIONS(1959),
    [anon_sym_linear] = ACTIONS(1959),
    [anon_sym_snorm] = ACTIONS(1959),
    [anon_sym_unorm] = ACTIONS(1959),
    [anon_sym_point] = ACTIONS(1959),
    [anon_sym_line] = ACTIONS(1959),
    [anon_sym_triangleadj] = ACTIONS(1959),
    [anon_sym_lineadj] = ACTIONS(1959),
    [anon_sym_triangle] = ACTIONS(1959),
  },
  [1457] = {
    [sym_expression] = STATE(3785),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4737),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1458] = {
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4888),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1459] = {
    [sym_expression] = STATE(4611),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4890),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1460] = {
    [sym_expression] = STATE(4613),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4892),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1461] = {
    [sym_expression] = STATE(4729),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(4894),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1462] = {
    [sym_expression] = STATE(3272),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4873),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1463] = {
    [sym_expression] = STATE(3296),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4846),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1464] = {
    [sym_expression] = STATE(3938),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4704),
    [anon_sym_LPAREN2] = ACTIONS(4896),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1465] = {
    [sym_expression] = STATE(4706),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_SEMI] = ACTIONS(4898),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1466] = {
    [sym_expression] = STATE(3799),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4714),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1467] = {
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [anon_sym_RBRACK] = ACTIONS(4900),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1468] = {
    [sym_expression] = STATE(4476),
    [sym__string] = STATE(4019),
    [sym_comma_expression] = STATE(7015),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1469] = {
    [sym_expression] = STATE(2760),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4719),
    [anon_sym_LPAREN2] = ACTIONS(4902),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1470] = {
    [sym_expression] = STATE(4262),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1471] = {
    [sym_expression] = STATE(3423),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4676),
    [anon_sym_BANG] = ACTIONS(3713),
    [anon_sym_TILDE] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3711),
    [anon_sym_PLUS] = ACTIONS(3711),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(3715),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3711),
    [anon_sym_compl] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(4562),
    [anon_sym_PLUS_PLUS] = ACTIONS(4562),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3719),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1472] = {
    [sym_expression] = STATE(3902),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_LPAREN2] = ACTIONS(4662),
    [anon_sym_BANG] = ACTIONS(3948),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3946),
    [anon_sym_PLUS] = ACTIONS(3946),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_DASH_DASH] = ACTIONS(4537),
    [anon_sym_PLUS_PLUS] = ACTIONS(4537),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1473] = {
    [sym_expression] = STATE(4318),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1474] = {
    [sym_expression] = STATE(4180),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_LPAREN2] = ACTIONS(4662),
    [anon_sym_BANG] = ACTIONS(3948),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3946),
    [anon_sym_PLUS] = ACTIONS(3946),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACK] = ACTIONS(4904),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_DASH_DASH] = ACTIONS(4537),
    [anon_sym_PLUS_PLUS] = ACTIONS(4537),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1475] = {
    [sym_expression] = STATE(4582),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1476] = {
    [sym_expression] = STATE(4384),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1477] = {
    [sym_expression] = STATE(2756),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1478] = {
    [sym_expression] = STATE(2712),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(4906),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1479] = {
    [sym_expression] = STATE(2712),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1480] = {
    [sym_expression] = STATE(3931),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1481] = {
    [sym_expression] = STATE(4464),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1482] = {
    [sym_expression] = STATE(2954),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3061),
    [sym_concatenated_string] = STATE(3059),
    [sym_string_literal] = STATE(2449),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2444),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4682),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3521),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3517),
    [anon_sym_compl] = ACTIONS(3517),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_sizeof] = ACTIONS(3527),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3537),
    [anon_sym_L_SQUOTE] = ACTIONS(3539),
    [anon_sym_u_SQUOTE] = ACTIONS(3539),
    [anon_sym_U_SQUOTE] = ACTIONS(3539),
    [anon_sym_u8_SQUOTE] = ACTIONS(3539),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3547),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [anon_sym_co_await] = ACTIONS(3551),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1483] = {
    [sym_expression] = STATE(4583),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(4908),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1484] = {
    [sym_expression] = STATE(2967),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3061),
    [sym_concatenated_string] = STATE(3059),
    [sym_string_literal] = STATE(2449),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2444),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4682),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3521),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3517),
    [anon_sym_compl] = ACTIONS(3517),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_sizeof] = ACTIONS(3527),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3537),
    [anon_sym_L_SQUOTE] = ACTIONS(3539),
    [anon_sym_u_SQUOTE] = ACTIONS(3539),
    [anon_sym_U_SQUOTE] = ACTIONS(3539),
    [anon_sym_u8_SQUOTE] = ACTIONS(3539),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3547),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [anon_sym_co_await] = ACTIONS(3551),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1485] = {
    [sym_expression] = STATE(4193),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_LPAREN2] = ACTIONS(4662),
    [anon_sym_BANG] = ACTIONS(3948),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3946),
    [anon_sym_PLUS] = ACTIONS(3946),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_DASH_DASH] = ACTIONS(4537),
    [anon_sym_PLUS_PLUS] = ACTIONS(4537),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1486] = {
    [sym_expression] = STATE(3931),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1487] = {
    [sym_expression] = STATE(4629),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1488] = {
    [sym_expression] = STATE(2743),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3061),
    [sym_concatenated_string] = STATE(3059),
    [sym_string_literal] = STATE(2449),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2444),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4682),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3521),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3517),
    [anon_sym_compl] = ACTIONS(3517),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_sizeof] = ACTIONS(3527),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3537),
    [anon_sym_L_SQUOTE] = ACTIONS(3539),
    [anon_sym_u_SQUOTE] = ACTIONS(3539),
    [anon_sym_U_SQUOTE] = ACTIONS(3539),
    [anon_sym_u8_SQUOTE] = ACTIONS(3539),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3547),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [anon_sym_co_await] = ACTIONS(3551),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1489] = {
    [sym_expression] = STATE(4624),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1490] = {
    [sym_expression] = STATE(3902),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1491] = {
    [sym_expression] = STATE(4597),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1492] = {
    [sym_expression] = STATE(3018),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3061),
    [sym_concatenated_string] = STATE(3059),
    [sym_string_literal] = STATE(2449),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2444),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4682),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3521),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3517),
    [anon_sym_compl] = ACTIONS(3517),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_sizeof] = ACTIONS(3527),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3537),
    [anon_sym_L_SQUOTE] = ACTIONS(3539),
    [anon_sym_u_SQUOTE] = ACTIONS(3539),
    [anon_sym_U_SQUOTE] = ACTIONS(3539),
    [anon_sym_u8_SQUOTE] = ACTIONS(3539),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3547),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [anon_sym_co_await] = ACTIONS(3551),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1493] = {
    [sym_expression] = STATE(3025),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3061),
    [sym_concatenated_string] = STATE(3059),
    [sym_string_literal] = STATE(2449),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2444),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4682),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3521),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3517),
    [anon_sym_compl] = ACTIONS(3517),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_sizeof] = ACTIONS(3527),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3537),
    [anon_sym_L_SQUOTE] = ACTIONS(3539),
    [anon_sym_u_SQUOTE] = ACTIONS(3539),
    [anon_sym_U_SQUOTE] = ACTIONS(3539),
    [anon_sym_u8_SQUOTE] = ACTIONS(3539),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3547),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [anon_sym_co_await] = ACTIONS(3551),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1494] = {
    [sym_expression] = STATE(3126),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(4910),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1495] = {
    [sym_expression] = STATE(4646),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1496] = {
    [sym_expression] = STATE(4642),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1497] = {
    [sym_expression] = STATE(2956),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3061),
    [sym_concatenated_string] = STATE(3059),
    [sym_string_literal] = STATE(2449),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2444),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4682),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3521),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3517),
    [anon_sym_compl] = ACTIONS(3517),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_sizeof] = ACTIONS(3527),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3537),
    [anon_sym_L_SQUOTE] = ACTIONS(3539),
    [anon_sym_u_SQUOTE] = ACTIONS(3539),
    [anon_sym_U_SQUOTE] = ACTIONS(3539),
    [anon_sym_u8_SQUOTE] = ACTIONS(3539),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3547),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [anon_sym_co_await] = ACTIONS(3551),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1498] = {
    [sym_expression] = STATE(3021),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3061),
    [sym_concatenated_string] = STATE(3059),
    [sym_string_literal] = STATE(2449),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2444),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4682),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3521),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3517),
    [anon_sym_compl] = ACTIONS(3517),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_sizeof] = ACTIONS(3527),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3537),
    [anon_sym_L_SQUOTE] = ACTIONS(3539),
    [anon_sym_u_SQUOTE] = ACTIONS(3539),
    [anon_sym_U_SQUOTE] = ACTIONS(3539),
    [anon_sym_u8_SQUOTE] = ACTIONS(3539),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3547),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [anon_sym_co_await] = ACTIONS(3551),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1499] = {
    [sym_expression] = STATE(3382),
    [sym__string] = STATE(3729),
    [sym_conditional_expression] = STATE(3729),
    [sym_assignment_expression] = STATE(3729),
    [sym_pointer_expression] = STATE(3736),
    [sym_unary_expression] = STATE(3729),
    [sym_binary_expression] = STATE(3729),
    [sym_update_expression] = STATE(3729),
    [sym_cast_expression] = STATE(3729),
    [sym_sizeof_expression] = STATE(3729),
    [sym_alignof_expression] = STATE(3729),
    [sym_offsetof_expression] = STATE(3729),
    [sym_generic_expression] = STATE(3729),
    [sym_subscript_expression] = STATE(3736),
    [sym_call_expression] = STATE(3736),
    [sym_gnu_asm_expression] = STATE(3729),
    [sym_field_expression] = STATE(3736),
    [sym_compound_literal_expression] = STATE(3729),
    [sym_parenthesized_expression] = STATE(3736),
    [sym_char_literal] = STATE(3602),
    [sym_concatenated_string] = STATE(3610),
    [sym_string_literal] = STATE(2698),
    [sym_null] = STATE(3729),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7745),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3729),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(3729),
    [sym_new_expression] = STATE(3729),
    [sym_delete_expression] = STATE(3729),
    [sym_requires_clause] = STATE(3729),
    [sym_requires_expression] = STATE(3729),
    [sym_lambda_expression] = STATE(3729),
    [sym_lambda_capture_specifier] = STATE(5813),
    [sym_fold_expression] = STATE(3729),
    [sym_parameter_pack_expansion] = STATE(3729),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3736),
    [sym_qualified_type_identifier] = STATE(7745),
    [sym_user_defined_literal] = STATE(3736),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_LPAREN2] = ACTIONS(4656),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3673),
    [anon_sym_LBRACK] = ACTIONS(4912),
    [sym_primitive_type] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3669),
    [anon_sym_compl] = ACTIONS(3669),
    [anon_sym_DASH_DASH] = ACTIONS(4558),
    [anon_sym_PLUS_PLUS] = ACTIONS(4558),
    [anon_sym_sizeof] = ACTIONS(3679),
    [anon_sym___alignof__] = ACTIONS(3681),
    [anon_sym___alignof] = ACTIONS(3681),
    [anon_sym__alignof] = ACTIONS(3681),
    [anon_sym_alignof] = ACTIONS(3681),
    [anon_sym__Alignof] = ACTIONS(3681),
    [anon_sym_offsetof] = ACTIONS(3683),
    [anon_sym__Generic] = ACTIONS(3685),
    [anon_sym_asm] = ACTIONS(3687),
    [anon_sym___asm__] = ACTIONS(3687),
    [sym_number_literal] = ACTIONS(3689),
    [anon_sym_L_SQUOTE] = ACTIONS(3691),
    [anon_sym_u_SQUOTE] = ACTIONS(3691),
    [anon_sym_U_SQUOTE] = ACTIONS(3691),
    [anon_sym_u8_SQUOTE] = ACTIONS(3691),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [anon_sym_L_DQUOTE] = ACTIONS(3693),
    [anon_sym_u_DQUOTE] = ACTIONS(3693),
    [anon_sym_U_DQUOTE] = ACTIONS(3693),
    [anon_sym_u8_DQUOTE] = ACTIONS(3693),
    [anon_sym_DQUOTE] = ACTIONS(3693),
    [sym_true] = ACTIONS(3695),
    [sym_false] = ACTIONS(3695),
    [anon_sym_NULL] = ACTIONS(3697),
    [anon_sym_nullptr] = ACTIONS(3697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3699),
    [anon_sym_R_DQUOTE] = ACTIONS(3701),
    [anon_sym_LR_DQUOTE] = ACTIONS(3701),
    [anon_sym_uR_DQUOTE] = ACTIONS(3701),
    [anon_sym_UR_DQUOTE] = ACTIONS(3701),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3701),
    [anon_sym_co_await] = ACTIONS(3703),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_requires] = ACTIONS(3707),
    [sym_this] = ACTIONS(3695),
  },
  [1500] = {
    [sym_expression] = STATE(4350),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1501] = {
    [sym_expression] = STATE(3381),
    [sym__string] = STATE(3729),
    [sym_conditional_expression] = STATE(3729),
    [sym_assignment_expression] = STATE(3729),
    [sym_pointer_expression] = STATE(3736),
    [sym_unary_expression] = STATE(3729),
    [sym_binary_expression] = STATE(3729),
    [sym_update_expression] = STATE(3729),
    [sym_cast_expression] = STATE(3729),
    [sym_sizeof_expression] = STATE(3729),
    [sym_alignof_expression] = STATE(3729),
    [sym_offsetof_expression] = STATE(3729),
    [sym_generic_expression] = STATE(3729),
    [sym_subscript_expression] = STATE(3736),
    [sym_call_expression] = STATE(3736),
    [sym_gnu_asm_expression] = STATE(3729),
    [sym_field_expression] = STATE(3736),
    [sym_compound_literal_expression] = STATE(3729),
    [sym_parenthesized_expression] = STATE(3736),
    [sym_char_literal] = STATE(3602),
    [sym_concatenated_string] = STATE(3610),
    [sym_string_literal] = STATE(2698),
    [sym_null] = STATE(3729),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7745),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3729),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(3729),
    [sym_new_expression] = STATE(3729),
    [sym_delete_expression] = STATE(3729),
    [sym_requires_clause] = STATE(3729),
    [sym_requires_expression] = STATE(3729),
    [sym_lambda_expression] = STATE(3729),
    [sym_lambda_capture_specifier] = STATE(5813),
    [sym_fold_expression] = STATE(3729),
    [sym_parameter_pack_expansion] = STATE(3729),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3736),
    [sym_qualified_type_identifier] = STATE(7745),
    [sym_user_defined_literal] = STATE(3736),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_LPAREN2] = ACTIONS(4656),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3673),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3669),
    [anon_sym_compl] = ACTIONS(3669),
    [anon_sym_DASH_DASH] = ACTIONS(4558),
    [anon_sym_PLUS_PLUS] = ACTIONS(4558),
    [anon_sym_sizeof] = ACTIONS(3679),
    [anon_sym___alignof__] = ACTIONS(3681),
    [anon_sym___alignof] = ACTIONS(3681),
    [anon_sym__alignof] = ACTIONS(3681),
    [anon_sym_alignof] = ACTIONS(3681),
    [anon_sym__Alignof] = ACTIONS(3681),
    [anon_sym_offsetof] = ACTIONS(3683),
    [anon_sym__Generic] = ACTIONS(3685),
    [anon_sym_asm] = ACTIONS(3687),
    [anon_sym___asm__] = ACTIONS(3687),
    [sym_number_literal] = ACTIONS(3689),
    [anon_sym_L_SQUOTE] = ACTIONS(3691),
    [anon_sym_u_SQUOTE] = ACTIONS(3691),
    [anon_sym_U_SQUOTE] = ACTIONS(3691),
    [anon_sym_u8_SQUOTE] = ACTIONS(3691),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [anon_sym_L_DQUOTE] = ACTIONS(3693),
    [anon_sym_u_DQUOTE] = ACTIONS(3693),
    [anon_sym_U_DQUOTE] = ACTIONS(3693),
    [anon_sym_u8_DQUOTE] = ACTIONS(3693),
    [anon_sym_DQUOTE] = ACTIONS(3693),
    [sym_true] = ACTIONS(3695),
    [sym_false] = ACTIONS(3695),
    [anon_sym_NULL] = ACTIONS(3697),
    [anon_sym_nullptr] = ACTIONS(3697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3699),
    [anon_sym_R_DQUOTE] = ACTIONS(3701),
    [anon_sym_LR_DQUOTE] = ACTIONS(3701),
    [anon_sym_uR_DQUOTE] = ACTIONS(3701),
    [anon_sym_UR_DQUOTE] = ACTIONS(3701),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3701),
    [anon_sym_co_await] = ACTIONS(3703),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_requires] = ACTIONS(3707),
    [sym_this] = ACTIONS(3695),
  },
  [1502] = {
    [sym_expression] = STATE(3016),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3061),
    [sym_concatenated_string] = STATE(3059),
    [sym_string_literal] = STATE(2449),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2444),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4682),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3521),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3517),
    [anon_sym_compl] = ACTIONS(3517),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_sizeof] = ACTIONS(3527),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3537),
    [anon_sym_L_SQUOTE] = ACTIONS(3539),
    [anon_sym_u_SQUOTE] = ACTIONS(3539),
    [anon_sym_U_SQUOTE] = ACTIONS(3539),
    [anon_sym_u8_SQUOTE] = ACTIONS(3539),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3547),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [anon_sym_co_await] = ACTIONS(3551),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1503] = {
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3360),
    [sym_concatenated_string] = STATE(3359),
    [sym_string_literal] = STATE(2634),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2625),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3635),
    [anon_sym_LPAREN2] = ACTIONS(4658),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3641),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3637),
    [anon_sym_compl] = ACTIONS(3637),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_sizeof] = ACTIONS(3643),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3645),
    [anon_sym_L_SQUOTE] = ACTIONS(3647),
    [anon_sym_u_SQUOTE] = ACTIONS(3647),
    [anon_sym_U_SQUOTE] = ACTIONS(3647),
    [anon_sym_u8_SQUOTE] = ACTIONS(3647),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [anon_sym_L_DQUOTE] = ACTIONS(3649),
    [anon_sym_u_DQUOTE] = ACTIONS(3649),
    [anon_sym_U_DQUOTE] = ACTIONS(3649),
    [anon_sym_u8_DQUOTE] = ACTIONS(3649),
    [anon_sym_DQUOTE] = ACTIONS(3649),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3651),
    [anon_sym_R_DQUOTE] = ACTIONS(3653),
    [anon_sym_LR_DQUOTE] = ACTIONS(3653),
    [anon_sym_uR_DQUOTE] = ACTIONS(3653),
    [anon_sym_UR_DQUOTE] = ACTIONS(3653),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3653),
    [anon_sym_co_await] = ACTIONS(3655),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1504] = {
    [sym_expression] = STATE(4673),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1505] = {
    [sym_expression] = STATE(4485),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1506] = {
    [sym_expression] = STATE(4482),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1507] = {
    [sym_expression] = STATE(4601),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1508] = {
    [sym_expression] = STATE(3015),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3061),
    [sym_concatenated_string] = STATE(3059),
    [sym_string_literal] = STATE(2449),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2444),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4682),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3521),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3517),
    [anon_sym_compl] = ACTIONS(3517),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_sizeof] = ACTIONS(3527),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3537),
    [anon_sym_L_SQUOTE] = ACTIONS(3539),
    [anon_sym_u_SQUOTE] = ACTIONS(3539),
    [anon_sym_U_SQUOTE] = ACTIONS(3539),
    [anon_sym_u8_SQUOTE] = ACTIONS(3539),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3547),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [anon_sym_co_await] = ACTIONS(3551),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1509] = {
    [sym_expression] = STATE(4674),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1510] = {
    [sym_expression] = STATE(3319),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3360),
    [sym_concatenated_string] = STATE(3359),
    [sym_string_literal] = STATE(2634),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2625),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3635),
    [anon_sym_LPAREN2] = ACTIONS(4658),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3641),
    [anon_sym_LBRACK] = ACTIONS(4914),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3637),
    [anon_sym_compl] = ACTIONS(3637),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_sizeof] = ACTIONS(3643),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3645),
    [anon_sym_L_SQUOTE] = ACTIONS(3647),
    [anon_sym_u_SQUOTE] = ACTIONS(3647),
    [anon_sym_U_SQUOTE] = ACTIONS(3647),
    [anon_sym_u8_SQUOTE] = ACTIONS(3647),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [anon_sym_L_DQUOTE] = ACTIONS(3649),
    [anon_sym_u_DQUOTE] = ACTIONS(3649),
    [anon_sym_U_DQUOTE] = ACTIONS(3649),
    [anon_sym_u8_DQUOTE] = ACTIONS(3649),
    [anon_sym_DQUOTE] = ACTIONS(3649),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3651),
    [anon_sym_R_DQUOTE] = ACTIONS(3653),
    [anon_sym_LR_DQUOTE] = ACTIONS(3653),
    [anon_sym_uR_DQUOTE] = ACTIONS(3653),
    [anon_sym_UR_DQUOTE] = ACTIONS(3653),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3653),
    [anon_sym_co_await] = ACTIONS(3655),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1511] = {
    [sym_expression] = STATE(4427),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1512] = {
    [sym_expression] = STATE(4187),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_LPAREN2] = ACTIONS(4662),
    [anon_sym_BANG] = ACTIONS(3948),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3946),
    [anon_sym_PLUS] = ACTIONS(3946),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACK] = ACTIONS(4916),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_DASH_DASH] = ACTIONS(4537),
    [anon_sym_PLUS_PLUS] = ACTIONS(4537),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1513] = {
    [sym_expression] = STATE(2958),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3061),
    [sym_concatenated_string] = STATE(3059),
    [sym_string_literal] = STATE(2449),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2444),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4682),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3521),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3517),
    [anon_sym_compl] = ACTIONS(3517),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_sizeof] = ACTIONS(3527),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3537),
    [anon_sym_L_SQUOTE] = ACTIONS(3539),
    [anon_sym_u_SQUOTE] = ACTIONS(3539),
    [anon_sym_U_SQUOTE] = ACTIONS(3539),
    [anon_sym_u8_SQUOTE] = ACTIONS(3539),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3547),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [anon_sym_co_await] = ACTIONS(3551),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1514] = {
    [sym_expression] = STATE(3000),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3061),
    [sym_concatenated_string] = STATE(3059),
    [sym_string_literal] = STATE(2449),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2444),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4682),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3521),
    [anon_sym_LBRACK] = ACTIONS(4918),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3517),
    [anon_sym_compl] = ACTIONS(3517),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_sizeof] = ACTIONS(3527),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3537),
    [anon_sym_L_SQUOTE] = ACTIONS(3539),
    [anon_sym_u_SQUOTE] = ACTIONS(3539),
    [anon_sym_U_SQUOTE] = ACTIONS(3539),
    [anon_sym_u8_SQUOTE] = ACTIONS(3539),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3547),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [anon_sym_co_await] = ACTIONS(3551),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1515] = {
    [sym_expression] = STATE(4599),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1516] = {
    [sym_expression] = STATE(4615),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1517] = {
    [sym_expression] = STATE(4306),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1518] = {
    [sym_expression] = STATE(4466),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(4920),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1519] = {
    [sym_expression] = STATE(4401),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1520] = {
    [sym_expression] = STATE(4432),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1521] = {
    [sym_expression] = STATE(4331),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1522] = {
    [sym_expression] = STATE(4568),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1523] = {
    [sym_expression] = STATE(4592),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1524] = {
    [sym_expression] = STATE(3013),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3061),
    [sym_concatenated_string] = STATE(3059),
    [sym_string_literal] = STATE(2449),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2444),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4682),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3521),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3517),
    [anon_sym_compl] = ACTIONS(3517),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_sizeof] = ACTIONS(3527),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3537),
    [anon_sym_L_SQUOTE] = ACTIONS(3539),
    [anon_sym_u_SQUOTE] = ACTIONS(3539),
    [anon_sym_U_SQUOTE] = ACTIONS(3539),
    [anon_sym_u8_SQUOTE] = ACTIONS(3539),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3547),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [anon_sym_co_await] = ACTIONS(3551),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1525] = {
    [sym_expression] = STATE(3007),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3061),
    [sym_concatenated_string] = STATE(3059),
    [sym_string_literal] = STATE(2449),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2444),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4682),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3521),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3517),
    [anon_sym_compl] = ACTIONS(3517),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_sizeof] = ACTIONS(3527),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3537),
    [anon_sym_L_SQUOTE] = ACTIONS(3539),
    [anon_sym_u_SQUOTE] = ACTIONS(3539),
    [anon_sym_U_SQUOTE] = ACTIONS(3539),
    [anon_sym_u8_SQUOTE] = ACTIONS(3539),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3547),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [anon_sym_co_await] = ACTIONS(3551),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1526] = {
    [sym_expression] = STATE(4458),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1527] = {
    [sym_expression] = STATE(4650),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1528] = {
    [sym_expression] = STATE(2966),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3061),
    [sym_concatenated_string] = STATE(3059),
    [sym_string_literal] = STATE(2449),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2444),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4682),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3521),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3517),
    [anon_sym_compl] = ACTIONS(3517),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_sizeof] = ACTIONS(3527),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3537),
    [anon_sym_L_SQUOTE] = ACTIONS(3539),
    [anon_sym_u_SQUOTE] = ACTIONS(3539),
    [anon_sym_U_SQUOTE] = ACTIONS(3539),
    [anon_sym_u8_SQUOTE] = ACTIONS(3539),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3547),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [anon_sym_co_await] = ACTIONS(3551),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1529] = {
    [sym_expression] = STATE(3394),
    [sym__string] = STATE(3729),
    [sym_conditional_expression] = STATE(3729),
    [sym_assignment_expression] = STATE(3729),
    [sym_pointer_expression] = STATE(3736),
    [sym_unary_expression] = STATE(3729),
    [sym_binary_expression] = STATE(3729),
    [sym_update_expression] = STATE(3729),
    [sym_cast_expression] = STATE(3729),
    [sym_sizeof_expression] = STATE(3729),
    [sym_alignof_expression] = STATE(3729),
    [sym_offsetof_expression] = STATE(3729),
    [sym_generic_expression] = STATE(3729),
    [sym_subscript_expression] = STATE(3736),
    [sym_call_expression] = STATE(3736),
    [sym_gnu_asm_expression] = STATE(3729),
    [sym_field_expression] = STATE(3736),
    [sym_compound_literal_expression] = STATE(3729),
    [sym_parenthesized_expression] = STATE(3736),
    [sym_char_literal] = STATE(3602),
    [sym_concatenated_string] = STATE(3610),
    [sym_string_literal] = STATE(2698),
    [sym_null] = STATE(3729),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7745),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3729),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(3729),
    [sym_new_expression] = STATE(3729),
    [sym_delete_expression] = STATE(3729),
    [sym_requires_clause] = STATE(3729),
    [sym_requires_expression] = STATE(3729),
    [sym_lambda_expression] = STATE(3729),
    [sym_lambda_capture_specifier] = STATE(5813),
    [sym_fold_expression] = STATE(3729),
    [sym_parameter_pack_expansion] = STATE(3729),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3736),
    [sym_qualified_type_identifier] = STATE(7745),
    [sym_user_defined_literal] = STATE(3736),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_LPAREN2] = ACTIONS(4656),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3673),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3669),
    [anon_sym_compl] = ACTIONS(3669),
    [anon_sym_DASH_DASH] = ACTIONS(4558),
    [anon_sym_PLUS_PLUS] = ACTIONS(4558),
    [anon_sym_sizeof] = ACTIONS(3679),
    [anon_sym___alignof__] = ACTIONS(3681),
    [anon_sym___alignof] = ACTIONS(3681),
    [anon_sym__alignof] = ACTIONS(3681),
    [anon_sym_alignof] = ACTIONS(3681),
    [anon_sym__Alignof] = ACTIONS(3681),
    [anon_sym_offsetof] = ACTIONS(3683),
    [anon_sym__Generic] = ACTIONS(3685),
    [anon_sym_asm] = ACTIONS(3687),
    [anon_sym___asm__] = ACTIONS(3687),
    [sym_number_literal] = ACTIONS(3689),
    [anon_sym_L_SQUOTE] = ACTIONS(3691),
    [anon_sym_u_SQUOTE] = ACTIONS(3691),
    [anon_sym_U_SQUOTE] = ACTIONS(3691),
    [anon_sym_u8_SQUOTE] = ACTIONS(3691),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [anon_sym_L_DQUOTE] = ACTIONS(3693),
    [anon_sym_u_DQUOTE] = ACTIONS(3693),
    [anon_sym_U_DQUOTE] = ACTIONS(3693),
    [anon_sym_u8_DQUOTE] = ACTIONS(3693),
    [anon_sym_DQUOTE] = ACTIONS(3693),
    [sym_true] = ACTIONS(3695),
    [sym_false] = ACTIONS(3695),
    [anon_sym_NULL] = ACTIONS(3697),
    [anon_sym_nullptr] = ACTIONS(3697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3699),
    [anon_sym_R_DQUOTE] = ACTIONS(3701),
    [anon_sym_LR_DQUOTE] = ACTIONS(3701),
    [anon_sym_uR_DQUOTE] = ACTIONS(3701),
    [anon_sym_UR_DQUOTE] = ACTIONS(3701),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3701),
    [anon_sym_co_await] = ACTIONS(3703),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_requires] = ACTIONS(3707),
    [sym_this] = ACTIONS(3695),
  },
  [1530] = {
    [sym_expression] = STATE(4663),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1531] = {
    [sym_expression] = STATE(2749),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3360),
    [sym_concatenated_string] = STATE(3359),
    [sym_string_literal] = STATE(2634),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2625),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3635),
    [anon_sym_LPAREN2] = ACTIONS(4658),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3641),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3637),
    [anon_sym_compl] = ACTIONS(3637),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_sizeof] = ACTIONS(3643),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3645),
    [anon_sym_L_SQUOTE] = ACTIONS(3647),
    [anon_sym_u_SQUOTE] = ACTIONS(3647),
    [anon_sym_U_SQUOTE] = ACTIONS(3647),
    [anon_sym_u8_SQUOTE] = ACTIONS(3647),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [anon_sym_L_DQUOTE] = ACTIONS(3649),
    [anon_sym_u_DQUOTE] = ACTIONS(3649),
    [anon_sym_U_DQUOTE] = ACTIONS(3649),
    [anon_sym_u8_DQUOTE] = ACTIONS(3649),
    [anon_sym_DQUOTE] = ACTIONS(3649),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3651),
    [anon_sym_R_DQUOTE] = ACTIONS(3653),
    [anon_sym_LR_DQUOTE] = ACTIONS(3653),
    [anon_sym_uR_DQUOTE] = ACTIONS(3653),
    [anon_sym_UR_DQUOTE] = ACTIONS(3653),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3653),
    [anon_sym_co_await] = ACTIONS(3655),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1532] = {
    [sym_expression] = STATE(4556),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(4922),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1533] = {
    [sym_expression] = STATE(3251),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3360),
    [sym_concatenated_string] = STATE(3359),
    [sym_string_literal] = STATE(2634),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2625),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3635),
    [anon_sym_LPAREN2] = ACTIONS(4658),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3641),
    [anon_sym_LBRACK] = ACTIONS(4924),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3637),
    [anon_sym_compl] = ACTIONS(3637),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_sizeof] = ACTIONS(3643),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3645),
    [anon_sym_L_SQUOTE] = ACTIONS(3647),
    [anon_sym_u_SQUOTE] = ACTIONS(3647),
    [anon_sym_U_SQUOTE] = ACTIONS(3647),
    [anon_sym_u8_SQUOTE] = ACTIONS(3647),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [anon_sym_L_DQUOTE] = ACTIONS(3649),
    [anon_sym_u_DQUOTE] = ACTIONS(3649),
    [anon_sym_U_DQUOTE] = ACTIONS(3649),
    [anon_sym_u8_DQUOTE] = ACTIONS(3649),
    [anon_sym_DQUOTE] = ACTIONS(3649),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3651),
    [anon_sym_R_DQUOTE] = ACTIONS(3653),
    [anon_sym_LR_DQUOTE] = ACTIONS(3653),
    [anon_sym_uR_DQUOTE] = ACTIONS(3653),
    [anon_sym_UR_DQUOTE] = ACTIONS(3653),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3653),
    [anon_sym_co_await] = ACTIONS(3655),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1534] = {
    [sym_expression] = STATE(4616),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1535] = {
    [sym_expression] = STATE(4587),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1536] = {
    [sym_expression] = STATE(4619),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1537] = {
    [sym_expression] = STATE(3385),
    [sym__string] = STATE(3729),
    [sym_conditional_expression] = STATE(3729),
    [sym_assignment_expression] = STATE(3729),
    [sym_pointer_expression] = STATE(3736),
    [sym_unary_expression] = STATE(3729),
    [sym_binary_expression] = STATE(3729),
    [sym_update_expression] = STATE(3729),
    [sym_cast_expression] = STATE(3729),
    [sym_sizeof_expression] = STATE(3729),
    [sym_alignof_expression] = STATE(3729),
    [sym_offsetof_expression] = STATE(3729),
    [sym_generic_expression] = STATE(3729),
    [sym_subscript_expression] = STATE(3736),
    [sym_call_expression] = STATE(3736),
    [sym_gnu_asm_expression] = STATE(3729),
    [sym_field_expression] = STATE(3736),
    [sym_compound_literal_expression] = STATE(3729),
    [sym_parenthesized_expression] = STATE(3736),
    [sym_char_literal] = STATE(3602),
    [sym_concatenated_string] = STATE(3610),
    [sym_string_literal] = STATE(2698),
    [sym_null] = STATE(3729),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7745),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3729),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(3729),
    [sym_new_expression] = STATE(3729),
    [sym_delete_expression] = STATE(3729),
    [sym_requires_clause] = STATE(3729),
    [sym_requires_expression] = STATE(3729),
    [sym_lambda_expression] = STATE(3729),
    [sym_lambda_capture_specifier] = STATE(5813),
    [sym_fold_expression] = STATE(3729),
    [sym_parameter_pack_expansion] = STATE(3729),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3736),
    [sym_qualified_type_identifier] = STATE(7745),
    [sym_user_defined_literal] = STATE(3736),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_LPAREN2] = ACTIONS(4656),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3673),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3669),
    [anon_sym_compl] = ACTIONS(3669),
    [anon_sym_DASH_DASH] = ACTIONS(4558),
    [anon_sym_PLUS_PLUS] = ACTIONS(4558),
    [anon_sym_sizeof] = ACTIONS(3679),
    [anon_sym___alignof__] = ACTIONS(3681),
    [anon_sym___alignof] = ACTIONS(3681),
    [anon_sym__alignof] = ACTIONS(3681),
    [anon_sym_alignof] = ACTIONS(3681),
    [anon_sym__Alignof] = ACTIONS(3681),
    [anon_sym_offsetof] = ACTIONS(3683),
    [anon_sym__Generic] = ACTIONS(3685),
    [anon_sym_asm] = ACTIONS(3687),
    [anon_sym___asm__] = ACTIONS(3687),
    [sym_number_literal] = ACTIONS(3689),
    [anon_sym_L_SQUOTE] = ACTIONS(3691),
    [anon_sym_u_SQUOTE] = ACTIONS(3691),
    [anon_sym_U_SQUOTE] = ACTIONS(3691),
    [anon_sym_u8_SQUOTE] = ACTIONS(3691),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [anon_sym_L_DQUOTE] = ACTIONS(3693),
    [anon_sym_u_DQUOTE] = ACTIONS(3693),
    [anon_sym_U_DQUOTE] = ACTIONS(3693),
    [anon_sym_u8_DQUOTE] = ACTIONS(3693),
    [anon_sym_DQUOTE] = ACTIONS(3693),
    [sym_true] = ACTIONS(3695),
    [sym_false] = ACTIONS(3695),
    [anon_sym_NULL] = ACTIONS(3697),
    [anon_sym_nullptr] = ACTIONS(3697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3699),
    [anon_sym_R_DQUOTE] = ACTIONS(3701),
    [anon_sym_LR_DQUOTE] = ACTIONS(3701),
    [anon_sym_uR_DQUOTE] = ACTIONS(3701),
    [anon_sym_UR_DQUOTE] = ACTIONS(3701),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3701),
    [anon_sym_co_await] = ACTIONS(3703),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_requires] = ACTIONS(3707),
    [sym_this] = ACTIONS(3695),
  },
  [1538] = {
    [sym_expression] = STATE(4533),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1539] = {
    [sym_expression] = STATE(2749),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3061),
    [sym_concatenated_string] = STATE(3059),
    [sym_string_literal] = STATE(2449),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2444),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4682),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3521),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3517),
    [anon_sym_compl] = ACTIONS(3517),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_sizeof] = ACTIONS(3527),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3537),
    [anon_sym_L_SQUOTE] = ACTIONS(3539),
    [anon_sym_u_SQUOTE] = ACTIONS(3539),
    [anon_sym_U_SQUOTE] = ACTIONS(3539),
    [anon_sym_u8_SQUOTE] = ACTIONS(3539),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3547),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [anon_sym_co_await] = ACTIONS(3551),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1540] = {
    [sym_expression] = STATE(4513),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1541] = {
    [sym_expression] = STATE(4554),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1542] = {
    [sym_expression] = STATE(3017),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3061),
    [sym_concatenated_string] = STATE(3059),
    [sym_string_literal] = STATE(2449),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2444),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4682),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3521),
    [anon_sym_LBRACK] = ACTIONS(4926),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3517),
    [anon_sym_compl] = ACTIONS(3517),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_sizeof] = ACTIONS(3527),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3537),
    [anon_sym_L_SQUOTE] = ACTIONS(3539),
    [anon_sym_u_SQUOTE] = ACTIONS(3539),
    [anon_sym_U_SQUOTE] = ACTIONS(3539),
    [anon_sym_u8_SQUOTE] = ACTIONS(3539),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3547),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [anon_sym_co_await] = ACTIONS(3551),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1543] = {
    [sym__declaration_modifiers] = STATE(1984),
    [sym__declaration_specifiers] = STATE(4097),
    [sym_attribute_specifier] = STATE(1984),
    [sym_attribute_declaration] = STATE(1984),
    [sym_ms_declspec_modifier] = STATE(1984),
    [sym_storage_class_specifier] = STATE(1984),
    [sym_type_qualifier] = STATE(1984),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_parameter_declaration] = STATE(7178),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_optional_parameter_declaration] = STATE(7178),
    [sym_variadic_parameter_declaration] = STATE(7178),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6449),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1984),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1984),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(4068),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1877),
    [anon_sym_RPAREN] = ACTIONS(3932),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1827),
    [anon_sym_out] = ACTIONS(1827),
    [anon_sym_inout] = ACTIONS(1827),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(4078),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(1833),
    [anon_sym_class] = ACTIONS(1835),
    [anon_sym_struct] = ACTIONS(1837),
    [anon_sym_union] = ACTIONS(1839),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1827),
    [anon_sym_typename] = ACTIONS(1863),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1544] = {
    [sym_expression] = STATE(3379),
    [sym__string] = STATE(3729),
    [sym_conditional_expression] = STATE(3729),
    [sym_assignment_expression] = STATE(3729),
    [sym_pointer_expression] = STATE(3736),
    [sym_unary_expression] = STATE(3729),
    [sym_binary_expression] = STATE(3729),
    [sym_update_expression] = STATE(3729),
    [sym_cast_expression] = STATE(3729),
    [sym_sizeof_expression] = STATE(3729),
    [sym_alignof_expression] = STATE(3729),
    [sym_offsetof_expression] = STATE(3729),
    [sym_generic_expression] = STATE(3729),
    [sym_subscript_expression] = STATE(3736),
    [sym_call_expression] = STATE(3736),
    [sym_gnu_asm_expression] = STATE(3729),
    [sym_field_expression] = STATE(3736),
    [sym_compound_literal_expression] = STATE(3729),
    [sym_parenthesized_expression] = STATE(3736),
    [sym_char_literal] = STATE(3602),
    [sym_concatenated_string] = STATE(3610),
    [sym_string_literal] = STATE(2698),
    [sym_null] = STATE(3729),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7745),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3729),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(3729),
    [sym_new_expression] = STATE(3729),
    [sym_delete_expression] = STATE(3729),
    [sym_requires_clause] = STATE(3729),
    [sym_requires_expression] = STATE(3729),
    [sym_lambda_expression] = STATE(3729),
    [sym_lambda_capture_specifier] = STATE(5813),
    [sym_fold_expression] = STATE(3729),
    [sym_parameter_pack_expansion] = STATE(3729),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3736),
    [sym_qualified_type_identifier] = STATE(7745),
    [sym_user_defined_literal] = STATE(3736),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_LPAREN2] = ACTIONS(4656),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3673),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3669),
    [anon_sym_compl] = ACTIONS(3669),
    [anon_sym_DASH_DASH] = ACTIONS(4558),
    [anon_sym_PLUS_PLUS] = ACTIONS(4558),
    [anon_sym_sizeof] = ACTIONS(3679),
    [anon_sym___alignof__] = ACTIONS(3681),
    [anon_sym___alignof] = ACTIONS(3681),
    [anon_sym__alignof] = ACTIONS(3681),
    [anon_sym_alignof] = ACTIONS(3681),
    [anon_sym__Alignof] = ACTIONS(3681),
    [anon_sym_offsetof] = ACTIONS(3683),
    [anon_sym__Generic] = ACTIONS(3685),
    [anon_sym_asm] = ACTIONS(3687),
    [anon_sym___asm__] = ACTIONS(3687),
    [sym_number_literal] = ACTIONS(3689),
    [anon_sym_L_SQUOTE] = ACTIONS(3691),
    [anon_sym_u_SQUOTE] = ACTIONS(3691),
    [anon_sym_U_SQUOTE] = ACTIONS(3691),
    [anon_sym_u8_SQUOTE] = ACTIONS(3691),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [anon_sym_L_DQUOTE] = ACTIONS(3693),
    [anon_sym_u_DQUOTE] = ACTIONS(3693),
    [anon_sym_U_DQUOTE] = ACTIONS(3693),
    [anon_sym_u8_DQUOTE] = ACTIONS(3693),
    [anon_sym_DQUOTE] = ACTIONS(3693),
    [sym_true] = ACTIONS(3695),
    [sym_false] = ACTIONS(3695),
    [anon_sym_NULL] = ACTIONS(3697),
    [anon_sym_nullptr] = ACTIONS(3697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3699),
    [anon_sym_R_DQUOTE] = ACTIONS(3701),
    [anon_sym_LR_DQUOTE] = ACTIONS(3701),
    [anon_sym_uR_DQUOTE] = ACTIONS(3701),
    [anon_sym_UR_DQUOTE] = ACTIONS(3701),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3701),
    [anon_sym_co_await] = ACTIONS(3703),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_requires] = ACTIONS(3707),
    [sym_this] = ACTIONS(3695),
  },
  [1545] = {
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3061),
    [sym_concatenated_string] = STATE(3059),
    [sym_string_literal] = STATE(2449),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2444),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4682),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3521),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3517),
    [anon_sym_compl] = ACTIONS(3517),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_sizeof] = ACTIONS(3527),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3537),
    [anon_sym_L_SQUOTE] = ACTIONS(3539),
    [anon_sym_u_SQUOTE] = ACTIONS(3539),
    [anon_sym_U_SQUOTE] = ACTIONS(3539),
    [anon_sym_u8_SQUOTE] = ACTIONS(3539),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3547),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [anon_sym_co_await] = ACTIONS(3551),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1546] = {
    [sym_expression] = STATE(4289),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1547] = {
    [sym_expression] = STATE(4451),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1548] = {
    [sym_expression] = STATE(4271),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(4928),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1549] = {
    [sym_expression] = STATE(4495),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1550] = {
    [sym_expression] = STATE(4535),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1551] = {
    [sym_expression] = STATE(3680),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1552] = {
    [sym_expression] = STATE(3378),
    [sym__string] = STATE(3729),
    [sym_conditional_expression] = STATE(3729),
    [sym_assignment_expression] = STATE(3729),
    [sym_pointer_expression] = STATE(3736),
    [sym_unary_expression] = STATE(3729),
    [sym_binary_expression] = STATE(3729),
    [sym_update_expression] = STATE(3729),
    [sym_cast_expression] = STATE(3729),
    [sym_sizeof_expression] = STATE(3729),
    [sym_alignof_expression] = STATE(3729),
    [sym_offsetof_expression] = STATE(3729),
    [sym_generic_expression] = STATE(3729),
    [sym_subscript_expression] = STATE(3736),
    [sym_call_expression] = STATE(3736),
    [sym_gnu_asm_expression] = STATE(3729),
    [sym_field_expression] = STATE(3736),
    [sym_compound_literal_expression] = STATE(3729),
    [sym_parenthesized_expression] = STATE(3736),
    [sym_char_literal] = STATE(3602),
    [sym_concatenated_string] = STATE(3610),
    [sym_string_literal] = STATE(2698),
    [sym_null] = STATE(3729),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7745),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3729),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(3729),
    [sym_new_expression] = STATE(3729),
    [sym_delete_expression] = STATE(3729),
    [sym_requires_clause] = STATE(3729),
    [sym_requires_expression] = STATE(3729),
    [sym_lambda_expression] = STATE(3729),
    [sym_lambda_capture_specifier] = STATE(5813),
    [sym_fold_expression] = STATE(3729),
    [sym_parameter_pack_expansion] = STATE(3729),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3736),
    [sym_qualified_type_identifier] = STATE(7745),
    [sym_user_defined_literal] = STATE(3736),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_LPAREN2] = ACTIONS(4656),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3673),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3669),
    [anon_sym_compl] = ACTIONS(3669),
    [anon_sym_DASH_DASH] = ACTIONS(4558),
    [anon_sym_PLUS_PLUS] = ACTIONS(4558),
    [anon_sym_sizeof] = ACTIONS(3679),
    [anon_sym___alignof__] = ACTIONS(3681),
    [anon_sym___alignof] = ACTIONS(3681),
    [anon_sym__alignof] = ACTIONS(3681),
    [anon_sym_alignof] = ACTIONS(3681),
    [anon_sym__Alignof] = ACTIONS(3681),
    [anon_sym_offsetof] = ACTIONS(3683),
    [anon_sym__Generic] = ACTIONS(3685),
    [anon_sym_asm] = ACTIONS(3687),
    [anon_sym___asm__] = ACTIONS(3687),
    [sym_number_literal] = ACTIONS(3689),
    [anon_sym_L_SQUOTE] = ACTIONS(3691),
    [anon_sym_u_SQUOTE] = ACTIONS(3691),
    [anon_sym_U_SQUOTE] = ACTIONS(3691),
    [anon_sym_u8_SQUOTE] = ACTIONS(3691),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [anon_sym_L_DQUOTE] = ACTIONS(3693),
    [anon_sym_u_DQUOTE] = ACTIONS(3693),
    [anon_sym_U_DQUOTE] = ACTIONS(3693),
    [anon_sym_u8_DQUOTE] = ACTIONS(3693),
    [anon_sym_DQUOTE] = ACTIONS(3693),
    [sym_true] = ACTIONS(3695),
    [sym_false] = ACTIONS(3695),
    [anon_sym_NULL] = ACTIONS(3697),
    [anon_sym_nullptr] = ACTIONS(3697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3699),
    [anon_sym_R_DQUOTE] = ACTIONS(3701),
    [anon_sym_LR_DQUOTE] = ACTIONS(3701),
    [anon_sym_uR_DQUOTE] = ACTIONS(3701),
    [anon_sym_UR_DQUOTE] = ACTIONS(3701),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3701),
    [anon_sym_co_await] = ACTIONS(3703),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_requires] = ACTIONS(3707),
    [sym_this] = ACTIONS(3695),
  },
  [1553] = {
    [sym_expression] = STATE(4433),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1554] = {
    [sym_expression] = STATE(4477),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1555] = {
    [sym_expression] = STATE(3377),
    [sym__string] = STATE(3729),
    [sym_conditional_expression] = STATE(3729),
    [sym_assignment_expression] = STATE(3729),
    [sym_pointer_expression] = STATE(3736),
    [sym_unary_expression] = STATE(3729),
    [sym_binary_expression] = STATE(3729),
    [sym_update_expression] = STATE(3729),
    [sym_cast_expression] = STATE(3729),
    [sym_sizeof_expression] = STATE(3729),
    [sym_alignof_expression] = STATE(3729),
    [sym_offsetof_expression] = STATE(3729),
    [sym_generic_expression] = STATE(3729),
    [sym_subscript_expression] = STATE(3736),
    [sym_call_expression] = STATE(3736),
    [sym_gnu_asm_expression] = STATE(3729),
    [sym_field_expression] = STATE(3736),
    [sym_compound_literal_expression] = STATE(3729),
    [sym_parenthesized_expression] = STATE(3736),
    [sym_char_literal] = STATE(3602),
    [sym_concatenated_string] = STATE(3610),
    [sym_string_literal] = STATE(2698),
    [sym_null] = STATE(3729),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7745),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3729),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(3729),
    [sym_new_expression] = STATE(3729),
    [sym_delete_expression] = STATE(3729),
    [sym_requires_clause] = STATE(3729),
    [sym_requires_expression] = STATE(3729),
    [sym_lambda_expression] = STATE(3729),
    [sym_lambda_capture_specifier] = STATE(5813),
    [sym_fold_expression] = STATE(3729),
    [sym_parameter_pack_expansion] = STATE(3729),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3736),
    [sym_qualified_type_identifier] = STATE(7745),
    [sym_user_defined_literal] = STATE(3736),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_LPAREN2] = ACTIONS(4656),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3673),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3669),
    [anon_sym_compl] = ACTIONS(3669),
    [anon_sym_DASH_DASH] = ACTIONS(4558),
    [anon_sym_PLUS_PLUS] = ACTIONS(4558),
    [anon_sym_sizeof] = ACTIONS(3679),
    [anon_sym___alignof__] = ACTIONS(3681),
    [anon_sym___alignof] = ACTIONS(3681),
    [anon_sym__alignof] = ACTIONS(3681),
    [anon_sym_alignof] = ACTIONS(3681),
    [anon_sym__Alignof] = ACTIONS(3681),
    [anon_sym_offsetof] = ACTIONS(3683),
    [anon_sym__Generic] = ACTIONS(3685),
    [anon_sym_asm] = ACTIONS(3687),
    [anon_sym___asm__] = ACTIONS(3687),
    [sym_number_literal] = ACTIONS(3689),
    [anon_sym_L_SQUOTE] = ACTIONS(3691),
    [anon_sym_u_SQUOTE] = ACTIONS(3691),
    [anon_sym_U_SQUOTE] = ACTIONS(3691),
    [anon_sym_u8_SQUOTE] = ACTIONS(3691),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [anon_sym_L_DQUOTE] = ACTIONS(3693),
    [anon_sym_u_DQUOTE] = ACTIONS(3693),
    [anon_sym_U_DQUOTE] = ACTIONS(3693),
    [anon_sym_u8_DQUOTE] = ACTIONS(3693),
    [anon_sym_DQUOTE] = ACTIONS(3693),
    [sym_true] = ACTIONS(3695),
    [sym_false] = ACTIONS(3695),
    [anon_sym_NULL] = ACTIONS(3697),
    [anon_sym_nullptr] = ACTIONS(3697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3699),
    [anon_sym_R_DQUOTE] = ACTIONS(3701),
    [anon_sym_LR_DQUOTE] = ACTIONS(3701),
    [anon_sym_uR_DQUOTE] = ACTIONS(3701),
    [anon_sym_UR_DQUOTE] = ACTIONS(3701),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3701),
    [anon_sym_co_await] = ACTIONS(3703),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_requires] = ACTIONS(3707),
    [sym_this] = ACTIONS(3695),
  },
  [1556] = {
    [sym_expression] = STATE(3376),
    [sym__string] = STATE(3729),
    [sym_conditional_expression] = STATE(3729),
    [sym_assignment_expression] = STATE(3729),
    [sym_pointer_expression] = STATE(3736),
    [sym_unary_expression] = STATE(3729),
    [sym_binary_expression] = STATE(3729),
    [sym_update_expression] = STATE(3729),
    [sym_cast_expression] = STATE(3729),
    [sym_sizeof_expression] = STATE(3729),
    [sym_alignof_expression] = STATE(3729),
    [sym_offsetof_expression] = STATE(3729),
    [sym_generic_expression] = STATE(3729),
    [sym_subscript_expression] = STATE(3736),
    [sym_call_expression] = STATE(3736),
    [sym_gnu_asm_expression] = STATE(3729),
    [sym_field_expression] = STATE(3736),
    [sym_compound_literal_expression] = STATE(3729),
    [sym_parenthesized_expression] = STATE(3736),
    [sym_char_literal] = STATE(3602),
    [sym_concatenated_string] = STATE(3610),
    [sym_string_literal] = STATE(2698),
    [sym_null] = STATE(3729),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7745),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3729),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(3729),
    [sym_new_expression] = STATE(3729),
    [sym_delete_expression] = STATE(3729),
    [sym_requires_clause] = STATE(3729),
    [sym_requires_expression] = STATE(3729),
    [sym_lambda_expression] = STATE(3729),
    [sym_lambda_capture_specifier] = STATE(5813),
    [sym_fold_expression] = STATE(3729),
    [sym_parameter_pack_expansion] = STATE(3729),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3736),
    [sym_qualified_type_identifier] = STATE(7745),
    [sym_user_defined_literal] = STATE(3736),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_LPAREN2] = ACTIONS(4656),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3673),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3669),
    [anon_sym_compl] = ACTIONS(3669),
    [anon_sym_DASH_DASH] = ACTIONS(4558),
    [anon_sym_PLUS_PLUS] = ACTIONS(4558),
    [anon_sym_sizeof] = ACTIONS(3679),
    [anon_sym___alignof__] = ACTIONS(3681),
    [anon_sym___alignof] = ACTIONS(3681),
    [anon_sym__alignof] = ACTIONS(3681),
    [anon_sym_alignof] = ACTIONS(3681),
    [anon_sym__Alignof] = ACTIONS(3681),
    [anon_sym_offsetof] = ACTIONS(3683),
    [anon_sym__Generic] = ACTIONS(3685),
    [anon_sym_asm] = ACTIONS(3687),
    [anon_sym___asm__] = ACTIONS(3687),
    [sym_number_literal] = ACTIONS(3689),
    [anon_sym_L_SQUOTE] = ACTIONS(3691),
    [anon_sym_u_SQUOTE] = ACTIONS(3691),
    [anon_sym_U_SQUOTE] = ACTIONS(3691),
    [anon_sym_u8_SQUOTE] = ACTIONS(3691),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [anon_sym_L_DQUOTE] = ACTIONS(3693),
    [anon_sym_u_DQUOTE] = ACTIONS(3693),
    [anon_sym_U_DQUOTE] = ACTIONS(3693),
    [anon_sym_u8_DQUOTE] = ACTIONS(3693),
    [anon_sym_DQUOTE] = ACTIONS(3693),
    [sym_true] = ACTIONS(3695),
    [sym_false] = ACTIONS(3695),
    [anon_sym_NULL] = ACTIONS(3697),
    [anon_sym_nullptr] = ACTIONS(3697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3699),
    [anon_sym_R_DQUOTE] = ACTIONS(3701),
    [anon_sym_LR_DQUOTE] = ACTIONS(3701),
    [anon_sym_uR_DQUOTE] = ACTIONS(3701),
    [anon_sym_UR_DQUOTE] = ACTIONS(3701),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3701),
    [anon_sym_co_await] = ACTIONS(3703),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_requires] = ACTIONS(3707),
    [sym_this] = ACTIONS(3695),
  },
  [1557] = {
    [sym_expression] = STATE(3375),
    [sym__string] = STATE(3729),
    [sym_conditional_expression] = STATE(3729),
    [sym_assignment_expression] = STATE(3729),
    [sym_pointer_expression] = STATE(3736),
    [sym_unary_expression] = STATE(3729),
    [sym_binary_expression] = STATE(3729),
    [sym_update_expression] = STATE(3729),
    [sym_cast_expression] = STATE(3729),
    [sym_sizeof_expression] = STATE(3729),
    [sym_alignof_expression] = STATE(3729),
    [sym_offsetof_expression] = STATE(3729),
    [sym_generic_expression] = STATE(3729),
    [sym_subscript_expression] = STATE(3736),
    [sym_call_expression] = STATE(3736),
    [sym_gnu_asm_expression] = STATE(3729),
    [sym_field_expression] = STATE(3736),
    [sym_compound_literal_expression] = STATE(3729),
    [sym_parenthesized_expression] = STATE(3736),
    [sym_char_literal] = STATE(3602),
    [sym_concatenated_string] = STATE(3610),
    [sym_string_literal] = STATE(2698),
    [sym_null] = STATE(3729),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7745),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3729),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(3729),
    [sym_new_expression] = STATE(3729),
    [sym_delete_expression] = STATE(3729),
    [sym_requires_clause] = STATE(3729),
    [sym_requires_expression] = STATE(3729),
    [sym_lambda_expression] = STATE(3729),
    [sym_lambda_capture_specifier] = STATE(5813),
    [sym_fold_expression] = STATE(3729),
    [sym_parameter_pack_expansion] = STATE(3729),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3736),
    [sym_qualified_type_identifier] = STATE(7745),
    [sym_user_defined_literal] = STATE(3736),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_LPAREN2] = ACTIONS(4656),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3673),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3669),
    [anon_sym_compl] = ACTIONS(3669),
    [anon_sym_DASH_DASH] = ACTIONS(4558),
    [anon_sym_PLUS_PLUS] = ACTIONS(4558),
    [anon_sym_sizeof] = ACTIONS(3679),
    [anon_sym___alignof__] = ACTIONS(3681),
    [anon_sym___alignof] = ACTIONS(3681),
    [anon_sym__alignof] = ACTIONS(3681),
    [anon_sym_alignof] = ACTIONS(3681),
    [anon_sym__Alignof] = ACTIONS(3681),
    [anon_sym_offsetof] = ACTIONS(3683),
    [anon_sym__Generic] = ACTIONS(3685),
    [anon_sym_asm] = ACTIONS(3687),
    [anon_sym___asm__] = ACTIONS(3687),
    [sym_number_literal] = ACTIONS(3689),
    [anon_sym_L_SQUOTE] = ACTIONS(3691),
    [anon_sym_u_SQUOTE] = ACTIONS(3691),
    [anon_sym_U_SQUOTE] = ACTIONS(3691),
    [anon_sym_u8_SQUOTE] = ACTIONS(3691),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [anon_sym_L_DQUOTE] = ACTIONS(3693),
    [anon_sym_u_DQUOTE] = ACTIONS(3693),
    [anon_sym_U_DQUOTE] = ACTIONS(3693),
    [anon_sym_u8_DQUOTE] = ACTIONS(3693),
    [anon_sym_DQUOTE] = ACTIONS(3693),
    [sym_true] = ACTIONS(3695),
    [sym_false] = ACTIONS(3695),
    [anon_sym_NULL] = ACTIONS(3697),
    [anon_sym_nullptr] = ACTIONS(3697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3699),
    [anon_sym_R_DQUOTE] = ACTIONS(3701),
    [anon_sym_LR_DQUOTE] = ACTIONS(3701),
    [anon_sym_uR_DQUOTE] = ACTIONS(3701),
    [anon_sym_UR_DQUOTE] = ACTIONS(3701),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3701),
    [anon_sym_co_await] = ACTIONS(3703),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_requires] = ACTIONS(3707),
    [sym_this] = ACTIONS(3695),
  },
  [1558] = {
    [sym_expression] = STATE(4322),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1559] = {
    [sym_expression] = STATE(4437),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1560] = {
    [sym_expression] = STATE(4566),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1561] = {
    [sym_expression] = STATE(3372),
    [sym__string] = STATE(3729),
    [sym_conditional_expression] = STATE(3729),
    [sym_assignment_expression] = STATE(3729),
    [sym_pointer_expression] = STATE(3736),
    [sym_unary_expression] = STATE(3729),
    [sym_binary_expression] = STATE(3729),
    [sym_update_expression] = STATE(3729),
    [sym_cast_expression] = STATE(3729),
    [sym_sizeof_expression] = STATE(3729),
    [sym_alignof_expression] = STATE(3729),
    [sym_offsetof_expression] = STATE(3729),
    [sym_generic_expression] = STATE(3729),
    [sym_subscript_expression] = STATE(3736),
    [sym_call_expression] = STATE(3736),
    [sym_gnu_asm_expression] = STATE(3729),
    [sym_field_expression] = STATE(3736),
    [sym_compound_literal_expression] = STATE(3729),
    [sym_parenthesized_expression] = STATE(3736),
    [sym_char_literal] = STATE(3602),
    [sym_concatenated_string] = STATE(3610),
    [sym_string_literal] = STATE(2698),
    [sym_null] = STATE(3729),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7745),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3729),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(3729),
    [sym_new_expression] = STATE(3729),
    [sym_delete_expression] = STATE(3729),
    [sym_requires_clause] = STATE(3729),
    [sym_requires_expression] = STATE(3729),
    [sym_lambda_expression] = STATE(3729),
    [sym_lambda_capture_specifier] = STATE(5813),
    [sym_fold_expression] = STATE(3729),
    [sym_parameter_pack_expansion] = STATE(3729),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3736),
    [sym_qualified_type_identifier] = STATE(7745),
    [sym_user_defined_literal] = STATE(3736),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_LPAREN2] = ACTIONS(4656),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3673),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3669),
    [anon_sym_compl] = ACTIONS(3669),
    [anon_sym_DASH_DASH] = ACTIONS(4558),
    [anon_sym_PLUS_PLUS] = ACTIONS(4558),
    [anon_sym_sizeof] = ACTIONS(3679),
    [anon_sym___alignof__] = ACTIONS(3681),
    [anon_sym___alignof] = ACTIONS(3681),
    [anon_sym__alignof] = ACTIONS(3681),
    [anon_sym_alignof] = ACTIONS(3681),
    [anon_sym__Alignof] = ACTIONS(3681),
    [anon_sym_offsetof] = ACTIONS(3683),
    [anon_sym__Generic] = ACTIONS(3685),
    [anon_sym_asm] = ACTIONS(3687),
    [anon_sym___asm__] = ACTIONS(3687),
    [sym_number_literal] = ACTIONS(3689),
    [anon_sym_L_SQUOTE] = ACTIONS(3691),
    [anon_sym_u_SQUOTE] = ACTIONS(3691),
    [anon_sym_U_SQUOTE] = ACTIONS(3691),
    [anon_sym_u8_SQUOTE] = ACTIONS(3691),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [anon_sym_L_DQUOTE] = ACTIONS(3693),
    [anon_sym_u_DQUOTE] = ACTIONS(3693),
    [anon_sym_U_DQUOTE] = ACTIONS(3693),
    [anon_sym_u8_DQUOTE] = ACTIONS(3693),
    [anon_sym_DQUOTE] = ACTIONS(3693),
    [sym_true] = ACTIONS(3695),
    [sym_false] = ACTIONS(3695),
    [anon_sym_NULL] = ACTIONS(3697),
    [anon_sym_nullptr] = ACTIONS(3697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3699),
    [anon_sym_R_DQUOTE] = ACTIONS(3701),
    [anon_sym_LR_DQUOTE] = ACTIONS(3701),
    [anon_sym_uR_DQUOTE] = ACTIONS(3701),
    [anon_sym_UR_DQUOTE] = ACTIONS(3701),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3701),
    [anon_sym_co_await] = ACTIONS(3703),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_requires] = ACTIONS(3707),
    [sym_this] = ACTIONS(3695),
  },
  [1562] = {
    [sym_expression] = STATE(3877),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1563] = {
    [sym__declaration_modifiers] = STATE(1984),
    [sym__declaration_specifiers] = STATE(4097),
    [sym_attribute_specifier] = STATE(1984),
    [sym_attribute_declaration] = STATE(1984),
    [sym_ms_declspec_modifier] = STATE(1984),
    [sym_storage_class_specifier] = STATE(1984),
    [sym_type_qualifier] = STATE(1984),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_parameter_declaration] = STATE(7405),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_optional_parameter_declaration] = STATE(7405),
    [sym_variadic_parameter_declaration] = STATE(7405),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6449),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1984),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1984),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(4068),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4930),
    [anon_sym_RPAREN] = ACTIONS(4932),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1827),
    [anon_sym_out] = ACTIONS(1827),
    [anon_sym_inout] = ACTIONS(1827),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(4078),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(1833),
    [anon_sym_class] = ACTIONS(1835),
    [anon_sym_struct] = ACTIONS(1837),
    [anon_sym_union] = ACTIONS(1839),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1827),
    [anon_sym_typename] = ACTIONS(1863),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1564] = {
    [sym_expression] = STATE(4567),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1565] = {
    [sym_expression] = STATE(4701),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1566] = {
    [sym_expression] = STATE(4438),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1567] = {
    [sym_expression] = STATE(4569),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1568] = {
    [sym_expression] = STATE(4570),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1569] = {
    [sym_expression] = STATE(3902),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1570] = {
    [sym_expression] = STATE(4571),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1571] = {
    [sym_expression] = STATE(4572),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1572] = {
    [sym_expression] = STATE(4439),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1573] = {
    [sym_expression] = STATE(4573),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1574] = {
    [sym_expression] = STATE(4574),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1575] = {
    [sym_expression] = STATE(4440),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1576] = {
    [sym_expression] = STATE(4575),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1577] = {
    [sym_expression] = STATE(4614),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1578] = {
    [sym_expression] = STATE(4576),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1579] = {
    [sym_expression] = STATE(4441),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1580] = {
    [sym_expression] = STATE(4188),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_LPAREN2] = ACTIONS(4662),
    [anon_sym_BANG] = ACTIONS(3948),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3946),
    [anon_sym_PLUS] = ACTIONS(3946),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_DASH_DASH] = ACTIONS(4537),
    [anon_sym_PLUS_PLUS] = ACTIONS(4537),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1581] = {
    [sym_expression] = STATE(3371),
    [sym__string] = STATE(3729),
    [sym_conditional_expression] = STATE(3729),
    [sym_assignment_expression] = STATE(3729),
    [sym_pointer_expression] = STATE(3736),
    [sym_unary_expression] = STATE(3729),
    [sym_binary_expression] = STATE(3729),
    [sym_update_expression] = STATE(3729),
    [sym_cast_expression] = STATE(3729),
    [sym_sizeof_expression] = STATE(3729),
    [sym_alignof_expression] = STATE(3729),
    [sym_offsetof_expression] = STATE(3729),
    [sym_generic_expression] = STATE(3729),
    [sym_subscript_expression] = STATE(3736),
    [sym_call_expression] = STATE(3736),
    [sym_gnu_asm_expression] = STATE(3729),
    [sym_field_expression] = STATE(3736),
    [sym_compound_literal_expression] = STATE(3729),
    [sym_parenthesized_expression] = STATE(3736),
    [sym_char_literal] = STATE(3602),
    [sym_concatenated_string] = STATE(3610),
    [sym_string_literal] = STATE(2698),
    [sym_null] = STATE(3729),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7745),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3729),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(3729),
    [sym_new_expression] = STATE(3729),
    [sym_delete_expression] = STATE(3729),
    [sym_requires_clause] = STATE(3729),
    [sym_requires_expression] = STATE(3729),
    [sym_lambda_expression] = STATE(3729),
    [sym_lambda_capture_specifier] = STATE(5813),
    [sym_fold_expression] = STATE(3729),
    [sym_parameter_pack_expansion] = STATE(3729),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3736),
    [sym_qualified_type_identifier] = STATE(7745),
    [sym_user_defined_literal] = STATE(3736),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_LPAREN2] = ACTIONS(4656),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3673),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3669),
    [anon_sym_compl] = ACTIONS(3669),
    [anon_sym_DASH_DASH] = ACTIONS(4558),
    [anon_sym_PLUS_PLUS] = ACTIONS(4558),
    [anon_sym_sizeof] = ACTIONS(3679),
    [anon_sym___alignof__] = ACTIONS(3681),
    [anon_sym___alignof] = ACTIONS(3681),
    [anon_sym__alignof] = ACTIONS(3681),
    [anon_sym_alignof] = ACTIONS(3681),
    [anon_sym__Alignof] = ACTIONS(3681),
    [anon_sym_offsetof] = ACTIONS(3683),
    [anon_sym__Generic] = ACTIONS(3685),
    [anon_sym_asm] = ACTIONS(3687),
    [anon_sym___asm__] = ACTIONS(3687),
    [sym_number_literal] = ACTIONS(3689),
    [anon_sym_L_SQUOTE] = ACTIONS(3691),
    [anon_sym_u_SQUOTE] = ACTIONS(3691),
    [anon_sym_U_SQUOTE] = ACTIONS(3691),
    [anon_sym_u8_SQUOTE] = ACTIONS(3691),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [anon_sym_L_DQUOTE] = ACTIONS(3693),
    [anon_sym_u_DQUOTE] = ACTIONS(3693),
    [anon_sym_U_DQUOTE] = ACTIONS(3693),
    [anon_sym_u8_DQUOTE] = ACTIONS(3693),
    [anon_sym_DQUOTE] = ACTIONS(3693),
    [sym_true] = ACTIONS(3695),
    [sym_false] = ACTIONS(3695),
    [anon_sym_NULL] = ACTIONS(3697),
    [anon_sym_nullptr] = ACTIONS(3697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3699),
    [anon_sym_R_DQUOTE] = ACTIONS(3701),
    [anon_sym_LR_DQUOTE] = ACTIONS(3701),
    [anon_sym_uR_DQUOTE] = ACTIONS(3701),
    [anon_sym_UR_DQUOTE] = ACTIONS(3701),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3701),
    [anon_sym_co_await] = ACTIONS(3703),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_requires] = ACTIONS(3707),
    [sym_this] = ACTIONS(3695),
  },
  [1582] = {
    [sym_expression] = STATE(4442),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1583] = {
    [sym_expression] = STATE(3370),
    [sym__string] = STATE(3729),
    [sym_conditional_expression] = STATE(3729),
    [sym_assignment_expression] = STATE(3729),
    [sym_pointer_expression] = STATE(3736),
    [sym_unary_expression] = STATE(3729),
    [sym_binary_expression] = STATE(3729),
    [sym_update_expression] = STATE(3729),
    [sym_cast_expression] = STATE(3729),
    [sym_sizeof_expression] = STATE(3729),
    [sym_alignof_expression] = STATE(3729),
    [sym_offsetof_expression] = STATE(3729),
    [sym_generic_expression] = STATE(3729),
    [sym_subscript_expression] = STATE(3736),
    [sym_call_expression] = STATE(3736),
    [sym_gnu_asm_expression] = STATE(3729),
    [sym_field_expression] = STATE(3736),
    [sym_compound_literal_expression] = STATE(3729),
    [sym_parenthesized_expression] = STATE(3736),
    [sym_char_literal] = STATE(3602),
    [sym_concatenated_string] = STATE(3610),
    [sym_string_literal] = STATE(2698),
    [sym_null] = STATE(3729),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7745),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3729),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(3729),
    [sym_new_expression] = STATE(3729),
    [sym_delete_expression] = STATE(3729),
    [sym_requires_clause] = STATE(3729),
    [sym_requires_expression] = STATE(3729),
    [sym_lambda_expression] = STATE(3729),
    [sym_lambda_capture_specifier] = STATE(5813),
    [sym_fold_expression] = STATE(3729),
    [sym_parameter_pack_expansion] = STATE(3729),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3736),
    [sym_qualified_type_identifier] = STATE(7745),
    [sym_user_defined_literal] = STATE(3736),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_LPAREN2] = ACTIONS(4656),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3673),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3669),
    [anon_sym_compl] = ACTIONS(3669),
    [anon_sym_DASH_DASH] = ACTIONS(4558),
    [anon_sym_PLUS_PLUS] = ACTIONS(4558),
    [anon_sym_sizeof] = ACTIONS(3679),
    [anon_sym___alignof__] = ACTIONS(3681),
    [anon_sym___alignof] = ACTIONS(3681),
    [anon_sym__alignof] = ACTIONS(3681),
    [anon_sym_alignof] = ACTIONS(3681),
    [anon_sym__Alignof] = ACTIONS(3681),
    [anon_sym_offsetof] = ACTIONS(3683),
    [anon_sym__Generic] = ACTIONS(3685),
    [anon_sym_asm] = ACTIONS(3687),
    [anon_sym___asm__] = ACTIONS(3687),
    [sym_number_literal] = ACTIONS(3689),
    [anon_sym_L_SQUOTE] = ACTIONS(3691),
    [anon_sym_u_SQUOTE] = ACTIONS(3691),
    [anon_sym_U_SQUOTE] = ACTIONS(3691),
    [anon_sym_u8_SQUOTE] = ACTIONS(3691),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [anon_sym_L_DQUOTE] = ACTIONS(3693),
    [anon_sym_u_DQUOTE] = ACTIONS(3693),
    [anon_sym_U_DQUOTE] = ACTIONS(3693),
    [anon_sym_u8_DQUOTE] = ACTIONS(3693),
    [anon_sym_DQUOTE] = ACTIONS(3693),
    [sym_true] = ACTIONS(3695),
    [sym_false] = ACTIONS(3695),
    [anon_sym_NULL] = ACTIONS(3697),
    [anon_sym_nullptr] = ACTIONS(3697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3699),
    [anon_sym_R_DQUOTE] = ACTIONS(3701),
    [anon_sym_LR_DQUOTE] = ACTIONS(3701),
    [anon_sym_uR_DQUOTE] = ACTIONS(3701),
    [anon_sym_UR_DQUOTE] = ACTIONS(3701),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3701),
    [anon_sym_co_await] = ACTIONS(3703),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_requires] = ACTIONS(3707),
    [sym_this] = ACTIONS(3695),
  },
  [1584] = {
    [sym_expression] = STATE(4630),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1585] = {
    [sym_expression] = STATE(3369),
    [sym__string] = STATE(3729),
    [sym_conditional_expression] = STATE(3729),
    [sym_assignment_expression] = STATE(3729),
    [sym_pointer_expression] = STATE(3736),
    [sym_unary_expression] = STATE(3729),
    [sym_binary_expression] = STATE(3729),
    [sym_update_expression] = STATE(3729),
    [sym_cast_expression] = STATE(3729),
    [sym_sizeof_expression] = STATE(3729),
    [sym_alignof_expression] = STATE(3729),
    [sym_offsetof_expression] = STATE(3729),
    [sym_generic_expression] = STATE(3729),
    [sym_subscript_expression] = STATE(3736),
    [sym_call_expression] = STATE(3736),
    [sym_gnu_asm_expression] = STATE(3729),
    [sym_field_expression] = STATE(3736),
    [sym_compound_literal_expression] = STATE(3729),
    [sym_parenthesized_expression] = STATE(3736),
    [sym_char_literal] = STATE(3602),
    [sym_concatenated_string] = STATE(3610),
    [sym_string_literal] = STATE(2698),
    [sym_null] = STATE(3729),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7745),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3729),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(3729),
    [sym_new_expression] = STATE(3729),
    [sym_delete_expression] = STATE(3729),
    [sym_requires_clause] = STATE(3729),
    [sym_requires_expression] = STATE(3729),
    [sym_lambda_expression] = STATE(3729),
    [sym_lambda_capture_specifier] = STATE(5813),
    [sym_fold_expression] = STATE(3729),
    [sym_parameter_pack_expansion] = STATE(3729),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3736),
    [sym_qualified_type_identifier] = STATE(7745),
    [sym_user_defined_literal] = STATE(3736),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_LPAREN2] = ACTIONS(4656),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3673),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3669),
    [anon_sym_compl] = ACTIONS(3669),
    [anon_sym_DASH_DASH] = ACTIONS(4558),
    [anon_sym_PLUS_PLUS] = ACTIONS(4558),
    [anon_sym_sizeof] = ACTIONS(3679),
    [anon_sym___alignof__] = ACTIONS(3681),
    [anon_sym___alignof] = ACTIONS(3681),
    [anon_sym__alignof] = ACTIONS(3681),
    [anon_sym_alignof] = ACTIONS(3681),
    [anon_sym__Alignof] = ACTIONS(3681),
    [anon_sym_offsetof] = ACTIONS(3683),
    [anon_sym__Generic] = ACTIONS(3685),
    [anon_sym_asm] = ACTIONS(3687),
    [anon_sym___asm__] = ACTIONS(3687),
    [sym_number_literal] = ACTIONS(3689),
    [anon_sym_L_SQUOTE] = ACTIONS(3691),
    [anon_sym_u_SQUOTE] = ACTIONS(3691),
    [anon_sym_U_SQUOTE] = ACTIONS(3691),
    [anon_sym_u8_SQUOTE] = ACTIONS(3691),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [anon_sym_L_DQUOTE] = ACTIONS(3693),
    [anon_sym_u_DQUOTE] = ACTIONS(3693),
    [anon_sym_U_DQUOTE] = ACTIONS(3693),
    [anon_sym_u8_DQUOTE] = ACTIONS(3693),
    [anon_sym_DQUOTE] = ACTIONS(3693),
    [sym_true] = ACTIONS(3695),
    [sym_false] = ACTIONS(3695),
    [anon_sym_NULL] = ACTIONS(3697),
    [anon_sym_nullptr] = ACTIONS(3697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3699),
    [anon_sym_R_DQUOTE] = ACTIONS(3701),
    [anon_sym_LR_DQUOTE] = ACTIONS(3701),
    [anon_sym_uR_DQUOTE] = ACTIONS(3701),
    [anon_sym_UR_DQUOTE] = ACTIONS(3701),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3701),
    [anon_sym_co_await] = ACTIONS(3703),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_requires] = ACTIONS(3707),
    [sym_this] = ACTIONS(3695),
  },
  [1586] = {
    [sym_expression] = STATE(4609),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1587] = {
    [sym_expression] = STATE(3368),
    [sym__string] = STATE(3729),
    [sym_conditional_expression] = STATE(3729),
    [sym_assignment_expression] = STATE(3729),
    [sym_pointer_expression] = STATE(3736),
    [sym_unary_expression] = STATE(3729),
    [sym_binary_expression] = STATE(3729),
    [sym_update_expression] = STATE(3729),
    [sym_cast_expression] = STATE(3729),
    [sym_sizeof_expression] = STATE(3729),
    [sym_alignof_expression] = STATE(3729),
    [sym_offsetof_expression] = STATE(3729),
    [sym_generic_expression] = STATE(3729),
    [sym_subscript_expression] = STATE(3736),
    [sym_call_expression] = STATE(3736),
    [sym_gnu_asm_expression] = STATE(3729),
    [sym_field_expression] = STATE(3736),
    [sym_compound_literal_expression] = STATE(3729),
    [sym_parenthesized_expression] = STATE(3736),
    [sym_char_literal] = STATE(3602),
    [sym_concatenated_string] = STATE(3610),
    [sym_string_literal] = STATE(2698),
    [sym_null] = STATE(3729),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7745),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3729),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(3729),
    [sym_new_expression] = STATE(3729),
    [sym_delete_expression] = STATE(3729),
    [sym_requires_clause] = STATE(3729),
    [sym_requires_expression] = STATE(3729),
    [sym_lambda_expression] = STATE(3729),
    [sym_lambda_capture_specifier] = STATE(5813),
    [sym_fold_expression] = STATE(3729),
    [sym_parameter_pack_expansion] = STATE(3729),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3736),
    [sym_qualified_type_identifier] = STATE(7745),
    [sym_user_defined_literal] = STATE(3736),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_LPAREN2] = ACTIONS(4656),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3673),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3669),
    [anon_sym_compl] = ACTIONS(3669),
    [anon_sym_DASH_DASH] = ACTIONS(4558),
    [anon_sym_PLUS_PLUS] = ACTIONS(4558),
    [anon_sym_sizeof] = ACTIONS(3679),
    [anon_sym___alignof__] = ACTIONS(3681),
    [anon_sym___alignof] = ACTIONS(3681),
    [anon_sym__alignof] = ACTIONS(3681),
    [anon_sym_alignof] = ACTIONS(3681),
    [anon_sym__Alignof] = ACTIONS(3681),
    [anon_sym_offsetof] = ACTIONS(3683),
    [anon_sym__Generic] = ACTIONS(3685),
    [anon_sym_asm] = ACTIONS(3687),
    [anon_sym___asm__] = ACTIONS(3687),
    [sym_number_literal] = ACTIONS(3689),
    [anon_sym_L_SQUOTE] = ACTIONS(3691),
    [anon_sym_u_SQUOTE] = ACTIONS(3691),
    [anon_sym_U_SQUOTE] = ACTIONS(3691),
    [anon_sym_u8_SQUOTE] = ACTIONS(3691),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [anon_sym_L_DQUOTE] = ACTIONS(3693),
    [anon_sym_u_DQUOTE] = ACTIONS(3693),
    [anon_sym_U_DQUOTE] = ACTIONS(3693),
    [anon_sym_u8_DQUOTE] = ACTIONS(3693),
    [anon_sym_DQUOTE] = ACTIONS(3693),
    [sym_true] = ACTIONS(3695),
    [sym_false] = ACTIONS(3695),
    [anon_sym_NULL] = ACTIONS(3697),
    [anon_sym_nullptr] = ACTIONS(3697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3699),
    [anon_sym_R_DQUOTE] = ACTIONS(3701),
    [anon_sym_LR_DQUOTE] = ACTIONS(3701),
    [anon_sym_uR_DQUOTE] = ACTIONS(3701),
    [anon_sym_UR_DQUOTE] = ACTIONS(3701),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3701),
    [anon_sym_co_await] = ACTIONS(3703),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_requires] = ACTIONS(3707),
    [sym_this] = ACTIONS(3695),
  },
  [1588] = {
    [sym_expression] = STATE(4287),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1589] = {
    [sym_expression] = STATE(4443),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1590] = {
    [sym_expression] = STATE(4352),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1591] = {
    [sym_expression] = STATE(4259),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1592] = {
    [sym_expression] = STATE(4444),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1593] = {
    [sym_expression] = STATE(4445),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1594] = {
    [sym_expression] = STATE(3930),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_LPAREN2] = ACTIONS(4662),
    [anon_sym_BANG] = ACTIONS(3948),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3946),
    [anon_sym_PLUS] = ACTIONS(3946),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_DASH_DASH] = ACTIONS(4537),
    [anon_sym_PLUS_PLUS] = ACTIONS(4537),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1595] = {
    [sym_expression] = STATE(3131),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1596] = {
    [sym_expression] = STATE(4295),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1597] = {
    [sym_expression] = STATE(2749),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1598] = {
    [sym_expression] = STATE(4189),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_LPAREN2] = ACTIONS(4662),
    [anon_sym_BANG] = ACTIONS(3948),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3946),
    [anon_sym_PLUS] = ACTIONS(3946),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_DASH_DASH] = ACTIONS(4537),
    [anon_sym_PLUS_PLUS] = ACTIONS(4537),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1599] = {
    [sym_expression] = STATE(4500),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1600] = {
    [sym_expression] = STATE(4190),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_LPAREN2] = ACTIONS(4662),
    [anon_sym_BANG] = ACTIONS(3948),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3946),
    [anon_sym_PLUS] = ACTIONS(3946),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_DASH_DASH] = ACTIONS(4537),
    [anon_sym_PLUS_PLUS] = ACTIONS(4537),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1601] = {
    [sym_expression] = STATE(4303),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1602] = {
    [sym_expression] = STATE(4431),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1603] = {
    [sym_expression] = STATE(4643),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1604] = {
    [sym_expression] = STATE(4191),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_LPAREN2] = ACTIONS(4662),
    [anon_sym_BANG] = ACTIONS(3948),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3946),
    [anon_sym_PLUS] = ACTIONS(3946),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_DASH_DASH] = ACTIONS(4537),
    [anon_sym_PLUS_PLUS] = ACTIONS(4537),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1605] = {
    [sym_expression] = STATE(4478),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1606] = {
    [sym_expression] = STATE(4509),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1607] = {
    [sym_expression] = STATE(4192),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_LPAREN2] = ACTIONS(4662),
    [anon_sym_BANG] = ACTIONS(3948),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3946),
    [anon_sym_PLUS] = ACTIONS(3946),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_DASH_DASH] = ACTIONS(4537),
    [anon_sym_PLUS_PLUS] = ACTIONS(4537),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1608] = {
    [sym_expression] = STATE(4658),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1609] = {
    [sym_expression] = STATE(3282),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1610] = {
    [sym_expression] = STATE(4428),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1611] = {
    [sym_expression] = STATE(4269),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1612] = {
    [sym_expression] = STATE(4266),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1613] = {
    [sym_expression] = STATE(4279),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1614] = {
    [sym_expression] = STATE(3930),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1615] = {
    [sym_expression] = STATE(3662),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(4934),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1616] = {
    [sym_expression] = STATE(4276),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1617] = {
    [sym_expression] = STATE(4379),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1618] = {
    [sym_expression] = STATE(4558),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1619] = {
    [sym_expression] = STATE(3139),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(4936),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1620] = {
    [sym_expression] = STATE(4486),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1621] = {
    [sym_expression] = STATE(4621),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1622] = {
    [sym_expression] = STATE(4194),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_LPAREN2] = ACTIONS(4662),
    [anon_sym_BANG] = ACTIONS(3948),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3946),
    [anon_sym_PLUS] = ACTIONS(3946),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_DASH_DASH] = ACTIONS(4537),
    [anon_sym_PLUS_PLUS] = ACTIONS(4537),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1623] = {
    [sym_expression] = STATE(4196),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_LPAREN2] = ACTIONS(4662),
    [anon_sym_BANG] = ACTIONS(3948),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3946),
    [anon_sym_PLUS] = ACTIONS(3946),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_DASH_DASH] = ACTIONS(4537),
    [anon_sym_PLUS_PLUS] = ACTIONS(4537),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1624] = {
    [sym_expression] = STATE(4201),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_LPAREN2] = ACTIONS(4662),
    [anon_sym_BANG] = ACTIONS(3948),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3946),
    [anon_sym_PLUS] = ACTIONS(3946),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_DASH_DASH] = ACTIONS(4537),
    [anon_sym_PLUS_PLUS] = ACTIONS(4537),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1625] = {
    [sym_expression] = STATE(4449),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(4938),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1626] = {
    [sym_expression] = STATE(3877),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1627] = {
    [sym_expression] = STATE(4208),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_LPAREN2] = ACTIONS(4662),
    [anon_sym_BANG] = ACTIONS(3948),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3946),
    [anon_sym_PLUS] = ACTIONS(3946),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_DASH_DASH] = ACTIONS(4537),
    [anon_sym_PLUS_PLUS] = ACTIONS(4537),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1628] = {
    [sym_expression] = STATE(3931),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1629] = {
    [sym_expression] = STATE(3702),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1630] = {
    [sym_expression] = STATE(4357),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1631] = {
    [sym_expression] = STATE(3771),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1632] = {
    [sym_expression] = STATE(4488),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1633] = {
    [sym_expression] = STATE(4382),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1634] = {
    [sym_expression] = STATE(3119),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1635] = {
    [sym__declaration_modifiers] = STATE(1984),
    [sym__declaration_specifiers] = STATE(4097),
    [sym_attribute_specifier] = STATE(1984),
    [sym_attribute_declaration] = STATE(1984),
    [sym_ms_declspec_modifier] = STATE(1984),
    [sym_storage_class_specifier] = STATE(1984),
    [sym_type_qualifier] = STATE(1984),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_parameter_declaration] = STATE(7081),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_optional_parameter_declaration] = STATE(7081),
    [sym_variadic_parameter_declaration] = STATE(7081),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6449),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1984),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1984),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(4068),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4940),
    [anon_sym_RPAREN] = ACTIONS(4942),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1827),
    [anon_sym_out] = ACTIONS(1827),
    [anon_sym_inout] = ACTIONS(1827),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(4078),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(1833),
    [anon_sym_class] = ACTIONS(1835),
    [anon_sym_struct] = ACTIONS(1837),
    [anon_sym_union] = ACTIONS(1839),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1827),
    [anon_sym_typename] = ACTIONS(1863),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1636] = {
    [sym_expression] = STATE(3272),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1637] = {
    [sym_expression] = STATE(4534),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1638] = {
    [sym_expression] = STATE(3275),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1639] = {
    [sym_expression] = STATE(3255),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3360),
    [sym_concatenated_string] = STATE(3359),
    [sym_string_literal] = STATE(2634),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2625),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3635),
    [anon_sym_LPAREN2] = ACTIONS(4658),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3641),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3637),
    [anon_sym_compl] = ACTIONS(3637),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_sizeof] = ACTIONS(3643),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3645),
    [anon_sym_L_SQUOTE] = ACTIONS(3647),
    [anon_sym_u_SQUOTE] = ACTIONS(3647),
    [anon_sym_U_SQUOTE] = ACTIONS(3647),
    [anon_sym_u8_SQUOTE] = ACTIONS(3647),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [anon_sym_L_DQUOTE] = ACTIONS(3649),
    [anon_sym_u_DQUOTE] = ACTIONS(3649),
    [anon_sym_U_DQUOTE] = ACTIONS(3649),
    [anon_sym_u8_DQUOTE] = ACTIONS(3649),
    [anon_sym_DQUOTE] = ACTIONS(3649),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3651),
    [anon_sym_R_DQUOTE] = ACTIONS(3653),
    [anon_sym_LR_DQUOTE] = ACTIONS(3653),
    [anon_sym_uR_DQUOTE] = ACTIONS(3653),
    [anon_sym_UR_DQUOTE] = ACTIONS(3653),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3653),
    [anon_sym_co_await] = ACTIONS(3655),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1640] = {
    [sym_expression] = STATE(3276),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1641] = {
    [sym_expression] = STATE(3267),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3360),
    [sym_concatenated_string] = STATE(3359),
    [sym_string_literal] = STATE(2634),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2625),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3635),
    [anon_sym_LPAREN2] = ACTIONS(4658),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3641),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3637),
    [anon_sym_compl] = ACTIONS(3637),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_sizeof] = ACTIONS(3643),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3645),
    [anon_sym_L_SQUOTE] = ACTIONS(3647),
    [anon_sym_u_SQUOTE] = ACTIONS(3647),
    [anon_sym_U_SQUOTE] = ACTIONS(3647),
    [anon_sym_u8_SQUOTE] = ACTIONS(3647),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [anon_sym_L_DQUOTE] = ACTIONS(3649),
    [anon_sym_u_DQUOTE] = ACTIONS(3649),
    [anon_sym_U_DQUOTE] = ACTIONS(3649),
    [anon_sym_u8_DQUOTE] = ACTIONS(3649),
    [anon_sym_DQUOTE] = ACTIONS(3649),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3651),
    [anon_sym_R_DQUOTE] = ACTIONS(3653),
    [anon_sym_LR_DQUOTE] = ACTIONS(3653),
    [anon_sym_uR_DQUOTE] = ACTIONS(3653),
    [anon_sym_UR_DQUOTE] = ACTIONS(3653),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3653),
    [anon_sym_co_await] = ACTIONS(3655),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1642] = {
    [sym_expression] = STATE(4539),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1643] = {
    [sym_expression] = STATE(4197),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_LPAREN2] = ACTIONS(4662),
    [anon_sym_BANG] = ACTIONS(3948),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3946),
    [anon_sym_PLUS] = ACTIONS(3946),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_DASH_DASH] = ACTIONS(4537),
    [anon_sym_PLUS_PLUS] = ACTIONS(4537),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1644] = {
    [sym_expression] = STATE(3277),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1645] = {
    [sym_expression] = STATE(4380),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1646] = {
    [sym_expression] = STATE(3433),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4676),
    [anon_sym_BANG] = ACTIONS(3713),
    [anon_sym_TILDE] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3711),
    [anon_sym_PLUS] = ACTIONS(3711),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(3715),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3711),
    [anon_sym_compl] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(4562),
    [anon_sym_PLUS_PLUS] = ACTIONS(4562),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3719),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1647] = {
    [sym_expression] = STATE(3278),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1648] = {
    [sym_expression] = STATE(4623),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1649] = {
    [sym_expression] = STATE(3280),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1650] = {
    [sym_expression] = STATE(4341),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1651] = {
    [sym_expression] = STATE(4389),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1652] = {
    [sym_expression] = STATE(3269),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3360),
    [sym_concatenated_string] = STATE(3359),
    [sym_string_literal] = STATE(2634),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2625),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3635),
    [anon_sym_LPAREN2] = ACTIONS(4658),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3641),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3637),
    [anon_sym_compl] = ACTIONS(3637),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_sizeof] = ACTIONS(3643),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3645),
    [anon_sym_L_SQUOTE] = ACTIONS(3647),
    [anon_sym_u_SQUOTE] = ACTIONS(3647),
    [anon_sym_U_SQUOTE] = ACTIONS(3647),
    [anon_sym_u8_SQUOTE] = ACTIONS(3647),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [anon_sym_L_DQUOTE] = ACTIONS(3649),
    [anon_sym_u_DQUOTE] = ACTIONS(3649),
    [anon_sym_U_DQUOTE] = ACTIONS(3649),
    [anon_sym_u8_DQUOTE] = ACTIONS(3649),
    [anon_sym_DQUOTE] = ACTIONS(3649),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3651),
    [anon_sym_R_DQUOTE] = ACTIONS(3653),
    [anon_sym_LR_DQUOTE] = ACTIONS(3653),
    [anon_sym_uR_DQUOTE] = ACTIONS(3653),
    [anon_sym_UR_DQUOTE] = ACTIONS(3653),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3653),
    [anon_sym_co_await] = ACTIONS(3655),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1653] = {
    [sym_expression] = STATE(3284),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1654] = {
    [sym_expression] = STATE(4462),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1655] = {
    [sym_expression] = STATE(3271),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3360),
    [sym_concatenated_string] = STATE(3359),
    [sym_string_literal] = STATE(2634),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2625),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3635),
    [anon_sym_LPAREN2] = ACTIONS(4658),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3641),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3637),
    [anon_sym_compl] = ACTIONS(3637),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_sizeof] = ACTIONS(3643),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3645),
    [anon_sym_L_SQUOTE] = ACTIONS(3647),
    [anon_sym_u_SQUOTE] = ACTIONS(3647),
    [anon_sym_U_SQUOTE] = ACTIONS(3647),
    [anon_sym_u8_SQUOTE] = ACTIONS(3647),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [anon_sym_L_DQUOTE] = ACTIONS(3649),
    [anon_sym_u_DQUOTE] = ACTIONS(3649),
    [anon_sym_U_DQUOTE] = ACTIONS(3649),
    [anon_sym_u8_DQUOTE] = ACTIONS(3649),
    [anon_sym_DQUOTE] = ACTIONS(3649),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3651),
    [anon_sym_R_DQUOTE] = ACTIONS(3653),
    [anon_sym_LR_DQUOTE] = ACTIONS(3653),
    [anon_sym_uR_DQUOTE] = ACTIONS(3653),
    [anon_sym_UR_DQUOTE] = ACTIONS(3653),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3653),
    [anon_sym_co_await] = ACTIONS(3655),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1656] = {
    [sym_expression] = STATE(4490),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1657] = {
    [sym_expression] = STATE(4421),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1658] = {
    [sym_expression] = STATE(4507),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1659] = {
    [sym_expression] = STATE(4581),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(4944),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1660] = {
    [sym_expression] = STATE(4516),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1661] = {
    [sym_expression] = STATE(4461),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1662] = {
    [sym_expression] = STATE(3296),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1663] = {
    [sym_expression] = STATE(3432),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4676),
    [anon_sym_BANG] = ACTIONS(3713),
    [anon_sym_TILDE] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3711),
    [anon_sym_PLUS] = ACTIONS(3711),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(3715),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3711),
    [anon_sym_compl] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(4562),
    [anon_sym_PLUS_PLUS] = ACTIONS(4562),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3719),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1664] = {
    [sym_expression] = STATE(4517),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1665] = {
    [sym_expression] = STATE(4399),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1666] = {
    [sym_expression] = STATE(3285),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1667] = {
    [sym_expression] = STATE(3877),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_LPAREN2] = ACTIONS(4662),
    [anon_sym_BANG] = ACTIONS(3948),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3946),
    [anon_sym_PLUS] = ACTIONS(3946),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_DASH_DASH] = ACTIONS(4537),
    [anon_sym_PLUS_PLUS] = ACTIONS(4537),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1668] = {
    [sym_expression] = STATE(3673),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1669] = {
    [sym_expression] = STATE(3931),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_LPAREN2] = ACTIONS(4662),
    [anon_sym_BANG] = ACTIONS(3948),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3946),
    [anon_sym_PLUS] = ACTIONS(3946),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_DASH_DASH] = ACTIONS(4537),
    [anon_sym_PLUS_PLUS] = ACTIONS(4537),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1670] = {
    [sym_expression] = STATE(3364),
    [sym__string] = STATE(3729),
    [sym_conditional_expression] = STATE(3729),
    [sym_assignment_expression] = STATE(3729),
    [sym_pointer_expression] = STATE(3736),
    [sym_unary_expression] = STATE(3729),
    [sym_binary_expression] = STATE(3729),
    [sym_update_expression] = STATE(3729),
    [sym_cast_expression] = STATE(3729),
    [sym_sizeof_expression] = STATE(3729),
    [sym_alignof_expression] = STATE(3729),
    [sym_offsetof_expression] = STATE(3729),
    [sym_generic_expression] = STATE(3729),
    [sym_subscript_expression] = STATE(3736),
    [sym_call_expression] = STATE(3736),
    [sym_gnu_asm_expression] = STATE(3729),
    [sym_field_expression] = STATE(3736),
    [sym_compound_literal_expression] = STATE(3729),
    [sym_parenthesized_expression] = STATE(3736),
    [sym_char_literal] = STATE(3602),
    [sym_concatenated_string] = STATE(3610),
    [sym_string_literal] = STATE(2698),
    [sym_null] = STATE(3729),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7745),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3729),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(3729),
    [sym_new_expression] = STATE(3729),
    [sym_delete_expression] = STATE(3729),
    [sym_requires_clause] = STATE(3729),
    [sym_requires_expression] = STATE(3729),
    [sym_lambda_expression] = STATE(3729),
    [sym_lambda_capture_specifier] = STATE(5813),
    [sym_fold_expression] = STATE(3729),
    [sym_parameter_pack_expansion] = STATE(3729),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3736),
    [sym_qualified_type_identifier] = STATE(7745),
    [sym_user_defined_literal] = STATE(3736),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_LPAREN2] = ACTIONS(4656),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3673),
    [anon_sym_LBRACK] = ACTIONS(4946),
    [sym_primitive_type] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3669),
    [anon_sym_compl] = ACTIONS(3669),
    [anon_sym_DASH_DASH] = ACTIONS(4558),
    [anon_sym_PLUS_PLUS] = ACTIONS(4558),
    [anon_sym_sizeof] = ACTIONS(3679),
    [anon_sym___alignof__] = ACTIONS(3681),
    [anon_sym___alignof] = ACTIONS(3681),
    [anon_sym__alignof] = ACTIONS(3681),
    [anon_sym_alignof] = ACTIONS(3681),
    [anon_sym__Alignof] = ACTIONS(3681),
    [anon_sym_offsetof] = ACTIONS(3683),
    [anon_sym__Generic] = ACTIONS(3685),
    [anon_sym_asm] = ACTIONS(3687),
    [anon_sym___asm__] = ACTIONS(3687),
    [sym_number_literal] = ACTIONS(3689),
    [anon_sym_L_SQUOTE] = ACTIONS(3691),
    [anon_sym_u_SQUOTE] = ACTIONS(3691),
    [anon_sym_U_SQUOTE] = ACTIONS(3691),
    [anon_sym_u8_SQUOTE] = ACTIONS(3691),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [anon_sym_L_DQUOTE] = ACTIONS(3693),
    [anon_sym_u_DQUOTE] = ACTIONS(3693),
    [anon_sym_U_DQUOTE] = ACTIONS(3693),
    [anon_sym_u8_DQUOTE] = ACTIONS(3693),
    [anon_sym_DQUOTE] = ACTIONS(3693),
    [sym_true] = ACTIONS(3695),
    [sym_false] = ACTIONS(3695),
    [anon_sym_NULL] = ACTIONS(3697),
    [anon_sym_nullptr] = ACTIONS(3697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3699),
    [anon_sym_R_DQUOTE] = ACTIONS(3701),
    [anon_sym_LR_DQUOTE] = ACTIONS(3701),
    [anon_sym_uR_DQUOTE] = ACTIONS(3701),
    [anon_sym_UR_DQUOTE] = ACTIONS(3701),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3701),
    [anon_sym_co_await] = ACTIONS(3703),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_requires] = ACTIONS(3707),
    [sym_this] = ACTIONS(3695),
  },
  [1671] = {
    [sym_expression] = STATE(3273),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3360),
    [sym_concatenated_string] = STATE(3359),
    [sym_string_literal] = STATE(2634),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2625),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3635),
    [anon_sym_LPAREN2] = ACTIONS(4658),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3641),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3637),
    [anon_sym_compl] = ACTIONS(3637),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_sizeof] = ACTIONS(3643),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3645),
    [anon_sym_L_SQUOTE] = ACTIONS(3647),
    [anon_sym_u_SQUOTE] = ACTIONS(3647),
    [anon_sym_U_SQUOTE] = ACTIONS(3647),
    [anon_sym_u8_SQUOTE] = ACTIONS(3647),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [anon_sym_L_DQUOTE] = ACTIONS(3649),
    [anon_sym_u_DQUOTE] = ACTIONS(3649),
    [anon_sym_U_DQUOTE] = ACTIONS(3649),
    [anon_sym_u8_DQUOTE] = ACTIONS(3649),
    [anon_sym_DQUOTE] = ACTIONS(3649),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3651),
    [anon_sym_R_DQUOTE] = ACTIONS(3653),
    [anon_sym_LR_DQUOTE] = ACTIONS(3653),
    [anon_sym_uR_DQUOTE] = ACTIONS(3653),
    [anon_sym_UR_DQUOTE] = ACTIONS(3653),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3653),
    [anon_sym_co_await] = ACTIONS(3655),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1672] = {
    [sym_expression] = STATE(4672),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1673] = {
    [sym_expression] = STATE(4708),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1674] = {
    [sym_expression] = STATE(4634),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1675] = {
    [sym_expression] = STATE(4635),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1676] = {
    [sym_expression] = STATE(3290),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1677] = {
    [sym_expression] = STATE(4560),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1678] = {
    [sym_expression] = STATE(4610),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1679] = {
    [sym_expression] = STATE(4707),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1680] = {
    [sym_expression] = STATE(4470),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1681] = {
    [sym_expression] = STATE(3405),
    [sym__string] = STATE(3729),
    [sym_conditional_expression] = STATE(3729),
    [sym_assignment_expression] = STATE(3729),
    [sym_pointer_expression] = STATE(3736),
    [sym_unary_expression] = STATE(3729),
    [sym_binary_expression] = STATE(3729),
    [sym_update_expression] = STATE(3729),
    [sym_cast_expression] = STATE(3729),
    [sym_sizeof_expression] = STATE(3729),
    [sym_alignof_expression] = STATE(3729),
    [sym_offsetof_expression] = STATE(3729),
    [sym_generic_expression] = STATE(3729),
    [sym_subscript_expression] = STATE(3736),
    [sym_call_expression] = STATE(3736),
    [sym_gnu_asm_expression] = STATE(3729),
    [sym_field_expression] = STATE(3736),
    [sym_compound_literal_expression] = STATE(3729),
    [sym_parenthesized_expression] = STATE(3736),
    [sym_char_literal] = STATE(3602),
    [sym_concatenated_string] = STATE(3610),
    [sym_string_literal] = STATE(2698),
    [sym_null] = STATE(3729),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7745),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3729),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(3729),
    [sym_new_expression] = STATE(3729),
    [sym_delete_expression] = STATE(3729),
    [sym_requires_clause] = STATE(3729),
    [sym_requires_expression] = STATE(3729),
    [sym_lambda_expression] = STATE(3729),
    [sym_lambda_capture_specifier] = STATE(5813),
    [sym_fold_expression] = STATE(3729),
    [sym_parameter_pack_expansion] = STATE(3729),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3736),
    [sym_qualified_type_identifier] = STATE(7745),
    [sym_user_defined_literal] = STATE(3736),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_LPAREN2] = ACTIONS(4656),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3673),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3669),
    [anon_sym_compl] = ACTIONS(3669),
    [anon_sym_DASH_DASH] = ACTIONS(4558),
    [anon_sym_PLUS_PLUS] = ACTIONS(4558),
    [anon_sym_sizeof] = ACTIONS(3679),
    [anon_sym___alignof__] = ACTIONS(3681),
    [anon_sym___alignof] = ACTIONS(3681),
    [anon_sym__alignof] = ACTIONS(3681),
    [anon_sym_alignof] = ACTIONS(3681),
    [anon_sym__Alignof] = ACTIONS(3681),
    [anon_sym_offsetof] = ACTIONS(3683),
    [anon_sym__Generic] = ACTIONS(3685),
    [anon_sym_asm] = ACTIONS(3687),
    [anon_sym___asm__] = ACTIONS(3687),
    [sym_number_literal] = ACTIONS(3689),
    [anon_sym_L_SQUOTE] = ACTIONS(3691),
    [anon_sym_u_SQUOTE] = ACTIONS(3691),
    [anon_sym_U_SQUOTE] = ACTIONS(3691),
    [anon_sym_u8_SQUOTE] = ACTIONS(3691),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [anon_sym_L_DQUOTE] = ACTIONS(3693),
    [anon_sym_u_DQUOTE] = ACTIONS(3693),
    [anon_sym_U_DQUOTE] = ACTIONS(3693),
    [anon_sym_u8_DQUOTE] = ACTIONS(3693),
    [anon_sym_DQUOTE] = ACTIONS(3693),
    [sym_true] = ACTIONS(3695),
    [sym_false] = ACTIONS(3695),
    [anon_sym_NULL] = ACTIONS(3697),
    [anon_sym_nullptr] = ACTIONS(3697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3699),
    [anon_sym_R_DQUOTE] = ACTIONS(3701),
    [anon_sym_LR_DQUOTE] = ACTIONS(3701),
    [anon_sym_uR_DQUOTE] = ACTIONS(3701),
    [anon_sym_UR_DQUOTE] = ACTIONS(3701),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3701),
    [anon_sym_co_await] = ACTIONS(3703),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_requires] = ACTIONS(3707),
    [sym_this] = ACTIONS(3695),
  },
  [1682] = {
    [sym_expression] = STATE(4524),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1683] = {
    [sym_expression] = STATE(4649),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1684] = {
    [sym_expression] = STATE(3701),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1685] = {
    [sym_expression] = STATE(4527),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1686] = {
    [sym_expression] = STATE(3930),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1687] = {
    [sym_expression] = STATE(4530),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1688] = {
    [sym_expression] = STATE(4387),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1689] = {
    [sym_expression] = STATE(3274),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3360),
    [sym_concatenated_string] = STATE(3359),
    [sym_string_literal] = STATE(2634),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2625),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3635),
    [anon_sym_LPAREN2] = ACTIONS(4658),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3641),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3637),
    [anon_sym_compl] = ACTIONS(3637),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_sizeof] = ACTIONS(3643),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3645),
    [anon_sym_L_SQUOTE] = ACTIONS(3647),
    [anon_sym_u_SQUOTE] = ACTIONS(3647),
    [anon_sym_U_SQUOTE] = ACTIONS(3647),
    [anon_sym_u8_SQUOTE] = ACTIONS(3647),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [anon_sym_L_DQUOTE] = ACTIONS(3649),
    [anon_sym_u_DQUOTE] = ACTIONS(3649),
    [anon_sym_U_DQUOTE] = ACTIONS(3649),
    [anon_sym_u8_DQUOTE] = ACTIONS(3649),
    [anon_sym_DQUOTE] = ACTIONS(3649),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3651),
    [anon_sym_R_DQUOTE] = ACTIONS(3653),
    [anon_sym_LR_DQUOTE] = ACTIONS(3653),
    [anon_sym_uR_DQUOTE] = ACTIONS(3653),
    [anon_sym_UR_DQUOTE] = ACTIONS(3653),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3653),
    [anon_sym_co_await] = ACTIONS(3655),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1690] = {
    [sym_expression] = STATE(4586),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1691] = {
    [sym_expression] = STATE(3268),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1692] = {
    [sym_expression] = STATE(3116),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1693] = {
    [sym_expression] = STATE(3115),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1694] = {
    [sym_expression] = STATE(3114),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1695] = {
    [sym_expression] = STATE(2712),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3360),
    [sym_concatenated_string] = STATE(3359),
    [sym_string_literal] = STATE(2634),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2625),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3635),
    [anon_sym_LPAREN2] = ACTIONS(4658),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3641),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3637),
    [anon_sym_compl] = ACTIONS(3637),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_sizeof] = ACTIONS(3643),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3645),
    [anon_sym_L_SQUOTE] = ACTIONS(3647),
    [anon_sym_u_SQUOTE] = ACTIONS(3647),
    [anon_sym_U_SQUOTE] = ACTIONS(3647),
    [anon_sym_u8_SQUOTE] = ACTIONS(3647),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [anon_sym_L_DQUOTE] = ACTIONS(3649),
    [anon_sym_u_DQUOTE] = ACTIONS(3649),
    [anon_sym_U_DQUOTE] = ACTIONS(3649),
    [anon_sym_u8_DQUOTE] = ACTIONS(3649),
    [anon_sym_DQUOTE] = ACTIONS(3649),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3651),
    [anon_sym_R_DQUOTE] = ACTIONS(3653),
    [anon_sym_LR_DQUOTE] = ACTIONS(3653),
    [anon_sym_uR_DQUOTE] = ACTIONS(3653),
    [anon_sym_UR_DQUOTE] = ACTIONS(3653),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3653),
    [anon_sym_co_await] = ACTIONS(3655),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1696] = {
    [sym_expression] = STATE(4492),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1697] = {
    [sym_expression] = STATE(3113),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1698] = {
    [sym_expression] = STATE(3470),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4676),
    [anon_sym_BANG] = ACTIONS(3713),
    [anon_sym_TILDE] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3711),
    [anon_sym_PLUS] = ACTIONS(3711),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(3715),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3711),
    [anon_sym_compl] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(4562),
    [anon_sym_PLUS_PLUS] = ACTIONS(4562),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3719),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1699] = {
    [sym_expression] = STATE(4410),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1700] = {
    [sym_expression] = STATE(3768),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(4948),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1701] = {
    [sym_expression] = STATE(4618),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1702] = {
    [sym_expression] = STATE(3111),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1703] = {
    [sym_expression] = STATE(3110),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1704] = {
    [sym_expression] = STATE(4406),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1705] = {
    [sym_expression] = STATE(4405),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1706] = {
    [sym_expression] = STATE(2756),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3360),
    [sym_concatenated_string] = STATE(3359),
    [sym_string_literal] = STATE(2634),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2625),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3635),
    [anon_sym_LPAREN2] = ACTIONS(4658),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3641),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3637),
    [anon_sym_compl] = ACTIONS(3637),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_sizeof] = ACTIONS(3643),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3645),
    [anon_sym_L_SQUOTE] = ACTIONS(3647),
    [anon_sym_u_SQUOTE] = ACTIONS(3647),
    [anon_sym_U_SQUOTE] = ACTIONS(3647),
    [anon_sym_u8_SQUOTE] = ACTIONS(3647),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [anon_sym_L_DQUOTE] = ACTIONS(3649),
    [anon_sym_u_DQUOTE] = ACTIONS(3649),
    [anon_sym_U_DQUOTE] = ACTIONS(3649),
    [anon_sym_u8_DQUOTE] = ACTIONS(3649),
    [anon_sym_DQUOTE] = ACTIONS(3649),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3651),
    [anon_sym_R_DQUOTE] = ACTIONS(3653),
    [anon_sym_LR_DQUOTE] = ACTIONS(3653),
    [anon_sym_uR_DQUOTE] = ACTIONS(3653),
    [anon_sym_UR_DQUOTE] = ACTIONS(3653),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3653),
    [anon_sym_co_await] = ACTIONS(3655),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1707] = {
    [sym_expression] = STATE(4404),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1708] = {
    [sym_expression] = STATE(3109),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1709] = {
    [sym_expression] = STATE(3129),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1710] = {
    [sym_expression] = STATE(2743),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1711] = {
    [sym_expression] = STATE(4403),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1712] = {
    [sym_expression] = STATE(4402),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1713] = {
    [sym_expression] = STATE(4400),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1714] = {
    [sym_expression] = STATE(4396),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1715] = {
    [sym_expression] = STATE(4393),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1716] = {
    [sym_expression] = STATE(3930),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1717] = {
    [sym_expression] = STATE(4392),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1718] = {
    [sym__declaration_modifiers] = STATE(1984),
    [sym__declaration_specifiers] = STATE(4097),
    [sym_attribute_specifier] = STATE(1984),
    [sym_attribute_declaration] = STATE(1984),
    [sym_ms_declspec_modifier] = STATE(1984),
    [sym_storage_class_specifier] = STATE(1984),
    [sym_type_qualifier] = STATE(1984),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_parameter_declaration] = STATE(7229),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_optional_parameter_declaration] = STATE(7229),
    [sym_variadic_parameter_declaration] = STATE(7229),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6449),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1984),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1984),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(4068),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4950),
    [anon_sym_RPAREN] = ACTIONS(4952),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1827),
    [anon_sym_out] = ACTIONS(1827),
    [anon_sym_inout] = ACTIONS(1827),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(4078),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(1833),
    [anon_sym_class] = ACTIONS(1835),
    [anon_sym_struct] = ACTIONS(1837),
    [anon_sym_union] = ACTIONS(1839),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1827),
    [anon_sym_typename] = ACTIONS(1863),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1719] = {
    [sym_expression] = STATE(3293),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3360),
    [sym_concatenated_string] = STATE(3359),
    [sym_string_literal] = STATE(2634),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2625),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3635),
    [anon_sym_LPAREN2] = ACTIONS(4658),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3641),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3637),
    [anon_sym_compl] = ACTIONS(3637),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_sizeof] = ACTIONS(3643),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3645),
    [anon_sym_L_SQUOTE] = ACTIONS(3647),
    [anon_sym_u_SQUOTE] = ACTIONS(3647),
    [anon_sym_U_SQUOTE] = ACTIONS(3647),
    [anon_sym_u8_SQUOTE] = ACTIONS(3647),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [anon_sym_L_DQUOTE] = ACTIONS(3649),
    [anon_sym_u_DQUOTE] = ACTIONS(3649),
    [anon_sym_U_DQUOTE] = ACTIONS(3649),
    [anon_sym_u8_DQUOTE] = ACTIONS(3649),
    [anon_sym_DQUOTE] = ACTIONS(3649),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3651),
    [anon_sym_R_DQUOTE] = ACTIONS(3653),
    [anon_sym_LR_DQUOTE] = ACTIONS(3653),
    [anon_sym_uR_DQUOTE] = ACTIONS(3653),
    [anon_sym_UR_DQUOTE] = ACTIONS(3653),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3653),
    [anon_sym_co_await] = ACTIONS(3655),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1720] = {
    [sym_expression] = STATE(3099),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1721] = {
    [sym_expression] = STATE(3256),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3360),
    [sym_concatenated_string] = STATE(3359),
    [sym_string_literal] = STATE(2634),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2625),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3635),
    [anon_sym_LPAREN2] = ACTIONS(4658),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3641),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3637),
    [anon_sym_compl] = ACTIONS(3637),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_sizeof] = ACTIONS(3643),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3645),
    [anon_sym_L_SQUOTE] = ACTIONS(3647),
    [anon_sym_u_SQUOTE] = ACTIONS(3647),
    [anon_sym_U_SQUOTE] = ACTIONS(3647),
    [anon_sym_u8_SQUOTE] = ACTIONS(3647),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [anon_sym_L_DQUOTE] = ACTIONS(3649),
    [anon_sym_u_DQUOTE] = ACTIONS(3649),
    [anon_sym_U_DQUOTE] = ACTIONS(3649),
    [anon_sym_u8_DQUOTE] = ACTIONS(3649),
    [anon_sym_DQUOTE] = ACTIONS(3649),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3651),
    [anon_sym_R_DQUOTE] = ACTIONS(3653),
    [anon_sym_LR_DQUOTE] = ACTIONS(3653),
    [anon_sym_uR_DQUOTE] = ACTIONS(3653),
    [anon_sym_UR_DQUOTE] = ACTIONS(3653),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3653),
    [anon_sym_co_await] = ACTIONS(3655),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1722] = {
    [sym_expression] = STATE(4529),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1723] = {
    [sym_expression] = STATE(4622),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4150),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1724] = {
    [sym_expression] = STATE(4307),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(4954),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1725] = {
    [sym_expression] = STATE(3465),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4676),
    [anon_sym_BANG] = ACTIONS(3713),
    [anon_sym_TILDE] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3711),
    [anon_sym_PLUS] = ACTIONS(3711),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(3715),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3711),
    [anon_sym_compl] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(4562),
    [anon_sym_PLUS_PLUS] = ACTIONS(4562),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3719),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1726] = {
    [sym_expression] = STATE(4371),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1727] = {
    [sym_expression] = STATE(3295),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3360),
    [sym_concatenated_string] = STATE(3359),
    [sym_string_literal] = STATE(2634),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2625),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3635),
    [anon_sym_LPAREN2] = ACTIONS(4658),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3641),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3637),
    [anon_sym_compl] = ACTIONS(3637),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_sizeof] = ACTIONS(3643),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3645),
    [anon_sym_L_SQUOTE] = ACTIONS(3647),
    [anon_sym_u_SQUOTE] = ACTIONS(3647),
    [anon_sym_U_SQUOTE] = ACTIONS(3647),
    [anon_sym_u8_SQUOTE] = ACTIONS(3647),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [anon_sym_L_DQUOTE] = ACTIONS(3649),
    [anon_sym_u_DQUOTE] = ACTIONS(3649),
    [anon_sym_U_DQUOTE] = ACTIONS(3649),
    [anon_sym_u8_DQUOTE] = ACTIONS(3649),
    [anon_sym_DQUOTE] = ACTIONS(3649),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3651),
    [anon_sym_R_DQUOTE] = ACTIONS(3653),
    [anon_sym_LR_DQUOTE] = ACTIONS(3653),
    [anon_sym_uR_DQUOTE] = ACTIONS(3653),
    [anon_sym_UR_DQUOTE] = ACTIONS(3653),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3653),
    [anon_sym_co_await] = ACTIONS(3655),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1728] = {
    [sym_expression] = STATE(2743),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3360),
    [sym_concatenated_string] = STATE(3359),
    [sym_string_literal] = STATE(2634),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2625),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3635),
    [anon_sym_LPAREN2] = ACTIONS(4658),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3641),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3637),
    [anon_sym_compl] = ACTIONS(3637),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_sizeof] = ACTIONS(3643),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3645),
    [anon_sym_L_SQUOTE] = ACTIONS(3647),
    [anon_sym_u_SQUOTE] = ACTIONS(3647),
    [anon_sym_U_SQUOTE] = ACTIONS(3647),
    [anon_sym_u8_SQUOTE] = ACTIONS(3647),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [anon_sym_L_DQUOTE] = ACTIONS(3649),
    [anon_sym_u_DQUOTE] = ACTIONS(3649),
    [anon_sym_U_DQUOTE] = ACTIONS(3649),
    [anon_sym_u8_DQUOTE] = ACTIONS(3649),
    [anon_sym_DQUOTE] = ACTIONS(3649),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3651),
    [anon_sym_R_DQUOTE] = ACTIONS(3653),
    [anon_sym_LR_DQUOTE] = ACTIONS(3653),
    [anon_sym_uR_DQUOTE] = ACTIONS(3653),
    [anon_sym_UR_DQUOTE] = ACTIONS(3653),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3653),
    [anon_sym_co_await] = ACTIONS(3655),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1729] = {
    [sym_expression] = STATE(3254),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3360),
    [sym_concatenated_string] = STATE(3359),
    [sym_string_literal] = STATE(2634),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2625),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3635),
    [anon_sym_LPAREN2] = ACTIONS(4658),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3641),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3637),
    [anon_sym_compl] = ACTIONS(3637),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_sizeof] = ACTIONS(3643),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3645),
    [anon_sym_L_SQUOTE] = ACTIONS(3647),
    [anon_sym_u_SQUOTE] = ACTIONS(3647),
    [anon_sym_U_SQUOTE] = ACTIONS(3647),
    [anon_sym_u8_SQUOTE] = ACTIONS(3647),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [anon_sym_L_DQUOTE] = ACTIONS(3649),
    [anon_sym_u_DQUOTE] = ACTIONS(3649),
    [anon_sym_U_DQUOTE] = ACTIONS(3649),
    [anon_sym_u8_DQUOTE] = ACTIONS(3649),
    [anon_sym_DQUOTE] = ACTIONS(3649),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3651),
    [anon_sym_R_DQUOTE] = ACTIONS(3653),
    [anon_sym_LR_DQUOTE] = ACTIONS(3653),
    [anon_sym_uR_DQUOTE] = ACTIONS(3653),
    [anon_sym_UR_DQUOTE] = ACTIONS(3653),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3653),
    [anon_sym_co_await] = ACTIONS(3655),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1730] = {
    [sym_expression] = STATE(2712),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3061),
    [sym_concatenated_string] = STATE(3059),
    [sym_string_literal] = STATE(2449),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2444),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4682),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3521),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3517),
    [anon_sym_compl] = ACTIONS(3517),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_sizeof] = ACTIONS(3527),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3537),
    [anon_sym_L_SQUOTE] = ACTIONS(3539),
    [anon_sym_u_SQUOTE] = ACTIONS(3539),
    [anon_sym_U_SQUOTE] = ACTIONS(3539),
    [anon_sym_u8_SQUOTE] = ACTIONS(3539),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3547),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [anon_sym_co_await] = ACTIONS(3551),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1731] = {
    [sym_expression] = STATE(4206),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_LPAREN2] = ACTIONS(4662),
    [anon_sym_BANG] = ACTIONS(3948),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3946),
    [anon_sym_PLUS] = ACTIONS(3946),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_DASH_DASH] = ACTIONS(4537),
    [anon_sym_PLUS_PLUS] = ACTIONS(4537),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1732] = {
    [sym_expression] = STATE(4381),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1733] = {
    [sym_expression] = STATE(3758),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1734] = {
    [sym_expression] = STATE(3438),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4676),
    [anon_sym_BANG] = ACTIONS(3713),
    [anon_sym_TILDE] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3711),
    [anon_sym_PLUS] = ACTIONS(3711),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(3715),
    [anon_sym_LBRACK] = ACTIONS(4956),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3711),
    [anon_sym_compl] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(4562),
    [anon_sym_PLUS_PLUS] = ACTIONS(4562),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3719),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1735] = {
    [sym_expression] = STATE(2756),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3061),
    [sym_concatenated_string] = STATE(3059),
    [sym_string_literal] = STATE(2449),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2444),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4682),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3521),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3517),
    [anon_sym_compl] = ACTIONS(3517),
    [anon_sym_DASH_DASH] = ACTIONS(4560),
    [anon_sym_PLUS_PLUS] = ACTIONS(4560),
    [anon_sym_sizeof] = ACTIONS(3527),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3537),
    [anon_sym_L_SQUOTE] = ACTIONS(3539),
    [anon_sym_u_SQUOTE] = ACTIONS(3539),
    [anon_sym_U_SQUOTE] = ACTIONS(3539),
    [anon_sym_u8_SQUOTE] = ACTIONS(3539),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3547),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [anon_sym_co_await] = ACTIONS(3551),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1736] = {
    [sym_expression] = STATE(4330),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1737] = {
    [sym_expression] = STATE(4636),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1738] = {
    [sym_expression] = STATE(3759),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1739] = {
    [sym_expression] = STATE(3436),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4676),
    [anon_sym_BANG] = ACTIONS(3713),
    [anon_sym_TILDE] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3711),
    [anon_sym_PLUS] = ACTIONS(3711),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(3715),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3711),
    [anon_sym_compl] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(4562),
    [anon_sym_PLUS_PLUS] = ACTIONS(4562),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3719),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1740] = {
    [sym_expression] = STATE(4563),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1741] = {
    [sym_expression] = STATE(4593),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1742] = {
    [sym_expression] = STATE(4603),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1743] = {
    [sym_expression] = STATE(3877),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1744] = {
    [sym_expression] = STATE(4638),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1745] = {
    [sym_expression] = STATE(3435),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4676),
    [anon_sym_BANG] = ACTIONS(3713),
    [anon_sym_TILDE] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3711),
    [anon_sym_PLUS] = ACTIONS(3711),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(3715),
    [anon_sym_LBRACK] = ACTIONS(4958),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3711),
    [anon_sym_compl] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(4562),
    [anon_sym_PLUS_PLUS] = ACTIONS(4562),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3719),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1746] = {
    [sym_expression] = STATE(3765),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1747] = {
    [sym_expression] = STATE(3774),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1748] = {
    [sym_expression] = STATE(3778),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1749] = {
    [sym_expression] = STATE(4361),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1750] = {
    [sym_expression] = STATE(4360),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACK] = ACTIONS(4960),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1751] = {
    [sym_expression] = STATE(4698),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1752] = {
    [sym_expression] = STATE(4659),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1753] = {
    [sym_expression] = STATE(3461),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4676),
    [anon_sym_BANG] = ACTIONS(3713),
    [anon_sym_TILDE] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3711),
    [anon_sym_PLUS] = ACTIONS(3711),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(3715),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3711),
    [anon_sym_compl] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(4562),
    [anon_sym_PLUS_PLUS] = ACTIONS(4562),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3719),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1754] = {
    [sym_expression] = STATE(3357),
    [sym__string] = STATE(3729),
    [sym_conditional_expression] = STATE(3729),
    [sym_assignment_expression] = STATE(3729),
    [sym_pointer_expression] = STATE(3736),
    [sym_unary_expression] = STATE(3729),
    [sym_binary_expression] = STATE(3729),
    [sym_update_expression] = STATE(3729),
    [sym_cast_expression] = STATE(3729),
    [sym_sizeof_expression] = STATE(3729),
    [sym_alignof_expression] = STATE(3729),
    [sym_offsetof_expression] = STATE(3729),
    [sym_generic_expression] = STATE(3729),
    [sym_subscript_expression] = STATE(3736),
    [sym_call_expression] = STATE(3736),
    [sym_gnu_asm_expression] = STATE(3729),
    [sym_field_expression] = STATE(3736),
    [sym_compound_literal_expression] = STATE(3729),
    [sym_parenthesized_expression] = STATE(3736),
    [sym_char_literal] = STATE(3602),
    [sym_concatenated_string] = STATE(3610),
    [sym_string_literal] = STATE(2698),
    [sym_null] = STATE(3729),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7745),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3729),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(3729),
    [sym_new_expression] = STATE(3729),
    [sym_delete_expression] = STATE(3729),
    [sym_requires_clause] = STATE(3729),
    [sym_requires_expression] = STATE(3729),
    [sym_lambda_expression] = STATE(3729),
    [sym_lambda_capture_specifier] = STATE(5813),
    [sym_fold_expression] = STATE(3729),
    [sym_parameter_pack_expansion] = STATE(3729),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3736),
    [sym_qualified_type_identifier] = STATE(7745),
    [sym_user_defined_literal] = STATE(3736),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_LPAREN2] = ACTIONS(4656),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3673),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3669),
    [anon_sym_compl] = ACTIONS(3669),
    [anon_sym_DASH_DASH] = ACTIONS(4558),
    [anon_sym_PLUS_PLUS] = ACTIONS(4558),
    [anon_sym_sizeof] = ACTIONS(3679),
    [anon_sym___alignof__] = ACTIONS(3681),
    [anon_sym___alignof] = ACTIONS(3681),
    [anon_sym__alignof] = ACTIONS(3681),
    [anon_sym_alignof] = ACTIONS(3681),
    [anon_sym__Alignof] = ACTIONS(3681),
    [anon_sym_offsetof] = ACTIONS(3683),
    [anon_sym__Generic] = ACTIONS(3685),
    [anon_sym_asm] = ACTIONS(3687),
    [anon_sym___asm__] = ACTIONS(3687),
    [sym_number_literal] = ACTIONS(3689),
    [anon_sym_L_SQUOTE] = ACTIONS(3691),
    [anon_sym_u_SQUOTE] = ACTIONS(3691),
    [anon_sym_U_SQUOTE] = ACTIONS(3691),
    [anon_sym_u8_SQUOTE] = ACTIONS(3691),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [anon_sym_L_DQUOTE] = ACTIONS(3693),
    [anon_sym_u_DQUOTE] = ACTIONS(3693),
    [anon_sym_U_DQUOTE] = ACTIONS(3693),
    [anon_sym_u8_DQUOTE] = ACTIONS(3693),
    [anon_sym_DQUOTE] = ACTIONS(3693),
    [sym_true] = ACTIONS(3695),
    [sym_false] = ACTIONS(3695),
    [anon_sym_NULL] = ACTIONS(3697),
    [anon_sym_nullptr] = ACTIONS(3697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3699),
    [anon_sym_R_DQUOTE] = ACTIONS(3701),
    [anon_sym_LR_DQUOTE] = ACTIONS(3701),
    [anon_sym_uR_DQUOTE] = ACTIONS(3701),
    [anon_sym_UR_DQUOTE] = ACTIONS(3701),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3701),
    [anon_sym_co_await] = ACTIONS(3703),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_requires] = ACTIONS(3707),
    [sym_this] = ACTIONS(3695),
  },
  [1755] = {
    [sym_expression] = STATE(4385),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1756] = {
    [sym_expression] = STATE(4641),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1757] = {
    [sym_expression] = STATE(3783),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1758] = {
    [sym_expression] = STATE(3785),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1759] = {
    [sym_expression] = STATE(3799),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1760] = {
    [sym_expression] = STATE(3789),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1761] = {
    [sym_expression] = STATE(4491),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1762] = {
    [sym_expression] = STATE(3780),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1763] = {
    [sym_expression] = STATE(4565),
    [sym__string] = STATE(4820),
    [sym_conditional_expression] = STATE(4820),
    [sym_assignment_expression] = STATE(4820),
    [sym_pointer_expression] = STATE(3667),
    [sym_unary_expression] = STATE(4820),
    [sym_binary_expression] = STATE(4820),
    [sym_update_expression] = STATE(4820),
    [sym_cast_expression] = STATE(4820),
    [sym_sizeof_expression] = STATE(4820),
    [sym_alignof_expression] = STATE(4820),
    [sym_offsetof_expression] = STATE(4820),
    [sym_generic_expression] = STATE(4820),
    [sym_subscript_expression] = STATE(3667),
    [sym_call_expression] = STATE(3667),
    [sym_gnu_asm_expression] = STATE(4820),
    [sym_field_expression] = STATE(3667),
    [sym_compound_literal_expression] = STATE(4820),
    [sym_parenthesized_expression] = STATE(3667),
    [sym_char_literal] = STATE(4695),
    [sym_concatenated_string] = STATE(4696),
    [sym_string_literal] = STATE(3807),
    [sym_null] = STATE(4820),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7712),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4820),
    [sym_raw_string_literal] = STATE(3812),
    [sym_co_await_expression] = STATE(4820),
    [sym_new_expression] = STATE(4820),
    [sym_delete_expression] = STATE(4820),
    [sym_requires_clause] = STATE(4820),
    [sym_requires_expression] = STATE(4820),
    [sym_lambda_expression] = STATE(4820),
    [sym_lambda_capture_specifier] = STATE(5812),
    [sym_fold_expression] = STATE(4820),
    [sym_parameter_pack_expansion] = STATE(4820),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3667),
    [sym_qualified_type_identifier] = STATE(7712),
    [sym_user_defined_literal] = STATE(3667),
    [sym_identifier] = ACTIONS(4017),
    [anon_sym_LPAREN2] = ACTIONS(3752),
    [anon_sym_BANG] = ACTIONS(3754),
    [anon_sym_TILDE] = ACTIONS(3754),
    [anon_sym_DASH] = ACTIONS(3756),
    [anon_sym_PLUS] = ACTIONS(3756),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3760),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(4021),
    [anon_sym_not] = ACTIONS(3756),
    [anon_sym_compl] = ACTIONS(3756),
    [anon_sym_DASH_DASH] = ACTIONS(3774),
    [anon_sym_PLUS_PLUS] = ACTIONS(3774),
    [anon_sym_sizeof] = ACTIONS(3776),
    [anon_sym___alignof__] = ACTIONS(3778),
    [anon_sym___alignof] = ACTIONS(3778),
    [anon_sym__alignof] = ACTIONS(3778),
    [anon_sym_alignof] = ACTIONS(3778),
    [anon_sym__Alignof] = ACTIONS(3778),
    [anon_sym_offsetof] = ACTIONS(3780),
    [anon_sym__Generic] = ACTIONS(3782),
    [anon_sym_asm] = ACTIONS(3784),
    [anon_sym___asm__] = ACTIONS(3784),
    [sym_number_literal] = ACTIONS(3786),
    [anon_sym_L_SQUOTE] = ACTIONS(3788),
    [anon_sym_u_SQUOTE] = ACTIONS(3788),
    [anon_sym_U_SQUOTE] = ACTIONS(3788),
    [anon_sym_u8_SQUOTE] = ACTIONS(3788),
    [anon_sym_SQUOTE] = ACTIONS(3788),
    [anon_sym_L_DQUOTE] = ACTIONS(3790),
    [anon_sym_u_DQUOTE] = ACTIONS(3790),
    [anon_sym_U_DQUOTE] = ACTIONS(3790),
    [anon_sym_u8_DQUOTE] = ACTIONS(3790),
    [anon_sym_DQUOTE] = ACTIONS(3790),
    [sym_true] = ACTIONS(3792),
    [sym_false] = ACTIONS(3792),
    [anon_sym_NULL] = ACTIONS(3794),
    [anon_sym_nullptr] = ACTIONS(3794),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3804),
    [anon_sym_R_DQUOTE] = ACTIONS(3806),
    [anon_sym_LR_DQUOTE] = ACTIONS(3806),
    [anon_sym_uR_DQUOTE] = ACTIONS(3806),
    [anon_sym_UR_DQUOTE] = ACTIONS(3806),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3806),
    [anon_sym_co_await] = ACTIONS(3808),
    [anon_sym_new] = ACTIONS(3810),
    [anon_sym_requires] = ACTIONS(3812),
    [sym_this] = ACTIONS(3792),
  },
  [1764] = {
    [sym_expression] = STATE(4552),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(4962),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1765] = {
    [sym_expression] = STATE(3460),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4676),
    [anon_sym_BANG] = ACTIONS(3713),
    [anon_sym_TILDE] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3711),
    [anon_sym_PLUS] = ACTIONS(3711),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(3715),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3711),
    [anon_sym_compl] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(4562),
    [anon_sym_PLUS_PLUS] = ACTIONS(4562),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3719),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1766] = {
    [sym_expression] = STATE(3902),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1767] = {
    [sym_expression] = STATE(4175),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3094),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3094),
    [sym_call_expression] = STATE(3094),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3094),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3094),
    [sym_char_literal] = STATE(4209),
    [sym_concatenated_string] = STATE(4224),
    [sym_string_literal] = STATE(3165),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3155),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3094),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3094),
    [sym_identifier] = ACTIONS(4535),
    [anon_sym_LPAREN2] = ACTIONS(4662),
    [anon_sym_BANG] = ACTIONS(3948),
    [anon_sym_TILDE] = ACTIONS(3948),
    [anon_sym_DASH] = ACTIONS(3946),
    [anon_sym_PLUS] = ACTIONS(3946),
    [anon_sym_STAR] = ACTIONS(4664),
    [anon_sym_AMP] = ACTIONS(4664),
    [anon_sym_COLON_COLON] = ACTIONS(3950),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3946),
    [anon_sym_compl] = ACTIONS(3946),
    [anon_sym_DASH_DASH] = ACTIONS(4537),
    [anon_sym_PLUS_PLUS] = ACTIONS(4537),
    [anon_sym_sizeof] = ACTIONS(3954),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3956),
    [anon_sym_L_SQUOTE] = ACTIONS(3958),
    [anon_sym_u_SQUOTE] = ACTIONS(3958),
    [anon_sym_U_SQUOTE] = ACTIONS(3958),
    [anon_sym_u8_SQUOTE] = ACTIONS(3958),
    [anon_sym_SQUOTE] = ACTIONS(3958),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3960),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
    [anon_sym_co_await] = ACTIONS(3962),
    [anon_sym_new] = ACTIONS(3964),
    [anon_sym_requires] = ACTIONS(3966),
    [sym_this] = ACTIONS(221),
  },
  [1768] = {
    [sym_expression] = STATE(3300),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1769] = {
    [sym_expression] = STATE(3459),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4676),
    [anon_sym_BANG] = ACTIONS(3713),
    [anon_sym_TILDE] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3711),
    [anon_sym_PLUS] = ACTIONS(3711),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(3715),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3711),
    [anon_sym_compl] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(4562),
    [anon_sym_PLUS_PLUS] = ACTIONS(4562),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3719),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1770] = {
    [sym_expression] = STATE(3877),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(4964),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1771] = {
    [sym_expression] = STATE(3458),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4676),
    [anon_sym_BANG] = ACTIONS(3713),
    [anon_sym_TILDE] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3711),
    [anon_sym_PLUS] = ACTIONS(3711),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(3715),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3711),
    [anon_sym_compl] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(4562),
    [anon_sym_PLUS_PLUS] = ACTIONS(4562),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3719),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1772] = {
    [sym_expression] = STATE(4415),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3509),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3509),
    [sym_call_expression] = STATE(3509),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3509),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3509),
    [sym_char_literal] = STATE(4523),
    [sym_concatenated_string] = STATE(4521),
    [sym_string_literal] = STATE(3695),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3698),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3509),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3509),
    [sym_identifier] = ACTIONS(3979),
    [anon_sym_LPAREN2] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3981),
    [anon_sym_PLUS] = ACTIONS(3981),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3985),
    [anon_sym_LBRACK] = ACTIONS(4813),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(3981),
    [anon_sym_compl] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_sizeof] = ACTIONS(3987),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(3989),
    [anon_sym_L_SQUOTE] = ACTIONS(3991),
    [anon_sym_u_SQUOTE] = ACTIONS(3991),
    [anon_sym_U_SQUOTE] = ACTIONS(3991),
    [anon_sym_u8_SQUOTE] = ACTIONS(3991),
    [anon_sym_SQUOTE] = ACTIONS(3991),
    [anon_sym_L_DQUOTE] = ACTIONS(3993),
    [anon_sym_u_DQUOTE] = ACTIONS(3993),
    [anon_sym_U_DQUOTE] = ACTIONS(3993),
    [anon_sym_u8_DQUOTE] = ACTIONS(3993),
    [anon_sym_DQUOTE] = ACTIONS(3993),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3995),
    [anon_sym_R_DQUOTE] = ACTIONS(3997),
    [anon_sym_LR_DQUOTE] = ACTIONS(3997),
    [anon_sym_uR_DQUOTE] = ACTIONS(3997),
    [anon_sym_UR_DQUOTE] = ACTIONS(3997),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3997),
    [anon_sym_co_await] = ACTIONS(3999),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1773] = {
    [sym_expression] = STATE(3291),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3360),
    [sym_concatenated_string] = STATE(3359),
    [sym_string_literal] = STATE(2634),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2625),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3635),
    [anon_sym_LPAREN2] = ACTIONS(4658),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3641),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3637),
    [anon_sym_compl] = ACTIONS(3637),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_sizeof] = ACTIONS(3643),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3645),
    [anon_sym_L_SQUOTE] = ACTIONS(3647),
    [anon_sym_u_SQUOTE] = ACTIONS(3647),
    [anon_sym_U_SQUOTE] = ACTIONS(3647),
    [anon_sym_u8_SQUOTE] = ACTIONS(3647),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [anon_sym_L_DQUOTE] = ACTIONS(3649),
    [anon_sym_u_DQUOTE] = ACTIONS(3649),
    [anon_sym_U_DQUOTE] = ACTIONS(3649),
    [anon_sym_u8_DQUOTE] = ACTIONS(3649),
    [anon_sym_DQUOTE] = ACTIONS(3649),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3651),
    [anon_sym_R_DQUOTE] = ACTIONS(3653),
    [anon_sym_LR_DQUOTE] = ACTIONS(3653),
    [anon_sym_uR_DQUOTE] = ACTIONS(3653),
    [anon_sym_UR_DQUOTE] = ACTIONS(3653),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3653),
    [anon_sym_co_await] = ACTIONS(3655),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1774] = {
    [sym_expression] = STATE(4308),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1775] = {
    [sym_expression] = STATE(3349),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1776] = {
    [sym_expression] = STATE(3318),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3360),
    [sym_concatenated_string] = STATE(3359),
    [sym_string_literal] = STATE(2634),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2625),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3635),
    [anon_sym_LPAREN2] = ACTIONS(4658),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_AMP] = ACTIONS(4468),
    [anon_sym_COLON_COLON] = ACTIONS(3641),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3637),
    [anon_sym_compl] = ACTIONS(3637),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_sizeof] = ACTIONS(3643),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3645),
    [anon_sym_L_SQUOTE] = ACTIONS(3647),
    [anon_sym_u_SQUOTE] = ACTIONS(3647),
    [anon_sym_U_SQUOTE] = ACTIONS(3647),
    [anon_sym_u8_SQUOTE] = ACTIONS(3647),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [anon_sym_L_DQUOTE] = ACTIONS(3649),
    [anon_sym_u_DQUOTE] = ACTIONS(3649),
    [anon_sym_U_DQUOTE] = ACTIONS(3649),
    [anon_sym_u8_DQUOTE] = ACTIONS(3649),
    [anon_sym_DQUOTE] = ACTIONS(3649),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3651),
    [anon_sym_R_DQUOTE] = ACTIONS(3653),
    [anon_sym_LR_DQUOTE] = ACTIONS(3653),
    [anon_sym_uR_DQUOTE] = ACTIONS(3653),
    [anon_sym_UR_DQUOTE] = ACTIONS(3653),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3653),
    [anon_sym_co_await] = ACTIONS(3655),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1777] = {
    [sym_expression] = STATE(3455),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4676),
    [anon_sym_BANG] = ACTIONS(3713),
    [anon_sym_TILDE] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3711),
    [anon_sym_PLUS] = ACTIONS(3711),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(3715),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3711),
    [anon_sym_compl] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(4562),
    [anon_sym_PLUS_PLUS] = ACTIONS(4562),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3719),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1778] = {
    [sym_expression] = STATE(4711),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1779] = {
    [sym_expression] = STATE(3386),
    [sym__string] = STATE(3729),
    [sym_conditional_expression] = STATE(3729),
    [sym_assignment_expression] = STATE(3729),
    [sym_pointer_expression] = STATE(3736),
    [sym_unary_expression] = STATE(3729),
    [sym_binary_expression] = STATE(3729),
    [sym_update_expression] = STATE(3729),
    [sym_cast_expression] = STATE(3729),
    [sym_sizeof_expression] = STATE(3729),
    [sym_alignof_expression] = STATE(3729),
    [sym_offsetof_expression] = STATE(3729),
    [sym_generic_expression] = STATE(3729),
    [sym_subscript_expression] = STATE(3736),
    [sym_call_expression] = STATE(3736),
    [sym_gnu_asm_expression] = STATE(3729),
    [sym_field_expression] = STATE(3736),
    [sym_compound_literal_expression] = STATE(3729),
    [sym_parenthesized_expression] = STATE(3736),
    [sym_char_literal] = STATE(3602),
    [sym_concatenated_string] = STATE(3610),
    [sym_string_literal] = STATE(2698),
    [sym_null] = STATE(3729),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7745),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3729),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(3729),
    [sym_new_expression] = STATE(3729),
    [sym_delete_expression] = STATE(3729),
    [sym_requires_clause] = STATE(3729),
    [sym_requires_expression] = STATE(3729),
    [sym_lambda_expression] = STATE(3729),
    [sym_lambda_capture_specifier] = STATE(5813),
    [sym_fold_expression] = STATE(3729),
    [sym_parameter_pack_expansion] = STATE(3729),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3736),
    [sym_qualified_type_identifier] = STATE(7745),
    [sym_user_defined_literal] = STATE(3736),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_LPAREN2] = ACTIONS(4656),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3673),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3669),
    [anon_sym_compl] = ACTIONS(3669),
    [anon_sym_DASH_DASH] = ACTIONS(4558),
    [anon_sym_PLUS_PLUS] = ACTIONS(4558),
    [anon_sym_sizeof] = ACTIONS(3679),
    [anon_sym___alignof__] = ACTIONS(3681),
    [anon_sym___alignof] = ACTIONS(3681),
    [anon_sym__alignof] = ACTIONS(3681),
    [anon_sym_alignof] = ACTIONS(3681),
    [anon_sym__Alignof] = ACTIONS(3681),
    [anon_sym_offsetof] = ACTIONS(3683),
    [anon_sym__Generic] = ACTIONS(3685),
    [anon_sym_asm] = ACTIONS(3687),
    [anon_sym___asm__] = ACTIONS(3687),
    [sym_number_literal] = ACTIONS(3689),
    [anon_sym_L_SQUOTE] = ACTIONS(3691),
    [anon_sym_u_SQUOTE] = ACTIONS(3691),
    [anon_sym_U_SQUOTE] = ACTIONS(3691),
    [anon_sym_u8_SQUOTE] = ACTIONS(3691),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [anon_sym_L_DQUOTE] = ACTIONS(3693),
    [anon_sym_u_DQUOTE] = ACTIONS(3693),
    [anon_sym_U_DQUOTE] = ACTIONS(3693),
    [anon_sym_u8_DQUOTE] = ACTIONS(3693),
    [anon_sym_DQUOTE] = ACTIONS(3693),
    [sym_true] = ACTIONS(3695),
    [sym_false] = ACTIONS(3695),
    [anon_sym_NULL] = ACTIONS(3697),
    [anon_sym_nullptr] = ACTIONS(3697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3699),
    [anon_sym_R_DQUOTE] = ACTIONS(3701),
    [anon_sym_LR_DQUOTE] = ACTIONS(3701),
    [anon_sym_uR_DQUOTE] = ACTIONS(3701),
    [anon_sym_UR_DQUOTE] = ACTIONS(3701),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3701),
    [anon_sym_co_await] = ACTIONS(3703),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_requires] = ACTIONS(3707),
    [sym_this] = ACTIONS(3695),
  },
  [1780] = {
    [sym_expression] = STATE(4315),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1781] = {
    [sym_expression] = STATE(4475),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1782] = {
    [sym_expression] = STATE(4628),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1783] = {
    [sym_expression] = STATE(4648),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1784] = {
    [sym_expression] = STATE(3260),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(4966),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1785] = {
    [sym_expression] = STATE(3260),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1786] = {
    [sym_expression] = STATE(3775),
    [sym__string] = STATE(3849),
    [sym_conditional_expression] = STATE(3849),
    [sym_assignment_expression] = STATE(3849),
    [sym_pointer_expression] = STATE(3537),
    [sym_unary_expression] = STATE(3849),
    [sym_binary_expression] = STATE(3849),
    [sym_update_expression] = STATE(3849),
    [sym_cast_expression] = STATE(3849),
    [sym_sizeof_expression] = STATE(3849),
    [sym_alignof_expression] = STATE(3849),
    [sym_offsetof_expression] = STATE(3849),
    [sym_generic_expression] = STATE(3849),
    [sym_subscript_expression] = STATE(3537),
    [sym_call_expression] = STATE(3537),
    [sym_gnu_asm_expression] = STATE(3849),
    [sym_field_expression] = STATE(3537),
    [sym_compound_literal_expression] = STATE(3849),
    [sym_parenthesized_expression] = STATE(3537),
    [sym_char_literal] = STATE(3804),
    [sym_concatenated_string] = STATE(3802),
    [sym_string_literal] = STATE(2787),
    [sym_null] = STATE(3849),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7818),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3849),
    [sym_raw_string_literal] = STATE(2772),
    [sym_co_await_expression] = STATE(3849),
    [sym_new_expression] = STATE(3849),
    [sym_delete_expression] = STATE(3849),
    [sym_requires_clause] = STATE(3849),
    [sym_requires_expression] = STATE(3849),
    [sym_lambda_expression] = STATE(3849),
    [sym_lambda_capture_specifier] = STATE(5825),
    [sym_fold_expression] = STATE(3849),
    [sym_parameter_pack_expansion] = STATE(3849),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3537),
    [sym_qualified_type_identifier] = STATE(7818),
    [sym_user_defined_literal] = STATE(3537),
    [sym_identifier] = ACTIONS(3739),
    [anon_sym_LPAREN2] = ACTIONS(1819),
    [anon_sym_BANG] = ACTIONS(1821),
    [anon_sym_TILDE] = ACTIONS(1821),
    [anon_sym_DASH] = ACTIONS(1823),
    [anon_sym_PLUS] = ACTIONS(1823),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(1829),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3743),
    [anon_sym_not] = ACTIONS(1823),
    [anon_sym_compl] = ACTIONS(1823),
    [anon_sym_DASH_DASH] = ACTIONS(1841),
    [anon_sym_PLUS_PLUS] = ACTIONS(1841),
    [anon_sym_sizeof] = ACTIONS(1843),
    [anon_sym___alignof__] = ACTIONS(1845),
    [anon_sym___alignof] = ACTIONS(1845),
    [anon_sym__alignof] = ACTIONS(1845),
    [anon_sym_alignof] = ACTIONS(1845),
    [anon_sym__Alignof] = ACTIONS(1845),
    [anon_sym_offsetof] = ACTIONS(1847),
    [anon_sym__Generic] = ACTIONS(1849),
    [anon_sym_asm] = ACTIONS(1851),
    [anon_sym___asm__] = ACTIONS(1851),
    [sym_number_literal] = ACTIONS(1853),
    [anon_sym_L_SQUOTE] = ACTIONS(1855),
    [anon_sym_u_SQUOTE] = ACTIONS(1855),
    [anon_sym_U_SQUOTE] = ACTIONS(1855),
    [anon_sym_u8_SQUOTE] = ACTIONS(1855),
    [anon_sym_SQUOTE] = ACTIONS(1855),
    [anon_sym_L_DQUOTE] = ACTIONS(1857),
    [anon_sym_u_DQUOTE] = ACTIONS(1857),
    [anon_sym_U_DQUOTE] = ACTIONS(1857),
    [anon_sym_u8_DQUOTE] = ACTIONS(1857),
    [anon_sym_DQUOTE] = ACTIONS(1857),
    [sym_true] = ACTIONS(1859),
    [sym_false] = ACTIONS(1859),
    [anon_sym_NULL] = ACTIONS(1861),
    [anon_sym_nullptr] = ACTIONS(1861),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(1865),
    [anon_sym_R_DQUOTE] = ACTIONS(1867),
    [anon_sym_LR_DQUOTE] = ACTIONS(1867),
    [anon_sym_uR_DQUOTE] = ACTIONS(1867),
    [anon_sym_UR_DQUOTE] = ACTIONS(1867),
    [anon_sym_u8R_DQUOTE] = ACTIONS(1867),
    [anon_sym_co_await] = ACTIONS(1869),
    [anon_sym_new] = ACTIONS(1871),
    [anon_sym_requires] = ACTIONS(1873),
    [sym_this] = ACTIONS(1859),
  },
  [1787] = {
    [sym_expression] = STATE(4430),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1788] = {
    [sym_expression] = STATE(4519),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1789] = {
    [sym_expression] = STATE(3453),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4676),
    [anon_sym_BANG] = ACTIONS(3713),
    [anon_sym_TILDE] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3711),
    [anon_sym_PLUS] = ACTIONS(3711),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(3715),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3711),
    [anon_sym_compl] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(4562),
    [anon_sym_PLUS_PLUS] = ACTIONS(4562),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3719),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1790] = {
    [sym_expression] = STATE(3413),
    [sym__string] = STATE(3729),
    [sym_conditional_expression] = STATE(3729),
    [sym_assignment_expression] = STATE(3729),
    [sym_pointer_expression] = STATE(3736),
    [sym_unary_expression] = STATE(3729),
    [sym_binary_expression] = STATE(3729),
    [sym_update_expression] = STATE(3729),
    [sym_cast_expression] = STATE(3729),
    [sym_sizeof_expression] = STATE(3729),
    [sym_alignof_expression] = STATE(3729),
    [sym_offsetof_expression] = STATE(3729),
    [sym_generic_expression] = STATE(3729),
    [sym_subscript_expression] = STATE(3736),
    [sym_call_expression] = STATE(3736),
    [sym_gnu_asm_expression] = STATE(3729),
    [sym_field_expression] = STATE(3736),
    [sym_compound_literal_expression] = STATE(3729),
    [sym_parenthesized_expression] = STATE(3736),
    [sym_char_literal] = STATE(3602),
    [sym_concatenated_string] = STATE(3610),
    [sym_string_literal] = STATE(2698),
    [sym_null] = STATE(3729),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7745),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3729),
    [sym_raw_string_literal] = STATE(2699),
    [sym_co_await_expression] = STATE(3729),
    [sym_new_expression] = STATE(3729),
    [sym_delete_expression] = STATE(3729),
    [sym_requires_clause] = STATE(3729),
    [sym_requires_expression] = STATE(3729),
    [sym_lambda_expression] = STATE(3729),
    [sym_lambda_capture_specifier] = STATE(5813),
    [sym_fold_expression] = STATE(3729),
    [sym_parameter_pack_expansion] = STATE(3729),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5623),
    [sym_qualified_identifier] = STATE(3736),
    [sym_qualified_type_identifier] = STATE(7745),
    [sym_user_defined_literal] = STATE(3736),
    [sym_identifier] = ACTIONS(3667),
    [anon_sym_LPAREN2] = ACTIONS(4656),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(3758),
    [anon_sym_AMP] = ACTIONS(3758),
    [anon_sym_COLON_COLON] = ACTIONS(3673),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3677),
    [anon_sym_not] = ACTIONS(3669),
    [anon_sym_compl] = ACTIONS(3669),
    [anon_sym_DASH_DASH] = ACTIONS(4558),
    [anon_sym_PLUS_PLUS] = ACTIONS(4558),
    [anon_sym_sizeof] = ACTIONS(3679),
    [anon_sym___alignof__] = ACTIONS(3681),
    [anon_sym___alignof] = ACTIONS(3681),
    [anon_sym__alignof] = ACTIONS(3681),
    [anon_sym_alignof] = ACTIONS(3681),
    [anon_sym__Alignof] = ACTIONS(3681),
    [anon_sym_offsetof] = ACTIONS(3683),
    [anon_sym__Generic] = ACTIONS(3685),
    [anon_sym_asm] = ACTIONS(3687),
    [anon_sym___asm__] = ACTIONS(3687),
    [sym_number_literal] = ACTIONS(3689),
    [anon_sym_L_SQUOTE] = ACTIONS(3691),
    [anon_sym_u_SQUOTE] = ACTIONS(3691),
    [anon_sym_U_SQUOTE] = ACTIONS(3691),
    [anon_sym_u8_SQUOTE] = ACTIONS(3691),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [anon_sym_L_DQUOTE] = ACTIONS(3693),
    [anon_sym_u_DQUOTE] = ACTIONS(3693),
    [anon_sym_U_DQUOTE] = ACTIONS(3693),
    [anon_sym_u8_DQUOTE] = ACTIONS(3693),
    [anon_sym_DQUOTE] = ACTIONS(3693),
    [sym_true] = ACTIONS(3695),
    [sym_false] = ACTIONS(3695),
    [anon_sym_NULL] = ACTIONS(3697),
    [anon_sym_nullptr] = ACTIONS(3697),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3699),
    [anon_sym_R_DQUOTE] = ACTIONS(3701),
    [anon_sym_LR_DQUOTE] = ACTIONS(3701),
    [anon_sym_uR_DQUOTE] = ACTIONS(3701),
    [anon_sym_UR_DQUOTE] = ACTIONS(3701),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3701),
    [anon_sym_co_await] = ACTIONS(3703),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_requires] = ACTIONS(3707),
    [sym_this] = ACTIONS(3695),
  },
  [1791] = {
    [sym_expression] = STATE(4686),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1792] = {
    [sym_expression] = STATE(4654),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1793] = {
    [sym_expression] = STATE(4713),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1794] = {
    [sym_expression] = STATE(4622),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1795] = {
    [sym_expression] = STATE(4667),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1796] = {
    [sym_expression] = STATE(3422),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4676),
    [anon_sym_BANG] = ACTIONS(3713),
    [anon_sym_TILDE] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3711),
    [anon_sym_PLUS] = ACTIONS(3711),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(3715),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3711),
    [anon_sym_compl] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(4562),
    [anon_sym_PLUS_PLUS] = ACTIONS(4562),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3719),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1797] = {
    [sym_expression] = STATE(3257),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(4968),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1798] = {
    [sym_expression] = STATE(3327),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1799] = {
    [sym_expression] = STATE(4717),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1800] = {
    [sym_expression] = STATE(4363),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1801] = {
    [sym_expression] = STATE(4434),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3795),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3795),
    [sym_call_expression] = STATE(3795),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3795),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3795),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3795),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3795),
    [sym_identifier] = ACTIONS(4023),
    [anon_sym_LPAREN2] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_DASH] = ACTIONS(4025),
    [anon_sym_PLUS] = ACTIONS(4025),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4025),
    [anon_sym_compl] = ACTIONS(4025),
    [anon_sym_DASH_DASH] = ACTIONS(4043),
    [anon_sym_PLUS_PLUS] = ACTIONS(4043),
    [anon_sym_sizeof] = ACTIONS(4031),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4033),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4035),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1802] = {
    [sym_expression] = STATE(3320),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(4970),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1803] = {
    [sym_expression] = STATE(3452),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4676),
    [anon_sym_BANG] = ACTIONS(3713),
    [anon_sym_TILDE] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3711),
    [anon_sym_PLUS] = ACTIONS(3711),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(3715),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3711),
    [anon_sym_compl] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(4562),
    [anon_sym_PLUS_PLUS] = ACTIONS(4562),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3719),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1804] = {
    [sym_expression] = STATE(3451),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4676),
    [anon_sym_BANG] = ACTIONS(3713),
    [anon_sym_TILDE] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3711),
    [anon_sym_PLUS] = ACTIONS(3711),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(3715),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3711),
    [anon_sym_compl] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(4562),
    [anon_sym_PLUS_PLUS] = ACTIONS(4562),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3719),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1805] = {
    [sym_expression] = STATE(3450),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4676),
    [anon_sym_BANG] = ACTIONS(3713),
    [anon_sym_TILDE] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3711),
    [anon_sym_PLUS] = ACTIONS(3711),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(3715),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3711),
    [anon_sym_compl] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(4562),
    [anon_sym_PLUS_PLUS] = ACTIONS(4562),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3719),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1806] = {
    [sym_expression] = STATE(4605),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3742),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3742),
    [sym_call_expression] = STATE(3742),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3742),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3742),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3742),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3742),
    [sym_identifier] = ACTIONS(4001),
    [anon_sym_LPAREN2] = ACTIONS(4643),
    [anon_sym_BANG] = ACTIONS(4005),
    [anon_sym_TILDE] = ACTIONS(4005),
    [anon_sym_DASH] = ACTIONS(4003),
    [anon_sym_PLUS] = ACTIONS(4003),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(4007),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(4003),
    [anon_sym_compl] = ACTIONS(4003),
    [anon_sym_DASH_DASH] = ACTIONS(4596),
    [anon_sym_PLUS_PLUS] = ACTIONS(4596),
    [anon_sym_sizeof] = ACTIONS(4009),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(4011),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(4013),
    [anon_sym_new] = ACTIONS(4015),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1807] = {
    [sym_expression] = STATE(4589),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1808] = {
    [sym_expression] = STATE(2710),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1809] = {
    [sym_expression] = STATE(4726),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1810] = {
    [sym_expression] = STATE(3446),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4676),
    [anon_sym_BANG] = ACTIONS(3713),
    [anon_sym_TILDE] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3711),
    [anon_sym_PLUS] = ACTIONS(3711),
    [anon_sym_STAR] = ACTIONS(4645),
    [anon_sym_AMP] = ACTIONS(4645),
    [anon_sym_COLON_COLON] = ACTIONS(3715),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3711),
    [anon_sym_compl] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(4562),
    [anon_sym_PLUS_PLUS] = ACTIONS(4562),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3719),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1811] = {
    [sym_expression] = STATE(4632),
    [sym__string] = STATE(4019),
    [sym_conditional_expression] = STATE(4019),
    [sym_assignment_expression] = STATE(4019),
    [sym_pointer_expression] = STATE(3392),
    [sym_unary_expression] = STATE(4019),
    [sym_binary_expression] = STATE(4019),
    [sym_update_expression] = STATE(4019),
    [sym_cast_expression] = STATE(4019),
    [sym_sizeof_expression] = STATE(4019),
    [sym_alignof_expression] = STATE(4019),
    [sym_offsetof_expression] = STATE(4019),
    [sym_generic_expression] = STATE(4019),
    [sym_subscript_expression] = STATE(3392),
    [sym_call_expression] = STATE(3392),
    [sym_gnu_asm_expression] = STATE(4019),
    [sym_field_expression] = STATE(3392),
    [sym_compound_literal_expression] = STATE(4019),
    [sym_parenthesized_expression] = STATE(3392),
    [sym_char_literal] = STATE(4240),
    [sym_concatenated_string] = STATE(4250),
    [sym_string_literal] = STATE(3325),
    [sym_null] = STATE(4019),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7510),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(4019),
    [sym_raw_string_literal] = STATE(3237),
    [sym_co_await_expression] = STATE(4019),
    [sym_new_expression] = STATE(4019),
    [sym_delete_expression] = STATE(4019),
    [sym_requires_clause] = STATE(4019),
    [sym_requires_expression] = STATE(4019),
    [sym_lambda_expression] = STATE(4019),
    [sym_lambda_capture_specifier] = STATE(5823),
    [sym_fold_expression] = STATE(4019),
    [sym_parameter_pack_expansion] = STATE(4019),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(3392),
    [sym_qualified_type_identifier] = STATE(7510),
    [sym_user_defined_literal] = STATE(3392),
    [sym_identifier] = ACTIONS(2847),
    [anon_sym_LPAREN2] = ACTIONS(1252),
    [anon_sym_BANG] = ACTIONS(21),
    [anon_sym_TILDE] = ACTIONS(21),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_PLUS] = ACTIONS(25),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(43),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(2853),
    [anon_sym_not] = ACTIONS(25),
    [anon_sym_compl] = ACTIONS(25),
    [anon_sym_DASH_DASH] = ACTIONS(99),
    [anon_sym_PLUS_PLUS] = ACTIONS(99),
    [anon_sym_sizeof] = ACTIONS(101),
    [anon_sym___alignof__] = ACTIONS(103),
    [anon_sym___alignof] = ACTIONS(103),
    [anon_sym__alignof] = ACTIONS(103),
    [anon_sym_alignof] = ACTIONS(103),
    [anon_sym__Alignof] = ACTIONS(103),
    [anon_sym_offsetof] = ACTIONS(105),
    [anon_sym__Generic] = ACTIONS(107),
    [anon_sym_asm] = ACTIONS(109),
    [anon_sym___asm__] = ACTIONS(109),
    [sym_number_literal] = ACTIONS(219),
    [anon_sym_L_SQUOTE] = ACTIONS(113),
    [anon_sym_u_SQUOTE] = ACTIONS(113),
    [anon_sym_U_SQUOTE] = ACTIONS(113),
    [anon_sym_u8_SQUOTE] = ACTIONS(113),
    [anon_sym_SQUOTE] = ACTIONS(113),
    [anon_sym_L_DQUOTE] = ACTIONS(115),
    [anon_sym_u_DQUOTE] = ACTIONS(115),
    [anon_sym_U_DQUOTE] = ACTIONS(115),
    [anon_sym_u8_DQUOTE] = ACTIONS(115),
    [anon_sym_DQUOTE] = ACTIONS(115),
    [sym_true] = ACTIONS(221),
    [sym_false] = ACTIONS(221),
    [anon_sym_NULL] = ACTIONS(119),
    [anon_sym_nullptr] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(135),
    [anon_sym_R_DQUOTE] = ACTIONS(151),
    [anon_sym_LR_DQUOTE] = ACTIONS(151),
    [anon_sym_uR_DQUOTE] = ACTIONS(151),
    [anon_sym_UR_DQUOTE] = ACTIONS(151),
    [anon_sym_u8R_DQUOTE] = ACTIONS(151),
    [anon_sym_co_await] = ACTIONS(153),
    [anon_sym_new] = ACTIONS(155),
    [anon_sym_requires] = ACTIONS(157),
    [sym_this] = ACTIONS(221),
  },
  [1812] = {
    [sym_expression] = STATE(3306),
    [sym__string] = STATE(3609),
    [sym_conditional_expression] = STATE(3609),
    [sym_assignment_expression] = STATE(3609),
    [sym_pointer_expression] = STATE(3659),
    [sym_unary_expression] = STATE(3609),
    [sym_binary_expression] = STATE(3609),
    [sym_update_expression] = STATE(3609),
    [sym_cast_expression] = STATE(3609),
    [sym_sizeof_expression] = STATE(3609),
    [sym_alignof_expression] = STATE(3609),
    [sym_offsetof_expression] = STATE(3609),
    [sym_generic_expression] = STATE(3609),
    [sym_subscript_expression] = STATE(3659),
    [sym_call_expression] = STATE(3659),
    [sym_gnu_asm_expression] = STATE(3609),
    [sym_field_expression] = STATE(3659),
    [sym_compound_literal_expression] = STATE(3609),
    [sym_parenthesized_expression] = STATE(3659),
    [sym_char_literal] = STATE(3406),
    [sym_concatenated_string] = STATE(3398),
    [sym_string_literal] = STATE(2614),
    [sym_null] = STATE(3609),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7503),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(3609),
    [sym_raw_string_literal] = STATE(2664),
    [sym_co_await_expression] = STATE(3609),
    [sym_new_expression] = STATE(3609),
    [sym_delete_expression] = STATE(3609),
    [sym_requires_clause] = STATE(3609),
    [sym_requires_expression] = STATE(3609),
    [sym_lambda_expression] = STATE(3609),
    [sym_lambda_capture_specifier] = STATE(5838),
    [sym_fold_expression] = STATE(3609),
    [sym_parameter_pack_expansion] = STATE(3609),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5605),
    [sym_qualified_identifier] = STATE(3659),
    [sym_qualified_type_identifier] = STATE(7503),
    [sym_user_defined_literal] = STATE(3659),
    [sym_identifier] = ACTIONS(3625),
    [anon_sym_LPAREN2] = ACTIONS(3663),
    [anon_sym_BANG] = ACTIONS(2022),
    [anon_sym_TILDE] = ACTIONS(2022),
    [anon_sym_DASH] = ACTIONS(2026),
    [anon_sym_PLUS] = ACTIONS(2026),
    [anon_sym_STAR] = ACTIONS(1825),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_COLON_COLON] = ACTIONS(2032),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3629),
    [anon_sym_not] = ACTIONS(2026),
    [anon_sym_compl] = ACTIONS(2026),
    [anon_sym_DASH_DASH] = ACTIONS(2050),
    [anon_sym_PLUS_PLUS] = ACTIONS(2050),
    [anon_sym_sizeof] = ACTIONS(2052),
    [anon_sym___alignof__] = ACTIONS(2054),
    [anon_sym___alignof] = ACTIONS(2054),
    [anon_sym__alignof] = ACTIONS(2054),
    [anon_sym_alignof] = ACTIONS(2054),
    [anon_sym__Alignof] = ACTIONS(2054),
    [anon_sym_offsetof] = ACTIONS(2056),
    [anon_sym__Generic] = ACTIONS(2058),
    [anon_sym_asm] = ACTIONS(2060),
    [anon_sym___asm__] = ACTIONS(2060),
    [sym_number_literal] = ACTIONS(2062),
    [anon_sym_L_SQUOTE] = ACTIONS(2064),
    [anon_sym_u_SQUOTE] = ACTIONS(2064),
    [anon_sym_U_SQUOTE] = ACTIONS(2064),
    [anon_sym_u8_SQUOTE] = ACTIONS(2064),
    [anon_sym_SQUOTE] = ACTIONS(2064),
    [anon_sym_L_DQUOTE] = ACTIONS(2066),
    [anon_sym_u_DQUOTE] = ACTIONS(2066),
    [anon_sym_U_DQUOTE] = ACTIONS(2066),
    [anon_sym_u8_DQUOTE] = ACTIONS(2066),
    [anon_sym_DQUOTE] = ACTIONS(2066),
    [sym_true] = ACTIONS(2068),
    [sym_false] = ACTIONS(2068),
    [anon_sym_NULL] = ACTIONS(2070),
    [anon_sym_nullptr] = ACTIONS(2070),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(2080),
    [anon_sym_R_DQUOTE] = ACTIONS(2082),
    [anon_sym_LR_DQUOTE] = ACTIONS(2082),
    [anon_sym_uR_DQUOTE] = ACTIONS(2082),
    [anon_sym_UR_DQUOTE] = ACTIONS(2082),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2082),
    [anon_sym_co_await] = ACTIONS(2084),
    [anon_sym_new] = ACTIONS(2086),
    [anon_sym_requires] = ACTIONS(2088),
    [sym_this] = ACTIONS(2068),
  },
  [1813] = {
    [sym_expression] = STATE(3123),
    [sym__string] = STATE(2844),
    [sym_conditional_expression] = STATE(2844),
    [sym_assignment_expression] = STATE(2844),
    [sym_pointer_expression] = STATE(2790),
    [sym_unary_expression] = STATE(2844),
    [sym_binary_expression] = STATE(2844),
    [sym_update_expression] = STATE(2844),
    [sym_cast_expression] = STATE(2844),
    [sym_sizeof_expression] = STATE(2844),
    [sym_alignof_expression] = STATE(2844),
    [sym_offsetof_expression] = STATE(2844),
    [sym_generic_expression] = STATE(2844),
    [sym_subscript_expression] = STATE(2790),
    [sym_call_expression] = STATE(2790),
    [sym_gnu_asm_expression] = STATE(2844),
    [sym_field_expression] = STATE(2790),
    [sym_compound_literal_expression] = STATE(2844),
    [sym_parenthesized_expression] = STATE(2790),
    [sym_char_literal] = STATE(3120),
    [sym_concatenated_string] = STATE(3146),
    [sym_string_literal] = STATE(2497),
    [sym_null] = STATE(2844),
    [sym_decltype] = STATE(8571),
    [sym__class_name] = STATE(7592),
    [sym_template_type] = STATE(2193),
    [sym_template_function] = STATE(2844),
    [sym_raw_string_literal] = STATE(2492),
    [sym_co_await_expression] = STATE(2844),
    [sym_new_expression] = STATE(2844),
    [sym_delete_expression] = STATE(2844),
    [sym_requires_clause] = STATE(2844),
    [sym_requires_expression] = STATE(2844),
    [sym_lambda_expression] = STATE(2844),
    [sym_lambda_capture_specifier] = STATE(5822),
    [sym_fold_expression] = STATE(2844),
    [sym_parameter_pack_expansion] = STATE(2844),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5628),
    [sym_qualified_identifier] = STATE(2790),
    [sym_qualified_type_identifier] = STATE(7592),
    [sym_user_defined_literal] = STATE(2790),
    [sym_identifier] = ACTIONS(3557),
    [anon_sym_LPAREN2] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3559),
    [anon_sym_PLUS] = ACTIONS(3559),
    [anon_sym_STAR] = ACTIONS(1254),
    [anon_sym_AMP] = ACTIONS(1254),
    [anon_sym_COLON_COLON] = ACTIONS(3563),
    [anon_sym_LBRACK] = ACTIONS(3665),
    [sym_primitive_type] = ACTIONS(3525),
    [anon_sym_not] = ACTIONS(3559),
    [anon_sym_compl] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3912),
    [anon_sym_PLUS_PLUS] = ACTIONS(3912),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym___alignof__] = ACTIONS(3529),
    [anon_sym___alignof] = ACTIONS(3529),
    [anon_sym__alignof] = ACTIONS(3529),
    [anon_sym_alignof] = ACTIONS(3529),
    [anon_sym__Alignof] = ACTIONS(3529),
    [anon_sym_offsetof] = ACTIONS(3531),
    [anon_sym__Generic] = ACTIONS(3533),
    [anon_sym_asm] = ACTIONS(3535),
    [anon_sym___asm__] = ACTIONS(3535),
    [sym_number_literal] = ACTIONS(3567),
    [anon_sym_L_SQUOTE] = ACTIONS(3569),
    [anon_sym_u_SQUOTE] = ACTIONS(3569),
    [anon_sym_U_SQUOTE] = ACTIONS(3569),
    [anon_sym_u8_SQUOTE] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3569),
    [anon_sym_L_DQUOTE] = ACTIONS(3571),
    [anon_sym_u_DQUOTE] = ACTIONS(3571),
    [anon_sym_U_DQUOTE] = ACTIONS(3571),
    [anon_sym_u8_DQUOTE] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_true] = ACTIONS(3543),
    [sym_false] = ACTIONS(3543),
    [anon_sym_NULL] = ACTIONS(3545),
    [anon_sym_nullptr] = ACTIONS(3545),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_delete] = ACTIONS(3573),
    [anon_sym_R_DQUOTE] = ACTIONS(3575),
    [anon_sym_LR_DQUOTE] = ACTIONS(3575),
    [anon_sym_uR_DQUOTE] = ACTIONS(3575),
    [anon_sym_UR_DQUOTE] = ACTIONS(3575),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3575),
    [anon_sym_co_await] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3579),
    [anon_sym_requires] = ACTIONS(3555),
    [sym_this] = ACTIONS(3543),
  },
  [1814] = {
    [sym_catch_clause] = STATE(1819),
    [aux_sym_constructor_try_statement_repeat1] = STATE(1819),
    [sym_identifier] = ACTIONS(1990),
    [aux_sym_preproc_def_token1] = ACTIONS(1990),
    [aux_sym_preproc_if_token1] = ACTIONS(1990),
    [aux_sym_preproc_if_token2] = ACTIONS(1990),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1990),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1990),
    [aux_sym_preproc_else_token1] = ACTIONS(1990),
    [aux_sym_preproc_elif_token1] = ACTIONS(1990),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1990),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1990),
    [sym_preproc_directive] = ACTIONS(1990),
    [anon_sym_LPAREN2] = ACTIONS(1992),
    [anon_sym_TILDE] = ACTIONS(1992),
    [anon_sym_STAR] = ACTIONS(1992),
    [anon_sym_AMP_AMP] = ACTIONS(1992),
    [anon_sym_AMP] = ACTIONS(1990),
    [anon_sym___extension__] = ACTIONS(1990),
    [anon_sym_typedef] = ACTIONS(1990),
    [anon_sym_in] = ACTIONS(1990),
    [anon_sym_out] = ACTIONS(1990),
    [anon_sym_inout] = ACTIONS(1990),
    [anon_sym_extern] = ACTIONS(1990),
    [anon_sym___attribute__] = ACTIONS(1990),
    [anon_sym_COLON_COLON] = ACTIONS(1992),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1992),
    [anon_sym___declspec] = ACTIONS(1990),
    [anon_sym___based] = ACTIONS(1990),
    [anon_sym_signed] = ACTIONS(1990),
    [anon_sym_unsigned] = ACTIONS(1990),
    [anon_sym_long] = ACTIONS(1990),
    [anon_sym_short] = ACTIONS(1990),
    [anon_sym_LBRACK] = ACTIONS(1990),
    [anon_sym_static] = ACTIONS(1990),
    [anon_sym_register] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1990),
    [anon_sym___inline] = ACTIONS(1990),
    [anon_sym___inline__] = ACTIONS(1990),
    [anon_sym___forceinline] = ACTIONS(1990),
    [anon_sym_thread_local] = ACTIONS(1990),
    [anon_sym___thread] = ACTIONS(1990),
    [anon_sym_const] = ACTIONS(1990),
    [anon_sym_constexpr] = ACTIONS(1990),
    [anon_sym_volatile] = ACTIONS(1990),
    [anon_sym_restrict] = ACTIONS(1990),
    [anon_sym___restrict__] = ACTIONS(1990),
    [anon_sym__Atomic] = ACTIONS(1990),
    [anon_sym__Noreturn] = ACTIONS(1990),
    [anon_sym_noreturn] = ACTIONS(1990),
    [anon_sym_mutable] = ACTIONS(1990),
    [anon_sym_constinit] = ACTIONS(1990),
    [anon_sym_consteval] = ACTIONS(1990),
    [anon_sym_alignas] = ACTIONS(1990),
    [anon_sym__Alignas] = ACTIONS(1990),
    [sym_primitive_type] = ACTIONS(1990),
    [anon_sym_enum] = ACTIONS(1990),
    [anon_sym_class] = ACTIONS(1990),
    [anon_sym_struct] = ACTIONS(1990),
    [anon_sym_union] = ACTIONS(1990),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1990),
    [anon_sym_decltype] = ACTIONS(1990),
    [sym_virtual] = ACTIONS(1990),
    [anon_sym_explicit] = ACTIONS(1990),
    [anon_sym_typename] = ACTIONS(1990),
    [anon_sym_template] = ACTIONS(1990),
    [anon_sym_operator] = ACTIONS(1990),
    [anon_sym_friend] = ACTIONS(1990),
    [anon_sym_public] = ACTIONS(1990),
    [anon_sym_private] = ACTIONS(1990),
    [anon_sym_protected] = ACTIONS(1990),
    [anon_sym_using] = ACTIONS(1990),
    [anon_sym_static_assert] = ACTIONS(1990),
    [anon_sym_catch] = ACTIONS(4972),
    [anon_sym_precise] = ACTIONS(1990),
    [anon_sym_shared] = ACTIONS(1990),
    [anon_sym_groupshared] = ACTIONS(1990),
    [anon_sym_uniform] = ACTIONS(1990),
    [anon_sym_row_major] = ACTIONS(1990),
    [anon_sym_column_major] = ACTIONS(1990),
    [anon_sym_globallycoherent] = ACTIONS(1990),
    [anon_sym_centroid] = ACTIONS(1990),
    [anon_sym_noperspective] = ACTIONS(1990),
    [anon_sym_nointerpolation] = ACTIONS(1990),
    [anon_sym_sample] = ACTIONS(1990),
    [anon_sym_linear] = ACTIONS(1990),
    [anon_sym_snorm] = ACTIONS(1990),
    [anon_sym_unorm] = ACTIONS(1990),
    [anon_sym_point] = ACTIONS(1990),
    [anon_sym_line] = ACTIONS(1990),
    [anon_sym_triangleadj] = ACTIONS(1990),
    [anon_sym_lineadj] = ACTIONS(1990),
    [anon_sym_triangle] = ACTIONS(1990),
  },
  [1815] = {
    [sym__declaration_modifiers] = STATE(1984),
    [sym__declaration_specifiers] = STATE(4097),
    [sym_attribute_specifier] = STATE(1984),
    [sym_attribute_declaration] = STATE(1984),
    [sym_ms_declspec_modifier] = STATE(1984),
    [sym_storage_class_specifier] = STATE(1984),
    [sym_type_qualifier] = STATE(1984),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_parameter_declaration] = STATE(7608),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_optional_parameter_declaration] = STATE(7608),
    [sym_variadic_parameter_declaration] = STATE(7608),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6449),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1984),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1984),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(4068),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4974),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1827),
    [anon_sym_out] = ACTIONS(1827),
    [anon_sym_inout] = ACTIONS(1827),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(4078),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(1833),
    [anon_sym_class] = ACTIONS(1835),
    [anon_sym_struct] = ACTIONS(1837),
    [anon_sym_union] = ACTIONS(1839),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1827),
    [anon_sym_typename] = ACTIONS(1863),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1816] = {
    [sym__declaration_modifiers] = STATE(1984),
    [sym__declaration_specifiers] = STATE(4097),
    [sym_attribute_specifier] = STATE(1984),
    [sym_attribute_declaration] = STATE(1984),
    [sym_ms_declspec_modifier] = STATE(1984),
    [sym_storage_class_specifier] = STATE(1984),
    [sym_type_qualifier] = STATE(1984),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_parameter_declaration] = STATE(7092),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_optional_parameter_declaration] = STATE(7092),
    [sym_variadic_parameter_declaration] = STATE(7092),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6449),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1984),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1984),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(4068),
    [anon_sym_RPAREN] = ACTIONS(1817),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1827),
    [anon_sym_out] = ACTIONS(1827),
    [anon_sym_inout] = ACTIONS(1827),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(4078),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(1833),
    [anon_sym_class] = ACTIONS(1835),
    [anon_sym_struct] = ACTIONS(1837),
    [anon_sym_union] = ACTIONS(1839),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1827),
    [anon_sym_typename] = ACTIONS(1863),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1817] = {
    [sym_catch_clause] = STATE(1819),
    [aux_sym_constructor_try_statement_repeat1] = STATE(1819),
    [sym_identifier] = ACTIONS(1963),
    [aux_sym_preproc_def_token1] = ACTIONS(1963),
    [aux_sym_preproc_if_token1] = ACTIONS(1963),
    [aux_sym_preproc_if_token2] = ACTIONS(1963),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1963),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1963),
    [aux_sym_preproc_else_token1] = ACTIONS(1963),
    [aux_sym_preproc_elif_token1] = ACTIONS(1963),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1963),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1963),
    [sym_preproc_directive] = ACTIONS(1963),
    [anon_sym_LPAREN2] = ACTIONS(1965),
    [anon_sym_TILDE] = ACTIONS(1965),
    [anon_sym_STAR] = ACTIONS(1965),
    [anon_sym_AMP_AMP] = ACTIONS(1965),
    [anon_sym_AMP] = ACTIONS(1963),
    [anon_sym___extension__] = ACTIONS(1963),
    [anon_sym_typedef] = ACTIONS(1963),
    [anon_sym_in] = ACTIONS(1963),
    [anon_sym_out] = ACTIONS(1963),
    [anon_sym_inout] = ACTIONS(1963),
    [anon_sym_extern] = ACTIONS(1963),
    [anon_sym___attribute__] = ACTIONS(1963),
    [anon_sym_COLON_COLON] = ACTIONS(1965),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1965),
    [anon_sym___declspec] = ACTIONS(1963),
    [anon_sym___based] = ACTIONS(1963),
    [anon_sym_signed] = ACTIONS(1963),
    [anon_sym_unsigned] = ACTIONS(1963),
    [anon_sym_long] = ACTIONS(1963),
    [anon_sym_short] = ACTIONS(1963),
    [anon_sym_LBRACK] = ACTIONS(1963),
    [anon_sym_static] = ACTIONS(1963),
    [anon_sym_register] = ACTIONS(1963),
    [anon_sym_inline] = ACTIONS(1963),
    [anon_sym___inline] = ACTIONS(1963),
    [anon_sym___inline__] = ACTIONS(1963),
    [anon_sym___forceinline] = ACTIONS(1963),
    [anon_sym_thread_local] = ACTIONS(1963),
    [anon_sym___thread] = ACTIONS(1963),
    [anon_sym_const] = ACTIONS(1963),
    [anon_sym_constexpr] = ACTIONS(1963),
    [anon_sym_volatile] = ACTIONS(1963),
    [anon_sym_restrict] = ACTIONS(1963),
    [anon_sym___restrict__] = ACTIONS(1963),
    [anon_sym__Atomic] = ACTIONS(1963),
    [anon_sym__Noreturn] = ACTIONS(1963),
    [anon_sym_noreturn] = ACTIONS(1963),
    [anon_sym_mutable] = ACTIONS(1963),
    [anon_sym_constinit] = ACTIONS(1963),
    [anon_sym_consteval] = ACTIONS(1963),
    [anon_sym_alignas] = ACTIONS(1963),
    [anon_sym__Alignas] = ACTIONS(1963),
    [sym_primitive_type] = ACTIONS(1963),
    [anon_sym_enum] = ACTIONS(1963),
    [anon_sym_class] = ACTIONS(1963),
    [anon_sym_struct] = ACTIONS(1963),
    [anon_sym_union] = ACTIONS(1963),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1963),
    [anon_sym_decltype] = ACTIONS(1963),
    [sym_virtual] = ACTIONS(1963),
    [anon_sym_explicit] = ACTIONS(1963),
    [anon_sym_typename] = ACTIONS(1963),
    [anon_sym_template] = ACTIONS(1963),
    [anon_sym_operator] = ACTIONS(1963),
    [anon_sym_friend] = ACTIONS(1963),
    [anon_sym_public] = ACTIONS(1963),
    [anon_sym_private] = ACTIONS(1963),
    [anon_sym_protected] = ACTIONS(1963),
    [anon_sym_using] = ACTIONS(1963),
    [anon_sym_static_assert] = ACTIONS(1963),
    [anon_sym_catch] = ACTIONS(4972),
    [anon_sym_precise] = ACTIONS(1963),
    [anon_sym_shared] = ACTIONS(1963),
    [anon_sym_groupshared] = ACTIONS(1963),
    [anon_sym_uniform] = ACTIONS(1963),
    [anon_sym_row_major] = ACTIONS(1963),
    [anon_sym_column_major] = ACTIONS(1963),
    [anon_sym_globallycoherent] = ACTIONS(1963),
    [anon_sym_centroid] = ACTIONS(1963),
    [anon_sym_noperspective] = ACTIONS(1963),
    [anon_sym_nointerpolation] = ACTIONS(1963),
    [anon_sym_sample] = ACTIONS(1963),
    [anon_sym_linear] = ACTIONS(1963),
    [anon_sym_snorm] = ACTIONS(1963),
    [anon_sym_unorm] = ACTIONS(1963),
    [anon_sym_point] = ACTIONS(1963),
    [anon_sym_line] = ACTIONS(1963),
    [anon_sym_triangleadj] = ACTIONS(1963),
    [anon_sym_lineadj] = ACTIONS(1963),
    [anon_sym_triangle] = ACTIONS(1963),
  },
  [1818] = {
    [sym_catch_clause] = STATE(1819),
    [aux_sym_constructor_try_statement_repeat1] = STATE(1819),
    [sym_identifier] = ACTIONS(1984),
    [aux_sym_preproc_def_token1] = ACTIONS(1984),
    [aux_sym_preproc_if_token1] = ACTIONS(1984),
    [aux_sym_preproc_if_token2] = ACTIONS(1984),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1984),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1984),
    [aux_sym_preproc_else_token1] = ACTIONS(1984),
    [aux_sym_preproc_elif_token1] = ACTIONS(1984),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1984),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1984),
    [sym_preproc_directive] = ACTIONS(1984),
    [anon_sym_LPAREN2] = ACTIONS(1986),
    [anon_sym_TILDE] = ACTIONS(1986),
    [anon_sym_STAR] = ACTIONS(1986),
    [anon_sym_AMP_AMP] = ACTIONS(1986),
    [anon_sym_AMP] = ACTIONS(1984),
    [anon_sym___extension__] = ACTIONS(1984),
    [anon_sym_typedef] = ACTIONS(1984),
    [anon_sym_in] = ACTIONS(1984),
    [anon_sym_out] = ACTIONS(1984),
    [anon_sym_inout] = ACTIONS(1984),
    [anon_sym_extern] = ACTIONS(1984),
    [anon_sym___attribute__] = ACTIONS(1984),
    [anon_sym_COLON_COLON] = ACTIONS(1986),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1986),
    [anon_sym___declspec] = ACTIONS(1984),
    [anon_sym___based] = ACTIONS(1984),
    [anon_sym_signed] = ACTIONS(1984),
    [anon_sym_unsigned] = ACTIONS(1984),
    [anon_sym_long] = ACTIONS(1984),
    [anon_sym_short] = ACTIONS(1984),
    [anon_sym_LBRACK] = ACTIONS(1984),
    [anon_sym_static] = ACTIONS(1984),
    [anon_sym_register] = ACTIONS(1984),
    [anon_sym_inline] = ACTIONS(1984),
    [anon_sym___inline] = ACTIONS(1984),
    [anon_sym___inline__] = ACTIONS(1984),
    [anon_sym___forceinline] = ACTIONS(1984),
    [anon_sym_thread_local] = ACTIONS(1984),
    [anon_sym___thread] = ACTIONS(1984),
    [anon_sym_const] = ACTIONS(1984),
    [anon_sym_constexpr] = ACTIONS(1984),
    [anon_sym_volatile] = ACTIONS(1984),
    [anon_sym_restrict] = ACTIONS(1984),
    [anon_sym___restrict__] = ACTIONS(1984),
    [anon_sym__Atomic] = ACTIONS(1984),
    [anon_sym__Noreturn] = ACTIONS(1984),
    [anon_sym_noreturn] = ACTIONS(1984),
    [anon_sym_mutable] = ACTIONS(1984),
    [anon_sym_constinit] = ACTIONS(1984),
    [anon_sym_consteval] = ACTIONS(1984),
    [anon_sym_alignas] = ACTIONS(1984),
    [anon_sym__Alignas] = ACTIONS(1984),
    [sym_primitive_type] = ACTIONS(1984),
    [anon_sym_enum] = ACTIONS(1984),
    [anon_sym_class] = ACTIONS(1984),
    [anon_sym_struct] = ACTIONS(1984),
    [anon_sym_union] = ACTIONS(1984),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1984),
    [anon_sym_decltype] = ACTIONS(1984),
    [sym_virtual] = ACTIONS(1984),
    [anon_sym_explicit] = ACTIONS(1984),
    [anon_sym_typename] = ACTIONS(1984),
    [anon_sym_template] = ACTIONS(1984),
    [anon_sym_operator] = ACTIONS(1984),
    [anon_sym_friend] = ACTIONS(1984),
    [anon_sym_public] = ACTIONS(1984),
    [anon_sym_private] = ACTIONS(1984),
    [anon_sym_protected] = ACTIONS(1984),
    [anon_sym_using] = ACTIONS(1984),
    [anon_sym_static_assert] = ACTIONS(1984),
    [anon_sym_catch] = ACTIONS(4972),
    [anon_sym_precise] = ACTIONS(1984),
    [anon_sym_shared] = ACTIONS(1984),
    [anon_sym_groupshared] = ACTIONS(1984),
    [anon_sym_uniform] = ACTIONS(1984),
    [anon_sym_row_major] = ACTIONS(1984),
    [anon_sym_column_major] = ACTIONS(1984),
    [anon_sym_globallycoherent] = ACTIONS(1984),
    [anon_sym_centroid] = ACTIONS(1984),
    [anon_sym_noperspective] = ACTIONS(1984),
    [anon_sym_nointerpolation] = ACTIONS(1984),
    [anon_sym_sample] = ACTIONS(1984),
    [anon_sym_linear] = ACTIONS(1984),
    [anon_sym_snorm] = ACTIONS(1984),
    [anon_sym_unorm] = ACTIONS(1984),
    [anon_sym_point] = ACTIONS(1984),
    [anon_sym_line] = ACTIONS(1984),
    [anon_sym_triangleadj] = ACTIONS(1984),
    [anon_sym_lineadj] = ACTIONS(1984),
    [anon_sym_triangle] = ACTIONS(1984),
  },
  [1819] = {
    [sym_catch_clause] = STATE(1819),
    [aux_sym_constructor_try_statement_repeat1] = STATE(1819),
    [sym_identifier] = ACTIONS(1973),
    [aux_sym_preproc_def_token1] = ACTIONS(1973),
    [aux_sym_preproc_if_token1] = ACTIONS(1973),
    [aux_sym_preproc_if_token2] = ACTIONS(1973),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1973),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1973),
    [aux_sym_preproc_else_token1] = ACTIONS(1973),
    [aux_sym_preproc_elif_token1] = ACTIONS(1973),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1973),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1973),
    [sym_preproc_directive] = ACTIONS(1973),
    [anon_sym_LPAREN2] = ACTIONS(1975),
    [anon_sym_TILDE] = ACTIONS(1975),
    [anon_sym_STAR] = ACTIONS(1975),
    [anon_sym_AMP_AMP] = ACTIONS(1975),
    [anon_sym_AMP] = ACTIONS(1973),
    [anon_sym___extension__] = ACTIONS(1973),
    [anon_sym_typedef] = ACTIONS(1973),
    [anon_sym_in] = ACTIONS(1973),
    [anon_sym_out] = ACTIONS(1973),
    [anon_sym_inout] = ACTIONS(1973),
    [anon_sym_extern] = ACTIONS(1973),
    [anon_sym___attribute__] = ACTIONS(1973),
    [anon_sym_COLON_COLON] = ACTIONS(1975),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1975),
    [anon_sym___declspec] = ACTIONS(1973),
    [anon_sym___based] = ACTIONS(1973),
    [anon_sym_signed] = ACTIONS(1973),
    [anon_sym_unsigned] = ACTIONS(1973),
    [anon_sym_long] = ACTIONS(1973),
    [anon_sym_short] = ACTIONS(1973),
    [anon_sym_LBRACK] = ACTIONS(1973),
    [anon_sym_static] = ACTIONS(1973),
    [anon_sym_register] = ACTIONS(1973),
    [anon_sym_inline] = ACTIONS(1973),
    [anon_sym___inline] = ACTIONS(1973),
    [anon_sym___inline__] = ACTIONS(1973),
    [anon_sym___forceinline] = ACTIONS(1973),
    [anon_sym_thread_local] = ACTIONS(1973),
    [anon_sym___thread] = ACTIONS(1973),
    [anon_sym_const] = ACTIONS(1973),
    [anon_sym_constexpr] = ACTIONS(1973),
    [anon_sym_volatile] = ACTIONS(1973),
    [anon_sym_restrict] = ACTIONS(1973),
    [anon_sym___restrict__] = ACTIONS(1973),
    [anon_sym__Atomic] = ACTIONS(1973),
    [anon_sym__Noreturn] = ACTIONS(1973),
    [anon_sym_noreturn] = ACTIONS(1973),
    [anon_sym_mutable] = ACTIONS(1973),
    [anon_sym_constinit] = ACTIONS(1973),
    [anon_sym_consteval] = ACTIONS(1973),
    [anon_sym_alignas] = ACTIONS(1973),
    [anon_sym__Alignas] = ACTIONS(1973),
    [sym_primitive_type] = ACTIONS(1973),
    [anon_sym_enum] = ACTIONS(1973),
    [anon_sym_class] = ACTIONS(1973),
    [anon_sym_struct] = ACTIONS(1973),
    [anon_sym_union] = ACTIONS(1973),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1973),
    [anon_sym_decltype] = ACTIONS(1973),
    [sym_virtual] = ACTIONS(1973),
    [anon_sym_explicit] = ACTIONS(1973),
    [anon_sym_typename] = ACTIONS(1973),
    [anon_sym_template] = ACTIONS(1973),
    [anon_sym_operator] = ACTIONS(1973),
    [anon_sym_friend] = ACTIONS(1973),
    [anon_sym_public] = ACTIONS(1973),
    [anon_sym_private] = ACTIONS(1973),
    [anon_sym_protected] = ACTIONS(1973),
    [anon_sym_using] = ACTIONS(1973),
    [anon_sym_static_assert] = ACTIONS(1973),
    [anon_sym_catch] = ACTIONS(4976),
    [anon_sym_precise] = ACTIONS(1973),
    [anon_sym_shared] = ACTIONS(1973),
    [anon_sym_groupshared] = ACTIONS(1973),
    [anon_sym_uniform] = ACTIONS(1973),
    [anon_sym_row_major] = ACTIONS(1973),
    [anon_sym_column_major] = ACTIONS(1973),
    [anon_sym_globallycoherent] = ACTIONS(1973),
    [anon_sym_centroid] = ACTIONS(1973),
    [anon_sym_noperspective] = ACTIONS(1973),
    [anon_sym_nointerpolation] = ACTIONS(1973),
    [anon_sym_sample] = ACTIONS(1973),
    [anon_sym_linear] = ACTIONS(1973),
    [anon_sym_snorm] = ACTIONS(1973),
    [anon_sym_unorm] = ACTIONS(1973),
    [anon_sym_point] = ACTIONS(1973),
    [anon_sym_line] = ACTIONS(1973),
    [anon_sym_triangleadj] = ACTIONS(1973),
    [anon_sym_lineadj] = ACTIONS(1973),
    [anon_sym_triangle] = ACTIONS(1973),
  },
  [1820] = {
    [sym__declaration_modifiers] = STATE(2370),
    [sym_attribute_specifier] = STATE(2370),
    [sym_attribute_declaration] = STATE(2370),
    [sym_ms_declspec_modifier] = STATE(2370),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6062),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2370),
    [sym_type_qualifier] = STATE(2370),
    [sym_alignas_qualifier] = STATE(2331),
    [sym_decltype] = STATE(8571),
    [sym_explicit_function_specifier] = STATE(2370),
    [sym_operator_cast] = STATE(6641),
    [sym__constructor_specifiers] = STATE(2370),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(8571),
    [sym_template_function] = STATE(6270),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5433),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_operator_cast_identifier] = STATE(6641),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2370),
    [aux_sym_operator_cast_definition_repeat1] = STATE(2370),
    [sym_identifier] = ACTIONS(4979),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(4981),
    [anon_sym_in] = ACTIONS(4983),
    [anon_sym_out] = ACTIONS(4983),
    [anon_sym_inout] = ACTIONS(4983),
    [anon_sym_extern] = ACTIONS(4985),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(4989),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4991),
    [anon_sym___declspec] = ACTIONS(4993),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(4985),
    [anon_sym_register] = ACTIONS(4985),
    [anon_sym_inline] = ACTIONS(4985),
    [anon_sym___inline] = ACTIONS(4985),
    [anon_sym___inline__] = ACTIONS(4985),
    [anon_sym___forceinline] = ACTIONS(4985),
    [anon_sym_thread_local] = ACTIONS(4985),
    [anon_sym___thread] = ACTIONS(4985),
    [anon_sym_const] = ACTIONS(4981),
    [anon_sym_constexpr] = ACTIONS(4981),
    [anon_sym_volatile] = ACTIONS(4981),
    [anon_sym_restrict] = ACTIONS(4981),
    [anon_sym___restrict__] = ACTIONS(4981),
    [anon_sym__Atomic] = ACTIONS(4981),
    [anon_sym__Noreturn] = ACTIONS(4981),
    [anon_sym_noreturn] = ACTIONS(4981),
    [anon_sym_mutable] = ACTIONS(4981),
    [anon_sym_constinit] = ACTIONS(4981),
    [anon_sym_consteval] = ACTIONS(4981),
    [anon_sym_alignas] = ACTIONS(4995),
    [anon_sym__Alignas] = ACTIONS(4995),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [sym_virtual] = ACTIONS(4983),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_precise] = ACTIONS(4997),
    [anon_sym_shared] = ACTIONS(4997),
    [anon_sym_groupshared] = ACTIONS(4997),
    [anon_sym_uniform] = ACTIONS(4997),
    [anon_sym_row_major] = ACTIONS(4997),
    [anon_sym_column_major] = ACTIONS(4997),
    [anon_sym_globallycoherent] = ACTIONS(4997),
    [anon_sym_centroid] = ACTIONS(4997),
    [anon_sym_noperspective] = ACTIONS(4997),
    [anon_sym_nointerpolation] = ACTIONS(4997),
    [anon_sym_sample] = ACTIONS(4997),
    [anon_sym_linear] = ACTIONS(4997),
    [anon_sym_snorm] = ACTIONS(4997),
    [anon_sym_unorm] = ACTIONS(4997),
    [anon_sym_point] = ACTIONS(4997),
    [anon_sym_line] = ACTIONS(4997),
    [anon_sym_triangleadj] = ACTIONS(4997),
    [anon_sym_lineadj] = ACTIONS(4997),
    [anon_sym_triangle] = ACTIONS(4997),
  },
  [1821] = {
    [sym_identifier] = ACTIONS(1947),
    [aux_sym_preproc_def_token1] = ACTIONS(1947),
    [anon_sym_COMMA] = ACTIONS(2202),
    [aux_sym_preproc_if_token1] = ACTIONS(1947),
    [aux_sym_preproc_if_token2] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1947),
    [aux_sym_preproc_else_token1] = ACTIONS(1947),
    [aux_sym_preproc_elif_token1] = ACTIONS(1947),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1947),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1947),
    [sym_preproc_directive] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1945),
    [anon_sym_TILDE] = ACTIONS(1945),
    [anon_sym_STAR] = ACTIONS(1945),
    [anon_sym_AMP_AMP] = ACTIONS(1945),
    [anon_sym_AMP] = ACTIONS(1947),
    [anon_sym_SEMI] = ACTIONS(2202),
    [anon_sym___extension__] = ACTIONS(1947),
    [anon_sym_typedef] = ACTIONS(1947),
    [anon_sym_in] = ACTIONS(1947),
    [anon_sym_out] = ACTIONS(1947),
    [anon_sym_inout] = ACTIONS(1947),
    [anon_sym_extern] = ACTIONS(1947),
    [anon_sym___attribute__] = ACTIONS(1947),
    [anon_sym_COLON_COLON] = ACTIONS(1945),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1945),
    [anon_sym___declspec] = ACTIONS(1947),
    [anon_sym___based] = ACTIONS(1947),
    [anon_sym_signed] = ACTIONS(1947),
    [anon_sym_unsigned] = ACTIONS(1947),
    [anon_sym_long] = ACTIONS(1947),
    [anon_sym_short] = ACTIONS(1947),
    [anon_sym_LBRACK] = ACTIONS(1947),
    [anon_sym_static] = ACTIONS(1947),
    [anon_sym_register] = ACTIONS(1947),
    [anon_sym_inline] = ACTIONS(1947),
    [anon_sym___inline] = ACTIONS(1947),
    [anon_sym___inline__] = ACTIONS(1947),
    [anon_sym___forceinline] = ACTIONS(1947),
    [anon_sym_thread_local] = ACTIONS(1947),
    [anon_sym___thread] = ACTIONS(1947),
    [anon_sym_const] = ACTIONS(1947),
    [anon_sym_constexpr] = ACTIONS(1947),
    [anon_sym_volatile] = ACTIONS(1947),
    [anon_sym_restrict] = ACTIONS(1947),
    [anon_sym___restrict__] = ACTIONS(1947),
    [anon_sym__Atomic] = ACTIONS(1947),
    [anon_sym__Noreturn] = ACTIONS(1947),
    [anon_sym_noreturn] = ACTIONS(1947),
    [anon_sym_mutable] = ACTIONS(1947),
    [anon_sym_constinit] = ACTIONS(1947),
    [anon_sym_consteval] = ACTIONS(1947),
    [anon_sym_alignas] = ACTIONS(1947),
    [anon_sym__Alignas] = ACTIONS(1947),
    [sym_primitive_type] = ACTIONS(1947),
    [anon_sym_enum] = ACTIONS(1947),
    [anon_sym_class] = ACTIONS(1947),
    [anon_sym_struct] = ACTIONS(1947),
    [anon_sym_union] = ACTIONS(1947),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1947),
    [anon_sym_decltype] = ACTIONS(1947),
    [sym_virtual] = ACTIONS(1947),
    [anon_sym_explicit] = ACTIONS(1947),
    [anon_sym_typename] = ACTIONS(1947),
    [anon_sym_template] = ACTIONS(1947),
    [anon_sym_operator] = ACTIONS(1947),
    [anon_sym_friend] = ACTIONS(1947),
    [anon_sym_public] = ACTIONS(1947),
    [anon_sym_private] = ACTIONS(1947),
    [anon_sym_protected] = ACTIONS(1947),
    [anon_sym_using] = ACTIONS(1947),
    [anon_sym_static_assert] = ACTIONS(1947),
    [anon_sym_precise] = ACTIONS(1947),
    [anon_sym_shared] = ACTIONS(1947),
    [anon_sym_groupshared] = ACTIONS(1947),
    [anon_sym_uniform] = ACTIONS(1947),
    [anon_sym_row_major] = ACTIONS(1947),
    [anon_sym_column_major] = ACTIONS(1947),
    [anon_sym_globallycoherent] = ACTIONS(1947),
    [anon_sym_centroid] = ACTIONS(1947),
    [anon_sym_noperspective] = ACTIONS(1947),
    [anon_sym_nointerpolation] = ACTIONS(1947),
    [anon_sym_sample] = ACTIONS(1947),
    [anon_sym_linear] = ACTIONS(1947),
    [anon_sym_snorm] = ACTIONS(1947),
    [anon_sym_unorm] = ACTIONS(1947),
    [anon_sym_point] = ACTIONS(1947),
    [anon_sym_line] = ACTIONS(1947),
    [anon_sym_triangleadj] = ACTIONS(1947),
    [anon_sym_lineadj] = ACTIONS(1947),
    [anon_sym_triangle] = ACTIONS(1947),
  },
  [1822] = {
    [sym__declaration_modifiers] = STATE(2370),
    [sym_attribute_specifier] = STATE(2370),
    [sym_attribute_declaration] = STATE(2370),
    [sym_ms_declspec_modifier] = STATE(2370),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6001),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2370),
    [sym_type_qualifier] = STATE(2370),
    [sym_alignas_qualifier] = STATE(2331),
    [sym_decltype] = STATE(8571),
    [sym_explicit_function_specifier] = STATE(2370),
    [sym_operator_cast] = STATE(6621),
    [sym__constructor_specifiers] = STATE(2370),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(8571),
    [sym_template_function] = STATE(6270),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5433),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_operator_cast_identifier] = STATE(6621),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2370),
    [aux_sym_operator_cast_definition_repeat1] = STATE(2370),
    [sym_identifier] = ACTIONS(4979),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(4981),
    [anon_sym_in] = ACTIONS(4983),
    [anon_sym_out] = ACTIONS(4983),
    [anon_sym_inout] = ACTIONS(4983),
    [anon_sym_extern] = ACTIONS(4985),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(4989),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4991),
    [anon_sym___declspec] = ACTIONS(4993),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(4985),
    [anon_sym_register] = ACTIONS(4985),
    [anon_sym_inline] = ACTIONS(4985),
    [anon_sym___inline] = ACTIONS(4985),
    [anon_sym___inline__] = ACTIONS(4985),
    [anon_sym___forceinline] = ACTIONS(4985),
    [anon_sym_thread_local] = ACTIONS(4985),
    [anon_sym___thread] = ACTIONS(4985),
    [anon_sym_const] = ACTIONS(4981),
    [anon_sym_constexpr] = ACTIONS(4981),
    [anon_sym_volatile] = ACTIONS(4981),
    [anon_sym_restrict] = ACTIONS(4981),
    [anon_sym___restrict__] = ACTIONS(4981),
    [anon_sym__Atomic] = ACTIONS(4981),
    [anon_sym__Noreturn] = ACTIONS(4981),
    [anon_sym_noreturn] = ACTIONS(4981),
    [anon_sym_mutable] = ACTIONS(4981),
    [anon_sym_constinit] = ACTIONS(4981),
    [anon_sym_consteval] = ACTIONS(4981),
    [anon_sym_alignas] = ACTIONS(4995),
    [anon_sym__Alignas] = ACTIONS(4995),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [sym_virtual] = ACTIONS(4983),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_precise] = ACTIONS(4997),
    [anon_sym_shared] = ACTIONS(4997),
    [anon_sym_groupshared] = ACTIONS(4997),
    [anon_sym_uniform] = ACTIONS(4997),
    [anon_sym_row_major] = ACTIONS(4997),
    [anon_sym_column_major] = ACTIONS(4997),
    [anon_sym_globallycoherent] = ACTIONS(4997),
    [anon_sym_centroid] = ACTIONS(4997),
    [anon_sym_noperspective] = ACTIONS(4997),
    [anon_sym_nointerpolation] = ACTIONS(4997),
    [anon_sym_sample] = ACTIONS(4997),
    [anon_sym_linear] = ACTIONS(4997),
    [anon_sym_snorm] = ACTIONS(4997),
    [anon_sym_unorm] = ACTIONS(4997),
    [anon_sym_point] = ACTIONS(4997),
    [anon_sym_line] = ACTIONS(4997),
    [anon_sym_triangleadj] = ACTIONS(4997),
    [anon_sym_lineadj] = ACTIONS(4997),
    [anon_sym_triangle] = ACTIONS(4997),
  },
  [1823] = {
    [sym__declaration_modifiers] = STATE(2370),
    [sym_attribute_specifier] = STATE(2370),
    [sym_attribute_declaration] = STATE(2370),
    [sym_ms_declspec_modifier] = STATE(2370),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6139),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2370),
    [sym_type_qualifier] = STATE(2370),
    [sym_alignas_qualifier] = STATE(2331),
    [sym_decltype] = STATE(8571),
    [sym_explicit_function_specifier] = STATE(2370),
    [sym_operator_cast] = STATE(6641),
    [sym__constructor_specifiers] = STATE(2370),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(8571),
    [sym_template_function] = STATE(6270),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5433),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_operator_cast_identifier] = STATE(6641),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2370),
    [aux_sym_operator_cast_definition_repeat1] = STATE(2370),
    [sym_identifier] = ACTIONS(4979),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(4981),
    [anon_sym_in] = ACTIONS(4983),
    [anon_sym_out] = ACTIONS(4983),
    [anon_sym_inout] = ACTIONS(4983),
    [anon_sym_extern] = ACTIONS(4985),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(4989),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4991),
    [anon_sym___declspec] = ACTIONS(4993),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(4985),
    [anon_sym_register] = ACTIONS(4985),
    [anon_sym_inline] = ACTIONS(4985),
    [anon_sym___inline] = ACTIONS(4985),
    [anon_sym___inline__] = ACTIONS(4985),
    [anon_sym___forceinline] = ACTIONS(4985),
    [anon_sym_thread_local] = ACTIONS(4985),
    [anon_sym___thread] = ACTIONS(4985),
    [anon_sym_const] = ACTIONS(4981),
    [anon_sym_constexpr] = ACTIONS(4981),
    [anon_sym_volatile] = ACTIONS(4981),
    [anon_sym_restrict] = ACTIONS(4981),
    [anon_sym___restrict__] = ACTIONS(4981),
    [anon_sym__Atomic] = ACTIONS(4981),
    [anon_sym__Noreturn] = ACTIONS(4981),
    [anon_sym_noreturn] = ACTIONS(4981),
    [anon_sym_mutable] = ACTIONS(4981),
    [anon_sym_constinit] = ACTIONS(4981),
    [anon_sym_consteval] = ACTIONS(4981),
    [anon_sym_alignas] = ACTIONS(4995),
    [anon_sym__Alignas] = ACTIONS(4995),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [sym_virtual] = ACTIONS(4983),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_precise] = ACTIONS(4997),
    [anon_sym_shared] = ACTIONS(4997),
    [anon_sym_groupshared] = ACTIONS(4997),
    [anon_sym_uniform] = ACTIONS(4997),
    [anon_sym_row_major] = ACTIONS(4997),
    [anon_sym_column_major] = ACTIONS(4997),
    [anon_sym_globallycoherent] = ACTIONS(4997),
    [anon_sym_centroid] = ACTIONS(4997),
    [anon_sym_noperspective] = ACTIONS(4997),
    [anon_sym_nointerpolation] = ACTIONS(4997),
    [anon_sym_sample] = ACTIONS(4997),
    [anon_sym_linear] = ACTIONS(4997),
    [anon_sym_snorm] = ACTIONS(4997),
    [anon_sym_unorm] = ACTIONS(4997),
    [anon_sym_point] = ACTIONS(4997),
    [anon_sym_line] = ACTIONS(4997),
    [anon_sym_triangleadj] = ACTIONS(4997),
    [anon_sym_lineadj] = ACTIONS(4997),
    [anon_sym_triangle] = ACTIONS(4997),
  },
  [1824] = {
    [sym__declaration_modifiers] = STATE(2370),
    [sym_attribute_specifier] = STATE(2370),
    [sym_attribute_declaration] = STATE(2370),
    [sym_ms_declspec_modifier] = STATE(2370),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6134),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2370),
    [sym_type_qualifier] = STATE(2370),
    [sym_alignas_qualifier] = STATE(2331),
    [sym_decltype] = STATE(8571),
    [sym_explicit_function_specifier] = STATE(2370),
    [sym_operator_cast] = STATE(6660),
    [sym__constructor_specifiers] = STATE(2370),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(8571),
    [sym_template_function] = STATE(6270),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5433),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_operator_cast_identifier] = STATE(6660),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2370),
    [aux_sym_operator_cast_definition_repeat1] = STATE(2370),
    [sym_identifier] = ACTIONS(4979),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(4981),
    [anon_sym_in] = ACTIONS(4983),
    [anon_sym_out] = ACTIONS(4983),
    [anon_sym_inout] = ACTIONS(4983),
    [anon_sym_extern] = ACTIONS(4985),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(4989),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4991),
    [anon_sym___declspec] = ACTIONS(4993),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(4985),
    [anon_sym_register] = ACTIONS(4985),
    [anon_sym_inline] = ACTIONS(4985),
    [anon_sym___inline] = ACTIONS(4985),
    [anon_sym___inline__] = ACTIONS(4985),
    [anon_sym___forceinline] = ACTIONS(4985),
    [anon_sym_thread_local] = ACTIONS(4985),
    [anon_sym___thread] = ACTIONS(4985),
    [anon_sym_const] = ACTIONS(4981),
    [anon_sym_constexpr] = ACTIONS(4981),
    [anon_sym_volatile] = ACTIONS(4981),
    [anon_sym_restrict] = ACTIONS(4981),
    [anon_sym___restrict__] = ACTIONS(4981),
    [anon_sym__Atomic] = ACTIONS(4981),
    [anon_sym__Noreturn] = ACTIONS(4981),
    [anon_sym_noreturn] = ACTIONS(4981),
    [anon_sym_mutable] = ACTIONS(4981),
    [anon_sym_constinit] = ACTIONS(4981),
    [anon_sym_consteval] = ACTIONS(4981),
    [anon_sym_alignas] = ACTIONS(4995),
    [anon_sym__Alignas] = ACTIONS(4995),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [sym_virtual] = ACTIONS(4983),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_precise] = ACTIONS(4997),
    [anon_sym_shared] = ACTIONS(4997),
    [anon_sym_groupshared] = ACTIONS(4997),
    [anon_sym_uniform] = ACTIONS(4997),
    [anon_sym_row_major] = ACTIONS(4997),
    [anon_sym_column_major] = ACTIONS(4997),
    [anon_sym_globallycoherent] = ACTIONS(4997),
    [anon_sym_centroid] = ACTIONS(4997),
    [anon_sym_noperspective] = ACTIONS(4997),
    [anon_sym_nointerpolation] = ACTIONS(4997),
    [anon_sym_sample] = ACTIONS(4997),
    [anon_sym_linear] = ACTIONS(4997),
    [anon_sym_snorm] = ACTIONS(4997),
    [anon_sym_unorm] = ACTIONS(4997),
    [anon_sym_point] = ACTIONS(4997),
    [anon_sym_line] = ACTIONS(4997),
    [anon_sym_triangleadj] = ACTIONS(4997),
    [anon_sym_lineadj] = ACTIONS(4997),
    [anon_sym_triangle] = ACTIONS(4997),
  },
  [1825] = {
    [sym__declaration_modifiers] = STATE(1984),
    [sym__declaration_specifiers] = STATE(4097),
    [sym_attribute_specifier] = STATE(1984),
    [sym_attribute_declaration] = STATE(1984),
    [sym_ms_declspec_modifier] = STATE(1984),
    [sym_storage_class_specifier] = STATE(1984),
    [sym_type_qualifier] = STATE(1984),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_parameter_declaration] = STATE(7612),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_optional_parameter_declaration] = STATE(7612),
    [sym_variadic_parameter_declaration] = STATE(7612),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6449),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1984),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1984),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(4068),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1827),
    [anon_sym_out] = ACTIONS(1827),
    [anon_sym_inout] = ACTIONS(1827),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(4078),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(1833),
    [anon_sym_class] = ACTIONS(1835),
    [anon_sym_struct] = ACTIONS(1837),
    [anon_sym_union] = ACTIONS(1839),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1827),
    [anon_sym_typename] = ACTIONS(1863),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1826] = {
    [sym__declaration_modifiers] = STATE(2370),
    [sym_attribute_specifier] = STATE(2370),
    [sym_attribute_declaration] = STATE(2370),
    [sym_ms_declspec_modifier] = STATE(2370),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6029),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2370),
    [sym_type_qualifier] = STATE(2370),
    [sym_alignas_qualifier] = STATE(2331),
    [sym_decltype] = STATE(8571),
    [sym_explicit_function_specifier] = STATE(2370),
    [sym_operator_cast] = STATE(6653),
    [sym__constructor_specifiers] = STATE(2370),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(8571),
    [sym_template_function] = STATE(6270),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5433),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_operator_cast_identifier] = STATE(6653),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2370),
    [aux_sym_operator_cast_definition_repeat1] = STATE(2370),
    [sym_identifier] = ACTIONS(4979),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(4981),
    [anon_sym_in] = ACTIONS(4983),
    [anon_sym_out] = ACTIONS(4983),
    [anon_sym_inout] = ACTIONS(4983),
    [anon_sym_extern] = ACTIONS(4985),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(4989),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4991),
    [anon_sym___declspec] = ACTIONS(4993),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(4985),
    [anon_sym_register] = ACTIONS(4985),
    [anon_sym_inline] = ACTIONS(4985),
    [anon_sym___inline] = ACTIONS(4985),
    [anon_sym___inline__] = ACTIONS(4985),
    [anon_sym___forceinline] = ACTIONS(4985),
    [anon_sym_thread_local] = ACTIONS(4985),
    [anon_sym___thread] = ACTIONS(4985),
    [anon_sym_const] = ACTIONS(4981),
    [anon_sym_constexpr] = ACTIONS(4981),
    [anon_sym_volatile] = ACTIONS(4981),
    [anon_sym_restrict] = ACTIONS(4981),
    [anon_sym___restrict__] = ACTIONS(4981),
    [anon_sym__Atomic] = ACTIONS(4981),
    [anon_sym__Noreturn] = ACTIONS(4981),
    [anon_sym_noreturn] = ACTIONS(4981),
    [anon_sym_mutable] = ACTIONS(4981),
    [anon_sym_constinit] = ACTIONS(4981),
    [anon_sym_consteval] = ACTIONS(4981),
    [anon_sym_alignas] = ACTIONS(4995),
    [anon_sym__Alignas] = ACTIONS(4995),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [sym_virtual] = ACTIONS(4983),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_precise] = ACTIONS(4997),
    [anon_sym_shared] = ACTIONS(4997),
    [anon_sym_groupshared] = ACTIONS(4997),
    [anon_sym_uniform] = ACTIONS(4997),
    [anon_sym_row_major] = ACTIONS(4997),
    [anon_sym_column_major] = ACTIONS(4997),
    [anon_sym_globallycoherent] = ACTIONS(4997),
    [anon_sym_centroid] = ACTIONS(4997),
    [anon_sym_noperspective] = ACTIONS(4997),
    [anon_sym_nointerpolation] = ACTIONS(4997),
    [anon_sym_sample] = ACTIONS(4997),
    [anon_sym_linear] = ACTIONS(4997),
    [anon_sym_snorm] = ACTIONS(4997),
    [anon_sym_unorm] = ACTIONS(4997),
    [anon_sym_point] = ACTIONS(4997),
    [anon_sym_line] = ACTIONS(4997),
    [anon_sym_triangleadj] = ACTIONS(4997),
    [anon_sym_lineadj] = ACTIONS(4997),
    [anon_sym_triangle] = ACTIONS(4997),
  },
  [1827] = {
    [sym_identifier] = ACTIONS(1947),
    [aux_sym_preproc_def_token1] = ACTIONS(1947),
    [anon_sym_COMMA] = ACTIONS(2202),
    [aux_sym_preproc_if_token1] = ACTIONS(1947),
    [aux_sym_preproc_if_token2] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1947),
    [aux_sym_preproc_else_token1] = ACTIONS(1947),
    [aux_sym_preproc_elif_token1] = ACTIONS(1947),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1947),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1947),
    [sym_preproc_directive] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1945),
    [anon_sym_TILDE] = ACTIONS(1945),
    [anon_sym_STAR] = ACTIONS(1945),
    [anon_sym_AMP_AMP] = ACTIONS(1945),
    [anon_sym_AMP] = ACTIONS(1947),
    [anon_sym_SEMI] = ACTIONS(2202),
    [anon_sym___extension__] = ACTIONS(1947),
    [anon_sym_typedef] = ACTIONS(1947),
    [anon_sym_in] = ACTIONS(1947),
    [anon_sym_out] = ACTIONS(1947),
    [anon_sym_inout] = ACTIONS(1947),
    [anon_sym_extern] = ACTIONS(1947),
    [anon_sym___attribute__] = ACTIONS(4999),
    [anon_sym_COLON_COLON] = ACTIONS(1945),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1945),
    [anon_sym___declspec] = ACTIONS(1947),
    [anon_sym___based] = ACTIONS(1947),
    [anon_sym_signed] = ACTIONS(1947),
    [anon_sym_unsigned] = ACTIONS(1947),
    [anon_sym_long] = ACTIONS(1947),
    [anon_sym_short] = ACTIONS(1947),
    [anon_sym_LBRACK] = ACTIONS(1947),
    [anon_sym_static] = ACTIONS(1947),
    [anon_sym_register] = ACTIONS(1947),
    [anon_sym_inline] = ACTIONS(1947),
    [anon_sym___inline] = ACTIONS(1947),
    [anon_sym___inline__] = ACTIONS(1947),
    [anon_sym___forceinline] = ACTIONS(1947),
    [anon_sym_thread_local] = ACTIONS(1947),
    [anon_sym___thread] = ACTIONS(1947),
    [anon_sym_const] = ACTIONS(1947),
    [anon_sym_constexpr] = ACTIONS(1947),
    [anon_sym_volatile] = ACTIONS(1947),
    [anon_sym_restrict] = ACTIONS(1947),
    [anon_sym___restrict__] = ACTIONS(1947),
    [anon_sym__Atomic] = ACTIONS(1947),
    [anon_sym__Noreturn] = ACTIONS(1947),
    [anon_sym_noreturn] = ACTIONS(1947),
    [anon_sym_mutable] = ACTIONS(1947),
    [anon_sym_constinit] = ACTIONS(1947),
    [anon_sym_consteval] = ACTIONS(1947),
    [anon_sym_alignas] = ACTIONS(1947),
    [anon_sym__Alignas] = ACTIONS(1947),
    [sym_primitive_type] = ACTIONS(1947),
    [anon_sym_enum] = ACTIONS(1947),
    [anon_sym_class] = ACTIONS(1947),
    [anon_sym_struct] = ACTIONS(1947),
    [anon_sym_union] = ACTIONS(1947),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1947),
    [anon_sym_decltype] = ACTIONS(1947),
    [sym_virtual] = ACTIONS(1947),
    [anon_sym_explicit] = ACTIONS(1947),
    [anon_sym_typename] = ACTIONS(1947),
    [anon_sym_template] = ACTIONS(1947),
    [anon_sym_operator] = ACTIONS(1947),
    [anon_sym_friend] = ACTIONS(1947),
    [anon_sym_public] = ACTIONS(1947),
    [anon_sym_private] = ACTIONS(1947),
    [anon_sym_protected] = ACTIONS(1947),
    [anon_sym_using] = ACTIONS(1947),
    [anon_sym_static_assert] = ACTIONS(1947),
    [anon_sym_precise] = ACTIONS(1947),
    [anon_sym_shared] = ACTIONS(1947),
    [anon_sym_groupshared] = ACTIONS(1947),
    [anon_sym_uniform] = ACTIONS(1947),
    [anon_sym_row_major] = ACTIONS(1947),
    [anon_sym_column_major] = ACTIONS(1947),
    [anon_sym_globallycoherent] = ACTIONS(1947),
    [anon_sym_centroid] = ACTIONS(1947),
    [anon_sym_noperspective] = ACTIONS(1947),
    [anon_sym_nointerpolation] = ACTIONS(1947),
    [anon_sym_sample] = ACTIONS(1947),
    [anon_sym_linear] = ACTIONS(1947),
    [anon_sym_snorm] = ACTIONS(1947),
    [anon_sym_unorm] = ACTIONS(1947),
    [anon_sym_point] = ACTIONS(1947),
    [anon_sym_line] = ACTIONS(1947),
    [anon_sym_triangleadj] = ACTIONS(1947),
    [anon_sym_lineadj] = ACTIONS(1947),
    [anon_sym_triangle] = ACTIONS(1947),
  },
  [1828] = {
    [sym__declaration_modifiers] = STATE(2370),
    [sym_attribute_specifier] = STATE(2370),
    [sym_attribute_declaration] = STATE(2370),
    [sym_ms_declspec_modifier] = STATE(2370),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6150),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2370),
    [sym_type_qualifier] = STATE(2370),
    [sym_alignas_qualifier] = STATE(2331),
    [sym_decltype] = STATE(8571),
    [sym_explicit_function_specifier] = STATE(2370),
    [sym_operator_cast] = STATE(6671),
    [sym__constructor_specifiers] = STATE(2370),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(8571),
    [sym_template_function] = STATE(6270),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5433),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_operator_cast_identifier] = STATE(6671),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2370),
    [aux_sym_operator_cast_definition_repeat1] = STATE(2370),
    [sym_identifier] = ACTIONS(4979),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(4981),
    [anon_sym_in] = ACTIONS(4983),
    [anon_sym_out] = ACTIONS(4983),
    [anon_sym_inout] = ACTIONS(4983),
    [anon_sym_extern] = ACTIONS(4985),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(4989),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4991),
    [anon_sym___declspec] = ACTIONS(4993),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(4985),
    [anon_sym_register] = ACTIONS(4985),
    [anon_sym_inline] = ACTIONS(4985),
    [anon_sym___inline] = ACTIONS(4985),
    [anon_sym___inline__] = ACTIONS(4985),
    [anon_sym___forceinline] = ACTIONS(4985),
    [anon_sym_thread_local] = ACTIONS(4985),
    [anon_sym___thread] = ACTIONS(4985),
    [anon_sym_const] = ACTIONS(4981),
    [anon_sym_constexpr] = ACTIONS(4981),
    [anon_sym_volatile] = ACTIONS(4981),
    [anon_sym_restrict] = ACTIONS(4981),
    [anon_sym___restrict__] = ACTIONS(4981),
    [anon_sym__Atomic] = ACTIONS(4981),
    [anon_sym__Noreturn] = ACTIONS(4981),
    [anon_sym_noreturn] = ACTIONS(4981),
    [anon_sym_mutable] = ACTIONS(4981),
    [anon_sym_constinit] = ACTIONS(4981),
    [anon_sym_consteval] = ACTIONS(4981),
    [anon_sym_alignas] = ACTIONS(4995),
    [anon_sym__Alignas] = ACTIONS(4995),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [sym_virtual] = ACTIONS(4983),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_precise] = ACTIONS(4997),
    [anon_sym_shared] = ACTIONS(4997),
    [anon_sym_groupshared] = ACTIONS(4997),
    [anon_sym_uniform] = ACTIONS(4997),
    [anon_sym_row_major] = ACTIONS(4997),
    [anon_sym_column_major] = ACTIONS(4997),
    [anon_sym_globallycoherent] = ACTIONS(4997),
    [anon_sym_centroid] = ACTIONS(4997),
    [anon_sym_noperspective] = ACTIONS(4997),
    [anon_sym_nointerpolation] = ACTIONS(4997),
    [anon_sym_sample] = ACTIONS(4997),
    [anon_sym_linear] = ACTIONS(4997),
    [anon_sym_snorm] = ACTIONS(4997),
    [anon_sym_unorm] = ACTIONS(4997),
    [anon_sym_point] = ACTIONS(4997),
    [anon_sym_line] = ACTIONS(4997),
    [anon_sym_triangleadj] = ACTIONS(4997),
    [anon_sym_lineadj] = ACTIONS(4997),
    [anon_sym_triangle] = ACTIONS(4997),
  },
  [1829] = {
    [sym__declaration_modifiers] = STATE(2370),
    [sym_attribute_specifier] = STATE(2370),
    [sym_attribute_declaration] = STATE(2370),
    [sym_ms_declspec_modifier] = STATE(2370),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6011),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2370),
    [sym_type_qualifier] = STATE(2370),
    [sym_alignas_qualifier] = STATE(2331),
    [sym_decltype] = STATE(8571),
    [sym_explicit_function_specifier] = STATE(2370),
    [sym_operator_cast] = STATE(6656),
    [sym__constructor_specifiers] = STATE(2370),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(8571),
    [sym_template_function] = STATE(6270),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5433),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_operator_cast_identifier] = STATE(6656),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2370),
    [aux_sym_operator_cast_definition_repeat1] = STATE(2370),
    [sym_identifier] = ACTIONS(4979),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(4981),
    [anon_sym_in] = ACTIONS(4983),
    [anon_sym_out] = ACTIONS(4983),
    [anon_sym_inout] = ACTIONS(4983),
    [anon_sym_extern] = ACTIONS(4985),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(4989),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4991),
    [anon_sym___declspec] = ACTIONS(4993),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(4985),
    [anon_sym_register] = ACTIONS(4985),
    [anon_sym_inline] = ACTIONS(4985),
    [anon_sym___inline] = ACTIONS(4985),
    [anon_sym___inline__] = ACTIONS(4985),
    [anon_sym___forceinline] = ACTIONS(4985),
    [anon_sym_thread_local] = ACTIONS(4985),
    [anon_sym___thread] = ACTIONS(4985),
    [anon_sym_const] = ACTIONS(4981),
    [anon_sym_constexpr] = ACTIONS(4981),
    [anon_sym_volatile] = ACTIONS(4981),
    [anon_sym_restrict] = ACTIONS(4981),
    [anon_sym___restrict__] = ACTIONS(4981),
    [anon_sym__Atomic] = ACTIONS(4981),
    [anon_sym__Noreturn] = ACTIONS(4981),
    [anon_sym_noreturn] = ACTIONS(4981),
    [anon_sym_mutable] = ACTIONS(4981),
    [anon_sym_constinit] = ACTIONS(4981),
    [anon_sym_consteval] = ACTIONS(4981),
    [anon_sym_alignas] = ACTIONS(4995),
    [anon_sym__Alignas] = ACTIONS(4995),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [sym_virtual] = ACTIONS(4983),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_precise] = ACTIONS(4997),
    [anon_sym_shared] = ACTIONS(4997),
    [anon_sym_groupshared] = ACTIONS(4997),
    [anon_sym_uniform] = ACTIONS(4997),
    [anon_sym_row_major] = ACTIONS(4997),
    [anon_sym_column_major] = ACTIONS(4997),
    [anon_sym_globallycoherent] = ACTIONS(4997),
    [anon_sym_centroid] = ACTIONS(4997),
    [anon_sym_noperspective] = ACTIONS(4997),
    [anon_sym_nointerpolation] = ACTIONS(4997),
    [anon_sym_sample] = ACTIONS(4997),
    [anon_sym_linear] = ACTIONS(4997),
    [anon_sym_snorm] = ACTIONS(4997),
    [anon_sym_unorm] = ACTIONS(4997),
    [anon_sym_point] = ACTIONS(4997),
    [anon_sym_line] = ACTIONS(4997),
    [anon_sym_triangleadj] = ACTIONS(4997),
    [anon_sym_lineadj] = ACTIONS(4997),
    [anon_sym_triangle] = ACTIONS(4997),
  },
  [1830] = {
    [sym__declaration_modifiers] = STATE(2370),
    [sym_attribute_specifier] = STATE(2370),
    [sym_attribute_declaration] = STATE(2370),
    [sym_ms_declspec_modifier] = STATE(2370),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6014),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2370),
    [sym_type_qualifier] = STATE(2370),
    [sym_alignas_qualifier] = STATE(2331),
    [sym_decltype] = STATE(8571),
    [sym_explicit_function_specifier] = STATE(2370),
    [sym_operator_cast] = STATE(6660),
    [sym__constructor_specifiers] = STATE(2370),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(8571),
    [sym_template_function] = STATE(6270),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5433),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_operator_cast_identifier] = STATE(6660),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2370),
    [aux_sym_operator_cast_definition_repeat1] = STATE(2370),
    [sym_identifier] = ACTIONS(4979),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(4981),
    [anon_sym_in] = ACTIONS(4983),
    [anon_sym_out] = ACTIONS(4983),
    [anon_sym_inout] = ACTIONS(4983),
    [anon_sym_extern] = ACTIONS(4985),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(4989),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4991),
    [anon_sym___declspec] = ACTIONS(4993),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(4985),
    [anon_sym_register] = ACTIONS(4985),
    [anon_sym_inline] = ACTIONS(4985),
    [anon_sym___inline] = ACTIONS(4985),
    [anon_sym___inline__] = ACTIONS(4985),
    [anon_sym___forceinline] = ACTIONS(4985),
    [anon_sym_thread_local] = ACTIONS(4985),
    [anon_sym___thread] = ACTIONS(4985),
    [anon_sym_const] = ACTIONS(4981),
    [anon_sym_constexpr] = ACTIONS(4981),
    [anon_sym_volatile] = ACTIONS(4981),
    [anon_sym_restrict] = ACTIONS(4981),
    [anon_sym___restrict__] = ACTIONS(4981),
    [anon_sym__Atomic] = ACTIONS(4981),
    [anon_sym__Noreturn] = ACTIONS(4981),
    [anon_sym_noreturn] = ACTIONS(4981),
    [anon_sym_mutable] = ACTIONS(4981),
    [anon_sym_constinit] = ACTIONS(4981),
    [anon_sym_consteval] = ACTIONS(4981),
    [anon_sym_alignas] = ACTIONS(4995),
    [anon_sym__Alignas] = ACTIONS(4995),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [sym_virtual] = ACTIONS(4983),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_precise] = ACTIONS(4997),
    [anon_sym_shared] = ACTIONS(4997),
    [anon_sym_groupshared] = ACTIONS(4997),
    [anon_sym_uniform] = ACTIONS(4997),
    [anon_sym_row_major] = ACTIONS(4997),
    [anon_sym_column_major] = ACTIONS(4997),
    [anon_sym_globallycoherent] = ACTIONS(4997),
    [anon_sym_centroid] = ACTIONS(4997),
    [anon_sym_noperspective] = ACTIONS(4997),
    [anon_sym_nointerpolation] = ACTIONS(4997),
    [anon_sym_sample] = ACTIONS(4997),
    [anon_sym_linear] = ACTIONS(4997),
    [anon_sym_snorm] = ACTIONS(4997),
    [anon_sym_unorm] = ACTIONS(4997),
    [anon_sym_point] = ACTIONS(4997),
    [anon_sym_line] = ACTIONS(4997),
    [anon_sym_triangleadj] = ACTIONS(4997),
    [anon_sym_lineadj] = ACTIONS(4997),
    [anon_sym_triangle] = ACTIONS(4997),
  },
  [1831] = {
    [sym__declaration_modifiers] = STATE(2370),
    [sym_attribute_specifier] = STATE(2370),
    [sym_attribute_declaration] = STATE(2370),
    [sym_ms_declspec_modifier] = STATE(2370),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6013),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2370),
    [sym_type_qualifier] = STATE(2370),
    [sym_alignas_qualifier] = STATE(2331),
    [sym_decltype] = STATE(8571),
    [sym_explicit_function_specifier] = STATE(2370),
    [sym_operator_cast] = STATE(6671),
    [sym__constructor_specifiers] = STATE(2370),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(8571),
    [sym_template_function] = STATE(6270),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5433),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_operator_cast_identifier] = STATE(6671),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2370),
    [aux_sym_operator_cast_definition_repeat1] = STATE(2370),
    [sym_identifier] = ACTIONS(4979),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(4981),
    [anon_sym_in] = ACTIONS(4983),
    [anon_sym_out] = ACTIONS(4983),
    [anon_sym_inout] = ACTIONS(4983),
    [anon_sym_extern] = ACTIONS(4985),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(4989),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4991),
    [anon_sym___declspec] = ACTIONS(4993),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(4985),
    [anon_sym_register] = ACTIONS(4985),
    [anon_sym_inline] = ACTIONS(4985),
    [anon_sym___inline] = ACTIONS(4985),
    [anon_sym___inline__] = ACTIONS(4985),
    [anon_sym___forceinline] = ACTIONS(4985),
    [anon_sym_thread_local] = ACTIONS(4985),
    [anon_sym___thread] = ACTIONS(4985),
    [anon_sym_const] = ACTIONS(4981),
    [anon_sym_constexpr] = ACTIONS(4981),
    [anon_sym_volatile] = ACTIONS(4981),
    [anon_sym_restrict] = ACTIONS(4981),
    [anon_sym___restrict__] = ACTIONS(4981),
    [anon_sym__Atomic] = ACTIONS(4981),
    [anon_sym__Noreturn] = ACTIONS(4981),
    [anon_sym_noreturn] = ACTIONS(4981),
    [anon_sym_mutable] = ACTIONS(4981),
    [anon_sym_constinit] = ACTIONS(4981),
    [anon_sym_consteval] = ACTIONS(4981),
    [anon_sym_alignas] = ACTIONS(4995),
    [anon_sym__Alignas] = ACTIONS(4995),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [sym_virtual] = ACTIONS(4983),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_precise] = ACTIONS(4997),
    [anon_sym_shared] = ACTIONS(4997),
    [anon_sym_groupshared] = ACTIONS(4997),
    [anon_sym_uniform] = ACTIONS(4997),
    [anon_sym_row_major] = ACTIONS(4997),
    [anon_sym_column_major] = ACTIONS(4997),
    [anon_sym_globallycoherent] = ACTIONS(4997),
    [anon_sym_centroid] = ACTIONS(4997),
    [anon_sym_noperspective] = ACTIONS(4997),
    [anon_sym_nointerpolation] = ACTIONS(4997),
    [anon_sym_sample] = ACTIONS(4997),
    [anon_sym_linear] = ACTIONS(4997),
    [anon_sym_snorm] = ACTIONS(4997),
    [anon_sym_unorm] = ACTIONS(4997),
    [anon_sym_point] = ACTIONS(4997),
    [anon_sym_line] = ACTIONS(4997),
    [anon_sym_triangleadj] = ACTIONS(4997),
    [anon_sym_lineadj] = ACTIONS(4997),
    [anon_sym_triangle] = ACTIONS(4997),
  },
  [1832] = {
    [sym__declaration_modifiers] = STATE(2370),
    [sym_attribute_specifier] = STATE(2370),
    [sym_attribute_declaration] = STATE(2370),
    [sym_ms_declspec_modifier] = STATE(2370),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6004),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2370),
    [sym_type_qualifier] = STATE(2370),
    [sym_alignas_qualifier] = STATE(2331),
    [sym_decltype] = STATE(8571),
    [sym_explicit_function_specifier] = STATE(2370),
    [sym_operator_cast] = STATE(6664),
    [sym__constructor_specifiers] = STATE(2370),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(8571),
    [sym_template_function] = STATE(6270),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5433),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_operator_cast_identifier] = STATE(6664),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2370),
    [aux_sym_operator_cast_definition_repeat1] = STATE(2370),
    [sym_identifier] = ACTIONS(4979),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(4981),
    [anon_sym_in] = ACTIONS(4983),
    [anon_sym_out] = ACTIONS(4983),
    [anon_sym_inout] = ACTIONS(4983),
    [anon_sym_extern] = ACTIONS(4985),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(4989),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4991),
    [anon_sym___declspec] = ACTIONS(4993),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(4985),
    [anon_sym_register] = ACTIONS(4985),
    [anon_sym_inline] = ACTIONS(4985),
    [anon_sym___inline] = ACTIONS(4985),
    [anon_sym___inline__] = ACTIONS(4985),
    [anon_sym___forceinline] = ACTIONS(4985),
    [anon_sym_thread_local] = ACTIONS(4985),
    [anon_sym___thread] = ACTIONS(4985),
    [anon_sym_const] = ACTIONS(4981),
    [anon_sym_constexpr] = ACTIONS(4981),
    [anon_sym_volatile] = ACTIONS(4981),
    [anon_sym_restrict] = ACTIONS(4981),
    [anon_sym___restrict__] = ACTIONS(4981),
    [anon_sym__Atomic] = ACTIONS(4981),
    [anon_sym__Noreturn] = ACTIONS(4981),
    [anon_sym_noreturn] = ACTIONS(4981),
    [anon_sym_mutable] = ACTIONS(4981),
    [anon_sym_constinit] = ACTIONS(4981),
    [anon_sym_consteval] = ACTIONS(4981),
    [anon_sym_alignas] = ACTIONS(4995),
    [anon_sym__Alignas] = ACTIONS(4995),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [sym_virtual] = ACTIONS(4983),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_precise] = ACTIONS(4997),
    [anon_sym_shared] = ACTIONS(4997),
    [anon_sym_groupshared] = ACTIONS(4997),
    [anon_sym_uniform] = ACTIONS(4997),
    [anon_sym_row_major] = ACTIONS(4997),
    [anon_sym_column_major] = ACTIONS(4997),
    [anon_sym_globallycoherent] = ACTIONS(4997),
    [anon_sym_centroid] = ACTIONS(4997),
    [anon_sym_noperspective] = ACTIONS(4997),
    [anon_sym_nointerpolation] = ACTIONS(4997),
    [anon_sym_sample] = ACTIONS(4997),
    [anon_sym_linear] = ACTIONS(4997),
    [anon_sym_snorm] = ACTIONS(4997),
    [anon_sym_unorm] = ACTIONS(4997),
    [anon_sym_point] = ACTIONS(4997),
    [anon_sym_line] = ACTIONS(4997),
    [anon_sym_triangleadj] = ACTIONS(4997),
    [anon_sym_lineadj] = ACTIONS(4997),
    [anon_sym_triangle] = ACTIONS(4997),
  },
  [1833] = {
    [sym__declaration_modifiers] = STATE(2370),
    [sym_attribute_specifier] = STATE(2370),
    [sym_attribute_declaration] = STATE(2370),
    [sym_ms_declspec_modifier] = STATE(2370),
    [sym_ms_based_modifier] = STATE(8582),
    [sym__declarator] = STATE(6561),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_function_declarator] = STATE(6177),
    [sym_array_declarator] = STATE(6270),
    [sym_storage_class_specifier] = STATE(2370),
    [sym_type_qualifier] = STATE(2370),
    [sym_alignas_qualifier] = STATE(2331),
    [sym_decltype] = STATE(8571),
    [sym_explicit_function_specifier] = STATE(2370),
    [sym_operator_cast] = STATE(6653),
    [sym__constructor_specifiers] = STATE(2370),
    [sym_reference_declarator] = STATE(6270),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym_template_type] = STATE(8571),
    [sym_template_function] = STATE(6270),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5433),
    [sym_qualified_identifier] = STATE(6270),
    [sym_qualified_operator_cast_identifier] = STATE(6653),
    [sym_operator_name] = STATE(6270),
    [sym_qualifiers] = STATE(2370),
    [aux_sym_operator_cast_definition_repeat1] = STATE(2370),
    [sym_identifier] = ACTIONS(4979),
    [anon_sym_LPAREN2] = ACTIONS(2601),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(2605),
    [anon_sym_AMP_AMP] = ACTIONS(29),
    [anon_sym_AMP] = ACTIONS(2607),
    [anon_sym___extension__] = ACTIONS(4981),
    [anon_sym_in] = ACTIONS(4983),
    [anon_sym_out] = ACTIONS(4983),
    [anon_sym_inout] = ACTIONS(4983),
    [anon_sym_extern] = ACTIONS(4985),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(4989),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4991),
    [anon_sym___declspec] = ACTIONS(4993),
    [anon_sym___based] = ACTIONS(49),
    [anon_sym_LBRACK] = ACTIONS(2615),
    [anon_sym_static] = ACTIONS(4985),
    [anon_sym_register] = ACTIONS(4985),
    [anon_sym_inline] = ACTIONS(4985),
    [anon_sym___inline] = ACTIONS(4985),
    [anon_sym___inline__] = ACTIONS(4985),
    [anon_sym___forceinline] = ACTIONS(4985),
    [anon_sym_thread_local] = ACTIONS(4985),
    [anon_sym___thread] = ACTIONS(4985),
    [anon_sym_const] = ACTIONS(4981),
    [anon_sym_constexpr] = ACTIONS(4981),
    [anon_sym_volatile] = ACTIONS(4981),
    [anon_sym_restrict] = ACTIONS(4981),
    [anon_sym___restrict__] = ACTIONS(4981),
    [anon_sym__Atomic] = ACTIONS(4981),
    [anon_sym__Noreturn] = ACTIONS(4981),
    [anon_sym_noreturn] = ACTIONS(4981),
    [anon_sym_mutable] = ACTIONS(4981),
    [anon_sym_constinit] = ACTIONS(4981),
    [anon_sym_consteval] = ACTIONS(4981),
    [anon_sym_alignas] = ACTIONS(4995),
    [anon_sym__Alignas] = ACTIONS(4995),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [sym_virtual] = ACTIONS(4983),
    [anon_sym_explicit] = ACTIONS(125),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(131),
    [anon_sym_precise] = ACTIONS(4997),
    [anon_sym_shared] = ACTIONS(4997),
    [anon_sym_groupshared] = ACTIONS(4997),
    [anon_sym_uniform] = ACTIONS(4997),
    [anon_sym_row_major] = ACTIONS(4997),
    [anon_sym_column_major] = ACTIONS(4997),
    [anon_sym_globallycoherent] = ACTIONS(4997),
    [anon_sym_centroid] = ACTIONS(4997),
    [anon_sym_noperspective] = ACTIONS(4997),
    [anon_sym_nointerpolation] = ACTIONS(4997),
    [anon_sym_sample] = ACTIONS(4997),
    [anon_sym_linear] = ACTIONS(4997),
    [anon_sym_snorm] = ACTIONS(4997),
    [anon_sym_unorm] = ACTIONS(4997),
    [anon_sym_point] = ACTIONS(4997),
    [anon_sym_line] = ACTIONS(4997),
    [anon_sym_triangleadj] = ACTIONS(4997),
    [anon_sym_lineadj] = ACTIONS(4997),
    [anon_sym_triangle] = ACTIONS(4997),
  },
  [1834] = {
    [sym_identifier] = ACTIONS(2012),
    [aux_sym_preproc_def_token1] = ACTIONS(2012),
    [aux_sym_preproc_if_token1] = ACTIONS(2012),
    [aux_sym_preproc_if_token2] = ACTIONS(2012),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2012),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2012),
    [aux_sym_preproc_else_token1] = ACTIONS(2012),
    [aux_sym_preproc_elif_token1] = ACTIONS(2012),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2012),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2012),
    [sym_preproc_directive] = ACTIONS(2012),
    [anon_sym_LPAREN2] = ACTIONS(2014),
    [anon_sym_TILDE] = ACTIONS(2014),
    [anon_sym_STAR] = ACTIONS(2014),
    [anon_sym_AMP_AMP] = ACTIONS(2014),
    [anon_sym_AMP] = ACTIONS(2012),
    [anon_sym___extension__] = ACTIONS(2012),
    [anon_sym_typedef] = ACTIONS(2012),
    [anon_sym_in] = ACTIONS(2012),
    [anon_sym_out] = ACTIONS(2012),
    [anon_sym_inout] = ACTIONS(2012),
    [anon_sym_extern] = ACTIONS(2012),
    [anon_sym___attribute__] = ACTIONS(2012),
    [anon_sym_COLON_COLON] = ACTIONS(2014),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2014),
    [anon_sym___declspec] = ACTIONS(2012),
    [anon_sym___based] = ACTIONS(2012),
    [anon_sym_signed] = ACTIONS(2012),
    [anon_sym_unsigned] = ACTIONS(2012),
    [anon_sym_long] = ACTIONS(2012),
    [anon_sym_short] = ACTIONS(2012),
    [anon_sym_LBRACK] = ACTIONS(2012),
    [anon_sym_static] = ACTIONS(2012),
    [anon_sym_register] = ACTIONS(2012),
    [anon_sym_inline] = ACTIONS(2012),
    [anon_sym___inline] = ACTIONS(2012),
    [anon_sym___inline__] = ACTIONS(2012),
    [anon_sym___forceinline] = ACTIONS(2012),
    [anon_sym_thread_local] = ACTIONS(2012),
    [anon_sym___thread] = ACTIONS(2012),
    [anon_sym_const] = ACTIONS(2012),
    [anon_sym_constexpr] = ACTIONS(2012),
    [anon_sym_volatile] = ACTIONS(2012),
    [anon_sym_restrict] = ACTIONS(2012),
    [anon_sym___restrict__] = ACTIONS(2012),
    [anon_sym__Atomic] = ACTIONS(2012),
    [anon_sym__Noreturn] = ACTIONS(2012),
    [anon_sym_noreturn] = ACTIONS(2012),
    [anon_sym_mutable] = ACTIONS(2012),
    [anon_sym_constinit] = ACTIONS(2012),
    [anon_sym_consteval] = ACTIONS(2012),
    [anon_sym_alignas] = ACTIONS(2012),
    [anon_sym__Alignas] = ACTIONS(2012),
    [sym_primitive_type] = ACTIONS(2012),
    [anon_sym_enum] = ACTIONS(2012),
    [anon_sym_class] = ACTIONS(2012),
    [anon_sym_struct] = ACTIONS(2012),
    [anon_sym_union] = ACTIONS(2012),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2012),
    [anon_sym_decltype] = ACTIONS(2012),
    [sym_virtual] = ACTIONS(2012),
    [anon_sym_explicit] = ACTIONS(2012),
    [anon_sym_typename] = ACTIONS(2012),
    [anon_sym_template] = ACTIONS(2012),
    [anon_sym_operator] = ACTIONS(2012),
    [anon_sym_friend] = ACTIONS(2012),
    [anon_sym_public] = ACTIONS(2012),
    [anon_sym_private] = ACTIONS(2012),
    [anon_sym_protected] = ACTIONS(2012),
    [anon_sym_using] = ACTIONS(2012),
    [anon_sym_static_assert] = ACTIONS(2012),
    [anon_sym_catch] = ACTIONS(2012),
    [anon_sym_precise] = ACTIONS(2012),
    [anon_sym_shared] = ACTIONS(2012),
    [anon_sym_groupshared] = ACTIONS(2012),
    [anon_sym_uniform] = ACTIONS(2012),
    [anon_sym_row_major] = ACTIONS(2012),
    [anon_sym_column_major] = ACTIONS(2012),
    [anon_sym_globallycoherent] = ACTIONS(2012),
    [anon_sym_centroid] = ACTIONS(2012),
    [anon_sym_noperspective] = ACTIONS(2012),
    [anon_sym_nointerpolation] = ACTIONS(2012),
    [anon_sym_sample] = ACTIONS(2012),
    [anon_sym_linear] = ACTIONS(2012),
    [anon_sym_snorm] = ACTIONS(2012),
    [anon_sym_unorm] = ACTIONS(2012),
    [anon_sym_point] = ACTIONS(2012),
    [anon_sym_line] = ACTIONS(2012),
    [anon_sym_triangleadj] = ACTIONS(2012),
    [anon_sym_lineadj] = ACTIONS(2012),
    [anon_sym_triangle] = ACTIONS(2012),
  },
  [1835] = {
    [sym_identifier] = ACTIONS(1947),
    [aux_sym_preproc_def_token1] = ACTIONS(1947),
    [aux_sym_preproc_if_token1] = ACTIONS(1947),
    [aux_sym_preproc_if_token2] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1947),
    [aux_sym_preproc_else_token1] = ACTIONS(1947),
    [aux_sym_preproc_elif_token1] = ACTIONS(1947),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1947),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1947),
    [sym_preproc_directive] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1945),
    [anon_sym_TILDE] = ACTIONS(1945),
    [anon_sym_STAR] = ACTIONS(1945),
    [anon_sym_AMP_AMP] = ACTIONS(1945),
    [anon_sym_AMP] = ACTIONS(1947),
    [anon_sym___extension__] = ACTIONS(1947),
    [anon_sym_typedef] = ACTIONS(1947),
    [anon_sym_in] = ACTIONS(1947),
    [anon_sym_out] = ACTIONS(1947),
    [anon_sym_inout] = ACTIONS(1947),
    [anon_sym_extern] = ACTIONS(1947),
    [anon_sym___attribute__] = ACTIONS(1947),
    [anon_sym_COLON_COLON] = ACTIONS(1945),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1945),
    [anon_sym___declspec] = ACTIONS(1947),
    [anon_sym___based] = ACTIONS(1947),
    [anon_sym_signed] = ACTIONS(1947),
    [anon_sym_unsigned] = ACTIONS(1947),
    [anon_sym_long] = ACTIONS(1947),
    [anon_sym_short] = ACTIONS(1947),
    [anon_sym_LBRACK] = ACTIONS(1947),
    [anon_sym_static] = ACTIONS(1947),
    [anon_sym_register] = ACTIONS(1947),
    [anon_sym_inline] = ACTIONS(1947),
    [anon_sym___inline] = ACTIONS(1947),
    [anon_sym___inline__] = ACTIONS(1947),
    [anon_sym___forceinline] = ACTIONS(1947),
    [anon_sym_thread_local] = ACTIONS(1947),
    [anon_sym___thread] = ACTIONS(1947),
    [anon_sym_const] = ACTIONS(1947),
    [anon_sym_constexpr] = ACTIONS(1947),
    [anon_sym_volatile] = ACTIONS(1947),
    [anon_sym_restrict] = ACTIONS(1947),
    [anon_sym___restrict__] = ACTIONS(1947),
    [anon_sym__Atomic] = ACTIONS(1947),
    [anon_sym__Noreturn] = ACTIONS(1947),
    [anon_sym_noreturn] = ACTIONS(1947),
    [anon_sym_mutable] = ACTIONS(1947),
    [anon_sym_constinit] = ACTIONS(1947),
    [anon_sym_consteval] = ACTIONS(1947),
    [anon_sym_alignas] = ACTIONS(1947),
    [anon_sym__Alignas] = ACTIONS(1947),
    [sym_primitive_type] = ACTIONS(1947),
    [anon_sym_enum] = ACTIONS(1947),
    [anon_sym_class] = ACTIONS(1947),
    [anon_sym_struct] = ACTIONS(1947),
    [anon_sym_union] = ACTIONS(1947),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1947),
    [anon_sym_decltype] = ACTIONS(1947),
    [sym_virtual] = ACTIONS(1947),
    [anon_sym_explicit] = ACTIONS(1947),
    [anon_sym_typename] = ACTIONS(1947),
    [anon_sym_template] = ACTIONS(1947),
    [anon_sym_operator] = ACTIONS(1947),
    [anon_sym_friend] = ACTIONS(1947),
    [anon_sym_public] = ACTIONS(1947),
    [anon_sym_private] = ACTIONS(1947),
    [anon_sym_protected] = ACTIONS(1947),
    [anon_sym_using] = ACTIONS(1947),
    [anon_sym_static_assert] = ACTIONS(1947),
    [anon_sym_catch] = ACTIONS(1947),
    [anon_sym_precise] = ACTIONS(1947),
    [anon_sym_shared] = ACTIONS(1947),
    [anon_sym_groupshared] = ACTIONS(1947),
    [anon_sym_uniform] = ACTIONS(1947),
    [anon_sym_row_major] = ACTIONS(1947),
    [anon_sym_column_major] = ACTIONS(1947),
    [anon_sym_globallycoherent] = ACTIONS(1947),
    [anon_sym_centroid] = ACTIONS(1947),
    [anon_sym_noperspective] = ACTIONS(1947),
    [anon_sym_nointerpolation] = ACTIONS(1947),
    [anon_sym_sample] = ACTIONS(1947),
    [anon_sym_linear] = ACTIONS(1947),
    [anon_sym_snorm] = ACTIONS(1947),
    [anon_sym_unorm] = ACTIONS(1947),
    [anon_sym_point] = ACTIONS(1947),
    [anon_sym_line] = ACTIONS(1947),
    [anon_sym_triangleadj] = ACTIONS(1947),
    [anon_sym_lineadj] = ACTIONS(1947),
    [anon_sym_triangle] = ACTIONS(1947),
  },
  [1836] = {
    [sym_identifier] = ACTIONS(1931),
    [aux_sym_preproc_def_token1] = ACTIONS(1931),
    [aux_sym_preproc_if_token1] = ACTIONS(1931),
    [aux_sym_preproc_if_token2] = ACTIONS(1931),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1931),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1931),
    [aux_sym_preproc_else_token1] = ACTIONS(1931),
    [aux_sym_preproc_elif_token1] = ACTIONS(1931),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1931),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1931),
    [sym_preproc_directive] = ACTIONS(1931),
    [anon_sym_LPAREN2] = ACTIONS(1929),
    [anon_sym_TILDE] = ACTIONS(1929),
    [anon_sym_STAR] = ACTIONS(1929),
    [anon_sym_AMP_AMP] = ACTIONS(1929),
    [anon_sym_AMP] = ACTIONS(1931),
    [anon_sym___extension__] = ACTIONS(1931),
    [anon_sym_typedef] = ACTIONS(1931),
    [anon_sym_in] = ACTIONS(1931),
    [anon_sym_out] = ACTIONS(1931),
    [anon_sym_inout] = ACTIONS(1931),
    [anon_sym_extern] = ACTIONS(1931),
    [anon_sym___attribute__] = ACTIONS(1931),
    [anon_sym_COLON_COLON] = ACTIONS(1929),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1929),
    [anon_sym___declspec] = ACTIONS(1931),
    [anon_sym___based] = ACTIONS(1931),
    [anon_sym_signed] = ACTIONS(1931),
    [anon_sym_unsigned] = ACTIONS(1931),
    [anon_sym_long] = ACTIONS(1931),
    [anon_sym_short] = ACTIONS(1931),
    [anon_sym_LBRACK] = ACTIONS(1931),
    [anon_sym_static] = ACTIONS(1931),
    [anon_sym_register] = ACTIONS(1931),
    [anon_sym_inline] = ACTIONS(1931),
    [anon_sym___inline] = ACTIONS(1931),
    [anon_sym___inline__] = ACTIONS(1931),
    [anon_sym___forceinline] = ACTIONS(1931),
    [anon_sym_thread_local] = ACTIONS(1931),
    [anon_sym___thread] = ACTIONS(1931),
    [anon_sym_const] = ACTIONS(1931),
    [anon_sym_constexpr] = ACTIONS(1931),
    [anon_sym_volatile] = ACTIONS(1931),
    [anon_sym_restrict] = ACTIONS(1931),
    [anon_sym___restrict__] = ACTIONS(1931),
    [anon_sym__Atomic] = ACTIONS(1931),
    [anon_sym__Noreturn] = ACTIONS(1931),
    [anon_sym_noreturn] = ACTIONS(1931),
    [anon_sym_mutable] = ACTIONS(1931),
    [anon_sym_constinit] = ACTIONS(1931),
    [anon_sym_consteval] = ACTIONS(1931),
    [anon_sym_alignas] = ACTIONS(1931),
    [anon_sym__Alignas] = ACTIONS(1931),
    [sym_primitive_type] = ACTIONS(1931),
    [anon_sym_enum] = ACTIONS(1931),
    [anon_sym_class] = ACTIONS(1931),
    [anon_sym_struct] = ACTIONS(1931),
    [anon_sym_union] = ACTIONS(1931),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1931),
    [anon_sym_decltype] = ACTIONS(1931),
    [sym_virtual] = ACTIONS(1931),
    [anon_sym_explicit] = ACTIONS(1931),
    [anon_sym_typename] = ACTIONS(1931),
    [anon_sym_template] = ACTIONS(1931),
    [anon_sym_operator] = ACTIONS(1931),
    [anon_sym_friend] = ACTIONS(1931),
    [anon_sym_public] = ACTIONS(1931),
    [anon_sym_private] = ACTIONS(1931),
    [anon_sym_protected] = ACTIONS(1931),
    [anon_sym_using] = ACTIONS(1931),
    [anon_sym_static_assert] = ACTIONS(1931),
    [anon_sym_catch] = ACTIONS(1931),
    [anon_sym_precise] = ACTIONS(1931),
    [anon_sym_shared] = ACTIONS(1931),
    [anon_sym_groupshared] = ACTIONS(1931),
    [anon_sym_uniform] = ACTIONS(1931),
    [anon_sym_row_major] = ACTIONS(1931),
    [anon_sym_column_major] = ACTIONS(1931),
    [anon_sym_globallycoherent] = ACTIONS(1931),
    [anon_sym_centroid] = ACTIONS(1931),
    [anon_sym_noperspective] = ACTIONS(1931),
    [anon_sym_nointerpolation] = ACTIONS(1931),
    [anon_sym_sample] = ACTIONS(1931),
    [anon_sym_linear] = ACTIONS(1931),
    [anon_sym_snorm] = ACTIONS(1931),
    [anon_sym_unorm] = ACTIONS(1931),
    [anon_sym_point] = ACTIONS(1931),
    [anon_sym_line] = ACTIONS(1931),
    [anon_sym_triangleadj] = ACTIONS(1931),
    [anon_sym_lineadj] = ACTIONS(1931),
    [anon_sym_triangle] = ACTIONS(1931),
  },
  [1837] = {
    [sym_identifier] = ACTIONS(5001),
    [aux_sym_preproc_def_token1] = ACTIONS(5001),
    [aux_sym_preproc_if_token1] = ACTIONS(5001),
    [aux_sym_preproc_if_token2] = ACTIONS(5001),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5001),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5001),
    [aux_sym_preproc_else_token1] = ACTIONS(5001),
    [aux_sym_preproc_elif_token1] = ACTIONS(5001),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5001),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5001),
    [sym_preproc_directive] = ACTIONS(5001),
    [anon_sym_LPAREN2] = ACTIONS(5003),
    [anon_sym_TILDE] = ACTIONS(5003),
    [anon_sym_STAR] = ACTIONS(5003),
    [anon_sym_AMP_AMP] = ACTIONS(5003),
    [anon_sym_AMP] = ACTIONS(5001),
    [anon_sym___extension__] = ACTIONS(5001),
    [anon_sym_typedef] = ACTIONS(5001),
    [anon_sym_in] = ACTIONS(5001),
    [anon_sym_out] = ACTIONS(5001),
    [anon_sym_inout] = ACTIONS(5001),
    [anon_sym_extern] = ACTIONS(5001),
    [anon_sym___attribute__] = ACTIONS(5001),
    [anon_sym_COLON_COLON] = ACTIONS(5003),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5003),
    [anon_sym___declspec] = ACTIONS(5001),
    [anon_sym___based] = ACTIONS(5001),
    [anon_sym_signed] = ACTIONS(5001),
    [anon_sym_unsigned] = ACTIONS(5001),
    [anon_sym_long] = ACTIONS(5001),
    [anon_sym_short] = ACTIONS(5001),
    [anon_sym_LBRACK] = ACTIONS(5001),
    [anon_sym_static] = ACTIONS(5001),
    [anon_sym_register] = ACTIONS(5001),
    [anon_sym_inline] = ACTIONS(5001),
    [anon_sym___inline] = ACTIONS(5001),
    [anon_sym___inline__] = ACTIONS(5001),
    [anon_sym___forceinline] = ACTIONS(5001),
    [anon_sym_thread_local] = ACTIONS(5001),
    [anon_sym___thread] = ACTIONS(5001),
    [anon_sym_const] = ACTIONS(5001),
    [anon_sym_constexpr] = ACTIONS(5001),
    [anon_sym_volatile] = ACTIONS(5001),
    [anon_sym_restrict] = ACTIONS(5001),
    [anon_sym___restrict__] = ACTIONS(5001),
    [anon_sym__Atomic] = ACTIONS(5001),
    [anon_sym__Noreturn] = ACTIONS(5001),
    [anon_sym_noreturn] = ACTIONS(5001),
    [anon_sym_mutable] = ACTIONS(5001),
    [anon_sym_constinit] = ACTIONS(5001),
    [anon_sym_consteval] = ACTIONS(5001),
    [anon_sym_alignas] = ACTIONS(5001),
    [anon_sym__Alignas] = ACTIONS(5001),
    [sym_primitive_type] = ACTIONS(5001),
    [anon_sym_enum] = ACTIONS(5001),
    [anon_sym_class] = ACTIONS(5001),
    [anon_sym_struct] = ACTIONS(5001),
    [anon_sym_union] = ACTIONS(5001),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5001),
    [anon_sym_decltype] = ACTIONS(5001),
    [sym_virtual] = ACTIONS(5001),
    [anon_sym_explicit] = ACTIONS(5001),
    [anon_sym_typename] = ACTIONS(5001),
    [anon_sym_template] = ACTIONS(5001),
    [anon_sym_operator] = ACTIONS(5001),
    [anon_sym_friend] = ACTIONS(5001),
    [anon_sym_public] = ACTIONS(5001),
    [anon_sym_private] = ACTIONS(5001),
    [anon_sym_protected] = ACTIONS(5001),
    [anon_sym_using] = ACTIONS(5001),
    [anon_sym_static_assert] = ACTIONS(5001),
    [anon_sym_precise] = ACTIONS(5001),
    [anon_sym_shared] = ACTIONS(5001),
    [anon_sym_groupshared] = ACTIONS(5001),
    [anon_sym_uniform] = ACTIONS(5001),
    [anon_sym_row_major] = ACTIONS(5001),
    [anon_sym_column_major] = ACTIONS(5001),
    [anon_sym_globallycoherent] = ACTIONS(5001),
    [anon_sym_centroid] = ACTIONS(5001),
    [anon_sym_noperspective] = ACTIONS(5001),
    [anon_sym_nointerpolation] = ACTIONS(5001),
    [anon_sym_sample] = ACTIONS(5001),
    [anon_sym_linear] = ACTIONS(5001),
    [anon_sym_snorm] = ACTIONS(5001),
    [anon_sym_unorm] = ACTIONS(5001),
    [anon_sym_point] = ACTIONS(5001),
    [anon_sym_line] = ACTIONS(5001),
    [anon_sym_triangleadj] = ACTIONS(5001),
    [anon_sym_lineadj] = ACTIONS(5001),
    [anon_sym_triangle] = ACTIONS(5001),
  },
  [1838] = {
    [sym_identifier] = ACTIONS(2440),
    [aux_sym_preproc_def_token1] = ACTIONS(2440),
    [aux_sym_preproc_if_token1] = ACTIONS(2440),
    [aux_sym_preproc_if_token2] = ACTIONS(2440),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2440),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2440),
    [aux_sym_preproc_else_token1] = ACTIONS(2440),
    [aux_sym_preproc_elif_token1] = ACTIONS(2440),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2440),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2440),
    [sym_preproc_directive] = ACTIONS(2440),
    [anon_sym_LPAREN2] = ACTIONS(2442),
    [anon_sym_TILDE] = ACTIONS(2442),
    [anon_sym_STAR] = ACTIONS(2442),
    [anon_sym_AMP_AMP] = ACTIONS(2442),
    [anon_sym_AMP] = ACTIONS(2440),
    [anon_sym___extension__] = ACTIONS(2440),
    [anon_sym_typedef] = ACTIONS(2440),
    [anon_sym_in] = ACTIONS(2440),
    [anon_sym_out] = ACTIONS(2440),
    [anon_sym_inout] = ACTIONS(2440),
    [anon_sym_extern] = ACTIONS(2440),
    [anon_sym___attribute__] = ACTIONS(2440),
    [anon_sym_COLON_COLON] = ACTIONS(2442),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2442),
    [anon_sym___declspec] = ACTIONS(2440),
    [anon_sym___based] = ACTIONS(2440),
    [anon_sym_signed] = ACTIONS(2440),
    [anon_sym_unsigned] = ACTIONS(2440),
    [anon_sym_long] = ACTIONS(2440),
    [anon_sym_short] = ACTIONS(2440),
    [anon_sym_LBRACK] = ACTIONS(2440),
    [anon_sym_static] = ACTIONS(2440),
    [anon_sym_register] = ACTIONS(2440),
    [anon_sym_inline] = ACTIONS(2440),
    [anon_sym___inline] = ACTIONS(2440),
    [anon_sym___inline__] = ACTIONS(2440),
    [anon_sym___forceinline] = ACTIONS(2440),
    [anon_sym_thread_local] = ACTIONS(2440),
    [anon_sym___thread] = ACTIONS(2440),
    [anon_sym_const] = ACTIONS(2440),
    [anon_sym_constexpr] = ACTIONS(2440),
    [anon_sym_volatile] = ACTIONS(2440),
    [anon_sym_restrict] = ACTIONS(2440),
    [anon_sym___restrict__] = ACTIONS(2440),
    [anon_sym__Atomic] = ACTIONS(2440),
    [anon_sym__Noreturn] = ACTIONS(2440),
    [anon_sym_noreturn] = ACTIONS(2440),
    [anon_sym_mutable] = ACTIONS(2440),
    [anon_sym_constinit] = ACTIONS(2440),
    [anon_sym_consteval] = ACTIONS(2440),
    [anon_sym_alignas] = ACTIONS(2440),
    [anon_sym__Alignas] = ACTIONS(2440),
    [sym_primitive_type] = ACTIONS(2440),
    [anon_sym_enum] = ACTIONS(2440),
    [anon_sym_class] = ACTIONS(2440),
    [anon_sym_struct] = ACTIONS(2440),
    [anon_sym_union] = ACTIONS(2440),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2440),
    [anon_sym_decltype] = ACTIONS(2440),
    [sym_virtual] = ACTIONS(2440),
    [anon_sym_explicit] = ACTIONS(2440),
    [anon_sym_typename] = ACTIONS(2440),
    [anon_sym_template] = ACTIONS(2440),
    [anon_sym_operator] = ACTIONS(2440),
    [anon_sym_friend] = ACTIONS(2440),
    [anon_sym_public] = ACTIONS(2440),
    [anon_sym_private] = ACTIONS(2440),
    [anon_sym_protected] = ACTIONS(2440),
    [anon_sym_using] = ACTIONS(2440),
    [anon_sym_static_assert] = ACTIONS(2440),
    [anon_sym_precise] = ACTIONS(2440),
    [anon_sym_shared] = ACTIONS(2440),
    [anon_sym_groupshared] = ACTIONS(2440),
    [anon_sym_uniform] = ACTIONS(2440),
    [anon_sym_row_major] = ACTIONS(2440),
    [anon_sym_column_major] = ACTIONS(2440),
    [anon_sym_globallycoherent] = ACTIONS(2440),
    [anon_sym_centroid] = ACTIONS(2440),
    [anon_sym_noperspective] = ACTIONS(2440),
    [anon_sym_nointerpolation] = ACTIONS(2440),
    [anon_sym_sample] = ACTIONS(2440),
    [anon_sym_linear] = ACTIONS(2440),
    [anon_sym_snorm] = ACTIONS(2440),
    [anon_sym_unorm] = ACTIONS(2440),
    [anon_sym_point] = ACTIONS(2440),
    [anon_sym_line] = ACTIONS(2440),
    [anon_sym_triangleadj] = ACTIONS(2440),
    [anon_sym_lineadj] = ACTIONS(2440),
    [anon_sym_triangle] = ACTIONS(2440),
  },
  [1839] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token2] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [aux_sym_preproc_else_token1] = ACTIONS(2324),
    [aux_sym_preproc_elif_token1] = ACTIONS(2324),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_friend] = ACTIONS(2324),
    [anon_sym_public] = ACTIONS(2324),
    [anon_sym_private] = ACTIONS(2324),
    [anon_sym_protected] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
  },
  [1840] = {
    [sym_identifier] = ACTIONS(2276),
    [aux_sym_preproc_def_token1] = ACTIONS(2276),
    [aux_sym_preproc_if_token1] = ACTIONS(2276),
    [aux_sym_preproc_if_token2] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2276),
    [aux_sym_preproc_else_token1] = ACTIONS(2276),
    [aux_sym_preproc_elif_token1] = ACTIONS(2276),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2276),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2276),
    [sym_preproc_directive] = ACTIONS(2276),
    [anon_sym_LPAREN2] = ACTIONS(2278),
    [anon_sym_TILDE] = ACTIONS(2278),
    [anon_sym_STAR] = ACTIONS(2278),
    [anon_sym_AMP_AMP] = ACTIONS(2278),
    [anon_sym_AMP] = ACTIONS(2276),
    [anon_sym___extension__] = ACTIONS(2276),
    [anon_sym_typedef] = ACTIONS(2276),
    [anon_sym_in] = ACTIONS(2276),
    [anon_sym_out] = ACTIONS(2276),
    [anon_sym_inout] = ACTIONS(2276),
    [anon_sym_extern] = ACTIONS(2276),
    [anon_sym___attribute__] = ACTIONS(2276),
    [anon_sym_COLON_COLON] = ACTIONS(2278),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2278),
    [anon_sym___declspec] = ACTIONS(2276),
    [anon_sym___based] = ACTIONS(2276),
    [anon_sym_signed] = ACTIONS(2276),
    [anon_sym_unsigned] = ACTIONS(2276),
    [anon_sym_long] = ACTIONS(2276),
    [anon_sym_short] = ACTIONS(2276),
    [anon_sym_LBRACK] = ACTIONS(2276),
    [anon_sym_static] = ACTIONS(2276),
    [anon_sym_register] = ACTIONS(2276),
    [anon_sym_inline] = ACTIONS(2276),
    [anon_sym___inline] = ACTIONS(2276),
    [anon_sym___inline__] = ACTIONS(2276),
    [anon_sym___forceinline] = ACTIONS(2276),
    [anon_sym_thread_local] = ACTIONS(2276),
    [anon_sym___thread] = ACTIONS(2276),
    [anon_sym_const] = ACTIONS(2276),
    [anon_sym_constexpr] = ACTIONS(2276),
    [anon_sym_volatile] = ACTIONS(2276),
    [anon_sym_restrict] = ACTIONS(2276),
    [anon_sym___restrict__] = ACTIONS(2276),
    [anon_sym__Atomic] = ACTIONS(2276),
    [anon_sym__Noreturn] = ACTIONS(2276),
    [anon_sym_noreturn] = ACTIONS(2276),
    [anon_sym_mutable] = ACTIONS(2276),
    [anon_sym_constinit] = ACTIONS(2276),
    [anon_sym_consteval] = ACTIONS(2276),
    [anon_sym_alignas] = ACTIONS(2276),
    [anon_sym__Alignas] = ACTIONS(2276),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2276),
    [anon_sym_class] = ACTIONS(2276),
    [anon_sym_struct] = ACTIONS(2276),
    [anon_sym_union] = ACTIONS(2276),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2276),
    [anon_sym_decltype] = ACTIONS(2276),
    [sym_virtual] = ACTIONS(2276),
    [anon_sym_explicit] = ACTIONS(2276),
    [anon_sym_typename] = ACTIONS(2276),
    [anon_sym_template] = ACTIONS(2276),
    [anon_sym_operator] = ACTIONS(2276),
    [anon_sym_friend] = ACTIONS(2276),
    [anon_sym_public] = ACTIONS(2276),
    [anon_sym_private] = ACTIONS(2276),
    [anon_sym_protected] = ACTIONS(2276),
    [anon_sym_using] = ACTIONS(2276),
    [anon_sym_static_assert] = ACTIONS(2276),
    [anon_sym_precise] = ACTIONS(2276),
    [anon_sym_shared] = ACTIONS(2276),
    [anon_sym_groupshared] = ACTIONS(2276),
    [anon_sym_uniform] = ACTIONS(2276),
    [anon_sym_row_major] = ACTIONS(2276),
    [anon_sym_column_major] = ACTIONS(2276),
    [anon_sym_globallycoherent] = ACTIONS(2276),
    [anon_sym_centroid] = ACTIONS(2276),
    [anon_sym_noperspective] = ACTIONS(2276),
    [anon_sym_nointerpolation] = ACTIONS(2276),
    [anon_sym_sample] = ACTIONS(2276),
    [anon_sym_linear] = ACTIONS(2276),
    [anon_sym_snorm] = ACTIONS(2276),
    [anon_sym_unorm] = ACTIONS(2276),
    [anon_sym_point] = ACTIONS(2276),
    [anon_sym_line] = ACTIONS(2276),
    [anon_sym_triangleadj] = ACTIONS(2276),
    [anon_sym_lineadj] = ACTIONS(2276),
    [anon_sym_triangle] = ACTIONS(2276),
  },
  [1841] = {
    [sym_identifier] = ACTIONS(2276),
    [aux_sym_preproc_def_token1] = ACTIONS(2276),
    [aux_sym_preproc_if_token1] = ACTIONS(2276),
    [aux_sym_preproc_if_token2] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2276),
    [aux_sym_preproc_else_token1] = ACTIONS(2276),
    [aux_sym_preproc_elif_token1] = ACTIONS(2276),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2276),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2276),
    [sym_preproc_directive] = ACTIONS(2276),
    [anon_sym_LPAREN2] = ACTIONS(2278),
    [anon_sym_TILDE] = ACTIONS(2278),
    [anon_sym_STAR] = ACTIONS(2278),
    [anon_sym_AMP_AMP] = ACTIONS(2278),
    [anon_sym_AMP] = ACTIONS(2276),
    [anon_sym___extension__] = ACTIONS(2276),
    [anon_sym_typedef] = ACTIONS(2276),
    [anon_sym_in] = ACTIONS(2276),
    [anon_sym_out] = ACTIONS(2276),
    [anon_sym_inout] = ACTIONS(2276),
    [anon_sym_extern] = ACTIONS(2276),
    [anon_sym___attribute__] = ACTIONS(2276),
    [anon_sym_COLON_COLON] = ACTIONS(2278),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2278),
    [anon_sym___declspec] = ACTIONS(2276),
    [anon_sym___based] = ACTIONS(2276),
    [anon_sym_signed] = ACTIONS(2276),
    [anon_sym_unsigned] = ACTIONS(2276),
    [anon_sym_long] = ACTIONS(2276),
    [anon_sym_short] = ACTIONS(2276),
    [anon_sym_LBRACK] = ACTIONS(2276),
    [anon_sym_static] = ACTIONS(2276),
    [anon_sym_register] = ACTIONS(2276),
    [anon_sym_inline] = ACTIONS(2276),
    [anon_sym___inline] = ACTIONS(2276),
    [anon_sym___inline__] = ACTIONS(2276),
    [anon_sym___forceinline] = ACTIONS(2276),
    [anon_sym_thread_local] = ACTIONS(2276),
    [anon_sym___thread] = ACTIONS(2276),
    [anon_sym_const] = ACTIONS(2276),
    [anon_sym_constexpr] = ACTIONS(2276),
    [anon_sym_volatile] = ACTIONS(2276),
    [anon_sym_restrict] = ACTIONS(2276),
    [anon_sym___restrict__] = ACTIONS(2276),
    [anon_sym__Atomic] = ACTIONS(2276),
    [anon_sym__Noreturn] = ACTIONS(2276),
    [anon_sym_noreturn] = ACTIONS(2276),
    [anon_sym_mutable] = ACTIONS(2276),
    [anon_sym_constinit] = ACTIONS(2276),
    [anon_sym_consteval] = ACTIONS(2276),
    [anon_sym_alignas] = ACTIONS(2276),
    [anon_sym__Alignas] = ACTIONS(2276),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2276),
    [anon_sym_class] = ACTIONS(2276),
    [anon_sym_struct] = ACTIONS(2276),
    [anon_sym_union] = ACTIONS(2276),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2276),
    [anon_sym_decltype] = ACTIONS(2276),
    [sym_virtual] = ACTIONS(2276),
    [anon_sym_explicit] = ACTIONS(2276),
    [anon_sym_typename] = ACTIONS(2276),
    [anon_sym_template] = ACTIONS(2276),
    [anon_sym_operator] = ACTIONS(2276),
    [anon_sym_friend] = ACTIONS(2276),
    [anon_sym_public] = ACTIONS(2276),
    [anon_sym_private] = ACTIONS(2276),
    [anon_sym_protected] = ACTIONS(2276),
    [anon_sym_using] = ACTIONS(2276),
    [anon_sym_static_assert] = ACTIONS(2276),
    [anon_sym_precise] = ACTIONS(2276),
    [anon_sym_shared] = ACTIONS(2276),
    [anon_sym_groupshared] = ACTIONS(2276),
    [anon_sym_uniform] = ACTIONS(2276),
    [anon_sym_row_major] = ACTIONS(2276),
    [anon_sym_column_major] = ACTIONS(2276),
    [anon_sym_globallycoherent] = ACTIONS(2276),
    [anon_sym_centroid] = ACTIONS(2276),
    [anon_sym_noperspective] = ACTIONS(2276),
    [anon_sym_nointerpolation] = ACTIONS(2276),
    [anon_sym_sample] = ACTIONS(2276),
    [anon_sym_linear] = ACTIONS(2276),
    [anon_sym_snorm] = ACTIONS(2276),
    [anon_sym_unorm] = ACTIONS(2276),
    [anon_sym_point] = ACTIONS(2276),
    [anon_sym_line] = ACTIONS(2276),
    [anon_sym_triangleadj] = ACTIONS(2276),
    [anon_sym_lineadj] = ACTIONS(2276),
    [anon_sym_triangle] = ACTIONS(2276),
  },
  [1842] = {
    [sym_identifier] = ACTIONS(5005),
    [aux_sym_preproc_def_token1] = ACTIONS(5005),
    [aux_sym_preproc_if_token1] = ACTIONS(5005),
    [aux_sym_preproc_if_token2] = ACTIONS(5005),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5005),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5005),
    [aux_sym_preproc_else_token1] = ACTIONS(5005),
    [aux_sym_preproc_elif_token1] = ACTIONS(5005),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5005),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5005),
    [sym_preproc_directive] = ACTIONS(5005),
    [anon_sym_LPAREN2] = ACTIONS(5007),
    [anon_sym_TILDE] = ACTIONS(5007),
    [anon_sym_STAR] = ACTIONS(5007),
    [anon_sym_AMP_AMP] = ACTIONS(5007),
    [anon_sym_AMP] = ACTIONS(5005),
    [anon_sym___extension__] = ACTIONS(5005),
    [anon_sym_typedef] = ACTIONS(5005),
    [anon_sym_in] = ACTIONS(5005),
    [anon_sym_out] = ACTIONS(5005),
    [anon_sym_inout] = ACTIONS(5005),
    [anon_sym_extern] = ACTIONS(5005),
    [anon_sym___attribute__] = ACTIONS(5005),
    [anon_sym_COLON_COLON] = ACTIONS(5007),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5007),
    [anon_sym___declspec] = ACTIONS(5005),
    [anon_sym___based] = ACTIONS(5005),
    [anon_sym_signed] = ACTIONS(5005),
    [anon_sym_unsigned] = ACTIONS(5005),
    [anon_sym_long] = ACTIONS(5005),
    [anon_sym_short] = ACTIONS(5005),
    [anon_sym_LBRACK] = ACTIONS(5005),
    [anon_sym_static] = ACTIONS(5005),
    [anon_sym_register] = ACTIONS(5005),
    [anon_sym_inline] = ACTIONS(5005),
    [anon_sym___inline] = ACTIONS(5005),
    [anon_sym___inline__] = ACTIONS(5005),
    [anon_sym___forceinline] = ACTIONS(5005),
    [anon_sym_thread_local] = ACTIONS(5005),
    [anon_sym___thread] = ACTIONS(5005),
    [anon_sym_const] = ACTIONS(5005),
    [anon_sym_constexpr] = ACTIONS(5005),
    [anon_sym_volatile] = ACTIONS(5005),
    [anon_sym_restrict] = ACTIONS(5005),
    [anon_sym___restrict__] = ACTIONS(5005),
    [anon_sym__Atomic] = ACTIONS(5005),
    [anon_sym__Noreturn] = ACTIONS(5005),
    [anon_sym_noreturn] = ACTIONS(5005),
    [anon_sym_mutable] = ACTIONS(5005),
    [anon_sym_constinit] = ACTIONS(5005),
    [anon_sym_consteval] = ACTIONS(5005),
    [anon_sym_alignas] = ACTIONS(5005),
    [anon_sym__Alignas] = ACTIONS(5005),
    [sym_primitive_type] = ACTIONS(5005),
    [anon_sym_enum] = ACTIONS(5005),
    [anon_sym_class] = ACTIONS(5005),
    [anon_sym_struct] = ACTIONS(5005),
    [anon_sym_union] = ACTIONS(5005),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5005),
    [anon_sym_decltype] = ACTIONS(5005),
    [sym_virtual] = ACTIONS(5005),
    [anon_sym_explicit] = ACTIONS(5005),
    [anon_sym_typename] = ACTIONS(5005),
    [anon_sym_template] = ACTIONS(5005),
    [anon_sym_operator] = ACTIONS(5005),
    [anon_sym_friend] = ACTIONS(5005),
    [anon_sym_public] = ACTIONS(5005),
    [anon_sym_private] = ACTIONS(5005),
    [anon_sym_protected] = ACTIONS(5005),
    [anon_sym_using] = ACTIONS(5005),
    [anon_sym_static_assert] = ACTIONS(5005),
    [anon_sym_precise] = ACTIONS(5005),
    [anon_sym_shared] = ACTIONS(5005),
    [anon_sym_groupshared] = ACTIONS(5005),
    [anon_sym_uniform] = ACTIONS(5005),
    [anon_sym_row_major] = ACTIONS(5005),
    [anon_sym_column_major] = ACTIONS(5005),
    [anon_sym_globallycoherent] = ACTIONS(5005),
    [anon_sym_centroid] = ACTIONS(5005),
    [anon_sym_noperspective] = ACTIONS(5005),
    [anon_sym_nointerpolation] = ACTIONS(5005),
    [anon_sym_sample] = ACTIONS(5005),
    [anon_sym_linear] = ACTIONS(5005),
    [anon_sym_snorm] = ACTIONS(5005),
    [anon_sym_unorm] = ACTIONS(5005),
    [anon_sym_point] = ACTIONS(5005),
    [anon_sym_line] = ACTIONS(5005),
    [anon_sym_triangleadj] = ACTIONS(5005),
    [anon_sym_lineadj] = ACTIONS(5005),
    [anon_sym_triangle] = ACTIONS(5005),
  },
  [1843] = {
    [sym_identifier] = ACTIONS(2328),
    [aux_sym_preproc_def_token1] = ACTIONS(2328),
    [aux_sym_preproc_if_token1] = ACTIONS(2328),
    [aux_sym_preproc_if_token2] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2328),
    [aux_sym_preproc_else_token1] = ACTIONS(2328),
    [aux_sym_preproc_elif_token1] = ACTIONS(2328),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2328),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2328),
    [sym_preproc_directive] = ACTIONS(2328),
    [anon_sym_LPAREN2] = ACTIONS(2330),
    [anon_sym_TILDE] = ACTIONS(2330),
    [anon_sym_STAR] = ACTIONS(2330),
    [anon_sym_AMP_AMP] = ACTIONS(2330),
    [anon_sym_AMP] = ACTIONS(2328),
    [anon_sym___extension__] = ACTIONS(2328),
    [anon_sym_typedef] = ACTIONS(2328),
    [anon_sym_in] = ACTIONS(2328),
    [anon_sym_out] = ACTIONS(2328),
    [anon_sym_inout] = ACTIONS(2328),
    [anon_sym_extern] = ACTIONS(2328),
    [anon_sym___attribute__] = ACTIONS(2328),
    [anon_sym_COLON_COLON] = ACTIONS(2330),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2330),
    [anon_sym___declspec] = ACTIONS(2328),
    [anon_sym___based] = ACTIONS(2328),
    [anon_sym_signed] = ACTIONS(2328),
    [anon_sym_unsigned] = ACTIONS(2328),
    [anon_sym_long] = ACTIONS(2328),
    [anon_sym_short] = ACTIONS(2328),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_static] = ACTIONS(2328),
    [anon_sym_register] = ACTIONS(2328),
    [anon_sym_inline] = ACTIONS(2328),
    [anon_sym___inline] = ACTIONS(2328),
    [anon_sym___inline__] = ACTIONS(2328),
    [anon_sym___forceinline] = ACTIONS(2328),
    [anon_sym_thread_local] = ACTIONS(2328),
    [anon_sym___thread] = ACTIONS(2328),
    [anon_sym_const] = ACTIONS(2328),
    [anon_sym_constexpr] = ACTIONS(2328),
    [anon_sym_volatile] = ACTIONS(2328),
    [anon_sym_restrict] = ACTIONS(2328),
    [anon_sym___restrict__] = ACTIONS(2328),
    [anon_sym__Atomic] = ACTIONS(2328),
    [anon_sym__Noreturn] = ACTIONS(2328),
    [anon_sym_noreturn] = ACTIONS(2328),
    [anon_sym_mutable] = ACTIONS(2328),
    [anon_sym_constinit] = ACTIONS(2328),
    [anon_sym_consteval] = ACTIONS(2328),
    [anon_sym_alignas] = ACTIONS(2328),
    [anon_sym__Alignas] = ACTIONS(2328),
    [sym_primitive_type] = ACTIONS(2328),
    [anon_sym_enum] = ACTIONS(2328),
    [anon_sym_class] = ACTIONS(2328),
    [anon_sym_struct] = ACTIONS(2328),
    [anon_sym_union] = ACTIONS(2328),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2328),
    [anon_sym_decltype] = ACTIONS(2328),
    [sym_virtual] = ACTIONS(2328),
    [anon_sym_explicit] = ACTIONS(2328),
    [anon_sym_typename] = ACTIONS(2328),
    [anon_sym_template] = ACTIONS(2328),
    [anon_sym_operator] = ACTIONS(2328),
    [anon_sym_friend] = ACTIONS(2328),
    [anon_sym_public] = ACTIONS(2328),
    [anon_sym_private] = ACTIONS(2328),
    [anon_sym_protected] = ACTIONS(2328),
    [anon_sym_using] = ACTIONS(2328),
    [anon_sym_static_assert] = ACTIONS(2328),
    [anon_sym_precise] = ACTIONS(2328),
    [anon_sym_shared] = ACTIONS(2328),
    [anon_sym_groupshared] = ACTIONS(2328),
    [anon_sym_uniform] = ACTIONS(2328),
    [anon_sym_row_major] = ACTIONS(2328),
    [anon_sym_column_major] = ACTIONS(2328),
    [anon_sym_globallycoherent] = ACTIONS(2328),
    [anon_sym_centroid] = ACTIONS(2328),
    [anon_sym_noperspective] = ACTIONS(2328),
    [anon_sym_nointerpolation] = ACTIONS(2328),
    [anon_sym_sample] = ACTIONS(2328),
    [anon_sym_linear] = ACTIONS(2328),
    [anon_sym_snorm] = ACTIONS(2328),
    [anon_sym_unorm] = ACTIONS(2328),
    [anon_sym_point] = ACTIONS(2328),
    [anon_sym_line] = ACTIONS(2328),
    [anon_sym_triangleadj] = ACTIONS(2328),
    [anon_sym_lineadj] = ACTIONS(2328),
    [anon_sym_triangle] = ACTIONS(2328),
  },
  [1844] = {
    [sym_identifier] = ACTIONS(2348),
    [aux_sym_preproc_def_token1] = ACTIONS(2348),
    [aux_sym_preproc_if_token1] = ACTIONS(2348),
    [aux_sym_preproc_if_token2] = ACTIONS(2348),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2348),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2348),
    [aux_sym_preproc_else_token1] = ACTIONS(2348),
    [aux_sym_preproc_elif_token1] = ACTIONS(2348),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2348),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2348),
    [sym_preproc_directive] = ACTIONS(2348),
    [anon_sym_LPAREN2] = ACTIONS(2350),
    [anon_sym_TILDE] = ACTIONS(2350),
    [anon_sym_STAR] = ACTIONS(2350),
    [anon_sym_AMP_AMP] = ACTIONS(2350),
    [anon_sym_AMP] = ACTIONS(2348),
    [anon_sym___extension__] = ACTIONS(2348),
    [anon_sym_typedef] = ACTIONS(2348),
    [anon_sym_in] = ACTIONS(2348),
    [anon_sym_out] = ACTIONS(2348),
    [anon_sym_inout] = ACTIONS(2348),
    [anon_sym_extern] = ACTIONS(2348),
    [anon_sym___attribute__] = ACTIONS(2348),
    [anon_sym_COLON_COLON] = ACTIONS(2350),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2350),
    [anon_sym___declspec] = ACTIONS(2348),
    [anon_sym___based] = ACTIONS(2348),
    [anon_sym_signed] = ACTIONS(2348),
    [anon_sym_unsigned] = ACTIONS(2348),
    [anon_sym_long] = ACTIONS(2348),
    [anon_sym_short] = ACTIONS(2348),
    [anon_sym_LBRACK] = ACTIONS(2348),
    [anon_sym_static] = ACTIONS(2348),
    [anon_sym_register] = ACTIONS(2348),
    [anon_sym_inline] = ACTIONS(2348),
    [anon_sym___inline] = ACTIONS(2348),
    [anon_sym___inline__] = ACTIONS(2348),
    [anon_sym___forceinline] = ACTIONS(2348),
    [anon_sym_thread_local] = ACTIONS(2348),
    [anon_sym___thread] = ACTIONS(2348),
    [anon_sym_const] = ACTIONS(2348),
    [anon_sym_constexpr] = ACTIONS(2348),
    [anon_sym_volatile] = ACTIONS(2348),
    [anon_sym_restrict] = ACTIONS(2348),
    [anon_sym___restrict__] = ACTIONS(2348),
    [anon_sym__Atomic] = ACTIONS(2348),
    [anon_sym__Noreturn] = ACTIONS(2348),
    [anon_sym_noreturn] = ACTIONS(2348),
    [anon_sym_mutable] = ACTIONS(2348),
    [anon_sym_constinit] = ACTIONS(2348),
    [anon_sym_consteval] = ACTIONS(2348),
    [anon_sym_alignas] = ACTIONS(2348),
    [anon_sym__Alignas] = ACTIONS(2348),
    [sym_primitive_type] = ACTIONS(2348),
    [anon_sym_enum] = ACTIONS(2348),
    [anon_sym_class] = ACTIONS(2348),
    [anon_sym_struct] = ACTIONS(2348),
    [anon_sym_union] = ACTIONS(2348),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2348),
    [anon_sym_decltype] = ACTIONS(2348),
    [sym_virtual] = ACTIONS(2348),
    [anon_sym_explicit] = ACTIONS(2348),
    [anon_sym_typename] = ACTIONS(2348),
    [anon_sym_template] = ACTIONS(2348),
    [anon_sym_operator] = ACTIONS(2348),
    [anon_sym_friend] = ACTIONS(2348),
    [anon_sym_public] = ACTIONS(2348),
    [anon_sym_private] = ACTIONS(2348),
    [anon_sym_protected] = ACTIONS(2348),
    [anon_sym_using] = ACTIONS(2348),
    [anon_sym_static_assert] = ACTIONS(2348),
    [anon_sym_precise] = ACTIONS(2348),
    [anon_sym_shared] = ACTIONS(2348),
    [anon_sym_groupshared] = ACTIONS(2348),
    [anon_sym_uniform] = ACTIONS(2348),
    [anon_sym_row_major] = ACTIONS(2348),
    [anon_sym_column_major] = ACTIONS(2348),
    [anon_sym_globallycoherent] = ACTIONS(2348),
    [anon_sym_centroid] = ACTIONS(2348),
    [anon_sym_noperspective] = ACTIONS(2348),
    [anon_sym_nointerpolation] = ACTIONS(2348),
    [anon_sym_sample] = ACTIONS(2348),
    [anon_sym_linear] = ACTIONS(2348),
    [anon_sym_snorm] = ACTIONS(2348),
    [anon_sym_unorm] = ACTIONS(2348),
    [anon_sym_point] = ACTIONS(2348),
    [anon_sym_line] = ACTIONS(2348),
    [anon_sym_triangleadj] = ACTIONS(2348),
    [anon_sym_lineadj] = ACTIONS(2348),
    [anon_sym_triangle] = ACTIONS(2348),
  },
  [1845] = {
    [sym_identifier] = ACTIONS(2320),
    [aux_sym_preproc_def_token1] = ACTIONS(2320),
    [aux_sym_preproc_if_token1] = ACTIONS(2320),
    [aux_sym_preproc_if_token2] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2320),
    [aux_sym_preproc_else_token1] = ACTIONS(2320),
    [aux_sym_preproc_elif_token1] = ACTIONS(2320),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2320),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2320),
    [sym_preproc_directive] = ACTIONS(2320),
    [anon_sym_LPAREN2] = ACTIONS(2322),
    [anon_sym_TILDE] = ACTIONS(2322),
    [anon_sym_STAR] = ACTIONS(2322),
    [anon_sym_AMP_AMP] = ACTIONS(2322),
    [anon_sym_AMP] = ACTIONS(2320),
    [anon_sym___extension__] = ACTIONS(2320),
    [anon_sym_typedef] = ACTIONS(2320),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_out] = ACTIONS(2320),
    [anon_sym_inout] = ACTIONS(2320),
    [anon_sym_extern] = ACTIONS(2320),
    [anon_sym___attribute__] = ACTIONS(2320),
    [anon_sym_COLON_COLON] = ACTIONS(2322),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2322),
    [anon_sym___declspec] = ACTIONS(2320),
    [anon_sym___based] = ACTIONS(2320),
    [anon_sym_signed] = ACTIONS(2320),
    [anon_sym_unsigned] = ACTIONS(2320),
    [anon_sym_long] = ACTIONS(2320),
    [anon_sym_short] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2320),
    [anon_sym_static] = ACTIONS(2320),
    [anon_sym_register] = ACTIONS(2320),
    [anon_sym_inline] = ACTIONS(2320),
    [anon_sym___inline] = ACTIONS(2320),
    [anon_sym___inline__] = ACTIONS(2320),
    [anon_sym___forceinline] = ACTIONS(2320),
    [anon_sym_thread_local] = ACTIONS(2320),
    [anon_sym___thread] = ACTIONS(2320),
    [anon_sym_const] = ACTIONS(2320),
    [anon_sym_constexpr] = ACTIONS(2320),
    [anon_sym_volatile] = ACTIONS(2320),
    [anon_sym_restrict] = ACTIONS(2320),
    [anon_sym___restrict__] = ACTIONS(2320),
    [anon_sym__Atomic] = ACTIONS(2320),
    [anon_sym__Noreturn] = ACTIONS(2320),
    [anon_sym_noreturn] = ACTIONS(2320),
    [anon_sym_mutable] = ACTIONS(2320),
    [anon_sym_constinit] = ACTIONS(2320),
    [anon_sym_consteval] = ACTIONS(2320),
    [anon_sym_alignas] = ACTIONS(2320),
    [anon_sym__Alignas] = ACTIONS(2320),
    [sym_primitive_type] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_class] = ACTIONS(2320),
    [anon_sym_struct] = ACTIONS(2320),
    [anon_sym_union] = ACTIONS(2320),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2320),
    [anon_sym_decltype] = ACTIONS(2320),
    [sym_virtual] = ACTIONS(2320),
    [anon_sym_explicit] = ACTIONS(2320),
    [anon_sym_typename] = ACTIONS(2320),
    [anon_sym_template] = ACTIONS(2320),
    [anon_sym_operator] = ACTIONS(2320),
    [anon_sym_friend] = ACTIONS(2320),
    [anon_sym_public] = ACTIONS(2320),
    [anon_sym_private] = ACTIONS(2320),
    [anon_sym_protected] = ACTIONS(2320),
    [anon_sym_using] = ACTIONS(2320),
    [anon_sym_static_assert] = ACTIONS(2320),
    [anon_sym_precise] = ACTIONS(2320),
    [anon_sym_shared] = ACTIONS(2320),
    [anon_sym_groupshared] = ACTIONS(2320),
    [anon_sym_uniform] = ACTIONS(2320),
    [anon_sym_row_major] = ACTIONS(2320),
    [anon_sym_column_major] = ACTIONS(2320),
    [anon_sym_globallycoherent] = ACTIONS(2320),
    [anon_sym_centroid] = ACTIONS(2320),
    [anon_sym_noperspective] = ACTIONS(2320),
    [anon_sym_nointerpolation] = ACTIONS(2320),
    [anon_sym_sample] = ACTIONS(2320),
    [anon_sym_linear] = ACTIONS(2320),
    [anon_sym_snorm] = ACTIONS(2320),
    [anon_sym_unorm] = ACTIONS(2320),
    [anon_sym_point] = ACTIONS(2320),
    [anon_sym_line] = ACTIONS(2320),
    [anon_sym_triangleadj] = ACTIONS(2320),
    [anon_sym_lineadj] = ACTIONS(2320),
    [anon_sym_triangle] = ACTIONS(2320),
  },
  [1846] = {
    [sym_identifier] = ACTIONS(2272),
    [aux_sym_preproc_def_token1] = ACTIONS(2272),
    [aux_sym_preproc_if_token1] = ACTIONS(2272),
    [aux_sym_preproc_if_token2] = ACTIONS(2272),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2272),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2272),
    [aux_sym_preproc_else_token1] = ACTIONS(2272),
    [aux_sym_preproc_elif_token1] = ACTIONS(2272),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2272),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2272),
    [sym_preproc_directive] = ACTIONS(2272),
    [anon_sym_LPAREN2] = ACTIONS(2274),
    [anon_sym_TILDE] = ACTIONS(2274),
    [anon_sym_STAR] = ACTIONS(2274),
    [anon_sym_AMP_AMP] = ACTIONS(2274),
    [anon_sym_AMP] = ACTIONS(2272),
    [anon_sym___extension__] = ACTIONS(2272),
    [anon_sym_typedef] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2272),
    [anon_sym_out] = ACTIONS(2272),
    [anon_sym_inout] = ACTIONS(2272),
    [anon_sym_extern] = ACTIONS(2272),
    [anon_sym___attribute__] = ACTIONS(2272),
    [anon_sym_COLON_COLON] = ACTIONS(2274),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2274),
    [anon_sym___declspec] = ACTIONS(2272),
    [anon_sym___based] = ACTIONS(2272),
    [anon_sym_signed] = ACTIONS(2272),
    [anon_sym_unsigned] = ACTIONS(2272),
    [anon_sym_long] = ACTIONS(2272),
    [anon_sym_short] = ACTIONS(2272),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(2272),
    [anon_sym_register] = ACTIONS(2272),
    [anon_sym_inline] = ACTIONS(2272),
    [anon_sym___inline] = ACTIONS(2272),
    [anon_sym___inline__] = ACTIONS(2272),
    [anon_sym___forceinline] = ACTIONS(2272),
    [anon_sym_thread_local] = ACTIONS(2272),
    [anon_sym___thread] = ACTIONS(2272),
    [anon_sym_const] = ACTIONS(2272),
    [anon_sym_constexpr] = ACTIONS(2272),
    [anon_sym_volatile] = ACTIONS(2272),
    [anon_sym_restrict] = ACTIONS(2272),
    [anon_sym___restrict__] = ACTIONS(2272),
    [anon_sym__Atomic] = ACTIONS(2272),
    [anon_sym__Noreturn] = ACTIONS(2272),
    [anon_sym_noreturn] = ACTIONS(2272),
    [anon_sym_mutable] = ACTIONS(2272),
    [anon_sym_constinit] = ACTIONS(2272),
    [anon_sym_consteval] = ACTIONS(2272),
    [anon_sym_alignas] = ACTIONS(2272),
    [anon_sym__Alignas] = ACTIONS(2272),
    [sym_primitive_type] = ACTIONS(2272),
    [anon_sym_enum] = ACTIONS(2272),
    [anon_sym_class] = ACTIONS(2272),
    [anon_sym_struct] = ACTIONS(2272),
    [anon_sym_union] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2272),
    [anon_sym_decltype] = ACTIONS(2272),
    [sym_virtual] = ACTIONS(2272),
    [anon_sym_explicit] = ACTIONS(2272),
    [anon_sym_typename] = ACTIONS(2272),
    [anon_sym_template] = ACTIONS(2272),
    [anon_sym_operator] = ACTIONS(2272),
    [anon_sym_friend] = ACTIONS(2272),
    [anon_sym_public] = ACTIONS(2272),
    [anon_sym_private] = ACTIONS(2272),
    [anon_sym_protected] = ACTIONS(2272),
    [anon_sym_using] = ACTIONS(2272),
    [anon_sym_static_assert] = ACTIONS(2272),
    [anon_sym_precise] = ACTIONS(2272),
    [anon_sym_shared] = ACTIONS(2272),
    [anon_sym_groupshared] = ACTIONS(2272),
    [anon_sym_uniform] = ACTIONS(2272),
    [anon_sym_row_major] = ACTIONS(2272),
    [anon_sym_column_major] = ACTIONS(2272),
    [anon_sym_globallycoherent] = ACTIONS(2272),
    [anon_sym_centroid] = ACTIONS(2272),
    [anon_sym_noperspective] = ACTIONS(2272),
    [anon_sym_nointerpolation] = ACTIONS(2272),
    [anon_sym_sample] = ACTIONS(2272),
    [anon_sym_linear] = ACTIONS(2272),
    [anon_sym_snorm] = ACTIONS(2272),
    [anon_sym_unorm] = ACTIONS(2272),
    [anon_sym_point] = ACTIONS(2272),
    [anon_sym_line] = ACTIONS(2272),
    [anon_sym_triangleadj] = ACTIONS(2272),
    [anon_sym_lineadj] = ACTIONS(2272),
    [anon_sym_triangle] = ACTIONS(2272),
  },
  [1847] = {
    [sym_identifier] = ACTIONS(5009),
    [aux_sym_preproc_def_token1] = ACTIONS(5009),
    [aux_sym_preproc_if_token1] = ACTIONS(5009),
    [aux_sym_preproc_if_token2] = ACTIONS(5009),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5009),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5009),
    [aux_sym_preproc_else_token1] = ACTIONS(5009),
    [aux_sym_preproc_elif_token1] = ACTIONS(5009),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5009),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5009),
    [sym_preproc_directive] = ACTIONS(5009),
    [anon_sym_LPAREN2] = ACTIONS(5011),
    [anon_sym_TILDE] = ACTIONS(5011),
    [anon_sym_STAR] = ACTIONS(5011),
    [anon_sym_AMP_AMP] = ACTIONS(5011),
    [anon_sym_AMP] = ACTIONS(5009),
    [anon_sym___extension__] = ACTIONS(5009),
    [anon_sym_typedef] = ACTIONS(5009),
    [anon_sym_in] = ACTIONS(5009),
    [anon_sym_out] = ACTIONS(5009),
    [anon_sym_inout] = ACTIONS(5009),
    [anon_sym_extern] = ACTIONS(5009),
    [anon_sym___attribute__] = ACTIONS(5009),
    [anon_sym_COLON_COLON] = ACTIONS(5011),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5011),
    [anon_sym___declspec] = ACTIONS(5009),
    [anon_sym___based] = ACTIONS(5009),
    [anon_sym_signed] = ACTIONS(5009),
    [anon_sym_unsigned] = ACTIONS(5009),
    [anon_sym_long] = ACTIONS(5009),
    [anon_sym_short] = ACTIONS(5009),
    [anon_sym_LBRACK] = ACTIONS(5009),
    [anon_sym_static] = ACTIONS(5009),
    [anon_sym_register] = ACTIONS(5009),
    [anon_sym_inline] = ACTIONS(5009),
    [anon_sym___inline] = ACTIONS(5009),
    [anon_sym___inline__] = ACTIONS(5009),
    [anon_sym___forceinline] = ACTIONS(5009),
    [anon_sym_thread_local] = ACTIONS(5009),
    [anon_sym___thread] = ACTIONS(5009),
    [anon_sym_const] = ACTIONS(5009),
    [anon_sym_constexpr] = ACTIONS(5009),
    [anon_sym_volatile] = ACTIONS(5009),
    [anon_sym_restrict] = ACTIONS(5009),
    [anon_sym___restrict__] = ACTIONS(5009),
    [anon_sym__Atomic] = ACTIONS(5009),
    [anon_sym__Noreturn] = ACTIONS(5009),
    [anon_sym_noreturn] = ACTIONS(5009),
    [anon_sym_mutable] = ACTIONS(5009),
    [anon_sym_constinit] = ACTIONS(5009),
    [anon_sym_consteval] = ACTIONS(5009),
    [anon_sym_alignas] = ACTIONS(5009),
    [anon_sym__Alignas] = ACTIONS(5009),
    [sym_primitive_type] = ACTIONS(5009),
    [anon_sym_enum] = ACTIONS(5009),
    [anon_sym_class] = ACTIONS(5009),
    [anon_sym_struct] = ACTIONS(5009),
    [anon_sym_union] = ACTIONS(5009),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5009),
    [anon_sym_decltype] = ACTIONS(5009),
    [sym_virtual] = ACTIONS(5009),
    [anon_sym_explicit] = ACTIONS(5009),
    [anon_sym_typename] = ACTIONS(5009),
    [anon_sym_template] = ACTIONS(5009),
    [anon_sym_operator] = ACTIONS(5009),
    [anon_sym_friend] = ACTIONS(5009),
    [anon_sym_public] = ACTIONS(5009),
    [anon_sym_private] = ACTIONS(5009),
    [anon_sym_protected] = ACTIONS(5009),
    [anon_sym_using] = ACTIONS(5009),
    [anon_sym_static_assert] = ACTIONS(5009),
    [anon_sym_precise] = ACTIONS(5009),
    [anon_sym_shared] = ACTIONS(5009),
    [anon_sym_groupshared] = ACTIONS(5009),
    [anon_sym_uniform] = ACTIONS(5009),
    [anon_sym_row_major] = ACTIONS(5009),
    [anon_sym_column_major] = ACTIONS(5009),
    [anon_sym_globallycoherent] = ACTIONS(5009),
    [anon_sym_centroid] = ACTIONS(5009),
    [anon_sym_noperspective] = ACTIONS(5009),
    [anon_sym_nointerpolation] = ACTIONS(5009),
    [anon_sym_sample] = ACTIONS(5009),
    [anon_sym_linear] = ACTIONS(5009),
    [anon_sym_snorm] = ACTIONS(5009),
    [anon_sym_unorm] = ACTIONS(5009),
    [anon_sym_point] = ACTIONS(5009),
    [anon_sym_line] = ACTIONS(5009),
    [anon_sym_triangleadj] = ACTIONS(5009),
    [anon_sym_lineadj] = ACTIONS(5009),
    [anon_sym_triangle] = ACTIONS(5009),
  },
  [1848] = {
    [sym_identifier] = ACTIONS(2458),
    [aux_sym_preproc_def_token1] = ACTIONS(2458),
    [aux_sym_preproc_if_token1] = ACTIONS(2458),
    [aux_sym_preproc_if_token2] = ACTIONS(2458),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2458),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2458),
    [aux_sym_preproc_else_token1] = ACTIONS(2458),
    [aux_sym_preproc_elif_token1] = ACTIONS(2458),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2458),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2458),
    [sym_preproc_directive] = ACTIONS(2458),
    [anon_sym_LPAREN2] = ACTIONS(2460),
    [anon_sym_TILDE] = ACTIONS(2460),
    [anon_sym_STAR] = ACTIONS(2460),
    [anon_sym_AMP_AMP] = ACTIONS(2460),
    [anon_sym_AMP] = ACTIONS(2458),
    [anon_sym___extension__] = ACTIONS(2458),
    [anon_sym_typedef] = ACTIONS(2458),
    [anon_sym_in] = ACTIONS(2458),
    [anon_sym_out] = ACTIONS(2458),
    [anon_sym_inout] = ACTIONS(2458),
    [anon_sym_extern] = ACTIONS(2458),
    [anon_sym___attribute__] = ACTIONS(2458),
    [anon_sym_COLON_COLON] = ACTIONS(2460),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2460),
    [anon_sym___declspec] = ACTIONS(2458),
    [anon_sym___based] = ACTIONS(2458),
    [anon_sym_signed] = ACTIONS(2458),
    [anon_sym_unsigned] = ACTIONS(2458),
    [anon_sym_long] = ACTIONS(2458),
    [anon_sym_short] = ACTIONS(2458),
    [anon_sym_LBRACK] = ACTIONS(2458),
    [anon_sym_static] = ACTIONS(2458),
    [anon_sym_register] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(2458),
    [anon_sym___inline] = ACTIONS(2458),
    [anon_sym___inline__] = ACTIONS(2458),
    [anon_sym___forceinline] = ACTIONS(2458),
    [anon_sym_thread_local] = ACTIONS(2458),
    [anon_sym___thread] = ACTIONS(2458),
    [anon_sym_const] = ACTIONS(2458),
    [anon_sym_constexpr] = ACTIONS(2458),
    [anon_sym_volatile] = ACTIONS(2458),
    [anon_sym_restrict] = ACTIONS(2458),
    [anon_sym___restrict__] = ACTIONS(2458),
    [anon_sym__Atomic] = ACTIONS(2458),
    [anon_sym__Noreturn] = ACTIONS(2458),
    [anon_sym_noreturn] = ACTIONS(2458),
    [anon_sym_mutable] = ACTIONS(2458),
    [anon_sym_constinit] = ACTIONS(2458),
    [anon_sym_consteval] = ACTIONS(2458),
    [anon_sym_alignas] = ACTIONS(2458),
    [anon_sym__Alignas] = ACTIONS(2458),
    [sym_primitive_type] = ACTIONS(2458),
    [anon_sym_enum] = ACTIONS(2458),
    [anon_sym_class] = ACTIONS(2458),
    [anon_sym_struct] = ACTIONS(2458),
    [anon_sym_union] = ACTIONS(2458),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2458),
    [anon_sym_decltype] = ACTIONS(2458),
    [sym_virtual] = ACTIONS(2458),
    [anon_sym_explicit] = ACTIONS(2458),
    [anon_sym_typename] = ACTIONS(2458),
    [anon_sym_template] = ACTIONS(2458),
    [anon_sym_operator] = ACTIONS(2458),
    [anon_sym_friend] = ACTIONS(2458),
    [anon_sym_public] = ACTIONS(2458),
    [anon_sym_private] = ACTIONS(2458),
    [anon_sym_protected] = ACTIONS(2458),
    [anon_sym_using] = ACTIONS(2458),
    [anon_sym_static_assert] = ACTIONS(2458),
    [anon_sym_precise] = ACTIONS(2458),
    [anon_sym_shared] = ACTIONS(2458),
    [anon_sym_groupshared] = ACTIONS(2458),
    [anon_sym_uniform] = ACTIONS(2458),
    [anon_sym_row_major] = ACTIONS(2458),
    [anon_sym_column_major] = ACTIONS(2458),
    [anon_sym_globallycoherent] = ACTIONS(2458),
    [anon_sym_centroid] = ACTIONS(2458),
    [anon_sym_noperspective] = ACTIONS(2458),
    [anon_sym_nointerpolation] = ACTIONS(2458),
    [anon_sym_sample] = ACTIONS(2458),
    [anon_sym_linear] = ACTIONS(2458),
    [anon_sym_snorm] = ACTIONS(2458),
    [anon_sym_unorm] = ACTIONS(2458),
    [anon_sym_point] = ACTIONS(2458),
    [anon_sym_line] = ACTIONS(2458),
    [anon_sym_triangleadj] = ACTIONS(2458),
    [anon_sym_lineadj] = ACTIONS(2458),
    [anon_sym_triangle] = ACTIONS(2458),
  },
  [1849] = {
    [sym_identifier] = ACTIONS(2536),
    [aux_sym_preproc_def_token1] = ACTIONS(2536),
    [aux_sym_preproc_if_token1] = ACTIONS(2536),
    [aux_sym_preproc_if_token2] = ACTIONS(2536),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2536),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2536),
    [aux_sym_preproc_else_token1] = ACTIONS(2536),
    [aux_sym_preproc_elif_token1] = ACTIONS(2536),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2536),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2536),
    [sym_preproc_directive] = ACTIONS(2536),
    [anon_sym_LPAREN2] = ACTIONS(2538),
    [anon_sym_TILDE] = ACTIONS(2538),
    [anon_sym_STAR] = ACTIONS(2538),
    [anon_sym_AMP_AMP] = ACTIONS(2538),
    [anon_sym_AMP] = ACTIONS(2536),
    [anon_sym___extension__] = ACTIONS(2536),
    [anon_sym_typedef] = ACTIONS(2536),
    [anon_sym_in] = ACTIONS(2536),
    [anon_sym_out] = ACTIONS(2536),
    [anon_sym_inout] = ACTIONS(2536),
    [anon_sym_extern] = ACTIONS(2536),
    [anon_sym___attribute__] = ACTIONS(2536),
    [anon_sym_COLON_COLON] = ACTIONS(2538),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2538),
    [anon_sym___declspec] = ACTIONS(2536),
    [anon_sym___based] = ACTIONS(2536),
    [anon_sym_signed] = ACTIONS(2536),
    [anon_sym_unsigned] = ACTIONS(2536),
    [anon_sym_long] = ACTIONS(2536),
    [anon_sym_short] = ACTIONS(2536),
    [anon_sym_LBRACK] = ACTIONS(2536),
    [anon_sym_static] = ACTIONS(2536),
    [anon_sym_register] = ACTIONS(2536),
    [anon_sym_inline] = ACTIONS(2536),
    [anon_sym___inline] = ACTIONS(2536),
    [anon_sym___inline__] = ACTIONS(2536),
    [anon_sym___forceinline] = ACTIONS(2536),
    [anon_sym_thread_local] = ACTIONS(2536),
    [anon_sym___thread] = ACTIONS(2536),
    [anon_sym_const] = ACTIONS(2536),
    [anon_sym_constexpr] = ACTIONS(2536),
    [anon_sym_volatile] = ACTIONS(2536),
    [anon_sym_restrict] = ACTIONS(2536),
    [anon_sym___restrict__] = ACTIONS(2536),
    [anon_sym__Atomic] = ACTIONS(2536),
    [anon_sym__Noreturn] = ACTIONS(2536),
    [anon_sym_noreturn] = ACTIONS(2536),
    [anon_sym_mutable] = ACTIONS(2536),
    [anon_sym_constinit] = ACTIONS(2536),
    [anon_sym_consteval] = ACTIONS(2536),
    [anon_sym_alignas] = ACTIONS(2536),
    [anon_sym__Alignas] = ACTIONS(2536),
    [sym_primitive_type] = ACTIONS(2536),
    [anon_sym_enum] = ACTIONS(2536),
    [anon_sym_class] = ACTIONS(2536),
    [anon_sym_struct] = ACTIONS(2536),
    [anon_sym_union] = ACTIONS(2536),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2536),
    [anon_sym_decltype] = ACTIONS(2536),
    [sym_virtual] = ACTIONS(2536),
    [anon_sym_explicit] = ACTIONS(2536),
    [anon_sym_typename] = ACTIONS(2536),
    [anon_sym_template] = ACTIONS(2536),
    [anon_sym_operator] = ACTIONS(2536),
    [anon_sym_friend] = ACTIONS(2536),
    [anon_sym_public] = ACTIONS(2536),
    [anon_sym_private] = ACTIONS(2536),
    [anon_sym_protected] = ACTIONS(2536),
    [anon_sym_using] = ACTIONS(2536),
    [anon_sym_static_assert] = ACTIONS(2536),
    [anon_sym_precise] = ACTIONS(2536),
    [anon_sym_shared] = ACTIONS(2536),
    [anon_sym_groupshared] = ACTIONS(2536),
    [anon_sym_uniform] = ACTIONS(2536),
    [anon_sym_row_major] = ACTIONS(2536),
    [anon_sym_column_major] = ACTIONS(2536),
    [anon_sym_globallycoherent] = ACTIONS(2536),
    [anon_sym_centroid] = ACTIONS(2536),
    [anon_sym_noperspective] = ACTIONS(2536),
    [anon_sym_nointerpolation] = ACTIONS(2536),
    [anon_sym_sample] = ACTIONS(2536),
    [anon_sym_linear] = ACTIONS(2536),
    [anon_sym_snorm] = ACTIONS(2536),
    [anon_sym_unorm] = ACTIONS(2536),
    [anon_sym_point] = ACTIONS(2536),
    [anon_sym_line] = ACTIONS(2536),
    [anon_sym_triangleadj] = ACTIONS(2536),
    [anon_sym_lineadj] = ACTIONS(2536),
    [anon_sym_triangle] = ACTIONS(2536),
  },
  [1850] = {
    [sym_identifier] = ACTIONS(2532),
    [aux_sym_preproc_def_token1] = ACTIONS(2532),
    [aux_sym_preproc_if_token1] = ACTIONS(2532),
    [aux_sym_preproc_if_token2] = ACTIONS(2532),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2532),
    [aux_sym_preproc_else_token1] = ACTIONS(2532),
    [aux_sym_preproc_elif_token1] = ACTIONS(2532),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2532),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2532),
    [sym_preproc_directive] = ACTIONS(2532),
    [anon_sym_LPAREN2] = ACTIONS(2534),
    [anon_sym_TILDE] = ACTIONS(2534),
    [anon_sym_STAR] = ACTIONS(2534),
    [anon_sym_AMP_AMP] = ACTIONS(2534),
    [anon_sym_AMP] = ACTIONS(2532),
    [anon_sym___extension__] = ACTIONS(2532),
    [anon_sym_typedef] = ACTIONS(2532),
    [anon_sym_in] = ACTIONS(2532),
    [anon_sym_out] = ACTIONS(2532),
    [anon_sym_inout] = ACTIONS(2532),
    [anon_sym_extern] = ACTIONS(2532),
    [anon_sym___attribute__] = ACTIONS(2532),
    [anon_sym_COLON_COLON] = ACTIONS(2534),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2534),
    [anon_sym___declspec] = ACTIONS(2532),
    [anon_sym___based] = ACTIONS(2532),
    [anon_sym_signed] = ACTIONS(2532),
    [anon_sym_unsigned] = ACTIONS(2532),
    [anon_sym_long] = ACTIONS(2532),
    [anon_sym_short] = ACTIONS(2532),
    [anon_sym_LBRACK] = ACTIONS(2532),
    [anon_sym_static] = ACTIONS(2532),
    [anon_sym_register] = ACTIONS(2532),
    [anon_sym_inline] = ACTIONS(2532),
    [anon_sym___inline] = ACTIONS(2532),
    [anon_sym___inline__] = ACTIONS(2532),
    [anon_sym___forceinline] = ACTIONS(2532),
    [anon_sym_thread_local] = ACTIONS(2532),
    [anon_sym___thread] = ACTIONS(2532),
    [anon_sym_const] = ACTIONS(2532),
    [anon_sym_constexpr] = ACTIONS(2532),
    [anon_sym_volatile] = ACTIONS(2532),
    [anon_sym_restrict] = ACTIONS(2532),
    [anon_sym___restrict__] = ACTIONS(2532),
    [anon_sym__Atomic] = ACTIONS(2532),
    [anon_sym__Noreturn] = ACTIONS(2532),
    [anon_sym_noreturn] = ACTIONS(2532),
    [anon_sym_mutable] = ACTIONS(2532),
    [anon_sym_constinit] = ACTIONS(2532),
    [anon_sym_consteval] = ACTIONS(2532),
    [anon_sym_alignas] = ACTIONS(2532),
    [anon_sym__Alignas] = ACTIONS(2532),
    [sym_primitive_type] = ACTIONS(2532),
    [anon_sym_enum] = ACTIONS(2532),
    [anon_sym_class] = ACTIONS(2532),
    [anon_sym_struct] = ACTIONS(2532),
    [anon_sym_union] = ACTIONS(2532),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2532),
    [anon_sym_decltype] = ACTIONS(2532),
    [sym_virtual] = ACTIONS(2532),
    [anon_sym_explicit] = ACTIONS(2532),
    [anon_sym_typename] = ACTIONS(2532),
    [anon_sym_template] = ACTIONS(2532),
    [anon_sym_operator] = ACTIONS(2532),
    [anon_sym_friend] = ACTIONS(2532),
    [anon_sym_public] = ACTIONS(2532),
    [anon_sym_private] = ACTIONS(2532),
    [anon_sym_protected] = ACTIONS(2532),
    [anon_sym_using] = ACTIONS(2532),
    [anon_sym_static_assert] = ACTIONS(2532),
    [anon_sym_precise] = ACTIONS(2532),
    [anon_sym_shared] = ACTIONS(2532),
    [anon_sym_groupshared] = ACTIONS(2532),
    [anon_sym_uniform] = ACTIONS(2532),
    [anon_sym_row_major] = ACTIONS(2532),
    [anon_sym_column_major] = ACTIONS(2532),
    [anon_sym_globallycoherent] = ACTIONS(2532),
    [anon_sym_centroid] = ACTIONS(2532),
    [anon_sym_noperspective] = ACTIONS(2532),
    [anon_sym_nointerpolation] = ACTIONS(2532),
    [anon_sym_sample] = ACTIONS(2532),
    [anon_sym_linear] = ACTIONS(2532),
    [anon_sym_snorm] = ACTIONS(2532),
    [anon_sym_unorm] = ACTIONS(2532),
    [anon_sym_point] = ACTIONS(2532),
    [anon_sym_line] = ACTIONS(2532),
    [anon_sym_triangleadj] = ACTIONS(2532),
    [anon_sym_lineadj] = ACTIONS(2532),
    [anon_sym_triangle] = ACTIONS(2532),
  },
  [1851] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token2] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [aux_sym_preproc_else_token1] = ACTIONS(2332),
    [aux_sym_preproc_elif_token1] = ACTIONS(2332),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_friend] = ACTIONS(2332),
    [anon_sym_public] = ACTIONS(2332),
    [anon_sym_private] = ACTIONS(2332),
    [anon_sym_protected] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
  },
  [1852] = {
    [sym_identifier] = ACTIONS(5013),
    [aux_sym_preproc_def_token1] = ACTIONS(5013),
    [aux_sym_preproc_if_token1] = ACTIONS(5013),
    [aux_sym_preproc_if_token2] = ACTIONS(5013),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5013),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5013),
    [aux_sym_preproc_else_token1] = ACTIONS(5013),
    [aux_sym_preproc_elif_token1] = ACTIONS(5013),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5013),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5013),
    [sym_preproc_directive] = ACTIONS(5013),
    [anon_sym_LPAREN2] = ACTIONS(5015),
    [anon_sym_TILDE] = ACTIONS(5015),
    [anon_sym_STAR] = ACTIONS(5015),
    [anon_sym_AMP_AMP] = ACTIONS(5015),
    [anon_sym_AMP] = ACTIONS(5013),
    [anon_sym___extension__] = ACTIONS(5013),
    [anon_sym_typedef] = ACTIONS(5013),
    [anon_sym_in] = ACTIONS(5013),
    [anon_sym_out] = ACTIONS(5013),
    [anon_sym_inout] = ACTIONS(5013),
    [anon_sym_extern] = ACTIONS(5013),
    [anon_sym___attribute__] = ACTIONS(5013),
    [anon_sym_COLON_COLON] = ACTIONS(5015),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5015),
    [anon_sym___declspec] = ACTIONS(5013),
    [anon_sym___based] = ACTIONS(5013),
    [anon_sym_signed] = ACTIONS(5013),
    [anon_sym_unsigned] = ACTIONS(5013),
    [anon_sym_long] = ACTIONS(5013),
    [anon_sym_short] = ACTIONS(5013),
    [anon_sym_LBRACK] = ACTIONS(5013),
    [anon_sym_static] = ACTIONS(5013),
    [anon_sym_register] = ACTIONS(5013),
    [anon_sym_inline] = ACTIONS(5013),
    [anon_sym___inline] = ACTIONS(5013),
    [anon_sym___inline__] = ACTIONS(5013),
    [anon_sym___forceinline] = ACTIONS(5013),
    [anon_sym_thread_local] = ACTIONS(5013),
    [anon_sym___thread] = ACTIONS(5013),
    [anon_sym_const] = ACTIONS(5013),
    [anon_sym_constexpr] = ACTIONS(5013),
    [anon_sym_volatile] = ACTIONS(5013),
    [anon_sym_restrict] = ACTIONS(5013),
    [anon_sym___restrict__] = ACTIONS(5013),
    [anon_sym__Atomic] = ACTIONS(5013),
    [anon_sym__Noreturn] = ACTIONS(5013),
    [anon_sym_noreturn] = ACTIONS(5013),
    [anon_sym_mutable] = ACTIONS(5013),
    [anon_sym_constinit] = ACTIONS(5013),
    [anon_sym_consteval] = ACTIONS(5013),
    [anon_sym_alignas] = ACTIONS(5013),
    [anon_sym__Alignas] = ACTIONS(5013),
    [sym_primitive_type] = ACTIONS(5013),
    [anon_sym_enum] = ACTIONS(5013),
    [anon_sym_class] = ACTIONS(5013),
    [anon_sym_struct] = ACTIONS(5013),
    [anon_sym_union] = ACTIONS(5013),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5013),
    [anon_sym_decltype] = ACTIONS(5013),
    [sym_virtual] = ACTIONS(5013),
    [anon_sym_explicit] = ACTIONS(5013),
    [anon_sym_typename] = ACTIONS(5013),
    [anon_sym_template] = ACTIONS(5013),
    [anon_sym_operator] = ACTIONS(5013),
    [anon_sym_friend] = ACTIONS(5013),
    [anon_sym_public] = ACTIONS(5013),
    [anon_sym_private] = ACTIONS(5013),
    [anon_sym_protected] = ACTIONS(5013),
    [anon_sym_using] = ACTIONS(5013),
    [anon_sym_static_assert] = ACTIONS(5013),
    [anon_sym_precise] = ACTIONS(5013),
    [anon_sym_shared] = ACTIONS(5013),
    [anon_sym_groupshared] = ACTIONS(5013),
    [anon_sym_uniform] = ACTIONS(5013),
    [anon_sym_row_major] = ACTIONS(5013),
    [anon_sym_column_major] = ACTIONS(5013),
    [anon_sym_globallycoherent] = ACTIONS(5013),
    [anon_sym_centroid] = ACTIONS(5013),
    [anon_sym_noperspective] = ACTIONS(5013),
    [anon_sym_nointerpolation] = ACTIONS(5013),
    [anon_sym_sample] = ACTIONS(5013),
    [anon_sym_linear] = ACTIONS(5013),
    [anon_sym_snorm] = ACTIONS(5013),
    [anon_sym_unorm] = ACTIONS(5013),
    [anon_sym_point] = ACTIONS(5013),
    [anon_sym_line] = ACTIONS(5013),
    [anon_sym_triangleadj] = ACTIONS(5013),
    [anon_sym_lineadj] = ACTIONS(5013),
    [anon_sym_triangle] = ACTIONS(5013),
  },
  [1853] = {
    [sym_identifier] = ACTIONS(5005),
    [aux_sym_preproc_def_token1] = ACTIONS(5005),
    [aux_sym_preproc_if_token1] = ACTIONS(5005),
    [aux_sym_preproc_if_token2] = ACTIONS(5005),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5005),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5005),
    [aux_sym_preproc_else_token1] = ACTIONS(5005),
    [aux_sym_preproc_elif_token1] = ACTIONS(5005),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5005),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5005),
    [sym_preproc_directive] = ACTIONS(5005),
    [anon_sym_LPAREN2] = ACTIONS(5007),
    [anon_sym_TILDE] = ACTIONS(5007),
    [anon_sym_STAR] = ACTIONS(5007),
    [anon_sym_AMP_AMP] = ACTIONS(5007),
    [anon_sym_AMP] = ACTIONS(5005),
    [anon_sym___extension__] = ACTIONS(5005),
    [anon_sym_typedef] = ACTIONS(5005),
    [anon_sym_in] = ACTIONS(5005),
    [anon_sym_out] = ACTIONS(5005),
    [anon_sym_inout] = ACTIONS(5005),
    [anon_sym_extern] = ACTIONS(5005),
    [anon_sym___attribute__] = ACTIONS(5005),
    [anon_sym_COLON_COLON] = ACTIONS(5007),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5007),
    [anon_sym___declspec] = ACTIONS(5005),
    [anon_sym___based] = ACTIONS(5005),
    [anon_sym_signed] = ACTIONS(5005),
    [anon_sym_unsigned] = ACTIONS(5005),
    [anon_sym_long] = ACTIONS(5005),
    [anon_sym_short] = ACTIONS(5005),
    [anon_sym_LBRACK] = ACTIONS(5005),
    [anon_sym_static] = ACTIONS(5005),
    [anon_sym_register] = ACTIONS(5005),
    [anon_sym_inline] = ACTIONS(5005),
    [anon_sym___inline] = ACTIONS(5005),
    [anon_sym___inline__] = ACTIONS(5005),
    [anon_sym___forceinline] = ACTIONS(5005),
    [anon_sym_thread_local] = ACTIONS(5005),
    [anon_sym___thread] = ACTIONS(5005),
    [anon_sym_const] = ACTIONS(5005),
    [anon_sym_constexpr] = ACTIONS(5005),
    [anon_sym_volatile] = ACTIONS(5005),
    [anon_sym_restrict] = ACTIONS(5005),
    [anon_sym___restrict__] = ACTIONS(5005),
    [anon_sym__Atomic] = ACTIONS(5005),
    [anon_sym__Noreturn] = ACTIONS(5005),
    [anon_sym_noreturn] = ACTIONS(5005),
    [anon_sym_mutable] = ACTIONS(5005),
    [anon_sym_constinit] = ACTIONS(5005),
    [anon_sym_consteval] = ACTIONS(5005),
    [anon_sym_alignas] = ACTIONS(5005),
    [anon_sym__Alignas] = ACTIONS(5005),
    [sym_primitive_type] = ACTIONS(5005),
    [anon_sym_enum] = ACTIONS(5005),
    [anon_sym_class] = ACTIONS(5005),
    [anon_sym_struct] = ACTIONS(5005),
    [anon_sym_union] = ACTIONS(5005),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5005),
    [anon_sym_decltype] = ACTIONS(5005),
    [sym_virtual] = ACTIONS(5005),
    [anon_sym_explicit] = ACTIONS(5005),
    [anon_sym_typename] = ACTIONS(5005),
    [anon_sym_template] = ACTIONS(5005),
    [anon_sym_operator] = ACTIONS(5005),
    [anon_sym_friend] = ACTIONS(5005),
    [anon_sym_public] = ACTIONS(5005),
    [anon_sym_private] = ACTIONS(5005),
    [anon_sym_protected] = ACTIONS(5005),
    [anon_sym_using] = ACTIONS(5005),
    [anon_sym_static_assert] = ACTIONS(5005),
    [anon_sym_precise] = ACTIONS(5005),
    [anon_sym_shared] = ACTIONS(5005),
    [anon_sym_groupshared] = ACTIONS(5005),
    [anon_sym_uniform] = ACTIONS(5005),
    [anon_sym_row_major] = ACTIONS(5005),
    [anon_sym_column_major] = ACTIONS(5005),
    [anon_sym_globallycoherent] = ACTIONS(5005),
    [anon_sym_centroid] = ACTIONS(5005),
    [anon_sym_noperspective] = ACTIONS(5005),
    [anon_sym_nointerpolation] = ACTIONS(5005),
    [anon_sym_sample] = ACTIONS(5005),
    [anon_sym_linear] = ACTIONS(5005),
    [anon_sym_snorm] = ACTIONS(5005),
    [anon_sym_unorm] = ACTIONS(5005),
    [anon_sym_point] = ACTIONS(5005),
    [anon_sym_line] = ACTIONS(5005),
    [anon_sym_triangleadj] = ACTIONS(5005),
    [anon_sym_lineadj] = ACTIONS(5005),
    [anon_sym_triangle] = ACTIONS(5005),
  },
  [1854] = {
    [sym_identifier] = ACTIONS(5013),
    [aux_sym_preproc_def_token1] = ACTIONS(5013),
    [aux_sym_preproc_if_token1] = ACTIONS(5013),
    [aux_sym_preproc_if_token2] = ACTIONS(5013),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5013),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5013),
    [aux_sym_preproc_else_token1] = ACTIONS(5013),
    [aux_sym_preproc_elif_token1] = ACTIONS(5013),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5013),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5013),
    [sym_preproc_directive] = ACTIONS(5013),
    [anon_sym_LPAREN2] = ACTIONS(5015),
    [anon_sym_TILDE] = ACTIONS(5015),
    [anon_sym_STAR] = ACTIONS(5015),
    [anon_sym_AMP_AMP] = ACTIONS(5015),
    [anon_sym_AMP] = ACTIONS(5013),
    [anon_sym___extension__] = ACTIONS(5013),
    [anon_sym_typedef] = ACTIONS(5013),
    [anon_sym_in] = ACTIONS(5013),
    [anon_sym_out] = ACTIONS(5013),
    [anon_sym_inout] = ACTIONS(5013),
    [anon_sym_extern] = ACTIONS(5013),
    [anon_sym___attribute__] = ACTIONS(5013),
    [anon_sym_COLON_COLON] = ACTIONS(5015),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5015),
    [anon_sym___declspec] = ACTIONS(5013),
    [anon_sym___based] = ACTIONS(5013),
    [anon_sym_signed] = ACTIONS(5013),
    [anon_sym_unsigned] = ACTIONS(5013),
    [anon_sym_long] = ACTIONS(5013),
    [anon_sym_short] = ACTIONS(5013),
    [anon_sym_LBRACK] = ACTIONS(5013),
    [anon_sym_static] = ACTIONS(5013),
    [anon_sym_register] = ACTIONS(5013),
    [anon_sym_inline] = ACTIONS(5013),
    [anon_sym___inline] = ACTIONS(5013),
    [anon_sym___inline__] = ACTIONS(5013),
    [anon_sym___forceinline] = ACTIONS(5013),
    [anon_sym_thread_local] = ACTIONS(5013),
    [anon_sym___thread] = ACTIONS(5013),
    [anon_sym_const] = ACTIONS(5013),
    [anon_sym_constexpr] = ACTIONS(5013),
    [anon_sym_volatile] = ACTIONS(5013),
    [anon_sym_restrict] = ACTIONS(5013),
    [anon_sym___restrict__] = ACTIONS(5013),
    [anon_sym__Atomic] = ACTIONS(5013),
    [anon_sym__Noreturn] = ACTIONS(5013),
    [anon_sym_noreturn] = ACTIONS(5013),
    [anon_sym_mutable] = ACTIONS(5013),
    [anon_sym_constinit] = ACTIONS(5013),
    [anon_sym_consteval] = ACTIONS(5013),
    [anon_sym_alignas] = ACTIONS(5013),
    [anon_sym__Alignas] = ACTIONS(5013),
    [sym_primitive_type] = ACTIONS(5013),
    [anon_sym_enum] = ACTIONS(5013),
    [anon_sym_class] = ACTIONS(5013),
    [anon_sym_struct] = ACTIONS(5013),
    [anon_sym_union] = ACTIONS(5013),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5013),
    [anon_sym_decltype] = ACTIONS(5013),
    [sym_virtual] = ACTIONS(5013),
    [anon_sym_explicit] = ACTIONS(5013),
    [anon_sym_typename] = ACTIONS(5013),
    [anon_sym_template] = ACTIONS(5013),
    [anon_sym_operator] = ACTIONS(5013),
    [anon_sym_friend] = ACTIONS(5013),
    [anon_sym_public] = ACTIONS(5013),
    [anon_sym_private] = ACTIONS(5013),
    [anon_sym_protected] = ACTIONS(5013),
    [anon_sym_using] = ACTIONS(5013),
    [anon_sym_static_assert] = ACTIONS(5013),
    [anon_sym_precise] = ACTIONS(5013),
    [anon_sym_shared] = ACTIONS(5013),
    [anon_sym_groupshared] = ACTIONS(5013),
    [anon_sym_uniform] = ACTIONS(5013),
    [anon_sym_row_major] = ACTIONS(5013),
    [anon_sym_column_major] = ACTIONS(5013),
    [anon_sym_globallycoherent] = ACTIONS(5013),
    [anon_sym_centroid] = ACTIONS(5013),
    [anon_sym_noperspective] = ACTIONS(5013),
    [anon_sym_nointerpolation] = ACTIONS(5013),
    [anon_sym_sample] = ACTIONS(5013),
    [anon_sym_linear] = ACTIONS(5013),
    [anon_sym_snorm] = ACTIONS(5013),
    [anon_sym_unorm] = ACTIONS(5013),
    [anon_sym_point] = ACTIONS(5013),
    [anon_sym_line] = ACTIONS(5013),
    [anon_sym_triangleadj] = ACTIONS(5013),
    [anon_sym_lineadj] = ACTIONS(5013),
    [anon_sym_triangle] = ACTIONS(5013),
  },
  [1855] = {
    [sym_identifier] = ACTIONS(2494),
    [aux_sym_preproc_def_token1] = ACTIONS(2494),
    [aux_sym_preproc_if_token1] = ACTIONS(2494),
    [aux_sym_preproc_if_token2] = ACTIONS(2494),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2494),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2494),
    [aux_sym_preproc_else_token1] = ACTIONS(2494),
    [aux_sym_preproc_elif_token1] = ACTIONS(2494),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2494),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2494),
    [sym_preproc_directive] = ACTIONS(2494),
    [anon_sym_LPAREN2] = ACTIONS(2496),
    [anon_sym_TILDE] = ACTIONS(2496),
    [anon_sym_STAR] = ACTIONS(2496),
    [anon_sym_AMP_AMP] = ACTIONS(2496),
    [anon_sym_AMP] = ACTIONS(2494),
    [anon_sym___extension__] = ACTIONS(2494),
    [anon_sym_typedef] = ACTIONS(2494),
    [anon_sym_in] = ACTIONS(2494),
    [anon_sym_out] = ACTIONS(2494),
    [anon_sym_inout] = ACTIONS(2494),
    [anon_sym_extern] = ACTIONS(2494),
    [anon_sym___attribute__] = ACTIONS(2494),
    [anon_sym_COLON_COLON] = ACTIONS(2496),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2496),
    [anon_sym___declspec] = ACTIONS(2494),
    [anon_sym___based] = ACTIONS(2494),
    [anon_sym_signed] = ACTIONS(2494),
    [anon_sym_unsigned] = ACTIONS(2494),
    [anon_sym_long] = ACTIONS(2494),
    [anon_sym_short] = ACTIONS(2494),
    [anon_sym_LBRACK] = ACTIONS(2494),
    [anon_sym_static] = ACTIONS(2494),
    [anon_sym_register] = ACTIONS(2494),
    [anon_sym_inline] = ACTIONS(2494),
    [anon_sym___inline] = ACTIONS(2494),
    [anon_sym___inline__] = ACTIONS(2494),
    [anon_sym___forceinline] = ACTIONS(2494),
    [anon_sym_thread_local] = ACTIONS(2494),
    [anon_sym___thread] = ACTIONS(2494),
    [anon_sym_const] = ACTIONS(2494),
    [anon_sym_constexpr] = ACTIONS(2494),
    [anon_sym_volatile] = ACTIONS(2494),
    [anon_sym_restrict] = ACTIONS(2494),
    [anon_sym___restrict__] = ACTIONS(2494),
    [anon_sym__Atomic] = ACTIONS(2494),
    [anon_sym__Noreturn] = ACTIONS(2494),
    [anon_sym_noreturn] = ACTIONS(2494),
    [anon_sym_mutable] = ACTIONS(2494),
    [anon_sym_constinit] = ACTIONS(2494),
    [anon_sym_consteval] = ACTIONS(2494),
    [anon_sym_alignas] = ACTIONS(2494),
    [anon_sym__Alignas] = ACTIONS(2494),
    [sym_primitive_type] = ACTIONS(2494),
    [anon_sym_enum] = ACTIONS(2494),
    [anon_sym_class] = ACTIONS(2494),
    [anon_sym_struct] = ACTIONS(2494),
    [anon_sym_union] = ACTIONS(2494),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2494),
    [anon_sym_decltype] = ACTIONS(2494),
    [sym_virtual] = ACTIONS(2494),
    [anon_sym_explicit] = ACTIONS(2494),
    [anon_sym_typename] = ACTIONS(2494),
    [anon_sym_template] = ACTIONS(2494),
    [anon_sym_operator] = ACTIONS(2494),
    [anon_sym_friend] = ACTIONS(2494),
    [anon_sym_public] = ACTIONS(2494),
    [anon_sym_private] = ACTIONS(2494),
    [anon_sym_protected] = ACTIONS(2494),
    [anon_sym_using] = ACTIONS(2494),
    [anon_sym_static_assert] = ACTIONS(2494),
    [anon_sym_precise] = ACTIONS(2494),
    [anon_sym_shared] = ACTIONS(2494),
    [anon_sym_groupshared] = ACTIONS(2494),
    [anon_sym_uniform] = ACTIONS(2494),
    [anon_sym_row_major] = ACTIONS(2494),
    [anon_sym_column_major] = ACTIONS(2494),
    [anon_sym_globallycoherent] = ACTIONS(2494),
    [anon_sym_centroid] = ACTIONS(2494),
    [anon_sym_noperspective] = ACTIONS(2494),
    [anon_sym_nointerpolation] = ACTIONS(2494),
    [anon_sym_sample] = ACTIONS(2494),
    [anon_sym_linear] = ACTIONS(2494),
    [anon_sym_snorm] = ACTIONS(2494),
    [anon_sym_unorm] = ACTIONS(2494),
    [anon_sym_point] = ACTIONS(2494),
    [anon_sym_line] = ACTIONS(2494),
    [anon_sym_triangleadj] = ACTIONS(2494),
    [anon_sym_lineadj] = ACTIONS(2494),
    [anon_sym_triangle] = ACTIONS(2494),
  },
  [1856] = {
    [sym_identifier] = ACTIONS(2400),
    [aux_sym_preproc_def_token1] = ACTIONS(2400),
    [aux_sym_preproc_if_token1] = ACTIONS(2400),
    [aux_sym_preproc_if_token2] = ACTIONS(2400),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2400),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2400),
    [aux_sym_preproc_else_token1] = ACTIONS(2400),
    [aux_sym_preproc_elif_token1] = ACTIONS(2400),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2400),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2400),
    [sym_preproc_directive] = ACTIONS(2400),
    [anon_sym_LPAREN2] = ACTIONS(2402),
    [anon_sym_TILDE] = ACTIONS(2402),
    [anon_sym_STAR] = ACTIONS(2402),
    [anon_sym_AMP_AMP] = ACTIONS(2402),
    [anon_sym_AMP] = ACTIONS(2400),
    [anon_sym___extension__] = ACTIONS(2400),
    [anon_sym_typedef] = ACTIONS(2400),
    [anon_sym_in] = ACTIONS(2400),
    [anon_sym_out] = ACTIONS(2400),
    [anon_sym_inout] = ACTIONS(2400),
    [anon_sym_extern] = ACTIONS(2400),
    [anon_sym___attribute__] = ACTIONS(2400),
    [anon_sym_COLON_COLON] = ACTIONS(2402),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2402),
    [anon_sym___declspec] = ACTIONS(2400),
    [anon_sym___based] = ACTIONS(2400),
    [anon_sym_signed] = ACTIONS(2400),
    [anon_sym_unsigned] = ACTIONS(2400),
    [anon_sym_long] = ACTIONS(2400),
    [anon_sym_short] = ACTIONS(2400),
    [anon_sym_LBRACK] = ACTIONS(2400),
    [anon_sym_static] = ACTIONS(2400),
    [anon_sym_register] = ACTIONS(2400),
    [anon_sym_inline] = ACTIONS(2400),
    [anon_sym___inline] = ACTIONS(2400),
    [anon_sym___inline__] = ACTIONS(2400),
    [anon_sym___forceinline] = ACTIONS(2400),
    [anon_sym_thread_local] = ACTIONS(2400),
    [anon_sym___thread] = ACTIONS(2400),
    [anon_sym_const] = ACTIONS(2400),
    [anon_sym_constexpr] = ACTIONS(2400),
    [anon_sym_volatile] = ACTIONS(2400),
    [anon_sym_restrict] = ACTIONS(2400),
    [anon_sym___restrict__] = ACTIONS(2400),
    [anon_sym__Atomic] = ACTIONS(2400),
    [anon_sym__Noreturn] = ACTIONS(2400),
    [anon_sym_noreturn] = ACTIONS(2400),
    [anon_sym_mutable] = ACTIONS(2400),
    [anon_sym_constinit] = ACTIONS(2400),
    [anon_sym_consteval] = ACTIONS(2400),
    [anon_sym_alignas] = ACTIONS(2400),
    [anon_sym__Alignas] = ACTIONS(2400),
    [sym_primitive_type] = ACTIONS(2400),
    [anon_sym_enum] = ACTIONS(2400),
    [anon_sym_class] = ACTIONS(2400),
    [anon_sym_struct] = ACTIONS(2400),
    [anon_sym_union] = ACTIONS(2400),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2400),
    [anon_sym_decltype] = ACTIONS(2400),
    [sym_virtual] = ACTIONS(2400),
    [anon_sym_explicit] = ACTIONS(2400),
    [anon_sym_typename] = ACTIONS(2400),
    [anon_sym_template] = ACTIONS(2400),
    [anon_sym_operator] = ACTIONS(2400),
    [anon_sym_friend] = ACTIONS(2400),
    [anon_sym_public] = ACTIONS(2400),
    [anon_sym_private] = ACTIONS(2400),
    [anon_sym_protected] = ACTIONS(2400),
    [anon_sym_using] = ACTIONS(2400),
    [anon_sym_static_assert] = ACTIONS(2400),
    [anon_sym_precise] = ACTIONS(2400),
    [anon_sym_shared] = ACTIONS(2400),
    [anon_sym_groupshared] = ACTIONS(2400),
    [anon_sym_uniform] = ACTIONS(2400),
    [anon_sym_row_major] = ACTIONS(2400),
    [anon_sym_column_major] = ACTIONS(2400),
    [anon_sym_globallycoherent] = ACTIONS(2400),
    [anon_sym_centroid] = ACTIONS(2400),
    [anon_sym_noperspective] = ACTIONS(2400),
    [anon_sym_nointerpolation] = ACTIONS(2400),
    [anon_sym_sample] = ACTIONS(2400),
    [anon_sym_linear] = ACTIONS(2400),
    [anon_sym_snorm] = ACTIONS(2400),
    [anon_sym_unorm] = ACTIONS(2400),
    [anon_sym_point] = ACTIONS(2400),
    [anon_sym_line] = ACTIONS(2400),
    [anon_sym_triangleadj] = ACTIONS(2400),
    [anon_sym_lineadj] = ACTIONS(2400),
    [anon_sym_triangle] = ACTIONS(2400),
  },
  [1857] = {
    [sym_identifier] = ACTIONS(2340),
    [aux_sym_preproc_def_token1] = ACTIONS(2340),
    [aux_sym_preproc_if_token1] = ACTIONS(2340),
    [aux_sym_preproc_if_token2] = ACTIONS(2340),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2340),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2340),
    [aux_sym_preproc_else_token1] = ACTIONS(2340),
    [aux_sym_preproc_elif_token1] = ACTIONS(2340),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2340),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2340),
    [sym_preproc_directive] = ACTIONS(2340),
    [anon_sym_LPAREN2] = ACTIONS(2342),
    [anon_sym_TILDE] = ACTIONS(2342),
    [anon_sym_STAR] = ACTIONS(2342),
    [anon_sym_AMP_AMP] = ACTIONS(2342),
    [anon_sym_AMP] = ACTIONS(2340),
    [anon_sym___extension__] = ACTIONS(2340),
    [anon_sym_typedef] = ACTIONS(2340),
    [anon_sym_in] = ACTIONS(2340),
    [anon_sym_out] = ACTIONS(2340),
    [anon_sym_inout] = ACTIONS(2340),
    [anon_sym_extern] = ACTIONS(2340),
    [anon_sym___attribute__] = ACTIONS(2340),
    [anon_sym_COLON_COLON] = ACTIONS(2342),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2342),
    [anon_sym___declspec] = ACTIONS(2340),
    [anon_sym___based] = ACTIONS(2340),
    [anon_sym_signed] = ACTIONS(2340),
    [anon_sym_unsigned] = ACTIONS(2340),
    [anon_sym_long] = ACTIONS(2340),
    [anon_sym_short] = ACTIONS(2340),
    [anon_sym_LBRACK] = ACTIONS(2340),
    [anon_sym_static] = ACTIONS(2340),
    [anon_sym_register] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(2340),
    [anon_sym___inline] = ACTIONS(2340),
    [anon_sym___inline__] = ACTIONS(2340),
    [anon_sym___forceinline] = ACTIONS(2340),
    [anon_sym_thread_local] = ACTIONS(2340),
    [anon_sym___thread] = ACTIONS(2340),
    [anon_sym_const] = ACTIONS(2340),
    [anon_sym_constexpr] = ACTIONS(2340),
    [anon_sym_volatile] = ACTIONS(2340),
    [anon_sym_restrict] = ACTIONS(2340),
    [anon_sym___restrict__] = ACTIONS(2340),
    [anon_sym__Atomic] = ACTIONS(2340),
    [anon_sym__Noreturn] = ACTIONS(2340),
    [anon_sym_noreturn] = ACTIONS(2340),
    [anon_sym_mutable] = ACTIONS(2340),
    [anon_sym_constinit] = ACTIONS(2340),
    [anon_sym_consteval] = ACTIONS(2340),
    [anon_sym_alignas] = ACTIONS(2340),
    [anon_sym__Alignas] = ACTIONS(2340),
    [sym_primitive_type] = ACTIONS(2340),
    [anon_sym_enum] = ACTIONS(2340),
    [anon_sym_class] = ACTIONS(2340),
    [anon_sym_struct] = ACTIONS(2340),
    [anon_sym_union] = ACTIONS(2340),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2340),
    [anon_sym_decltype] = ACTIONS(2340),
    [sym_virtual] = ACTIONS(2340),
    [anon_sym_explicit] = ACTIONS(2340),
    [anon_sym_typename] = ACTIONS(2340),
    [anon_sym_template] = ACTIONS(2340),
    [anon_sym_operator] = ACTIONS(2340),
    [anon_sym_friend] = ACTIONS(2340),
    [anon_sym_public] = ACTIONS(2340),
    [anon_sym_private] = ACTIONS(2340),
    [anon_sym_protected] = ACTIONS(2340),
    [anon_sym_using] = ACTIONS(2340),
    [anon_sym_static_assert] = ACTIONS(2340),
    [anon_sym_precise] = ACTIONS(2340),
    [anon_sym_shared] = ACTIONS(2340),
    [anon_sym_groupshared] = ACTIONS(2340),
    [anon_sym_uniform] = ACTIONS(2340),
    [anon_sym_row_major] = ACTIONS(2340),
    [anon_sym_column_major] = ACTIONS(2340),
    [anon_sym_globallycoherent] = ACTIONS(2340),
    [anon_sym_centroid] = ACTIONS(2340),
    [anon_sym_noperspective] = ACTIONS(2340),
    [anon_sym_nointerpolation] = ACTIONS(2340),
    [anon_sym_sample] = ACTIONS(2340),
    [anon_sym_linear] = ACTIONS(2340),
    [anon_sym_snorm] = ACTIONS(2340),
    [anon_sym_unorm] = ACTIONS(2340),
    [anon_sym_point] = ACTIONS(2340),
    [anon_sym_line] = ACTIONS(2340),
    [anon_sym_triangleadj] = ACTIONS(2340),
    [anon_sym_lineadj] = ACTIONS(2340),
    [anon_sym_triangle] = ACTIONS(2340),
  },
  [1858] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token2] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [aux_sym_preproc_else_token1] = ACTIONS(2332),
    [aux_sym_preproc_elif_token1] = ACTIONS(2332),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_friend] = ACTIONS(2332),
    [anon_sym_public] = ACTIONS(2332),
    [anon_sym_private] = ACTIONS(2332),
    [anon_sym_protected] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
  },
  [1859] = {
    [sym_identifier] = ACTIONS(5017),
    [aux_sym_preproc_def_token1] = ACTIONS(5017),
    [aux_sym_preproc_if_token1] = ACTIONS(5017),
    [aux_sym_preproc_if_token2] = ACTIONS(5017),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5017),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5017),
    [aux_sym_preproc_else_token1] = ACTIONS(5017),
    [aux_sym_preproc_elif_token1] = ACTIONS(5017),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5017),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5017),
    [sym_preproc_directive] = ACTIONS(5017),
    [anon_sym_LPAREN2] = ACTIONS(5019),
    [anon_sym_TILDE] = ACTIONS(5019),
    [anon_sym_STAR] = ACTIONS(5019),
    [anon_sym_AMP_AMP] = ACTIONS(5019),
    [anon_sym_AMP] = ACTIONS(5017),
    [anon_sym___extension__] = ACTIONS(5017),
    [anon_sym_typedef] = ACTIONS(5017),
    [anon_sym_in] = ACTIONS(5017),
    [anon_sym_out] = ACTIONS(5017),
    [anon_sym_inout] = ACTIONS(5017),
    [anon_sym_extern] = ACTIONS(5017),
    [anon_sym___attribute__] = ACTIONS(5017),
    [anon_sym_COLON_COLON] = ACTIONS(5019),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5019),
    [anon_sym___declspec] = ACTIONS(5017),
    [anon_sym___based] = ACTIONS(5017),
    [anon_sym_signed] = ACTIONS(5017),
    [anon_sym_unsigned] = ACTIONS(5017),
    [anon_sym_long] = ACTIONS(5017),
    [anon_sym_short] = ACTIONS(5017),
    [anon_sym_LBRACK] = ACTIONS(5017),
    [anon_sym_static] = ACTIONS(5017),
    [anon_sym_register] = ACTIONS(5017),
    [anon_sym_inline] = ACTIONS(5017),
    [anon_sym___inline] = ACTIONS(5017),
    [anon_sym___inline__] = ACTIONS(5017),
    [anon_sym___forceinline] = ACTIONS(5017),
    [anon_sym_thread_local] = ACTIONS(5017),
    [anon_sym___thread] = ACTIONS(5017),
    [anon_sym_const] = ACTIONS(5017),
    [anon_sym_constexpr] = ACTIONS(5017),
    [anon_sym_volatile] = ACTIONS(5017),
    [anon_sym_restrict] = ACTIONS(5017),
    [anon_sym___restrict__] = ACTIONS(5017),
    [anon_sym__Atomic] = ACTIONS(5017),
    [anon_sym__Noreturn] = ACTIONS(5017),
    [anon_sym_noreturn] = ACTIONS(5017),
    [anon_sym_mutable] = ACTIONS(5017),
    [anon_sym_constinit] = ACTIONS(5017),
    [anon_sym_consteval] = ACTIONS(5017),
    [anon_sym_alignas] = ACTIONS(5017),
    [anon_sym__Alignas] = ACTIONS(5017),
    [sym_primitive_type] = ACTIONS(5017),
    [anon_sym_enum] = ACTIONS(5017),
    [anon_sym_class] = ACTIONS(5017),
    [anon_sym_struct] = ACTIONS(5017),
    [anon_sym_union] = ACTIONS(5017),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5017),
    [anon_sym_decltype] = ACTIONS(5017),
    [sym_virtual] = ACTIONS(5017),
    [anon_sym_explicit] = ACTIONS(5017),
    [anon_sym_typename] = ACTIONS(5017),
    [anon_sym_template] = ACTIONS(5017),
    [anon_sym_operator] = ACTIONS(5017),
    [anon_sym_friend] = ACTIONS(5017),
    [anon_sym_public] = ACTIONS(5017),
    [anon_sym_private] = ACTIONS(5017),
    [anon_sym_protected] = ACTIONS(5017),
    [anon_sym_using] = ACTIONS(5017),
    [anon_sym_static_assert] = ACTIONS(5017),
    [anon_sym_precise] = ACTIONS(5017),
    [anon_sym_shared] = ACTIONS(5017),
    [anon_sym_groupshared] = ACTIONS(5017),
    [anon_sym_uniform] = ACTIONS(5017),
    [anon_sym_row_major] = ACTIONS(5017),
    [anon_sym_column_major] = ACTIONS(5017),
    [anon_sym_globallycoherent] = ACTIONS(5017),
    [anon_sym_centroid] = ACTIONS(5017),
    [anon_sym_noperspective] = ACTIONS(5017),
    [anon_sym_nointerpolation] = ACTIONS(5017),
    [anon_sym_sample] = ACTIONS(5017),
    [anon_sym_linear] = ACTIONS(5017),
    [anon_sym_snorm] = ACTIONS(5017),
    [anon_sym_unorm] = ACTIONS(5017),
    [anon_sym_point] = ACTIONS(5017),
    [anon_sym_line] = ACTIONS(5017),
    [anon_sym_triangleadj] = ACTIONS(5017),
    [anon_sym_lineadj] = ACTIONS(5017),
    [anon_sym_triangle] = ACTIONS(5017),
  },
  [1860] = {
    [sym_identifier] = ACTIONS(2360),
    [aux_sym_preproc_def_token1] = ACTIONS(2360),
    [aux_sym_preproc_if_token1] = ACTIONS(2360),
    [aux_sym_preproc_if_token2] = ACTIONS(2360),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2360),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2360),
    [aux_sym_preproc_else_token1] = ACTIONS(2360),
    [aux_sym_preproc_elif_token1] = ACTIONS(2360),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2360),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2360),
    [sym_preproc_directive] = ACTIONS(2360),
    [anon_sym_LPAREN2] = ACTIONS(2362),
    [anon_sym_TILDE] = ACTIONS(2362),
    [anon_sym_STAR] = ACTIONS(2362),
    [anon_sym_AMP_AMP] = ACTIONS(2362),
    [anon_sym_AMP] = ACTIONS(2360),
    [anon_sym___extension__] = ACTIONS(2360),
    [anon_sym_typedef] = ACTIONS(2360),
    [anon_sym_in] = ACTIONS(2360),
    [anon_sym_out] = ACTIONS(2360),
    [anon_sym_inout] = ACTIONS(2360),
    [anon_sym_extern] = ACTIONS(2360),
    [anon_sym___attribute__] = ACTIONS(2360),
    [anon_sym_COLON_COLON] = ACTIONS(2362),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2362),
    [anon_sym___declspec] = ACTIONS(2360),
    [anon_sym___based] = ACTIONS(2360),
    [anon_sym_signed] = ACTIONS(2360),
    [anon_sym_unsigned] = ACTIONS(2360),
    [anon_sym_long] = ACTIONS(2360),
    [anon_sym_short] = ACTIONS(2360),
    [anon_sym_LBRACK] = ACTIONS(2360),
    [anon_sym_static] = ACTIONS(2360),
    [anon_sym_register] = ACTIONS(2360),
    [anon_sym_inline] = ACTIONS(2360),
    [anon_sym___inline] = ACTIONS(2360),
    [anon_sym___inline__] = ACTIONS(2360),
    [anon_sym___forceinline] = ACTIONS(2360),
    [anon_sym_thread_local] = ACTIONS(2360),
    [anon_sym___thread] = ACTIONS(2360),
    [anon_sym_const] = ACTIONS(2360),
    [anon_sym_constexpr] = ACTIONS(2360),
    [anon_sym_volatile] = ACTIONS(2360),
    [anon_sym_restrict] = ACTIONS(2360),
    [anon_sym___restrict__] = ACTIONS(2360),
    [anon_sym__Atomic] = ACTIONS(2360),
    [anon_sym__Noreturn] = ACTIONS(2360),
    [anon_sym_noreturn] = ACTIONS(2360),
    [anon_sym_mutable] = ACTIONS(2360),
    [anon_sym_constinit] = ACTIONS(2360),
    [anon_sym_consteval] = ACTIONS(2360),
    [anon_sym_alignas] = ACTIONS(2360),
    [anon_sym__Alignas] = ACTIONS(2360),
    [sym_primitive_type] = ACTIONS(2360),
    [anon_sym_enum] = ACTIONS(2360),
    [anon_sym_class] = ACTIONS(2360),
    [anon_sym_struct] = ACTIONS(2360),
    [anon_sym_union] = ACTIONS(2360),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2360),
    [anon_sym_decltype] = ACTIONS(2360),
    [sym_virtual] = ACTIONS(2360),
    [anon_sym_explicit] = ACTIONS(2360),
    [anon_sym_typename] = ACTIONS(2360),
    [anon_sym_template] = ACTIONS(2360),
    [anon_sym_operator] = ACTIONS(2360),
    [anon_sym_friend] = ACTIONS(2360),
    [anon_sym_public] = ACTIONS(2360),
    [anon_sym_private] = ACTIONS(2360),
    [anon_sym_protected] = ACTIONS(2360),
    [anon_sym_using] = ACTIONS(2360),
    [anon_sym_static_assert] = ACTIONS(2360),
    [anon_sym_precise] = ACTIONS(2360),
    [anon_sym_shared] = ACTIONS(2360),
    [anon_sym_groupshared] = ACTIONS(2360),
    [anon_sym_uniform] = ACTIONS(2360),
    [anon_sym_row_major] = ACTIONS(2360),
    [anon_sym_column_major] = ACTIONS(2360),
    [anon_sym_globallycoherent] = ACTIONS(2360),
    [anon_sym_centroid] = ACTIONS(2360),
    [anon_sym_noperspective] = ACTIONS(2360),
    [anon_sym_nointerpolation] = ACTIONS(2360),
    [anon_sym_sample] = ACTIONS(2360),
    [anon_sym_linear] = ACTIONS(2360),
    [anon_sym_snorm] = ACTIONS(2360),
    [anon_sym_unorm] = ACTIONS(2360),
    [anon_sym_point] = ACTIONS(2360),
    [anon_sym_line] = ACTIONS(2360),
    [anon_sym_triangleadj] = ACTIONS(2360),
    [anon_sym_lineadj] = ACTIONS(2360),
    [anon_sym_triangle] = ACTIONS(2360),
  },
  [1861] = {
    [sym_identifier] = ACTIONS(5021),
    [aux_sym_preproc_def_token1] = ACTIONS(5021),
    [aux_sym_preproc_if_token1] = ACTIONS(5021),
    [aux_sym_preproc_if_token2] = ACTIONS(5021),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5021),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5021),
    [aux_sym_preproc_else_token1] = ACTIONS(5021),
    [aux_sym_preproc_elif_token1] = ACTIONS(5021),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5021),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5021),
    [sym_preproc_directive] = ACTIONS(5021),
    [anon_sym_LPAREN2] = ACTIONS(5023),
    [anon_sym_TILDE] = ACTIONS(5023),
    [anon_sym_STAR] = ACTIONS(5023),
    [anon_sym_AMP_AMP] = ACTIONS(5023),
    [anon_sym_AMP] = ACTIONS(5021),
    [anon_sym___extension__] = ACTIONS(5021),
    [anon_sym_typedef] = ACTIONS(5021),
    [anon_sym_in] = ACTIONS(5021),
    [anon_sym_out] = ACTIONS(5021),
    [anon_sym_inout] = ACTIONS(5021),
    [anon_sym_extern] = ACTIONS(5021),
    [anon_sym___attribute__] = ACTIONS(5021),
    [anon_sym_COLON_COLON] = ACTIONS(5023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5023),
    [anon_sym___declspec] = ACTIONS(5021),
    [anon_sym___based] = ACTIONS(5021),
    [anon_sym_signed] = ACTIONS(5021),
    [anon_sym_unsigned] = ACTIONS(5021),
    [anon_sym_long] = ACTIONS(5021),
    [anon_sym_short] = ACTIONS(5021),
    [anon_sym_LBRACK] = ACTIONS(5021),
    [anon_sym_static] = ACTIONS(5021),
    [anon_sym_register] = ACTIONS(5021),
    [anon_sym_inline] = ACTIONS(5021),
    [anon_sym___inline] = ACTIONS(5021),
    [anon_sym___inline__] = ACTIONS(5021),
    [anon_sym___forceinline] = ACTIONS(5021),
    [anon_sym_thread_local] = ACTIONS(5021),
    [anon_sym___thread] = ACTIONS(5021),
    [anon_sym_const] = ACTIONS(5021),
    [anon_sym_constexpr] = ACTIONS(5021),
    [anon_sym_volatile] = ACTIONS(5021),
    [anon_sym_restrict] = ACTIONS(5021),
    [anon_sym___restrict__] = ACTIONS(5021),
    [anon_sym__Atomic] = ACTIONS(5021),
    [anon_sym__Noreturn] = ACTIONS(5021),
    [anon_sym_noreturn] = ACTIONS(5021),
    [anon_sym_mutable] = ACTIONS(5021),
    [anon_sym_constinit] = ACTIONS(5021),
    [anon_sym_consteval] = ACTIONS(5021),
    [anon_sym_alignas] = ACTIONS(5021),
    [anon_sym__Alignas] = ACTIONS(5021),
    [sym_primitive_type] = ACTIONS(5021),
    [anon_sym_enum] = ACTIONS(5021),
    [anon_sym_class] = ACTIONS(5021),
    [anon_sym_struct] = ACTIONS(5021),
    [anon_sym_union] = ACTIONS(5021),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5021),
    [anon_sym_decltype] = ACTIONS(5021),
    [sym_virtual] = ACTIONS(5021),
    [anon_sym_explicit] = ACTIONS(5021),
    [anon_sym_typename] = ACTIONS(5021),
    [anon_sym_template] = ACTIONS(5021),
    [anon_sym_operator] = ACTIONS(5021),
    [anon_sym_friend] = ACTIONS(5021),
    [anon_sym_public] = ACTIONS(5021),
    [anon_sym_private] = ACTIONS(5021),
    [anon_sym_protected] = ACTIONS(5021),
    [anon_sym_using] = ACTIONS(5021),
    [anon_sym_static_assert] = ACTIONS(5021),
    [anon_sym_precise] = ACTIONS(5021),
    [anon_sym_shared] = ACTIONS(5021),
    [anon_sym_groupshared] = ACTIONS(5021),
    [anon_sym_uniform] = ACTIONS(5021),
    [anon_sym_row_major] = ACTIONS(5021),
    [anon_sym_column_major] = ACTIONS(5021),
    [anon_sym_globallycoherent] = ACTIONS(5021),
    [anon_sym_centroid] = ACTIONS(5021),
    [anon_sym_noperspective] = ACTIONS(5021),
    [anon_sym_nointerpolation] = ACTIONS(5021),
    [anon_sym_sample] = ACTIONS(5021),
    [anon_sym_linear] = ACTIONS(5021),
    [anon_sym_snorm] = ACTIONS(5021),
    [anon_sym_unorm] = ACTIONS(5021),
    [anon_sym_point] = ACTIONS(5021),
    [anon_sym_line] = ACTIONS(5021),
    [anon_sym_triangleadj] = ACTIONS(5021),
    [anon_sym_lineadj] = ACTIONS(5021),
    [anon_sym_triangle] = ACTIONS(5021),
  },
  [1862] = {
    [sym_identifier] = ACTIONS(2565),
    [aux_sym_preproc_def_token1] = ACTIONS(2565),
    [aux_sym_preproc_if_token1] = ACTIONS(2565),
    [aux_sym_preproc_if_token2] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2565),
    [aux_sym_preproc_else_token1] = ACTIONS(2565),
    [aux_sym_preproc_elif_token1] = ACTIONS(2565),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2565),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2565),
    [sym_preproc_directive] = ACTIONS(2565),
    [anon_sym_LPAREN2] = ACTIONS(2567),
    [anon_sym_TILDE] = ACTIONS(2567),
    [anon_sym_STAR] = ACTIONS(2567),
    [anon_sym_AMP_AMP] = ACTIONS(2567),
    [anon_sym_AMP] = ACTIONS(2565),
    [anon_sym___extension__] = ACTIONS(2565),
    [anon_sym_typedef] = ACTIONS(2565),
    [anon_sym_in] = ACTIONS(2565),
    [anon_sym_out] = ACTIONS(2565),
    [anon_sym_inout] = ACTIONS(2565),
    [anon_sym_extern] = ACTIONS(2565),
    [anon_sym___attribute__] = ACTIONS(2565),
    [anon_sym_COLON_COLON] = ACTIONS(2567),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2567),
    [anon_sym___declspec] = ACTIONS(2565),
    [anon_sym___based] = ACTIONS(2565),
    [anon_sym_signed] = ACTIONS(2565),
    [anon_sym_unsigned] = ACTIONS(2565),
    [anon_sym_long] = ACTIONS(2565),
    [anon_sym_short] = ACTIONS(2565),
    [anon_sym_LBRACK] = ACTIONS(2565),
    [anon_sym_static] = ACTIONS(2565),
    [anon_sym_register] = ACTIONS(2565),
    [anon_sym_inline] = ACTIONS(2565),
    [anon_sym___inline] = ACTIONS(2565),
    [anon_sym___inline__] = ACTIONS(2565),
    [anon_sym___forceinline] = ACTIONS(2565),
    [anon_sym_thread_local] = ACTIONS(2565),
    [anon_sym___thread] = ACTIONS(2565),
    [anon_sym_const] = ACTIONS(2565),
    [anon_sym_constexpr] = ACTIONS(2565),
    [anon_sym_volatile] = ACTIONS(2565),
    [anon_sym_restrict] = ACTIONS(2565),
    [anon_sym___restrict__] = ACTIONS(2565),
    [anon_sym__Atomic] = ACTIONS(2565),
    [anon_sym__Noreturn] = ACTIONS(2565),
    [anon_sym_noreturn] = ACTIONS(2565),
    [anon_sym_mutable] = ACTIONS(2565),
    [anon_sym_constinit] = ACTIONS(2565),
    [anon_sym_consteval] = ACTIONS(2565),
    [anon_sym_alignas] = ACTIONS(2565),
    [anon_sym__Alignas] = ACTIONS(2565),
    [sym_primitive_type] = ACTIONS(2565),
    [anon_sym_enum] = ACTIONS(2565),
    [anon_sym_class] = ACTIONS(2565),
    [anon_sym_struct] = ACTIONS(2565),
    [anon_sym_union] = ACTIONS(2565),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2565),
    [anon_sym_decltype] = ACTIONS(2565),
    [sym_virtual] = ACTIONS(2565),
    [anon_sym_explicit] = ACTIONS(2565),
    [anon_sym_typename] = ACTIONS(2565),
    [anon_sym_template] = ACTIONS(2565),
    [anon_sym_operator] = ACTIONS(2565),
    [anon_sym_friend] = ACTIONS(2565),
    [anon_sym_public] = ACTIONS(2565),
    [anon_sym_private] = ACTIONS(2565),
    [anon_sym_protected] = ACTIONS(2565),
    [anon_sym_using] = ACTIONS(2565),
    [anon_sym_static_assert] = ACTIONS(2565),
    [anon_sym_precise] = ACTIONS(2565),
    [anon_sym_shared] = ACTIONS(2565),
    [anon_sym_groupshared] = ACTIONS(2565),
    [anon_sym_uniform] = ACTIONS(2565),
    [anon_sym_row_major] = ACTIONS(2565),
    [anon_sym_column_major] = ACTIONS(2565),
    [anon_sym_globallycoherent] = ACTIONS(2565),
    [anon_sym_centroid] = ACTIONS(2565),
    [anon_sym_noperspective] = ACTIONS(2565),
    [anon_sym_nointerpolation] = ACTIONS(2565),
    [anon_sym_sample] = ACTIONS(2565),
    [anon_sym_linear] = ACTIONS(2565),
    [anon_sym_snorm] = ACTIONS(2565),
    [anon_sym_unorm] = ACTIONS(2565),
    [anon_sym_point] = ACTIONS(2565),
    [anon_sym_line] = ACTIONS(2565),
    [anon_sym_triangleadj] = ACTIONS(2565),
    [anon_sym_lineadj] = ACTIONS(2565),
    [anon_sym_triangle] = ACTIONS(2565),
  },
  [1863] = {
    [sym_identifier] = ACTIONS(2336),
    [aux_sym_preproc_def_token1] = ACTIONS(2336),
    [aux_sym_preproc_if_token1] = ACTIONS(2336),
    [aux_sym_preproc_if_token2] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2336),
    [aux_sym_preproc_else_token1] = ACTIONS(2336),
    [aux_sym_preproc_elif_token1] = ACTIONS(2336),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2336),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2336),
    [sym_preproc_directive] = ACTIONS(2336),
    [anon_sym_LPAREN2] = ACTIONS(2338),
    [anon_sym_TILDE] = ACTIONS(2338),
    [anon_sym_STAR] = ACTIONS(2338),
    [anon_sym_AMP_AMP] = ACTIONS(2338),
    [anon_sym_AMP] = ACTIONS(2336),
    [anon_sym___extension__] = ACTIONS(2336),
    [anon_sym_typedef] = ACTIONS(2336),
    [anon_sym_in] = ACTIONS(2336),
    [anon_sym_out] = ACTIONS(2336),
    [anon_sym_inout] = ACTIONS(2336),
    [anon_sym_extern] = ACTIONS(2336),
    [anon_sym___attribute__] = ACTIONS(2336),
    [anon_sym_COLON_COLON] = ACTIONS(2338),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2338),
    [anon_sym___declspec] = ACTIONS(2336),
    [anon_sym___based] = ACTIONS(2336),
    [anon_sym_signed] = ACTIONS(2336),
    [anon_sym_unsigned] = ACTIONS(2336),
    [anon_sym_long] = ACTIONS(2336),
    [anon_sym_short] = ACTIONS(2336),
    [anon_sym_LBRACK] = ACTIONS(2336),
    [anon_sym_static] = ACTIONS(2336),
    [anon_sym_register] = ACTIONS(2336),
    [anon_sym_inline] = ACTIONS(2336),
    [anon_sym___inline] = ACTIONS(2336),
    [anon_sym___inline__] = ACTIONS(2336),
    [anon_sym___forceinline] = ACTIONS(2336),
    [anon_sym_thread_local] = ACTIONS(2336),
    [anon_sym___thread] = ACTIONS(2336),
    [anon_sym_const] = ACTIONS(2336),
    [anon_sym_constexpr] = ACTIONS(2336),
    [anon_sym_volatile] = ACTIONS(2336),
    [anon_sym_restrict] = ACTIONS(2336),
    [anon_sym___restrict__] = ACTIONS(2336),
    [anon_sym__Atomic] = ACTIONS(2336),
    [anon_sym__Noreturn] = ACTIONS(2336),
    [anon_sym_noreturn] = ACTIONS(2336),
    [anon_sym_mutable] = ACTIONS(2336),
    [anon_sym_constinit] = ACTIONS(2336),
    [anon_sym_consteval] = ACTIONS(2336),
    [anon_sym_alignas] = ACTIONS(2336),
    [anon_sym__Alignas] = ACTIONS(2336),
    [sym_primitive_type] = ACTIONS(2336),
    [anon_sym_enum] = ACTIONS(2336),
    [anon_sym_class] = ACTIONS(2336),
    [anon_sym_struct] = ACTIONS(2336),
    [anon_sym_union] = ACTIONS(2336),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2336),
    [anon_sym_decltype] = ACTIONS(2336),
    [sym_virtual] = ACTIONS(2336),
    [anon_sym_explicit] = ACTIONS(2336),
    [anon_sym_typename] = ACTIONS(2336),
    [anon_sym_template] = ACTIONS(2336),
    [anon_sym_operator] = ACTIONS(2336),
    [anon_sym_friend] = ACTIONS(2336),
    [anon_sym_public] = ACTIONS(2336),
    [anon_sym_private] = ACTIONS(2336),
    [anon_sym_protected] = ACTIONS(2336),
    [anon_sym_using] = ACTIONS(2336),
    [anon_sym_static_assert] = ACTIONS(2336),
    [anon_sym_precise] = ACTIONS(2336),
    [anon_sym_shared] = ACTIONS(2336),
    [anon_sym_groupshared] = ACTIONS(2336),
    [anon_sym_uniform] = ACTIONS(2336),
    [anon_sym_row_major] = ACTIONS(2336),
    [anon_sym_column_major] = ACTIONS(2336),
    [anon_sym_globallycoherent] = ACTIONS(2336),
    [anon_sym_centroid] = ACTIONS(2336),
    [anon_sym_noperspective] = ACTIONS(2336),
    [anon_sym_nointerpolation] = ACTIONS(2336),
    [anon_sym_sample] = ACTIONS(2336),
    [anon_sym_linear] = ACTIONS(2336),
    [anon_sym_snorm] = ACTIONS(2336),
    [anon_sym_unorm] = ACTIONS(2336),
    [anon_sym_point] = ACTIONS(2336),
    [anon_sym_line] = ACTIONS(2336),
    [anon_sym_triangleadj] = ACTIONS(2336),
    [anon_sym_lineadj] = ACTIONS(2336),
    [anon_sym_triangle] = ACTIONS(2336),
  },
  [1864] = {
    [sym_identifier] = ACTIONS(2549),
    [aux_sym_preproc_def_token1] = ACTIONS(2549),
    [aux_sym_preproc_if_token1] = ACTIONS(2549),
    [aux_sym_preproc_if_token2] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2549),
    [aux_sym_preproc_else_token1] = ACTIONS(2549),
    [aux_sym_preproc_elif_token1] = ACTIONS(2549),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2549),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2549),
    [sym_preproc_directive] = ACTIONS(2549),
    [anon_sym_LPAREN2] = ACTIONS(2551),
    [anon_sym_TILDE] = ACTIONS(2551),
    [anon_sym_STAR] = ACTIONS(2551),
    [anon_sym_AMP_AMP] = ACTIONS(2551),
    [anon_sym_AMP] = ACTIONS(2549),
    [anon_sym___extension__] = ACTIONS(2549),
    [anon_sym_typedef] = ACTIONS(2549),
    [anon_sym_in] = ACTIONS(2549),
    [anon_sym_out] = ACTIONS(2549),
    [anon_sym_inout] = ACTIONS(2549),
    [anon_sym_extern] = ACTIONS(2549),
    [anon_sym___attribute__] = ACTIONS(2549),
    [anon_sym_COLON_COLON] = ACTIONS(2551),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2551),
    [anon_sym___declspec] = ACTIONS(2549),
    [anon_sym___based] = ACTIONS(2549),
    [anon_sym_signed] = ACTIONS(2549),
    [anon_sym_unsigned] = ACTIONS(2549),
    [anon_sym_long] = ACTIONS(2549),
    [anon_sym_short] = ACTIONS(2549),
    [anon_sym_LBRACK] = ACTIONS(2549),
    [anon_sym_static] = ACTIONS(2549),
    [anon_sym_register] = ACTIONS(2549),
    [anon_sym_inline] = ACTIONS(2549),
    [anon_sym___inline] = ACTIONS(2549),
    [anon_sym___inline__] = ACTIONS(2549),
    [anon_sym___forceinline] = ACTIONS(2549),
    [anon_sym_thread_local] = ACTIONS(2549),
    [anon_sym___thread] = ACTIONS(2549),
    [anon_sym_const] = ACTIONS(2549),
    [anon_sym_constexpr] = ACTIONS(2549),
    [anon_sym_volatile] = ACTIONS(2549),
    [anon_sym_restrict] = ACTIONS(2549),
    [anon_sym___restrict__] = ACTIONS(2549),
    [anon_sym__Atomic] = ACTIONS(2549),
    [anon_sym__Noreturn] = ACTIONS(2549),
    [anon_sym_noreturn] = ACTIONS(2549),
    [anon_sym_mutable] = ACTIONS(2549),
    [anon_sym_constinit] = ACTIONS(2549),
    [anon_sym_consteval] = ACTIONS(2549),
    [anon_sym_alignas] = ACTIONS(2549),
    [anon_sym__Alignas] = ACTIONS(2549),
    [sym_primitive_type] = ACTIONS(2549),
    [anon_sym_enum] = ACTIONS(2549),
    [anon_sym_class] = ACTIONS(2549),
    [anon_sym_struct] = ACTIONS(2549),
    [anon_sym_union] = ACTIONS(2549),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2549),
    [anon_sym_decltype] = ACTIONS(2549),
    [sym_virtual] = ACTIONS(2549),
    [anon_sym_explicit] = ACTIONS(2549),
    [anon_sym_typename] = ACTIONS(2549),
    [anon_sym_template] = ACTIONS(2549),
    [anon_sym_operator] = ACTIONS(2549),
    [anon_sym_friend] = ACTIONS(2549),
    [anon_sym_public] = ACTIONS(2549),
    [anon_sym_private] = ACTIONS(2549),
    [anon_sym_protected] = ACTIONS(2549),
    [anon_sym_using] = ACTIONS(2549),
    [anon_sym_static_assert] = ACTIONS(2549),
    [anon_sym_precise] = ACTIONS(2549),
    [anon_sym_shared] = ACTIONS(2549),
    [anon_sym_groupshared] = ACTIONS(2549),
    [anon_sym_uniform] = ACTIONS(2549),
    [anon_sym_row_major] = ACTIONS(2549),
    [anon_sym_column_major] = ACTIONS(2549),
    [anon_sym_globallycoherent] = ACTIONS(2549),
    [anon_sym_centroid] = ACTIONS(2549),
    [anon_sym_noperspective] = ACTIONS(2549),
    [anon_sym_nointerpolation] = ACTIONS(2549),
    [anon_sym_sample] = ACTIONS(2549),
    [anon_sym_linear] = ACTIONS(2549),
    [anon_sym_snorm] = ACTIONS(2549),
    [anon_sym_unorm] = ACTIONS(2549),
    [anon_sym_point] = ACTIONS(2549),
    [anon_sym_line] = ACTIONS(2549),
    [anon_sym_triangleadj] = ACTIONS(2549),
    [anon_sym_lineadj] = ACTIONS(2549),
    [anon_sym_triangle] = ACTIONS(2549),
  },
  [1865] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token2] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [aux_sym_preproc_else_token1] = ACTIONS(2332),
    [aux_sym_preproc_elif_token1] = ACTIONS(2332),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_friend] = ACTIONS(2332),
    [anon_sym_public] = ACTIONS(2332),
    [anon_sym_private] = ACTIONS(2332),
    [anon_sym_protected] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
  },
  [1866] = {
    [sym_identifier] = ACTIONS(2393),
    [aux_sym_preproc_def_token1] = ACTIONS(2393),
    [aux_sym_preproc_if_token1] = ACTIONS(2393),
    [aux_sym_preproc_if_token2] = ACTIONS(2393),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2393),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2393),
    [aux_sym_preproc_else_token1] = ACTIONS(2393),
    [aux_sym_preproc_elif_token1] = ACTIONS(2393),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2393),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2393),
    [sym_preproc_directive] = ACTIONS(2393),
    [anon_sym_LPAREN2] = ACTIONS(2395),
    [anon_sym_TILDE] = ACTIONS(2395),
    [anon_sym_STAR] = ACTIONS(2395),
    [anon_sym_AMP_AMP] = ACTIONS(2395),
    [anon_sym_AMP] = ACTIONS(2393),
    [anon_sym___extension__] = ACTIONS(2393),
    [anon_sym_typedef] = ACTIONS(2393),
    [anon_sym_in] = ACTIONS(2393),
    [anon_sym_out] = ACTIONS(2393),
    [anon_sym_inout] = ACTIONS(2393),
    [anon_sym_extern] = ACTIONS(2393),
    [anon_sym___attribute__] = ACTIONS(2393),
    [anon_sym_COLON_COLON] = ACTIONS(2395),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2395),
    [anon_sym___declspec] = ACTIONS(2393),
    [anon_sym___based] = ACTIONS(2393),
    [anon_sym_signed] = ACTIONS(2393),
    [anon_sym_unsigned] = ACTIONS(2393),
    [anon_sym_long] = ACTIONS(2393),
    [anon_sym_short] = ACTIONS(2393),
    [anon_sym_LBRACK] = ACTIONS(2393),
    [anon_sym_static] = ACTIONS(2393),
    [anon_sym_register] = ACTIONS(2393),
    [anon_sym_inline] = ACTIONS(2393),
    [anon_sym___inline] = ACTIONS(2393),
    [anon_sym___inline__] = ACTIONS(2393),
    [anon_sym___forceinline] = ACTIONS(2393),
    [anon_sym_thread_local] = ACTIONS(2393),
    [anon_sym___thread] = ACTIONS(2393),
    [anon_sym_const] = ACTIONS(2393),
    [anon_sym_constexpr] = ACTIONS(2393),
    [anon_sym_volatile] = ACTIONS(2393),
    [anon_sym_restrict] = ACTIONS(2393),
    [anon_sym___restrict__] = ACTIONS(2393),
    [anon_sym__Atomic] = ACTIONS(2393),
    [anon_sym__Noreturn] = ACTIONS(2393),
    [anon_sym_noreturn] = ACTIONS(2393),
    [anon_sym_mutable] = ACTIONS(2393),
    [anon_sym_constinit] = ACTIONS(2393),
    [anon_sym_consteval] = ACTIONS(2393),
    [anon_sym_alignas] = ACTIONS(2393),
    [anon_sym__Alignas] = ACTIONS(2393),
    [sym_primitive_type] = ACTIONS(2393),
    [anon_sym_enum] = ACTIONS(2393),
    [anon_sym_class] = ACTIONS(2393),
    [anon_sym_struct] = ACTIONS(2393),
    [anon_sym_union] = ACTIONS(2393),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2393),
    [anon_sym_decltype] = ACTIONS(2393),
    [sym_virtual] = ACTIONS(2393),
    [anon_sym_explicit] = ACTIONS(2393),
    [anon_sym_typename] = ACTIONS(2393),
    [anon_sym_template] = ACTIONS(2393),
    [anon_sym_operator] = ACTIONS(2393),
    [anon_sym_friend] = ACTIONS(2393),
    [anon_sym_public] = ACTIONS(2393),
    [anon_sym_private] = ACTIONS(2393),
    [anon_sym_protected] = ACTIONS(2393),
    [anon_sym_using] = ACTIONS(2393),
    [anon_sym_static_assert] = ACTIONS(2393),
    [anon_sym_precise] = ACTIONS(2393),
    [anon_sym_shared] = ACTIONS(2393),
    [anon_sym_groupshared] = ACTIONS(2393),
    [anon_sym_uniform] = ACTIONS(2393),
    [anon_sym_row_major] = ACTIONS(2393),
    [anon_sym_column_major] = ACTIONS(2393),
    [anon_sym_globallycoherent] = ACTIONS(2393),
    [anon_sym_centroid] = ACTIONS(2393),
    [anon_sym_noperspective] = ACTIONS(2393),
    [anon_sym_nointerpolation] = ACTIONS(2393),
    [anon_sym_sample] = ACTIONS(2393),
    [anon_sym_linear] = ACTIONS(2393),
    [anon_sym_snorm] = ACTIONS(2393),
    [anon_sym_unorm] = ACTIONS(2393),
    [anon_sym_point] = ACTIONS(2393),
    [anon_sym_line] = ACTIONS(2393),
    [anon_sym_triangleadj] = ACTIONS(2393),
    [anon_sym_lineadj] = ACTIONS(2393),
    [anon_sym_triangle] = ACTIONS(2393),
  },
  [1867] = {
    [sym_identifier] = ACTIONS(2389),
    [aux_sym_preproc_def_token1] = ACTIONS(2389),
    [aux_sym_preproc_if_token1] = ACTIONS(2389),
    [aux_sym_preproc_if_token2] = ACTIONS(2389),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2389),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2389),
    [aux_sym_preproc_else_token1] = ACTIONS(2389),
    [aux_sym_preproc_elif_token1] = ACTIONS(2389),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2389),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2389),
    [sym_preproc_directive] = ACTIONS(2389),
    [anon_sym_LPAREN2] = ACTIONS(2391),
    [anon_sym_TILDE] = ACTIONS(2391),
    [anon_sym_STAR] = ACTIONS(2391),
    [anon_sym_AMP_AMP] = ACTIONS(2391),
    [anon_sym_AMP] = ACTIONS(2389),
    [anon_sym___extension__] = ACTIONS(2389),
    [anon_sym_typedef] = ACTIONS(2389),
    [anon_sym_in] = ACTIONS(2389),
    [anon_sym_out] = ACTIONS(2389),
    [anon_sym_inout] = ACTIONS(2389),
    [anon_sym_extern] = ACTIONS(2389),
    [anon_sym___attribute__] = ACTIONS(2389),
    [anon_sym_COLON_COLON] = ACTIONS(2391),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2391),
    [anon_sym___declspec] = ACTIONS(2389),
    [anon_sym___based] = ACTIONS(2389),
    [anon_sym_signed] = ACTIONS(2389),
    [anon_sym_unsigned] = ACTIONS(2389),
    [anon_sym_long] = ACTIONS(2389),
    [anon_sym_short] = ACTIONS(2389),
    [anon_sym_LBRACK] = ACTIONS(2389),
    [anon_sym_static] = ACTIONS(2389),
    [anon_sym_register] = ACTIONS(2389),
    [anon_sym_inline] = ACTIONS(2389),
    [anon_sym___inline] = ACTIONS(2389),
    [anon_sym___inline__] = ACTIONS(2389),
    [anon_sym___forceinline] = ACTIONS(2389),
    [anon_sym_thread_local] = ACTIONS(2389),
    [anon_sym___thread] = ACTIONS(2389),
    [anon_sym_const] = ACTIONS(2389),
    [anon_sym_constexpr] = ACTIONS(2389),
    [anon_sym_volatile] = ACTIONS(2389),
    [anon_sym_restrict] = ACTIONS(2389),
    [anon_sym___restrict__] = ACTIONS(2389),
    [anon_sym__Atomic] = ACTIONS(2389),
    [anon_sym__Noreturn] = ACTIONS(2389),
    [anon_sym_noreturn] = ACTIONS(2389),
    [anon_sym_mutable] = ACTIONS(2389),
    [anon_sym_constinit] = ACTIONS(2389),
    [anon_sym_consteval] = ACTIONS(2389),
    [anon_sym_alignas] = ACTIONS(2389),
    [anon_sym__Alignas] = ACTIONS(2389),
    [sym_primitive_type] = ACTIONS(2389),
    [anon_sym_enum] = ACTIONS(2389),
    [anon_sym_class] = ACTIONS(2389),
    [anon_sym_struct] = ACTIONS(2389),
    [anon_sym_union] = ACTIONS(2389),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2389),
    [anon_sym_decltype] = ACTIONS(2389),
    [sym_virtual] = ACTIONS(2389),
    [anon_sym_explicit] = ACTIONS(2389),
    [anon_sym_typename] = ACTIONS(2389),
    [anon_sym_template] = ACTIONS(2389),
    [anon_sym_operator] = ACTIONS(2389),
    [anon_sym_friend] = ACTIONS(2389),
    [anon_sym_public] = ACTIONS(2389),
    [anon_sym_private] = ACTIONS(2389),
    [anon_sym_protected] = ACTIONS(2389),
    [anon_sym_using] = ACTIONS(2389),
    [anon_sym_static_assert] = ACTIONS(2389),
    [anon_sym_precise] = ACTIONS(2389),
    [anon_sym_shared] = ACTIONS(2389),
    [anon_sym_groupshared] = ACTIONS(2389),
    [anon_sym_uniform] = ACTIONS(2389),
    [anon_sym_row_major] = ACTIONS(2389),
    [anon_sym_column_major] = ACTIONS(2389),
    [anon_sym_globallycoherent] = ACTIONS(2389),
    [anon_sym_centroid] = ACTIONS(2389),
    [anon_sym_noperspective] = ACTIONS(2389),
    [anon_sym_nointerpolation] = ACTIONS(2389),
    [anon_sym_sample] = ACTIONS(2389),
    [anon_sym_linear] = ACTIONS(2389),
    [anon_sym_snorm] = ACTIONS(2389),
    [anon_sym_unorm] = ACTIONS(2389),
    [anon_sym_point] = ACTIONS(2389),
    [anon_sym_line] = ACTIONS(2389),
    [anon_sym_triangleadj] = ACTIONS(2389),
    [anon_sym_lineadj] = ACTIONS(2389),
    [anon_sym_triangle] = ACTIONS(2389),
  },
  [1868] = {
    [sym_identifier] = ACTIONS(2316),
    [aux_sym_preproc_def_token1] = ACTIONS(2316),
    [aux_sym_preproc_if_token1] = ACTIONS(2316),
    [aux_sym_preproc_if_token2] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2316),
    [aux_sym_preproc_else_token1] = ACTIONS(2316),
    [aux_sym_preproc_elif_token1] = ACTIONS(2316),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2316),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2316),
    [sym_preproc_directive] = ACTIONS(2316),
    [anon_sym_LPAREN2] = ACTIONS(2318),
    [anon_sym_TILDE] = ACTIONS(2318),
    [anon_sym_STAR] = ACTIONS(2318),
    [anon_sym_AMP_AMP] = ACTIONS(2318),
    [anon_sym_AMP] = ACTIONS(2316),
    [anon_sym___extension__] = ACTIONS(2316),
    [anon_sym_typedef] = ACTIONS(2316),
    [anon_sym_in] = ACTIONS(2316),
    [anon_sym_out] = ACTIONS(2316),
    [anon_sym_inout] = ACTIONS(2316),
    [anon_sym_extern] = ACTIONS(2316),
    [anon_sym___attribute__] = ACTIONS(2316),
    [anon_sym_COLON_COLON] = ACTIONS(2318),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2318),
    [anon_sym___declspec] = ACTIONS(2316),
    [anon_sym___based] = ACTIONS(2316),
    [anon_sym_signed] = ACTIONS(2316),
    [anon_sym_unsigned] = ACTIONS(2316),
    [anon_sym_long] = ACTIONS(2316),
    [anon_sym_short] = ACTIONS(2316),
    [anon_sym_LBRACK] = ACTIONS(2316),
    [anon_sym_static] = ACTIONS(2316),
    [anon_sym_register] = ACTIONS(2316),
    [anon_sym_inline] = ACTIONS(2316),
    [anon_sym___inline] = ACTIONS(2316),
    [anon_sym___inline__] = ACTIONS(2316),
    [anon_sym___forceinline] = ACTIONS(2316),
    [anon_sym_thread_local] = ACTIONS(2316),
    [anon_sym___thread] = ACTIONS(2316),
    [anon_sym_const] = ACTIONS(2316),
    [anon_sym_constexpr] = ACTIONS(2316),
    [anon_sym_volatile] = ACTIONS(2316),
    [anon_sym_restrict] = ACTIONS(2316),
    [anon_sym___restrict__] = ACTIONS(2316),
    [anon_sym__Atomic] = ACTIONS(2316),
    [anon_sym__Noreturn] = ACTIONS(2316),
    [anon_sym_noreturn] = ACTIONS(2316),
    [anon_sym_mutable] = ACTIONS(2316),
    [anon_sym_constinit] = ACTIONS(2316),
    [anon_sym_consteval] = ACTIONS(2316),
    [anon_sym_alignas] = ACTIONS(2316),
    [anon_sym__Alignas] = ACTIONS(2316),
    [sym_primitive_type] = ACTIONS(2316),
    [anon_sym_enum] = ACTIONS(2316),
    [anon_sym_class] = ACTIONS(2316),
    [anon_sym_struct] = ACTIONS(2316),
    [anon_sym_union] = ACTIONS(2316),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2316),
    [anon_sym_decltype] = ACTIONS(2316),
    [sym_virtual] = ACTIONS(2316),
    [anon_sym_explicit] = ACTIONS(2316),
    [anon_sym_typename] = ACTIONS(2316),
    [anon_sym_template] = ACTIONS(2316),
    [anon_sym_operator] = ACTIONS(2316),
    [anon_sym_friend] = ACTIONS(2316),
    [anon_sym_public] = ACTIONS(2316),
    [anon_sym_private] = ACTIONS(2316),
    [anon_sym_protected] = ACTIONS(2316),
    [anon_sym_using] = ACTIONS(2316),
    [anon_sym_static_assert] = ACTIONS(2316),
    [anon_sym_precise] = ACTIONS(2316),
    [anon_sym_shared] = ACTIONS(2316),
    [anon_sym_groupshared] = ACTIONS(2316),
    [anon_sym_uniform] = ACTIONS(2316),
    [anon_sym_row_major] = ACTIONS(2316),
    [anon_sym_column_major] = ACTIONS(2316),
    [anon_sym_globallycoherent] = ACTIONS(2316),
    [anon_sym_centroid] = ACTIONS(2316),
    [anon_sym_noperspective] = ACTIONS(2316),
    [anon_sym_nointerpolation] = ACTIONS(2316),
    [anon_sym_sample] = ACTIONS(2316),
    [anon_sym_linear] = ACTIONS(2316),
    [anon_sym_snorm] = ACTIONS(2316),
    [anon_sym_unorm] = ACTIONS(2316),
    [anon_sym_point] = ACTIONS(2316),
    [anon_sym_line] = ACTIONS(2316),
    [anon_sym_triangleadj] = ACTIONS(2316),
    [anon_sym_lineadj] = ACTIONS(2316),
    [anon_sym_triangle] = ACTIONS(2316),
  },
  [1869] = {
    [sym_identifier] = ACTIONS(2336),
    [aux_sym_preproc_def_token1] = ACTIONS(2336),
    [aux_sym_preproc_if_token1] = ACTIONS(2336),
    [aux_sym_preproc_if_token2] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2336),
    [aux_sym_preproc_else_token1] = ACTIONS(2336),
    [aux_sym_preproc_elif_token1] = ACTIONS(2336),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2336),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2336),
    [sym_preproc_directive] = ACTIONS(2336),
    [anon_sym_LPAREN2] = ACTIONS(2338),
    [anon_sym_TILDE] = ACTIONS(2338),
    [anon_sym_STAR] = ACTIONS(2338),
    [anon_sym_AMP_AMP] = ACTIONS(2338),
    [anon_sym_AMP] = ACTIONS(2336),
    [anon_sym___extension__] = ACTIONS(2336),
    [anon_sym_typedef] = ACTIONS(2336),
    [anon_sym_in] = ACTIONS(2336),
    [anon_sym_out] = ACTIONS(2336),
    [anon_sym_inout] = ACTIONS(2336),
    [anon_sym_extern] = ACTIONS(2336),
    [anon_sym___attribute__] = ACTIONS(2336),
    [anon_sym_COLON_COLON] = ACTIONS(2338),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2338),
    [anon_sym___declspec] = ACTIONS(2336),
    [anon_sym___based] = ACTIONS(2336),
    [anon_sym_signed] = ACTIONS(2336),
    [anon_sym_unsigned] = ACTIONS(2336),
    [anon_sym_long] = ACTIONS(2336),
    [anon_sym_short] = ACTIONS(2336),
    [anon_sym_LBRACK] = ACTIONS(2336),
    [anon_sym_static] = ACTIONS(2336),
    [anon_sym_register] = ACTIONS(2336),
    [anon_sym_inline] = ACTIONS(2336),
    [anon_sym___inline] = ACTIONS(2336),
    [anon_sym___inline__] = ACTIONS(2336),
    [anon_sym___forceinline] = ACTIONS(2336),
    [anon_sym_thread_local] = ACTIONS(2336),
    [anon_sym___thread] = ACTIONS(2336),
    [anon_sym_const] = ACTIONS(2336),
    [anon_sym_constexpr] = ACTIONS(2336),
    [anon_sym_volatile] = ACTIONS(2336),
    [anon_sym_restrict] = ACTIONS(2336),
    [anon_sym___restrict__] = ACTIONS(2336),
    [anon_sym__Atomic] = ACTIONS(2336),
    [anon_sym__Noreturn] = ACTIONS(2336),
    [anon_sym_noreturn] = ACTIONS(2336),
    [anon_sym_mutable] = ACTIONS(2336),
    [anon_sym_constinit] = ACTIONS(2336),
    [anon_sym_consteval] = ACTIONS(2336),
    [anon_sym_alignas] = ACTIONS(2336),
    [anon_sym__Alignas] = ACTIONS(2336),
    [sym_primitive_type] = ACTIONS(2336),
    [anon_sym_enum] = ACTIONS(2336),
    [anon_sym_class] = ACTIONS(2336),
    [anon_sym_struct] = ACTIONS(2336),
    [anon_sym_union] = ACTIONS(2336),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2336),
    [anon_sym_decltype] = ACTIONS(2336),
    [sym_virtual] = ACTIONS(2336),
    [anon_sym_explicit] = ACTIONS(2336),
    [anon_sym_typename] = ACTIONS(2336),
    [anon_sym_template] = ACTIONS(2336),
    [anon_sym_operator] = ACTIONS(2336),
    [anon_sym_friend] = ACTIONS(2336),
    [anon_sym_public] = ACTIONS(2336),
    [anon_sym_private] = ACTIONS(2336),
    [anon_sym_protected] = ACTIONS(2336),
    [anon_sym_using] = ACTIONS(2336),
    [anon_sym_static_assert] = ACTIONS(2336),
    [anon_sym_precise] = ACTIONS(2336),
    [anon_sym_shared] = ACTIONS(2336),
    [anon_sym_groupshared] = ACTIONS(2336),
    [anon_sym_uniform] = ACTIONS(2336),
    [anon_sym_row_major] = ACTIONS(2336),
    [anon_sym_column_major] = ACTIONS(2336),
    [anon_sym_globallycoherent] = ACTIONS(2336),
    [anon_sym_centroid] = ACTIONS(2336),
    [anon_sym_noperspective] = ACTIONS(2336),
    [anon_sym_nointerpolation] = ACTIONS(2336),
    [anon_sym_sample] = ACTIONS(2336),
    [anon_sym_linear] = ACTIONS(2336),
    [anon_sym_snorm] = ACTIONS(2336),
    [anon_sym_unorm] = ACTIONS(2336),
    [anon_sym_point] = ACTIONS(2336),
    [anon_sym_line] = ACTIONS(2336),
    [anon_sym_triangleadj] = ACTIONS(2336),
    [anon_sym_lineadj] = ACTIONS(2336),
    [anon_sym_triangle] = ACTIONS(2336),
  },
  [1870] = {
    [sym_identifier] = ACTIONS(5025),
    [aux_sym_preproc_def_token1] = ACTIONS(5025),
    [aux_sym_preproc_if_token1] = ACTIONS(5025),
    [aux_sym_preproc_if_token2] = ACTIONS(5025),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5025),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5025),
    [aux_sym_preproc_else_token1] = ACTIONS(5025),
    [aux_sym_preproc_elif_token1] = ACTIONS(5025),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5025),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5025),
    [sym_preproc_directive] = ACTIONS(5025),
    [anon_sym_LPAREN2] = ACTIONS(5027),
    [anon_sym_TILDE] = ACTIONS(5027),
    [anon_sym_STAR] = ACTIONS(5027),
    [anon_sym_AMP_AMP] = ACTIONS(5027),
    [anon_sym_AMP] = ACTIONS(5025),
    [anon_sym___extension__] = ACTIONS(5025),
    [anon_sym_typedef] = ACTIONS(5025),
    [anon_sym_in] = ACTIONS(5025),
    [anon_sym_out] = ACTIONS(5025),
    [anon_sym_inout] = ACTIONS(5025),
    [anon_sym_extern] = ACTIONS(5025),
    [anon_sym___attribute__] = ACTIONS(5025),
    [anon_sym_COLON_COLON] = ACTIONS(5027),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5027),
    [anon_sym___declspec] = ACTIONS(5025),
    [anon_sym___based] = ACTIONS(5025),
    [anon_sym_signed] = ACTIONS(5025),
    [anon_sym_unsigned] = ACTIONS(5025),
    [anon_sym_long] = ACTIONS(5025),
    [anon_sym_short] = ACTIONS(5025),
    [anon_sym_LBRACK] = ACTIONS(5025),
    [anon_sym_static] = ACTIONS(5025),
    [anon_sym_register] = ACTIONS(5025),
    [anon_sym_inline] = ACTIONS(5025),
    [anon_sym___inline] = ACTIONS(5025),
    [anon_sym___inline__] = ACTIONS(5025),
    [anon_sym___forceinline] = ACTIONS(5025),
    [anon_sym_thread_local] = ACTIONS(5025),
    [anon_sym___thread] = ACTIONS(5025),
    [anon_sym_const] = ACTIONS(5025),
    [anon_sym_constexpr] = ACTIONS(5025),
    [anon_sym_volatile] = ACTIONS(5025),
    [anon_sym_restrict] = ACTIONS(5025),
    [anon_sym___restrict__] = ACTIONS(5025),
    [anon_sym__Atomic] = ACTIONS(5025),
    [anon_sym__Noreturn] = ACTIONS(5025),
    [anon_sym_noreturn] = ACTIONS(5025),
    [anon_sym_mutable] = ACTIONS(5025),
    [anon_sym_constinit] = ACTIONS(5025),
    [anon_sym_consteval] = ACTIONS(5025),
    [anon_sym_alignas] = ACTIONS(5025),
    [anon_sym__Alignas] = ACTIONS(5025),
    [sym_primitive_type] = ACTIONS(5025),
    [anon_sym_enum] = ACTIONS(5025),
    [anon_sym_class] = ACTIONS(5025),
    [anon_sym_struct] = ACTIONS(5025),
    [anon_sym_union] = ACTIONS(5025),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5025),
    [anon_sym_decltype] = ACTIONS(5025),
    [sym_virtual] = ACTIONS(5025),
    [anon_sym_explicit] = ACTIONS(5025),
    [anon_sym_typename] = ACTIONS(5025),
    [anon_sym_template] = ACTIONS(5025),
    [anon_sym_operator] = ACTIONS(5025),
    [anon_sym_friend] = ACTIONS(5025),
    [anon_sym_public] = ACTIONS(5025),
    [anon_sym_private] = ACTIONS(5025),
    [anon_sym_protected] = ACTIONS(5025),
    [anon_sym_using] = ACTIONS(5025),
    [anon_sym_static_assert] = ACTIONS(5025),
    [anon_sym_precise] = ACTIONS(5025),
    [anon_sym_shared] = ACTIONS(5025),
    [anon_sym_groupshared] = ACTIONS(5025),
    [anon_sym_uniform] = ACTIONS(5025),
    [anon_sym_row_major] = ACTIONS(5025),
    [anon_sym_column_major] = ACTIONS(5025),
    [anon_sym_globallycoherent] = ACTIONS(5025),
    [anon_sym_centroid] = ACTIONS(5025),
    [anon_sym_noperspective] = ACTIONS(5025),
    [anon_sym_nointerpolation] = ACTIONS(5025),
    [anon_sym_sample] = ACTIONS(5025),
    [anon_sym_linear] = ACTIONS(5025),
    [anon_sym_snorm] = ACTIONS(5025),
    [anon_sym_unorm] = ACTIONS(5025),
    [anon_sym_point] = ACTIONS(5025),
    [anon_sym_line] = ACTIONS(5025),
    [anon_sym_triangleadj] = ACTIONS(5025),
    [anon_sym_lineadj] = ACTIONS(5025),
    [anon_sym_triangle] = ACTIONS(5025),
  },
  [1871] = {
    [sym_identifier] = ACTIONS(5029),
    [aux_sym_preproc_def_token1] = ACTIONS(5029),
    [aux_sym_preproc_if_token1] = ACTIONS(5029),
    [aux_sym_preproc_if_token2] = ACTIONS(5029),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5029),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5029),
    [aux_sym_preproc_else_token1] = ACTIONS(5029),
    [aux_sym_preproc_elif_token1] = ACTIONS(5029),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5029),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5029),
    [sym_preproc_directive] = ACTIONS(5029),
    [anon_sym_LPAREN2] = ACTIONS(5031),
    [anon_sym_TILDE] = ACTIONS(5031),
    [anon_sym_STAR] = ACTIONS(5031),
    [anon_sym_AMP_AMP] = ACTIONS(5031),
    [anon_sym_AMP] = ACTIONS(5029),
    [anon_sym___extension__] = ACTIONS(5029),
    [anon_sym_typedef] = ACTIONS(5029),
    [anon_sym_in] = ACTIONS(5029),
    [anon_sym_out] = ACTIONS(5029),
    [anon_sym_inout] = ACTIONS(5029),
    [anon_sym_extern] = ACTIONS(5029),
    [anon_sym___attribute__] = ACTIONS(5029),
    [anon_sym_COLON_COLON] = ACTIONS(5031),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5031),
    [anon_sym___declspec] = ACTIONS(5029),
    [anon_sym___based] = ACTIONS(5029),
    [anon_sym_signed] = ACTIONS(5029),
    [anon_sym_unsigned] = ACTIONS(5029),
    [anon_sym_long] = ACTIONS(5029),
    [anon_sym_short] = ACTIONS(5029),
    [anon_sym_LBRACK] = ACTIONS(5029),
    [anon_sym_static] = ACTIONS(5029),
    [anon_sym_register] = ACTIONS(5029),
    [anon_sym_inline] = ACTIONS(5029),
    [anon_sym___inline] = ACTIONS(5029),
    [anon_sym___inline__] = ACTIONS(5029),
    [anon_sym___forceinline] = ACTIONS(5029),
    [anon_sym_thread_local] = ACTIONS(5029),
    [anon_sym___thread] = ACTIONS(5029),
    [anon_sym_const] = ACTIONS(5029),
    [anon_sym_constexpr] = ACTIONS(5029),
    [anon_sym_volatile] = ACTIONS(5029),
    [anon_sym_restrict] = ACTIONS(5029),
    [anon_sym___restrict__] = ACTIONS(5029),
    [anon_sym__Atomic] = ACTIONS(5029),
    [anon_sym__Noreturn] = ACTIONS(5029),
    [anon_sym_noreturn] = ACTIONS(5029),
    [anon_sym_mutable] = ACTIONS(5029),
    [anon_sym_constinit] = ACTIONS(5029),
    [anon_sym_consteval] = ACTIONS(5029),
    [anon_sym_alignas] = ACTIONS(5029),
    [anon_sym__Alignas] = ACTIONS(5029),
    [sym_primitive_type] = ACTIONS(5029),
    [anon_sym_enum] = ACTIONS(5029),
    [anon_sym_class] = ACTIONS(5029),
    [anon_sym_struct] = ACTIONS(5029),
    [anon_sym_union] = ACTIONS(5029),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5029),
    [anon_sym_decltype] = ACTIONS(5029),
    [sym_virtual] = ACTIONS(5029),
    [anon_sym_explicit] = ACTIONS(5029),
    [anon_sym_typename] = ACTIONS(5029),
    [anon_sym_template] = ACTIONS(5029),
    [anon_sym_operator] = ACTIONS(5029),
    [anon_sym_friend] = ACTIONS(5029),
    [anon_sym_public] = ACTIONS(5029),
    [anon_sym_private] = ACTIONS(5029),
    [anon_sym_protected] = ACTIONS(5029),
    [anon_sym_using] = ACTIONS(5029),
    [anon_sym_static_assert] = ACTIONS(5029),
    [anon_sym_precise] = ACTIONS(5029),
    [anon_sym_shared] = ACTIONS(5029),
    [anon_sym_groupshared] = ACTIONS(5029),
    [anon_sym_uniform] = ACTIONS(5029),
    [anon_sym_row_major] = ACTIONS(5029),
    [anon_sym_column_major] = ACTIONS(5029),
    [anon_sym_globallycoherent] = ACTIONS(5029),
    [anon_sym_centroid] = ACTIONS(5029),
    [anon_sym_noperspective] = ACTIONS(5029),
    [anon_sym_nointerpolation] = ACTIONS(5029),
    [anon_sym_sample] = ACTIONS(5029),
    [anon_sym_linear] = ACTIONS(5029),
    [anon_sym_snorm] = ACTIONS(5029),
    [anon_sym_unorm] = ACTIONS(5029),
    [anon_sym_point] = ACTIONS(5029),
    [anon_sym_line] = ACTIONS(5029),
    [anon_sym_triangleadj] = ACTIONS(5029),
    [anon_sym_lineadj] = ACTIONS(5029),
    [anon_sym_triangle] = ACTIONS(5029),
  },
  [1872] = {
    [sym_identifier] = ACTIONS(5029),
    [aux_sym_preproc_def_token1] = ACTIONS(5029),
    [aux_sym_preproc_if_token1] = ACTIONS(5029),
    [aux_sym_preproc_if_token2] = ACTIONS(5029),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5029),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5029),
    [aux_sym_preproc_else_token1] = ACTIONS(5029),
    [aux_sym_preproc_elif_token1] = ACTIONS(5029),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5029),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5029),
    [sym_preproc_directive] = ACTIONS(5029),
    [anon_sym_LPAREN2] = ACTIONS(5031),
    [anon_sym_TILDE] = ACTIONS(5031),
    [anon_sym_STAR] = ACTIONS(5031),
    [anon_sym_AMP_AMP] = ACTIONS(5031),
    [anon_sym_AMP] = ACTIONS(5029),
    [anon_sym___extension__] = ACTIONS(5029),
    [anon_sym_typedef] = ACTIONS(5029),
    [anon_sym_in] = ACTIONS(5029),
    [anon_sym_out] = ACTIONS(5029),
    [anon_sym_inout] = ACTIONS(5029),
    [anon_sym_extern] = ACTIONS(5029),
    [anon_sym___attribute__] = ACTIONS(5029),
    [anon_sym_COLON_COLON] = ACTIONS(5031),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5031),
    [anon_sym___declspec] = ACTIONS(5029),
    [anon_sym___based] = ACTIONS(5029),
    [anon_sym_signed] = ACTIONS(5029),
    [anon_sym_unsigned] = ACTIONS(5029),
    [anon_sym_long] = ACTIONS(5029),
    [anon_sym_short] = ACTIONS(5029),
    [anon_sym_LBRACK] = ACTIONS(5029),
    [anon_sym_static] = ACTIONS(5029),
    [anon_sym_register] = ACTIONS(5029),
    [anon_sym_inline] = ACTIONS(5029),
    [anon_sym___inline] = ACTIONS(5029),
    [anon_sym___inline__] = ACTIONS(5029),
    [anon_sym___forceinline] = ACTIONS(5029),
    [anon_sym_thread_local] = ACTIONS(5029),
    [anon_sym___thread] = ACTIONS(5029),
    [anon_sym_const] = ACTIONS(5029),
    [anon_sym_constexpr] = ACTIONS(5029),
    [anon_sym_volatile] = ACTIONS(5029),
    [anon_sym_restrict] = ACTIONS(5029),
    [anon_sym___restrict__] = ACTIONS(5029),
    [anon_sym__Atomic] = ACTIONS(5029),
    [anon_sym__Noreturn] = ACTIONS(5029),
    [anon_sym_noreturn] = ACTIONS(5029),
    [anon_sym_mutable] = ACTIONS(5029),
    [anon_sym_constinit] = ACTIONS(5029),
    [anon_sym_consteval] = ACTIONS(5029),
    [anon_sym_alignas] = ACTIONS(5029),
    [anon_sym__Alignas] = ACTIONS(5029),
    [sym_primitive_type] = ACTIONS(5029),
    [anon_sym_enum] = ACTIONS(5029),
    [anon_sym_class] = ACTIONS(5029),
    [anon_sym_struct] = ACTIONS(5029),
    [anon_sym_union] = ACTIONS(5029),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5029),
    [anon_sym_decltype] = ACTIONS(5029),
    [sym_virtual] = ACTIONS(5029),
    [anon_sym_explicit] = ACTIONS(5029),
    [anon_sym_typename] = ACTIONS(5029),
    [anon_sym_template] = ACTIONS(5029),
    [anon_sym_operator] = ACTIONS(5029),
    [anon_sym_friend] = ACTIONS(5029),
    [anon_sym_public] = ACTIONS(5029),
    [anon_sym_private] = ACTIONS(5029),
    [anon_sym_protected] = ACTIONS(5029),
    [anon_sym_using] = ACTIONS(5029),
    [anon_sym_static_assert] = ACTIONS(5029),
    [anon_sym_precise] = ACTIONS(5029),
    [anon_sym_shared] = ACTIONS(5029),
    [anon_sym_groupshared] = ACTIONS(5029),
    [anon_sym_uniform] = ACTIONS(5029),
    [anon_sym_row_major] = ACTIONS(5029),
    [anon_sym_column_major] = ACTIONS(5029),
    [anon_sym_globallycoherent] = ACTIONS(5029),
    [anon_sym_centroid] = ACTIONS(5029),
    [anon_sym_noperspective] = ACTIONS(5029),
    [anon_sym_nointerpolation] = ACTIONS(5029),
    [anon_sym_sample] = ACTIONS(5029),
    [anon_sym_linear] = ACTIONS(5029),
    [anon_sym_snorm] = ACTIONS(5029),
    [anon_sym_unorm] = ACTIONS(5029),
    [anon_sym_point] = ACTIONS(5029),
    [anon_sym_line] = ACTIONS(5029),
    [anon_sym_triangleadj] = ACTIONS(5029),
    [anon_sym_lineadj] = ACTIONS(5029),
    [anon_sym_triangle] = ACTIONS(5029),
  },
  [1873] = {
    [sym_identifier] = ACTIONS(5029),
    [aux_sym_preproc_def_token1] = ACTIONS(5029),
    [aux_sym_preproc_if_token1] = ACTIONS(5029),
    [aux_sym_preproc_if_token2] = ACTIONS(5029),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5029),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5029),
    [aux_sym_preproc_else_token1] = ACTIONS(5029),
    [aux_sym_preproc_elif_token1] = ACTIONS(5029),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5029),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5029),
    [sym_preproc_directive] = ACTIONS(5029),
    [anon_sym_LPAREN2] = ACTIONS(5031),
    [anon_sym_TILDE] = ACTIONS(5031),
    [anon_sym_STAR] = ACTIONS(5031),
    [anon_sym_AMP_AMP] = ACTIONS(5031),
    [anon_sym_AMP] = ACTIONS(5029),
    [anon_sym___extension__] = ACTIONS(5029),
    [anon_sym_typedef] = ACTIONS(5029),
    [anon_sym_in] = ACTIONS(5029),
    [anon_sym_out] = ACTIONS(5029),
    [anon_sym_inout] = ACTIONS(5029),
    [anon_sym_extern] = ACTIONS(5029),
    [anon_sym___attribute__] = ACTIONS(5029),
    [anon_sym_COLON_COLON] = ACTIONS(5031),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5031),
    [anon_sym___declspec] = ACTIONS(5029),
    [anon_sym___based] = ACTIONS(5029),
    [anon_sym_signed] = ACTIONS(5029),
    [anon_sym_unsigned] = ACTIONS(5029),
    [anon_sym_long] = ACTIONS(5029),
    [anon_sym_short] = ACTIONS(5029),
    [anon_sym_LBRACK] = ACTIONS(5029),
    [anon_sym_static] = ACTIONS(5029),
    [anon_sym_register] = ACTIONS(5029),
    [anon_sym_inline] = ACTIONS(5029),
    [anon_sym___inline] = ACTIONS(5029),
    [anon_sym___inline__] = ACTIONS(5029),
    [anon_sym___forceinline] = ACTIONS(5029),
    [anon_sym_thread_local] = ACTIONS(5029),
    [anon_sym___thread] = ACTIONS(5029),
    [anon_sym_const] = ACTIONS(5029),
    [anon_sym_constexpr] = ACTIONS(5029),
    [anon_sym_volatile] = ACTIONS(5029),
    [anon_sym_restrict] = ACTIONS(5029),
    [anon_sym___restrict__] = ACTIONS(5029),
    [anon_sym__Atomic] = ACTIONS(5029),
    [anon_sym__Noreturn] = ACTIONS(5029),
    [anon_sym_noreturn] = ACTIONS(5029),
    [anon_sym_mutable] = ACTIONS(5029),
    [anon_sym_constinit] = ACTIONS(5029),
    [anon_sym_consteval] = ACTIONS(5029),
    [anon_sym_alignas] = ACTIONS(5029),
    [anon_sym__Alignas] = ACTIONS(5029),
    [sym_primitive_type] = ACTIONS(5029),
    [anon_sym_enum] = ACTIONS(5029),
    [anon_sym_class] = ACTIONS(5029),
    [anon_sym_struct] = ACTIONS(5029),
    [anon_sym_union] = ACTIONS(5029),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5029),
    [anon_sym_decltype] = ACTIONS(5029),
    [sym_virtual] = ACTIONS(5029),
    [anon_sym_explicit] = ACTIONS(5029),
    [anon_sym_typename] = ACTIONS(5029),
    [anon_sym_template] = ACTIONS(5029),
    [anon_sym_operator] = ACTIONS(5029),
    [anon_sym_friend] = ACTIONS(5029),
    [anon_sym_public] = ACTIONS(5029),
    [anon_sym_private] = ACTIONS(5029),
    [anon_sym_protected] = ACTIONS(5029),
    [anon_sym_using] = ACTIONS(5029),
    [anon_sym_static_assert] = ACTIONS(5029),
    [anon_sym_precise] = ACTIONS(5029),
    [anon_sym_shared] = ACTIONS(5029),
    [anon_sym_groupshared] = ACTIONS(5029),
    [anon_sym_uniform] = ACTIONS(5029),
    [anon_sym_row_major] = ACTIONS(5029),
    [anon_sym_column_major] = ACTIONS(5029),
    [anon_sym_globallycoherent] = ACTIONS(5029),
    [anon_sym_centroid] = ACTIONS(5029),
    [anon_sym_noperspective] = ACTIONS(5029),
    [anon_sym_nointerpolation] = ACTIONS(5029),
    [anon_sym_sample] = ACTIONS(5029),
    [anon_sym_linear] = ACTIONS(5029),
    [anon_sym_snorm] = ACTIONS(5029),
    [anon_sym_unorm] = ACTIONS(5029),
    [anon_sym_point] = ACTIONS(5029),
    [anon_sym_line] = ACTIONS(5029),
    [anon_sym_triangleadj] = ACTIONS(5029),
    [anon_sym_lineadj] = ACTIONS(5029),
    [anon_sym_triangle] = ACTIONS(5029),
  },
  [1874] = {
    [sym_identifier] = ACTIONS(2510),
    [aux_sym_preproc_def_token1] = ACTIONS(2510),
    [aux_sym_preproc_if_token1] = ACTIONS(2510),
    [aux_sym_preproc_if_token2] = ACTIONS(2510),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2510),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2510),
    [aux_sym_preproc_else_token1] = ACTIONS(2510),
    [aux_sym_preproc_elif_token1] = ACTIONS(2510),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2510),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2510),
    [sym_preproc_directive] = ACTIONS(2510),
    [anon_sym_LPAREN2] = ACTIONS(2512),
    [anon_sym_TILDE] = ACTIONS(2512),
    [anon_sym_STAR] = ACTIONS(2512),
    [anon_sym_AMP_AMP] = ACTIONS(2512),
    [anon_sym_AMP] = ACTIONS(2510),
    [anon_sym___extension__] = ACTIONS(2510),
    [anon_sym_typedef] = ACTIONS(2510),
    [anon_sym_in] = ACTIONS(2510),
    [anon_sym_out] = ACTIONS(2510),
    [anon_sym_inout] = ACTIONS(2510),
    [anon_sym_extern] = ACTIONS(2510),
    [anon_sym___attribute__] = ACTIONS(2510),
    [anon_sym_COLON_COLON] = ACTIONS(2512),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2512),
    [anon_sym___declspec] = ACTIONS(2510),
    [anon_sym___based] = ACTIONS(2510),
    [anon_sym_signed] = ACTIONS(2510),
    [anon_sym_unsigned] = ACTIONS(2510),
    [anon_sym_long] = ACTIONS(2510),
    [anon_sym_short] = ACTIONS(2510),
    [anon_sym_LBRACK] = ACTIONS(2510),
    [anon_sym_static] = ACTIONS(2510),
    [anon_sym_register] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(2510),
    [anon_sym___inline] = ACTIONS(2510),
    [anon_sym___inline__] = ACTIONS(2510),
    [anon_sym___forceinline] = ACTIONS(2510),
    [anon_sym_thread_local] = ACTIONS(2510),
    [anon_sym___thread] = ACTIONS(2510),
    [anon_sym_const] = ACTIONS(2510),
    [anon_sym_constexpr] = ACTIONS(2510),
    [anon_sym_volatile] = ACTIONS(2510),
    [anon_sym_restrict] = ACTIONS(2510),
    [anon_sym___restrict__] = ACTIONS(2510),
    [anon_sym__Atomic] = ACTIONS(2510),
    [anon_sym__Noreturn] = ACTIONS(2510),
    [anon_sym_noreturn] = ACTIONS(2510),
    [anon_sym_mutable] = ACTIONS(2510),
    [anon_sym_constinit] = ACTIONS(2510),
    [anon_sym_consteval] = ACTIONS(2510),
    [anon_sym_alignas] = ACTIONS(2510),
    [anon_sym__Alignas] = ACTIONS(2510),
    [sym_primitive_type] = ACTIONS(2510),
    [anon_sym_enum] = ACTIONS(2510),
    [anon_sym_class] = ACTIONS(2510),
    [anon_sym_struct] = ACTIONS(2510),
    [anon_sym_union] = ACTIONS(2510),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2510),
    [anon_sym_decltype] = ACTIONS(2510),
    [sym_virtual] = ACTIONS(2510),
    [anon_sym_explicit] = ACTIONS(2510),
    [anon_sym_typename] = ACTIONS(2510),
    [anon_sym_template] = ACTIONS(2510),
    [anon_sym_operator] = ACTIONS(2510),
    [anon_sym_friend] = ACTIONS(2510),
    [anon_sym_public] = ACTIONS(2510),
    [anon_sym_private] = ACTIONS(2510),
    [anon_sym_protected] = ACTIONS(2510),
    [anon_sym_using] = ACTIONS(2510),
    [anon_sym_static_assert] = ACTIONS(2510),
    [anon_sym_precise] = ACTIONS(2510),
    [anon_sym_shared] = ACTIONS(2510),
    [anon_sym_groupshared] = ACTIONS(2510),
    [anon_sym_uniform] = ACTIONS(2510),
    [anon_sym_row_major] = ACTIONS(2510),
    [anon_sym_column_major] = ACTIONS(2510),
    [anon_sym_globallycoherent] = ACTIONS(2510),
    [anon_sym_centroid] = ACTIONS(2510),
    [anon_sym_noperspective] = ACTIONS(2510),
    [anon_sym_nointerpolation] = ACTIONS(2510),
    [anon_sym_sample] = ACTIONS(2510),
    [anon_sym_linear] = ACTIONS(2510),
    [anon_sym_snorm] = ACTIONS(2510),
    [anon_sym_unorm] = ACTIONS(2510),
    [anon_sym_point] = ACTIONS(2510),
    [anon_sym_line] = ACTIONS(2510),
    [anon_sym_triangleadj] = ACTIONS(2510),
    [anon_sym_lineadj] = ACTIONS(2510),
    [anon_sym_triangle] = ACTIONS(2510),
  },
  [1875] = {
    [sym_identifier] = ACTIONS(5025),
    [aux_sym_preproc_def_token1] = ACTIONS(5025),
    [aux_sym_preproc_if_token1] = ACTIONS(5025),
    [aux_sym_preproc_if_token2] = ACTIONS(5025),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5025),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5025),
    [aux_sym_preproc_else_token1] = ACTIONS(5025),
    [aux_sym_preproc_elif_token1] = ACTIONS(5025),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5025),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5025),
    [sym_preproc_directive] = ACTIONS(5025),
    [anon_sym_LPAREN2] = ACTIONS(5027),
    [anon_sym_TILDE] = ACTIONS(5027),
    [anon_sym_STAR] = ACTIONS(5027),
    [anon_sym_AMP_AMP] = ACTIONS(5027),
    [anon_sym_AMP] = ACTIONS(5025),
    [anon_sym___extension__] = ACTIONS(5025),
    [anon_sym_typedef] = ACTIONS(5025),
    [anon_sym_in] = ACTIONS(5025),
    [anon_sym_out] = ACTIONS(5025),
    [anon_sym_inout] = ACTIONS(5025),
    [anon_sym_extern] = ACTIONS(5025),
    [anon_sym___attribute__] = ACTIONS(5025),
    [anon_sym_COLON_COLON] = ACTIONS(5027),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5027),
    [anon_sym___declspec] = ACTIONS(5025),
    [anon_sym___based] = ACTIONS(5025),
    [anon_sym_signed] = ACTIONS(5025),
    [anon_sym_unsigned] = ACTIONS(5025),
    [anon_sym_long] = ACTIONS(5025),
    [anon_sym_short] = ACTIONS(5025),
    [anon_sym_LBRACK] = ACTIONS(5025),
    [anon_sym_static] = ACTIONS(5025),
    [anon_sym_register] = ACTIONS(5025),
    [anon_sym_inline] = ACTIONS(5025),
    [anon_sym___inline] = ACTIONS(5025),
    [anon_sym___inline__] = ACTIONS(5025),
    [anon_sym___forceinline] = ACTIONS(5025),
    [anon_sym_thread_local] = ACTIONS(5025),
    [anon_sym___thread] = ACTIONS(5025),
    [anon_sym_const] = ACTIONS(5025),
    [anon_sym_constexpr] = ACTIONS(5025),
    [anon_sym_volatile] = ACTIONS(5025),
    [anon_sym_restrict] = ACTIONS(5025),
    [anon_sym___restrict__] = ACTIONS(5025),
    [anon_sym__Atomic] = ACTIONS(5025),
    [anon_sym__Noreturn] = ACTIONS(5025),
    [anon_sym_noreturn] = ACTIONS(5025),
    [anon_sym_mutable] = ACTIONS(5025),
    [anon_sym_constinit] = ACTIONS(5025),
    [anon_sym_consteval] = ACTIONS(5025),
    [anon_sym_alignas] = ACTIONS(5025),
    [anon_sym__Alignas] = ACTIONS(5025),
    [sym_primitive_type] = ACTIONS(5025),
    [anon_sym_enum] = ACTIONS(5025),
    [anon_sym_class] = ACTIONS(5025),
    [anon_sym_struct] = ACTIONS(5025),
    [anon_sym_union] = ACTIONS(5025),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5025),
    [anon_sym_decltype] = ACTIONS(5025),
    [sym_virtual] = ACTIONS(5025),
    [anon_sym_explicit] = ACTIONS(5025),
    [anon_sym_typename] = ACTIONS(5025),
    [anon_sym_template] = ACTIONS(5025),
    [anon_sym_operator] = ACTIONS(5025),
    [anon_sym_friend] = ACTIONS(5025),
    [anon_sym_public] = ACTIONS(5025),
    [anon_sym_private] = ACTIONS(5025),
    [anon_sym_protected] = ACTIONS(5025),
    [anon_sym_using] = ACTIONS(5025),
    [anon_sym_static_assert] = ACTIONS(5025),
    [anon_sym_precise] = ACTIONS(5025),
    [anon_sym_shared] = ACTIONS(5025),
    [anon_sym_groupshared] = ACTIONS(5025),
    [anon_sym_uniform] = ACTIONS(5025),
    [anon_sym_row_major] = ACTIONS(5025),
    [anon_sym_column_major] = ACTIONS(5025),
    [anon_sym_globallycoherent] = ACTIONS(5025),
    [anon_sym_centroid] = ACTIONS(5025),
    [anon_sym_noperspective] = ACTIONS(5025),
    [anon_sym_nointerpolation] = ACTIONS(5025),
    [anon_sym_sample] = ACTIONS(5025),
    [anon_sym_linear] = ACTIONS(5025),
    [anon_sym_snorm] = ACTIONS(5025),
    [anon_sym_unorm] = ACTIONS(5025),
    [anon_sym_point] = ACTIONS(5025),
    [anon_sym_line] = ACTIONS(5025),
    [anon_sym_triangleadj] = ACTIONS(5025),
    [anon_sym_lineadj] = ACTIONS(5025),
    [anon_sym_triangle] = ACTIONS(5025),
  },
  [1876] = {
    [sym_identifier] = ACTIONS(5033),
    [aux_sym_preproc_def_token1] = ACTIONS(5033),
    [aux_sym_preproc_if_token1] = ACTIONS(5033),
    [aux_sym_preproc_if_token2] = ACTIONS(5033),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5033),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5033),
    [aux_sym_preproc_else_token1] = ACTIONS(5033),
    [aux_sym_preproc_elif_token1] = ACTIONS(5033),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5033),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5033),
    [sym_preproc_directive] = ACTIONS(5033),
    [anon_sym_LPAREN2] = ACTIONS(5035),
    [anon_sym_TILDE] = ACTIONS(5035),
    [anon_sym_STAR] = ACTIONS(5035),
    [anon_sym_AMP_AMP] = ACTIONS(5035),
    [anon_sym_AMP] = ACTIONS(5033),
    [anon_sym___extension__] = ACTIONS(5033),
    [anon_sym_typedef] = ACTIONS(5033),
    [anon_sym_in] = ACTIONS(5033),
    [anon_sym_out] = ACTIONS(5033),
    [anon_sym_inout] = ACTIONS(5033),
    [anon_sym_extern] = ACTIONS(5033),
    [anon_sym___attribute__] = ACTIONS(5033),
    [anon_sym_COLON_COLON] = ACTIONS(5035),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5035),
    [anon_sym___declspec] = ACTIONS(5033),
    [anon_sym___based] = ACTIONS(5033),
    [anon_sym_signed] = ACTIONS(5033),
    [anon_sym_unsigned] = ACTIONS(5033),
    [anon_sym_long] = ACTIONS(5033),
    [anon_sym_short] = ACTIONS(5033),
    [anon_sym_LBRACK] = ACTIONS(5033),
    [anon_sym_static] = ACTIONS(5033),
    [anon_sym_register] = ACTIONS(5033),
    [anon_sym_inline] = ACTIONS(5033),
    [anon_sym___inline] = ACTIONS(5033),
    [anon_sym___inline__] = ACTIONS(5033),
    [anon_sym___forceinline] = ACTIONS(5033),
    [anon_sym_thread_local] = ACTIONS(5033),
    [anon_sym___thread] = ACTIONS(5033),
    [anon_sym_const] = ACTIONS(5033),
    [anon_sym_constexpr] = ACTIONS(5033),
    [anon_sym_volatile] = ACTIONS(5033),
    [anon_sym_restrict] = ACTIONS(5033),
    [anon_sym___restrict__] = ACTIONS(5033),
    [anon_sym__Atomic] = ACTIONS(5033),
    [anon_sym__Noreturn] = ACTIONS(5033),
    [anon_sym_noreturn] = ACTIONS(5033),
    [anon_sym_mutable] = ACTIONS(5033),
    [anon_sym_constinit] = ACTIONS(5033),
    [anon_sym_consteval] = ACTIONS(5033),
    [anon_sym_alignas] = ACTIONS(5033),
    [anon_sym__Alignas] = ACTIONS(5033),
    [sym_primitive_type] = ACTIONS(5033),
    [anon_sym_enum] = ACTIONS(5033),
    [anon_sym_class] = ACTIONS(5033),
    [anon_sym_struct] = ACTIONS(5033),
    [anon_sym_union] = ACTIONS(5033),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5033),
    [anon_sym_decltype] = ACTIONS(5033),
    [sym_virtual] = ACTIONS(5033),
    [anon_sym_explicit] = ACTIONS(5033),
    [anon_sym_typename] = ACTIONS(5033),
    [anon_sym_template] = ACTIONS(5033),
    [anon_sym_operator] = ACTIONS(5033),
    [anon_sym_friend] = ACTIONS(5033),
    [anon_sym_public] = ACTIONS(5033),
    [anon_sym_private] = ACTIONS(5033),
    [anon_sym_protected] = ACTIONS(5033),
    [anon_sym_using] = ACTIONS(5033),
    [anon_sym_static_assert] = ACTIONS(5033),
    [anon_sym_precise] = ACTIONS(5033),
    [anon_sym_shared] = ACTIONS(5033),
    [anon_sym_groupshared] = ACTIONS(5033),
    [anon_sym_uniform] = ACTIONS(5033),
    [anon_sym_row_major] = ACTIONS(5033),
    [anon_sym_column_major] = ACTIONS(5033),
    [anon_sym_globallycoherent] = ACTIONS(5033),
    [anon_sym_centroid] = ACTIONS(5033),
    [anon_sym_noperspective] = ACTIONS(5033),
    [anon_sym_nointerpolation] = ACTIONS(5033),
    [anon_sym_sample] = ACTIONS(5033),
    [anon_sym_linear] = ACTIONS(5033),
    [anon_sym_snorm] = ACTIONS(5033),
    [anon_sym_unorm] = ACTIONS(5033),
    [anon_sym_point] = ACTIONS(5033),
    [anon_sym_line] = ACTIONS(5033),
    [anon_sym_triangleadj] = ACTIONS(5033),
    [anon_sym_lineadj] = ACTIONS(5033),
    [anon_sym_triangle] = ACTIONS(5033),
  },
  [1877] = {
    [sym_identifier] = ACTIONS(5037),
    [aux_sym_preproc_def_token1] = ACTIONS(5037),
    [aux_sym_preproc_if_token1] = ACTIONS(5037),
    [aux_sym_preproc_if_token2] = ACTIONS(5037),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5037),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5037),
    [aux_sym_preproc_else_token1] = ACTIONS(5037),
    [aux_sym_preproc_elif_token1] = ACTIONS(5037),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5037),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5037),
    [sym_preproc_directive] = ACTIONS(5037),
    [anon_sym_LPAREN2] = ACTIONS(5039),
    [anon_sym_TILDE] = ACTIONS(5039),
    [anon_sym_STAR] = ACTIONS(5039),
    [anon_sym_AMP_AMP] = ACTIONS(5039),
    [anon_sym_AMP] = ACTIONS(5037),
    [anon_sym___extension__] = ACTIONS(5037),
    [anon_sym_typedef] = ACTIONS(5037),
    [anon_sym_in] = ACTIONS(5037),
    [anon_sym_out] = ACTIONS(5037),
    [anon_sym_inout] = ACTIONS(5037),
    [anon_sym_extern] = ACTIONS(5037),
    [anon_sym___attribute__] = ACTIONS(5037),
    [anon_sym_COLON_COLON] = ACTIONS(5039),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5039),
    [anon_sym___declspec] = ACTIONS(5037),
    [anon_sym___based] = ACTIONS(5037),
    [anon_sym_signed] = ACTIONS(5037),
    [anon_sym_unsigned] = ACTIONS(5037),
    [anon_sym_long] = ACTIONS(5037),
    [anon_sym_short] = ACTIONS(5037),
    [anon_sym_LBRACK] = ACTIONS(5037),
    [anon_sym_static] = ACTIONS(5037),
    [anon_sym_register] = ACTIONS(5037),
    [anon_sym_inline] = ACTIONS(5037),
    [anon_sym___inline] = ACTIONS(5037),
    [anon_sym___inline__] = ACTIONS(5037),
    [anon_sym___forceinline] = ACTIONS(5037),
    [anon_sym_thread_local] = ACTIONS(5037),
    [anon_sym___thread] = ACTIONS(5037),
    [anon_sym_const] = ACTIONS(5037),
    [anon_sym_constexpr] = ACTIONS(5037),
    [anon_sym_volatile] = ACTIONS(5037),
    [anon_sym_restrict] = ACTIONS(5037),
    [anon_sym___restrict__] = ACTIONS(5037),
    [anon_sym__Atomic] = ACTIONS(5037),
    [anon_sym__Noreturn] = ACTIONS(5037),
    [anon_sym_noreturn] = ACTIONS(5037),
    [anon_sym_mutable] = ACTIONS(5037),
    [anon_sym_constinit] = ACTIONS(5037),
    [anon_sym_consteval] = ACTIONS(5037),
    [anon_sym_alignas] = ACTIONS(5037),
    [anon_sym__Alignas] = ACTIONS(5037),
    [sym_primitive_type] = ACTIONS(5037),
    [anon_sym_enum] = ACTIONS(5037),
    [anon_sym_class] = ACTIONS(5037),
    [anon_sym_struct] = ACTIONS(5037),
    [anon_sym_union] = ACTIONS(5037),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5037),
    [anon_sym_decltype] = ACTIONS(5037),
    [sym_virtual] = ACTIONS(5037),
    [anon_sym_explicit] = ACTIONS(5037),
    [anon_sym_typename] = ACTIONS(5037),
    [anon_sym_template] = ACTIONS(5037),
    [anon_sym_operator] = ACTIONS(5037),
    [anon_sym_friend] = ACTIONS(5037),
    [anon_sym_public] = ACTIONS(5037),
    [anon_sym_private] = ACTIONS(5037),
    [anon_sym_protected] = ACTIONS(5037),
    [anon_sym_using] = ACTIONS(5037),
    [anon_sym_static_assert] = ACTIONS(5037),
    [anon_sym_precise] = ACTIONS(5037),
    [anon_sym_shared] = ACTIONS(5037),
    [anon_sym_groupshared] = ACTIONS(5037),
    [anon_sym_uniform] = ACTIONS(5037),
    [anon_sym_row_major] = ACTIONS(5037),
    [anon_sym_column_major] = ACTIONS(5037),
    [anon_sym_globallycoherent] = ACTIONS(5037),
    [anon_sym_centroid] = ACTIONS(5037),
    [anon_sym_noperspective] = ACTIONS(5037),
    [anon_sym_nointerpolation] = ACTIONS(5037),
    [anon_sym_sample] = ACTIONS(5037),
    [anon_sym_linear] = ACTIONS(5037),
    [anon_sym_snorm] = ACTIONS(5037),
    [anon_sym_unorm] = ACTIONS(5037),
    [anon_sym_point] = ACTIONS(5037),
    [anon_sym_line] = ACTIONS(5037),
    [anon_sym_triangleadj] = ACTIONS(5037),
    [anon_sym_lineadj] = ACTIONS(5037),
    [anon_sym_triangle] = ACTIONS(5037),
  },
  [1878] = {
    [sym_identifier] = ACTIONS(5041),
    [aux_sym_preproc_def_token1] = ACTIONS(5041),
    [aux_sym_preproc_if_token1] = ACTIONS(5041),
    [aux_sym_preproc_if_token2] = ACTIONS(5041),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5041),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5041),
    [aux_sym_preproc_else_token1] = ACTIONS(5041),
    [aux_sym_preproc_elif_token1] = ACTIONS(5041),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5041),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5041),
    [sym_preproc_directive] = ACTIONS(5041),
    [anon_sym_LPAREN2] = ACTIONS(5043),
    [anon_sym_TILDE] = ACTIONS(5043),
    [anon_sym_STAR] = ACTIONS(5043),
    [anon_sym_AMP_AMP] = ACTIONS(5043),
    [anon_sym_AMP] = ACTIONS(5041),
    [anon_sym___extension__] = ACTIONS(5041),
    [anon_sym_typedef] = ACTIONS(5041),
    [anon_sym_in] = ACTIONS(5041),
    [anon_sym_out] = ACTIONS(5041),
    [anon_sym_inout] = ACTIONS(5041),
    [anon_sym_extern] = ACTIONS(5041),
    [anon_sym___attribute__] = ACTIONS(5041),
    [anon_sym_COLON_COLON] = ACTIONS(5043),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5043),
    [anon_sym___declspec] = ACTIONS(5041),
    [anon_sym___based] = ACTIONS(5041),
    [anon_sym_signed] = ACTIONS(5041),
    [anon_sym_unsigned] = ACTIONS(5041),
    [anon_sym_long] = ACTIONS(5041),
    [anon_sym_short] = ACTIONS(5041),
    [anon_sym_LBRACK] = ACTIONS(5041),
    [anon_sym_static] = ACTIONS(5041),
    [anon_sym_register] = ACTIONS(5041),
    [anon_sym_inline] = ACTIONS(5041),
    [anon_sym___inline] = ACTIONS(5041),
    [anon_sym___inline__] = ACTIONS(5041),
    [anon_sym___forceinline] = ACTIONS(5041),
    [anon_sym_thread_local] = ACTIONS(5041),
    [anon_sym___thread] = ACTIONS(5041),
    [anon_sym_const] = ACTIONS(5041),
    [anon_sym_constexpr] = ACTIONS(5041),
    [anon_sym_volatile] = ACTIONS(5041),
    [anon_sym_restrict] = ACTIONS(5041),
    [anon_sym___restrict__] = ACTIONS(5041),
    [anon_sym__Atomic] = ACTIONS(5041),
    [anon_sym__Noreturn] = ACTIONS(5041),
    [anon_sym_noreturn] = ACTIONS(5041),
    [anon_sym_mutable] = ACTIONS(5041),
    [anon_sym_constinit] = ACTIONS(5041),
    [anon_sym_consteval] = ACTIONS(5041),
    [anon_sym_alignas] = ACTIONS(5041),
    [anon_sym__Alignas] = ACTIONS(5041),
    [sym_primitive_type] = ACTIONS(5041),
    [anon_sym_enum] = ACTIONS(5041),
    [anon_sym_class] = ACTIONS(5041),
    [anon_sym_struct] = ACTIONS(5041),
    [anon_sym_union] = ACTIONS(5041),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5041),
    [anon_sym_decltype] = ACTIONS(5041),
    [sym_virtual] = ACTIONS(5041),
    [anon_sym_explicit] = ACTIONS(5041),
    [anon_sym_typename] = ACTIONS(5041),
    [anon_sym_template] = ACTIONS(5041),
    [anon_sym_operator] = ACTIONS(5041),
    [anon_sym_friend] = ACTIONS(5041),
    [anon_sym_public] = ACTIONS(5041),
    [anon_sym_private] = ACTIONS(5041),
    [anon_sym_protected] = ACTIONS(5041),
    [anon_sym_using] = ACTIONS(5041),
    [anon_sym_static_assert] = ACTIONS(5041),
    [anon_sym_precise] = ACTIONS(5041),
    [anon_sym_shared] = ACTIONS(5041),
    [anon_sym_groupshared] = ACTIONS(5041),
    [anon_sym_uniform] = ACTIONS(5041),
    [anon_sym_row_major] = ACTIONS(5041),
    [anon_sym_column_major] = ACTIONS(5041),
    [anon_sym_globallycoherent] = ACTIONS(5041),
    [anon_sym_centroid] = ACTIONS(5041),
    [anon_sym_noperspective] = ACTIONS(5041),
    [anon_sym_nointerpolation] = ACTIONS(5041),
    [anon_sym_sample] = ACTIONS(5041),
    [anon_sym_linear] = ACTIONS(5041),
    [anon_sym_snorm] = ACTIONS(5041),
    [anon_sym_unorm] = ACTIONS(5041),
    [anon_sym_point] = ACTIONS(5041),
    [anon_sym_line] = ACTIONS(5041),
    [anon_sym_triangleadj] = ACTIONS(5041),
    [anon_sym_lineadj] = ACTIONS(5041),
    [anon_sym_triangle] = ACTIONS(5041),
  },
  [1879] = {
    [sym_identifier] = ACTIONS(5045),
    [aux_sym_preproc_def_token1] = ACTIONS(5045),
    [aux_sym_preproc_if_token1] = ACTIONS(5045),
    [aux_sym_preproc_if_token2] = ACTIONS(5045),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5045),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5045),
    [aux_sym_preproc_else_token1] = ACTIONS(5045),
    [aux_sym_preproc_elif_token1] = ACTIONS(5045),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5045),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5045),
    [sym_preproc_directive] = ACTIONS(5045),
    [anon_sym_LPAREN2] = ACTIONS(5047),
    [anon_sym_TILDE] = ACTIONS(5047),
    [anon_sym_STAR] = ACTIONS(5047),
    [anon_sym_AMP_AMP] = ACTIONS(5047),
    [anon_sym_AMP] = ACTIONS(5045),
    [anon_sym___extension__] = ACTIONS(5045),
    [anon_sym_typedef] = ACTIONS(5045),
    [anon_sym_in] = ACTIONS(5045),
    [anon_sym_out] = ACTIONS(5045),
    [anon_sym_inout] = ACTIONS(5045),
    [anon_sym_extern] = ACTIONS(5045),
    [anon_sym___attribute__] = ACTIONS(5045),
    [anon_sym_COLON_COLON] = ACTIONS(5047),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5047),
    [anon_sym___declspec] = ACTIONS(5045),
    [anon_sym___based] = ACTIONS(5045),
    [anon_sym_signed] = ACTIONS(5045),
    [anon_sym_unsigned] = ACTIONS(5045),
    [anon_sym_long] = ACTIONS(5045),
    [anon_sym_short] = ACTIONS(5045),
    [anon_sym_LBRACK] = ACTIONS(5045),
    [anon_sym_static] = ACTIONS(5045),
    [anon_sym_register] = ACTIONS(5045),
    [anon_sym_inline] = ACTIONS(5045),
    [anon_sym___inline] = ACTIONS(5045),
    [anon_sym___inline__] = ACTIONS(5045),
    [anon_sym___forceinline] = ACTIONS(5045),
    [anon_sym_thread_local] = ACTIONS(5045),
    [anon_sym___thread] = ACTIONS(5045),
    [anon_sym_const] = ACTIONS(5045),
    [anon_sym_constexpr] = ACTIONS(5045),
    [anon_sym_volatile] = ACTIONS(5045),
    [anon_sym_restrict] = ACTIONS(5045),
    [anon_sym___restrict__] = ACTIONS(5045),
    [anon_sym__Atomic] = ACTIONS(5045),
    [anon_sym__Noreturn] = ACTIONS(5045),
    [anon_sym_noreturn] = ACTIONS(5045),
    [anon_sym_mutable] = ACTIONS(5045),
    [anon_sym_constinit] = ACTIONS(5045),
    [anon_sym_consteval] = ACTIONS(5045),
    [anon_sym_alignas] = ACTIONS(5045),
    [anon_sym__Alignas] = ACTIONS(5045),
    [sym_primitive_type] = ACTIONS(5045),
    [anon_sym_enum] = ACTIONS(5045),
    [anon_sym_class] = ACTIONS(5045),
    [anon_sym_struct] = ACTIONS(5045),
    [anon_sym_union] = ACTIONS(5045),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5045),
    [anon_sym_decltype] = ACTIONS(5045),
    [sym_virtual] = ACTIONS(5045),
    [anon_sym_explicit] = ACTIONS(5045),
    [anon_sym_typename] = ACTIONS(5045),
    [anon_sym_template] = ACTIONS(5045),
    [anon_sym_operator] = ACTIONS(5045),
    [anon_sym_friend] = ACTIONS(5045),
    [anon_sym_public] = ACTIONS(5045),
    [anon_sym_private] = ACTIONS(5045),
    [anon_sym_protected] = ACTIONS(5045),
    [anon_sym_using] = ACTIONS(5045),
    [anon_sym_static_assert] = ACTIONS(5045),
    [anon_sym_precise] = ACTIONS(5045),
    [anon_sym_shared] = ACTIONS(5045),
    [anon_sym_groupshared] = ACTIONS(5045),
    [anon_sym_uniform] = ACTIONS(5045),
    [anon_sym_row_major] = ACTIONS(5045),
    [anon_sym_column_major] = ACTIONS(5045),
    [anon_sym_globallycoherent] = ACTIONS(5045),
    [anon_sym_centroid] = ACTIONS(5045),
    [anon_sym_noperspective] = ACTIONS(5045),
    [anon_sym_nointerpolation] = ACTIONS(5045),
    [anon_sym_sample] = ACTIONS(5045),
    [anon_sym_linear] = ACTIONS(5045),
    [anon_sym_snorm] = ACTIONS(5045),
    [anon_sym_unorm] = ACTIONS(5045),
    [anon_sym_point] = ACTIONS(5045),
    [anon_sym_line] = ACTIONS(5045),
    [anon_sym_triangleadj] = ACTIONS(5045),
    [anon_sym_lineadj] = ACTIONS(5045),
    [anon_sym_triangle] = ACTIONS(5045),
  },
  [1880] = {
    [sym_identifier] = ACTIONS(5049),
    [aux_sym_preproc_def_token1] = ACTIONS(5049),
    [aux_sym_preproc_if_token1] = ACTIONS(5049),
    [aux_sym_preproc_if_token2] = ACTIONS(5049),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5049),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5049),
    [aux_sym_preproc_else_token1] = ACTIONS(5049),
    [aux_sym_preproc_elif_token1] = ACTIONS(5049),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5049),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5049),
    [sym_preproc_directive] = ACTIONS(5049),
    [anon_sym_LPAREN2] = ACTIONS(5051),
    [anon_sym_TILDE] = ACTIONS(5051),
    [anon_sym_STAR] = ACTIONS(5051),
    [anon_sym_AMP_AMP] = ACTIONS(5051),
    [anon_sym_AMP] = ACTIONS(5049),
    [anon_sym___extension__] = ACTIONS(5049),
    [anon_sym_typedef] = ACTIONS(5049),
    [anon_sym_in] = ACTIONS(5049),
    [anon_sym_out] = ACTIONS(5049),
    [anon_sym_inout] = ACTIONS(5049),
    [anon_sym_extern] = ACTIONS(5049),
    [anon_sym___attribute__] = ACTIONS(5049),
    [anon_sym_COLON_COLON] = ACTIONS(5051),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5051),
    [anon_sym___declspec] = ACTIONS(5049),
    [anon_sym___based] = ACTIONS(5049),
    [anon_sym_signed] = ACTIONS(5049),
    [anon_sym_unsigned] = ACTIONS(5049),
    [anon_sym_long] = ACTIONS(5049),
    [anon_sym_short] = ACTIONS(5049),
    [anon_sym_LBRACK] = ACTIONS(5049),
    [anon_sym_static] = ACTIONS(5049),
    [anon_sym_register] = ACTIONS(5049),
    [anon_sym_inline] = ACTIONS(5049),
    [anon_sym___inline] = ACTIONS(5049),
    [anon_sym___inline__] = ACTIONS(5049),
    [anon_sym___forceinline] = ACTIONS(5049),
    [anon_sym_thread_local] = ACTIONS(5049),
    [anon_sym___thread] = ACTIONS(5049),
    [anon_sym_const] = ACTIONS(5049),
    [anon_sym_constexpr] = ACTIONS(5049),
    [anon_sym_volatile] = ACTIONS(5049),
    [anon_sym_restrict] = ACTIONS(5049),
    [anon_sym___restrict__] = ACTIONS(5049),
    [anon_sym__Atomic] = ACTIONS(5049),
    [anon_sym__Noreturn] = ACTIONS(5049),
    [anon_sym_noreturn] = ACTIONS(5049),
    [anon_sym_mutable] = ACTIONS(5049),
    [anon_sym_constinit] = ACTIONS(5049),
    [anon_sym_consteval] = ACTIONS(5049),
    [anon_sym_alignas] = ACTIONS(5049),
    [anon_sym__Alignas] = ACTIONS(5049),
    [sym_primitive_type] = ACTIONS(5049),
    [anon_sym_enum] = ACTIONS(5049),
    [anon_sym_class] = ACTIONS(5049),
    [anon_sym_struct] = ACTIONS(5049),
    [anon_sym_union] = ACTIONS(5049),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5049),
    [anon_sym_decltype] = ACTIONS(5049),
    [sym_virtual] = ACTIONS(5049),
    [anon_sym_explicit] = ACTIONS(5049),
    [anon_sym_typename] = ACTIONS(5049),
    [anon_sym_template] = ACTIONS(5049),
    [anon_sym_operator] = ACTIONS(5049),
    [anon_sym_friend] = ACTIONS(5049),
    [anon_sym_public] = ACTIONS(5049),
    [anon_sym_private] = ACTIONS(5049),
    [anon_sym_protected] = ACTIONS(5049),
    [anon_sym_using] = ACTIONS(5049),
    [anon_sym_static_assert] = ACTIONS(5049),
    [anon_sym_precise] = ACTIONS(5049),
    [anon_sym_shared] = ACTIONS(5049),
    [anon_sym_groupshared] = ACTIONS(5049),
    [anon_sym_uniform] = ACTIONS(5049),
    [anon_sym_row_major] = ACTIONS(5049),
    [anon_sym_column_major] = ACTIONS(5049),
    [anon_sym_globallycoherent] = ACTIONS(5049),
    [anon_sym_centroid] = ACTIONS(5049),
    [anon_sym_noperspective] = ACTIONS(5049),
    [anon_sym_nointerpolation] = ACTIONS(5049),
    [anon_sym_sample] = ACTIONS(5049),
    [anon_sym_linear] = ACTIONS(5049),
    [anon_sym_snorm] = ACTIONS(5049),
    [anon_sym_unorm] = ACTIONS(5049),
    [anon_sym_point] = ACTIONS(5049),
    [anon_sym_line] = ACTIONS(5049),
    [anon_sym_triangleadj] = ACTIONS(5049),
    [anon_sym_lineadj] = ACTIONS(5049),
    [anon_sym_triangle] = ACTIONS(5049),
  },
  [1881] = {
    [sym_identifier] = ACTIONS(5053),
    [aux_sym_preproc_def_token1] = ACTIONS(5053),
    [aux_sym_preproc_if_token1] = ACTIONS(5053),
    [aux_sym_preproc_if_token2] = ACTIONS(5053),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5053),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5053),
    [aux_sym_preproc_else_token1] = ACTIONS(5053),
    [aux_sym_preproc_elif_token1] = ACTIONS(5053),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5053),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5053),
    [sym_preproc_directive] = ACTIONS(5053),
    [anon_sym_LPAREN2] = ACTIONS(5055),
    [anon_sym_TILDE] = ACTIONS(5055),
    [anon_sym_STAR] = ACTIONS(5055),
    [anon_sym_AMP_AMP] = ACTIONS(5055),
    [anon_sym_AMP] = ACTIONS(5053),
    [anon_sym___extension__] = ACTIONS(5053),
    [anon_sym_typedef] = ACTIONS(5053),
    [anon_sym_in] = ACTIONS(5053),
    [anon_sym_out] = ACTIONS(5053),
    [anon_sym_inout] = ACTIONS(5053),
    [anon_sym_extern] = ACTIONS(5053),
    [anon_sym___attribute__] = ACTIONS(5053),
    [anon_sym_COLON_COLON] = ACTIONS(5055),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5055),
    [anon_sym___declspec] = ACTIONS(5053),
    [anon_sym___based] = ACTIONS(5053),
    [anon_sym_signed] = ACTIONS(5053),
    [anon_sym_unsigned] = ACTIONS(5053),
    [anon_sym_long] = ACTIONS(5053),
    [anon_sym_short] = ACTIONS(5053),
    [anon_sym_LBRACK] = ACTIONS(5053),
    [anon_sym_static] = ACTIONS(5053),
    [anon_sym_register] = ACTIONS(5053),
    [anon_sym_inline] = ACTIONS(5053),
    [anon_sym___inline] = ACTIONS(5053),
    [anon_sym___inline__] = ACTIONS(5053),
    [anon_sym___forceinline] = ACTIONS(5053),
    [anon_sym_thread_local] = ACTIONS(5053),
    [anon_sym___thread] = ACTIONS(5053),
    [anon_sym_const] = ACTIONS(5053),
    [anon_sym_constexpr] = ACTIONS(5053),
    [anon_sym_volatile] = ACTIONS(5053),
    [anon_sym_restrict] = ACTIONS(5053),
    [anon_sym___restrict__] = ACTIONS(5053),
    [anon_sym__Atomic] = ACTIONS(5053),
    [anon_sym__Noreturn] = ACTIONS(5053),
    [anon_sym_noreturn] = ACTIONS(5053),
    [anon_sym_mutable] = ACTIONS(5053),
    [anon_sym_constinit] = ACTIONS(5053),
    [anon_sym_consteval] = ACTIONS(5053),
    [anon_sym_alignas] = ACTIONS(5053),
    [anon_sym__Alignas] = ACTIONS(5053),
    [sym_primitive_type] = ACTIONS(5053),
    [anon_sym_enum] = ACTIONS(5053),
    [anon_sym_class] = ACTIONS(5053),
    [anon_sym_struct] = ACTIONS(5053),
    [anon_sym_union] = ACTIONS(5053),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5053),
    [anon_sym_decltype] = ACTIONS(5053),
    [sym_virtual] = ACTIONS(5053),
    [anon_sym_explicit] = ACTIONS(5053),
    [anon_sym_typename] = ACTIONS(5053),
    [anon_sym_template] = ACTIONS(5053),
    [anon_sym_operator] = ACTIONS(5053),
    [anon_sym_friend] = ACTIONS(5053),
    [anon_sym_public] = ACTIONS(5053),
    [anon_sym_private] = ACTIONS(5053),
    [anon_sym_protected] = ACTIONS(5053),
    [anon_sym_using] = ACTIONS(5053),
    [anon_sym_static_assert] = ACTIONS(5053),
    [anon_sym_precise] = ACTIONS(5053),
    [anon_sym_shared] = ACTIONS(5053),
    [anon_sym_groupshared] = ACTIONS(5053),
    [anon_sym_uniform] = ACTIONS(5053),
    [anon_sym_row_major] = ACTIONS(5053),
    [anon_sym_column_major] = ACTIONS(5053),
    [anon_sym_globallycoherent] = ACTIONS(5053),
    [anon_sym_centroid] = ACTIONS(5053),
    [anon_sym_noperspective] = ACTIONS(5053),
    [anon_sym_nointerpolation] = ACTIONS(5053),
    [anon_sym_sample] = ACTIONS(5053),
    [anon_sym_linear] = ACTIONS(5053),
    [anon_sym_snorm] = ACTIONS(5053),
    [anon_sym_unorm] = ACTIONS(5053),
    [anon_sym_point] = ACTIONS(5053),
    [anon_sym_line] = ACTIONS(5053),
    [anon_sym_triangleadj] = ACTIONS(5053),
    [anon_sym_lineadj] = ACTIONS(5053),
    [anon_sym_triangle] = ACTIONS(5053),
  },
  [1882] = {
    [sym_identifier] = ACTIONS(2134),
    [aux_sym_preproc_def_token1] = ACTIONS(2134),
    [aux_sym_preproc_if_token1] = ACTIONS(2134),
    [aux_sym_preproc_if_token2] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2134),
    [aux_sym_preproc_else_token1] = ACTIONS(2134),
    [aux_sym_preproc_elif_token1] = ACTIONS(2134),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2134),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2134),
    [sym_preproc_directive] = ACTIONS(2134),
    [anon_sym_LPAREN2] = ACTIONS(2136),
    [anon_sym_TILDE] = ACTIONS(2136),
    [anon_sym_STAR] = ACTIONS(2136),
    [anon_sym_AMP_AMP] = ACTIONS(2136),
    [anon_sym_AMP] = ACTIONS(2134),
    [anon_sym___extension__] = ACTIONS(2134),
    [anon_sym_typedef] = ACTIONS(2134),
    [anon_sym_in] = ACTIONS(2134),
    [anon_sym_out] = ACTIONS(2134),
    [anon_sym_inout] = ACTIONS(2134),
    [anon_sym_extern] = ACTIONS(2134),
    [anon_sym___attribute__] = ACTIONS(2134),
    [anon_sym_COLON_COLON] = ACTIONS(2136),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2136),
    [anon_sym___declspec] = ACTIONS(2134),
    [anon_sym___based] = ACTIONS(2134),
    [anon_sym_signed] = ACTIONS(2134),
    [anon_sym_unsigned] = ACTIONS(2134),
    [anon_sym_long] = ACTIONS(2134),
    [anon_sym_short] = ACTIONS(2134),
    [anon_sym_LBRACK] = ACTIONS(2134),
    [anon_sym_static] = ACTIONS(2134),
    [anon_sym_register] = ACTIONS(2134),
    [anon_sym_inline] = ACTIONS(2134),
    [anon_sym___inline] = ACTIONS(2134),
    [anon_sym___inline__] = ACTIONS(2134),
    [anon_sym___forceinline] = ACTIONS(2134),
    [anon_sym_thread_local] = ACTIONS(2134),
    [anon_sym___thread] = ACTIONS(2134),
    [anon_sym_const] = ACTIONS(2134),
    [anon_sym_constexpr] = ACTIONS(2134),
    [anon_sym_volatile] = ACTIONS(2134),
    [anon_sym_restrict] = ACTIONS(2134),
    [anon_sym___restrict__] = ACTIONS(2134),
    [anon_sym__Atomic] = ACTIONS(2134),
    [anon_sym__Noreturn] = ACTIONS(2134),
    [anon_sym_noreturn] = ACTIONS(2134),
    [anon_sym_mutable] = ACTIONS(2134),
    [anon_sym_constinit] = ACTIONS(2134),
    [anon_sym_consteval] = ACTIONS(2134),
    [anon_sym_alignas] = ACTIONS(2134),
    [anon_sym__Alignas] = ACTIONS(2134),
    [sym_primitive_type] = ACTIONS(2134),
    [anon_sym_enum] = ACTIONS(2134),
    [anon_sym_class] = ACTIONS(2134),
    [anon_sym_struct] = ACTIONS(2134),
    [anon_sym_union] = ACTIONS(2134),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2134),
    [anon_sym_decltype] = ACTIONS(2134),
    [sym_virtual] = ACTIONS(2134),
    [anon_sym_explicit] = ACTIONS(2134),
    [anon_sym_typename] = ACTIONS(2134),
    [anon_sym_template] = ACTIONS(2134),
    [anon_sym_operator] = ACTIONS(2134),
    [anon_sym_friend] = ACTIONS(2134),
    [anon_sym_public] = ACTIONS(2134),
    [anon_sym_private] = ACTIONS(2134),
    [anon_sym_protected] = ACTIONS(2134),
    [anon_sym_using] = ACTIONS(2134),
    [anon_sym_static_assert] = ACTIONS(2134),
    [anon_sym_precise] = ACTIONS(2134),
    [anon_sym_shared] = ACTIONS(2134),
    [anon_sym_groupshared] = ACTIONS(2134),
    [anon_sym_uniform] = ACTIONS(2134),
    [anon_sym_row_major] = ACTIONS(2134),
    [anon_sym_column_major] = ACTIONS(2134),
    [anon_sym_globallycoherent] = ACTIONS(2134),
    [anon_sym_centroid] = ACTIONS(2134),
    [anon_sym_noperspective] = ACTIONS(2134),
    [anon_sym_nointerpolation] = ACTIONS(2134),
    [anon_sym_sample] = ACTIONS(2134),
    [anon_sym_linear] = ACTIONS(2134),
    [anon_sym_snorm] = ACTIONS(2134),
    [anon_sym_unorm] = ACTIONS(2134),
    [anon_sym_point] = ACTIONS(2134),
    [anon_sym_line] = ACTIONS(2134),
    [anon_sym_triangleadj] = ACTIONS(2134),
    [anon_sym_lineadj] = ACTIONS(2134),
    [anon_sym_triangle] = ACTIONS(2134),
  },
  [1883] = {
    [sym_identifier] = ACTIONS(2498),
    [aux_sym_preproc_def_token1] = ACTIONS(2498),
    [aux_sym_preproc_if_token1] = ACTIONS(2498),
    [aux_sym_preproc_if_token2] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2498),
    [aux_sym_preproc_else_token1] = ACTIONS(2498),
    [aux_sym_preproc_elif_token1] = ACTIONS(2498),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2498),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2498),
    [sym_preproc_directive] = ACTIONS(2498),
    [anon_sym_LPAREN2] = ACTIONS(2500),
    [anon_sym_TILDE] = ACTIONS(2500),
    [anon_sym_STAR] = ACTIONS(2500),
    [anon_sym_AMP_AMP] = ACTIONS(2500),
    [anon_sym_AMP] = ACTIONS(2498),
    [anon_sym___extension__] = ACTIONS(2498),
    [anon_sym_typedef] = ACTIONS(2498),
    [anon_sym_in] = ACTIONS(2498),
    [anon_sym_out] = ACTIONS(2498),
    [anon_sym_inout] = ACTIONS(2498),
    [anon_sym_extern] = ACTIONS(2498),
    [anon_sym___attribute__] = ACTIONS(2498),
    [anon_sym_COLON_COLON] = ACTIONS(2500),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2500),
    [anon_sym___declspec] = ACTIONS(2498),
    [anon_sym___based] = ACTIONS(2498),
    [anon_sym_signed] = ACTIONS(2498),
    [anon_sym_unsigned] = ACTIONS(2498),
    [anon_sym_long] = ACTIONS(2498),
    [anon_sym_short] = ACTIONS(2498),
    [anon_sym_LBRACK] = ACTIONS(2498),
    [anon_sym_static] = ACTIONS(2498),
    [anon_sym_register] = ACTIONS(2498),
    [anon_sym_inline] = ACTIONS(2498),
    [anon_sym___inline] = ACTIONS(2498),
    [anon_sym___inline__] = ACTIONS(2498),
    [anon_sym___forceinline] = ACTIONS(2498),
    [anon_sym_thread_local] = ACTIONS(2498),
    [anon_sym___thread] = ACTIONS(2498),
    [anon_sym_const] = ACTIONS(2498),
    [anon_sym_constexpr] = ACTIONS(2498),
    [anon_sym_volatile] = ACTIONS(2498),
    [anon_sym_restrict] = ACTIONS(2498),
    [anon_sym___restrict__] = ACTIONS(2498),
    [anon_sym__Atomic] = ACTIONS(2498),
    [anon_sym__Noreturn] = ACTIONS(2498),
    [anon_sym_noreturn] = ACTIONS(2498),
    [anon_sym_mutable] = ACTIONS(2498),
    [anon_sym_constinit] = ACTIONS(2498),
    [anon_sym_consteval] = ACTIONS(2498),
    [anon_sym_alignas] = ACTIONS(2498),
    [anon_sym__Alignas] = ACTIONS(2498),
    [sym_primitive_type] = ACTIONS(2498),
    [anon_sym_enum] = ACTIONS(2498),
    [anon_sym_class] = ACTIONS(2498),
    [anon_sym_struct] = ACTIONS(2498),
    [anon_sym_union] = ACTIONS(2498),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2498),
    [anon_sym_decltype] = ACTIONS(2498),
    [sym_virtual] = ACTIONS(2498),
    [anon_sym_explicit] = ACTIONS(2498),
    [anon_sym_typename] = ACTIONS(2498),
    [anon_sym_template] = ACTIONS(2498),
    [anon_sym_operator] = ACTIONS(2498),
    [anon_sym_friend] = ACTIONS(2498),
    [anon_sym_public] = ACTIONS(2498),
    [anon_sym_private] = ACTIONS(2498),
    [anon_sym_protected] = ACTIONS(2498),
    [anon_sym_using] = ACTIONS(2498),
    [anon_sym_static_assert] = ACTIONS(2498),
    [anon_sym_precise] = ACTIONS(2498),
    [anon_sym_shared] = ACTIONS(2498),
    [anon_sym_groupshared] = ACTIONS(2498),
    [anon_sym_uniform] = ACTIONS(2498),
    [anon_sym_row_major] = ACTIONS(2498),
    [anon_sym_column_major] = ACTIONS(2498),
    [anon_sym_globallycoherent] = ACTIONS(2498),
    [anon_sym_centroid] = ACTIONS(2498),
    [anon_sym_noperspective] = ACTIONS(2498),
    [anon_sym_nointerpolation] = ACTIONS(2498),
    [anon_sym_sample] = ACTIONS(2498),
    [anon_sym_linear] = ACTIONS(2498),
    [anon_sym_snorm] = ACTIONS(2498),
    [anon_sym_unorm] = ACTIONS(2498),
    [anon_sym_point] = ACTIONS(2498),
    [anon_sym_line] = ACTIONS(2498),
    [anon_sym_triangleadj] = ACTIONS(2498),
    [anon_sym_lineadj] = ACTIONS(2498),
    [anon_sym_triangle] = ACTIONS(2498),
  },
  [1884] = {
    [sym_identifier] = ACTIONS(5057),
    [aux_sym_preproc_def_token1] = ACTIONS(5057),
    [aux_sym_preproc_if_token1] = ACTIONS(5057),
    [aux_sym_preproc_if_token2] = ACTIONS(5057),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5057),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5057),
    [aux_sym_preproc_else_token1] = ACTIONS(5057),
    [aux_sym_preproc_elif_token1] = ACTIONS(5057),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5057),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5057),
    [sym_preproc_directive] = ACTIONS(5057),
    [anon_sym_LPAREN2] = ACTIONS(5059),
    [anon_sym_TILDE] = ACTIONS(5059),
    [anon_sym_STAR] = ACTIONS(5059),
    [anon_sym_AMP_AMP] = ACTIONS(5059),
    [anon_sym_AMP] = ACTIONS(5057),
    [anon_sym___extension__] = ACTIONS(5057),
    [anon_sym_typedef] = ACTIONS(5057),
    [anon_sym_in] = ACTIONS(5057),
    [anon_sym_out] = ACTIONS(5057),
    [anon_sym_inout] = ACTIONS(5057),
    [anon_sym_extern] = ACTIONS(5057),
    [anon_sym___attribute__] = ACTIONS(5057),
    [anon_sym_COLON_COLON] = ACTIONS(5059),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5059),
    [anon_sym___declspec] = ACTIONS(5057),
    [anon_sym___based] = ACTIONS(5057),
    [anon_sym_signed] = ACTIONS(5057),
    [anon_sym_unsigned] = ACTIONS(5057),
    [anon_sym_long] = ACTIONS(5057),
    [anon_sym_short] = ACTIONS(5057),
    [anon_sym_LBRACK] = ACTIONS(5057),
    [anon_sym_static] = ACTIONS(5057),
    [anon_sym_register] = ACTIONS(5057),
    [anon_sym_inline] = ACTIONS(5057),
    [anon_sym___inline] = ACTIONS(5057),
    [anon_sym___inline__] = ACTIONS(5057),
    [anon_sym___forceinline] = ACTIONS(5057),
    [anon_sym_thread_local] = ACTIONS(5057),
    [anon_sym___thread] = ACTIONS(5057),
    [anon_sym_const] = ACTIONS(5057),
    [anon_sym_constexpr] = ACTIONS(5057),
    [anon_sym_volatile] = ACTIONS(5057),
    [anon_sym_restrict] = ACTIONS(5057),
    [anon_sym___restrict__] = ACTIONS(5057),
    [anon_sym__Atomic] = ACTIONS(5057),
    [anon_sym__Noreturn] = ACTIONS(5057),
    [anon_sym_noreturn] = ACTIONS(5057),
    [anon_sym_mutable] = ACTIONS(5057),
    [anon_sym_constinit] = ACTIONS(5057),
    [anon_sym_consteval] = ACTIONS(5057),
    [anon_sym_alignas] = ACTIONS(5057),
    [anon_sym__Alignas] = ACTIONS(5057),
    [sym_primitive_type] = ACTIONS(5057),
    [anon_sym_enum] = ACTIONS(5057),
    [anon_sym_class] = ACTIONS(5057),
    [anon_sym_struct] = ACTIONS(5057),
    [anon_sym_union] = ACTIONS(5057),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5057),
    [anon_sym_decltype] = ACTIONS(5057),
    [sym_virtual] = ACTIONS(5057),
    [anon_sym_explicit] = ACTIONS(5057),
    [anon_sym_typename] = ACTIONS(5057),
    [anon_sym_template] = ACTIONS(5057),
    [anon_sym_operator] = ACTIONS(5057),
    [anon_sym_friend] = ACTIONS(5057),
    [anon_sym_public] = ACTIONS(5057),
    [anon_sym_private] = ACTIONS(5057),
    [anon_sym_protected] = ACTIONS(5057),
    [anon_sym_using] = ACTIONS(5057),
    [anon_sym_static_assert] = ACTIONS(5057),
    [anon_sym_precise] = ACTIONS(5057),
    [anon_sym_shared] = ACTIONS(5057),
    [anon_sym_groupshared] = ACTIONS(5057),
    [anon_sym_uniform] = ACTIONS(5057),
    [anon_sym_row_major] = ACTIONS(5057),
    [anon_sym_column_major] = ACTIONS(5057),
    [anon_sym_globallycoherent] = ACTIONS(5057),
    [anon_sym_centroid] = ACTIONS(5057),
    [anon_sym_noperspective] = ACTIONS(5057),
    [anon_sym_nointerpolation] = ACTIONS(5057),
    [anon_sym_sample] = ACTIONS(5057),
    [anon_sym_linear] = ACTIONS(5057),
    [anon_sym_snorm] = ACTIONS(5057),
    [anon_sym_unorm] = ACTIONS(5057),
    [anon_sym_point] = ACTIONS(5057),
    [anon_sym_line] = ACTIONS(5057),
    [anon_sym_triangleadj] = ACTIONS(5057),
    [anon_sym_lineadj] = ACTIONS(5057),
    [anon_sym_triangle] = ACTIONS(5057),
  },
  [1885] = {
    [sym_identifier] = ACTIONS(5061),
    [aux_sym_preproc_def_token1] = ACTIONS(5061),
    [aux_sym_preproc_if_token1] = ACTIONS(5061),
    [aux_sym_preproc_if_token2] = ACTIONS(5061),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5061),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5061),
    [aux_sym_preproc_else_token1] = ACTIONS(5061),
    [aux_sym_preproc_elif_token1] = ACTIONS(5061),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5061),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5061),
    [sym_preproc_directive] = ACTIONS(5061),
    [anon_sym_LPAREN2] = ACTIONS(5063),
    [anon_sym_TILDE] = ACTIONS(5063),
    [anon_sym_STAR] = ACTIONS(5063),
    [anon_sym_AMP_AMP] = ACTIONS(5063),
    [anon_sym_AMP] = ACTIONS(5061),
    [anon_sym___extension__] = ACTIONS(5061),
    [anon_sym_typedef] = ACTIONS(5061),
    [anon_sym_in] = ACTIONS(5061),
    [anon_sym_out] = ACTIONS(5061),
    [anon_sym_inout] = ACTIONS(5061),
    [anon_sym_extern] = ACTIONS(5061),
    [anon_sym___attribute__] = ACTIONS(5061),
    [anon_sym_COLON_COLON] = ACTIONS(5063),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5063),
    [anon_sym___declspec] = ACTIONS(5061),
    [anon_sym___based] = ACTIONS(5061),
    [anon_sym_signed] = ACTIONS(5061),
    [anon_sym_unsigned] = ACTIONS(5061),
    [anon_sym_long] = ACTIONS(5061),
    [anon_sym_short] = ACTIONS(5061),
    [anon_sym_LBRACK] = ACTIONS(5061),
    [anon_sym_static] = ACTIONS(5061),
    [anon_sym_register] = ACTIONS(5061),
    [anon_sym_inline] = ACTIONS(5061),
    [anon_sym___inline] = ACTIONS(5061),
    [anon_sym___inline__] = ACTIONS(5061),
    [anon_sym___forceinline] = ACTIONS(5061),
    [anon_sym_thread_local] = ACTIONS(5061),
    [anon_sym___thread] = ACTIONS(5061),
    [anon_sym_const] = ACTIONS(5061),
    [anon_sym_constexpr] = ACTIONS(5061),
    [anon_sym_volatile] = ACTIONS(5061),
    [anon_sym_restrict] = ACTIONS(5061),
    [anon_sym___restrict__] = ACTIONS(5061),
    [anon_sym__Atomic] = ACTIONS(5061),
    [anon_sym__Noreturn] = ACTIONS(5061),
    [anon_sym_noreturn] = ACTIONS(5061),
    [anon_sym_mutable] = ACTIONS(5061),
    [anon_sym_constinit] = ACTIONS(5061),
    [anon_sym_consteval] = ACTIONS(5061),
    [anon_sym_alignas] = ACTIONS(5061),
    [anon_sym__Alignas] = ACTIONS(5061),
    [sym_primitive_type] = ACTIONS(5061),
    [anon_sym_enum] = ACTIONS(5061),
    [anon_sym_class] = ACTIONS(5061),
    [anon_sym_struct] = ACTIONS(5061),
    [anon_sym_union] = ACTIONS(5061),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5061),
    [anon_sym_decltype] = ACTIONS(5061),
    [sym_virtual] = ACTIONS(5061),
    [anon_sym_explicit] = ACTIONS(5061),
    [anon_sym_typename] = ACTIONS(5061),
    [anon_sym_template] = ACTIONS(5061),
    [anon_sym_operator] = ACTIONS(5061),
    [anon_sym_friend] = ACTIONS(5061),
    [anon_sym_public] = ACTIONS(5061),
    [anon_sym_private] = ACTIONS(5061),
    [anon_sym_protected] = ACTIONS(5061),
    [anon_sym_using] = ACTIONS(5061),
    [anon_sym_static_assert] = ACTIONS(5061),
    [anon_sym_precise] = ACTIONS(5061),
    [anon_sym_shared] = ACTIONS(5061),
    [anon_sym_groupshared] = ACTIONS(5061),
    [anon_sym_uniform] = ACTIONS(5061),
    [anon_sym_row_major] = ACTIONS(5061),
    [anon_sym_column_major] = ACTIONS(5061),
    [anon_sym_globallycoherent] = ACTIONS(5061),
    [anon_sym_centroid] = ACTIONS(5061),
    [anon_sym_noperspective] = ACTIONS(5061),
    [anon_sym_nointerpolation] = ACTIONS(5061),
    [anon_sym_sample] = ACTIONS(5061),
    [anon_sym_linear] = ACTIONS(5061),
    [anon_sym_snorm] = ACTIONS(5061),
    [anon_sym_unorm] = ACTIONS(5061),
    [anon_sym_point] = ACTIONS(5061),
    [anon_sym_line] = ACTIONS(5061),
    [anon_sym_triangleadj] = ACTIONS(5061),
    [anon_sym_lineadj] = ACTIONS(5061),
    [anon_sym_triangle] = ACTIONS(5061),
  },
  [1886] = {
    [sym_identifier] = ACTIONS(2312),
    [aux_sym_preproc_def_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token2] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2312),
    [aux_sym_preproc_else_token1] = ACTIONS(2312),
    [aux_sym_preproc_elif_token1] = ACTIONS(2312),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2312),
    [sym_preproc_directive] = ACTIONS(2312),
    [anon_sym_LPAREN2] = ACTIONS(2314),
    [anon_sym_TILDE] = ACTIONS(2314),
    [anon_sym_STAR] = ACTIONS(2314),
    [anon_sym_AMP_AMP] = ACTIONS(2314),
    [anon_sym_AMP] = ACTIONS(2312),
    [anon_sym___extension__] = ACTIONS(2312),
    [anon_sym_typedef] = ACTIONS(2312),
    [anon_sym_in] = ACTIONS(2312),
    [anon_sym_out] = ACTIONS(2312),
    [anon_sym_inout] = ACTIONS(2312),
    [anon_sym_extern] = ACTIONS(2312),
    [anon_sym___attribute__] = ACTIONS(2312),
    [anon_sym_COLON_COLON] = ACTIONS(2314),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2314),
    [anon_sym___declspec] = ACTIONS(2312),
    [anon_sym___based] = ACTIONS(2312),
    [anon_sym_signed] = ACTIONS(2312),
    [anon_sym_unsigned] = ACTIONS(2312),
    [anon_sym_long] = ACTIONS(2312),
    [anon_sym_short] = ACTIONS(2312),
    [anon_sym_LBRACK] = ACTIONS(2312),
    [anon_sym_static] = ACTIONS(2312),
    [anon_sym_register] = ACTIONS(2312),
    [anon_sym_inline] = ACTIONS(2312),
    [anon_sym___inline] = ACTIONS(2312),
    [anon_sym___inline__] = ACTIONS(2312),
    [anon_sym___forceinline] = ACTIONS(2312),
    [anon_sym_thread_local] = ACTIONS(2312),
    [anon_sym___thread] = ACTIONS(2312),
    [anon_sym_const] = ACTIONS(2312),
    [anon_sym_constexpr] = ACTIONS(2312),
    [anon_sym_volatile] = ACTIONS(2312),
    [anon_sym_restrict] = ACTIONS(2312),
    [anon_sym___restrict__] = ACTIONS(2312),
    [anon_sym__Atomic] = ACTIONS(2312),
    [anon_sym__Noreturn] = ACTIONS(2312),
    [anon_sym_noreturn] = ACTIONS(2312),
    [anon_sym_mutable] = ACTIONS(2312),
    [anon_sym_constinit] = ACTIONS(2312),
    [anon_sym_consteval] = ACTIONS(2312),
    [anon_sym_alignas] = ACTIONS(2312),
    [anon_sym__Alignas] = ACTIONS(2312),
    [sym_primitive_type] = ACTIONS(2312),
    [anon_sym_enum] = ACTIONS(2312),
    [anon_sym_class] = ACTIONS(2312),
    [anon_sym_struct] = ACTIONS(2312),
    [anon_sym_union] = ACTIONS(2312),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2312),
    [anon_sym_decltype] = ACTIONS(2312),
    [sym_virtual] = ACTIONS(2312),
    [anon_sym_explicit] = ACTIONS(2312),
    [anon_sym_typename] = ACTIONS(2312),
    [anon_sym_template] = ACTIONS(2312),
    [anon_sym_operator] = ACTIONS(2312),
    [anon_sym_friend] = ACTIONS(2312),
    [anon_sym_public] = ACTIONS(2312),
    [anon_sym_private] = ACTIONS(2312),
    [anon_sym_protected] = ACTIONS(2312),
    [anon_sym_using] = ACTIONS(2312),
    [anon_sym_static_assert] = ACTIONS(2312),
    [anon_sym_precise] = ACTIONS(2312),
    [anon_sym_shared] = ACTIONS(2312),
    [anon_sym_groupshared] = ACTIONS(2312),
    [anon_sym_uniform] = ACTIONS(2312),
    [anon_sym_row_major] = ACTIONS(2312),
    [anon_sym_column_major] = ACTIONS(2312),
    [anon_sym_globallycoherent] = ACTIONS(2312),
    [anon_sym_centroid] = ACTIONS(2312),
    [anon_sym_noperspective] = ACTIONS(2312),
    [anon_sym_nointerpolation] = ACTIONS(2312),
    [anon_sym_sample] = ACTIONS(2312),
    [anon_sym_linear] = ACTIONS(2312),
    [anon_sym_snorm] = ACTIONS(2312),
    [anon_sym_unorm] = ACTIONS(2312),
    [anon_sym_point] = ACTIONS(2312),
    [anon_sym_line] = ACTIONS(2312),
    [anon_sym_triangleadj] = ACTIONS(2312),
    [anon_sym_lineadj] = ACTIONS(2312),
    [anon_sym_triangle] = ACTIONS(2312),
  },
  [1887] = {
    [sym_identifier] = ACTIONS(2482),
    [aux_sym_preproc_def_token1] = ACTIONS(2482),
    [aux_sym_preproc_if_token1] = ACTIONS(2482),
    [aux_sym_preproc_if_token2] = ACTIONS(2482),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2482),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2482),
    [aux_sym_preproc_else_token1] = ACTIONS(2482),
    [aux_sym_preproc_elif_token1] = ACTIONS(2482),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2482),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2482),
    [sym_preproc_directive] = ACTIONS(2482),
    [anon_sym_LPAREN2] = ACTIONS(2484),
    [anon_sym_TILDE] = ACTIONS(2484),
    [anon_sym_STAR] = ACTIONS(2484),
    [anon_sym_AMP_AMP] = ACTIONS(2484),
    [anon_sym_AMP] = ACTIONS(2482),
    [anon_sym___extension__] = ACTIONS(2482),
    [anon_sym_typedef] = ACTIONS(2482),
    [anon_sym_in] = ACTIONS(2482),
    [anon_sym_out] = ACTIONS(2482),
    [anon_sym_inout] = ACTIONS(2482),
    [anon_sym_extern] = ACTIONS(2482),
    [anon_sym___attribute__] = ACTIONS(2482),
    [anon_sym_COLON_COLON] = ACTIONS(2484),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2484),
    [anon_sym___declspec] = ACTIONS(2482),
    [anon_sym___based] = ACTIONS(2482),
    [anon_sym_signed] = ACTIONS(2482),
    [anon_sym_unsigned] = ACTIONS(2482),
    [anon_sym_long] = ACTIONS(2482),
    [anon_sym_short] = ACTIONS(2482),
    [anon_sym_LBRACK] = ACTIONS(2482),
    [anon_sym_static] = ACTIONS(2482),
    [anon_sym_register] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(2482),
    [anon_sym___inline] = ACTIONS(2482),
    [anon_sym___inline__] = ACTIONS(2482),
    [anon_sym___forceinline] = ACTIONS(2482),
    [anon_sym_thread_local] = ACTIONS(2482),
    [anon_sym___thread] = ACTIONS(2482),
    [anon_sym_const] = ACTIONS(2482),
    [anon_sym_constexpr] = ACTIONS(2482),
    [anon_sym_volatile] = ACTIONS(2482),
    [anon_sym_restrict] = ACTIONS(2482),
    [anon_sym___restrict__] = ACTIONS(2482),
    [anon_sym__Atomic] = ACTIONS(2482),
    [anon_sym__Noreturn] = ACTIONS(2482),
    [anon_sym_noreturn] = ACTIONS(2482),
    [anon_sym_mutable] = ACTIONS(2482),
    [anon_sym_constinit] = ACTIONS(2482),
    [anon_sym_consteval] = ACTIONS(2482),
    [anon_sym_alignas] = ACTIONS(2482),
    [anon_sym__Alignas] = ACTIONS(2482),
    [sym_primitive_type] = ACTIONS(2482),
    [anon_sym_enum] = ACTIONS(2482),
    [anon_sym_class] = ACTIONS(2482),
    [anon_sym_struct] = ACTIONS(2482),
    [anon_sym_union] = ACTIONS(2482),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2482),
    [anon_sym_decltype] = ACTIONS(2482),
    [sym_virtual] = ACTIONS(2482),
    [anon_sym_explicit] = ACTIONS(2482),
    [anon_sym_typename] = ACTIONS(2482),
    [anon_sym_template] = ACTIONS(2482),
    [anon_sym_operator] = ACTIONS(2482),
    [anon_sym_friend] = ACTIONS(2482),
    [anon_sym_public] = ACTIONS(2482),
    [anon_sym_private] = ACTIONS(2482),
    [anon_sym_protected] = ACTIONS(2482),
    [anon_sym_using] = ACTIONS(2482),
    [anon_sym_static_assert] = ACTIONS(2482),
    [anon_sym_precise] = ACTIONS(2482),
    [anon_sym_shared] = ACTIONS(2482),
    [anon_sym_groupshared] = ACTIONS(2482),
    [anon_sym_uniform] = ACTIONS(2482),
    [anon_sym_row_major] = ACTIONS(2482),
    [anon_sym_column_major] = ACTIONS(2482),
    [anon_sym_globallycoherent] = ACTIONS(2482),
    [anon_sym_centroid] = ACTIONS(2482),
    [anon_sym_noperspective] = ACTIONS(2482),
    [anon_sym_nointerpolation] = ACTIONS(2482),
    [anon_sym_sample] = ACTIONS(2482),
    [anon_sym_linear] = ACTIONS(2482),
    [anon_sym_snorm] = ACTIONS(2482),
    [anon_sym_unorm] = ACTIONS(2482),
    [anon_sym_point] = ACTIONS(2482),
    [anon_sym_line] = ACTIONS(2482),
    [anon_sym_triangleadj] = ACTIONS(2482),
    [anon_sym_lineadj] = ACTIONS(2482),
    [anon_sym_triangle] = ACTIONS(2482),
  },
  [1888] = {
    [sym_identifier] = ACTIONS(5065),
    [aux_sym_preproc_def_token1] = ACTIONS(5065),
    [aux_sym_preproc_if_token1] = ACTIONS(5065),
    [aux_sym_preproc_if_token2] = ACTIONS(5065),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5065),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5065),
    [aux_sym_preproc_else_token1] = ACTIONS(5065),
    [aux_sym_preproc_elif_token1] = ACTIONS(5065),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5065),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5065),
    [sym_preproc_directive] = ACTIONS(5065),
    [anon_sym_LPAREN2] = ACTIONS(5067),
    [anon_sym_TILDE] = ACTIONS(5067),
    [anon_sym_STAR] = ACTIONS(5067),
    [anon_sym_AMP_AMP] = ACTIONS(5067),
    [anon_sym_AMP] = ACTIONS(5065),
    [anon_sym___extension__] = ACTIONS(5065),
    [anon_sym_typedef] = ACTIONS(5065),
    [anon_sym_in] = ACTIONS(5065),
    [anon_sym_out] = ACTIONS(5065),
    [anon_sym_inout] = ACTIONS(5065),
    [anon_sym_extern] = ACTIONS(5065),
    [anon_sym___attribute__] = ACTIONS(5065),
    [anon_sym_COLON_COLON] = ACTIONS(5067),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5067),
    [anon_sym___declspec] = ACTIONS(5065),
    [anon_sym___based] = ACTIONS(5065),
    [anon_sym_signed] = ACTIONS(5065),
    [anon_sym_unsigned] = ACTIONS(5065),
    [anon_sym_long] = ACTIONS(5065),
    [anon_sym_short] = ACTIONS(5065),
    [anon_sym_LBRACK] = ACTIONS(5065),
    [anon_sym_static] = ACTIONS(5065),
    [anon_sym_register] = ACTIONS(5065),
    [anon_sym_inline] = ACTIONS(5065),
    [anon_sym___inline] = ACTIONS(5065),
    [anon_sym___inline__] = ACTIONS(5065),
    [anon_sym___forceinline] = ACTIONS(5065),
    [anon_sym_thread_local] = ACTIONS(5065),
    [anon_sym___thread] = ACTIONS(5065),
    [anon_sym_const] = ACTIONS(5065),
    [anon_sym_constexpr] = ACTIONS(5065),
    [anon_sym_volatile] = ACTIONS(5065),
    [anon_sym_restrict] = ACTIONS(5065),
    [anon_sym___restrict__] = ACTIONS(5065),
    [anon_sym__Atomic] = ACTIONS(5065),
    [anon_sym__Noreturn] = ACTIONS(5065),
    [anon_sym_noreturn] = ACTIONS(5065),
    [anon_sym_mutable] = ACTIONS(5065),
    [anon_sym_constinit] = ACTIONS(5065),
    [anon_sym_consteval] = ACTIONS(5065),
    [anon_sym_alignas] = ACTIONS(5065),
    [anon_sym__Alignas] = ACTIONS(5065),
    [sym_primitive_type] = ACTIONS(5065),
    [anon_sym_enum] = ACTIONS(5065),
    [anon_sym_class] = ACTIONS(5065),
    [anon_sym_struct] = ACTIONS(5065),
    [anon_sym_union] = ACTIONS(5065),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5065),
    [anon_sym_decltype] = ACTIONS(5065),
    [sym_virtual] = ACTIONS(5065),
    [anon_sym_explicit] = ACTIONS(5065),
    [anon_sym_typename] = ACTIONS(5065),
    [anon_sym_template] = ACTIONS(5065),
    [anon_sym_operator] = ACTIONS(5065),
    [anon_sym_friend] = ACTIONS(5065),
    [anon_sym_public] = ACTIONS(5065),
    [anon_sym_private] = ACTIONS(5065),
    [anon_sym_protected] = ACTIONS(5065),
    [anon_sym_using] = ACTIONS(5065),
    [anon_sym_static_assert] = ACTIONS(5065),
    [anon_sym_precise] = ACTIONS(5065),
    [anon_sym_shared] = ACTIONS(5065),
    [anon_sym_groupshared] = ACTIONS(5065),
    [anon_sym_uniform] = ACTIONS(5065),
    [anon_sym_row_major] = ACTIONS(5065),
    [anon_sym_column_major] = ACTIONS(5065),
    [anon_sym_globallycoherent] = ACTIONS(5065),
    [anon_sym_centroid] = ACTIONS(5065),
    [anon_sym_noperspective] = ACTIONS(5065),
    [anon_sym_nointerpolation] = ACTIONS(5065),
    [anon_sym_sample] = ACTIONS(5065),
    [anon_sym_linear] = ACTIONS(5065),
    [anon_sym_snorm] = ACTIONS(5065),
    [anon_sym_unorm] = ACTIONS(5065),
    [anon_sym_point] = ACTIONS(5065),
    [anon_sym_line] = ACTIONS(5065),
    [anon_sym_triangleadj] = ACTIONS(5065),
    [anon_sym_lineadj] = ACTIONS(5065),
    [anon_sym_triangle] = ACTIONS(5065),
  },
  [1889] = {
    [sym_identifier] = ACTIONS(5069),
    [aux_sym_preproc_def_token1] = ACTIONS(5069),
    [aux_sym_preproc_if_token1] = ACTIONS(5069),
    [aux_sym_preproc_if_token2] = ACTIONS(5069),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5069),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5069),
    [aux_sym_preproc_else_token1] = ACTIONS(5069),
    [aux_sym_preproc_elif_token1] = ACTIONS(5069),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5069),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5069),
    [sym_preproc_directive] = ACTIONS(5069),
    [anon_sym_LPAREN2] = ACTIONS(5071),
    [anon_sym_TILDE] = ACTIONS(5071),
    [anon_sym_STAR] = ACTIONS(5071),
    [anon_sym_AMP_AMP] = ACTIONS(5071),
    [anon_sym_AMP] = ACTIONS(5069),
    [anon_sym___extension__] = ACTIONS(5069),
    [anon_sym_typedef] = ACTIONS(5069),
    [anon_sym_in] = ACTIONS(5069),
    [anon_sym_out] = ACTIONS(5069),
    [anon_sym_inout] = ACTIONS(5069),
    [anon_sym_extern] = ACTIONS(5069),
    [anon_sym___attribute__] = ACTIONS(5069),
    [anon_sym_COLON_COLON] = ACTIONS(5071),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5071),
    [anon_sym___declspec] = ACTIONS(5069),
    [anon_sym___based] = ACTIONS(5069),
    [anon_sym_signed] = ACTIONS(5069),
    [anon_sym_unsigned] = ACTIONS(5069),
    [anon_sym_long] = ACTIONS(5069),
    [anon_sym_short] = ACTIONS(5069),
    [anon_sym_LBRACK] = ACTIONS(5069),
    [anon_sym_static] = ACTIONS(5069),
    [anon_sym_register] = ACTIONS(5069),
    [anon_sym_inline] = ACTIONS(5069),
    [anon_sym___inline] = ACTIONS(5069),
    [anon_sym___inline__] = ACTIONS(5069),
    [anon_sym___forceinline] = ACTIONS(5069),
    [anon_sym_thread_local] = ACTIONS(5069),
    [anon_sym___thread] = ACTIONS(5069),
    [anon_sym_const] = ACTIONS(5069),
    [anon_sym_constexpr] = ACTIONS(5069),
    [anon_sym_volatile] = ACTIONS(5069),
    [anon_sym_restrict] = ACTIONS(5069),
    [anon_sym___restrict__] = ACTIONS(5069),
    [anon_sym__Atomic] = ACTIONS(5069),
    [anon_sym__Noreturn] = ACTIONS(5069),
    [anon_sym_noreturn] = ACTIONS(5069),
    [anon_sym_mutable] = ACTIONS(5069),
    [anon_sym_constinit] = ACTIONS(5069),
    [anon_sym_consteval] = ACTIONS(5069),
    [anon_sym_alignas] = ACTIONS(5069),
    [anon_sym__Alignas] = ACTIONS(5069),
    [sym_primitive_type] = ACTIONS(5069),
    [anon_sym_enum] = ACTIONS(5069),
    [anon_sym_class] = ACTIONS(5069),
    [anon_sym_struct] = ACTIONS(5069),
    [anon_sym_union] = ACTIONS(5069),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5069),
    [anon_sym_decltype] = ACTIONS(5069),
    [sym_virtual] = ACTIONS(5069),
    [anon_sym_explicit] = ACTIONS(5069),
    [anon_sym_typename] = ACTIONS(5069),
    [anon_sym_template] = ACTIONS(5069),
    [anon_sym_operator] = ACTIONS(5069),
    [anon_sym_friend] = ACTIONS(5069),
    [anon_sym_public] = ACTIONS(5069),
    [anon_sym_private] = ACTIONS(5069),
    [anon_sym_protected] = ACTIONS(5069),
    [anon_sym_using] = ACTIONS(5069),
    [anon_sym_static_assert] = ACTIONS(5069),
    [anon_sym_precise] = ACTIONS(5069),
    [anon_sym_shared] = ACTIONS(5069),
    [anon_sym_groupshared] = ACTIONS(5069),
    [anon_sym_uniform] = ACTIONS(5069),
    [anon_sym_row_major] = ACTIONS(5069),
    [anon_sym_column_major] = ACTIONS(5069),
    [anon_sym_globallycoherent] = ACTIONS(5069),
    [anon_sym_centroid] = ACTIONS(5069),
    [anon_sym_noperspective] = ACTIONS(5069),
    [anon_sym_nointerpolation] = ACTIONS(5069),
    [anon_sym_sample] = ACTIONS(5069),
    [anon_sym_linear] = ACTIONS(5069),
    [anon_sym_snorm] = ACTIONS(5069),
    [anon_sym_unorm] = ACTIONS(5069),
    [anon_sym_point] = ACTIONS(5069),
    [anon_sym_line] = ACTIONS(5069),
    [anon_sym_triangleadj] = ACTIONS(5069),
    [anon_sym_lineadj] = ACTIONS(5069),
    [anon_sym_triangle] = ACTIONS(5069),
  },
  [1890] = {
    [sym_identifier] = ACTIONS(2470),
    [aux_sym_preproc_def_token1] = ACTIONS(2470),
    [aux_sym_preproc_if_token1] = ACTIONS(2470),
    [aux_sym_preproc_if_token2] = ACTIONS(2470),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2470),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2470),
    [aux_sym_preproc_else_token1] = ACTIONS(2470),
    [aux_sym_preproc_elif_token1] = ACTIONS(2470),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2470),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2470),
    [sym_preproc_directive] = ACTIONS(2470),
    [anon_sym_LPAREN2] = ACTIONS(2472),
    [anon_sym_TILDE] = ACTIONS(2472),
    [anon_sym_STAR] = ACTIONS(2472),
    [anon_sym_AMP_AMP] = ACTIONS(2472),
    [anon_sym_AMP] = ACTIONS(2470),
    [anon_sym___extension__] = ACTIONS(2470),
    [anon_sym_typedef] = ACTIONS(2470),
    [anon_sym_in] = ACTIONS(2470),
    [anon_sym_out] = ACTIONS(2470),
    [anon_sym_inout] = ACTIONS(2470),
    [anon_sym_extern] = ACTIONS(2470),
    [anon_sym___attribute__] = ACTIONS(2470),
    [anon_sym_COLON_COLON] = ACTIONS(2472),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2472),
    [anon_sym___declspec] = ACTIONS(2470),
    [anon_sym___based] = ACTIONS(2470),
    [anon_sym_signed] = ACTIONS(2470),
    [anon_sym_unsigned] = ACTIONS(2470),
    [anon_sym_long] = ACTIONS(2470),
    [anon_sym_short] = ACTIONS(2470),
    [anon_sym_LBRACK] = ACTIONS(2470),
    [anon_sym_static] = ACTIONS(2470),
    [anon_sym_register] = ACTIONS(2470),
    [anon_sym_inline] = ACTIONS(2470),
    [anon_sym___inline] = ACTIONS(2470),
    [anon_sym___inline__] = ACTIONS(2470),
    [anon_sym___forceinline] = ACTIONS(2470),
    [anon_sym_thread_local] = ACTIONS(2470),
    [anon_sym___thread] = ACTIONS(2470),
    [anon_sym_const] = ACTIONS(2470),
    [anon_sym_constexpr] = ACTIONS(2470),
    [anon_sym_volatile] = ACTIONS(2470),
    [anon_sym_restrict] = ACTIONS(2470),
    [anon_sym___restrict__] = ACTIONS(2470),
    [anon_sym__Atomic] = ACTIONS(2470),
    [anon_sym__Noreturn] = ACTIONS(2470),
    [anon_sym_noreturn] = ACTIONS(2470),
    [anon_sym_mutable] = ACTIONS(2470),
    [anon_sym_constinit] = ACTIONS(2470),
    [anon_sym_consteval] = ACTIONS(2470),
    [anon_sym_alignas] = ACTIONS(2470),
    [anon_sym__Alignas] = ACTIONS(2470),
    [sym_primitive_type] = ACTIONS(2470),
    [anon_sym_enum] = ACTIONS(2470),
    [anon_sym_class] = ACTIONS(2470),
    [anon_sym_struct] = ACTIONS(2470),
    [anon_sym_union] = ACTIONS(2470),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2470),
    [anon_sym_decltype] = ACTIONS(2470),
    [sym_virtual] = ACTIONS(2470),
    [anon_sym_explicit] = ACTIONS(2470),
    [anon_sym_typename] = ACTIONS(2470),
    [anon_sym_template] = ACTIONS(2470),
    [anon_sym_operator] = ACTIONS(2470),
    [anon_sym_friend] = ACTIONS(2470),
    [anon_sym_public] = ACTIONS(2470),
    [anon_sym_private] = ACTIONS(2470),
    [anon_sym_protected] = ACTIONS(2470),
    [anon_sym_using] = ACTIONS(2470),
    [anon_sym_static_assert] = ACTIONS(2470),
    [anon_sym_precise] = ACTIONS(2470),
    [anon_sym_shared] = ACTIONS(2470),
    [anon_sym_groupshared] = ACTIONS(2470),
    [anon_sym_uniform] = ACTIONS(2470),
    [anon_sym_row_major] = ACTIONS(2470),
    [anon_sym_column_major] = ACTIONS(2470),
    [anon_sym_globallycoherent] = ACTIONS(2470),
    [anon_sym_centroid] = ACTIONS(2470),
    [anon_sym_noperspective] = ACTIONS(2470),
    [anon_sym_nointerpolation] = ACTIONS(2470),
    [anon_sym_sample] = ACTIONS(2470),
    [anon_sym_linear] = ACTIONS(2470),
    [anon_sym_snorm] = ACTIONS(2470),
    [anon_sym_unorm] = ACTIONS(2470),
    [anon_sym_point] = ACTIONS(2470),
    [anon_sym_line] = ACTIONS(2470),
    [anon_sym_triangleadj] = ACTIONS(2470),
    [anon_sym_lineadj] = ACTIONS(2470),
    [anon_sym_triangle] = ACTIONS(2470),
  },
  [1891] = {
    [sym_identifier] = ACTIONS(5073),
    [aux_sym_preproc_def_token1] = ACTIONS(5073),
    [aux_sym_preproc_if_token1] = ACTIONS(5073),
    [aux_sym_preproc_if_token2] = ACTIONS(5073),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5073),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5073),
    [aux_sym_preproc_else_token1] = ACTIONS(5073),
    [aux_sym_preproc_elif_token1] = ACTIONS(5073),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5073),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5073),
    [sym_preproc_directive] = ACTIONS(5073),
    [anon_sym_LPAREN2] = ACTIONS(5075),
    [anon_sym_TILDE] = ACTIONS(5075),
    [anon_sym_STAR] = ACTIONS(5075),
    [anon_sym_AMP_AMP] = ACTIONS(5075),
    [anon_sym_AMP] = ACTIONS(5073),
    [anon_sym___extension__] = ACTIONS(5073),
    [anon_sym_typedef] = ACTIONS(5073),
    [anon_sym_in] = ACTIONS(5073),
    [anon_sym_out] = ACTIONS(5073),
    [anon_sym_inout] = ACTIONS(5073),
    [anon_sym_extern] = ACTIONS(5073),
    [anon_sym___attribute__] = ACTIONS(5073),
    [anon_sym_COLON_COLON] = ACTIONS(5075),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5075),
    [anon_sym___declspec] = ACTIONS(5073),
    [anon_sym___based] = ACTIONS(5073),
    [anon_sym_signed] = ACTIONS(5073),
    [anon_sym_unsigned] = ACTIONS(5073),
    [anon_sym_long] = ACTIONS(5073),
    [anon_sym_short] = ACTIONS(5073),
    [anon_sym_LBRACK] = ACTIONS(5073),
    [anon_sym_static] = ACTIONS(5073),
    [anon_sym_register] = ACTIONS(5073),
    [anon_sym_inline] = ACTIONS(5073),
    [anon_sym___inline] = ACTIONS(5073),
    [anon_sym___inline__] = ACTIONS(5073),
    [anon_sym___forceinline] = ACTIONS(5073),
    [anon_sym_thread_local] = ACTIONS(5073),
    [anon_sym___thread] = ACTIONS(5073),
    [anon_sym_const] = ACTIONS(5073),
    [anon_sym_constexpr] = ACTIONS(5073),
    [anon_sym_volatile] = ACTIONS(5073),
    [anon_sym_restrict] = ACTIONS(5073),
    [anon_sym___restrict__] = ACTIONS(5073),
    [anon_sym__Atomic] = ACTIONS(5073),
    [anon_sym__Noreturn] = ACTIONS(5073),
    [anon_sym_noreturn] = ACTIONS(5073),
    [anon_sym_mutable] = ACTIONS(5073),
    [anon_sym_constinit] = ACTIONS(5073),
    [anon_sym_consteval] = ACTIONS(5073),
    [anon_sym_alignas] = ACTIONS(5073),
    [anon_sym__Alignas] = ACTIONS(5073),
    [sym_primitive_type] = ACTIONS(5073),
    [anon_sym_enum] = ACTIONS(5073),
    [anon_sym_class] = ACTIONS(5073),
    [anon_sym_struct] = ACTIONS(5073),
    [anon_sym_union] = ACTIONS(5073),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5073),
    [anon_sym_decltype] = ACTIONS(5073),
    [sym_virtual] = ACTIONS(5073),
    [anon_sym_explicit] = ACTIONS(5073),
    [anon_sym_typename] = ACTIONS(5073),
    [anon_sym_template] = ACTIONS(5073),
    [anon_sym_operator] = ACTIONS(5073),
    [anon_sym_friend] = ACTIONS(5073),
    [anon_sym_public] = ACTIONS(5073),
    [anon_sym_private] = ACTIONS(5073),
    [anon_sym_protected] = ACTIONS(5073),
    [anon_sym_using] = ACTIONS(5073),
    [anon_sym_static_assert] = ACTIONS(5073),
    [anon_sym_precise] = ACTIONS(5073),
    [anon_sym_shared] = ACTIONS(5073),
    [anon_sym_groupshared] = ACTIONS(5073),
    [anon_sym_uniform] = ACTIONS(5073),
    [anon_sym_row_major] = ACTIONS(5073),
    [anon_sym_column_major] = ACTIONS(5073),
    [anon_sym_globallycoherent] = ACTIONS(5073),
    [anon_sym_centroid] = ACTIONS(5073),
    [anon_sym_noperspective] = ACTIONS(5073),
    [anon_sym_nointerpolation] = ACTIONS(5073),
    [anon_sym_sample] = ACTIONS(5073),
    [anon_sym_linear] = ACTIONS(5073),
    [anon_sym_snorm] = ACTIONS(5073),
    [anon_sym_unorm] = ACTIONS(5073),
    [anon_sym_point] = ACTIONS(5073),
    [anon_sym_line] = ACTIONS(5073),
    [anon_sym_triangleadj] = ACTIONS(5073),
    [anon_sym_lineadj] = ACTIONS(5073),
    [anon_sym_triangle] = ACTIONS(5073),
  },
  [1892] = {
    [sym_identifier] = ACTIONS(5073),
    [aux_sym_preproc_def_token1] = ACTIONS(5073),
    [aux_sym_preproc_if_token1] = ACTIONS(5073),
    [aux_sym_preproc_if_token2] = ACTIONS(5073),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5073),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5073),
    [aux_sym_preproc_else_token1] = ACTIONS(5073),
    [aux_sym_preproc_elif_token1] = ACTIONS(5073),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5073),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5073),
    [sym_preproc_directive] = ACTIONS(5073),
    [anon_sym_LPAREN2] = ACTIONS(5075),
    [anon_sym_TILDE] = ACTIONS(5075),
    [anon_sym_STAR] = ACTIONS(5075),
    [anon_sym_AMP_AMP] = ACTIONS(5075),
    [anon_sym_AMP] = ACTIONS(5073),
    [anon_sym___extension__] = ACTIONS(5073),
    [anon_sym_typedef] = ACTIONS(5073),
    [anon_sym_in] = ACTIONS(5073),
    [anon_sym_out] = ACTIONS(5073),
    [anon_sym_inout] = ACTIONS(5073),
    [anon_sym_extern] = ACTIONS(5073),
    [anon_sym___attribute__] = ACTIONS(5073),
    [anon_sym_COLON_COLON] = ACTIONS(5075),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5075),
    [anon_sym___declspec] = ACTIONS(5073),
    [anon_sym___based] = ACTIONS(5073),
    [anon_sym_signed] = ACTIONS(5073),
    [anon_sym_unsigned] = ACTIONS(5073),
    [anon_sym_long] = ACTIONS(5073),
    [anon_sym_short] = ACTIONS(5073),
    [anon_sym_LBRACK] = ACTIONS(5073),
    [anon_sym_static] = ACTIONS(5073),
    [anon_sym_register] = ACTIONS(5073),
    [anon_sym_inline] = ACTIONS(5073),
    [anon_sym___inline] = ACTIONS(5073),
    [anon_sym___inline__] = ACTIONS(5073),
    [anon_sym___forceinline] = ACTIONS(5073),
    [anon_sym_thread_local] = ACTIONS(5073),
    [anon_sym___thread] = ACTIONS(5073),
    [anon_sym_const] = ACTIONS(5073),
    [anon_sym_constexpr] = ACTIONS(5073),
    [anon_sym_volatile] = ACTIONS(5073),
    [anon_sym_restrict] = ACTIONS(5073),
    [anon_sym___restrict__] = ACTIONS(5073),
    [anon_sym__Atomic] = ACTIONS(5073),
    [anon_sym__Noreturn] = ACTIONS(5073),
    [anon_sym_noreturn] = ACTIONS(5073),
    [anon_sym_mutable] = ACTIONS(5073),
    [anon_sym_constinit] = ACTIONS(5073),
    [anon_sym_consteval] = ACTIONS(5073),
    [anon_sym_alignas] = ACTIONS(5073),
    [anon_sym__Alignas] = ACTIONS(5073),
    [sym_primitive_type] = ACTIONS(5073),
    [anon_sym_enum] = ACTIONS(5073),
    [anon_sym_class] = ACTIONS(5073),
    [anon_sym_struct] = ACTIONS(5073),
    [anon_sym_union] = ACTIONS(5073),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5073),
    [anon_sym_decltype] = ACTIONS(5073),
    [sym_virtual] = ACTIONS(5073),
    [anon_sym_explicit] = ACTIONS(5073),
    [anon_sym_typename] = ACTIONS(5073),
    [anon_sym_template] = ACTIONS(5073),
    [anon_sym_operator] = ACTIONS(5073),
    [anon_sym_friend] = ACTIONS(5073),
    [anon_sym_public] = ACTIONS(5073),
    [anon_sym_private] = ACTIONS(5073),
    [anon_sym_protected] = ACTIONS(5073),
    [anon_sym_using] = ACTIONS(5073),
    [anon_sym_static_assert] = ACTIONS(5073),
    [anon_sym_precise] = ACTIONS(5073),
    [anon_sym_shared] = ACTIONS(5073),
    [anon_sym_groupshared] = ACTIONS(5073),
    [anon_sym_uniform] = ACTIONS(5073),
    [anon_sym_row_major] = ACTIONS(5073),
    [anon_sym_column_major] = ACTIONS(5073),
    [anon_sym_globallycoherent] = ACTIONS(5073),
    [anon_sym_centroid] = ACTIONS(5073),
    [anon_sym_noperspective] = ACTIONS(5073),
    [anon_sym_nointerpolation] = ACTIONS(5073),
    [anon_sym_sample] = ACTIONS(5073),
    [anon_sym_linear] = ACTIONS(5073),
    [anon_sym_snorm] = ACTIONS(5073),
    [anon_sym_unorm] = ACTIONS(5073),
    [anon_sym_point] = ACTIONS(5073),
    [anon_sym_line] = ACTIONS(5073),
    [anon_sym_triangleadj] = ACTIONS(5073),
    [anon_sym_lineadj] = ACTIONS(5073),
    [anon_sym_triangle] = ACTIONS(5073),
  },
  [1893] = {
    [sym_identifier] = ACTIONS(2204),
    [aux_sym_preproc_def_token1] = ACTIONS(2204),
    [aux_sym_preproc_if_token1] = ACTIONS(2204),
    [aux_sym_preproc_if_token2] = ACTIONS(2204),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2204),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2204),
    [aux_sym_preproc_else_token1] = ACTIONS(2204),
    [aux_sym_preproc_elif_token1] = ACTIONS(2204),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2204),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2204),
    [sym_preproc_directive] = ACTIONS(2204),
    [anon_sym_LPAREN2] = ACTIONS(2206),
    [anon_sym_TILDE] = ACTIONS(2206),
    [anon_sym_STAR] = ACTIONS(2206),
    [anon_sym_AMP_AMP] = ACTIONS(2206),
    [anon_sym_AMP] = ACTIONS(2204),
    [anon_sym___extension__] = ACTIONS(2204),
    [anon_sym_typedef] = ACTIONS(2204),
    [anon_sym_in] = ACTIONS(2204),
    [anon_sym_out] = ACTIONS(2204),
    [anon_sym_inout] = ACTIONS(2204),
    [anon_sym_extern] = ACTIONS(2204),
    [anon_sym___attribute__] = ACTIONS(2204),
    [anon_sym_COLON_COLON] = ACTIONS(2206),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2206),
    [anon_sym___declspec] = ACTIONS(2204),
    [anon_sym___based] = ACTIONS(2204),
    [anon_sym_signed] = ACTIONS(2204),
    [anon_sym_unsigned] = ACTIONS(2204),
    [anon_sym_long] = ACTIONS(2204),
    [anon_sym_short] = ACTIONS(2204),
    [anon_sym_LBRACK] = ACTIONS(2204),
    [anon_sym_static] = ACTIONS(2204),
    [anon_sym_register] = ACTIONS(2204),
    [anon_sym_inline] = ACTIONS(2204),
    [anon_sym___inline] = ACTIONS(2204),
    [anon_sym___inline__] = ACTIONS(2204),
    [anon_sym___forceinline] = ACTIONS(2204),
    [anon_sym_thread_local] = ACTIONS(2204),
    [anon_sym___thread] = ACTIONS(2204),
    [anon_sym_const] = ACTIONS(2204),
    [anon_sym_constexpr] = ACTIONS(2204),
    [anon_sym_volatile] = ACTIONS(2204),
    [anon_sym_restrict] = ACTIONS(2204),
    [anon_sym___restrict__] = ACTIONS(2204),
    [anon_sym__Atomic] = ACTIONS(2204),
    [anon_sym__Noreturn] = ACTIONS(2204),
    [anon_sym_noreturn] = ACTIONS(2204),
    [anon_sym_mutable] = ACTIONS(2204),
    [anon_sym_constinit] = ACTIONS(2204),
    [anon_sym_consteval] = ACTIONS(2204),
    [anon_sym_alignas] = ACTIONS(2204),
    [anon_sym__Alignas] = ACTIONS(2204),
    [sym_primitive_type] = ACTIONS(2204),
    [anon_sym_enum] = ACTIONS(2204),
    [anon_sym_class] = ACTIONS(2204),
    [anon_sym_struct] = ACTIONS(2204),
    [anon_sym_union] = ACTIONS(2204),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2204),
    [anon_sym_decltype] = ACTIONS(2204),
    [sym_virtual] = ACTIONS(2204),
    [anon_sym_explicit] = ACTIONS(2204),
    [anon_sym_typename] = ACTIONS(2204),
    [anon_sym_template] = ACTIONS(2204),
    [anon_sym_operator] = ACTIONS(2204),
    [anon_sym_friend] = ACTIONS(2204),
    [anon_sym_public] = ACTIONS(2204),
    [anon_sym_private] = ACTIONS(2204),
    [anon_sym_protected] = ACTIONS(2204),
    [anon_sym_using] = ACTIONS(2204),
    [anon_sym_static_assert] = ACTIONS(2204),
    [anon_sym_precise] = ACTIONS(2204),
    [anon_sym_shared] = ACTIONS(2204),
    [anon_sym_groupshared] = ACTIONS(2204),
    [anon_sym_uniform] = ACTIONS(2204),
    [anon_sym_row_major] = ACTIONS(2204),
    [anon_sym_column_major] = ACTIONS(2204),
    [anon_sym_globallycoherent] = ACTIONS(2204),
    [anon_sym_centroid] = ACTIONS(2204),
    [anon_sym_noperspective] = ACTIONS(2204),
    [anon_sym_nointerpolation] = ACTIONS(2204),
    [anon_sym_sample] = ACTIONS(2204),
    [anon_sym_linear] = ACTIONS(2204),
    [anon_sym_snorm] = ACTIONS(2204),
    [anon_sym_unorm] = ACTIONS(2204),
    [anon_sym_point] = ACTIONS(2204),
    [anon_sym_line] = ACTIONS(2204),
    [anon_sym_triangleadj] = ACTIONS(2204),
    [anon_sym_lineadj] = ACTIONS(2204),
    [anon_sym_triangle] = ACTIONS(2204),
  },
  [1894] = {
    [sym_identifier] = ACTIONS(2462),
    [aux_sym_preproc_def_token1] = ACTIONS(2462),
    [aux_sym_preproc_if_token1] = ACTIONS(2462),
    [aux_sym_preproc_if_token2] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2462),
    [aux_sym_preproc_else_token1] = ACTIONS(2462),
    [aux_sym_preproc_elif_token1] = ACTIONS(2462),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2462),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2462),
    [sym_preproc_directive] = ACTIONS(2462),
    [anon_sym_LPAREN2] = ACTIONS(2464),
    [anon_sym_TILDE] = ACTIONS(2464),
    [anon_sym_STAR] = ACTIONS(2464),
    [anon_sym_AMP_AMP] = ACTIONS(2464),
    [anon_sym_AMP] = ACTIONS(2462),
    [anon_sym___extension__] = ACTIONS(2462),
    [anon_sym_typedef] = ACTIONS(2462),
    [anon_sym_in] = ACTIONS(2462),
    [anon_sym_out] = ACTIONS(2462),
    [anon_sym_inout] = ACTIONS(2462),
    [anon_sym_extern] = ACTIONS(2462),
    [anon_sym___attribute__] = ACTIONS(2462),
    [anon_sym_COLON_COLON] = ACTIONS(2464),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2464),
    [anon_sym___declspec] = ACTIONS(2462),
    [anon_sym___based] = ACTIONS(2462),
    [anon_sym_signed] = ACTIONS(2462),
    [anon_sym_unsigned] = ACTIONS(2462),
    [anon_sym_long] = ACTIONS(2462),
    [anon_sym_short] = ACTIONS(2462),
    [anon_sym_LBRACK] = ACTIONS(2462),
    [anon_sym_static] = ACTIONS(2462),
    [anon_sym_register] = ACTIONS(2462),
    [anon_sym_inline] = ACTIONS(2462),
    [anon_sym___inline] = ACTIONS(2462),
    [anon_sym___inline__] = ACTIONS(2462),
    [anon_sym___forceinline] = ACTIONS(2462),
    [anon_sym_thread_local] = ACTIONS(2462),
    [anon_sym___thread] = ACTIONS(2462),
    [anon_sym_const] = ACTIONS(2462),
    [anon_sym_constexpr] = ACTIONS(2462),
    [anon_sym_volatile] = ACTIONS(2462),
    [anon_sym_restrict] = ACTIONS(2462),
    [anon_sym___restrict__] = ACTIONS(2462),
    [anon_sym__Atomic] = ACTIONS(2462),
    [anon_sym__Noreturn] = ACTIONS(2462),
    [anon_sym_noreturn] = ACTIONS(2462),
    [anon_sym_mutable] = ACTIONS(2462),
    [anon_sym_constinit] = ACTIONS(2462),
    [anon_sym_consteval] = ACTIONS(2462),
    [anon_sym_alignas] = ACTIONS(2462),
    [anon_sym__Alignas] = ACTIONS(2462),
    [sym_primitive_type] = ACTIONS(2462),
    [anon_sym_enum] = ACTIONS(2462),
    [anon_sym_class] = ACTIONS(2462),
    [anon_sym_struct] = ACTIONS(2462),
    [anon_sym_union] = ACTIONS(2462),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2462),
    [anon_sym_decltype] = ACTIONS(2462),
    [sym_virtual] = ACTIONS(2462),
    [anon_sym_explicit] = ACTIONS(2462),
    [anon_sym_typename] = ACTIONS(2462),
    [anon_sym_template] = ACTIONS(2462),
    [anon_sym_operator] = ACTIONS(2462),
    [anon_sym_friend] = ACTIONS(2462),
    [anon_sym_public] = ACTIONS(2462),
    [anon_sym_private] = ACTIONS(2462),
    [anon_sym_protected] = ACTIONS(2462),
    [anon_sym_using] = ACTIONS(2462),
    [anon_sym_static_assert] = ACTIONS(2462),
    [anon_sym_precise] = ACTIONS(2462),
    [anon_sym_shared] = ACTIONS(2462),
    [anon_sym_groupshared] = ACTIONS(2462),
    [anon_sym_uniform] = ACTIONS(2462),
    [anon_sym_row_major] = ACTIONS(2462),
    [anon_sym_column_major] = ACTIONS(2462),
    [anon_sym_globallycoherent] = ACTIONS(2462),
    [anon_sym_centroid] = ACTIONS(2462),
    [anon_sym_noperspective] = ACTIONS(2462),
    [anon_sym_nointerpolation] = ACTIONS(2462),
    [anon_sym_sample] = ACTIONS(2462),
    [anon_sym_linear] = ACTIONS(2462),
    [anon_sym_snorm] = ACTIONS(2462),
    [anon_sym_unorm] = ACTIONS(2462),
    [anon_sym_point] = ACTIONS(2462),
    [anon_sym_line] = ACTIONS(2462),
    [anon_sym_triangleadj] = ACTIONS(2462),
    [anon_sym_lineadj] = ACTIONS(2462),
    [anon_sym_triangle] = ACTIONS(2462),
  },
  [1895] = {
    [sym_identifier] = ACTIONS(5077),
    [aux_sym_preproc_def_token1] = ACTIONS(5077),
    [aux_sym_preproc_if_token1] = ACTIONS(5077),
    [aux_sym_preproc_if_token2] = ACTIONS(5077),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5077),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5077),
    [aux_sym_preproc_else_token1] = ACTIONS(5077),
    [aux_sym_preproc_elif_token1] = ACTIONS(5077),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5077),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5077),
    [sym_preproc_directive] = ACTIONS(5077),
    [anon_sym_LPAREN2] = ACTIONS(5079),
    [anon_sym_TILDE] = ACTIONS(5079),
    [anon_sym_STAR] = ACTIONS(5079),
    [anon_sym_AMP_AMP] = ACTIONS(5079),
    [anon_sym_AMP] = ACTIONS(5077),
    [anon_sym___extension__] = ACTIONS(5077),
    [anon_sym_typedef] = ACTIONS(5077),
    [anon_sym_in] = ACTIONS(5077),
    [anon_sym_out] = ACTIONS(5077),
    [anon_sym_inout] = ACTIONS(5077),
    [anon_sym_extern] = ACTIONS(5077),
    [anon_sym___attribute__] = ACTIONS(5077),
    [anon_sym_COLON_COLON] = ACTIONS(5079),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5079),
    [anon_sym___declspec] = ACTIONS(5077),
    [anon_sym___based] = ACTIONS(5077),
    [anon_sym_signed] = ACTIONS(5077),
    [anon_sym_unsigned] = ACTIONS(5077),
    [anon_sym_long] = ACTIONS(5077),
    [anon_sym_short] = ACTIONS(5077),
    [anon_sym_LBRACK] = ACTIONS(5077),
    [anon_sym_static] = ACTIONS(5077),
    [anon_sym_register] = ACTIONS(5077),
    [anon_sym_inline] = ACTIONS(5077),
    [anon_sym___inline] = ACTIONS(5077),
    [anon_sym___inline__] = ACTIONS(5077),
    [anon_sym___forceinline] = ACTIONS(5077),
    [anon_sym_thread_local] = ACTIONS(5077),
    [anon_sym___thread] = ACTIONS(5077),
    [anon_sym_const] = ACTIONS(5077),
    [anon_sym_constexpr] = ACTIONS(5077),
    [anon_sym_volatile] = ACTIONS(5077),
    [anon_sym_restrict] = ACTIONS(5077),
    [anon_sym___restrict__] = ACTIONS(5077),
    [anon_sym__Atomic] = ACTIONS(5077),
    [anon_sym__Noreturn] = ACTIONS(5077),
    [anon_sym_noreturn] = ACTIONS(5077),
    [anon_sym_mutable] = ACTIONS(5077),
    [anon_sym_constinit] = ACTIONS(5077),
    [anon_sym_consteval] = ACTIONS(5077),
    [anon_sym_alignas] = ACTIONS(5077),
    [anon_sym__Alignas] = ACTIONS(5077),
    [sym_primitive_type] = ACTIONS(5077),
    [anon_sym_enum] = ACTIONS(5077),
    [anon_sym_class] = ACTIONS(5077),
    [anon_sym_struct] = ACTIONS(5077),
    [anon_sym_union] = ACTIONS(5077),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5077),
    [anon_sym_decltype] = ACTIONS(5077),
    [sym_virtual] = ACTIONS(5077),
    [anon_sym_explicit] = ACTIONS(5077),
    [anon_sym_typename] = ACTIONS(5077),
    [anon_sym_template] = ACTIONS(5077),
    [anon_sym_operator] = ACTIONS(5077),
    [anon_sym_friend] = ACTIONS(5077),
    [anon_sym_public] = ACTIONS(5077),
    [anon_sym_private] = ACTIONS(5077),
    [anon_sym_protected] = ACTIONS(5077),
    [anon_sym_using] = ACTIONS(5077),
    [anon_sym_static_assert] = ACTIONS(5077),
    [anon_sym_precise] = ACTIONS(5077),
    [anon_sym_shared] = ACTIONS(5077),
    [anon_sym_groupshared] = ACTIONS(5077),
    [anon_sym_uniform] = ACTIONS(5077),
    [anon_sym_row_major] = ACTIONS(5077),
    [anon_sym_column_major] = ACTIONS(5077),
    [anon_sym_globallycoherent] = ACTIONS(5077),
    [anon_sym_centroid] = ACTIONS(5077),
    [anon_sym_noperspective] = ACTIONS(5077),
    [anon_sym_nointerpolation] = ACTIONS(5077),
    [anon_sym_sample] = ACTIONS(5077),
    [anon_sym_linear] = ACTIONS(5077),
    [anon_sym_snorm] = ACTIONS(5077),
    [anon_sym_unorm] = ACTIONS(5077),
    [anon_sym_point] = ACTIONS(5077),
    [anon_sym_line] = ACTIONS(5077),
    [anon_sym_triangleadj] = ACTIONS(5077),
    [anon_sym_lineadj] = ACTIONS(5077),
    [anon_sym_triangle] = ACTIONS(5077),
  },
  [1896] = {
    [sym_identifier] = ACTIONS(2490),
    [aux_sym_preproc_def_token1] = ACTIONS(2490),
    [aux_sym_preproc_if_token1] = ACTIONS(2490),
    [aux_sym_preproc_if_token2] = ACTIONS(2490),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2490),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2490),
    [aux_sym_preproc_else_token1] = ACTIONS(2490),
    [aux_sym_preproc_elif_token1] = ACTIONS(2490),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2490),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2490),
    [sym_preproc_directive] = ACTIONS(2490),
    [anon_sym_LPAREN2] = ACTIONS(2492),
    [anon_sym_TILDE] = ACTIONS(2492),
    [anon_sym_STAR] = ACTIONS(2492),
    [anon_sym_AMP_AMP] = ACTIONS(2492),
    [anon_sym_AMP] = ACTIONS(2490),
    [anon_sym___extension__] = ACTIONS(2490),
    [anon_sym_typedef] = ACTIONS(2490),
    [anon_sym_in] = ACTIONS(2490),
    [anon_sym_out] = ACTIONS(2490),
    [anon_sym_inout] = ACTIONS(2490),
    [anon_sym_extern] = ACTIONS(2490),
    [anon_sym___attribute__] = ACTIONS(2490),
    [anon_sym_COLON_COLON] = ACTIONS(2492),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2492),
    [anon_sym___declspec] = ACTIONS(2490),
    [anon_sym___based] = ACTIONS(2490),
    [anon_sym_signed] = ACTIONS(2490),
    [anon_sym_unsigned] = ACTIONS(2490),
    [anon_sym_long] = ACTIONS(2490),
    [anon_sym_short] = ACTIONS(2490),
    [anon_sym_LBRACK] = ACTIONS(2490),
    [anon_sym_static] = ACTIONS(2490),
    [anon_sym_register] = ACTIONS(2490),
    [anon_sym_inline] = ACTIONS(2490),
    [anon_sym___inline] = ACTIONS(2490),
    [anon_sym___inline__] = ACTIONS(2490),
    [anon_sym___forceinline] = ACTIONS(2490),
    [anon_sym_thread_local] = ACTIONS(2490),
    [anon_sym___thread] = ACTIONS(2490),
    [anon_sym_const] = ACTIONS(2490),
    [anon_sym_constexpr] = ACTIONS(2490),
    [anon_sym_volatile] = ACTIONS(2490),
    [anon_sym_restrict] = ACTIONS(2490),
    [anon_sym___restrict__] = ACTIONS(2490),
    [anon_sym__Atomic] = ACTIONS(2490),
    [anon_sym__Noreturn] = ACTIONS(2490),
    [anon_sym_noreturn] = ACTIONS(2490),
    [anon_sym_mutable] = ACTIONS(2490),
    [anon_sym_constinit] = ACTIONS(2490),
    [anon_sym_consteval] = ACTIONS(2490),
    [anon_sym_alignas] = ACTIONS(2490),
    [anon_sym__Alignas] = ACTIONS(2490),
    [sym_primitive_type] = ACTIONS(2490),
    [anon_sym_enum] = ACTIONS(2490),
    [anon_sym_class] = ACTIONS(2490),
    [anon_sym_struct] = ACTIONS(2490),
    [anon_sym_union] = ACTIONS(2490),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2490),
    [anon_sym_decltype] = ACTIONS(2490),
    [sym_virtual] = ACTIONS(2490),
    [anon_sym_explicit] = ACTIONS(2490),
    [anon_sym_typename] = ACTIONS(2490),
    [anon_sym_template] = ACTIONS(2490),
    [anon_sym_operator] = ACTIONS(2490),
    [anon_sym_friend] = ACTIONS(2490),
    [anon_sym_public] = ACTIONS(2490),
    [anon_sym_private] = ACTIONS(2490),
    [anon_sym_protected] = ACTIONS(2490),
    [anon_sym_using] = ACTIONS(2490),
    [anon_sym_static_assert] = ACTIONS(2490),
    [anon_sym_precise] = ACTIONS(2490),
    [anon_sym_shared] = ACTIONS(2490),
    [anon_sym_groupshared] = ACTIONS(2490),
    [anon_sym_uniform] = ACTIONS(2490),
    [anon_sym_row_major] = ACTIONS(2490),
    [anon_sym_column_major] = ACTIONS(2490),
    [anon_sym_globallycoherent] = ACTIONS(2490),
    [anon_sym_centroid] = ACTIONS(2490),
    [anon_sym_noperspective] = ACTIONS(2490),
    [anon_sym_nointerpolation] = ACTIONS(2490),
    [anon_sym_sample] = ACTIONS(2490),
    [anon_sym_linear] = ACTIONS(2490),
    [anon_sym_snorm] = ACTIONS(2490),
    [anon_sym_unorm] = ACTIONS(2490),
    [anon_sym_point] = ACTIONS(2490),
    [anon_sym_line] = ACTIONS(2490),
    [anon_sym_triangleadj] = ACTIONS(2490),
    [anon_sym_lineadj] = ACTIONS(2490),
    [anon_sym_triangle] = ACTIONS(2490),
  },
  [1897] = {
    [sym_identifier] = ACTIONS(2462),
    [aux_sym_preproc_def_token1] = ACTIONS(2462),
    [aux_sym_preproc_if_token1] = ACTIONS(2462),
    [aux_sym_preproc_if_token2] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2462),
    [aux_sym_preproc_else_token1] = ACTIONS(2462),
    [aux_sym_preproc_elif_token1] = ACTIONS(2462),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2462),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2462),
    [sym_preproc_directive] = ACTIONS(2462),
    [anon_sym_LPAREN2] = ACTIONS(2464),
    [anon_sym_TILDE] = ACTIONS(2464),
    [anon_sym_STAR] = ACTIONS(2464),
    [anon_sym_AMP_AMP] = ACTIONS(2464),
    [anon_sym_AMP] = ACTIONS(2462),
    [anon_sym___extension__] = ACTIONS(2462),
    [anon_sym_typedef] = ACTIONS(2462),
    [anon_sym_in] = ACTIONS(2462),
    [anon_sym_out] = ACTIONS(2462),
    [anon_sym_inout] = ACTIONS(2462),
    [anon_sym_extern] = ACTIONS(2462),
    [anon_sym___attribute__] = ACTIONS(2462),
    [anon_sym_COLON_COLON] = ACTIONS(2464),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2464),
    [anon_sym___declspec] = ACTIONS(2462),
    [anon_sym___based] = ACTIONS(2462),
    [anon_sym_signed] = ACTIONS(2462),
    [anon_sym_unsigned] = ACTIONS(2462),
    [anon_sym_long] = ACTIONS(2462),
    [anon_sym_short] = ACTIONS(2462),
    [anon_sym_LBRACK] = ACTIONS(2462),
    [anon_sym_static] = ACTIONS(2462),
    [anon_sym_register] = ACTIONS(2462),
    [anon_sym_inline] = ACTIONS(2462),
    [anon_sym___inline] = ACTIONS(2462),
    [anon_sym___inline__] = ACTIONS(2462),
    [anon_sym___forceinline] = ACTIONS(2462),
    [anon_sym_thread_local] = ACTIONS(2462),
    [anon_sym___thread] = ACTIONS(2462),
    [anon_sym_const] = ACTIONS(2462),
    [anon_sym_constexpr] = ACTIONS(2462),
    [anon_sym_volatile] = ACTIONS(2462),
    [anon_sym_restrict] = ACTIONS(2462),
    [anon_sym___restrict__] = ACTIONS(2462),
    [anon_sym__Atomic] = ACTIONS(2462),
    [anon_sym__Noreturn] = ACTIONS(2462),
    [anon_sym_noreturn] = ACTIONS(2462),
    [anon_sym_mutable] = ACTIONS(2462),
    [anon_sym_constinit] = ACTIONS(2462),
    [anon_sym_consteval] = ACTIONS(2462),
    [anon_sym_alignas] = ACTIONS(2462),
    [anon_sym__Alignas] = ACTIONS(2462),
    [sym_primitive_type] = ACTIONS(2462),
    [anon_sym_enum] = ACTIONS(2462),
    [anon_sym_class] = ACTIONS(2462),
    [anon_sym_struct] = ACTIONS(2462),
    [anon_sym_union] = ACTIONS(2462),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2462),
    [anon_sym_decltype] = ACTIONS(2462),
    [sym_virtual] = ACTIONS(2462),
    [anon_sym_explicit] = ACTIONS(2462),
    [anon_sym_typename] = ACTIONS(2462),
    [anon_sym_template] = ACTIONS(2462),
    [anon_sym_operator] = ACTIONS(2462),
    [anon_sym_friend] = ACTIONS(2462),
    [anon_sym_public] = ACTIONS(2462),
    [anon_sym_private] = ACTIONS(2462),
    [anon_sym_protected] = ACTIONS(2462),
    [anon_sym_using] = ACTIONS(2462),
    [anon_sym_static_assert] = ACTIONS(2462),
    [anon_sym_precise] = ACTIONS(2462),
    [anon_sym_shared] = ACTIONS(2462),
    [anon_sym_groupshared] = ACTIONS(2462),
    [anon_sym_uniform] = ACTIONS(2462),
    [anon_sym_row_major] = ACTIONS(2462),
    [anon_sym_column_major] = ACTIONS(2462),
    [anon_sym_globallycoherent] = ACTIONS(2462),
    [anon_sym_centroid] = ACTIONS(2462),
    [anon_sym_noperspective] = ACTIONS(2462),
    [anon_sym_nointerpolation] = ACTIONS(2462),
    [anon_sym_sample] = ACTIONS(2462),
    [anon_sym_linear] = ACTIONS(2462),
    [anon_sym_snorm] = ACTIONS(2462),
    [anon_sym_unorm] = ACTIONS(2462),
    [anon_sym_point] = ACTIONS(2462),
    [anon_sym_line] = ACTIONS(2462),
    [anon_sym_triangleadj] = ACTIONS(2462),
    [anon_sym_lineadj] = ACTIONS(2462),
    [anon_sym_triangle] = ACTIONS(2462),
  },
  [1898] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token2] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [aux_sym_preproc_else_token1] = ACTIONS(2324),
    [aux_sym_preproc_elif_token1] = ACTIONS(2324),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_friend] = ACTIONS(2324),
    [anon_sym_public] = ACTIONS(2324),
    [anon_sym_private] = ACTIONS(2324),
    [anon_sym_protected] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
  },
  [1899] = {
    [sym_identifier] = ACTIONS(2502),
    [aux_sym_preproc_def_token1] = ACTIONS(2502),
    [aux_sym_preproc_if_token1] = ACTIONS(2502),
    [aux_sym_preproc_if_token2] = ACTIONS(2502),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2502),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2502),
    [aux_sym_preproc_else_token1] = ACTIONS(2502),
    [aux_sym_preproc_elif_token1] = ACTIONS(2502),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2502),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2502),
    [sym_preproc_directive] = ACTIONS(2502),
    [anon_sym_LPAREN2] = ACTIONS(2504),
    [anon_sym_TILDE] = ACTIONS(2504),
    [anon_sym_STAR] = ACTIONS(2504),
    [anon_sym_AMP_AMP] = ACTIONS(2504),
    [anon_sym_AMP] = ACTIONS(2502),
    [anon_sym___extension__] = ACTIONS(2502),
    [anon_sym_typedef] = ACTIONS(2502),
    [anon_sym_in] = ACTIONS(2502),
    [anon_sym_out] = ACTIONS(2502),
    [anon_sym_inout] = ACTIONS(2502),
    [anon_sym_extern] = ACTIONS(2502),
    [anon_sym___attribute__] = ACTIONS(2502),
    [anon_sym_COLON_COLON] = ACTIONS(2504),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2504),
    [anon_sym___declspec] = ACTIONS(2502),
    [anon_sym___based] = ACTIONS(2502),
    [anon_sym_signed] = ACTIONS(2502),
    [anon_sym_unsigned] = ACTIONS(2502),
    [anon_sym_long] = ACTIONS(2502),
    [anon_sym_short] = ACTIONS(2502),
    [anon_sym_LBRACK] = ACTIONS(2502),
    [anon_sym_static] = ACTIONS(2502),
    [anon_sym_register] = ACTIONS(2502),
    [anon_sym_inline] = ACTIONS(2502),
    [anon_sym___inline] = ACTIONS(2502),
    [anon_sym___inline__] = ACTIONS(2502),
    [anon_sym___forceinline] = ACTIONS(2502),
    [anon_sym_thread_local] = ACTIONS(2502),
    [anon_sym___thread] = ACTIONS(2502),
    [anon_sym_const] = ACTIONS(2502),
    [anon_sym_constexpr] = ACTIONS(2502),
    [anon_sym_volatile] = ACTIONS(2502),
    [anon_sym_restrict] = ACTIONS(2502),
    [anon_sym___restrict__] = ACTIONS(2502),
    [anon_sym__Atomic] = ACTIONS(2502),
    [anon_sym__Noreturn] = ACTIONS(2502),
    [anon_sym_noreturn] = ACTIONS(2502),
    [anon_sym_mutable] = ACTIONS(2502),
    [anon_sym_constinit] = ACTIONS(2502),
    [anon_sym_consteval] = ACTIONS(2502),
    [anon_sym_alignas] = ACTIONS(2502),
    [anon_sym__Alignas] = ACTIONS(2502),
    [sym_primitive_type] = ACTIONS(2502),
    [anon_sym_enum] = ACTIONS(2502),
    [anon_sym_class] = ACTIONS(2502),
    [anon_sym_struct] = ACTIONS(2502),
    [anon_sym_union] = ACTIONS(2502),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2502),
    [anon_sym_decltype] = ACTIONS(2502),
    [sym_virtual] = ACTIONS(2502),
    [anon_sym_explicit] = ACTIONS(2502),
    [anon_sym_typename] = ACTIONS(2502),
    [anon_sym_template] = ACTIONS(2502),
    [anon_sym_operator] = ACTIONS(2502),
    [anon_sym_friend] = ACTIONS(2502),
    [anon_sym_public] = ACTIONS(2502),
    [anon_sym_private] = ACTIONS(2502),
    [anon_sym_protected] = ACTIONS(2502),
    [anon_sym_using] = ACTIONS(2502),
    [anon_sym_static_assert] = ACTIONS(2502),
    [anon_sym_precise] = ACTIONS(2502),
    [anon_sym_shared] = ACTIONS(2502),
    [anon_sym_groupshared] = ACTIONS(2502),
    [anon_sym_uniform] = ACTIONS(2502),
    [anon_sym_row_major] = ACTIONS(2502),
    [anon_sym_column_major] = ACTIONS(2502),
    [anon_sym_globallycoherent] = ACTIONS(2502),
    [anon_sym_centroid] = ACTIONS(2502),
    [anon_sym_noperspective] = ACTIONS(2502),
    [anon_sym_nointerpolation] = ACTIONS(2502),
    [anon_sym_sample] = ACTIONS(2502),
    [anon_sym_linear] = ACTIONS(2502),
    [anon_sym_snorm] = ACTIONS(2502),
    [anon_sym_unorm] = ACTIONS(2502),
    [anon_sym_point] = ACTIONS(2502),
    [anon_sym_line] = ACTIONS(2502),
    [anon_sym_triangleadj] = ACTIONS(2502),
    [anon_sym_lineadj] = ACTIONS(2502),
    [anon_sym_triangle] = ACTIONS(2502),
  },
  [1900] = {
    [sym_identifier] = ACTIONS(2498),
    [aux_sym_preproc_def_token1] = ACTIONS(2498),
    [aux_sym_preproc_if_token1] = ACTIONS(2498),
    [aux_sym_preproc_if_token2] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2498),
    [aux_sym_preproc_else_token1] = ACTIONS(2498),
    [aux_sym_preproc_elif_token1] = ACTIONS(2498),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2498),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2498),
    [sym_preproc_directive] = ACTIONS(2498),
    [anon_sym_LPAREN2] = ACTIONS(2500),
    [anon_sym_TILDE] = ACTIONS(2500),
    [anon_sym_STAR] = ACTIONS(2500),
    [anon_sym_AMP_AMP] = ACTIONS(2500),
    [anon_sym_AMP] = ACTIONS(2498),
    [anon_sym___extension__] = ACTIONS(2498),
    [anon_sym_typedef] = ACTIONS(2498),
    [anon_sym_in] = ACTIONS(2498),
    [anon_sym_out] = ACTIONS(2498),
    [anon_sym_inout] = ACTIONS(2498),
    [anon_sym_extern] = ACTIONS(2498),
    [anon_sym___attribute__] = ACTIONS(2498),
    [anon_sym_COLON_COLON] = ACTIONS(2500),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2500),
    [anon_sym___declspec] = ACTIONS(2498),
    [anon_sym___based] = ACTIONS(2498),
    [anon_sym_signed] = ACTIONS(2498),
    [anon_sym_unsigned] = ACTIONS(2498),
    [anon_sym_long] = ACTIONS(2498),
    [anon_sym_short] = ACTIONS(2498),
    [anon_sym_LBRACK] = ACTIONS(2498),
    [anon_sym_static] = ACTIONS(2498),
    [anon_sym_register] = ACTIONS(2498),
    [anon_sym_inline] = ACTIONS(2498),
    [anon_sym___inline] = ACTIONS(2498),
    [anon_sym___inline__] = ACTIONS(2498),
    [anon_sym___forceinline] = ACTIONS(2498),
    [anon_sym_thread_local] = ACTIONS(2498),
    [anon_sym___thread] = ACTIONS(2498),
    [anon_sym_const] = ACTIONS(2498),
    [anon_sym_constexpr] = ACTIONS(2498),
    [anon_sym_volatile] = ACTIONS(2498),
    [anon_sym_restrict] = ACTIONS(2498),
    [anon_sym___restrict__] = ACTIONS(2498),
    [anon_sym__Atomic] = ACTIONS(2498),
    [anon_sym__Noreturn] = ACTIONS(2498),
    [anon_sym_noreturn] = ACTIONS(2498),
    [anon_sym_mutable] = ACTIONS(2498),
    [anon_sym_constinit] = ACTIONS(2498),
    [anon_sym_consteval] = ACTIONS(2498),
    [anon_sym_alignas] = ACTIONS(2498),
    [anon_sym__Alignas] = ACTIONS(2498),
    [sym_primitive_type] = ACTIONS(2498),
    [anon_sym_enum] = ACTIONS(2498),
    [anon_sym_class] = ACTIONS(2498),
    [anon_sym_struct] = ACTIONS(2498),
    [anon_sym_union] = ACTIONS(2498),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2498),
    [anon_sym_decltype] = ACTIONS(2498),
    [sym_virtual] = ACTIONS(2498),
    [anon_sym_explicit] = ACTIONS(2498),
    [anon_sym_typename] = ACTIONS(2498),
    [anon_sym_template] = ACTIONS(2498),
    [anon_sym_operator] = ACTIONS(2498),
    [anon_sym_friend] = ACTIONS(2498),
    [anon_sym_public] = ACTIONS(2498),
    [anon_sym_private] = ACTIONS(2498),
    [anon_sym_protected] = ACTIONS(2498),
    [anon_sym_using] = ACTIONS(2498),
    [anon_sym_static_assert] = ACTIONS(2498),
    [anon_sym_precise] = ACTIONS(2498),
    [anon_sym_shared] = ACTIONS(2498),
    [anon_sym_groupshared] = ACTIONS(2498),
    [anon_sym_uniform] = ACTIONS(2498),
    [anon_sym_row_major] = ACTIONS(2498),
    [anon_sym_column_major] = ACTIONS(2498),
    [anon_sym_globallycoherent] = ACTIONS(2498),
    [anon_sym_centroid] = ACTIONS(2498),
    [anon_sym_noperspective] = ACTIONS(2498),
    [anon_sym_nointerpolation] = ACTIONS(2498),
    [anon_sym_sample] = ACTIONS(2498),
    [anon_sym_linear] = ACTIONS(2498),
    [anon_sym_snorm] = ACTIONS(2498),
    [anon_sym_unorm] = ACTIONS(2498),
    [anon_sym_point] = ACTIONS(2498),
    [anon_sym_line] = ACTIONS(2498),
    [anon_sym_triangleadj] = ACTIONS(2498),
    [anon_sym_lineadj] = ACTIONS(2498),
    [anon_sym_triangle] = ACTIONS(2498),
  },
  [1901] = {
    [sym_identifier] = ACTIONS(5081),
    [aux_sym_preproc_def_token1] = ACTIONS(5081),
    [aux_sym_preproc_if_token1] = ACTIONS(5081),
    [aux_sym_preproc_if_token2] = ACTIONS(5081),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5081),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5081),
    [aux_sym_preproc_else_token1] = ACTIONS(5081),
    [aux_sym_preproc_elif_token1] = ACTIONS(5081),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5081),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5081),
    [sym_preproc_directive] = ACTIONS(5081),
    [anon_sym_LPAREN2] = ACTIONS(5083),
    [anon_sym_TILDE] = ACTIONS(5083),
    [anon_sym_STAR] = ACTIONS(5083),
    [anon_sym_AMP_AMP] = ACTIONS(5083),
    [anon_sym_AMP] = ACTIONS(5081),
    [anon_sym___extension__] = ACTIONS(5081),
    [anon_sym_typedef] = ACTIONS(5081),
    [anon_sym_in] = ACTIONS(5081),
    [anon_sym_out] = ACTIONS(5081),
    [anon_sym_inout] = ACTIONS(5081),
    [anon_sym_extern] = ACTIONS(5081),
    [anon_sym___attribute__] = ACTIONS(5081),
    [anon_sym_COLON_COLON] = ACTIONS(5083),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5083),
    [anon_sym___declspec] = ACTIONS(5081),
    [anon_sym___based] = ACTIONS(5081),
    [anon_sym_signed] = ACTIONS(5081),
    [anon_sym_unsigned] = ACTIONS(5081),
    [anon_sym_long] = ACTIONS(5081),
    [anon_sym_short] = ACTIONS(5081),
    [anon_sym_LBRACK] = ACTIONS(5081),
    [anon_sym_static] = ACTIONS(5081),
    [anon_sym_register] = ACTIONS(5081),
    [anon_sym_inline] = ACTIONS(5081),
    [anon_sym___inline] = ACTIONS(5081),
    [anon_sym___inline__] = ACTIONS(5081),
    [anon_sym___forceinline] = ACTIONS(5081),
    [anon_sym_thread_local] = ACTIONS(5081),
    [anon_sym___thread] = ACTIONS(5081),
    [anon_sym_const] = ACTIONS(5081),
    [anon_sym_constexpr] = ACTIONS(5081),
    [anon_sym_volatile] = ACTIONS(5081),
    [anon_sym_restrict] = ACTIONS(5081),
    [anon_sym___restrict__] = ACTIONS(5081),
    [anon_sym__Atomic] = ACTIONS(5081),
    [anon_sym__Noreturn] = ACTIONS(5081),
    [anon_sym_noreturn] = ACTIONS(5081),
    [anon_sym_mutable] = ACTIONS(5081),
    [anon_sym_constinit] = ACTIONS(5081),
    [anon_sym_consteval] = ACTIONS(5081),
    [anon_sym_alignas] = ACTIONS(5081),
    [anon_sym__Alignas] = ACTIONS(5081),
    [sym_primitive_type] = ACTIONS(5081),
    [anon_sym_enum] = ACTIONS(5081),
    [anon_sym_class] = ACTIONS(5081),
    [anon_sym_struct] = ACTIONS(5081),
    [anon_sym_union] = ACTIONS(5081),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5081),
    [anon_sym_decltype] = ACTIONS(5081),
    [sym_virtual] = ACTIONS(5081),
    [anon_sym_explicit] = ACTIONS(5081),
    [anon_sym_typename] = ACTIONS(5081),
    [anon_sym_template] = ACTIONS(5081),
    [anon_sym_operator] = ACTIONS(5081),
    [anon_sym_friend] = ACTIONS(5081),
    [anon_sym_public] = ACTIONS(5081),
    [anon_sym_private] = ACTIONS(5081),
    [anon_sym_protected] = ACTIONS(5081),
    [anon_sym_using] = ACTIONS(5081),
    [anon_sym_static_assert] = ACTIONS(5081),
    [anon_sym_precise] = ACTIONS(5081),
    [anon_sym_shared] = ACTIONS(5081),
    [anon_sym_groupshared] = ACTIONS(5081),
    [anon_sym_uniform] = ACTIONS(5081),
    [anon_sym_row_major] = ACTIONS(5081),
    [anon_sym_column_major] = ACTIONS(5081),
    [anon_sym_globallycoherent] = ACTIONS(5081),
    [anon_sym_centroid] = ACTIONS(5081),
    [anon_sym_noperspective] = ACTIONS(5081),
    [anon_sym_nointerpolation] = ACTIONS(5081),
    [anon_sym_sample] = ACTIONS(5081),
    [anon_sym_linear] = ACTIONS(5081),
    [anon_sym_snorm] = ACTIONS(5081),
    [anon_sym_unorm] = ACTIONS(5081),
    [anon_sym_point] = ACTIONS(5081),
    [anon_sym_line] = ACTIONS(5081),
    [anon_sym_triangleadj] = ACTIONS(5081),
    [anon_sym_lineadj] = ACTIONS(5081),
    [anon_sym_triangle] = ACTIONS(5081),
  },
  [1902] = {
    [sym_identifier] = ACTIONS(2118),
    [aux_sym_preproc_def_token1] = ACTIONS(2118),
    [aux_sym_preproc_if_token1] = ACTIONS(2118),
    [aux_sym_preproc_if_token2] = ACTIONS(2118),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2118),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2118),
    [aux_sym_preproc_else_token1] = ACTIONS(2118),
    [aux_sym_preproc_elif_token1] = ACTIONS(2118),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2118),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2118),
    [sym_preproc_directive] = ACTIONS(2118),
    [anon_sym_LPAREN2] = ACTIONS(2120),
    [anon_sym_TILDE] = ACTIONS(2120),
    [anon_sym_STAR] = ACTIONS(2120),
    [anon_sym_AMP_AMP] = ACTIONS(2120),
    [anon_sym_AMP] = ACTIONS(2118),
    [anon_sym___extension__] = ACTIONS(2118),
    [anon_sym_typedef] = ACTIONS(2118),
    [anon_sym_in] = ACTIONS(2118),
    [anon_sym_out] = ACTIONS(2118),
    [anon_sym_inout] = ACTIONS(2118),
    [anon_sym_extern] = ACTIONS(2118),
    [anon_sym___attribute__] = ACTIONS(2118),
    [anon_sym_COLON_COLON] = ACTIONS(2120),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2120),
    [anon_sym___declspec] = ACTIONS(2118),
    [anon_sym___based] = ACTIONS(2118),
    [anon_sym_signed] = ACTIONS(2118),
    [anon_sym_unsigned] = ACTIONS(2118),
    [anon_sym_long] = ACTIONS(2118),
    [anon_sym_short] = ACTIONS(2118),
    [anon_sym_LBRACK] = ACTIONS(2118),
    [anon_sym_static] = ACTIONS(2118),
    [anon_sym_register] = ACTIONS(2118),
    [anon_sym_inline] = ACTIONS(2118),
    [anon_sym___inline] = ACTIONS(2118),
    [anon_sym___inline__] = ACTIONS(2118),
    [anon_sym___forceinline] = ACTIONS(2118),
    [anon_sym_thread_local] = ACTIONS(2118),
    [anon_sym___thread] = ACTIONS(2118),
    [anon_sym_const] = ACTIONS(2118),
    [anon_sym_constexpr] = ACTIONS(2118),
    [anon_sym_volatile] = ACTIONS(2118),
    [anon_sym_restrict] = ACTIONS(2118),
    [anon_sym___restrict__] = ACTIONS(2118),
    [anon_sym__Atomic] = ACTIONS(2118),
    [anon_sym__Noreturn] = ACTIONS(2118),
    [anon_sym_noreturn] = ACTIONS(2118),
    [anon_sym_mutable] = ACTIONS(2118),
    [anon_sym_constinit] = ACTIONS(2118),
    [anon_sym_consteval] = ACTIONS(2118),
    [anon_sym_alignas] = ACTIONS(2118),
    [anon_sym__Alignas] = ACTIONS(2118),
    [sym_primitive_type] = ACTIONS(2118),
    [anon_sym_enum] = ACTIONS(2118),
    [anon_sym_class] = ACTIONS(2118),
    [anon_sym_struct] = ACTIONS(2118),
    [anon_sym_union] = ACTIONS(2118),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2118),
    [anon_sym_decltype] = ACTIONS(2118),
    [sym_virtual] = ACTIONS(2118),
    [anon_sym_explicit] = ACTIONS(2118),
    [anon_sym_typename] = ACTIONS(2118),
    [anon_sym_template] = ACTIONS(2118),
    [anon_sym_operator] = ACTIONS(2118),
    [anon_sym_friend] = ACTIONS(2118),
    [anon_sym_public] = ACTIONS(2118),
    [anon_sym_private] = ACTIONS(2118),
    [anon_sym_protected] = ACTIONS(2118),
    [anon_sym_using] = ACTIONS(2118),
    [anon_sym_static_assert] = ACTIONS(2118),
    [anon_sym_precise] = ACTIONS(2118),
    [anon_sym_shared] = ACTIONS(2118),
    [anon_sym_groupshared] = ACTIONS(2118),
    [anon_sym_uniform] = ACTIONS(2118),
    [anon_sym_row_major] = ACTIONS(2118),
    [anon_sym_column_major] = ACTIONS(2118),
    [anon_sym_globallycoherent] = ACTIONS(2118),
    [anon_sym_centroid] = ACTIONS(2118),
    [anon_sym_noperspective] = ACTIONS(2118),
    [anon_sym_nointerpolation] = ACTIONS(2118),
    [anon_sym_sample] = ACTIONS(2118),
    [anon_sym_linear] = ACTIONS(2118),
    [anon_sym_snorm] = ACTIONS(2118),
    [anon_sym_unorm] = ACTIONS(2118),
    [anon_sym_point] = ACTIONS(2118),
    [anon_sym_line] = ACTIONS(2118),
    [anon_sym_triangleadj] = ACTIONS(2118),
    [anon_sym_lineadj] = ACTIONS(2118),
    [anon_sym_triangle] = ACTIONS(2118),
  },
  [1903] = {
    [sym_identifier] = ACTIONS(2264),
    [aux_sym_preproc_def_token1] = ACTIONS(2264),
    [aux_sym_preproc_if_token1] = ACTIONS(2264),
    [aux_sym_preproc_if_token2] = ACTIONS(2264),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2264),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2264),
    [aux_sym_preproc_else_token1] = ACTIONS(2264),
    [aux_sym_preproc_elif_token1] = ACTIONS(2264),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2264),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2264),
    [sym_preproc_directive] = ACTIONS(2264),
    [anon_sym_LPAREN2] = ACTIONS(2266),
    [anon_sym_TILDE] = ACTIONS(2266),
    [anon_sym_STAR] = ACTIONS(2266),
    [anon_sym_AMP_AMP] = ACTIONS(2266),
    [anon_sym_AMP] = ACTIONS(2264),
    [anon_sym___extension__] = ACTIONS(2264),
    [anon_sym_typedef] = ACTIONS(2264),
    [anon_sym_in] = ACTIONS(2264),
    [anon_sym_out] = ACTIONS(2264),
    [anon_sym_inout] = ACTIONS(2264),
    [anon_sym_extern] = ACTIONS(2264),
    [anon_sym___attribute__] = ACTIONS(2264),
    [anon_sym_COLON_COLON] = ACTIONS(2266),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2266),
    [anon_sym___declspec] = ACTIONS(2264),
    [anon_sym___based] = ACTIONS(2264),
    [anon_sym_signed] = ACTIONS(2264),
    [anon_sym_unsigned] = ACTIONS(2264),
    [anon_sym_long] = ACTIONS(2264),
    [anon_sym_short] = ACTIONS(2264),
    [anon_sym_LBRACK] = ACTIONS(2264),
    [anon_sym_static] = ACTIONS(2264),
    [anon_sym_register] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(2264),
    [anon_sym___inline] = ACTIONS(2264),
    [anon_sym___inline__] = ACTIONS(2264),
    [anon_sym___forceinline] = ACTIONS(2264),
    [anon_sym_thread_local] = ACTIONS(2264),
    [anon_sym___thread] = ACTIONS(2264),
    [anon_sym_const] = ACTIONS(2264),
    [anon_sym_constexpr] = ACTIONS(2264),
    [anon_sym_volatile] = ACTIONS(2264),
    [anon_sym_restrict] = ACTIONS(2264),
    [anon_sym___restrict__] = ACTIONS(2264),
    [anon_sym__Atomic] = ACTIONS(2264),
    [anon_sym__Noreturn] = ACTIONS(2264),
    [anon_sym_noreturn] = ACTIONS(2264),
    [anon_sym_mutable] = ACTIONS(2264),
    [anon_sym_constinit] = ACTIONS(2264),
    [anon_sym_consteval] = ACTIONS(2264),
    [anon_sym_alignas] = ACTIONS(2264),
    [anon_sym__Alignas] = ACTIONS(2264),
    [sym_primitive_type] = ACTIONS(2264),
    [anon_sym_enum] = ACTIONS(2264),
    [anon_sym_class] = ACTIONS(2264),
    [anon_sym_struct] = ACTIONS(2264),
    [anon_sym_union] = ACTIONS(2264),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2264),
    [anon_sym_decltype] = ACTIONS(2264),
    [sym_virtual] = ACTIONS(2264),
    [anon_sym_explicit] = ACTIONS(2264),
    [anon_sym_typename] = ACTIONS(2264),
    [anon_sym_template] = ACTIONS(2264),
    [anon_sym_operator] = ACTIONS(2264),
    [anon_sym_friend] = ACTIONS(2264),
    [anon_sym_public] = ACTIONS(2264),
    [anon_sym_private] = ACTIONS(2264),
    [anon_sym_protected] = ACTIONS(2264),
    [anon_sym_using] = ACTIONS(2264),
    [anon_sym_static_assert] = ACTIONS(2264),
    [anon_sym_precise] = ACTIONS(2264),
    [anon_sym_shared] = ACTIONS(2264),
    [anon_sym_groupshared] = ACTIONS(2264),
    [anon_sym_uniform] = ACTIONS(2264),
    [anon_sym_row_major] = ACTIONS(2264),
    [anon_sym_column_major] = ACTIONS(2264),
    [anon_sym_globallycoherent] = ACTIONS(2264),
    [anon_sym_centroid] = ACTIONS(2264),
    [anon_sym_noperspective] = ACTIONS(2264),
    [anon_sym_nointerpolation] = ACTIONS(2264),
    [anon_sym_sample] = ACTIONS(2264),
    [anon_sym_linear] = ACTIONS(2264),
    [anon_sym_snorm] = ACTIONS(2264),
    [anon_sym_unorm] = ACTIONS(2264),
    [anon_sym_point] = ACTIONS(2264),
    [anon_sym_line] = ACTIONS(2264),
    [anon_sym_triangleadj] = ACTIONS(2264),
    [anon_sym_lineadj] = ACTIONS(2264),
    [anon_sym_triangle] = ACTIONS(2264),
  },
  [1904] = {
    [sym_identifier] = ACTIONS(2454),
    [aux_sym_preproc_def_token1] = ACTIONS(2454),
    [aux_sym_preproc_if_token1] = ACTIONS(2454),
    [aux_sym_preproc_if_token2] = ACTIONS(2454),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2454),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2454),
    [aux_sym_preproc_else_token1] = ACTIONS(2454),
    [aux_sym_preproc_elif_token1] = ACTIONS(2454),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2454),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2454),
    [sym_preproc_directive] = ACTIONS(2454),
    [anon_sym_LPAREN2] = ACTIONS(2456),
    [anon_sym_TILDE] = ACTIONS(2456),
    [anon_sym_STAR] = ACTIONS(2456),
    [anon_sym_AMP_AMP] = ACTIONS(2456),
    [anon_sym_AMP] = ACTIONS(2454),
    [anon_sym___extension__] = ACTIONS(2454),
    [anon_sym_typedef] = ACTIONS(2454),
    [anon_sym_in] = ACTIONS(2454),
    [anon_sym_out] = ACTIONS(2454),
    [anon_sym_inout] = ACTIONS(2454),
    [anon_sym_extern] = ACTIONS(2454),
    [anon_sym___attribute__] = ACTIONS(2454),
    [anon_sym_COLON_COLON] = ACTIONS(2456),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2456),
    [anon_sym___declspec] = ACTIONS(2454),
    [anon_sym___based] = ACTIONS(2454),
    [anon_sym_signed] = ACTIONS(2454),
    [anon_sym_unsigned] = ACTIONS(2454),
    [anon_sym_long] = ACTIONS(2454),
    [anon_sym_short] = ACTIONS(2454),
    [anon_sym_LBRACK] = ACTIONS(2454),
    [anon_sym_static] = ACTIONS(2454),
    [anon_sym_register] = ACTIONS(2454),
    [anon_sym_inline] = ACTIONS(2454),
    [anon_sym___inline] = ACTIONS(2454),
    [anon_sym___inline__] = ACTIONS(2454),
    [anon_sym___forceinline] = ACTIONS(2454),
    [anon_sym_thread_local] = ACTIONS(2454),
    [anon_sym___thread] = ACTIONS(2454),
    [anon_sym_const] = ACTIONS(2454),
    [anon_sym_constexpr] = ACTIONS(2454),
    [anon_sym_volatile] = ACTIONS(2454),
    [anon_sym_restrict] = ACTIONS(2454),
    [anon_sym___restrict__] = ACTIONS(2454),
    [anon_sym__Atomic] = ACTIONS(2454),
    [anon_sym__Noreturn] = ACTIONS(2454),
    [anon_sym_noreturn] = ACTIONS(2454),
    [anon_sym_mutable] = ACTIONS(2454),
    [anon_sym_constinit] = ACTIONS(2454),
    [anon_sym_consteval] = ACTIONS(2454),
    [anon_sym_alignas] = ACTIONS(2454),
    [anon_sym__Alignas] = ACTIONS(2454),
    [sym_primitive_type] = ACTIONS(2454),
    [anon_sym_enum] = ACTIONS(2454),
    [anon_sym_class] = ACTIONS(2454),
    [anon_sym_struct] = ACTIONS(2454),
    [anon_sym_union] = ACTIONS(2454),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2454),
    [anon_sym_decltype] = ACTIONS(2454),
    [sym_virtual] = ACTIONS(2454),
    [anon_sym_explicit] = ACTIONS(2454),
    [anon_sym_typename] = ACTIONS(2454),
    [anon_sym_template] = ACTIONS(2454),
    [anon_sym_operator] = ACTIONS(2454),
    [anon_sym_friend] = ACTIONS(2454),
    [anon_sym_public] = ACTIONS(2454),
    [anon_sym_private] = ACTIONS(2454),
    [anon_sym_protected] = ACTIONS(2454),
    [anon_sym_using] = ACTIONS(2454),
    [anon_sym_static_assert] = ACTIONS(2454),
    [anon_sym_precise] = ACTIONS(2454),
    [anon_sym_shared] = ACTIONS(2454),
    [anon_sym_groupshared] = ACTIONS(2454),
    [anon_sym_uniform] = ACTIONS(2454),
    [anon_sym_row_major] = ACTIONS(2454),
    [anon_sym_column_major] = ACTIONS(2454),
    [anon_sym_globallycoherent] = ACTIONS(2454),
    [anon_sym_centroid] = ACTIONS(2454),
    [anon_sym_noperspective] = ACTIONS(2454),
    [anon_sym_nointerpolation] = ACTIONS(2454),
    [anon_sym_sample] = ACTIONS(2454),
    [anon_sym_linear] = ACTIONS(2454),
    [anon_sym_snorm] = ACTIONS(2454),
    [anon_sym_unorm] = ACTIONS(2454),
    [anon_sym_point] = ACTIONS(2454),
    [anon_sym_line] = ACTIONS(2454),
    [anon_sym_triangleadj] = ACTIONS(2454),
    [anon_sym_lineadj] = ACTIONS(2454),
    [anon_sym_triangle] = ACTIONS(2454),
  },
  [1905] = {
    [sym_identifier] = ACTIONS(5085),
    [aux_sym_preproc_def_token1] = ACTIONS(5085),
    [aux_sym_preproc_if_token1] = ACTIONS(5085),
    [aux_sym_preproc_if_token2] = ACTIONS(5085),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5085),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5085),
    [aux_sym_preproc_else_token1] = ACTIONS(5085),
    [aux_sym_preproc_elif_token1] = ACTIONS(5085),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5085),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5085),
    [sym_preproc_directive] = ACTIONS(5085),
    [anon_sym_LPAREN2] = ACTIONS(5087),
    [anon_sym_TILDE] = ACTIONS(5087),
    [anon_sym_STAR] = ACTIONS(5087),
    [anon_sym_AMP_AMP] = ACTIONS(5087),
    [anon_sym_AMP] = ACTIONS(5085),
    [anon_sym___extension__] = ACTIONS(5085),
    [anon_sym_typedef] = ACTIONS(5085),
    [anon_sym_in] = ACTIONS(5085),
    [anon_sym_out] = ACTIONS(5085),
    [anon_sym_inout] = ACTIONS(5085),
    [anon_sym_extern] = ACTIONS(5085),
    [anon_sym___attribute__] = ACTIONS(5085),
    [anon_sym_COLON_COLON] = ACTIONS(5087),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5087),
    [anon_sym___declspec] = ACTIONS(5085),
    [anon_sym___based] = ACTIONS(5085),
    [anon_sym_signed] = ACTIONS(5085),
    [anon_sym_unsigned] = ACTIONS(5085),
    [anon_sym_long] = ACTIONS(5085),
    [anon_sym_short] = ACTIONS(5085),
    [anon_sym_LBRACK] = ACTIONS(5085),
    [anon_sym_static] = ACTIONS(5085),
    [anon_sym_register] = ACTIONS(5085),
    [anon_sym_inline] = ACTIONS(5085),
    [anon_sym___inline] = ACTIONS(5085),
    [anon_sym___inline__] = ACTIONS(5085),
    [anon_sym___forceinline] = ACTIONS(5085),
    [anon_sym_thread_local] = ACTIONS(5085),
    [anon_sym___thread] = ACTIONS(5085),
    [anon_sym_const] = ACTIONS(5085),
    [anon_sym_constexpr] = ACTIONS(5085),
    [anon_sym_volatile] = ACTIONS(5085),
    [anon_sym_restrict] = ACTIONS(5085),
    [anon_sym___restrict__] = ACTIONS(5085),
    [anon_sym__Atomic] = ACTIONS(5085),
    [anon_sym__Noreturn] = ACTIONS(5085),
    [anon_sym_noreturn] = ACTIONS(5085),
    [anon_sym_mutable] = ACTIONS(5085),
    [anon_sym_constinit] = ACTIONS(5085),
    [anon_sym_consteval] = ACTIONS(5085),
    [anon_sym_alignas] = ACTIONS(5085),
    [anon_sym__Alignas] = ACTIONS(5085),
    [sym_primitive_type] = ACTIONS(5085),
    [anon_sym_enum] = ACTIONS(5085),
    [anon_sym_class] = ACTIONS(5085),
    [anon_sym_struct] = ACTIONS(5085),
    [anon_sym_union] = ACTIONS(5085),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5085),
    [anon_sym_decltype] = ACTIONS(5085),
    [sym_virtual] = ACTIONS(5085),
    [anon_sym_explicit] = ACTIONS(5085),
    [anon_sym_typename] = ACTIONS(5085),
    [anon_sym_template] = ACTIONS(5085),
    [anon_sym_operator] = ACTIONS(5085),
    [anon_sym_friend] = ACTIONS(5085),
    [anon_sym_public] = ACTIONS(5085),
    [anon_sym_private] = ACTIONS(5085),
    [anon_sym_protected] = ACTIONS(5085),
    [anon_sym_using] = ACTIONS(5085),
    [anon_sym_static_assert] = ACTIONS(5085),
    [anon_sym_precise] = ACTIONS(5085),
    [anon_sym_shared] = ACTIONS(5085),
    [anon_sym_groupshared] = ACTIONS(5085),
    [anon_sym_uniform] = ACTIONS(5085),
    [anon_sym_row_major] = ACTIONS(5085),
    [anon_sym_column_major] = ACTIONS(5085),
    [anon_sym_globallycoherent] = ACTIONS(5085),
    [anon_sym_centroid] = ACTIONS(5085),
    [anon_sym_noperspective] = ACTIONS(5085),
    [anon_sym_nointerpolation] = ACTIONS(5085),
    [anon_sym_sample] = ACTIONS(5085),
    [anon_sym_linear] = ACTIONS(5085),
    [anon_sym_snorm] = ACTIONS(5085),
    [anon_sym_unorm] = ACTIONS(5085),
    [anon_sym_point] = ACTIONS(5085),
    [anon_sym_line] = ACTIONS(5085),
    [anon_sym_triangleadj] = ACTIONS(5085),
    [anon_sym_lineadj] = ACTIONS(5085),
    [anon_sym_triangle] = ACTIONS(5085),
  },
  [1906] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token2] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [aux_sym_preproc_else_token1] = ACTIONS(2324),
    [aux_sym_preproc_elif_token1] = ACTIONS(2324),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_friend] = ACTIONS(2324),
    [anon_sym_public] = ACTIONS(2324),
    [anon_sym_private] = ACTIONS(2324),
    [anon_sym_protected] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
  },
  [1907] = {
    [sym_identifier] = ACTIONS(2466),
    [aux_sym_preproc_def_token1] = ACTIONS(2466),
    [aux_sym_preproc_if_token1] = ACTIONS(2466),
    [aux_sym_preproc_if_token2] = ACTIONS(2466),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2466),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2466),
    [aux_sym_preproc_else_token1] = ACTIONS(2466),
    [aux_sym_preproc_elif_token1] = ACTIONS(2466),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2466),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2466),
    [sym_preproc_directive] = ACTIONS(2466),
    [anon_sym_LPAREN2] = ACTIONS(2468),
    [anon_sym_TILDE] = ACTIONS(2468),
    [anon_sym_STAR] = ACTIONS(2468),
    [anon_sym_AMP_AMP] = ACTIONS(2468),
    [anon_sym_AMP] = ACTIONS(2466),
    [anon_sym___extension__] = ACTIONS(2466),
    [anon_sym_typedef] = ACTIONS(2466),
    [anon_sym_in] = ACTIONS(2466),
    [anon_sym_out] = ACTIONS(2466),
    [anon_sym_inout] = ACTIONS(2466),
    [anon_sym_extern] = ACTIONS(2466),
    [anon_sym___attribute__] = ACTIONS(2466),
    [anon_sym_COLON_COLON] = ACTIONS(2468),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2468),
    [anon_sym___declspec] = ACTIONS(2466),
    [anon_sym___based] = ACTIONS(2466),
    [anon_sym_signed] = ACTIONS(2466),
    [anon_sym_unsigned] = ACTIONS(2466),
    [anon_sym_long] = ACTIONS(2466),
    [anon_sym_short] = ACTIONS(2466),
    [anon_sym_LBRACK] = ACTIONS(2466),
    [anon_sym_static] = ACTIONS(2466),
    [anon_sym_register] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2466),
    [anon_sym___inline] = ACTIONS(2466),
    [anon_sym___inline__] = ACTIONS(2466),
    [anon_sym___forceinline] = ACTIONS(2466),
    [anon_sym_thread_local] = ACTIONS(2466),
    [anon_sym___thread] = ACTIONS(2466),
    [anon_sym_const] = ACTIONS(2466),
    [anon_sym_constexpr] = ACTIONS(2466),
    [anon_sym_volatile] = ACTIONS(2466),
    [anon_sym_restrict] = ACTIONS(2466),
    [anon_sym___restrict__] = ACTIONS(2466),
    [anon_sym__Atomic] = ACTIONS(2466),
    [anon_sym__Noreturn] = ACTIONS(2466),
    [anon_sym_noreturn] = ACTIONS(2466),
    [anon_sym_mutable] = ACTIONS(2466),
    [anon_sym_constinit] = ACTIONS(2466),
    [anon_sym_consteval] = ACTIONS(2466),
    [anon_sym_alignas] = ACTIONS(2466),
    [anon_sym__Alignas] = ACTIONS(2466),
    [sym_primitive_type] = ACTIONS(2466),
    [anon_sym_enum] = ACTIONS(2466),
    [anon_sym_class] = ACTIONS(2466),
    [anon_sym_struct] = ACTIONS(2466),
    [anon_sym_union] = ACTIONS(2466),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2466),
    [anon_sym_decltype] = ACTIONS(2466),
    [sym_virtual] = ACTIONS(2466),
    [anon_sym_explicit] = ACTIONS(2466),
    [anon_sym_typename] = ACTIONS(2466),
    [anon_sym_template] = ACTIONS(2466),
    [anon_sym_operator] = ACTIONS(2466),
    [anon_sym_friend] = ACTIONS(2466),
    [anon_sym_public] = ACTIONS(2466),
    [anon_sym_private] = ACTIONS(2466),
    [anon_sym_protected] = ACTIONS(2466),
    [anon_sym_using] = ACTIONS(2466),
    [anon_sym_static_assert] = ACTIONS(2466),
    [anon_sym_precise] = ACTIONS(2466),
    [anon_sym_shared] = ACTIONS(2466),
    [anon_sym_groupshared] = ACTIONS(2466),
    [anon_sym_uniform] = ACTIONS(2466),
    [anon_sym_row_major] = ACTIONS(2466),
    [anon_sym_column_major] = ACTIONS(2466),
    [anon_sym_globallycoherent] = ACTIONS(2466),
    [anon_sym_centroid] = ACTIONS(2466),
    [anon_sym_noperspective] = ACTIONS(2466),
    [anon_sym_nointerpolation] = ACTIONS(2466),
    [anon_sym_sample] = ACTIONS(2466),
    [anon_sym_linear] = ACTIONS(2466),
    [anon_sym_snorm] = ACTIONS(2466),
    [anon_sym_unorm] = ACTIONS(2466),
    [anon_sym_point] = ACTIONS(2466),
    [anon_sym_line] = ACTIONS(2466),
    [anon_sym_triangleadj] = ACTIONS(2466),
    [anon_sym_lineadj] = ACTIONS(2466),
    [anon_sym_triangle] = ACTIONS(2466),
  },
  [1908] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token2] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [aux_sym_preproc_else_token1] = ACTIONS(2324),
    [aux_sym_preproc_elif_token1] = ACTIONS(2324),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_friend] = ACTIONS(2324),
    [anon_sym_public] = ACTIONS(2324),
    [anon_sym_private] = ACTIONS(2324),
    [anon_sym_protected] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
  },
  [1909] = {
    [sym_identifier] = ACTIONS(2573),
    [aux_sym_preproc_def_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token2] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2573),
    [aux_sym_preproc_else_token1] = ACTIONS(2573),
    [aux_sym_preproc_elif_token1] = ACTIONS(2573),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2573),
    [sym_preproc_directive] = ACTIONS(2573),
    [anon_sym_LPAREN2] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(2575),
    [anon_sym_STAR] = ACTIONS(2575),
    [anon_sym_AMP_AMP] = ACTIONS(2575),
    [anon_sym_AMP] = ACTIONS(2573),
    [anon_sym___extension__] = ACTIONS(2573),
    [anon_sym_typedef] = ACTIONS(2573),
    [anon_sym_in] = ACTIONS(2573),
    [anon_sym_out] = ACTIONS(2573),
    [anon_sym_inout] = ACTIONS(2573),
    [anon_sym_extern] = ACTIONS(2573),
    [anon_sym___attribute__] = ACTIONS(2573),
    [anon_sym_COLON_COLON] = ACTIONS(2575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2575),
    [anon_sym___declspec] = ACTIONS(2573),
    [anon_sym___based] = ACTIONS(2573),
    [anon_sym_signed] = ACTIONS(2573),
    [anon_sym_unsigned] = ACTIONS(2573),
    [anon_sym_long] = ACTIONS(2573),
    [anon_sym_short] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2573),
    [anon_sym_static] = ACTIONS(2573),
    [anon_sym_register] = ACTIONS(2573),
    [anon_sym_inline] = ACTIONS(2573),
    [anon_sym___inline] = ACTIONS(2573),
    [anon_sym___inline__] = ACTIONS(2573),
    [anon_sym___forceinline] = ACTIONS(2573),
    [anon_sym_thread_local] = ACTIONS(2573),
    [anon_sym___thread] = ACTIONS(2573),
    [anon_sym_const] = ACTIONS(2573),
    [anon_sym_constexpr] = ACTIONS(2573),
    [anon_sym_volatile] = ACTIONS(2573),
    [anon_sym_restrict] = ACTIONS(2573),
    [anon_sym___restrict__] = ACTIONS(2573),
    [anon_sym__Atomic] = ACTIONS(2573),
    [anon_sym__Noreturn] = ACTIONS(2573),
    [anon_sym_noreturn] = ACTIONS(2573),
    [anon_sym_mutable] = ACTIONS(2573),
    [anon_sym_constinit] = ACTIONS(2573),
    [anon_sym_consteval] = ACTIONS(2573),
    [anon_sym_alignas] = ACTIONS(2573),
    [anon_sym__Alignas] = ACTIONS(2573),
    [sym_primitive_type] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_class] = ACTIONS(2573),
    [anon_sym_struct] = ACTIONS(2573),
    [anon_sym_union] = ACTIONS(2573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2573),
    [anon_sym_decltype] = ACTIONS(2573),
    [sym_virtual] = ACTIONS(2573),
    [anon_sym_explicit] = ACTIONS(2573),
    [anon_sym_typename] = ACTIONS(2573),
    [anon_sym_template] = ACTIONS(2573),
    [anon_sym_operator] = ACTIONS(2573),
    [anon_sym_friend] = ACTIONS(2573),
    [anon_sym_public] = ACTIONS(2573),
    [anon_sym_private] = ACTIONS(2573),
    [anon_sym_protected] = ACTIONS(2573),
    [anon_sym_using] = ACTIONS(2573),
    [anon_sym_static_assert] = ACTIONS(2573),
    [anon_sym_precise] = ACTIONS(2573),
    [anon_sym_shared] = ACTIONS(2573),
    [anon_sym_groupshared] = ACTIONS(2573),
    [anon_sym_uniform] = ACTIONS(2573),
    [anon_sym_row_major] = ACTIONS(2573),
    [anon_sym_column_major] = ACTIONS(2573),
    [anon_sym_globallycoherent] = ACTIONS(2573),
    [anon_sym_centroid] = ACTIONS(2573),
    [anon_sym_noperspective] = ACTIONS(2573),
    [anon_sym_nointerpolation] = ACTIONS(2573),
    [anon_sym_sample] = ACTIONS(2573),
    [anon_sym_linear] = ACTIONS(2573),
    [anon_sym_snorm] = ACTIONS(2573),
    [anon_sym_unorm] = ACTIONS(2573),
    [anon_sym_point] = ACTIONS(2573),
    [anon_sym_line] = ACTIONS(2573),
    [anon_sym_triangleadj] = ACTIONS(2573),
    [anon_sym_lineadj] = ACTIONS(2573),
    [anon_sym_triangle] = ACTIONS(2573),
  },
  [1910] = {
    [sym_identifier] = ACTIONS(5089),
    [aux_sym_preproc_def_token1] = ACTIONS(5089),
    [aux_sym_preproc_if_token1] = ACTIONS(5089),
    [aux_sym_preproc_if_token2] = ACTIONS(5089),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5089),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5089),
    [aux_sym_preproc_else_token1] = ACTIONS(5089),
    [aux_sym_preproc_elif_token1] = ACTIONS(5089),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5089),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5089),
    [sym_preproc_directive] = ACTIONS(5089),
    [anon_sym_LPAREN2] = ACTIONS(5091),
    [anon_sym_TILDE] = ACTIONS(5091),
    [anon_sym_STAR] = ACTIONS(5091),
    [anon_sym_AMP_AMP] = ACTIONS(5091),
    [anon_sym_AMP] = ACTIONS(5089),
    [anon_sym___extension__] = ACTIONS(5089),
    [anon_sym_typedef] = ACTIONS(5089),
    [anon_sym_in] = ACTIONS(5089),
    [anon_sym_out] = ACTIONS(5089),
    [anon_sym_inout] = ACTIONS(5089),
    [anon_sym_extern] = ACTIONS(5089),
    [anon_sym___attribute__] = ACTIONS(5089),
    [anon_sym_COLON_COLON] = ACTIONS(5091),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5091),
    [anon_sym___declspec] = ACTIONS(5089),
    [anon_sym___based] = ACTIONS(5089),
    [anon_sym_signed] = ACTIONS(5089),
    [anon_sym_unsigned] = ACTIONS(5089),
    [anon_sym_long] = ACTIONS(5089),
    [anon_sym_short] = ACTIONS(5089),
    [anon_sym_LBRACK] = ACTIONS(5089),
    [anon_sym_static] = ACTIONS(5089),
    [anon_sym_register] = ACTIONS(5089),
    [anon_sym_inline] = ACTIONS(5089),
    [anon_sym___inline] = ACTIONS(5089),
    [anon_sym___inline__] = ACTIONS(5089),
    [anon_sym___forceinline] = ACTIONS(5089),
    [anon_sym_thread_local] = ACTIONS(5089),
    [anon_sym___thread] = ACTIONS(5089),
    [anon_sym_const] = ACTIONS(5089),
    [anon_sym_constexpr] = ACTIONS(5089),
    [anon_sym_volatile] = ACTIONS(5089),
    [anon_sym_restrict] = ACTIONS(5089),
    [anon_sym___restrict__] = ACTIONS(5089),
    [anon_sym__Atomic] = ACTIONS(5089),
    [anon_sym__Noreturn] = ACTIONS(5089),
    [anon_sym_noreturn] = ACTIONS(5089),
    [anon_sym_mutable] = ACTIONS(5089),
    [anon_sym_constinit] = ACTIONS(5089),
    [anon_sym_consteval] = ACTIONS(5089),
    [anon_sym_alignas] = ACTIONS(5089),
    [anon_sym__Alignas] = ACTIONS(5089),
    [sym_primitive_type] = ACTIONS(5089),
    [anon_sym_enum] = ACTIONS(5089),
    [anon_sym_class] = ACTIONS(5089),
    [anon_sym_struct] = ACTIONS(5089),
    [anon_sym_union] = ACTIONS(5089),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5089),
    [anon_sym_decltype] = ACTIONS(5089),
    [sym_virtual] = ACTIONS(5089),
    [anon_sym_explicit] = ACTIONS(5089),
    [anon_sym_typename] = ACTIONS(5089),
    [anon_sym_template] = ACTIONS(5089),
    [anon_sym_operator] = ACTIONS(5089),
    [anon_sym_friend] = ACTIONS(5089),
    [anon_sym_public] = ACTIONS(5089),
    [anon_sym_private] = ACTIONS(5089),
    [anon_sym_protected] = ACTIONS(5089),
    [anon_sym_using] = ACTIONS(5089),
    [anon_sym_static_assert] = ACTIONS(5089),
    [anon_sym_precise] = ACTIONS(5089),
    [anon_sym_shared] = ACTIONS(5089),
    [anon_sym_groupshared] = ACTIONS(5089),
    [anon_sym_uniform] = ACTIONS(5089),
    [anon_sym_row_major] = ACTIONS(5089),
    [anon_sym_column_major] = ACTIONS(5089),
    [anon_sym_globallycoherent] = ACTIONS(5089),
    [anon_sym_centroid] = ACTIONS(5089),
    [anon_sym_noperspective] = ACTIONS(5089),
    [anon_sym_nointerpolation] = ACTIONS(5089),
    [anon_sym_sample] = ACTIONS(5089),
    [anon_sym_linear] = ACTIONS(5089),
    [anon_sym_snorm] = ACTIONS(5089),
    [anon_sym_unorm] = ACTIONS(5089),
    [anon_sym_point] = ACTIONS(5089),
    [anon_sym_line] = ACTIONS(5089),
    [anon_sym_triangleadj] = ACTIONS(5089),
    [anon_sym_lineadj] = ACTIONS(5089),
    [anon_sym_triangle] = ACTIONS(5089),
  },
  [1911] = {
    [sym_identifier] = ACTIONS(2448),
    [aux_sym_preproc_def_token1] = ACTIONS(2448),
    [aux_sym_preproc_if_token1] = ACTIONS(2448),
    [aux_sym_preproc_if_token2] = ACTIONS(2448),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2448),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2448),
    [aux_sym_preproc_else_token1] = ACTIONS(2448),
    [aux_sym_preproc_elif_token1] = ACTIONS(2448),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2448),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2448),
    [sym_preproc_directive] = ACTIONS(2448),
    [anon_sym_LPAREN2] = ACTIONS(2450),
    [anon_sym_TILDE] = ACTIONS(2450),
    [anon_sym_STAR] = ACTIONS(2450),
    [anon_sym_AMP_AMP] = ACTIONS(2450),
    [anon_sym_AMP] = ACTIONS(2448),
    [anon_sym___extension__] = ACTIONS(2448),
    [anon_sym_typedef] = ACTIONS(2448),
    [anon_sym_in] = ACTIONS(2448),
    [anon_sym_out] = ACTIONS(2448),
    [anon_sym_inout] = ACTIONS(2448),
    [anon_sym_extern] = ACTIONS(2448),
    [anon_sym___attribute__] = ACTIONS(2448),
    [anon_sym_COLON_COLON] = ACTIONS(2450),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2450),
    [anon_sym___declspec] = ACTIONS(2448),
    [anon_sym___based] = ACTIONS(2448),
    [anon_sym_signed] = ACTIONS(2448),
    [anon_sym_unsigned] = ACTIONS(2448),
    [anon_sym_long] = ACTIONS(2448),
    [anon_sym_short] = ACTIONS(2448),
    [anon_sym_LBRACK] = ACTIONS(2448),
    [anon_sym_static] = ACTIONS(2448),
    [anon_sym_register] = ACTIONS(2448),
    [anon_sym_inline] = ACTIONS(2448),
    [anon_sym___inline] = ACTIONS(2448),
    [anon_sym___inline__] = ACTIONS(2448),
    [anon_sym___forceinline] = ACTIONS(2448),
    [anon_sym_thread_local] = ACTIONS(2448),
    [anon_sym___thread] = ACTIONS(2448),
    [anon_sym_const] = ACTIONS(2448),
    [anon_sym_constexpr] = ACTIONS(2448),
    [anon_sym_volatile] = ACTIONS(2448),
    [anon_sym_restrict] = ACTIONS(2448),
    [anon_sym___restrict__] = ACTIONS(2448),
    [anon_sym__Atomic] = ACTIONS(2448),
    [anon_sym__Noreturn] = ACTIONS(2448),
    [anon_sym_noreturn] = ACTIONS(2448),
    [anon_sym_mutable] = ACTIONS(2448),
    [anon_sym_constinit] = ACTIONS(2448),
    [anon_sym_consteval] = ACTIONS(2448),
    [anon_sym_alignas] = ACTIONS(2448),
    [anon_sym__Alignas] = ACTIONS(2448),
    [sym_primitive_type] = ACTIONS(2448),
    [anon_sym_enum] = ACTIONS(2448),
    [anon_sym_class] = ACTIONS(2448),
    [anon_sym_struct] = ACTIONS(2448),
    [anon_sym_union] = ACTIONS(2448),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2448),
    [anon_sym_decltype] = ACTIONS(2448),
    [sym_virtual] = ACTIONS(2448),
    [anon_sym_explicit] = ACTIONS(2448),
    [anon_sym_typename] = ACTIONS(2448),
    [anon_sym_template] = ACTIONS(2448),
    [anon_sym_operator] = ACTIONS(2448),
    [anon_sym_friend] = ACTIONS(2448),
    [anon_sym_public] = ACTIONS(2448),
    [anon_sym_private] = ACTIONS(2448),
    [anon_sym_protected] = ACTIONS(2448),
    [anon_sym_using] = ACTIONS(2448),
    [anon_sym_static_assert] = ACTIONS(2448),
    [anon_sym_precise] = ACTIONS(2448),
    [anon_sym_shared] = ACTIONS(2448),
    [anon_sym_groupshared] = ACTIONS(2448),
    [anon_sym_uniform] = ACTIONS(2448),
    [anon_sym_row_major] = ACTIONS(2448),
    [anon_sym_column_major] = ACTIONS(2448),
    [anon_sym_globallycoherent] = ACTIONS(2448),
    [anon_sym_centroid] = ACTIONS(2448),
    [anon_sym_noperspective] = ACTIONS(2448),
    [anon_sym_nointerpolation] = ACTIONS(2448),
    [anon_sym_sample] = ACTIONS(2448),
    [anon_sym_linear] = ACTIONS(2448),
    [anon_sym_snorm] = ACTIONS(2448),
    [anon_sym_unorm] = ACTIONS(2448),
    [anon_sym_point] = ACTIONS(2448),
    [anon_sym_line] = ACTIONS(2448),
    [anon_sym_triangleadj] = ACTIONS(2448),
    [anon_sym_lineadj] = ACTIONS(2448),
    [anon_sym_triangle] = ACTIONS(2448),
  },
  [1912] = {
    [sym_identifier] = ACTIONS(5093),
    [aux_sym_preproc_def_token1] = ACTIONS(5093),
    [aux_sym_preproc_if_token1] = ACTIONS(5093),
    [aux_sym_preproc_if_token2] = ACTIONS(5093),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5093),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5093),
    [aux_sym_preproc_else_token1] = ACTIONS(5093),
    [aux_sym_preproc_elif_token1] = ACTIONS(5093),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5093),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5093),
    [sym_preproc_directive] = ACTIONS(5093),
    [anon_sym_LPAREN2] = ACTIONS(5095),
    [anon_sym_TILDE] = ACTIONS(5095),
    [anon_sym_STAR] = ACTIONS(5095),
    [anon_sym_AMP_AMP] = ACTIONS(5095),
    [anon_sym_AMP] = ACTIONS(5093),
    [anon_sym___extension__] = ACTIONS(5093),
    [anon_sym_typedef] = ACTIONS(5093),
    [anon_sym_in] = ACTIONS(5093),
    [anon_sym_out] = ACTIONS(5093),
    [anon_sym_inout] = ACTIONS(5093),
    [anon_sym_extern] = ACTIONS(5093),
    [anon_sym___attribute__] = ACTIONS(5093),
    [anon_sym_COLON_COLON] = ACTIONS(5095),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5095),
    [anon_sym___declspec] = ACTIONS(5093),
    [anon_sym___based] = ACTIONS(5093),
    [anon_sym_signed] = ACTIONS(5093),
    [anon_sym_unsigned] = ACTIONS(5093),
    [anon_sym_long] = ACTIONS(5093),
    [anon_sym_short] = ACTIONS(5093),
    [anon_sym_LBRACK] = ACTIONS(5093),
    [anon_sym_static] = ACTIONS(5093),
    [anon_sym_register] = ACTIONS(5093),
    [anon_sym_inline] = ACTIONS(5093),
    [anon_sym___inline] = ACTIONS(5093),
    [anon_sym___inline__] = ACTIONS(5093),
    [anon_sym___forceinline] = ACTIONS(5093),
    [anon_sym_thread_local] = ACTIONS(5093),
    [anon_sym___thread] = ACTIONS(5093),
    [anon_sym_const] = ACTIONS(5093),
    [anon_sym_constexpr] = ACTIONS(5093),
    [anon_sym_volatile] = ACTIONS(5093),
    [anon_sym_restrict] = ACTIONS(5093),
    [anon_sym___restrict__] = ACTIONS(5093),
    [anon_sym__Atomic] = ACTIONS(5093),
    [anon_sym__Noreturn] = ACTIONS(5093),
    [anon_sym_noreturn] = ACTIONS(5093),
    [anon_sym_mutable] = ACTIONS(5093),
    [anon_sym_constinit] = ACTIONS(5093),
    [anon_sym_consteval] = ACTIONS(5093),
    [anon_sym_alignas] = ACTIONS(5093),
    [anon_sym__Alignas] = ACTIONS(5093),
    [sym_primitive_type] = ACTIONS(5093),
    [anon_sym_enum] = ACTIONS(5093),
    [anon_sym_class] = ACTIONS(5093),
    [anon_sym_struct] = ACTIONS(5093),
    [anon_sym_union] = ACTIONS(5093),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5093),
    [anon_sym_decltype] = ACTIONS(5093),
    [sym_virtual] = ACTIONS(5093),
    [anon_sym_explicit] = ACTIONS(5093),
    [anon_sym_typename] = ACTIONS(5093),
    [anon_sym_template] = ACTIONS(5093),
    [anon_sym_operator] = ACTIONS(5093),
    [anon_sym_friend] = ACTIONS(5093),
    [anon_sym_public] = ACTIONS(5093),
    [anon_sym_private] = ACTIONS(5093),
    [anon_sym_protected] = ACTIONS(5093),
    [anon_sym_using] = ACTIONS(5093),
    [anon_sym_static_assert] = ACTIONS(5093),
    [anon_sym_precise] = ACTIONS(5093),
    [anon_sym_shared] = ACTIONS(5093),
    [anon_sym_groupshared] = ACTIONS(5093),
    [anon_sym_uniform] = ACTIONS(5093),
    [anon_sym_row_major] = ACTIONS(5093),
    [anon_sym_column_major] = ACTIONS(5093),
    [anon_sym_globallycoherent] = ACTIONS(5093),
    [anon_sym_centroid] = ACTIONS(5093),
    [anon_sym_noperspective] = ACTIONS(5093),
    [anon_sym_nointerpolation] = ACTIONS(5093),
    [anon_sym_sample] = ACTIONS(5093),
    [anon_sym_linear] = ACTIONS(5093),
    [anon_sym_snorm] = ACTIONS(5093),
    [anon_sym_unorm] = ACTIONS(5093),
    [anon_sym_point] = ACTIONS(5093),
    [anon_sym_line] = ACTIONS(5093),
    [anon_sym_triangleadj] = ACTIONS(5093),
    [anon_sym_lineadj] = ACTIONS(5093),
    [anon_sym_triangle] = ACTIONS(5093),
  },
  [1913] = {
    [sym_identifier] = ACTIONS(5097),
    [aux_sym_preproc_def_token1] = ACTIONS(5097),
    [aux_sym_preproc_if_token1] = ACTIONS(5097),
    [aux_sym_preproc_if_token2] = ACTIONS(5097),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5097),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5097),
    [aux_sym_preproc_else_token1] = ACTIONS(5097),
    [aux_sym_preproc_elif_token1] = ACTIONS(5097),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5097),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5097),
    [sym_preproc_directive] = ACTIONS(5097),
    [anon_sym_LPAREN2] = ACTIONS(5099),
    [anon_sym_TILDE] = ACTIONS(5099),
    [anon_sym_STAR] = ACTIONS(5099),
    [anon_sym_AMP_AMP] = ACTIONS(5099),
    [anon_sym_AMP] = ACTIONS(5097),
    [anon_sym___extension__] = ACTIONS(5097),
    [anon_sym_typedef] = ACTIONS(5097),
    [anon_sym_in] = ACTIONS(5097),
    [anon_sym_out] = ACTIONS(5097),
    [anon_sym_inout] = ACTIONS(5097),
    [anon_sym_extern] = ACTIONS(5097),
    [anon_sym___attribute__] = ACTIONS(5097),
    [anon_sym_COLON_COLON] = ACTIONS(5099),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5099),
    [anon_sym___declspec] = ACTIONS(5097),
    [anon_sym___based] = ACTIONS(5097),
    [anon_sym_signed] = ACTIONS(5097),
    [anon_sym_unsigned] = ACTIONS(5097),
    [anon_sym_long] = ACTIONS(5097),
    [anon_sym_short] = ACTIONS(5097),
    [anon_sym_LBRACK] = ACTIONS(5097),
    [anon_sym_static] = ACTIONS(5097),
    [anon_sym_register] = ACTIONS(5097),
    [anon_sym_inline] = ACTIONS(5097),
    [anon_sym___inline] = ACTIONS(5097),
    [anon_sym___inline__] = ACTIONS(5097),
    [anon_sym___forceinline] = ACTIONS(5097),
    [anon_sym_thread_local] = ACTIONS(5097),
    [anon_sym___thread] = ACTIONS(5097),
    [anon_sym_const] = ACTIONS(5097),
    [anon_sym_constexpr] = ACTIONS(5097),
    [anon_sym_volatile] = ACTIONS(5097),
    [anon_sym_restrict] = ACTIONS(5097),
    [anon_sym___restrict__] = ACTIONS(5097),
    [anon_sym__Atomic] = ACTIONS(5097),
    [anon_sym__Noreturn] = ACTIONS(5097),
    [anon_sym_noreturn] = ACTIONS(5097),
    [anon_sym_mutable] = ACTIONS(5097),
    [anon_sym_constinit] = ACTIONS(5097),
    [anon_sym_consteval] = ACTIONS(5097),
    [anon_sym_alignas] = ACTIONS(5097),
    [anon_sym__Alignas] = ACTIONS(5097),
    [sym_primitive_type] = ACTIONS(5097),
    [anon_sym_enum] = ACTIONS(5097),
    [anon_sym_class] = ACTIONS(5097),
    [anon_sym_struct] = ACTIONS(5097),
    [anon_sym_union] = ACTIONS(5097),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5097),
    [anon_sym_decltype] = ACTIONS(5097),
    [sym_virtual] = ACTIONS(5097),
    [anon_sym_explicit] = ACTIONS(5097),
    [anon_sym_typename] = ACTIONS(5097),
    [anon_sym_template] = ACTIONS(5097),
    [anon_sym_operator] = ACTIONS(5097),
    [anon_sym_friend] = ACTIONS(5097),
    [anon_sym_public] = ACTIONS(5097),
    [anon_sym_private] = ACTIONS(5097),
    [anon_sym_protected] = ACTIONS(5097),
    [anon_sym_using] = ACTIONS(5097),
    [anon_sym_static_assert] = ACTIONS(5097),
    [anon_sym_precise] = ACTIONS(5097),
    [anon_sym_shared] = ACTIONS(5097),
    [anon_sym_groupshared] = ACTIONS(5097),
    [anon_sym_uniform] = ACTIONS(5097),
    [anon_sym_row_major] = ACTIONS(5097),
    [anon_sym_column_major] = ACTIONS(5097),
    [anon_sym_globallycoherent] = ACTIONS(5097),
    [anon_sym_centroid] = ACTIONS(5097),
    [anon_sym_noperspective] = ACTIONS(5097),
    [anon_sym_nointerpolation] = ACTIONS(5097),
    [anon_sym_sample] = ACTIONS(5097),
    [anon_sym_linear] = ACTIONS(5097),
    [anon_sym_snorm] = ACTIONS(5097),
    [anon_sym_unorm] = ACTIONS(5097),
    [anon_sym_point] = ACTIONS(5097),
    [anon_sym_line] = ACTIONS(5097),
    [anon_sym_triangleadj] = ACTIONS(5097),
    [anon_sym_lineadj] = ACTIONS(5097),
    [anon_sym_triangle] = ACTIONS(5097),
  },
  [1914] = {
    [sym_identifier] = ACTIONS(2248),
    [aux_sym_preproc_def_token1] = ACTIONS(2248),
    [aux_sym_preproc_if_token1] = ACTIONS(2248),
    [aux_sym_preproc_if_token2] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2248),
    [aux_sym_preproc_else_token1] = ACTIONS(2248),
    [aux_sym_preproc_elif_token1] = ACTIONS(2248),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2248),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2248),
    [sym_preproc_directive] = ACTIONS(2248),
    [anon_sym_LPAREN2] = ACTIONS(2250),
    [anon_sym_TILDE] = ACTIONS(2250),
    [anon_sym_STAR] = ACTIONS(2250),
    [anon_sym_AMP_AMP] = ACTIONS(2250),
    [anon_sym_AMP] = ACTIONS(2248),
    [anon_sym___extension__] = ACTIONS(2248),
    [anon_sym_typedef] = ACTIONS(2248),
    [anon_sym_in] = ACTIONS(2248),
    [anon_sym_out] = ACTIONS(2248),
    [anon_sym_inout] = ACTIONS(2248),
    [anon_sym_extern] = ACTIONS(2248),
    [anon_sym___attribute__] = ACTIONS(2248),
    [anon_sym_COLON_COLON] = ACTIONS(2250),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2250),
    [anon_sym___declspec] = ACTIONS(2248),
    [anon_sym___based] = ACTIONS(2248),
    [anon_sym_signed] = ACTIONS(2248),
    [anon_sym_unsigned] = ACTIONS(2248),
    [anon_sym_long] = ACTIONS(2248),
    [anon_sym_short] = ACTIONS(2248),
    [anon_sym_LBRACK] = ACTIONS(2248),
    [anon_sym_static] = ACTIONS(2248),
    [anon_sym_register] = ACTIONS(2248),
    [anon_sym_inline] = ACTIONS(2248),
    [anon_sym___inline] = ACTIONS(2248),
    [anon_sym___inline__] = ACTIONS(2248),
    [anon_sym___forceinline] = ACTIONS(2248),
    [anon_sym_thread_local] = ACTIONS(2248),
    [anon_sym___thread] = ACTIONS(2248),
    [anon_sym_const] = ACTIONS(2248),
    [anon_sym_constexpr] = ACTIONS(2248),
    [anon_sym_volatile] = ACTIONS(2248),
    [anon_sym_restrict] = ACTIONS(2248),
    [anon_sym___restrict__] = ACTIONS(2248),
    [anon_sym__Atomic] = ACTIONS(2248),
    [anon_sym__Noreturn] = ACTIONS(2248),
    [anon_sym_noreturn] = ACTIONS(2248),
    [anon_sym_mutable] = ACTIONS(2248),
    [anon_sym_constinit] = ACTIONS(2248),
    [anon_sym_consteval] = ACTIONS(2248),
    [anon_sym_alignas] = ACTIONS(2248),
    [anon_sym__Alignas] = ACTIONS(2248),
    [sym_primitive_type] = ACTIONS(2248),
    [anon_sym_enum] = ACTIONS(2248),
    [anon_sym_class] = ACTIONS(2248),
    [anon_sym_struct] = ACTIONS(2248),
    [anon_sym_union] = ACTIONS(2248),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2248),
    [anon_sym_decltype] = ACTIONS(2248),
    [sym_virtual] = ACTIONS(2248),
    [anon_sym_explicit] = ACTIONS(2248),
    [anon_sym_typename] = ACTIONS(2248),
    [anon_sym_template] = ACTIONS(2248),
    [anon_sym_operator] = ACTIONS(2248),
    [anon_sym_friend] = ACTIONS(2248),
    [anon_sym_public] = ACTIONS(2248),
    [anon_sym_private] = ACTIONS(2248),
    [anon_sym_protected] = ACTIONS(2248),
    [anon_sym_using] = ACTIONS(2248),
    [anon_sym_static_assert] = ACTIONS(2248),
    [anon_sym_precise] = ACTIONS(2248),
    [anon_sym_shared] = ACTIONS(2248),
    [anon_sym_groupshared] = ACTIONS(2248),
    [anon_sym_uniform] = ACTIONS(2248),
    [anon_sym_row_major] = ACTIONS(2248),
    [anon_sym_column_major] = ACTIONS(2248),
    [anon_sym_globallycoherent] = ACTIONS(2248),
    [anon_sym_centroid] = ACTIONS(2248),
    [anon_sym_noperspective] = ACTIONS(2248),
    [anon_sym_nointerpolation] = ACTIONS(2248),
    [anon_sym_sample] = ACTIONS(2248),
    [anon_sym_linear] = ACTIONS(2248),
    [anon_sym_snorm] = ACTIONS(2248),
    [anon_sym_unorm] = ACTIONS(2248),
    [anon_sym_point] = ACTIONS(2248),
    [anon_sym_line] = ACTIONS(2248),
    [anon_sym_triangleadj] = ACTIONS(2248),
    [anon_sym_lineadj] = ACTIONS(2248),
    [anon_sym_triangle] = ACTIONS(2248),
  },
  [1915] = {
    [sym_identifier] = ACTIONS(2444),
    [aux_sym_preproc_def_token1] = ACTIONS(2444),
    [aux_sym_preproc_if_token1] = ACTIONS(2444),
    [aux_sym_preproc_if_token2] = ACTIONS(2444),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2444),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2444),
    [aux_sym_preproc_else_token1] = ACTIONS(2444),
    [aux_sym_preproc_elif_token1] = ACTIONS(2444),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2444),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2444),
    [sym_preproc_directive] = ACTIONS(2444),
    [anon_sym_LPAREN2] = ACTIONS(2446),
    [anon_sym_TILDE] = ACTIONS(2446),
    [anon_sym_STAR] = ACTIONS(2446),
    [anon_sym_AMP_AMP] = ACTIONS(2446),
    [anon_sym_AMP] = ACTIONS(2444),
    [anon_sym___extension__] = ACTIONS(2444),
    [anon_sym_typedef] = ACTIONS(2444),
    [anon_sym_in] = ACTIONS(2444),
    [anon_sym_out] = ACTIONS(2444),
    [anon_sym_inout] = ACTIONS(2444),
    [anon_sym_extern] = ACTIONS(2444),
    [anon_sym___attribute__] = ACTIONS(2444),
    [anon_sym_COLON_COLON] = ACTIONS(2446),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2446),
    [anon_sym___declspec] = ACTIONS(2444),
    [anon_sym___based] = ACTIONS(2444),
    [anon_sym_signed] = ACTIONS(2444),
    [anon_sym_unsigned] = ACTIONS(2444),
    [anon_sym_long] = ACTIONS(2444),
    [anon_sym_short] = ACTIONS(2444),
    [anon_sym_LBRACK] = ACTIONS(2444),
    [anon_sym_static] = ACTIONS(2444),
    [anon_sym_register] = ACTIONS(2444),
    [anon_sym_inline] = ACTIONS(2444),
    [anon_sym___inline] = ACTIONS(2444),
    [anon_sym___inline__] = ACTIONS(2444),
    [anon_sym___forceinline] = ACTIONS(2444),
    [anon_sym_thread_local] = ACTIONS(2444),
    [anon_sym___thread] = ACTIONS(2444),
    [anon_sym_const] = ACTIONS(2444),
    [anon_sym_constexpr] = ACTIONS(2444),
    [anon_sym_volatile] = ACTIONS(2444),
    [anon_sym_restrict] = ACTIONS(2444),
    [anon_sym___restrict__] = ACTIONS(2444),
    [anon_sym__Atomic] = ACTIONS(2444),
    [anon_sym__Noreturn] = ACTIONS(2444),
    [anon_sym_noreturn] = ACTIONS(2444),
    [anon_sym_mutable] = ACTIONS(2444),
    [anon_sym_constinit] = ACTIONS(2444),
    [anon_sym_consteval] = ACTIONS(2444),
    [anon_sym_alignas] = ACTIONS(2444),
    [anon_sym__Alignas] = ACTIONS(2444),
    [sym_primitive_type] = ACTIONS(2444),
    [anon_sym_enum] = ACTIONS(2444),
    [anon_sym_class] = ACTIONS(2444),
    [anon_sym_struct] = ACTIONS(2444),
    [anon_sym_union] = ACTIONS(2444),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2444),
    [anon_sym_decltype] = ACTIONS(2444),
    [sym_virtual] = ACTIONS(2444),
    [anon_sym_explicit] = ACTIONS(2444),
    [anon_sym_typename] = ACTIONS(2444),
    [anon_sym_template] = ACTIONS(2444),
    [anon_sym_operator] = ACTIONS(2444),
    [anon_sym_friend] = ACTIONS(2444),
    [anon_sym_public] = ACTIONS(2444),
    [anon_sym_private] = ACTIONS(2444),
    [anon_sym_protected] = ACTIONS(2444),
    [anon_sym_using] = ACTIONS(2444),
    [anon_sym_static_assert] = ACTIONS(2444),
    [anon_sym_precise] = ACTIONS(2444),
    [anon_sym_shared] = ACTIONS(2444),
    [anon_sym_groupshared] = ACTIONS(2444),
    [anon_sym_uniform] = ACTIONS(2444),
    [anon_sym_row_major] = ACTIONS(2444),
    [anon_sym_column_major] = ACTIONS(2444),
    [anon_sym_globallycoherent] = ACTIONS(2444),
    [anon_sym_centroid] = ACTIONS(2444),
    [anon_sym_noperspective] = ACTIONS(2444),
    [anon_sym_nointerpolation] = ACTIONS(2444),
    [anon_sym_sample] = ACTIONS(2444),
    [anon_sym_linear] = ACTIONS(2444),
    [anon_sym_snorm] = ACTIONS(2444),
    [anon_sym_unorm] = ACTIONS(2444),
    [anon_sym_point] = ACTIONS(2444),
    [anon_sym_line] = ACTIONS(2444),
    [anon_sym_triangleadj] = ACTIONS(2444),
    [anon_sym_lineadj] = ACTIONS(2444),
    [anon_sym_triangle] = ACTIONS(2444),
  },
  [1916] = {
    [sym_identifier] = ACTIONS(2138),
    [aux_sym_preproc_def_token1] = ACTIONS(2138),
    [aux_sym_preproc_if_token1] = ACTIONS(2138),
    [aux_sym_preproc_if_token2] = ACTIONS(2138),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2138),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2138),
    [aux_sym_preproc_else_token1] = ACTIONS(2138),
    [aux_sym_preproc_elif_token1] = ACTIONS(2138),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2138),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2138),
    [sym_preproc_directive] = ACTIONS(2138),
    [anon_sym_LPAREN2] = ACTIONS(2140),
    [anon_sym_TILDE] = ACTIONS(2140),
    [anon_sym_STAR] = ACTIONS(2140),
    [anon_sym_AMP_AMP] = ACTIONS(2140),
    [anon_sym_AMP] = ACTIONS(2138),
    [anon_sym___extension__] = ACTIONS(2138),
    [anon_sym_typedef] = ACTIONS(2138),
    [anon_sym_in] = ACTIONS(2138),
    [anon_sym_out] = ACTIONS(2138),
    [anon_sym_inout] = ACTIONS(2138),
    [anon_sym_extern] = ACTIONS(2138),
    [anon_sym___attribute__] = ACTIONS(2138),
    [anon_sym_COLON_COLON] = ACTIONS(2140),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2140),
    [anon_sym___declspec] = ACTIONS(2138),
    [anon_sym___based] = ACTIONS(2138),
    [anon_sym_signed] = ACTIONS(2138),
    [anon_sym_unsigned] = ACTIONS(2138),
    [anon_sym_long] = ACTIONS(2138),
    [anon_sym_short] = ACTIONS(2138),
    [anon_sym_LBRACK] = ACTIONS(2138),
    [anon_sym_static] = ACTIONS(2138),
    [anon_sym_register] = ACTIONS(2138),
    [anon_sym_inline] = ACTIONS(2138),
    [anon_sym___inline] = ACTIONS(2138),
    [anon_sym___inline__] = ACTIONS(2138),
    [anon_sym___forceinline] = ACTIONS(2138),
    [anon_sym_thread_local] = ACTIONS(2138),
    [anon_sym___thread] = ACTIONS(2138),
    [anon_sym_const] = ACTIONS(2138),
    [anon_sym_constexpr] = ACTIONS(2138),
    [anon_sym_volatile] = ACTIONS(2138),
    [anon_sym_restrict] = ACTIONS(2138),
    [anon_sym___restrict__] = ACTIONS(2138),
    [anon_sym__Atomic] = ACTIONS(2138),
    [anon_sym__Noreturn] = ACTIONS(2138),
    [anon_sym_noreturn] = ACTIONS(2138),
    [anon_sym_mutable] = ACTIONS(2138),
    [anon_sym_constinit] = ACTIONS(2138),
    [anon_sym_consteval] = ACTIONS(2138),
    [anon_sym_alignas] = ACTIONS(2138),
    [anon_sym__Alignas] = ACTIONS(2138),
    [sym_primitive_type] = ACTIONS(2138),
    [anon_sym_enum] = ACTIONS(2138),
    [anon_sym_class] = ACTIONS(2138),
    [anon_sym_struct] = ACTIONS(2138),
    [anon_sym_union] = ACTIONS(2138),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2138),
    [anon_sym_decltype] = ACTIONS(2138),
    [sym_virtual] = ACTIONS(2138),
    [anon_sym_explicit] = ACTIONS(2138),
    [anon_sym_typename] = ACTIONS(2138),
    [anon_sym_template] = ACTIONS(2138),
    [anon_sym_operator] = ACTIONS(2138),
    [anon_sym_friend] = ACTIONS(2138),
    [anon_sym_public] = ACTIONS(2138),
    [anon_sym_private] = ACTIONS(2138),
    [anon_sym_protected] = ACTIONS(2138),
    [anon_sym_using] = ACTIONS(2138),
    [anon_sym_static_assert] = ACTIONS(2138),
    [anon_sym_precise] = ACTIONS(2138),
    [anon_sym_shared] = ACTIONS(2138),
    [anon_sym_groupshared] = ACTIONS(2138),
    [anon_sym_uniform] = ACTIONS(2138),
    [anon_sym_row_major] = ACTIONS(2138),
    [anon_sym_column_major] = ACTIONS(2138),
    [anon_sym_globallycoherent] = ACTIONS(2138),
    [anon_sym_centroid] = ACTIONS(2138),
    [anon_sym_noperspective] = ACTIONS(2138),
    [anon_sym_nointerpolation] = ACTIONS(2138),
    [anon_sym_sample] = ACTIONS(2138),
    [anon_sym_linear] = ACTIONS(2138),
    [anon_sym_snorm] = ACTIONS(2138),
    [anon_sym_unorm] = ACTIONS(2138),
    [anon_sym_point] = ACTIONS(2138),
    [anon_sym_line] = ACTIONS(2138),
    [anon_sym_triangleadj] = ACTIONS(2138),
    [anon_sym_lineadj] = ACTIONS(2138),
    [anon_sym_triangle] = ACTIONS(2138),
  },
  [1917] = {
    [sym_identifier] = ACTIONS(2561),
    [aux_sym_preproc_def_token1] = ACTIONS(2561),
    [aux_sym_preproc_if_token1] = ACTIONS(2561),
    [aux_sym_preproc_if_token2] = ACTIONS(2561),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2561),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2561),
    [aux_sym_preproc_else_token1] = ACTIONS(2561),
    [aux_sym_preproc_elif_token1] = ACTIONS(2561),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2561),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2561),
    [sym_preproc_directive] = ACTIONS(2561),
    [anon_sym_LPAREN2] = ACTIONS(2563),
    [anon_sym_TILDE] = ACTIONS(2563),
    [anon_sym_STAR] = ACTIONS(2563),
    [anon_sym_AMP_AMP] = ACTIONS(2563),
    [anon_sym_AMP] = ACTIONS(2561),
    [anon_sym___extension__] = ACTIONS(2561),
    [anon_sym_typedef] = ACTIONS(2561),
    [anon_sym_in] = ACTIONS(2561),
    [anon_sym_out] = ACTIONS(2561),
    [anon_sym_inout] = ACTIONS(2561),
    [anon_sym_extern] = ACTIONS(2561),
    [anon_sym___attribute__] = ACTIONS(2561),
    [anon_sym_COLON_COLON] = ACTIONS(2563),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2563),
    [anon_sym___declspec] = ACTIONS(2561),
    [anon_sym___based] = ACTIONS(2561),
    [anon_sym_signed] = ACTIONS(2561),
    [anon_sym_unsigned] = ACTIONS(2561),
    [anon_sym_long] = ACTIONS(2561),
    [anon_sym_short] = ACTIONS(2561),
    [anon_sym_LBRACK] = ACTIONS(2561),
    [anon_sym_static] = ACTIONS(2561),
    [anon_sym_register] = ACTIONS(2561),
    [anon_sym_inline] = ACTIONS(2561),
    [anon_sym___inline] = ACTIONS(2561),
    [anon_sym___inline__] = ACTIONS(2561),
    [anon_sym___forceinline] = ACTIONS(2561),
    [anon_sym_thread_local] = ACTIONS(2561),
    [anon_sym___thread] = ACTIONS(2561),
    [anon_sym_const] = ACTIONS(2561),
    [anon_sym_constexpr] = ACTIONS(2561),
    [anon_sym_volatile] = ACTIONS(2561),
    [anon_sym_restrict] = ACTIONS(2561),
    [anon_sym___restrict__] = ACTIONS(2561),
    [anon_sym__Atomic] = ACTIONS(2561),
    [anon_sym__Noreturn] = ACTIONS(2561),
    [anon_sym_noreturn] = ACTIONS(2561),
    [anon_sym_mutable] = ACTIONS(2561),
    [anon_sym_constinit] = ACTIONS(2561),
    [anon_sym_consteval] = ACTIONS(2561),
    [anon_sym_alignas] = ACTIONS(2561),
    [anon_sym__Alignas] = ACTIONS(2561),
    [sym_primitive_type] = ACTIONS(2561),
    [anon_sym_enum] = ACTIONS(2561),
    [anon_sym_class] = ACTIONS(2561),
    [anon_sym_struct] = ACTIONS(2561),
    [anon_sym_union] = ACTIONS(2561),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2561),
    [anon_sym_decltype] = ACTIONS(2561),
    [sym_virtual] = ACTIONS(2561),
    [anon_sym_explicit] = ACTIONS(2561),
    [anon_sym_typename] = ACTIONS(2561),
    [anon_sym_template] = ACTIONS(2561),
    [anon_sym_operator] = ACTIONS(2561),
    [anon_sym_friend] = ACTIONS(2561),
    [anon_sym_public] = ACTIONS(2561),
    [anon_sym_private] = ACTIONS(2561),
    [anon_sym_protected] = ACTIONS(2561),
    [anon_sym_using] = ACTIONS(2561),
    [anon_sym_static_assert] = ACTIONS(2561),
    [anon_sym_precise] = ACTIONS(2561),
    [anon_sym_shared] = ACTIONS(2561),
    [anon_sym_groupshared] = ACTIONS(2561),
    [anon_sym_uniform] = ACTIONS(2561),
    [anon_sym_row_major] = ACTIONS(2561),
    [anon_sym_column_major] = ACTIONS(2561),
    [anon_sym_globallycoherent] = ACTIONS(2561),
    [anon_sym_centroid] = ACTIONS(2561),
    [anon_sym_noperspective] = ACTIONS(2561),
    [anon_sym_nointerpolation] = ACTIONS(2561),
    [anon_sym_sample] = ACTIONS(2561),
    [anon_sym_linear] = ACTIONS(2561),
    [anon_sym_snorm] = ACTIONS(2561),
    [anon_sym_unorm] = ACTIONS(2561),
    [anon_sym_point] = ACTIONS(2561),
    [anon_sym_line] = ACTIONS(2561),
    [anon_sym_triangleadj] = ACTIONS(2561),
    [anon_sym_lineadj] = ACTIONS(2561),
    [anon_sym_triangle] = ACTIONS(2561),
  },
  [1918] = {
    [sym_identifier] = ACTIONS(2432),
    [aux_sym_preproc_def_token1] = ACTIONS(2432),
    [aux_sym_preproc_if_token1] = ACTIONS(2432),
    [aux_sym_preproc_if_token2] = ACTIONS(2432),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2432),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2432),
    [aux_sym_preproc_else_token1] = ACTIONS(2432),
    [aux_sym_preproc_elif_token1] = ACTIONS(2432),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2432),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2432),
    [sym_preproc_directive] = ACTIONS(2432),
    [anon_sym_LPAREN2] = ACTIONS(2434),
    [anon_sym_TILDE] = ACTIONS(2434),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_AMP_AMP] = ACTIONS(2434),
    [anon_sym_AMP] = ACTIONS(2432),
    [anon_sym___extension__] = ACTIONS(2432),
    [anon_sym_typedef] = ACTIONS(2432),
    [anon_sym_in] = ACTIONS(2432),
    [anon_sym_out] = ACTIONS(2432),
    [anon_sym_inout] = ACTIONS(2432),
    [anon_sym_extern] = ACTIONS(2432),
    [anon_sym___attribute__] = ACTIONS(2432),
    [anon_sym_COLON_COLON] = ACTIONS(2434),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2434),
    [anon_sym___declspec] = ACTIONS(2432),
    [anon_sym___based] = ACTIONS(2432),
    [anon_sym_signed] = ACTIONS(2432),
    [anon_sym_unsigned] = ACTIONS(2432),
    [anon_sym_long] = ACTIONS(2432),
    [anon_sym_short] = ACTIONS(2432),
    [anon_sym_LBRACK] = ACTIONS(2432),
    [anon_sym_static] = ACTIONS(2432),
    [anon_sym_register] = ACTIONS(2432),
    [anon_sym_inline] = ACTIONS(2432),
    [anon_sym___inline] = ACTIONS(2432),
    [anon_sym___inline__] = ACTIONS(2432),
    [anon_sym___forceinline] = ACTIONS(2432),
    [anon_sym_thread_local] = ACTIONS(2432),
    [anon_sym___thread] = ACTIONS(2432),
    [anon_sym_const] = ACTIONS(2432),
    [anon_sym_constexpr] = ACTIONS(2432),
    [anon_sym_volatile] = ACTIONS(2432),
    [anon_sym_restrict] = ACTIONS(2432),
    [anon_sym___restrict__] = ACTIONS(2432),
    [anon_sym__Atomic] = ACTIONS(2432),
    [anon_sym__Noreturn] = ACTIONS(2432),
    [anon_sym_noreturn] = ACTIONS(2432),
    [anon_sym_mutable] = ACTIONS(2432),
    [anon_sym_constinit] = ACTIONS(2432),
    [anon_sym_consteval] = ACTIONS(2432),
    [anon_sym_alignas] = ACTIONS(2432),
    [anon_sym__Alignas] = ACTIONS(2432),
    [sym_primitive_type] = ACTIONS(2432),
    [anon_sym_enum] = ACTIONS(2432),
    [anon_sym_class] = ACTIONS(2432),
    [anon_sym_struct] = ACTIONS(2432),
    [anon_sym_union] = ACTIONS(2432),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2432),
    [anon_sym_decltype] = ACTIONS(2432),
    [sym_virtual] = ACTIONS(2432),
    [anon_sym_explicit] = ACTIONS(2432),
    [anon_sym_typename] = ACTIONS(2432),
    [anon_sym_template] = ACTIONS(2432),
    [anon_sym_operator] = ACTIONS(2432),
    [anon_sym_friend] = ACTIONS(2432),
    [anon_sym_public] = ACTIONS(2432),
    [anon_sym_private] = ACTIONS(2432),
    [anon_sym_protected] = ACTIONS(2432),
    [anon_sym_using] = ACTIONS(2432),
    [anon_sym_static_assert] = ACTIONS(2432),
    [anon_sym_precise] = ACTIONS(2432),
    [anon_sym_shared] = ACTIONS(2432),
    [anon_sym_groupshared] = ACTIONS(2432),
    [anon_sym_uniform] = ACTIONS(2432),
    [anon_sym_row_major] = ACTIONS(2432),
    [anon_sym_column_major] = ACTIONS(2432),
    [anon_sym_globallycoherent] = ACTIONS(2432),
    [anon_sym_centroid] = ACTIONS(2432),
    [anon_sym_noperspective] = ACTIONS(2432),
    [anon_sym_nointerpolation] = ACTIONS(2432),
    [anon_sym_sample] = ACTIONS(2432),
    [anon_sym_linear] = ACTIONS(2432),
    [anon_sym_snorm] = ACTIONS(2432),
    [anon_sym_unorm] = ACTIONS(2432),
    [anon_sym_point] = ACTIONS(2432),
    [anon_sym_line] = ACTIONS(2432),
    [anon_sym_triangleadj] = ACTIONS(2432),
    [anon_sym_lineadj] = ACTIONS(2432),
    [anon_sym_triangle] = ACTIONS(2432),
  },
  [1919] = {
    [sym_identifier] = ACTIONS(2404),
    [aux_sym_preproc_def_token1] = ACTIONS(2404),
    [aux_sym_preproc_if_token1] = ACTIONS(2404),
    [aux_sym_preproc_if_token2] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2404),
    [aux_sym_preproc_else_token1] = ACTIONS(2404),
    [aux_sym_preproc_elif_token1] = ACTIONS(2404),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2404),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2404),
    [sym_preproc_directive] = ACTIONS(2404),
    [anon_sym_LPAREN2] = ACTIONS(2406),
    [anon_sym_TILDE] = ACTIONS(2406),
    [anon_sym_STAR] = ACTIONS(2406),
    [anon_sym_AMP_AMP] = ACTIONS(2406),
    [anon_sym_AMP] = ACTIONS(2404),
    [anon_sym___extension__] = ACTIONS(2404),
    [anon_sym_typedef] = ACTIONS(2404),
    [anon_sym_in] = ACTIONS(2404),
    [anon_sym_out] = ACTIONS(2404),
    [anon_sym_inout] = ACTIONS(2404),
    [anon_sym_extern] = ACTIONS(2404),
    [anon_sym___attribute__] = ACTIONS(2404),
    [anon_sym_COLON_COLON] = ACTIONS(2406),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2406),
    [anon_sym___declspec] = ACTIONS(2404),
    [anon_sym___based] = ACTIONS(2404),
    [anon_sym_signed] = ACTIONS(2404),
    [anon_sym_unsigned] = ACTIONS(2404),
    [anon_sym_long] = ACTIONS(2404),
    [anon_sym_short] = ACTIONS(2404),
    [anon_sym_LBRACK] = ACTIONS(2404),
    [anon_sym_static] = ACTIONS(2404),
    [anon_sym_register] = ACTIONS(2404),
    [anon_sym_inline] = ACTIONS(2404),
    [anon_sym___inline] = ACTIONS(2404),
    [anon_sym___inline__] = ACTIONS(2404),
    [anon_sym___forceinline] = ACTIONS(2404),
    [anon_sym_thread_local] = ACTIONS(2404),
    [anon_sym___thread] = ACTIONS(2404),
    [anon_sym_const] = ACTIONS(2404),
    [anon_sym_constexpr] = ACTIONS(2404),
    [anon_sym_volatile] = ACTIONS(2404),
    [anon_sym_restrict] = ACTIONS(2404),
    [anon_sym___restrict__] = ACTIONS(2404),
    [anon_sym__Atomic] = ACTIONS(2404),
    [anon_sym__Noreturn] = ACTIONS(2404),
    [anon_sym_noreturn] = ACTIONS(2404),
    [anon_sym_mutable] = ACTIONS(2404),
    [anon_sym_constinit] = ACTIONS(2404),
    [anon_sym_consteval] = ACTIONS(2404),
    [anon_sym_alignas] = ACTIONS(2404),
    [anon_sym__Alignas] = ACTIONS(2404),
    [sym_primitive_type] = ACTIONS(2404),
    [anon_sym_enum] = ACTIONS(2404),
    [anon_sym_class] = ACTIONS(2404),
    [anon_sym_struct] = ACTIONS(2404),
    [anon_sym_union] = ACTIONS(2404),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2404),
    [anon_sym_decltype] = ACTIONS(2404),
    [sym_virtual] = ACTIONS(2404),
    [anon_sym_explicit] = ACTIONS(2404),
    [anon_sym_typename] = ACTIONS(2404),
    [anon_sym_template] = ACTIONS(2404),
    [anon_sym_operator] = ACTIONS(2404),
    [anon_sym_friend] = ACTIONS(2404),
    [anon_sym_public] = ACTIONS(2404),
    [anon_sym_private] = ACTIONS(2404),
    [anon_sym_protected] = ACTIONS(2404),
    [anon_sym_using] = ACTIONS(2404),
    [anon_sym_static_assert] = ACTIONS(2404),
    [anon_sym_precise] = ACTIONS(2404),
    [anon_sym_shared] = ACTIONS(2404),
    [anon_sym_groupshared] = ACTIONS(2404),
    [anon_sym_uniform] = ACTIONS(2404),
    [anon_sym_row_major] = ACTIONS(2404),
    [anon_sym_column_major] = ACTIONS(2404),
    [anon_sym_globallycoherent] = ACTIONS(2404),
    [anon_sym_centroid] = ACTIONS(2404),
    [anon_sym_noperspective] = ACTIONS(2404),
    [anon_sym_nointerpolation] = ACTIONS(2404),
    [anon_sym_sample] = ACTIONS(2404),
    [anon_sym_linear] = ACTIONS(2404),
    [anon_sym_snorm] = ACTIONS(2404),
    [anon_sym_unorm] = ACTIONS(2404),
    [anon_sym_point] = ACTIONS(2404),
    [anon_sym_line] = ACTIONS(2404),
    [anon_sym_triangleadj] = ACTIONS(2404),
    [anon_sym_lineadj] = ACTIONS(2404),
    [anon_sym_triangle] = ACTIONS(2404),
  },
  [1920] = {
    [sym_identifier] = ACTIONS(5101),
    [aux_sym_preproc_def_token1] = ACTIONS(5101),
    [aux_sym_preproc_if_token1] = ACTIONS(5101),
    [aux_sym_preproc_if_token2] = ACTIONS(5101),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5101),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5101),
    [aux_sym_preproc_else_token1] = ACTIONS(5101),
    [aux_sym_preproc_elif_token1] = ACTIONS(5101),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5101),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5101),
    [sym_preproc_directive] = ACTIONS(5101),
    [anon_sym_LPAREN2] = ACTIONS(5103),
    [anon_sym_TILDE] = ACTIONS(5103),
    [anon_sym_STAR] = ACTIONS(5103),
    [anon_sym_AMP_AMP] = ACTIONS(5103),
    [anon_sym_AMP] = ACTIONS(5101),
    [anon_sym___extension__] = ACTIONS(5101),
    [anon_sym_typedef] = ACTIONS(5101),
    [anon_sym_in] = ACTIONS(5101),
    [anon_sym_out] = ACTIONS(5101),
    [anon_sym_inout] = ACTIONS(5101),
    [anon_sym_extern] = ACTIONS(5101),
    [anon_sym___attribute__] = ACTIONS(5101),
    [anon_sym_COLON_COLON] = ACTIONS(5103),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5103),
    [anon_sym___declspec] = ACTIONS(5101),
    [anon_sym___based] = ACTIONS(5101),
    [anon_sym_signed] = ACTIONS(5101),
    [anon_sym_unsigned] = ACTIONS(5101),
    [anon_sym_long] = ACTIONS(5101),
    [anon_sym_short] = ACTIONS(5101),
    [anon_sym_LBRACK] = ACTIONS(5101),
    [anon_sym_static] = ACTIONS(5101),
    [anon_sym_register] = ACTIONS(5101),
    [anon_sym_inline] = ACTIONS(5101),
    [anon_sym___inline] = ACTIONS(5101),
    [anon_sym___inline__] = ACTIONS(5101),
    [anon_sym___forceinline] = ACTIONS(5101),
    [anon_sym_thread_local] = ACTIONS(5101),
    [anon_sym___thread] = ACTIONS(5101),
    [anon_sym_const] = ACTIONS(5101),
    [anon_sym_constexpr] = ACTIONS(5101),
    [anon_sym_volatile] = ACTIONS(5101),
    [anon_sym_restrict] = ACTIONS(5101),
    [anon_sym___restrict__] = ACTIONS(5101),
    [anon_sym__Atomic] = ACTIONS(5101),
    [anon_sym__Noreturn] = ACTIONS(5101),
    [anon_sym_noreturn] = ACTIONS(5101),
    [anon_sym_mutable] = ACTIONS(5101),
    [anon_sym_constinit] = ACTIONS(5101),
    [anon_sym_consteval] = ACTIONS(5101),
    [anon_sym_alignas] = ACTIONS(5101),
    [anon_sym__Alignas] = ACTIONS(5101),
    [sym_primitive_type] = ACTIONS(5101),
    [anon_sym_enum] = ACTIONS(5101),
    [anon_sym_class] = ACTIONS(5101),
    [anon_sym_struct] = ACTIONS(5101),
    [anon_sym_union] = ACTIONS(5101),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5101),
    [anon_sym_decltype] = ACTIONS(5101),
    [sym_virtual] = ACTIONS(5101),
    [anon_sym_explicit] = ACTIONS(5101),
    [anon_sym_typename] = ACTIONS(5101),
    [anon_sym_template] = ACTIONS(5101),
    [anon_sym_operator] = ACTIONS(5101),
    [anon_sym_friend] = ACTIONS(5101),
    [anon_sym_public] = ACTIONS(5101),
    [anon_sym_private] = ACTIONS(5101),
    [anon_sym_protected] = ACTIONS(5101),
    [anon_sym_using] = ACTIONS(5101),
    [anon_sym_static_assert] = ACTIONS(5101),
    [anon_sym_precise] = ACTIONS(5101),
    [anon_sym_shared] = ACTIONS(5101),
    [anon_sym_groupshared] = ACTIONS(5101),
    [anon_sym_uniform] = ACTIONS(5101),
    [anon_sym_row_major] = ACTIONS(5101),
    [anon_sym_column_major] = ACTIONS(5101),
    [anon_sym_globallycoherent] = ACTIONS(5101),
    [anon_sym_centroid] = ACTIONS(5101),
    [anon_sym_noperspective] = ACTIONS(5101),
    [anon_sym_nointerpolation] = ACTIONS(5101),
    [anon_sym_sample] = ACTIONS(5101),
    [anon_sym_linear] = ACTIONS(5101),
    [anon_sym_snorm] = ACTIONS(5101),
    [anon_sym_unorm] = ACTIONS(5101),
    [anon_sym_point] = ACTIONS(5101),
    [anon_sym_line] = ACTIONS(5101),
    [anon_sym_triangleadj] = ACTIONS(5101),
    [anon_sym_lineadj] = ACTIONS(5101),
    [anon_sym_triangle] = ACTIONS(5101),
  },
  [1921] = {
    [sym_identifier] = ACTIONS(2428),
    [aux_sym_preproc_def_token1] = ACTIONS(2428),
    [aux_sym_preproc_if_token1] = ACTIONS(2428),
    [aux_sym_preproc_if_token2] = ACTIONS(2428),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2428),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2428),
    [aux_sym_preproc_else_token1] = ACTIONS(2428),
    [aux_sym_preproc_elif_token1] = ACTIONS(2428),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2428),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2428),
    [sym_preproc_directive] = ACTIONS(2428),
    [anon_sym_LPAREN2] = ACTIONS(2430),
    [anon_sym_TILDE] = ACTIONS(2430),
    [anon_sym_STAR] = ACTIONS(2430),
    [anon_sym_AMP_AMP] = ACTIONS(2430),
    [anon_sym_AMP] = ACTIONS(2428),
    [anon_sym___extension__] = ACTIONS(2428),
    [anon_sym_typedef] = ACTIONS(2428),
    [anon_sym_in] = ACTIONS(2428),
    [anon_sym_out] = ACTIONS(2428),
    [anon_sym_inout] = ACTIONS(2428),
    [anon_sym_extern] = ACTIONS(2428),
    [anon_sym___attribute__] = ACTIONS(2428),
    [anon_sym_COLON_COLON] = ACTIONS(2430),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2430),
    [anon_sym___declspec] = ACTIONS(2428),
    [anon_sym___based] = ACTIONS(2428),
    [anon_sym_signed] = ACTIONS(2428),
    [anon_sym_unsigned] = ACTIONS(2428),
    [anon_sym_long] = ACTIONS(2428),
    [anon_sym_short] = ACTIONS(2428),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [anon_sym_static] = ACTIONS(2428),
    [anon_sym_register] = ACTIONS(2428),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym___inline] = ACTIONS(2428),
    [anon_sym___inline__] = ACTIONS(2428),
    [anon_sym___forceinline] = ACTIONS(2428),
    [anon_sym_thread_local] = ACTIONS(2428),
    [anon_sym___thread] = ACTIONS(2428),
    [anon_sym_const] = ACTIONS(2428),
    [anon_sym_constexpr] = ACTIONS(2428),
    [anon_sym_volatile] = ACTIONS(2428),
    [anon_sym_restrict] = ACTIONS(2428),
    [anon_sym___restrict__] = ACTIONS(2428),
    [anon_sym__Atomic] = ACTIONS(2428),
    [anon_sym__Noreturn] = ACTIONS(2428),
    [anon_sym_noreturn] = ACTIONS(2428),
    [anon_sym_mutable] = ACTIONS(2428),
    [anon_sym_constinit] = ACTIONS(2428),
    [anon_sym_consteval] = ACTIONS(2428),
    [anon_sym_alignas] = ACTIONS(2428),
    [anon_sym__Alignas] = ACTIONS(2428),
    [sym_primitive_type] = ACTIONS(2428),
    [anon_sym_enum] = ACTIONS(2428),
    [anon_sym_class] = ACTIONS(2428),
    [anon_sym_struct] = ACTIONS(2428),
    [anon_sym_union] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2428),
    [anon_sym_decltype] = ACTIONS(2428),
    [sym_virtual] = ACTIONS(2428),
    [anon_sym_explicit] = ACTIONS(2428),
    [anon_sym_typename] = ACTIONS(2428),
    [anon_sym_template] = ACTIONS(2428),
    [anon_sym_operator] = ACTIONS(2428),
    [anon_sym_friend] = ACTIONS(2428),
    [anon_sym_public] = ACTIONS(2428),
    [anon_sym_private] = ACTIONS(2428),
    [anon_sym_protected] = ACTIONS(2428),
    [anon_sym_using] = ACTIONS(2428),
    [anon_sym_static_assert] = ACTIONS(2428),
    [anon_sym_precise] = ACTIONS(2428),
    [anon_sym_shared] = ACTIONS(2428),
    [anon_sym_groupshared] = ACTIONS(2428),
    [anon_sym_uniform] = ACTIONS(2428),
    [anon_sym_row_major] = ACTIONS(2428),
    [anon_sym_column_major] = ACTIONS(2428),
    [anon_sym_globallycoherent] = ACTIONS(2428),
    [anon_sym_centroid] = ACTIONS(2428),
    [anon_sym_noperspective] = ACTIONS(2428),
    [anon_sym_nointerpolation] = ACTIONS(2428),
    [anon_sym_sample] = ACTIONS(2428),
    [anon_sym_linear] = ACTIONS(2428),
    [anon_sym_snorm] = ACTIONS(2428),
    [anon_sym_unorm] = ACTIONS(2428),
    [anon_sym_point] = ACTIONS(2428),
    [anon_sym_line] = ACTIONS(2428),
    [anon_sym_triangleadj] = ACTIONS(2428),
    [anon_sym_lineadj] = ACTIONS(2428),
    [anon_sym_triangle] = ACTIONS(2428),
  },
  [1922] = {
    [sym_identifier] = ACTIONS(2420),
    [aux_sym_preproc_def_token1] = ACTIONS(2420),
    [aux_sym_preproc_if_token1] = ACTIONS(2420),
    [aux_sym_preproc_if_token2] = ACTIONS(2420),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2420),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2420),
    [aux_sym_preproc_else_token1] = ACTIONS(2420),
    [aux_sym_preproc_elif_token1] = ACTIONS(2420),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2420),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2420),
    [sym_preproc_directive] = ACTIONS(2420),
    [anon_sym_LPAREN2] = ACTIONS(2422),
    [anon_sym_TILDE] = ACTIONS(2422),
    [anon_sym_STAR] = ACTIONS(2422),
    [anon_sym_AMP_AMP] = ACTIONS(2422),
    [anon_sym_AMP] = ACTIONS(2420),
    [anon_sym___extension__] = ACTIONS(2420),
    [anon_sym_typedef] = ACTIONS(2420),
    [anon_sym_in] = ACTIONS(2420),
    [anon_sym_out] = ACTIONS(2420),
    [anon_sym_inout] = ACTIONS(2420),
    [anon_sym_extern] = ACTIONS(2420),
    [anon_sym___attribute__] = ACTIONS(2420),
    [anon_sym_COLON_COLON] = ACTIONS(2422),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2422),
    [anon_sym___declspec] = ACTIONS(2420),
    [anon_sym___based] = ACTIONS(2420),
    [anon_sym_signed] = ACTIONS(2420),
    [anon_sym_unsigned] = ACTIONS(2420),
    [anon_sym_long] = ACTIONS(2420),
    [anon_sym_short] = ACTIONS(2420),
    [anon_sym_LBRACK] = ACTIONS(2420),
    [anon_sym_static] = ACTIONS(2420),
    [anon_sym_register] = ACTIONS(2420),
    [anon_sym_inline] = ACTIONS(2420),
    [anon_sym___inline] = ACTIONS(2420),
    [anon_sym___inline__] = ACTIONS(2420),
    [anon_sym___forceinline] = ACTIONS(2420),
    [anon_sym_thread_local] = ACTIONS(2420),
    [anon_sym___thread] = ACTIONS(2420),
    [anon_sym_const] = ACTIONS(2420),
    [anon_sym_constexpr] = ACTIONS(2420),
    [anon_sym_volatile] = ACTIONS(2420),
    [anon_sym_restrict] = ACTIONS(2420),
    [anon_sym___restrict__] = ACTIONS(2420),
    [anon_sym__Atomic] = ACTIONS(2420),
    [anon_sym__Noreturn] = ACTIONS(2420),
    [anon_sym_noreturn] = ACTIONS(2420),
    [anon_sym_mutable] = ACTIONS(2420),
    [anon_sym_constinit] = ACTIONS(2420),
    [anon_sym_consteval] = ACTIONS(2420),
    [anon_sym_alignas] = ACTIONS(2420),
    [anon_sym__Alignas] = ACTIONS(2420),
    [sym_primitive_type] = ACTIONS(2420),
    [anon_sym_enum] = ACTIONS(2420),
    [anon_sym_class] = ACTIONS(2420),
    [anon_sym_struct] = ACTIONS(2420),
    [anon_sym_union] = ACTIONS(2420),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2420),
    [anon_sym_decltype] = ACTIONS(2420),
    [sym_virtual] = ACTIONS(2420),
    [anon_sym_explicit] = ACTIONS(2420),
    [anon_sym_typename] = ACTIONS(2420),
    [anon_sym_template] = ACTIONS(2420),
    [anon_sym_operator] = ACTIONS(2420),
    [anon_sym_friend] = ACTIONS(2420),
    [anon_sym_public] = ACTIONS(2420),
    [anon_sym_private] = ACTIONS(2420),
    [anon_sym_protected] = ACTIONS(2420),
    [anon_sym_using] = ACTIONS(2420),
    [anon_sym_static_assert] = ACTIONS(2420),
    [anon_sym_precise] = ACTIONS(2420),
    [anon_sym_shared] = ACTIONS(2420),
    [anon_sym_groupshared] = ACTIONS(2420),
    [anon_sym_uniform] = ACTIONS(2420),
    [anon_sym_row_major] = ACTIONS(2420),
    [anon_sym_column_major] = ACTIONS(2420),
    [anon_sym_globallycoherent] = ACTIONS(2420),
    [anon_sym_centroid] = ACTIONS(2420),
    [anon_sym_noperspective] = ACTIONS(2420),
    [anon_sym_nointerpolation] = ACTIONS(2420),
    [anon_sym_sample] = ACTIONS(2420),
    [anon_sym_linear] = ACTIONS(2420),
    [anon_sym_snorm] = ACTIONS(2420),
    [anon_sym_unorm] = ACTIONS(2420),
    [anon_sym_point] = ACTIONS(2420),
    [anon_sym_line] = ACTIONS(2420),
    [anon_sym_triangleadj] = ACTIONS(2420),
    [anon_sym_lineadj] = ACTIONS(2420),
    [anon_sym_triangle] = ACTIONS(2420),
  },
  [1923] = {
    [sym_identifier] = ACTIONS(5017),
    [aux_sym_preproc_def_token1] = ACTIONS(5017),
    [aux_sym_preproc_if_token1] = ACTIONS(5017),
    [aux_sym_preproc_if_token2] = ACTIONS(5017),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5017),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5017),
    [aux_sym_preproc_else_token1] = ACTIONS(5017),
    [aux_sym_preproc_elif_token1] = ACTIONS(5017),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5017),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5017),
    [sym_preproc_directive] = ACTIONS(5017),
    [anon_sym_LPAREN2] = ACTIONS(5019),
    [anon_sym_TILDE] = ACTIONS(5019),
    [anon_sym_STAR] = ACTIONS(5019),
    [anon_sym_AMP_AMP] = ACTIONS(5019),
    [anon_sym_AMP] = ACTIONS(5017),
    [anon_sym___extension__] = ACTIONS(5017),
    [anon_sym_typedef] = ACTIONS(5017),
    [anon_sym_in] = ACTIONS(5017),
    [anon_sym_out] = ACTIONS(5017),
    [anon_sym_inout] = ACTIONS(5017),
    [anon_sym_extern] = ACTIONS(5017),
    [anon_sym___attribute__] = ACTIONS(5017),
    [anon_sym_COLON_COLON] = ACTIONS(5019),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5019),
    [anon_sym___declspec] = ACTIONS(5017),
    [anon_sym___based] = ACTIONS(5017),
    [anon_sym_signed] = ACTIONS(5017),
    [anon_sym_unsigned] = ACTIONS(5017),
    [anon_sym_long] = ACTIONS(5017),
    [anon_sym_short] = ACTIONS(5017),
    [anon_sym_LBRACK] = ACTIONS(5017),
    [anon_sym_static] = ACTIONS(5017),
    [anon_sym_register] = ACTIONS(5017),
    [anon_sym_inline] = ACTIONS(5017),
    [anon_sym___inline] = ACTIONS(5017),
    [anon_sym___inline__] = ACTIONS(5017),
    [anon_sym___forceinline] = ACTIONS(5017),
    [anon_sym_thread_local] = ACTIONS(5017),
    [anon_sym___thread] = ACTIONS(5017),
    [anon_sym_const] = ACTIONS(5017),
    [anon_sym_constexpr] = ACTIONS(5017),
    [anon_sym_volatile] = ACTIONS(5017),
    [anon_sym_restrict] = ACTIONS(5017),
    [anon_sym___restrict__] = ACTIONS(5017),
    [anon_sym__Atomic] = ACTIONS(5017),
    [anon_sym__Noreturn] = ACTIONS(5017),
    [anon_sym_noreturn] = ACTIONS(5017),
    [anon_sym_mutable] = ACTIONS(5017),
    [anon_sym_constinit] = ACTIONS(5017),
    [anon_sym_consteval] = ACTIONS(5017),
    [anon_sym_alignas] = ACTIONS(5017),
    [anon_sym__Alignas] = ACTIONS(5017),
    [sym_primitive_type] = ACTIONS(5017),
    [anon_sym_enum] = ACTIONS(5017),
    [anon_sym_class] = ACTIONS(5017),
    [anon_sym_struct] = ACTIONS(5017),
    [anon_sym_union] = ACTIONS(5017),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5017),
    [anon_sym_decltype] = ACTIONS(5017),
    [sym_virtual] = ACTIONS(5017),
    [anon_sym_explicit] = ACTIONS(5017),
    [anon_sym_typename] = ACTIONS(5017),
    [anon_sym_template] = ACTIONS(5017),
    [anon_sym_operator] = ACTIONS(5017),
    [anon_sym_friend] = ACTIONS(5017),
    [anon_sym_public] = ACTIONS(5017),
    [anon_sym_private] = ACTIONS(5017),
    [anon_sym_protected] = ACTIONS(5017),
    [anon_sym_using] = ACTIONS(5017),
    [anon_sym_static_assert] = ACTIONS(5017),
    [anon_sym_precise] = ACTIONS(5017),
    [anon_sym_shared] = ACTIONS(5017),
    [anon_sym_groupshared] = ACTIONS(5017),
    [anon_sym_uniform] = ACTIONS(5017),
    [anon_sym_row_major] = ACTIONS(5017),
    [anon_sym_column_major] = ACTIONS(5017),
    [anon_sym_globallycoherent] = ACTIONS(5017),
    [anon_sym_centroid] = ACTIONS(5017),
    [anon_sym_noperspective] = ACTIONS(5017),
    [anon_sym_nointerpolation] = ACTIONS(5017),
    [anon_sym_sample] = ACTIONS(5017),
    [anon_sym_linear] = ACTIONS(5017),
    [anon_sym_snorm] = ACTIONS(5017),
    [anon_sym_unorm] = ACTIONS(5017),
    [anon_sym_point] = ACTIONS(5017),
    [anon_sym_line] = ACTIONS(5017),
    [anon_sym_triangleadj] = ACTIONS(5017),
    [anon_sym_lineadj] = ACTIONS(5017),
    [anon_sym_triangle] = ACTIONS(5017),
  },
  [1924] = {
    [sym_identifier] = ACTIONS(2404),
    [aux_sym_preproc_def_token1] = ACTIONS(2404),
    [aux_sym_preproc_if_token1] = ACTIONS(2404),
    [aux_sym_preproc_if_token2] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2404),
    [aux_sym_preproc_else_token1] = ACTIONS(2404),
    [aux_sym_preproc_elif_token1] = ACTIONS(2404),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2404),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2404),
    [sym_preproc_directive] = ACTIONS(2404),
    [anon_sym_LPAREN2] = ACTIONS(2406),
    [anon_sym_TILDE] = ACTIONS(2406),
    [anon_sym_STAR] = ACTIONS(2406),
    [anon_sym_AMP_AMP] = ACTIONS(2406),
    [anon_sym_AMP] = ACTIONS(2404),
    [anon_sym___extension__] = ACTIONS(2404),
    [anon_sym_typedef] = ACTIONS(2404),
    [anon_sym_in] = ACTIONS(2404),
    [anon_sym_out] = ACTIONS(2404),
    [anon_sym_inout] = ACTIONS(2404),
    [anon_sym_extern] = ACTIONS(2404),
    [anon_sym___attribute__] = ACTIONS(2404),
    [anon_sym_COLON_COLON] = ACTIONS(2406),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2406),
    [anon_sym___declspec] = ACTIONS(2404),
    [anon_sym___based] = ACTIONS(2404),
    [anon_sym_signed] = ACTIONS(2404),
    [anon_sym_unsigned] = ACTIONS(2404),
    [anon_sym_long] = ACTIONS(2404),
    [anon_sym_short] = ACTIONS(2404),
    [anon_sym_LBRACK] = ACTIONS(2404),
    [anon_sym_static] = ACTIONS(2404),
    [anon_sym_register] = ACTIONS(2404),
    [anon_sym_inline] = ACTIONS(2404),
    [anon_sym___inline] = ACTIONS(2404),
    [anon_sym___inline__] = ACTIONS(2404),
    [anon_sym___forceinline] = ACTIONS(2404),
    [anon_sym_thread_local] = ACTIONS(2404),
    [anon_sym___thread] = ACTIONS(2404),
    [anon_sym_const] = ACTIONS(2404),
    [anon_sym_constexpr] = ACTIONS(2404),
    [anon_sym_volatile] = ACTIONS(2404),
    [anon_sym_restrict] = ACTIONS(2404),
    [anon_sym___restrict__] = ACTIONS(2404),
    [anon_sym__Atomic] = ACTIONS(2404),
    [anon_sym__Noreturn] = ACTIONS(2404),
    [anon_sym_noreturn] = ACTIONS(2404),
    [anon_sym_mutable] = ACTIONS(2404),
    [anon_sym_constinit] = ACTIONS(2404),
    [anon_sym_consteval] = ACTIONS(2404),
    [anon_sym_alignas] = ACTIONS(2404),
    [anon_sym__Alignas] = ACTIONS(2404),
    [sym_primitive_type] = ACTIONS(2404),
    [anon_sym_enum] = ACTIONS(2404),
    [anon_sym_class] = ACTIONS(2404),
    [anon_sym_struct] = ACTIONS(2404),
    [anon_sym_union] = ACTIONS(2404),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2404),
    [anon_sym_decltype] = ACTIONS(2404),
    [sym_virtual] = ACTIONS(2404),
    [anon_sym_explicit] = ACTIONS(2404),
    [anon_sym_typename] = ACTIONS(2404),
    [anon_sym_template] = ACTIONS(2404),
    [anon_sym_operator] = ACTIONS(2404),
    [anon_sym_friend] = ACTIONS(2404),
    [anon_sym_public] = ACTIONS(2404),
    [anon_sym_private] = ACTIONS(2404),
    [anon_sym_protected] = ACTIONS(2404),
    [anon_sym_using] = ACTIONS(2404),
    [anon_sym_static_assert] = ACTIONS(2404),
    [anon_sym_precise] = ACTIONS(2404),
    [anon_sym_shared] = ACTIONS(2404),
    [anon_sym_groupshared] = ACTIONS(2404),
    [anon_sym_uniform] = ACTIONS(2404),
    [anon_sym_row_major] = ACTIONS(2404),
    [anon_sym_column_major] = ACTIONS(2404),
    [anon_sym_globallycoherent] = ACTIONS(2404),
    [anon_sym_centroid] = ACTIONS(2404),
    [anon_sym_noperspective] = ACTIONS(2404),
    [anon_sym_nointerpolation] = ACTIONS(2404),
    [anon_sym_sample] = ACTIONS(2404),
    [anon_sym_linear] = ACTIONS(2404),
    [anon_sym_snorm] = ACTIONS(2404),
    [anon_sym_unorm] = ACTIONS(2404),
    [anon_sym_point] = ACTIONS(2404),
    [anon_sym_line] = ACTIONS(2404),
    [anon_sym_triangleadj] = ACTIONS(2404),
    [anon_sym_lineadj] = ACTIONS(2404),
    [anon_sym_triangle] = ACTIONS(2404),
  },
  [1925] = {
    [sym_identifier] = ACTIONS(2577),
    [aux_sym_preproc_def_token1] = ACTIONS(2577),
    [aux_sym_preproc_if_token1] = ACTIONS(2577),
    [aux_sym_preproc_if_token2] = ACTIONS(2577),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2577),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2577),
    [aux_sym_preproc_else_token1] = ACTIONS(2577),
    [aux_sym_preproc_elif_token1] = ACTIONS(2577),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2577),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2577),
    [sym_preproc_directive] = ACTIONS(2577),
    [anon_sym_LPAREN2] = ACTIONS(2579),
    [anon_sym_TILDE] = ACTIONS(2579),
    [anon_sym_STAR] = ACTIONS(2579),
    [anon_sym_AMP_AMP] = ACTIONS(2579),
    [anon_sym_AMP] = ACTIONS(2577),
    [anon_sym___extension__] = ACTIONS(2577),
    [anon_sym_typedef] = ACTIONS(2577),
    [anon_sym_in] = ACTIONS(2577),
    [anon_sym_out] = ACTIONS(2577),
    [anon_sym_inout] = ACTIONS(2577),
    [anon_sym_extern] = ACTIONS(2577),
    [anon_sym___attribute__] = ACTIONS(2577),
    [anon_sym_COLON_COLON] = ACTIONS(2579),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2579),
    [anon_sym___declspec] = ACTIONS(2577),
    [anon_sym___based] = ACTIONS(2577),
    [anon_sym_signed] = ACTIONS(2577),
    [anon_sym_unsigned] = ACTIONS(2577),
    [anon_sym_long] = ACTIONS(2577),
    [anon_sym_short] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2577),
    [anon_sym_static] = ACTIONS(2577),
    [anon_sym_register] = ACTIONS(2577),
    [anon_sym_inline] = ACTIONS(2577),
    [anon_sym___inline] = ACTIONS(2577),
    [anon_sym___inline__] = ACTIONS(2577),
    [anon_sym___forceinline] = ACTIONS(2577),
    [anon_sym_thread_local] = ACTIONS(2577),
    [anon_sym___thread] = ACTIONS(2577),
    [anon_sym_const] = ACTIONS(2577),
    [anon_sym_constexpr] = ACTIONS(2577),
    [anon_sym_volatile] = ACTIONS(2577),
    [anon_sym_restrict] = ACTIONS(2577),
    [anon_sym___restrict__] = ACTIONS(2577),
    [anon_sym__Atomic] = ACTIONS(2577),
    [anon_sym__Noreturn] = ACTIONS(2577),
    [anon_sym_noreturn] = ACTIONS(2577),
    [anon_sym_mutable] = ACTIONS(2577),
    [anon_sym_constinit] = ACTIONS(2577),
    [anon_sym_consteval] = ACTIONS(2577),
    [anon_sym_alignas] = ACTIONS(2577),
    [anon_sym__Alignas] = ACTIONS(2577),
    [sym_primitive_type] = ACTIONS(2577),
    [anon_sym_enum] = ACTIONS(2577),
    [anon_sym_class] = ACTIONS(2577),
    [anon_sym_struct] = ACTIONS(2577),
    [anon_sym_union] = ACTIONS(2577),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2577),
    [anon_sym_decltype] = ACTIONS(2577),
    [sym_virtual] = ACTIONS(2577),
    [anon_sym_explicit] = ACTIONS(2577),
    [anon_sym_typename] = ACTIONS(2577),
    [anon_sym_template] = ACTIONS(2577),
    [anon_sym_operator] = ACTIONS(2577),
    [anon_sym_friend] = ACTIONS(2577),
    [anon_sym_public] = ACTIONS(2577),
    [anon_sym_private] = ACTIONS(2577),
    [anon_sym_protected] = ACTIONS(2577),
    [anon_sym_using] = ACTIONS(2577),
    [anon_sym_static_assert] = ACTIONS(2577),
    [anon_sym_precise] = ACTIONS(2577),
    [anon_sym_shared] = ACTIONS(2577),
    [anon_sym_groupshared] = ACTIONS(2577),
    [anon_sym_uniform] = ACTIONS(2577),
    [anon_sym_row_major] = ACTIONS(2577),
    [anon_sym_column_major] = ACTIONS(2577),
    [anon_sym_globallycoherent] = ACTIONS(2577),
    [anon_sym_centroid] = ACTIONS(2577),
    [anon_sym_noperspective] = ACTIONS(2577),
    [anon_sym_nointerpolation] = ACTIONS(2577),
    [anon_sym_sample] = ACTIONS(2577),
    [anon_sym_linear] = ACTIONS(2577),
    [anon_sym_snorm] = ACTIONS(2577),
    [anon_sym_unorm] = ACTIONS(2577),
    [anon_sym_point] = ACTIONS(2577),
    [anon_sym_line] = ACTIONS(2577),
    [anon_sym_triangleadj] = ACTIONS(2577),
    [anon_sym_lineadj] = ACTIONS(2577),
    [anon_sym_triangle] = ACTIONS(2577),
  },
  [1926] = {
    [sym_identifier] = ACTIONS(2540),
    [aux_sym_preproc_def_token1] = ACTIONS(2540),
    [aux_sym_preproc_if_token1] = ACTIONS(2540),
    [aux_sym_preproc_if_token2] = ACTIONS(2540),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2540),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2540),
    [aux_sym_preproc_else_token1] = ACTIONS(2540),
    [aux_sym_preproc_elif_token1] = ACTIONS(2540),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2540),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2540),
    [sym_preproc_directive] = ACTIONS(2540),
    [anon_sym_LPAREN2] = ACTIONS(2542),
    [anon_sym_TILDE] = ACTIONS(2542),
    [anon_sym_STAR] = ACTIONS(2542),
    [anon_sym_AMP_AMP] = ACTIONS(2542),
    [anon_sym_AMP] = ACTIONS(2540),
    [anon_sym___extension__] = ACTIONS(2540),
    [anon_sym_typedef] = ACTIONS(2540),
    [anon_sym_in] = ACTIONS(2540),
    [anon_sym_out] = ACTIONS(2540),
    [anon_sym_inout] = ACTIONS(2540),
    [anon_sym_extern] = ACTIONS(2540),
    [anon_sym___attribute__] = ACTIONS(2540),
    [anon_sym_COLON_COLON] = ACTIONS(2542),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2542),
    [anon_sym___declspec] = ACTIONS(2540),
    [anon_sym___based] = ACTIONS(2540),
    [anon_sym_signed] = ACTIONS(2540),
    [anon_sym_unsigned] = ACTIONS(2540),
    [anon_sym_long] = ACTIONS(2540),
    [anon_sym_short] = ACTIONS(2540),
    [anon_sym_LBRACK] = ACTIONS(2540),
    [anon_sym_static] = ACTIONS(2540),
    [anon_sym_register] = ACTIONS(2540),
    [anon_sym_inline] = ACTIONS(2540),
    [anon_sym___inline] = ACTIONS(2540),
    [anon_sym___inline__] = ACTIONS(2540),
    [anon_sym___forceinline] = ACTIONS(2540),
    [anon_sym_thread_local] = ACTIONS(2540),
    [anon_sym___thread] = ACTIONS(2540),
    [anon_sym_const] = ACTIONS(2540),
    [anon_sym_constexpr] = ACTIONS(2540),
    [anon_sym_volatile] = ACTIONS(2540),
    [anon_sym_restrict] = ACTIONS(2540),
    [anon_sym___restrict__] = ACTIONS(2540),
    [anon_sym__Atomic] = ACTIONS(2540),
    [anon_sym__Noreturn] = ACTIONS(2540),
    [anon_sym_noreturn] = ACTIONS(2540),
    [anon_sym_mutable] = ACTIONS(2540),
    [anon_sym_constinit] = ACTIONS(2540),
    [anon_sym_consteval] = ACTIONS(2540),
    [anon_sym_alignas] = ACTIONS(2540),
    [anon_sym__Alignas] = ACTIONS(2540),
    [sym_primitive_type] = ACTIONS(2540),
    [anon_sym_enum] = ACTIONS(2540),
    [anon_sym_class] = ACTIONS(2540),
    [anon_sym_struct] = ACTIONS(2540),
    [anon_sym_union] = ACTIONS(2540),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2540),
    [anon_sym_decltype] = ACTIONS(2540),
    [sym_virtual] = ACTIONS(2540),
    [anon_sym_explicit] = ACTIONS(2540),
    [anon_sym_typename] = ACTIONS(2540),
    [anon_sym_template] = ACTIONS(2540),
    [anon_sym_operator] = ACTIONS(2540),
    [anon_sym_friend] = ACTIONS(2540),
    [anon_sym_public] = ACTIONS(2540),
    [anon_sym_private] = ACTIONS(2540),
    [anon_sym_protected] = ACTIONS(2540),
    [anon_sym_using] = ACTIONS(2540),
    [anon_sym_static_assert] = ACTIONS(2540),
    [anon_sym_precise] = ACTIONS(2540),
    [anon_sym_shared] = ACTIONS(2540),
    [anon_sym_groupshared] = ACTIONS(2540),
    [anon_sym_uniform] = ACTIONS(2540),
    [anon_sym_row_major] = ACTIONS(2540),
    [anon_sym_column_major] = ACTIONS(2540),
    [anon_sym_globallycoherent] = ACTIONS(2540),
    [anon_sym_centroid] = ACTIONS(2540),
    [anon_sym_noperspective] = ACTIONS(2540),
    [anon_sym_nointerpolation] = ACTIONS(2540),
    [anon_sym_sample] = ACTIONS(2540),
    [anon_sym_linear] = ACTIONS(2540),
    [anon_sym_snorm] = ACTIONS(2540),
    [anon_sym_unorm] = ACTIONS(2540),
    [anon_sym_point] = ACTIONS(2540),
    [anon_sym_line] = ACTIONS(2540),
    [anon_sym_triangleadj] = ACTIONS(2540),
    [anon_sym_lineadj] = ACTIONS(2540),
    [anon_sym_triangle] = ACTIONS(2540),
  },
  [1927] = {
    [sym_identifier] = ACTIONS(5001),
    [aux_sym_preproc_def_token1] = ACTIONS(5001),
    [aux_sym_preproc_if_token1] = ACTIONS(5001),
    [aux_sym_preproc_if_token2] = ACTIONS(5001),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5001),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5001),
    [aux_sym_preproc_else_token1] = ACTIONS(5001),
    [aux_sym_preproc_elif_token1] = ACTIONS(5001),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5001),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5001),
    [sym_preproc_directive] = ACTIONS(5001),
    [anon_sym_LPAREN2] = ACTIONS(5003),
    [anon_sym_TILDE] = ACTIONS(5003),
    [anon_sym_STAR] = ACTIONS(5003),
    [anon_sym_AMP_AMP] = ACTIONS(5003),
    [anon_sym_AMP] = ACTIONS(5001),
    [anon_sym___extension__] = ACTIONS(5001),
    [anon_sym_typedef] = ACTIONS(5001),
    [anon_sym_in] = ACTIONS(5001),
    [anon_sym_out] = ACTIONS(5001),
    [anon_sym_inout] = ACTIONS(5001),
    [anon_sym_extern] = ACTIONS(5001),
    [anon_sym___attribute__] = ACTIONS(5001),
    [anon_sym_COLON_COLON] = ACTIONS(5003),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5003),
    [anon_sym___declspec] = ACTIONS(5001),
    [anon_sym___based] = ACTIONS(5001),
    [anon_sym_signed] = ACTIONS(5001),
    [anon_sym_unsigned] = ACTIONS(5001),
    [anon_sym_long] = ACTIONS(5001),
    [anon_sym_short] = ACTIONS(5001),
    [anon_sym_LBRACK] = ACTIONS(5001),
    [anon_sym_static] = ACTIONS(5001),
    [anon_sym_register] = ACTIONS(5001),
    [anon_sym_inline] = ACTIONS(5001),
    [anon_sym___inline] = ACTIONS(5001),
    [anon_sym___inline__] = ACTIONS(5001),
    [anon_sym___forceinline] = ACTIONS(5001),
    [anon_sym_thread_local] = ACTIONS(5001),
    [anon_sym___thread] = ACTIONS(5001),
    [anon_sym_const] = ACTIONS(5001),
    [anon_sym_constexpr] = ACTIONS(5001),
    [anon_sym_volatile] = ACTIONS(5001),
    [anon_sym_restrict] = ACTIONS(5001),
    [anon_sym___restrict__] = ACTIONS(5001),
    [anon_sym__Atomic] = ACTIONS(5001),
    [anon_sym__Noreturn] = ACTIONS(5001),
    [anon_sym_noreturn] = ACTIONS(5001),
    [anon_sym_mutable] = ACTIONS(5001),
    [anon_sym_constinit] = ACTIONS(5001),
    [anon_sym_consteval] = ACTIONS(5001),
    [anon_sym_alignas] = ACTIONS(5001),
    [anon_sym__Alignas] = ACTIONS(5001),
    [sym_primitive_type] = ACTIONS(5001),
    [anon_sym_enum] = ACTIONS(5001),
    [anon_sym_class] = ACTIONS(5001),
    [anon_sym_struct] = ACTIONS(5001),
    [anon_sym_union] = ACTIONS(5001),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5001),
    [anon_sym_decltype] = ACTIONS(5001),
    [sym_virtual] = ACTIONS(5001),
    [anon_sym_explicit] = ACTIONS(5001),
    [anon_sym_typename] = ACTIONS(5001),
    [anon_sym_template] = ACTIONS(5001),
    [anon_sym_operator] = ACTIONS(5001),
    [anon_sym_friend] = ACTIONS(5001),
    [anon_sym_public] = ACTIONS(5001),
    [anon_sym_private] = ACTIONS(5001),
    [anon_sym_protected] = ACTIONS(5001),
    [anon_sym_using] = ACTIONS(5001),
    [anon_sym_static_assert] = ACTIONS(5001),
    [anon_sym_precise] = ACTIONS(5001),
    [anon_sym_shared] = ACTIONS(5001),
    [anon_sym_groupshared] = ACTIONS(5001),
    [anon_sym_uniform] = ACTIONS(5001),
    [anon_sym_row_major] = ACTIONS(5001),
    [anon_sym_column_major] = ACTIONS(5001),
    [anon_sym_globallycoherent] = ACTIONS(5001),
    [anon_sym_centroid] = ACTIONS(5001),
    [anon_sym_noperspective] = ACTIONS(5001),
    [anon_sym_nointerpolation] = ACTIONS(5001),
    [anon_sym_sample] = ACTIONS(5001),
    [anon_sym_linear] = ACTIONS(5001),
    [anon_sym_snorm] = ACTIONS(5001),
    [anon_sym_unorm] = ACTIONS(5001),
    [anon_sym_point] = ACTIONS(5001),
    [anon_sym_line] = ACTIONS(5001),
    [anon_sym_triangleadj] = ACTIONS(5001),
    [anon_sym_lineadj] = ACTIONS(5001),
    [anon_sym_triangle] = ACTIONS(5001),
  },
  [1928] = {
    [sym_identifier] = ACTIONS(2248),
    [aux_sym_preproc_def_token1] = ACTIONS(2248),
    [aux_sym_preproc_if_token1] = ACTIONS(2248),
    [aux_sym_preproc_if_token2] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2248),
    [aux_sym_preproc_else_token1] = ACTIONS(2248),
    [aux_sym_preproc_elif_token1] = ACTIONS(2248),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2248),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2248),
    [sym_preproc_directive] = ACTIONS(2248),
    [anon_sym_LPAREN2] = ACTIONS(2250),
    [anon_sym_TILDE] = ACTIONS(2250),
    [anon_sym_STAR] = ACTIONS(2250),
    [anon_sym_AMP_AMP] = ACTIONS(2250),
    [anon_sym_AMP] = ACTIONS(2248),
    [anon_sym___extension__] = ACTIONS(2248),
    [anon_sym_typedef] = ACTIONS(2248),
    [anon_sym_in] = ACTIONS(2248),
    [anon_sym_out] = ACTIONS(2248),
    [anon_sym_inout] = ACTIONS(2248),
    [anon_sym_extern] = ACTIONS(2248),
    [anon_sym___attribute__] = ACTIONS(2248),
    [anon_sym_COLON_COLON] = ACTIONS(2250),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2250),
    [anon_sym___declspec] = ACTIONS(2248),
    [anon_sym___based] = ACTIONS(2248),
    [anon_sym_signed] = ACTIONS(2248),
    [anon_sym_unsigned] = ACTIONS(2248),
    [anon_sym_long] = ACTIONS(2248),
    [anon_sym_short] = ACTIONS(2248),
    [anon_sym_LBRACK] = ACTIONS(2248),
    [anon_sym_static] = ACTIONS(2248),
    [anon_sym_register] = ACTIONS(2248),
    [anon_sym_inline] = ACTIONS(2248),
    [anon_sym___inline] = ACTIONS(2248),
    [anon_sym___inline__] = ACTIONS(2248),
    [anon_sym___forceinline] = ACTIONS(2248),
    [anon_sym_thread_local] = ACTIONS(2248),
    [anon_sym___thread] = ACTIONS(2248),
    [anon_sym_const] = ACTIONS(2248),
    [anon_sym_constexpr] = ACTIONS(2248),
    [anon_sym_volatile] = ACTIONS(2248),
    [anon_sym_restrict] = ACTIONS(2248),
    [anon_sym___restrict__] = ACTIONS(2248),
    [anon_sym__Atomic] = ACTIONS(2248),
    [anon_sym__Noreturn] = ACTIONS(2248),
    [anon_sym_noreturn] = ACTIONS(2248),
    [anon_sym_mutable] = ACTIONS(2248),
    [anon_sym_constinit] = ACTIONS(2248),
    [anon_sym_consteval] = ACTIONS(2248),
    [anon_sym_alignas] = ACTIONS(2248),
    [anon_sym__Alignas] = ACTIONS(2248),
    [sym_primitive_type] = ACTIONS(2248),
    [anon_sym_enum] = ACTIONS(2248),
    [anon_sym_class] = ACTIONS(2248),
    [anon_sym_struct] = ACTIONS(2248),
    [anon_sym_union] = ACTIONS(2248),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2248),
    [anon_sym_decltype] = ACTIONS(2248),
    [sym_virtual] = ACTIONS(2248),
    [anon_sym_explicit] = ACTIONS(2248),
    [anon_sym_typename] = ACTIONS(2248),
    [anon_sym_template] = ACTIONS(2248),
    [anon_sym_operator] = ACTIONS(2248),
    [anon_sym_friend] = ACTIONS(2248),
    [anon_sym_public] = ACTIONS(2248),
    [anon_sym_private] = ACTIONS(2248),
    [anon_sym_protected] = ACTIONS(2248),
    [anon_sym_using] = ACTIONS(2248),
    [anon_sym_static_assert] = ACTIONS(2248),
    [anon_sym_precise] = ACTIONS(2248),
    [anon_sym_shared] = ACTIONS(2248),
    [anon_sym_groupshared] = ACTIONS(2248),
    [anon_sym_uniform] = ACTIONS(2248),
    [anon_sym_row_major] = ACTIONS(2248),
    [anon_sym_column_major] = ACTIONS(2248),
    [anon_sym_globallycoherent] = ACTIONS(2248),
    [anon_sym_centroid] = ACTIONS(2248),
    [anon_sym_noperspective] = ACTIONS(2248),
    [anon_sym_nointerpolation] = ACTIONS(2248),
    [anon_sym_sample] = ACTIONS(2248),
    [anon_sym_linear] = ACTIONS(2248),
    [anon_sym_snorm] = ACTIONS(2248),
    [anon_sym_unorm] = ACTIONS(2248),
    [anon_sym_point] = ACTIONS(2248),
    [anon_sym_line] = ACTIONS(2248),
    [anon_sym_triangleadj] = ACTIONS(2248),
    [anon_sym_lineadj] = ACTIONS(2248),
    [anon_sym_triangle] = ACTIONS(2248),
  },
  [1929] = {
    [sym_identifier] = ACTIONS(5105),
    [aux_sym_preproc_def_token1] = ACTIONS(5105),
    [aux_sym_preproc_if_token1] = ACTIONS(5105),
    [aux_sym_preproc_if_token2] = ACTIONS(5105),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5105),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5105),
    [aux_sym_preproc_else_token1] = ACTIONS(5105),
    [aux_sym_preproc_elif_token1] = ACTIONS(5105),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5105),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5105),
    [sym_preproc_directive] = ACTIONS(5105),
    [anon_sym_LPAREN2] = ACTIONS(5107),
    [anon_sym_TILDE] = ACTIONS(5107),
    [anon_sym_STAR] = ACTIONS(5107),
    [anon_sym_AMP_AMP] = ACTIONS(5107),
    [anon_sym_AMP] = ACTIONS(5105),
    [anon_sym___extension__] = ACTIONS(5105),
    [anon_sym_typedef] = ACTIONS(5105),
    [anon_sym_in] = ACTIONS(5105),
    [anon_sym_out] = ACTIONS(5105),
    [anon_sym_inout] = ACTIONS(5105),
    [anon_sym_extern] = ACTIONS(5105),
    [anon_sym___attribute__] = ACTIONS(5105),
    [anon_sym_COLON_COLON] = ACTIONS(5107),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5107),
    [anon_sym___declspec] = ACTIONS(5105),
    [anon_sym___based] = ACTIONS(5105),
    [anon_sym_signed] = ACTIONS(5105),
    [anon_sym_unsigned] = ACTIONS(5105),
    [anon_sym_long] = ACTIONS(5105),
    [anon_sym_short] = ACTIONS(5105),
    [anon_sym_LBRACK] = ACTIONS(5105),
    [anon_sym_static] = ACTIONS(5105),
    [anon_sym_register] = ACTIONS(5105),
    [anon_sym_inline] = ACTIONS(5105),
    [anon_sym___inline] = ACTIONS(5105),
    [anon_sym___inline__] = ACTIONS(5105),
    [anon_sym___forceinline] = ACTIONS(5105),
    [anon_sym_thread_local] = ACTIONS(5105),
    [anon_sym___thread] = ACTIONS(5105),
    [anon_sym_const] = ACTIONS(5105),
    [anon_sym_constexpr] = ACTIONS(5105),
    [anon_sym_volatile] = ACTIONS(5105),
    [anon_sym_restrict] = ACTIONS(5105),
    [anon_sym___restrict__] = ACTIONS(5105),
    [anon_sym__Atomic] = ACTIONS(5105),
    [anon_sym__Noreturn] = ACTIONS(5105),
    [anon_sym_noreturn] = ACTIONS(5105),
    [anon_sym_mutable] = ACTIONS(5105),
    [anon_sym_constinit] = ACTIONS(5105),
    [anon_sym_consteval] = ACTIONS(5105),
    [anon_sym_alignas] = ACTIONS(5105),
    [anon_sym__Alignas] = ACTIONS(5105),
    [sym_primitive_type] = ACTIONS(5105),
    [anon_sym_enum] = ACTIONS(5105),
    [anon_sym_class] = ACTIONS(5105),
    [anon_sym_struct] = ACTIONS(5105),
    [anon_sym_union] = ACTIONS(5105),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5105),
    [anon_sym_decltype] = ACTIONS(5105),
    [sym_virtual] = ACTIONS(5105),
    [anon_sym_explicit] = ACTIONS(5105),
    [anon_sym_typename] = ACTIONS(5105),
    [anon_sym_template] = ACTIONS(5105),
    [anon_sym_operator] = ACTIONS(5105),
    [anon_sym_friend] = ACTIONS(5105),
    [anon_sym_public] = ACTIONS(5105),
    [anon_sym_private] = ACTIONS(5105),
    [anon_sym_protected] = ACTIONS(5105),
    [anon_sym_using] = ACTIONS(5105),
    [anon_sym_static_assert] = ACTIONS(5105),
    [anon_sym_precise] = ACTIONS(5105),
    [anon_sym_shared] = ACTIONS(5105),
    [anon_sym_groupshared] = ACTIONS(5105),
    [anon_sym_uniform] = ACTIONS(5105),
    [anon_sym_row_major] = ACTIONS(5105),
    [anon_sym_column_major] = ACTIONS(5105),
    [anon_sym_globallycoherent] = ACTIONS(5105),
    [anon_sym_centroid] = ACTIONS(5105),
    [anon_sym_noperspective] = ACTIONS(5105),
    [anon_sym_nointerpolation] = ACTIONS(5105),
    [anon_sym_sample] = ACTIONS(5105),
    [anon_sym_linear] = ACTIONS(5105),
    [anon_sym_snorm] = ACTIONS(5105),
    [anon_sym_unorm] = ACTIONS(5105),
    [anon_sym_point] = ACTIONS(5105),
    [anon_sym_line] = ACTIONS(5105),
    [anon_sym_triangleadj] = ACTIONS(5105),
    [anon_sym_lineadj] = ACTIONS(5105),
    [anon_sym_triangle] = ACTIONS(5105),
  },
  [1930] = {
    [sym_identifier] = ACTIONS(2308),
    [aux_sym_preproc_def_token1] = ACTIONS(2308),
    [aux_sym_preproc_if_token1] = ACTIONS(2308),
    [aux_sym_preproc_if_token2] = ACTIONS(2308),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2308),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2308),
    [aux_sym_preproc_else_token1] = ACTIONS(2308),
    [aux_sym_preproc_elif_token1] = ACTIONS(2308),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2308),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2308),
    [sym_preproc_directive] = ACTIONS(2308),
    [anon_sym_LPAREN2] = ACTIONS(2310),
    [anon_sym_TILDE] = ACTIONS(2310),
    [anon_sym_STAR] = ACTIONS(2310),
    [anon_sym_AMP_AMP] = ACTIONS(2310),
    [anon_sym_AMP] = ACTIONS(2308),
    [anon_sym___extension__] = ACTIONS(2308),
    [anon_sym_typedef] = ACTIONS(2308),
    [anon_sym_in] = ACTIONS(2308),
    [anon_sym_out] = ACTIONS(2308),
    [anon_sym_inout] = ACTIONS(2308),
    [anon_sym_extern] = ACTIONS(2308),
    [anon_sym___attribute__] = ACTIONS(2308),
    [anon_sym_COLON_COLON] = ACTIONS(2310),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2310),
    [anon_sym___declspec] = ACTIONS(2308),
    [anon_sym___based] = ACTIONS(2308),
    [anon_sym_signed] = ACTIONS(2308),
    [anon_sym_unsigned] = ACTIONS(2308),
    [anon_sym_long] = ACTIONS(2308),
    [anon_sym_short] = ACTIONS(2308),
    [anon_sym_LBRACK] = ACTIONS(2308),
    [anon_sym_static] = ACTIONS(2308),
    [anon_sym_register] = ACTIONS(2308),
    [anon_sym_inline] = ACTIONS(2308),
    [anon_sym___inline] = ACTIONS(2308),
    [anon_sym___inline__] = ACTIONS(2308),
    [anon_sym___forceinline] = ACTIONS(2308),
    [anon_sym_thread_local] = ACTIONS(2308),
    [anon_sym___thread] = ACTIONS(2308),
    [anon_sym_const] = ACTIONS(2308),
    [anon_sym_constexpr] = ACTIONS(2308),
    [anon_sym_volatile] = ACTIONS(2308),
    [anon_sym_restrict] = ACTIONS(2308),
    [anon_sym___restrict__] = ACTIONS(2308),
    [anon_sym__Atomic] = ACTIONS(2308),
    [anon_sym__Noreturn] = ACTIONS(2308),
    [anon_sym_noreturn] = ACTIONS(2308),
    [anon_sym_mutable] = ACTIONS(2308),
    [anon_sym_constinit] = ACTIONS(2308),
    [anon_sym_consteval] = ACTIONS(2308),
    [anon_sym_alignas] = ACTIONS(2308),
    [anon_sym__Alignas] = ACTIONS(2308),
    [sym_primitive_type] = ACTIONS(2308),
    [anon_sym_enum] = ACTIONS(2308),
    [anon_sym_class] = ACTIONS(2308),
    [anon_sym_struct] = ACTIONS(2308),
    [anon_sym_union] = ACTIONS(2308),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2308),
    [anon_sym_decltype] = ACTIONS(2308),
    [sym_virtual] = ACTIONS(2308),
    [anon_sym_explicit] = ACTIONS(2308),
    [anon_sym_typename] = ACTIONS(2308),
    [anon_sym_template] = ACTIONS(2308),
    [anon_sym_operator] = ACTIONS(2308),
    [anon_sym_friend] = ACTIONS(2308),
    [anon_sym_public] = ACTIONS(2308),
    [anon_sym_private] = ACTIONS(2308),
    [anon_sym_protected] = ACTIONS(2308),
    [anon_sym_using] = ACTIONS(2308),
    [anon_sym_static_assert] = ACTIONS(2308),
    [anon_sym_precise] = ACTIONS(2308),
    [anon_sym_shared] = ACTIONS(2308),
    [anon_sym_groupshared] = ACTIONS(2308),
    [anon_sym_uniform] = ACTIONS(2308),
    [anon_sym_row_major] = ACTIONS(2308),
    [anon_sym_column_major] = ACTIONS(2308),
    [anon_sym_globallycoherent] = ACTIONS(2308),
    [anon_sym_centroid] = ACTIONS(2308),
    [anon_sym_noperspective] = ACTIONS(2308),
    [anon_sym_nointerpolation] = ACTIONS(2308),
    [anon_sym_sample] = ACTIONS(2308),
    [anon_sym_linear] = ACTIONS(2308),
    [anon_sym_snorm] = ACTIONS(2308),
    [anon_sym_unorm] = ACTIONS(2308),
    [anon_sym_point] = ACTIONS(2308),
    [anon_sym_line] = ACTIONS(2308),
    [anon_sym_triangleadj] = ACTIONS(2308),
    [anon_sym_lineadj] = ACTIONS(2308),
    [anon_sym_triangle] = ACTIONS(2308),
  },
  [1931] = {
    [sym_identifier] = ACTIONS(2516),
    [aux_sym_preproc_def_token1] = ACTIONS(2516),
    [aux_sym_preproc_if_token1] = ACTIONS(2516),
    [aux_sym_preproc_if_token2] = ACTIONS(2516),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2516),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2516),
    [aux_sym_preproc_else_token1] = ACTIONS(2516),
    [aux_sym_preproc_elif_token1] = ACTIONS(2516),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2516),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2516),
    [sym_preproc_directive] = ACTIONS(2516),
    [anon_sym_LPAREN2] = ACTIONS(2518),
    [anon_sym_TILDE] = ACTIONS(2518),
    [anon_sym_STAR] = ACTIONS(2518),
    [anon_sym_AMP_AMP] = ACTIONS(2518),
    [anon_sym_AMP] = ACTIONS(2516),
    [anon_sym___extension__] = ACTIONS(2516),
    [anon_sym_typedef] = ACTIONS(2516),
    [anon_sym_in] = ACTIONS(2516),
    [anon_sym_out] = ACTIONS(2516),
    [anon_sym_inout] = ACTIONS(2516),
    [anon_sym_extern] = ACTIONS(2516),
    [anon_sym___attribute__] = ACTIONS(2516),
    [anon_sym_COLON_COLON] = ACTIONS(2518),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2518),
    [anon_sym___declspec] = ACTIONS(2516),
    [anon_sym___based] = ACTIONS(2516),
    [anon_sym_signed] = ACTIONS(2516),
    [anon_sym_unsigned] = ACTIONS(2516),
    [anon_sym_long] = ACTIONS(2516),
    [anon_sym_short] = ACTIONS(2516),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_static] = ACTIONS(2516),
    [anon_sym_register] = ACTIONS(2516),
    [anon_sym_inline] = ACTIONS(2516),
    [anon_sym___inline] = ACTIONS(2516),
    [anon_sym___inline__] = ACTIONS(2516),
    [anon_sym___forceinline] = ACTIONS(2516),
    [anon_sym_thread_local] = ACTIONS(2516),
    [anon_sym___thread] = ACTIONS(2516),
    [anon_sym_const] = ACTIONS(2516),
    [anon_sym_constexpr] = ACTIONS(2516),
    [anon_sym_volatile] = ACTIONS(2516),
    [anon_sym_restrict] = ACTIONS(2516),
    [anon_sym___restrict__] = ACTIONS(2516),
    [anon_sym__Atomic] = ACTIONS(2516),
    [anon_sym__Noreturn] = ACTIONS(2516),
    [anon_sym_noreturn] = ACTIONS(2516),
    [anon_sym_mutable] = ACTIONS(2516),
    [anon_sym_constinit] = ACTIONS(2516),
    [anon_sym_consteval] = ACTIONS(2516),
    [anon_sym_alignas] = ACTIONS(2516),
    [anon_sym__Alignas] = ACTIONS(2516),
    [sym_primitive_type] = ACTIONS(2516),
    [anon_sym_enum] = ACTIONS(2516),
    [anon_sym_class] = ACTIONS(2516),
    [anon_sym_struct] = ACTIONS(2516),
    [anon_sym_union] = ACTIONS(2516),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2516),
    [anon_sym_decltype] = ACTIONS(2516),
    [sym_virtual] = ACTIONS(2516),
    [anon_sym_explicit] = ACTIONS(2516),
    [anon_sym_typename] = ACTIONS(2516),
    [anon_sym_template] = ACTIONS(2516),
    [anon_sym_operator] = ACTIONS(2516),
    [anon_sym_friend] = ACTIONS(2516),
    [anon_sym_public] = ACTIONS(2516),
    [anon_sym_private] = ACTIONS(2516),
    [anon_sym_protected] = ACTIONS(2516),
    [anon_sym_using] = ACTIONS(2516),
    [anon_sym_static_assert] = ACTIONS(2516),
    [anon_sym_precise] = ACTIONS(2516),
    [anon_sym_shared] = ACTIONS(2516),
    [anon_sym_groupshared] = ACTIONS(2516),
    [anon_sym_uniform] = ACTIONS(2516),
    [anon_sym_row_major] = ACTIONS(2516),
    [anon_sym_column_major] = ACTIONS(2516),
    [anon_sym_globallycoherent] = ACTIONS(2516),
    [anon_sym_centroid] = ACTIONS(2516),
    [anon_sym_noperspective] = ACTIONS(2516),
    [anon_sym_nointerpolation] = ACTIONS(2516),
    [anon_sym_sample] = ACTIONS(2516),
    [anon_sym_linear] = ACTIONS(2516),
    [anon_sym_snorm] = ACTIONS(2516),
    [anon_sym_unorm] = ACTIONS(2516),
    [anon_sym_point] = ACTIONS(2516),
    [anon_sym_line] = ACTIONS(2516),
    [anon_sym_triangleadj] = ACTIONS(2516),
    [anon_sym_lineadj] = ACTIONS(2516),
    [anon_sym_triangle] = ACTIONS(2516),
  },
  [1932] = {
    [sym_identifier] = ACTIONS(5109),
    [aux_sym_preproc_def_token1] = ACTIONS(5109),
    [aux_sym_preproc_if_token1] = ACTIONS(5109),
    [aux_sym_preproc_if_token2] = ACTIONS(5109),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5109),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5109),
    [aux_sym_preproc_else_token1] = ACTIONS(5109),
    [aux_sym_preproc_elif_token1] = ACTIONS(5109),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5109),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5109),
    [sym_preproc_directive] = ACTIONS(5109),
    [anon_sym_LPAREN2] = ACTIONS(5111),
    [anon_sym_TILDE] = ACTIONS(5111),
    [anon_sym_STAR] = ACTIONS(5111),
    [anon_sym_AMP_AMP] = ACTIONS(5111),
    [anon_sym_AMP] = ACTIONS(5109),
    [anon_sym___extension__] = ACTIONS(5109),
    [anon_sym_typedef] = ACTIONS(5109),
    [anon_sym_in] = ACTIONS(5109),
    [anon_sym_out] = ACTIONS(5109),
    [anon_sym_inout] = ACTIONS(5109),
    [anon_sym_extern] = ACTIONS(5109),
    [anon_sym___attribute__] = ACTIONS(5109),
    [anon_sym_COLON_COLON] = ACTIONS(5111),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5111),
    [anon_sym___declspec] = ACTIONS(5109),
    [anon_sym___based] = ACTIONS(5109),
    [anon_sym_signed] = ACTIONS(5109),
    [anon_sym_unsigned] = ACTIONS(5109),
    [anon_sym_long] = ACTIONS(5109),
    [anon_sym_short] = ACTIONS(5109),
    [anon_sym_LBRACK] = ACTIONS(5109),
    [anon_sym_static] = ACTIONS(5109),
    [anon_sym_register] = ACTIONS(5109),
    [anon_sym_inline] = ACTIONS(5109),
    [anon_sym___inline] = ACTIONS(5109),
    [anon_sym___inline__] = ACTIONS(5109),
    [anon_sym___forceinline] = ACTIONS(5109),
    [anon_sym_thread_local] = ACTIONS(5109),
    [anon_sym___thread] = ACTIONS(5109),
    [anon_sym_const] = ACTIONS(5109),
    [anon_sym_constexpr] = ACTIONS(5109),
    [anon_sym_volatile] = ACTIONS(5109),
    [anon_sym_restrict] = ACTIONS(5109),
    [anon_sym___restrict__] = ACTIONS(5109),
    [anon_sym__Atomic] = ACTIONS(5109),
    [anon_sym__Noreturn] = ACTIONS(5109),
    [anon_sym_noreturn] = ACTIONS(5109),
    [anon_sym_mutable] = ACTIONS(5109),
    [anon_sym_constinit] = ACTIONS(5109),
    [anon_sym_consteval] = ACTIONS(5109),
    [anon_sym_alignas] = ACTIONS(5109),
    [anon_sym__Alignas] = ACTIONS(5109),
    [sym_primitive_type] = ACTIONS(5109),
    [anon_sym_enum] = ACTIONS(5109),
    [anon_sym_class] = ACTIONS(5109),
    [anon_sym_struct] = ACTIONS(5109),
    [anon_sym_union] = ACTIONS(5109),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5109),
    [anon_sym_decltype] = ACTIONS(5109),
    [sym_virtual] = ACTIONS(5109),
    [anon_sym_explicit] = ACTIONS(5109),
    [anon_sym_typename] = ACTIONS(5109),
    [anon_sym_template] = ACTIONS(5109),
    [anon_sym_operator] = ACTIONS(5109),
    [anon_sym_friend] = ACTIONS(5109),
    [anon_sym_public] = ACTIONS(5109),
    [anon_sym_private] = ACTIONS(5109),
    [anon_sym_protected] = ACTIONS(5109),
    [anon_sym_using] = ACTIONS(5109),
    [anon_sym_static_assert] = ACTIONS(5109),
    [anon_sym_precise] = ACTIONS(5109),
    [anon_sym_shared] = ACTIONS(5109),
    [anon_sym_groupshared] = ACTIONS(5109),
    [anon_sym_uniform] = ACTIONS(5109),
    [anon_sym_row_major] = ACTIONS(5109),
    [anon_sym_column_major] = ACTIONS(5109),
    [anon_sym_globallycoherent] = ACTIONS(5109),
    [anon_sym_centroid] = ACTIONS(5109),
    [anon_sym_noperspective] = ACTIONS(5109),
    [anon_sym_nointerpolation] = ACTIONS(5109),
    [anon_sym_sample] = ACTIONS(5109),
    [anon_sym_linear] = ACTIONS(5109),
    [anon_sym_snorm] = ACTIONS(5109),
    [anon_sym_unorm] = ACTIONS(5109),
    [anon_sym_point] = ACTIONS(5109),
    [anon_sym_line] = ACTIONS(5109),
    [anon_sym_triangleadj] = ACTIONS(5109),
    [anon_sym_lineadj] = ACTIONS(5109),
    [anon_sym_triangle] = ACTIONS(5109),
  },
  [1933] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token2] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [aux_sym_preproc_else_token1] = ACTIONS(2332),
    [aux_sym_preproc_elif_token1] = ACTIONS(2332),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_friend] = ACTIONS(2332),
    [anon_sym_public] = ACTIONS(2332),
    [anon_sym_private] = ACTIONS(2332),
    [anon_sym_protected] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
  },
  [1934] = {
    [sym_identifier] = ACTIONS(2356),
    [aux_sym_preproc_def_token1] = ACTIONS(2356),
    [aux_sym_preproc_if_token1] = ACTIONS(2356),
    [aux_sym_preproc_if_token2] = ACTIONS(2356),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2356),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2356),
    [aux_sym_preproc_else_token1] = ACTIONS(2356),
    [aux_sym_preproc_elif_token1] = ACTIONS(2356),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2356),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2356),
    [sym_preproc_directive] = ACTIONS(2356),
    [anon_sym_LPAREN2] = ACTIONS(2358),
    [anon_sym_TILDE] = ACTIONS(2358),
    [anon_sym_STAR] = ACTIONS(2358),
    [anon_sym_AMP_AMP] = ACTIONS(2358),
    [anon_sym_AMP] = ACTIONS(2356),
    [anon_sym___extension__] = ACTIONS(2356),
    [anon_sym_typedef] = ACTIONS(2356),
    [anon_sym_in] = ACTIONS(2356),
    [anon_sym_out] = ACTIONS(2356),
    [anon_sym_inout] = ACTIONS(2356),
    [anon_sym_extern] = ACTIONS(2356),
    [anon_sym___attribute__] = ACTIONS(2356),
    [anon_sym_COLON_COLON] = ACTIONS(2358),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2358),
    [anon_sym___declspec] = ACTIONS(2356),
    [anon_sym___based] = ACTIONS(2356),
    [anon_sym_signed] = ACTIONS(2356),
    [anon_sym_unsigned] = ACTIONS(2356),
    [anon_sym_long] = ACTIONS(2356),
    [anon_sym_short] = ACTIONS(2356),
    [anon_sym_LBRACK] = ACTIONS(2356),
    [anon_sym_static] = ACTIONS(2356),
    [anon_sym_register] = ACTIONS(2356),
    [anon_sym_inline] = ACTIONS(2356),
    [anon_sym___inline] = ACTIONS(2356),
    [anon_sym___inline__] = ACTIONS(2356),
    [anon_sym___forceinline] = ACTIONS(2356),
    [anon_sym_thread_local] = ACTIONS(2356),
    [anon_sym___thread] = ACTIONS(2356),
    [anon_sym_const] = ACTIONS(2356),
    [anon_sym_constexpr] = ACTIONS(2356),
    [anon_sym_volatile] = ACTIONS(2356),
    [anon_sym_restrict] = ACTIONS(2356),
    [anon_sym___restrict__] = ACTIONS(2356),
    [anon_sym__Atomic] = ACTIONS(2356),
    [anon_sym__Noreturn] = ACTIONS(2356),
    [anon_sym_noreturn] = ACTIONS(2356),
    [anon_sym_mutable] = ACTIONS(2356),
    [anon_sym_constinit] = ACTIONS(2356),
    [anon_sym_consteval] = ACTIONS(2356),
    [anon_sym_alignas] = ACTIONS(2356),
    [anon_sym__Alignas] = ACTIONS(2356),
    [sym_primitive_type] = ACTIONS(2356),
    [anon_sym_enum] = ACTIONS(2356),
    [anon_sym_class] = ACTIONS(2356),
    [anon_sym_struct] = ACTIONS(2356),
    [anon_sym_union] = ACTIONS(2356),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2356),
    [anon_sym_decltype] = ACTIONS(2356),
    [sym_virtual] = ACTIONS(2356),
    [anon_sym_explicit] = ACTIONS(2356),
    [anon_sym_typename] = ACTIONS(2356),
    [anon_sym_template] = ACTIONS(2356),
    [anon_sym_operator] = ACTIONS(2356),
    [anon_sym_friend] = ACTIONS(2356),
    [anon_sym_public] = ACTIONS(2356),
    [anon_sym_private] = ACTIONS(2356),
    [anon_sym_protected] = ACTIONS(2356),
    [anon_sym_using] = ACTIONS(2356),
    [anon_sym_static_assert] = ACTIONS(2356),
    [anon_sym_precise] = ACTIONS(2356),
    [anon_sym_shared] = ACTIONS(2356),
    [anon_sym_groupshared] = ACTIONS(2356),
    [anon_sym_uniform] = ACTIONS(2356),
    [anon_sym_row_major] = ACTIONS(2356),
    [anon_sym_column_major] = ACTIONS(2356),
    [anon_sym_globallycoherent] = ACTIONS(2356),
    [anon_sym_centroid] = ACTIONS(2356),
    [anon_sym_noperspective] = ACTIONS(2356),
    [anon_sym_nointerpolation] = ACTIONS(2356),
    [anon_sym_sample] = ACTIONS(2356),
    [anon_sym_linear] = ACTIONS(2356),
    [anon_sym_snorm] = ACTIONS(2356),
    [anon_sym_unorm] = ACTIONS(2356),
    [anon_sym_point] = ACTIONS(2356),
    [anon_sym_line] = ACTIONS(2356),
    [anon_sym_triangleadj] = ACTIONS(2356),
    [anon_sym_lineadj] = ACTIONS(2356),
    [anon_sym_triangle] = ACTIONS(2356),
  },
  [1935] = {
    [sym_identifier] = ACTIONS(5113),
    [anon_sym_RPAREN] = ACTIONS(5115),
    [anon_sym_LPAREN2] = ACTIONS(5115),
    [anon_sym_TILDE] = ACTIONS(5115),
    [anon_sym_STAR] = ACTIONS(5115),
    [anon_sym_PIPE_PIPE] = ACTIONS(5115),
    [anon_sym_AMP_AMP] = ACTIONS(5115),
    [anon_sym_AMP] = ACTIONS(5113),
    [anon_sym___extension__] = ACTIONS(5113),
    [anon_sym_in] = ACTIONS(5113),
    [anon_sym_out] = ACTIONS(5113),
    [anon_sym_inout] = ACTIONS(5113),
    [anon_sym_extern] = ACTIONS(5113),
    [anon_sym___attribute__] = ACTIONS(5113),
    [anon_sym_COLON_COLON] = ACTIONS(5115),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5115),
    [anon_sym___declspec] = ACTIONS(5113),
    [anon_sym___based] = ACTIONS(5113),
    [anon_sym___cdecl] = ACTIONS(5113),
    [anon_sym___clrcall] = ACTIONS(5113),
    [anon_sym___stdcall] = ACTIONS(5113),
    [anon_sym___fastcall] = ACTIONS(5113),
    [anon_sym___thiscall] = ACTIONS(5113),
    [anon_sym___vectorcall] = ACTIONS(5113),
    [anon_sym_signed] = ACTIONS(5113),
    [anon_sym_unsigned] = ACTIONS(5113),
    [anon_sym_long] = ACTIONS(5113),
    [anon_sym_short] = ACTIONS(5113),
    [anon_sym_LBRACK] = ACTIONS(5113),
    [anon_sym_static] = ACTIONS(5113),
    [anon_sym_register] = ACTIONS(5113),
    [anon_sym_inline] = ACTIONS(5113),
    [anon_sym___inline] = ACTIONS(5113),
    [anon_sym___inline__] = ACTIONS(5113),
    [anon_sym___forceinline] = ACTIONS(5113),
    [anon_sym_thread_local] = ACTIONS(5113),
    [anon_sym___thread] = ACTIONS(5113),
    [anon_sym_const] = ACTIONS(5113),
    [anon_sym_constexpr] = ACTIONS(5113),
    [anon_sym_volatile] = ACTIONS(5113),
    [anon_sym_restrict] = ACTIONS(5113),
    [anon_sym___restrict__] = ACTIONS(5113),
    [anon_sym__Atomic] = ACTIONS(5113),
    [anon_sym__Noreturn] = ACTIONS(5113),
    [anon_sym_noreturn] = ACTIONS(5113),
    [anon_sym_mutable] = ACTIONS(5113),
    [anon_sym_constinit] = ACTIONS(5113),
    [anon_sym_consteval] = ACTIONS(5113),
    [anon_sym_alignas] = ACTIONS(5113),
    [anon_sym__Alignas] = ACTIONS(5113),
    [sym_primitive_type] = ACTIONS(5113),
    [anon_sym_enum] = ACTIONS(5113),
    [anon_sym_class] = ACTIONS(5113),
    [anon_sym_struct] = ACTIONS(5113),
    [anon_sym_union] = ACTIONS(5113),
    [anon_sym_or] = ACTIONS(5113),
    [anon_sym_and] = ACTIONS(5113),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5113),
    [anon_sym_decltype] = ACTIONS(5113),
    [anon_sym_final] = ACTIONS(5113),
    [anon_sym_override] = ACTIONS(5113),
    [sym_virtual] = ACTIONS(5113),
    [anon_sym_explicit] = ACTIONS(5113),
    [anon_sym_typename] = ACTIONS(5113),
    [anon_sym_template] = ACTIONS(5113),
    [anon_sym_operator] = ACTIONS(5113),
    [anon_sym_friend] = ACTIONS(5113),
    [anon_sym_using] = ACTIONS(5113),
    [anon_sym_concept] = ACTIONS(5113),
    [anon_sym_requires] = ACTIONS(5113),
    [anon_sym_precise] = ACTIONS(5113),
    [anon_sym_shared] = ACTIONS(5113),
    [anon_sym_groupshared] = ACTIONS(5113),
    [anon_sym_uniform] = ACTIONS(5113),
    [anon_sym_row_major] = ACTIONS(5113),
    [anon_sym_column_major] = ACTIONS(5113),
    [anon_sym_globallycoherent] = ACTIONS(5113),
    [anon_sym_centroid] = ACTIONS(5113),
    [anon_sym_noperspective] = ACTIONS(5113),
    [anon_sym_nointerpolation] = ACTIONS(5113),
    [anon_sym_sample] = ACTIONS(5113),
    [anon_sym_linear] = ACTIONS(5113),
    [anon_sym_snorm] = ACTIONS(5113),
    [anon_sym_unorm] = ACTIONS(5113),
    [anon_sym_point] = ACTIONS(5113),
    [anon_sym_line] = ACTIONS(5113),
    [anon_sym_triangleadj] = ACTIONS(5113),
    [anon_sym_lineadj] = ACTIONS(5113),
    [anon_sym_triangle] = ACTIONS(5113),
  },
  [1936] = {
    [sym_catch_clause] = STATE(1966),
    [aux_sym_constructor_try_statement_repeat1] = STATE(1966),
    [sym_identifier] = ACTIONS(1990),
    [aux_sym_preproc_def_token1] = ACTIONS(1990),
    [aux_sym_preproc_if_token1] = ACTIONS(1990),
    [aux_sym_preproc_if_token2] = ACTIONS(1990),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1990),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1990),
    [sym_preproc_directive] = ACTIONS(1990),
    [anon_sym_LPAREN2] = ACTIONS(1992),
    [anon_sym_TILDE] = ACTIONS(1992),
    [anon_sym_STAR] = ACTIONS(1992),
    [anon_sym_AMP_AMP] = ACTIONS(1992),
    [anon_sym_AMP] = ACTIONS(1990),
    [anon_sym___extension__] = ACTIONS(1990),
    [anon_sym_typedef] = ACTIONS(1990),
    [anon_sym_in] = ACTIONS(1990),
    [anon_sym_out] = ACTIONS(1990),
    [anon_sym_inout] = ACTIONS(1990),
    [anon_sym_extern] = ACTIONS(1990),
    [anon_sym___attribute__] = ACTIONS(1990),
    [anon_sym_COLON_COLON] = ACTIONS(1992),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1992),
    [anon_sym___declspec] = ACTIONS(1990),
    [anon_sym___based] = ACTIONS(1990),
    [anon_sym_signed] = ACTIONS(1990),
    [anon_sym_unsigned] = ACTIONS(1990),
    [anon_sym_long] = ACTIONS(1990),
    [anon_sym_short] = ACTIONS(1990),
    [anon_sym_LBRACK] = ACTIONS(1990),
    [anon_sym_static] = ACTIONS(1990),
    [anon_sym_register] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1990),
    [anon_sym___inline] = ACTIONS(1990),
    [anon_sym___inline__] = ACTIONS(1990),
    [anon_sym___forceinline] = ACTIONS(1990),
    [anon_sym_thread_local] = ACTIONS(1990),
    [anon_sym___thread] = ACTIONS(1990),
    [anon_sym_const] = ACTIONS(1990),
    [anon_sym_constexpr] = ACTIONS(1990),
    [anon_sym_volatile] = ACTIONS(1990),
    [anon_sym_restrict] = ACTIONS(1990),
    [anon_sym___restrict__] = ACTIONS(1990),
    [anon_sym__Atomic] = ACTIONS(1990),
    [anon_sym__Noreturn] = ACTIONS(1990),
    [anon_sym_noreturn] = ACTIONS(1990),
    [anon_sym_mutable] = ACTIONS(1990),
    [anon_sym_constinit] = ACTIONS(1990),
    [anon_sym_consteval] = ACTIONS(1990),
    [anon_sym_alignas] = ACTIONS(1990),
    [anon_sym__Alignas] = ACTIONS(1990),
    [sym_primitive_type] = ACTIONS(1990),
    [anon_sym_enum] = ACTIONS(1990),
    [anon_sym_class] = ACTIONS(1990),
    [anon_sym_struct] = ACTIONS(1990),
    [anon_sym_union] = ACTIONS(1990),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1990),
    [anon_sym_decltype] = ACTIONS(1990),
    [sym_virtual] = ACTIONS(1990),
    [anon_sym_explicit] = ACTIONS(1990),
    [anon_sym_typename] = ACTIONS(1990),
    [anon_sym_template] = ACTIONS(1990),
    [anon_sym_operator] = ACTIONS(1990),
    [anon_sym_friend] = ACTIONS(1990),
    [anon_sym_public] = ACTIONS(1990),
    [anon_sym_private] = ACTIONS(1990),
    [anon_sym_protected] = ACTIONS(1990),
    [anon_sym_using] = ACTIONS(1990),
    [anon_sym_static_assert] = ACTIONS(1990),
    [anon_sym_catch] = ACTIONS(5117),
    [anon_sym_precise] = ACTIONS(1990),
    [anon_sym_shared] = ACTIONS(1990),
    [anon_sym_groupshared] = ACTIONS(1990),
    [anon_sym_uniform] = ACTIONS(1990),
    [anon_sym_row_major] = ACTIONS(1990),
    [anon_sym_column_major] = ACTIONS(1990),
    [anon_sym_globallycoherent] = ACTIONS(1990),
    [anon_sym_centroid] = ACTIONS(1990),
    [anon_sym_noperspective] = ACTIONS(1990),
    [anon_sym_nointerpolation] = ACTIONS(1990),
    [anon_sym_sample] = ACTIONS(1990),
    [anon_sym_linear] = ACTIONS(1990),
    [anon_sym_snorm] = ACTIONS(1990),
    [anon_sym_unorm] = ACTIONS(1990),
    [anon_sym_point] = ACTIONS(1990),
    [anon_sym_line] = ACTIONS(1990),
    [anon_sym_triangleadj] = ACTIONS(1990),
    [anon_sym_lineadj] = ACTIONS(1990),
    [anon_sym_triangle] = ACTIONS(1990),
  },
  [1937] = {
    [sym_identifier] = ACTIONS(5119),
    [anon_sym_RPAREN] = ACTIONS(5121),
    [anon_sym_LPAREN2] = ACTIONS(5121),
    [anon_sym_TILDE] = ACTIONS(5121),
    [anon_sym_STAR] = ACTIONS(5121),
    [anon_sym_PIPE_PIPE] = ACTIONS(5121),
    [anon_sym_AMP_AMP] = ACTIONS(5121),
    [anon_sym_AMP] = ACTIONS(5119),
    [anon_sym___extension__] = ACTIONS(5119),
    [anon_sym_in] = ACTIONS(5119),
    [anon_sym_out] = ACTIONS(5119),
    [anon_sym_inout] = ACTIONS(5119),
    [anon_sym_extern] = ACTIONS(5119),
    [anon_sym___attribute__] = ACTIONS(5119),
    [anon_sym_COLON_COLON] = ACTIONS(5121),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5121),
    [anon_sym___declspec] = ACTIONS(5119),
    [anon_sym___based] = ACTIONS(5119),
    [anon_sym___cdecl] = ACTIONS(5119),
    [anon_sym___clrcall] = ACTIONS(5119),
    [anon_sym___stdcall] = ACTIONS(5119),
    [anon_sym___fastcall] = ACTIONS(5119),
    [anon_sym___thiscall] = ACTIONS(5119),
    [anon_sym___vectorcall] = ACTIONS(5119),
    [anon_sym_signed] = ACTIONS(5119),
    [anon_sym_unsigned] = ACTIONS(5119),
    [anon_sym_long] = ACTIONS(5119),
    [anon_sym_short] = ACTIONS(5119),
    [anon_sym_LBRACK] = ACTIONS(5119),
    [anon_sym_static] = ACTIONS(5119),
    [anon_sym_register] = ACTIONS(5119),
    [anon_sym_inline] = ACTIONS(5119),
    [anon_sym___inline] = ACTIONS(5119),
    [anon_sym___inline__] = ACTIONS(5119),
    [anon_sym___forceinline] = ACTIONS(5119),
    [anon_sym_thread_local] = ACTIONS(5119),
    [anon_sym___thread] = ACTIONS(5119),
    [anon_sym_const] = ACTIONS(5119),
    [anon_sym_constexpr] = ACTIONS(5119),
    [anon_sym_volatile] = ACTIONS(5119),
    [anon_sym_restrict] = ACTIONS(5119),
    [anon_sym___restrict__] = ACTIONS(5119),
    [anon_sym__Atomic] = ACTIONS(5119),
    [anon_sym__Noreturn] = ACTIONS(5119),
    [anon_sym_noreturn] = ACTIONS(5119),
    [anon_sym_mutable] = ACTIONS(5119),
    [anon_sym_constinit] = ACTIONS(5119),
    [anon_sym_consteval] = ACTIONS(5119),
    [anon_sym_alignas] = ACTIONS(5119),
    [anon_sym__Alignas] = ACTIONS(5119),
    [sym_primitive_type] = ACTIONS(5119),
    [anon_sym_enum] = ACTIONS(5119),
    [anon_sym_class] = ACTIONS(5119),
    [anon_sym_struct] = ACTIONS(5119),
    [anon_sym_union] = ACTIONS(5119),
    [anon_sym_or] = ACTIONS(5119),
    [anon_sym_and] = ACTIONS(5119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5119),
    [anon_sym_decltype] = ACTIONS(5119),
    [anon_sym_final] = ACTIONS(5119),
    [anon_sym_override] = ACTIONS(5119),
    [sym_virtual] = ACTIONS(5119),
    [anon_sym_explicit] = ACTIONS(5119),
    [anon_sym_typename] = ACTIONS(5119),
    [anon_sym_template] = ACTIONS(5119),
    [anon_sym_operator] = ACTIONS(5119),
    [anon_sym_friend] = ACTIONS(5119),
    [anon_sym_using] = ACTIONS(5119),
    [anon_sym_concept] = ACTIONS(5119),
    [anon_sym_requires] = ACTIONS(5119),
    [anon_sym_precise] = ACTIONS(5119),
    [anon_sym_shared] = ACTIONS(5119),
    [anon_sym_groupshared] = ACTIONS(5119),
    [anon_sym_uniform] = ACTIONS(5119),
    [anon_sym_row_major] = ACTIONS(5119),
    [anon_sym_column_major] = ACTIONS(5119),
    [anon_sym_globallycoherent] = ACTIONS(5119),
    [anon_sym_centroid] = ACTIONS(5119),
    [anon_sym_noperspective] = ACTIONS(5119),
    [anon_sym_nointerpolation] = ACTIONS(5119),
    [anon_sym_sample] = ACTIONS(5119),
    [anon_sym_linear] = ACTIONS(5119),
    [anon_sym_snorm] = ACTIONS(5119),
    [anon_sym_unorm] = ACTIONS(5119),
    [anon_sym_point] = ACTIONS(5119),
    [anon_sym_line] = ACTIONS(5119),
    [anon_sym_triangleadj] = ACTIONS(5119),
    [anon_sym_lineadj] = ACTIONS(5119),
    [anon_sym_triangle] = ACTIONS(5119),
  },
  [1938] = {
    [sym_identifier] = ACTIONS(5123),
    [anon_sym_RPAREN] = ACTIONS(5125),
    [anon_sym_LPAREN2] = ACTIONS(5125),
    [anon_sym_TILDE] = ACTIONS(5125),
    [anon_sym_STAR] = ACTIONS(5125),
    [anon_sym_PIPE_PIPE] = ACTIONS(5125),
    [anon_sym_AMP_AMP] = ACTIONS(5125),
    [anon_sym_AMP] = ACTIONS(5123),
    [anon_sym___extension__] = ACTIONS(5123),
    [anon_sym_in] = ACTIONS(5123),
    [anon_sym_out] = ACTIONS(5123),
    [anon_sym_inout] = ACTIONS(5123),
    [anon_sym_extern] = ACTIONS(5123),
    [anon_sym___attribute__] = ACTIONS(5123),
    [anon_sym_COLON_COLON] = ACTIONS(5125),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5125),
    [anon_sym___declspec] = ACTIONS(5123),
    [anon_sym___based] = ACTIONS(5123),
    [anon_sym___cdecl] = ACTIONS(5123),
    [anon_sym___clrcall] = ACTIONS(5123),
    [anon_sym___stdcall] = ACTIONS(5123),
    [anon_sym___fastcall] = ACTIONS(5123),
    [anon_sym___thiscall] = ACTIONS(5123),
    [anon_sym___vectorcall] = ACTIONS(5123),
    [anon_sym_signed] = ACTIONS(5123),
    [anon_sym_unsigned] = ACTIONS(5123),
    [anon_sym_long] = ACTIONS(5123),
    [anon_sym_short] = ACTIONS(5123),
    [anon_sym_LBRACK] = ACTIONS(5123),
    [anon_sym_static] = ACTIONS(5123),
    [anon_sym_register] = ACTIONS(5123),
    [anon_sym_inline] = ACTIONS(5123),
    [anon_sym___inline] = ACTIONS(5123),
    [anon_sym___inline__] = ACTIONS(5123),
    [anon_sym___forceinline] = ACTIONS(5123),
    [anon_sym_thread_local] = ACTIONS(5123),
    [anon_sym___thread] = ACTIONS(5123),
    [anon_sym_const] = ACTIONS(5123),
    [anon_sym_constexpr] = ACTIONS(5123),
    [anon_sym_volatile] = ACTIONS(5123),
    [anon_sym_restrict] = ACTIONS(5123),
    [anon_sym___restrict__] = ACTIONS(5123),
    [anon_sym__Atomic] = ACTIONS(5123),
    [anon_sym__Noreturn] = ACTIONS(5123),
    [anon_sym_noreturn] = ACTIONS(5123),
    [anon_sym_mutable] = ACTIONS(5123),
    [anon_sym_constinit] = ACTIONS(5123),
    [anon_sym_consteval] = ACTIONS(5123),
    [anon_sym_alignas] = ACTIONS(5123),
    [anon_sym__Alignas] = ACTIONS(5123),
    [sym_primitive_type] = ACTIONS(5123),
    [anon_sym_enum] = ACTIONS(5123),
    [anon_sym_class] = ACTIONS(5123),
    [anon_sym_struct] = ACTIONS(5123),
    [anon_sym_union] = ACTIONS(5123),
    [anon_sym_or] = ACTIONS(5123),
    [anon_sym_and] = ACTIONS(5123),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5123),
    [anon_sym_decltype] = ACTIONS(5123),
    [anon_sym_final] = ACTIONS(5123),
    [anon_sym_override] = ACTIONS(5123),
    [sym_virtual] = ACTIONS(5123),
    [anon_sym_explicit] = ACTIONS(5123),
    [anon_sym_typename] = ACTIONS(5123),
    [anon_sym_template] = ACTIONS(5123),
    [anon_sym_operator] = ACTIONS(5123),
    [anon_sym_friend] = ACTIONS(5123),
    [anon_sym_using] = ACTIONS(5123),
    [anon_sym_concept] = ACTIONS(5123),
    [anon_sym_requires] = ACTIONS(5123),
    [anon_sym_precise] = ACTIONS(5123),
    [anon_sym_shared] = ACTIONS(5123),
    [anon_sym_groupshared] = ACTIONS(5123),
    [anon_sym_uniform] = ACTIONS(5123),
    [anon_sym_row_major] = ACTIONS(5123),
    [anon_sym_column_major] = ACTIONS(5123),
    [anon_sym_globallycoherent] = ACTIONS(5123),
    [anon_sym_centroid] = ACTIONS(5123),
    [anon_sym_noperspective] = ACTIONS(5123),
    [anon_sym_nointerpolation] = ACTIONS(5123),
    [anon_sym_sample] = ACTIONS(5123),
    [anon_sym_linear] = ACTIONS(5123),
    [anon_sym_snorm] = ACTIONS(5123),
    [anon_sym_unorm] = ACTIONS(5123),
    [anon_sym_point] = ACTIONS(5123),
    [anon_sym_line] = ACTIONS(5123),
    [anon_sym_triangleadj] = ACTIONS(5123),
    [anon_sym_lineadj] = ACTIONS(5123),
    [anon_sym_triangle] = ACTIONS(5123),
  },
  [1939] = {
    [sym_catch_clause] = STATE(1975),
    [aux_sym_constructor_try_statement_repeat1] = STATE(1975),
    [sym_identifier] = ACTIONS(1963),
    [aux_sym_preproc_def_token1] = ACTIONS(1963),
    [aux_sym_preproc_if_token1] = ACTIONS(1963),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1963),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1963),
    [sym_preproc_directive] = ACTIONS(1963),
    [anon_sym_LPAREN2] = ACTIONS(1965),
    [anon_sym_TILDE] = ACTIONS(1965),
    [anon_sym_STAR] = ACTIONS(1965),
    [anon_sym_AMP_AMP] = ACTIONS(1965),
    [anon_sym_AMP] = ACTIONS(1963),
    [anon_sym___extension__] = ACTIONS(1963),
    [anon_sym_typedef] = ACTIONS(1963),
    [anon_sym_in] = ACTIONS(1963),
    [anon_sym_out] = ACTIONS(1963),
    [anon_sym_inout] = ACTIONS(1963),
    [anon_sym_extern] = ACTIONS(1963),
    [anon_sym___attribute__] = ACTIONS(1963),
    [anon_sym_COLON_COLON] = ACTIONS(1965),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1965),
    [anon_sym___declspec] = ACTIONS(1963),
    [anon_sym___based] = ACTIONS(1963),
    [anon_sym_RBRACE] = ACTIONS(1965),
    [anon_sym_signed] = ACTIONS(1963),
    [anon_sym_unsigned] = ACTIONS(1963),
    [anon_sym_long] = ACTIONS(1963),
    [anon_sym_short] = ACTIONS(1963),
    [anon_sym_LBRACK] = ACTIONS(1963),
    [anon_sym_static] = ACTIONS(1963),
    [anon_sym_register] = ACTIONS(1963),
    [anon_sym_inline] = ACTIONS(1963),
    [anon_sym___inline] = ACTIONS(1963),
    [anon_sym___inline__] = ACTIONS(1963),
    [anon_sym___forceinline] = ACTIONS(1963),
    [anon_sym_thread_local] = ACTIONS(1963),
    [anon_sym___thread] = ACTIONS(1963),
    [anon_sym_const] = ACTIONS(1963),
    [anon_sym_constexpr] = ACTIONS(1963),
    [anon_sym_volatile] = ACTIONS(1963),
    [anon_sym_restrict] = ACTIONS(1963),
    [anon_sym___restrict__] = ACTIONS(1963),
    [anon_sym__Atomic] = ACTIONS(1963),
    [anon_sym__Noreturn] = ACTIONS(1963),
    [anon_sym_noreturn] = ACTIONS(1963),
    [anon_sym_mutable] = ACTIONS(1963),
    [anon_sym_constinit] = ACTIONS(1963),
    [anon_sym_consteval] = ACTIONS(1963),
    [anon_sym_alignas] = ACTIONS(1963),
    [anon_sym__Alignas] = ACTIONS(1963),
    [sym_primitive_type] = ACTIONS(1963),
    [anon_sym_enum] = ACTIONS(1963),
    [anon_sym_class] = ACTIONS(1963),
    [anon_sym_struct] = ACTIONS(1963),
    [anon_sym_union] = ACTIONS(1963),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1963),
    [anon_sym_decltype] = ACTIONS(1963),
    [sym_virtual] = ACTIONS(1963),
    [anon_sym_explicit] = ACTIONS(1963),
    [anon_sym_typename] = ACTIONS(1963),
    [anon_sym_template] = ACTIONS(1963),
    [anon_sym_operator] = ACTIONS(1963),
    [anon_sym_friend] = ACTIONS(1963),
    [anon_sym_public] = ACTIONS(1963),
    [anon_sym_private] = ACTIONS(1963),
    [anon_sym_protected] = ACTIONS(1963),
    [anon_sym_using] = ACTIONS(1963),
    [anon_sym_static_assert] = ACTIONS(1963),
    [anon_sym_catch] = ACTIONS(5127),
    [anon_sym_precise] = ACTIONS(1963),
    [anon_sym_shared] = ACTIONS(1963),
    [anon_sym_groupshared] = ACTIONS(1963),
    [anon_sym_uniform] = ACTIONS(1963),
    [anon_sym_row_major] = ACTIONS(1963),
    [anon_sym_column_major] = ACTIONS(1963),
    [anon_sym_globallycoherent] = ACTIONS(1963),
    [anon_sym_centroid] = ACTIONS(1963),
    [anon_sym_noperspective] = ACTIONS(1963),
    [anon_sym_nointerpolation] = ACTIONS(1963),
    [anon_sym_sample] = ACTIONS(1963),
    [anon_sym_linear] = ACTIONS(1963),
    [anon_sym_snorm] = ACTIONS(1963),
    [anon_sym_unorm] = ACTIONS(1963),
    [anon_sym_point] = ACTIONS(1963),
    [anon_sym_line] = ACTIONS(1963),
    [anon_sym_triangleadj] = ACTIONS(1963),
    [anon_sym_lineadj] = ACTIONS(1963),
    [anon_sym_triangle] = ACTIONS(1963),
  },
  [1940] = {
    [sym_identifier] = ACTIONS(5129),
    [anon_sym_RPAREN] = ACTIONS(5131),
    [anon_sym_LPAREN2] = ACTIONS(5131),
    [anon_sym_TILDE] = ACTIONS(5131),
    [anon_sym_STAR] = ACTIONS(5131),
    [anon_sym_PIPE_PIPE] = ACTIONS(5131),
    [anon_sym_AMP_AMP] = ACTIONS(5131),
    [anon_sym_AMP] = ACTIONS(5129),
    [anon_sym___extension__] = ACTIONS(5129),
    [anon_sym_in] = ACTIONS(5129),
    [anon_sym_out] = ACTIONS(5129),
    [anon_sym_inout] = ACTIONS(5129),
    [anon_sym_extern] = ACTIONS(5129),
    [anon_sym___attribute__] = ACTIONS(5129),
    [anon_sym_COLON_COLON] = ACTIONS(5131),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5131),
    [anon_sym___declspec] = ACTIONS(5129),
    [anon_sym___based] = ACTIONS(5129),
    [anon_sym___cdecl] = ACTIONS(5129),
    [anon_sym___clrcall] = ACTIONS(5129),
    [anon_sym___stdcall] = ACTIONS(5129),
    [anon_sym___fastcall] = ACTIONS(5129),
    [anon_sym___thiscall] = ACTIONS(5129),
    [anon_sym___vectorcall] = ACTIONS(5129),
    [anon_sym_signed] = ACTIONS(5129),
    [anon_sym_unsigned] = ACTIONS(5129),
    [anon_sym_long] = ACTIONS(5129),
    [anon_sym_short] = ACTIONS(5129),
    [anon_sym_LBRACK] = ACTIONS(5129),
    [anon_sym_static] = ACTIONS(5129),
    [anon_sym_register] = ACTIONS(5129),
    [anon_sym_inline] = ACTIONS(5129),
    [anon_sym___inline] = ACTIONS(5129),
    [anon_sym___inline__] = ACTIONS(5129),
    [anon_sym___forceinline] = ACTIONS(5129),
    [anon_sym_thread_local] = ACTIONS(5129),
    [anon_sym___thread] = ACTIONS(5129),
    [anon_sym_const] = ACTIONS(5129),
    [anon_sym_constexpr] = ACTIONS(5129),
    [anon_sym_volatile] = ACTIONS(5129),
    [anon_sym_restrict] = ACTIONS(5129),
    [anon_sym___restrict__] = ACTIONS(5129),
    [anon_sym__Atomic] = ACTIONS(5129),
    [anon_sym__Noreturn] = ACTIONS(5129),
    [anon_sym_noreturn] = ACTIONS(5129),
    [anon_sym_mutable] = ACTIONS(5129),
    [anon_sym_constinit] = ACTIONS(5129),
    [anon_sym_consteval] = ACTIONS(5129),
    [anon_sym_alignas] = ACTIONS(5129),
    [anon_sym__Alignas] = ACTIONS(5129),
    [sym_primitive_type] = ACTIONS(5129),
    [anon_sym_enum] = ACTIONS(5129),
    [anon_sym_class] = ACTIONS(5129),
    [anon_sym_struct] = ACTIONS(5129),
    [anon_sym_union] = ACTIONS(5129),
    [anon_sym_or] = ACTIONS(5129),
    [anon_sym_and] = ACTIONS(5129),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5129),
    [anon_sym_decltype] = ACTIONS(5129),
    [anon_sym_final] = ACTIONS(5129),
    [anon_sym_override] = ACTIONS(5129),
    [sym_virtual] = ACTIONS(5129),
    [anon_sym_explicit] = ACTIONS(5129),
    [anon_sym_typename] = ACTIONS(5129),
    [anon_sym_template] = ACTIONS(5129),
    [anon_sym_operator] = ACTIONS(5129),
    [anon_sym_friend] = ACTIONS(5129),
    [anon_sym_using] = ACTIONS(5129),
    [anon_sym_concept] = ACTIONS(5129),
    [anon_sym_requires] = ACTIONS(5129),
    [anon_sym_precise] = ACTIONS(5129),
    [anon_sym_shared] = ACTIONS(5129),
    [anon_sym_groupshared] = ACTIONS(5129),
    [anon_sym_uniform] = ACTIONS(5129),
    [anon_sym_row_major] = ACTIONS(5129),
    [anon_sym_column_major] = ACTIONS(5129),
    [anon_sym_globallycoherent] = ACTIONS(5129),
    [anon_sym_centroid] = ACTIONS(5129),
    [anon_sym_noperspective] = ACTIONS(5129),
    [anon_sym_nointerpolation] = ACTIONS(5129),
    [anon_sym_sample] = ACTIONS(5129),
    [anon_sym_linear] = ACTIONS(5129),
    [anon_sym_snorm] = ACTIONS(5129),
    [anon_sym_unorm] = ACTIONS(5129),
    [anon_sym_point] = ACTIONS(5129),
    [anon_sym_line] = ACTIONS(5129),
    [anon_sym_triangleadj] = ACTIONS(5129),
    [anon_sym_lineadj] = ACTIONS(5129),
    [anon_sym_triangle] = ACTIONS(5129),
  },
  [1941] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4758),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1942] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(5239),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1943] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4787),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1944] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4811),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1945] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4738),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1946] = {
    [sym_identifier] = ACTIONS(5133),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5135),
    [anon_sym_COMMA] = ACTIONS(5135),
    [anon_sym_RPAREN] = ACTIONS(5135),
    [anon_sym_LPAREN2] = ACTIONS(5135),
    [anon_sym_TILDE] = ACTIONS(5135),
    [anon_sym_STAR] = ACTIONS(5135),
    [anon_sym_AMP_AMP] = ACTIONS(5135),
    [anon_sym_AMP] = ACTIONS(5133),
    [anon_sym_SEMI] = ACTIONS(5135),
    [anon_sym___extension__] = ACTIONS(5133),
    [anon_sym_in] = ACTIONS(5133),
    [anon_sym_out] = ACTIONS(5133),
    [anon_sym_inout] = ACTIONS(5133),
    [anon_sym_extern] = ACTIONS(5133),
    [anon_sym___attribute__] = ACTIONS(5133),
    [anon_sym_COLON_COLON] = ACTIONS(5135),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5135),
    [anon_sym___declspec] = ACTIONS(5133),
    [anon_sym___based] = ACTIONS(5133),
    [anon_sym_LBRACE] = ACTIONS(5135),
    [anon_sym_signed] = ACTIONS(5133),
    [anon_sym_unsigned] = ACTIONS(5133),
    [anon_sym_long] = ACTIONS(5133),
    [anon_sym_short] = ACTIONS(5133),
    [anon_sym_LBRACK] = ACTIONS(5133),
    [anon_sym_static] = ACTIONS(5133),
    [anon_sym_EQ] = ACTIONS(5135),
    [anon_sym_register] = ACTIONS(5133),
    [anon_sym_inline] = ACTIONS(5133),
    [anon_sym___inline] = ACTIONS(5133),
    [anon_sym___inline__] = ACTIONS(5133),
    [anon_sym___forceinline] = ACTIONS(5133),
    [anon_sym_thread_local] = ACTIONS(5133),
    [anon_sym___thread] = ACTIONS(5133),
    [anon_sym_const] = ACTIONS(5133),
    [anon_sym_constexpr] = ACTIONS(5133),
    [anon_sym_volatile] = ACTIONS(5133),
    [anon_sym_restrict] = ACTIONS(5133),
    [anon_sym___restrict__] = ACTIONS(5133),
    [anon_sym__Atomic] = ACTIONS(5133),
    [anon_sym__Noreturn] = ACTIONS(5133),
    [anon_sym_noreturn] = ACTIONS(5133),
    [anon_sym_mutable] = ACTIONS(5133),
    [anon_sym_constinit] = ACTIONS(5133),
    [anon_sym_consteval] = ACTIONS(5133),
    [anon_sym_alignas] = ACTIONS(5133),
    [anon_sym__Alignas] = ACTIONS(5133),
    [sym_primitive_type] = ACTIONS(5133),
    [anon_sym_enum] = ACTIONS(5133),
    [anon_sym_class] = ACTIONS(5133),
    [anon_sym_struct] = ACTIONS(5133),
    [anon_sym_union] = ACTIONS(5133),
    [anon_sym_asm] = ACTIONS(5133),
    [anon_sym___asm__] = ACTIONS(5133),
    [anon_sym_DASH_GT] = ACTIONS(5135),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5133),
    [anon_sym_decltype] = ACTIONS(5133),
    [anon_sym_final] = ACTIONS(5133),
    [anon_sym_override] = ACTIONS(5133),
    [sym_virtual] = ACTIONS(5133),
    [anon_sym_explicit] = ACTIONS(5133),
    [anon_sym_typename] = ACTIONS(5133),
    [anon_sym_template] = ACTIONS(5133),
    [anon_sym_GT2] = ACTIONS(5135),
    [anon_sym_operator] = ACTIONS(5133),
    [anon_sym_try] = ACTIONS(5133),
    [anon_sym_noexcept] = ACTIONS(5133),
    [anon_sym_throw] = ACTIONS(5133),
    [anon_sym_requires] = ACTIONS(5133),
    [anon_sym_precise] = ACTIONS(5133),
    [anon_sym_shared] = ACTIONS(5133),
    [anon_sym_groupshared] = ACTIONS(5133),
    [anon_sym_uniform] = ACTIONS(5133),
    [anon_sym_row_major] = ACTIONS(5133),
    [anon_sym_column_major] = ACTIONS(5133),
    [anon_sym_globallycoherent] = ACTIONS(5133),
    [anon_sym_centroid] = ACTIONS(5133),
    [anon_sym_noperspective] = ACTIONS(5133),
    [anon_sym_nointerpolation] = ACTIONS(5133),
    [anon_sym_sample] = ACTIONS(5133),
    [anon_sym_linear] = ACTIONS(5133),
    [anon_sym_snorm] = ACTIONS(5133),
    [anon_sym_unorm] = ACTIONS(5133),
    [anon_sym_point] = ACTIONS(5133),
    [anon_sym_line] = ACTIONS(5133),
    [anon_sym_triangleadj] = ACTIONS(5133),
    [anon_sym_lineadj] = ACTIONS(5133),
    [anon_sym_triangle] = ACTIONS(5133),
  },
  [1947] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4782),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1948] = {
    [sym_catch_clause] = STATE(1975),
    [aux_sym_constructor_try_statement_repeat1] = STATE(1975),
    [sym_identifier] = ACTIONS(1984),
    [aux_sym_preproc_def_token1] = ACTIONS(1984),
    [aux_sym_preproc_if_token1] = ACTIONS(1984),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1984),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1984),
    [sym_preproc_directive] = ACTIONS(1984),
    [anon_sym_LPAREN2] = ACTIONS(1986),
    [anon_sym_TILDE] = ACTIONS(1986),
    [anon_sym_STAR] = ACTIONS(1986),
    [anon_sym_AMP_AMP] = ACTIONS(1986),
    [anon_sym_AMP] = ACTIONS(1984),
    [anon_sym___extension__] = ACTIONS(1984),
    [anon_sym_typedef] = ACTIONS(1984),
    [anon_sym_in] = ACTIONS(1984),
    [anon_sym_out] = ACTIONS(1984),
    [anon_sym_inout] = ACTIONS(1984),
    [anon_sym_extern] = ACTIONS(1984),
    [anon_sym___attribute__] = ACTIONS(1984),
    [anon_sym_COLON_COLON] = ACTIONS(1986),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1986),
    [anon_sym___declspec] = ACTIONS(1984),
    [anon_sym___based] = ACTIONS(1984),
    [anon_sym_RBRACE] = ACTIONS(1986),
    [anon_sym_signed] = ACTIONS(1984),
    [anon_sym_unsigned] = ACTIONS(1984),
    [anon_sym_long] = ACTIONS(1984),
    [anon_sym_short] = ACTIONS(1984),
    [anon_sym_LBRACK] = ACTIONS(1984),
    [anon_sym_static] = ACTIONS(1984),
    [anon_sym_register] = ACTIONS(1984),
    [anon_sym_inline] = ACTIONS(1984),
    [anon_sym___inline] = ACTIONS(1984),
    [anon_sym___inline__] = ACTIONS(1984),
    [anon_sym___forceinline] = ACTIONS(1984),
    [anon_sym_thread_local] = ACTIONS(1984),
    [anon_sym___thread] = ACTIONS(1984),
    [anon_sym_const] = ACTIONS(1984),
    [anon_sym_constexpr] = ACTIONS(1984),
    [anon_sym_volatile] = ACTIONS(1984),
    [anon_sym_restrict] = ACTIONS(1984),
    [anon_sym___restrict__] = ACTIONS(1984),
    [anon_sym__Atomic] = ACTIONS(1984),
    [anon_sym__Noreturn] = ACTIONS(1984),
    [anon_sym_noreturn] = ACTIONS(1984),
    [anon_sym_mutable] = ACTIONS(1984),
    [anon_sym_constinit] = ACTIONS(1984),
    [anon_sym_consteval] = ACTIONS(1984),
    [anon_sym_alignas] = ACTIONS(1984),
    [anon_sym__Alignas] = ACTIONS(1984),
    [sym_primitive_type] = ACTIONS(1984),
    [anon_sym_enum] = ACTIONS(1984),
    [anon_sym_class] = ACTIONS(1984),
    [anon_sym_struct] = ACTIONS(1984),
    [anon_sym_union] = ACTIONS(1984),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1984),
    [anon_sym_decltype] = ACTIONS(1984),
    [sym_virtual] = ACTIONS(1984),
    [anon_sym_explicit] = ACTIONS(1984),
    [anon_sym_typename] = ACTIONS(1984),
    [anon_sym_template] = ACTIONS(1984),
    [anon_sym_operator] = ACTIONS(1984),
    [anon_sym_friend] = ACTIONS(1984),
    [anon_sym_public] = ACTIONS(1984),
    [anon_sym_private] = ACTIONS(1984),
    [anon_sym_protected] = ACTIONS(1984),
    [anon_sym_using] = ACTIONS(1984),
    [anon_sym_static_assert] = ACTIONS(1984),
    [anon_sym_catch] = ACTIONS(5127),
    [anon_sym_precise] = ACTIONS(1984),
    [anon_sym_shared] = ACTIONS(1984),
    [anon_sym_groupshared] = ACTIONS(1984),
    [anon_sym_uniform] = ACTIONS(1984),
    [anon_sym_row_major] = ACTIONS(1984),
    [anon_sym_column_major] = ACTIONS(1984),
    [anon_sym_globallycoherent] = ACTIONS(1984),
    [anon_sym_centroid] = ACTIONS(1984),
    [anon_sym_noperspective] = ACTIONS(1984),
    [anon_sym_nointerpolation] = ACTIONS(1984),
    [anon_sym_sample] = ACTIONS(1984),
    [anon_sym_linear] = ACTIONS(1984),
    [anon_sym_snorm] = ACTIONS(1984),
    [anon_sym_unorm] = ACTIONS(1984),
    [anon_sym_point] = ACTIONS(1984),
    [anon_sym_line] = ACTIONS(1984),
    [anon_sym_triangleadj] = ACTIONS(1984),
    [anon_sym_lineadj] = ACTIONS(1984),
    [anon_sym_triangle] = ACTIONS(1984),
  },
  [1949] = {
    [sym_identifier] = ACTIONS(5119),
    [anon_sym_RPAREN] = ACTIONS(5121),
    [anon_sym_LPAREN2] = ACTIONS(5121),
    [anon_sym_TILDE] = ACTIONS(5121),
    [anon_sym_STAR] = ACTIONS(5121),
    [anon_sym_PIPE_PIPE] = ACTIONS(5121),
    [anon_sym_AMP_AMP] = ACTIONS(5121),
    [anon_sym_AMP] = ACTIONS(5119),
    [anon_sym___extension__] = ACTIONS(5119),
    [anon_sym_in] = ACTIONS(5119),
    [anon_sym_out] = ACTIONS(5119),
    [anon_sym_inout] = ACTIONS(5119),
    [anon_sym_extern] = ACTIONS(5119),
    [anon_sym___attribute__] = ACTIONS(5119),
    [anon_sym_COLON_COLON] = ACTIONS(5121),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5121),
    [anon_sym___declspec] = ACTIONS(5119),
    [anon_sym___based] = ACTIONS(5119),
    [anon_sym___cdecl] = ACTIONS(5119),
    [anon_sym___clrcall] = ACTIONS(5119),
    [anon_sym___stdcall] = ACTIONS(5119),
    [anon_sym___fastcall] = ACTIONS(5119),
    [anon_sym___thiscall] = ACTIONS(5119),
    [anon_sym___vectorcall] = ACTIONS(5119),
    [anon_sym_signed] = ACTIONS(5119),
    [anon_sym_unsigned] = ACTIONS(5119),
    [anon_sym_long] = ACTIONS(5119),
    [anon_sym_short] = ACTIONS(5119),
    [anon_sym_LBRACK] = ACTIONS(5119),
    [anon_sym_static] = ACTIONS(5119),
    [anon_sym_register] = ACTIONS(5119),
    [anon_sym_inline] = ACTIONS(5119),
    [anon_sym___inline] = ACTIONS(5119),
    [anon_sym___inline__] = ACTIONS(5119),
    [anon_sym___forceinline] = ACTIONS(5119),
    [anon_sym_thread_local] = ACTIONS(5119),
    [anon_sym___thread] = ACTIONS(5119),
    [anon_sym_const] = ACTIONS(5119),
    [anon_sym_constexpr] = ACTIONS(5119),
    [anon_sym_volatile] = ACTIONS(5119),
    [anon_sym_restrict] = ACTIONS(5119),
    [anon_sym___restrict__] = ACTIONS(5119),
    [anon_sym__Atomic] = ACTIONS(5119),
    [anon_sym__Noreturn] = ACTIONS(5119),
    [anon_sym_noreturn] = ACTIONS(5119),
    [anon_sym_mutable] = ACTIONS(5119),
    [anon_sym_constinit] = ACTIONS(5119),
    [anon_sym_consteval] = ACTIONS(5119),
    [anon_sym_alignas] = ACTIONS(5119),
    [anon_sym__Alignas] = ACTIONS(5119),
    [sym_primitive_type] = ACTIONS(5119),
    [anon_sym_enum] = ACTIONS(5119),
    [anon_sym_class] = ACTIONS(5119),
    [anon_sym_struct] = ACTIONS(5119),
    [anon_sym_union] = ACTIONS(5119),
    [anon_sym_or] = ACTIONS(5119),
    [anon_sym_and] = ACTIONS(5119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5119),
    [anon_sym_decltype] = ACTIONS(5119),
    [anon_sym_final] = ACTIONS(5119),
    [anon_sym_override] = ACTIONS(5119),
    [sym_virtual] = ACTIONS(5119),
    [anon_sym_explicit] = ACTIONS(5119),
    [anon_sym_typename] = ACTIONS(5119),
    [anon_sym_template] = ACTIONS(5119),
    [anon_sym_operator] = ACTIONS(5119),
    [anon_sym_friend] = ACTIONS(5119),
    [anon_sym_using] = ACTIONS(5119),
    [anon_sym_concept] = ACTIONS(5119),
    [anon_sym_requires] = ACTIONS(5119),
    [anon_sym_precise] = ACTIONS(5119),
    [anon_sym_shared] = ACTIONS(5119),
    [anon_sym_groupshared] = ACTIONS(5119),
    [anon_sym_uniform] = ACTIONS(5119),
    [anon_sym_row_major] = ACTIONS(5119),
    [anon_sym_column_major] = ACTIONS(5119),
    [anon_sym_globallycoherent] = ACTIONS(5119),
    [anon_sym_centroid] = ACTIONS(5119),
    [anon_sym_noperspective] = ACTIONS(5119),
    [anon_sym_nointerpolation] = ACTIONS(5119),
    [anon_sym_sample] = ACTIONS(5119),
    [anon_sym_linear] = ACTIONS(5119),
    [anon_sym_snorm] = ACTIONS(5119),
    [anon_sym_unorm] = ACTIONS(5119),
    [anon_sym_point] = ACTIONS(5119),
    [anon_sym_line] = ACTIONS(5119),
    [anon_sym_triangleadj] = ACTIONS(5119),
    [anon_sym_lineadj] = ACTIONS(5119),
    [anon_sym_triangle] = ACTIONS(5119),
  },
  [1950] = {
    [sym_identifier] = ACTIONS(5137),
    [anon_sym_RPAREN] = ACTIONS(5139),
    [anon_sym_LPAREN2] = ACTIONS(5139),
    [anon_sym_TILDE] = ACTIONS(5139),
    [anon_sym_STAR] = ACTIONS(5139),
    [anon_sym_PIPE_PIPE] = ACTIONS(5139),
    [anon_sym_AMP_AMP] = ACTIONS(5139),
    [anon_sym_AMP] = ACTIONS(5137),
    [anon_sym___extension__] = ACTIONS(5137),
    [anon_sym_in] = ACTIONS(5137),
    [anon_sym_out] = ACTIONS(5137),
    [anon_sym_inout] = ACTIONS(5137),
    [anon_sym_extern] = ACTIONS(5137),
    [anon_sym___attribute__] = ACTIONS(5137),
    [anon_sym_COLON_COLON] = ACTIONS(5139),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5139),
    [anon_sym___declspec] = ACTIONS(5137),
    [anon_sym___based] = ACTIONS(5137),
    [anon_sym___cdecl] = ACTIONS(5137),
    [anon_sym___clrcall] = ACTIONS(5137),
    [anon_sym___stdcall] = ACTIONS(5137),
    [anon_sym___fastcall] = ACTIONS(5137),
    [anon_sym___thiscall] = ACTIONS(5137),
    [anon_sym___vectorcall] = ACTIONS(5137),
    [anon_sym_signed] = ACTIONS(5137),
    [anon_sym_unsigned] = ACTIONS(5137),
    [anon_sym_long] = ACTIONS(5137),
    [anon_sym_short] = ACTIONS(5137),
    [anon_sym_LBRACK] = ACTIONS(5137),
    [anon_sym_static] = ACTIONS(5137),
    [anon_sym_register] = ACTIONS(5137),
    [anon_sym_inline] = ACTIONS(5137),
    [anon_sym___inline] = ACTIONS(5137),
    [anon_sym___inline__] = ACTIONS(5137),
    [anon_sym___forceinline] = ACTIONS(5137),
    [anon_sym_thread_local] = ACTIONS(5137),
    [anon_sym___thread] = ACTIONS(5137),
    [anon_sym_const] = ACTIONS(5137),
    [anon_sym_constexpr] = ACTIONS(5137),
    [anon_sym_volatile] = ACTIONS(5137),
    [anon_sym_restrict] = ACTIONS(5137),
    [anon_sym___restrict__] = ACTIONS(5137),
    [anon_sym__Atomic] = ACTIONS(5137),
    [anon_sym__Noreturn] = ACTIONS(5137),
    [anon_sym_noreturn] = ACTIONS(5137),
    [anon_sym_mutable] = ACTIONS(5137),
    [anon_sym_constinit] = ACTIONS(5137),
    [anon_sym_consteval] = ACTIONS(5137),
    [anon_sym_alignas] = ACTIONS(5137),
    [anon_sym__Alignas] = ACTIONS(5137),
    [sym_primitive_type] = ACTIONS(5137),
    [anon_sym_enum] = ACTIONS(5137),
    [anon_sym_class] = ACTIONS(5137),
    [anon_sym_struct] = ACTIONS(5137),
    [anon_sym_union] = ACTIONS(5137),
    [anon_sym_or] = ACTIONS(5137),
    [anon_sym_and] = ACTIONS(5137),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5137),
    [anon_sym_decltype] = ACTIONS(5137),
    [anon_sym_final] = ACTIONS(5137),
    [anon_sym_override] = ACTIONS(5137),
    [sym_virtual] = ACTIONS(5137),
    [anon_sym_explicit] = ACTIONS(5137),
    [anon_sym_typename] = ACTIONS(5137),
    [anon_sym_template] = ACTIONS(5137),
    [anon_sym_operator] = ACTIONS(5137),
    [anon_sym_friend] = ACTIONS(5137),
    [anon_sym_using] = ACTIONS(5137),
    [anon_sym_concept] = ACTIONS(5137),
    [anon_sym_requires] = ACTIONS(5137),
    [anon_sym_precise] = ACTIONS(5137),
    [anon_sym_shared] = ACTIONS(5137),
    [anon_sym_groupshared] = ACTIONS(5137),
    [anon_sym_uniform] = ACTIONS(5137),
    [anon_sym_row_major] = ACTIONS(5137),
    [anon_sym_column_major] = ACTIONS(5137),
    [anon_sym_globallycoherent] = ACTIONS(5137),
    [anon_sym_centroid] = ACTIONS(5137),
    [anon_sym_noperspective] = ACTIONS(5137),
    [anon_sym_nointerpolation] = ACTIONS(5137),
    [anon_sym_sample] = ACTIONS(5137),
    [anon_sym_linear] = ACTIONS(5137),
    [anon_sym_snorm] = ACTIONS(5137),
    [anon_sym_unorm] = ACTIONS(5137),
    [anon_sym_point] = ACTIONS(5137),
    [anon_sym_line] = ACTIONS(5137),
    [anon_sym_triangleadj] = ACTIONS(5137),
    [anon_sym_lineadj] = ACTIONS(5137),
    [anon_sym_triangle] = ACTIONS(5137),
  },
  [1951] = {
    [sym_identifier] = ACTIONS(5141),
    [anon_sym_RPAREN] = ACTIONS(5143),
    [anon_sym_LPAREN2] = ACTIONS(5143),
    [anon_sym_TILDE] = ACTIONS(5143),
    [anon_sym_STAR] = ACTIONS(5143),
    [anon_sym_PIPE_PIPE] = ACTIONS(5143),
    [anon_sym_AMP_AMP] = ACTIONS(5143),
    [anon_sym_AMP] = ACTIONS(5141),
    [anon_sym___extension__] = ACTIONS(5141),
    [anon_sym_in] = ACTIONS(5141),
    [anon_sym_out] = ACTIONS(5141),
    [anon_sym_inout] = ACTIONS(5141),
    [anon_sym_extern] = ACTIONS(5141),
    [anon_sym___attribute__] = ACTIONS(5141),
    [anon_sym_COLON_COLON] = ACTIONS(5143),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5143),
    [anon_sym___declspec] = ACTIONS(5141),
    [anon_sym___based] = ACTIONS(5141),
    [anon_sym___cdecl] = ACTIONS(5141),
    [anon_sym___clrcall] = ACTIONS(5141),
    [anon_sym___stdcall] = ACTIONS(5141),
    [anon_sym___fastcall] = ACTIONS(5141),
    [anon_sym___thiscall] = ACTIONS(5141),
    [anon_sym___vectorcall] = ACTIONS(5141),
    [anon_sym_signed] = ACTIONS(5141),
    [anon_sym_unsigned] = ACTIONS(5141),
    [anon_sym_long] = ACTIONS(5141),
    [anon_sym_short] = ACTIONS(5141),
    [anon_sym_LBRACK] = ACTIONS(5141),
    [anon_sym_static] = ACTIONS(5141),
    [anon_sym_register] = ACTIONS(5141),
    [anon_sym_inline] = ACTIONS(5141),
    [anon_sym___inline] = ACTIONS(5141),
    [anon_sym___inline__] = ACTIONS(5141),
    [anon_sym___forceinline] = ACTIONS(5141),
    [anon_sym_thread_local] = ACTIONS(5141),
    [anon_sym___thread] = ACTIONS(5141),
    [anon_sym_const] = ACTIONS(5141),
    [anon_sym_constexpr] = ACTIONS(5141),
    [anon_sym_volatile] = ACTIONS(5141),
    [anon_sym_restrict] = ACTIONS(5141),
    [anon_sym___restrict__] = ACTIONS(5141),
    [anon_sym__Atomic] = ACTIONS(5141),
    [anon_sym__Noreturn] = ACTIONS(5141),
    [anon_sym_noreturn] = ACTIONS(5141),
    [anon_sym_mutable] = ACTIONS(5141),
    [anon_sym_constinit] = ACTIONS(5141),
    [anon_sym_consteval] = ACTIONS(5141),
    [anon_sym_alignas] = ACTIONS(5141),
    [anon_sym__Alignas] = ACTIONS(5141),
    [sym_primitive_type] = ACTIONS(5141),
    [anon_sym_enum] = ACTIONS(5141),
    [anon_sym_class] = ACTIONS(5141),
    [anon_sym_struct] = ACTIONS(5141),
    [anon_sym_union] = ACTIONS(5141),
    [anon_sym_or] = ACTIONS(5141),
    [anon_sym_and] = ACTIONS(5141),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5141),
    [anon_sym_decltype] = ACTIONS(5141),
    [anon_sym_final] = ACTIONS(5141),
    [anon_sym_override] = ACTIONS(5141),
    [sym_virtual] = ACTIONS(5141),
    [anon_sym_explicit] = ACTIONS(5141),
    [anon_sym_typename] = ACTIONS(5141),
    [anon_sym_template] = ACTIONS(5141),
    [anon_sym_operator] = ACTIONS(5141),
    [anon_sym_friend] = ACTIONS(5141),
    [anon_sym_using] = ACTIONS(5141),
    [anon_sym_concept] = ACTIONS(5141),
    [anon_sym_requires] = ACTIONS(5141),
    [anon_sym_precise] = ACTIONS(5141),
    [anon_sym_shared] = ACTIONS(5141),
    [anon_sym_groupshared] = ACTIONS(5141),
    [anon_sym_uniform] = ACTIONS(5141),
    [anon_sym_row_major] = ACTIONS(5141),
    [anon_sym_column_major] = ACTIONS(5141),
    [anon_sym_globallycoherent] = ACTIONS(5141),
    [anon_sym_centroid] = ACTIONS(5141),
    [anon_sym_noperspective] = ACTIONS(5141),
    [anon_sym_nointerpolation] = ACTIONS(5141),
    [anon_sym_sample] = ACTIONS(5141),
    [anon_sym_linear] = ACTIONS(5141),
    [anon_sym_snorm] = ACTIONS(5141),
    [anon_sym_unorm] = ACTIONS(5141),
    [anon_sym_point] = ACTIONS(5141),
    [anon_sym_line] = ACTIONS(5141),
    [anon_sym_triangleadj] = ACTIONS(5141),
    [anon_sym_lineadj] = ACTIONS(5141),
    [anon_sym_triangle] = ACTIONS(5141),
  },
  [1952] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4785),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1953] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4733),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1954] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4824),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1955] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4825),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1956] = {
    [sym_identifier] = ACTIONS(5119),
    [anon_sym_RPAREN] = ACTIONS(5121),
    [anon_sym_LPAREN2] = ACTIONS(5121),
    [anon_sym_TILDE] = ACTIONS(5121),
    [anon_sym_STAR] = ACTIONS(5121),
    [anon_sym_PIPE_PIPE] = ACTIONS(5121),
    [anon_sym_AMP_AMP] = ACTIONS(5121),
    [anon_sym_AMP] = ACTIONS(5119),
    [anon_sym___extension__] = ACTIONS(5119),
    [anon_sym_in] = ACTIONS(5119),
    [anon_sym_out] = ACTIONS(5119),
    [anon_sym_inout] = ACTIONS(5119),
    [anon_sym_extern] = ACTIONS(5119),
    [anon_sym___attribute__] = ACTIONS(5119),
    [anon_sym_COLON_COLON] = ACTIONS(5121),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5121),
    [anon_sym___declspec] = ACTIONS(5119),
    [anon_sym___based] = ACTIONS(5119),
    [anon_sym___cdecl] = ACTIONS(5119),
    [anon_sym___clrcall] = ACTIONS(5119),
    [anon_sym___stdcall] = ACTIONS(5119),
    [anon_sym___fastcall] = ACTIONS(5119),
    [anon_sym___thiscall] = ACTIONS(5119),
    [anon_sym___vectorcall] = ACTIONS(5119),
    [anon_sym_signed] = ACTIONS(5119),
    [anon_sym_unsigned] = ACTIONS(5119),
    [anon_sym_long] = ACTIONS(5119),
    [anon_sym_short] = ACTIONS(5119),
    [anon_sym_LBRACK] = ACTIONS(5119),
    [anon_sym_static] = ACTIONS(5119),
    [anon_sym_register] = ACTIONS(5119),
    [anon_sym_inline] = ACTIONS(5119),
    [anon_sym___inline] = ACTIONS(5119),
    [anon_sym___inline__] = ACTIONS(5119),
    [anon_sym___forceinline] = ACTIONS(5119),
    [anon_sym_thread_local] = ACTIONS(5119),
    [anon_sym___thread] = ACTIONS(5119),
    [anon_sym_const] = ACTIONS(5119),
    [anon_sym_constexpr] = ACTIONS(5119),
    [anon_sym_volatile] = ACTIONS(5119),
    [anon_sym_restrict] = ACTIONS(5119),
    [anon_sym___restrict__] = ACTIONS(5119),
    [anon_sym__Atomic] = ACTIONS(5119),
    [anon_sym__Noreturn] = ACTIONS(5119),
    [anon_sym_noreturn] = ACTIONS(5119),
    [anon_sym_mutable] = ACTIONS(5119),
    [anon_sym_constinit] = ACTIONS(5119),
    [anon_sym_consteval] = ACTIONS(5119),
    [anon_sym_alignas] = ACTIONS(5119),
    [anon_sym__Alignas] = ACTIONS(5119),
    [sym_primitive_type] = ACTIONS(5119),
    [anon_sym_enum] = ACTIONS(5119),
    [anon_sym_class] = ACTIONS(5119),
    [anon_sym_struct] = ACTIONS(5119),
    [anon_sym_union] = ACTIONS(5119),
    [anon_sym_or] = ACTIONS(5119),
    [anon_sym_and] = ACTIONS(5119),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5119),
    [anon_sym_decltype] = ACTIONS(5119),
    [anon_sym_final] = ACTIONS(5119),
    [anon_sym_override] = ACTIONS(5119),
    [sym_virtual] = ACTIONS(5119),
    [anon_sym_explicit] = ACTIONS(5119),
    [anon_sym_typename] = ACTIONS(5119),
    [anon_sym_template] = ACTIONS(5119),
    [anon_sym_operator] = ACTIONS(5119),
    [anon_sym_friend] = ACTIONS(5119),
    [anon_sym_using] = ACTIONS(5119),
    [anon_sym_concept] = ACTIONS(5119),
    [anon_sym_requires] = ACTIONS(5119),
    [anon_sym_precise] = ACTIONS(5119),
    [anon_sym_shared] = ACTIONS(5119),
    [anon_sym_groupshared] = ACTIONS(5119),
    [anon_sym_uniform] = ACTIONS(5119),
    [anon_sym_row_major] = ACTIONS(5119),
    [anon_sym_column_major] = ACTIONS(5119),
    [anon_sym_globallycoherent] = ACTIONS(5119),
    [anon_sym_centroid] = ACTIONS(5119),
    [anon_sym_noperspective] = ACTIONS(5119),
    [anon_sym_nointerpolation] = ACTIONS(5119),
    [anon_sym_sample] = ACTIONS(5119),
    [anon_sym_linear] = ACTIONS(5119),
    [anon_sym_snorm] = ACTIONS(5119),
    [anon_sym_unorm] = ACTIONS(5119),
    [anon_sym_point] = ACTIONS(5119),
    [anon_sym_line] = ACTIONS(5119),
    [anon_sym_triangleadj] = ACTIONS(5119),
    [anon_sym_lineadj] = ACTIONS(5119),
    [anon_sym_triangle] = ACTIONS(5119),
  },
  [1957] = {
    [sym_identifier] = ACTIONS(2849),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2851),
    [anon_sym_COMMA] = ACTIONS(2851),
    [anon_sym_RPAREN] = ACTIONS(2851),
    [anon_sym_LPAREN2] = ACTIONS(2851),
    [anon_sym_TILDE] = ACTIONS(2851),
    [anon_sym_STAR] = ACTIONS(2851),
    [anon_sym_AMP_AMP] = ACTIONS(2851),
    [anon_sym_AMP] = ACTIONS(2849),
    [anon_sym_SEMI] = ACTIONS(2851),
    [anon_sym___extension__] = ACTIONS(2849),
    [anon_sym_in] = ACTIONS(2849),
    [anon_sym_out] = ACTIONS(2849),
    [anon_sym_inout] = ACTIONS(2849),
    [anon_sym_extern] = ACTIONS(2849),
    [anon_sym___attribute__] = ACTIONS(2849),
    [anon_sym_COLON_COLON] = ACTIONS(2851),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2851),
    [anon_sym___declspec] = ACTIONS(2849),
    [anon_sym___based] = ACTIONS(2849),
    [anon_sym_LBRACE] = ACTIONS(2851),
    [anon_sym_signed] = ACTIONS(2849),
    [anon_sym_unsigned] = ACTIONS(2849),
    [anon_sym_long] = ACTIONS(2849),
    [anon_sym_short] = ACTIONS(2849),
    [anon_sym_LBRACK] = ACTIONS(2849),
    [anon_sym_static] = ACTIONS(2849),
    [anon_sym_EQ] = ACTIONS(2851),
    [anon_sym_register] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2849),
    [anon_sym___inline] = ACTIONS(2849),
    [anon_sym___inline__] = ACTIONS(2849),
    [anon_sym___forceinline] = ACTIONS(2849),
    [anon_sym_thread_local] = ACTIONS(2849),
    [anon_sym___thread] = ACTIONS(2849),
    [anon_sym_const] = ACTIONS(2849),
    [anon_sym_constexpr] = ACTIONS(2849),
    [anon_sym_volatile] = ACTIONS(2849),
    [anon_sym_restrict] = ACTIONS(2849),
    [anon_sym___restrict__] = ACTIONS(2849),
    [anon_sym__Atomic] = ACTIONS(2849),
    [anon_sym__Noreturn] = ACTIONS(2849),
    [anon_sym_noreturn] = ACTIONS(2849),
    [anon_sym_mutable] = ACTIONS(2849),
    [anon_sym_constinit] = ACTIONS(2849),
    [anon_sym_consteval] = ACTIONS(2849),
    [anon_sym_alignas] = ACTIONS(2849),
    [anon_sym__Alignas] = ACTIONS(2849),
    [sym_primitive_type] = ACTIONS(2849),
    [anon_sym_enum] = ACTIONS(2849),
    [anon_sym_class] = ACTIONS(2849),
    [anon_sym_struct] = ACTIONS(2849),
    [anon_sym_union] = ACTIONS(2849),
    [anon_sym_asm] = ACTIONS(2849),
    [anon_sym___asm__] = ACTIONS(2849),
    [anon_sym_DASH_GT] = ACTIONS(2851),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2849),
    [anon_sym_decltype] = ACTIONS(2849),
    [anon_sym_final] = ACTIONS(2849),
    [anon_sym_override] = ACTIONS(2849),
    [sym_virtual] = ACTIONS(2849),
    [anon_sym_explicit] = ACTIONS(2849),
    [anon_sym_typename] = ACTIONS(2849),
    [anon_sym_template] = ACTIONS(2849),
    [anon_sym_GT2] = ACTIONS(2851),
    [anon_sym_operator] = ACTIONS(2849),
    [anon_sym_try] = ACTIONS(2849),
    [anon_sym_noexcept] = ACTIONS(2849),
    [anon_sym_throw] = ACTIONS(2849),
    [anon_sym_requires] = ACTIONS(2849),
    [anon_sym_precise] = ACTIONS(2849),
    [anon_sym_shared] = ACTIONS(2849),
    [anon_sym_groupshared] = ACTIONS(2849),
    [anon_sym_uniform] = ACTIONS(2849),
    [anon_sym_row_major] = ACTIONS(2849),
    [anon_sym_column_major] = ACTIONS(2849),
    [anon_sym_globallycoherent] = ACTIONS(2849),
    [anon_sym_centroid] = ACTIONS(2849),
    [anon_sym_noperspective] = ACTIONS(2849),
    [anon_sym_nointerpolation] = ACTIONS(2849),
    [anon_sym_sample] = ACTIONS(2849),
    [anon_sym_linear] = ACTIONS(2849),
    [anon_sym_snorm] = ACTIONS(2849),
    [anon_sym_unorm] = ACTIONS(2849),
    [anon_sym_point] = ACTIONS(2849),
    [anon_sym_line] = ACTIONS(2849),
    [anon_sym_triangleadj] = ACTIONS(2849),
    [anon_sym_lineadj] = ACTIONS(2849),
    [anon_sym_triangle] = ACTIONS(2849),
  },
  [1958] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4834),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1959] = {
    [sym_catch_clause] = STATE(1975),
    [aux_sym_constructor_try_statement_repeat1] = STATE(1975),
    [sym_identifier] = ACTIONS(1990),
    [aux_sym_preproc_def_token1] = ACTIONS(1990),
    [aux_sym_preproc_if_token1] = ACTIONS(1990),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1990),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1990),
    [sym_preproc_directive] = ACTIONS(1990),
    [anon_sym_LPAREN2] = ACTIONS(1992),
    [anon_sym_TILDE] = ACTIONS(1992),
    [anon_sym_STAR] = ACTIONS(1992),
    [anon_sym_AMP_AMP] = ACTIONS(1992),
    [anon_sym_AMP] = ACTIONS(1990),
    [anon_sym___extension__] = ACTIONS(1990),
    [anon_sym_typedef] = ACTIONS(1990),
    [anon_sym_in] = ACTIONS(1990),
    [anon_sym_out] = ACTIONS(1990),
    [anon_sym_inout] = ACTIONS(1990),
    [anon_sym_extern] = ACTIONS(1990),
    [anon_sym___attribute__] = ACTIONS(1990),
    [anon_sym_COLON_COLON] = ACTIONS(1992),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1992),
    [anon_sym___declspec] = ACTIONS(1990),
    [anon_sym___based] = ACTIONS(1990),
    [anon_sym_RBRACE] = ACTIONS(1992),
    [anon_sym_signed] = ACTIONS(1990),
    [anon_sym_unsigned] = ACTIONS(1990),
    [anon_sym_long] = ACTIONS(1990),
    [anon_sym_short] = ACTIONS(1990),
    [anon_sym_LBRACK] = ACTIONS(1990),
    [anon_sym_static] = ACTIONS(1990),
    [anon_sym_register] = ACTIONS(1990),
    [anon_sym_inline] = ACTIONS(1990),
    [anon_sym___inline] = ACTIONS(1990),
    [anon_sym___inline__] = ACTIONS(1990),
    [anon_sym___forceinline] = ACTIONS(1990),
    [anon_sym_thread_local] = ACTIONS(1990),
    [anon_sym___thread] = ACTIONS(1990),
    [anon_sym_const] = ACTIONS(1990),
    [anon_sym_constexpr] = ACTIONS(1990),
    [anon_sym_volatile] = ACTIONS(1990),
    [anon_sym_restrict] = ACTIONS(1990),
    [anon_sym___restrict__] = ACTIONS(1990),
    [anon_sym__Atomic] = ACTIONS(1990),
    [anon_sym__Noreturn] = ACTIONS(1990),
    [anon_sym_noreturn] = ACTIONS(1990),
    [anon_sym_mutable] = ACTIONS(1990),
    [anon_sym_constinit] = ACTIONS(1990),
    [anon_sym_consteval] = ACTIONS(1990),
    [anon_sym_alignas] = ACTIONS(1990),
    [anon_sym__Alignas] = ACTIONS(1990),
    [sym_primitive_type] = ACTIONS(1990),
    [anon_sym_enum] = ACTIONS(1990),
    [anon_sym_class] = ACTIONS(1990),
    [anon_sym_struct] = ACTIONS(1990),
    [anon_sym_union] = ACTIONS(1990),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1990),
    [anon_sym_decltype] = ACTIONS(1990),
    [sym_virtual] = ACTIONS(1990),
    [anon_sym_explicit] = ACTIONS(1990),
    [anon_sym_typename] = ACTIONS(1990),
    [anon_sym_template] = ACTIONS(1990),
    [anon_sym_operator] = ACTIONS(1990),
    [anon_sym_friend] = ACTIONS(1990),
    [anon_sym_public] = ACTIONS(1990),
    [anon_sym_private] = ACTIONS(1990),
    [anon_sym_protected] = ACTIONS(1990),
    [anon_sym_using] = ACTIONS(1990),
    [anon_sym_static_assert] = ACTIONS(1990),
    [anon_sym_catch] = ACTIONS(5127),
    [anon_sym_precise] = ACTIONS(1990),
    [anon_sym_shared] = ACTIONS(1990),
    [anon_sym_groupshared] = ACTIONS(1990),
    [anon_sym_uniform] = ACTIONS(1990),
    [anon_sym_row_major] = ACTIONS(1990),
    [anon_sym_column_major] = ACTIONS(1990),
    [anon_sym_globallycoherent] = ACTIONS(1990),
    [anon_sym_centroid] = ACTIONS(1990),
    [anon_sym_noperspective] = ACTIONS(1990),
    [anon_sym_nointerpolation] = ACTIONS(1990),
    [anon_sym_sample] = ACTIONS(1990),
    [anon_sym_linear] = ACTIONS(1990),
    [anon_sym_snorm] = ACTIONS(1990),
    [anon_sym_unorm] = ACTIONS(1990),
    [anon_sym_point] = ACTIONS(1990),
    [anon_sym_line] = ACTIONS(1990),
    [anon_sym_triangleadj] = ACTIONS(1990),
    [anon_sym_lineadj] = ACTIONS(1990),
    [anon_sym_triangle] = ACTIONS(1990),
  },
  [1960] = {
    [sym_identifier] = ACTIONS(5145),
    [anon_sym_RPAREN] = ACTIONS(5147),
    [anon_sym_LPAREN2] = ACTIONS(5147),
    [anon_sym_TILDE] = ACTIONS(5147),
    [anon_sym_STAR] = ACTIONS(5147),
    [anon_sym_PIPE_PIPE] = ACTIONS(5147),
    [anon_sym_AMP_AMP] = ACTIONS(5147),
    [anon_sym_AMP] = ACTIONS(5145),
    [anon_sym___extension__] = ACTIONS(5145),
    [anon_sym_in] = ACTIONS(5145),
    [anon_sym_out] = ACTIONS(5145),
    [anon_sym_inout] = ACTIONS(5145),
    [anon_sym_extern] = ACTIONS(5145),
    [anon_sym___attribute__] = ACTIONS(5145),
    [anon_sym_COLON_COLON] = ACTIONS(5147),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5147),
    [anon_sym___declspec] = ACTIONS(5145),
    [anon_sym___based] = ACTIONS(5145),
    [anon_sym___cdecl] = ACTIONS(5145),
    [anon_sym___clrcall] = ACTIONS(5145),
    [anon_sym___stdcall] = ACTIONS(5145),
    [anon_sym___fastcall] = ACTIONS(5145),
    [anon_sym___thiscall] = ACTIONS(5145),
    [anon_sym___vectorcall] = ACTIONS(5145),
    [anon_sym_signed] = ACTIONS(5145),
    [anon_sym_unsigned] = ACTIONS(5145),
    [anon_sym_long] = ACTIONS(5145),
    [anon_sym_short] = ACTIONS(5145),
    [anon_sym_LBRACK] = ACTIONS(5145),
    [anon_sym_static] = ACTIONS(5145),
    [anon_sym_register] = ACTIONS(5145),
    [anon_sym_inline] = ACTIONS(5145),
    [anon_sym___inline] = ACTIONS(5145),
    [anon_sym___inline__] = ACTIONS(5145),
    [anon_sym___forceinline] = ACTIONS(5145),
    [anon_sym_thread_local] = ACTIONS(5145),
    [anon_sym___thread] = ACTIONS(5145),
    [anon_sym_const] = ACTIONS(5145),
    [anon_sym_constexpr] = ACTIONS(5145),
    [anon_sym_volatile] = ACTIONS(5145),
    [anon_sym_restrict] = ACTIONS(5145),
    [anon_sym___restrict__] = ACTIONS(5145),
    [anon_sym__Atomic] = ACTIONS(5145),
    [anon_sym__Noreturn] = ACTIONS(5145),
    [anon_sym_noreturn] = ACTIONS(5145),
    [anon_sym_mutable] = ACTIONS(5145),
    [anon_sym_constinit] = ACTIONS(5145),
    [anon_sym_consteval] = ACTIONS(5145),
    [anon_sym_alignas] = ACTIONS(5145),
    [anon_sym__Alignas] = ACTIONS(5145),
    [sym_primitive_type] = ACTIONS(5145),
    [anon_sym_enum] = ACTIONS(5145),
    [anon_sym_class] = ACTIONS(5145),
    [anon_sym_struct] = ACTIONS(5145),
    [anon_sym_union] = ACTIONS(5145),
    [anon_sym_or] = ACTIONS(5145),
    [anon_sym_and] = ACTIONS(5145),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5145),
    [anon_sym_decltype] = ACTIONS(5145),
    [anon_sym_final] = ACTIONS(5145),
    [anon_sym_override] = ACTIONS(5145),
    [sym_virtual] = ACTIONS(5145),
    [anon_sym_explicit] = ACTIONS(5145),
    [anon_sym_typename] = ACTIONS(5145),
    [anon_sym_template] = ACTIONS(5145),
    [anon_sym_operator] = ACTIONS(5145),
    [anon_sym_friend] = ACTIONS(5145),
    [anon_sym_using] = ACTIONS(5145),
    [anon_sym_concept] = ACTIONS(5145),
    [anon_sym_requires] = ACTIONS(5145),
    [anon_sym_precise] = ACTIONS(5145),
    [anon_sym_shared] = ACTIONS(5145),
    [anon_sym_groupshared] = ACTIONS(5145),
    [anon_sym_uniform] = ACTIONS(5145),
    [anon_sym_row_major] = ACTIONS(5145),
    [anon_sym_column_major] = ACTIONS(5145),
    [anon_sym_globallycoherent] = ACTIONS(5145),
    [anon_sym_centroid] = ACTIONS(5145),
    [anon_sym_noperspective] = ACTIONS(5145),
    [anon_sym_nointerpolation] = ACTIONS(5145),
    [anon_sym_sample] = ACTIONS(5145),
    [anon_sym_linear] = ACTIONS(5145),
    [anon_sym_snorm] = ACTIONS(5145),
    [anon_sym_unorm] = ACTIONS(5145),
    [anon_sym_point] = ACTIONS(5145),
    [anon_sym_line] = ACTIONS(5145),
    [anon_sym_triangleadj] = ACTIONS(5145),
    [anon_sym_lineadj] = ACTIONS(5145),
    [anon_sym_triangle] = ACTIONS(5145),
  },
  [1961] = {
    [sym_identifier] = ACTIONS(5149),
    [anon_sym_RPAREN] = ACTIONS(5151),
    [anon_sym_LPAREN2] = ACTIONS(5151),
    [anon_sym_TILDE] = ACTIONS(5151),
    [anon_sym_STAR] = ACTIONS(5151),
    [anon_sym_PIPE_PIPE] = ACTIONS(5151),
    [anon_sym_AMP_AMP] = ACTIONS(5151),
    [anon_sym_AMP] = ACTIONS(5149),
    [anon_sym___extension__] = ACTIONS(5149),
    [anon_sym_in] = ACTIONS(5149),
    [anon_sym_out] = ACTIONS(5149),
    [anon_sym_inout] = ACTIONS(5149),
    [anon_sym_extern] = ACTIONS(5149),
    [anon_sym___attribute__] = ACTIONS(5149),
    [anon_sym_COLON_COLON] = ACTIONS(5151),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5151),
    [anon_sym___declspec] = ACTIONS(5149),
    [anon_sym___based] = ACTIONS(5149),
    [anon_sym___cdecl] = ACTIONS(5149),
    [anon_sym___clrcall] = ACTIONS(5149),
    [anon_sym___stdcall] = ACTIONS(5149),
    [anon_sym___fastcall] = ACTIONS(5149),
    [anon_sym___thiscall] = ACTIONS(5149),
    [anon_sym___vectorcall] = ACTIONS(5149),
    [anon_sym_signed] = ACTIONS(5149),
    [anon_sym_unsigned] = ACTIONS(5149),
    [anon_sym_long] = ACTIONS(5149),
    [anon_sym_short] = ACTIONS(5149),
    [anon_sym_LBRACK] = ACTIONS(5149),
    [anon_sym_static] = ACTIONS(5149),
    [anon_sym_register] = ACTIONS(5149),
    [anon_sym_inline] = ACTIONS(5149),
    [anon_sym___inline] = ACTIONS(5149),
    [anon_sym___inline__] = ACTIONS(5149),
    [anon_sym___forceinline] = ACTIONS(5149),
    [anon_sym_thread_local] = ACTIONS(5149),
    [anon_sym___thread] = ACTIONS(5149),
    [anon_sym_const] = ACTIONS(5149),
    [anon_sym_constexpr] = ACTIONS(5149),
    [anon_sym_volatile] = ACTIONS(5149),
    [anon_sym_restrict] = ACTIONS(5149),
    [anon_sym___restrict__] = ACTIONS(5149),
    [anon_sym__Atomic] = ACTIONS(5149),
    [anon_sym__Noreturn] = ACTIONS(5149),
    [anon_sym_noreturn] = ACTIONS(5149),
    [anon_sym_mutable] = ACTIONS(5149),
    [anon_sym_constinit] = ACTIONS(5149),
    [anon_sym_consteval] = ACTIONS(5149),
    [anon_sym_alignas] = ACTIONS(5149),
    [anon_sym__Alignas] = ACTIONS(5149),
    [sym_primitive_type] = ACTIONS(5149),
    [anon_sym_enum] = ACTIONS(5149),
    [anon_sym_class] = ACTIONS(5149),
    [anon_sym_struct] = ACTIONS(5149),
    [anon_sym_union] = ACTIONS(5149),
    [anon_sym_or] = ACTIONS(5149),
    [anon_sym_and] = ACTIONS(5149),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5149),
    [anon_sym_decltype] = ACTIONS(5149),
    [anon_sym_final] = ACTIONS(5149),
    [anon_sym_override] = ACTIONS(5149),
    [sym_virtual] = ACTIONS(5149),
    [anon_sym_explicit] = ACTIONS(5149),
    [anon_sym_typename] = ACTIONS(5149),
    [anon_sym_template] = ACTIONS(5149),
    [anon_sym_operator] = ACTIONS(5149),
    [anon_sym_friend] = ACTIONS(5149),
    [anon_sym_using] = ACTIONS(5149),
    [anon_sym_concept] = ACTIONS(5149),
    [anon_sym_requires] = ACTIONS(5149),
    [anon_sym_precise] = ACTIONS(5149),
    [anon_sym_shared] = ACTIONS(5149),
    [anon_sym_groupshared] = ACTIONS(5149),
    [anon_sym_uniform] = ACTIONS(5149),
    [anon_sym_row_major] = ACTIONS(5149),
    [anon_sym_column_major] = ACTIONS(5149),
    [anon_sym_globallycoherent] = ACTIONS(5149),
    [anon_sym_centroid] = ACTIONS(5149),
    [anon_sym_noperspective] = ACTIONS(5149),
    [anon_sym_nointerpolation] = ACTIONS(5149),
    [anon_sym_sample] = ACTIONS(5149),
    [anon_sym_linear] = ACTIONS(5149),
    [anon_sym_snorm] = ACTIONS(5149),
    [anon_sym_unorm] = ACTIONS(5149),
    [anon_sym_point] = ACTIONS(5149),
    [anon_sym_line] = ACTIONS(5149),
    [anon_sym_triangleadj] = ACTIONS(5149),
    [anon_sym_lineadj] = ACTIONS(5149),
    [anon_sym_triangle] = ACTIONS(5149),
  },
  [1962] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4810),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1963] = {
    [sym_identifier] = ACTIONS(5153),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5155),
    [anon_sym_COMMA] = ACTIONS(5155),
    [anon_sym_RPAREN] = ACTIONS(5155),
    [anon_sym_LPAREN2] = ACTIONS(5155),
    [anon_sym_TILDE] = ACTIONS(5155),
    [anon_sym_STAR] = ACTIONS(5155),
    [anon_sym_AMP_AMP] = ACTIONS(5155),
    [anon_sym_AMP] = ACTIONS(5153),
    [anon_sym_SEMI] = ACTIONS(5155),
    [anon_sym___extension__] = ACTIONS(5153),
    [anon_sym_in] = ACTIONS(5153),
    [anon_sym_out] = ACTIONS(5153),
    [anon_sym_inout] = ACTIONS(5153),
    [anon_sym_extern] = ACTIONS(5153),
    [anon_sym___attribute__] = ACTIONS(5153),
    [anon_sym_COLON_COLON] = ACTIONS(5155),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5155),
    [anon_sym___declspec] = ACTIONS(5153),
    [anon_sym___based] = ACTIONS(5153),
    [anon_sym_LBRACE] = ACTIONS(5155),
    [anon_sym_signed] = ACTIONS(5153),
    [anon_sym_unsigned] = ACTIONS(5153),
    [anon_sym_long] = ACTIONS(5153),
    [anon_sym_short] = ACTIONS(5153),
    [anon_sym_LBRACK] = ACTIONS(5153),
    [anon_sym_static] = ACTIONS(5153),
    [anon_sym_EQ] = ACTIONS(5155),
    [anon_sym_register] = ACTIONS(5153),
    [anon_sym_inline] = ACTIONS(5153),
    [anon_sym___inline] = ACTIONS(5153),
    [anon_sym___inline__] = ACTIONS(5153),
    [anon_sym___forceinline] = ACTIONS(5153),
    [anon_sym_thread_local] = ACTIONS(5153),
    [anon_sym___thread] = ACTIONS(5153),
    [anon_sym_const] = ACTIONS(5153),
    [anon_sym_constexpr] = ACTIONS(5153),
    [anon_sym_volatile] = ACTIONS(5153),
    [anon_sym_restrict] = ACTIONS(5153),
    [anon_sym___restrict__] = ACTIONS(5153),
    [anon_sym__Atomic] = ACTIONS(5153),
    [anon_sym__Noreturn] = ACTIONS(5153),
    [anon_sym_noreturn] = ACTIONS(5153),
    [anon_sym_mutable] = ACTIONS(5153),
    [anon_sym_constinit] = ACTIONS(5153),
    [anon_sym_consteval] = ACTIONS(5153),
    [anon_sym_alignas] = ACTIONS(5153),
    [anon_sym__Alignas] = ACTIONS(5153),
    [sym_primitive_type] = ACTIONS(5153),
    [anon_sym_enum] = ACTIONS(5153),
    [anon_sym_class] = ACTIONS(5153),
    [anon_sym_struct] = ACTIONS(5153),
    [anon_sym_union] = ACTIONS(5153),
    [anon_sym_asm] = ACTIONS(5153),
    [anon_sym___asm__] = ACTIONS(5153),
    [anon_sym_DASH_GT] = ACTIONS(5155),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5153),
    [anon_sym_decltype] = ACTIONS(5153),
    [anon_sym_final] = ACTIONS(5153),
    [anon_sym_override] = ACTIONS(5153),
    [sym_virtual] = ACTIONS(5153),
    [anon_sym_explicit] = ACTIONS(5153),
    [anon_sym_typename] = ACTIONS(5153),
    [anon_sym_template] = ACTIONS(5153),
    [anon_sym_GT2] = ACTIONS(5155),
    [anon_sym_operator] = ACTIONS(5153),
    [anon_sym_try] = ACTIONS(5153),
    [anon_sym_noexcept] = ACTIONS(5153),
    [anon_sym_throw] = ACTIONS(5153),
    [anon_sym_requires] = ACTIONS(5153),
    [anon_sym_precise] = ACTIONS(5153),
    [anon_sym_shared] = ACTIONS(5153),
    [anon_sym_groupshared] = ACTIONS(5153),
    [anon_sym_uniform] = ACTIONS(5153),
    [anon_sym_row_major] = ACTIONS(5153),
    [anon_sym_column_major] = ACTIONS(5153),
    [anon_sym_globallycoherent] = ACTIONS(5153),
    [anon_sym_centroid] = ACTIONS(5153),
    [anon_sym_noperspective] = ACTIONS(5153),
    [anon_sym_nointerpolation] = ACTIONS(5153),
    [anon_sym_sample] = ACTIONS(5153),
    [anon_sym_linear] = ACTIONS(5153),
    [anon_sym_snorm] = ACTIONS(5153),
    [anon_sym_unorm] = ACTIONS(5153),
    [anon_sym_point] = ACTIONS(5153),
    [anon_sym_line] = ACTIONS(5153),
    [anon_sym_triangleadj] = ACTIONS(5153),
    [anon_sym_lineadj] = ACTIONS(5153),
    [anon_sym_triangle] = ACTIONS(5153),
  },
  [1964] = {
    [sym_identifier] = ACTIONS(5157),
    [anon_sym_RPAREN] = ACTIONS(5159),
    [anon_sym_LPAREN2] = ACTIONS(5159),
    [anon_sym_TILDE] = ACTIONS(5159),
    [anon_sym_STAR] = ACTIONS(5159),
    [anon_sym_PIPE_PIPE] = ACTIONS(5159),
    [anon_sym_AMP_AMP] = ACTIONS(5159),
    [anon_sym_AMP] = ACTIONS(5157),
    [anon_sym___extension__] = ACTIONS(5157),
    [anon_sym_in] = ACTIONS(5157),
    [anon_sym_out] = ACTIONS(5157),
    [anon_sym_inout] = ACTIONS(5157),
    [anon_sym_extern] = ACTIONS(5157),
    [anon_sym___attribute__] = ACTIONS(5157),
    [anon_sym_COLON_COLON] = ACTIONS(5159),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5159),
    [anon_sym___declspec] = ACTIONS(5157),
    [anon_sym___based] = ACTIONS(5157),
    [anon_sym___cdecl] = ACTIONS(5157),
    [anon_sym___clrcall] = ACTIONS(5157),
    [anon_sym___stdcall] = ACTIONS(5157),
    [anon_sym___fastcall] = ACTIONS(5157),
    [anon_sym___thiscall] = ACTIONS(5157),
    [anon_sym___vectorcall] = ACTIONS(5157),
    [anon_sym_signed] = ACTIONS(5157),
    [anon_sym_unsigned] = ACTIONS(5157),
    [anon_sym_long] = ACTIONS(5157),
    [anon_sym_short] = ACTIONS(5157),
    [anon_sym_LBRACK] = ACTIONS(5157),
    [anon_sym_static] = ACTIONS(5157),
    [anon_sym_register] = ACTIONS(5157),
    [anon_sym_inline] = ACTIONS(5157),
    [anon_sym___inline] = ACTIONS(5157),
    [anon_sym___inline__] = ACTIONS(5157),
    [anon_sym___forceinline] = ACTIONS(5157),
    [anon_sym_thread_local] = ACTIONS(5157),
    [anon_sym___thread] = ACTIONS(5157),
    [anon_sym_const] = ACTIONS(5157),
    [anon_sym_constexpr] = ACTIONS(5157),
    [anon_sym_volatile] = ACTIONS(5157),
    [anon_sym_restrict] = ACTIONS(5157),
    [anon_sym___restrict__] = ACTIONS(5157),
    [anon_sym__Atomic] = ACTIONS(5157),
    [anon_sym__Noreturn] = ACTIONS(5157),
    [anon_sym_noreturn] = ACTIONS(5157),
    [anon_sym_mutable] = ACTIONS(5157),
    [anon_sym_constinit] = ACTIONS(5157),
    [anon_sym_consteval] = ACTIONS(5157),
    [anon_sym_alignas] = ACTIONS(5157),
    [anon_sym__Alignas] = ACTIONS(5157),
    [sym_primitive_type] = ACTIONS(5157),
    [anon_sym_enum] = ACTIONS(5157),
    [anon_sym_class] = ACTIONS(5157),
    [anon_sym_struct] = ACTIONS(5157),
    [anon_sym_union] = ACTIONS(5157),
    [anon_sym_or] = ACTIONS(5157),
    [anon_sym_and] = ACTIONS(5157),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5157),
    [anon_sym_decltype] = ACTIONS(5157),
    [anon_sym_final] = ACTIONS(5157),
    [anon_sym_override] = ACTIONS(5157),
    [sym_virtual] = ACTIONS(5157),
    [anon_sym_explicit] = ACTIONS(5157),
    [anon_sym_typename] = ACTIONS(5157),
    [anon_sym_template] = ACTIONS(5157),
    [anon_sym_operator] = ACTIONS(5157),
    [anon_sym_friend] = ACTIONS(5157),
    [anon_sym_using] = ACTIONS(5157),
    [anon_sym_concept] = ACTIONS(5157),
    [anon_sym_requires] = ACTIONS(5157),
    [anon_sym_precise] = ACTIONS(5157),
    [anon_sym_shared] = ACTIONS(5157),
    [anon_sym_groupshared] = ACTIONS(5157),
    [anon_sym_uniform] = ACTIONS(5157),
    [anon_sym_row_major] = ACTIONS(5157),
    [anon_sym_column_major] = ACTIONS(5157),
    [anon_sym_globallycoherent] = ACTIONS(5157),
    [anon_sym_centroid] = ACTIONS(5157),
    [anon_sym_noperspective] = ACTIONS(5157),
    [anon_sym_nointerpolation] = ACTIONS(5157),
    [anon_sym_sample] = ACTIONS(5157),
    [anon_sym_linear] = ACTIONS(5157),
    [anon_sym_snorm] = ACTIONS(5157),
    [anon_sym_unorm] = ACTIONS(5157),
    [anon_sym_point] = ACTIONS(5157),
    [anon_sym_line] = ACTIONS(5157),
    [anon_sym_triangleadj] = ACTIONS(5157),
    [anon_sym_lineadj] = ACTIONS(5157),
    [anon_sym_triangle] = ACTIONS(5157),
  },
  [1965] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4781),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1966] = {
    [sym_catch_clause] = STATE(1966),
    [aux_sym_constructor_try_statement_repeat1] = STATE(1966),
    [sym_identifier] = ACTIONS(1973),
    [aux_sym_preproc_def_token1] = ACTIONS(1973),
    [aux_sym_preproc_if_token1] = ACTIONS(1973),
    [aux_sym_preproc_if_token2] = ACTIONS(1973),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1973),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1973),
    [sym_preproc_directive] = ACTIONS(1973),
    [anon_sym_LPAREN2] = ACTIONS(1975),
    [anon_sym_TILDE] = ACTIONS(1975),
    [anon_sym_STAR] = ACTIONS(1975),
    [anon_sym_AMP_AMP] = ACTIONS(1975),
    [anon_sym_AMP] = ACTIONS(1973),
    [anon_sym___extension__] = ACTIONS(1973),
    [anon_sym_typedef] = ACTIONS(1973),
    [anon_sym_in] = ACTIONS(1973),
    [anon_sym_out] = ACTIONS(1973),
    [anon_sym_inout] = ACTIONS(1973),
    [anon_sym_extern] = ACTIONS(1973),
    [anon_sym___attribute__] = ACTIONS(1973),
    [anon_sym_COLON_COLON] = ACTIONS(1975),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1975),
    [anon_sym___declspec] = ACTIONS(1973),
    [anon_sym___based] = ACTIONS(1973),
    [anon_sym_signed] = ACTIONS(1973),
    [anon_sym_unsigned] = ACTIONS(1973),
    [anon_sym_long] = ACTIONS(1973),
    [anon_sym_short] = ACTIONS(1973),
    [anon_sym_LBRACK] = ACTIONS(1973),
    [anon_sym_static] = ACTIONS(1973),
    [anon_sym_register] = ACTIONS(1973),
    [anon_sym_inline] = ACTIONS(1973),
    [anon_sym___inline] = ACTIONS(1973),
    [anon_sym___inline__] = ACTIONS(1973),
    [anon_sym___forceinline] = ACTIONS(1973),
    [anon_sym_thread_local] = ACTIONS(1973),
    [anon_sym___thread] = ACTIONS(1973),
    [anon_sym_const] = ACTIONS(1973),
    [anon_sym_constexpr] = ACTIONS(1973),
    [anon_sym_volatile] = ACTIONS(1973),
    [anon_sym_restrict] = ACTIONS(1973),
    [anon_sym___restrict__] = ACTIONS(1973),
    [anon_sym__Atomic] = ACTIONS(1973),
    [anon_sym__Noreturn] = ACTIONS(1973),
    [anon_sym_noreturn] = ACTIONS(1973),
    [anon_sym_mutable] = ACTIONS(1973),
    [anon_sym_constinit] = ACTIONS(1973),
    [anon_sym_consteval] = ACTIONS(1973),
    [anon_sym_alignas] = ACTIONS(1973),
    [anon_sym__Alignas] = ACTIONS(1973),
    [sym_primitive_type] = ACTIONS(1973),
    [anon_sym_enum] = ACTIONS(1973),
    [anon_sym_class] = ACTIONS(1973),
    [anon_sym_struct] = ACTIONS(1973),
    [anon_sym_union] = ACTIONS(1973),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1973),
    [anon_sym_decltype] = ACTIONS(1973),
    [sym_virtual] = ACTIONS(1973),
    [anon_sym_explicit] = ACTIONS(1973),
    [anon_sym_typename] = ACTIONS(1973),
    [anon_sym_template] = ACTIONS(1973),
    [anon_sym_operator] = ACTIONS(1973),
    [anon_sym_friend] = ACTIONS(1973),
    [anon_sym_public] = ACTIONS(1973),
    [anon_sym_private] = ACTIONS(1973),
    [anon_sym_protected] = ACTIONS(1973),
    [anon_sym_using] = ACTIONS(1973),
    [anon_sym_static_assert] = ACTIONS(1973),
    [anon_sym_catch] = ACTIONS(5161),
    [anon_sym_precise] = ACTIONS(1973),
    [anon_sym_shared] = ACTIONS(1973),
    [anon_sym_groupshared] = ACTIONS(1973),
    [anon_sym_uniform] = ACTIONS(1973),
    [anon_sym_row_major] = ACTIONS(1973),
    [anon_sym_column_major] = ACTIONS(1973),
    [anon_sym_globallycoherent] = ACTIONS(1973),
    [anon_sym_centroid] = ACTIONS(1973),
    [anon_sym_noperspective] = ACTIONS(1973),
    [anon_sym_nointerpolation] = ACTIONS(1973),
    [anon_sym_sample] = ACTIONS(1973),
    [anon_sym_linear] = ACTIONS(1973),
    [anon_sym_snorm] = ACTIONS(1973),
    [anon_sym_unorm] = ACTIONS(1973),
    [anon_sym_point] = ACTIONS(1973),
    [anon_sym_line] = ACTIONS(1973),
    [anon_sym_triangleadj] = ACTIONS(1973),
    [anon_sym_lineadj] = ACTIONS(1973),
    [anon_sym_triangle] = ACTIONS(1973),
  },
  [1967] = {
    [sym_identifier] = ACTIONS(5164),
    [anon_sym_RPAREN] = ACTIONS(5166),
    [anon_sym_LPAREN2] = ACTIONS(5166),
    [anon_sym_TILDE] = ACTIONS(5166),
    [anon_sym_STAR] = ACTIONS(5166),
    [anon_sym_PIPE_PIPE] = ACTIONS(5166),
    [anon_sym_AMP_AMP] = ACTIONS(5166),
    [anon_sym_AMP] = ACTIONS(5164),
    [anon_sym___extension__] = ACTIONS(5164),
    [anon_sym_in] = ACTIONS(5164),
    [anon_sym_out] = ACTIONS(5164),
    [anon_sym_inout] = ACTIONS(5164),
    [anon_sym_extern] = ACTIONS(5164),
    [anon_sym___attribute__] = ACTIONS(5164),
    [anon_sym_COLON_COLON] = ACTIONS(5166),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5166),
    [anon_sym___declspec] = ACTIONS(5164),
    [anon_sym___based] = ACTIONS(5164),
    [anon_sym___cdecl] = ACTIONS(5164),
    [anon_sym___clrcall] = ACTIONS(5164),
    [anon_sym___stdcall] = ACTIONS(5164),
    [anon_sym___fastcall] = ACTIONS(5164),
    [anon_sym___thiscall] = ACTIONS(5164),
    [anon_sym___vectorcall] = ACTIONS(5164),
    [anon_sym_signed] = ACTIONS(5164),
    [anon_sym_unsigned] = ACTIONS(5164),
    [anon_sym_long] = ACTIONS(5164),
    [anon_sym_short] = ACTIONS(5164),
    [anon_sym_LBRACK] = ACTIONS(5164),
    [anon_sym_static] = ACTIONS(5164),
    [anon_sym_register] = ACTIONS(5164),
    [anon_sym_inline] = ACTIONS(5164),
    [anon_sym___inline] = ACTIONS(5164),
    [anon_sym___inline__] = ACTIONS(5164),
    [anon_sym___forceinline] = ACTIONS(5164),
    [anon_sym_thread_local] = ACTIONS(5164),
    [anon_sym___thread] = ACTIONS(5164),
    [anon_sym_const] = ACTIONS(5164),
    [anon_sym_constexpr] = ACTIONS(5164),
    [anon_sym_volatile] = ACTIONS(5164),
    [anon_sym_restrict] = ACTIONS(5164),
    [anon_sym___restrict__] = ACTIONS(5164),
    [anon_sym__Atomic] = ACTIONS(5164),
    [anon_sym__Noreturn] = ACTIONS(5164),
    [anon_sym_noreturn] = ACTIONS(5164),
    [anon_sym_mutable] = ACTIONS(5164),
    [anon_sym_constinit] = ACTIONS(5164),
    [anon_sym_consteval] = ACTIONS(5164),
    [anon_sym_alignas] = ACTIONS(5164),
    [anon_sym__Alignas] = ACTIONS(5164),
    [sym_primitive_type] = ACTIONS(5164),
    [anon_sym_enum] = ACTIONS(5164),
    [anon_sym_class] = ACTIONS(5164),
    [anon_sym_struct] = ACTIONS(5164),
    [anon_sym_union] = ACTIONS(5164),
    [anon_sym_or] = ACTIONS(5164),
    [anon_sym_and] = ACTIONS(5164),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5164),
    [anon_sym_decltype] = ACTIONS(5164),
    [anon_sym_final] = ACTIONS(5164),
    [anon_sym_override] = ACTIONS(5164),
    [sym_virtual] = ACTIONS(5164),
    [anon_sym_explicit] = ACTIONS(5164),
    [anon_sym_typename] = ACTIONS(5164),
    [anon_sym_template] = ACTIONS(5164),
    [anon_sym_operator] = ACTIONS(5164),
    [anon_sym_friend] = ACTIONS(5164),
    [anon_sym_using] = ACTIONS(5164),
    [anon_sym_concept] = ACTIONS(5164),
    [anon_sym_requires] = ACTIONS(5164),
    [anon_sym_precise] = ACTIONS(5164),
    [anon_sym_shared] = ACTIONS(5164),
    [anon_sym_groupshared] = ACTIONS(5164),
    [anon_sym_uniform] = ACTIONS(5164),
    [anon_sym_row_major] = ACTIONS(5164),
    [anon_sym_column_major] = ACTIONS(5164),
    [anon_sym_globallycoherent] = ACTIONS(5164),
    [anon_sym_centroid] = ACTIONS(5164),
    [anon_sym_noperspective] = ACTIONS(5164),
    [anon_sym_nointerpolation] = ACTIONS(5164),
    [anon_sym_sample] = ACTIONS(5164),
    [anon_sym_linear] = ACTIONS(5164),
    [anon_sym_snorm] = ACTIONS(5164),
    [anon_sym_unorm] = ACTIONS(5164),
    [anon_sym_point] = ACTIONS(5164),
    [anon_sym_line] = ACTIONS(5164),
    [anon_sym_triangleadj] = ACTIONS(5164),
    [anon_sym_lineadj] = ACTIONS(5164),
    [anon_sym_triangle] = ACTIONS(5164),
  },
  [1968] = {
    [sym_identifier] = ACTIONS(5168),
    [anon_sym_RPAREN] = ACTIONS(5170),
    [anon_sym_LPAREN2] = ACTIONS(5170),
    [anon_sym_TILDE] = ACTIONS(5170),
    [anon_sym_STAR] = ACTIONS(5170),
    [anon_sym_PIPE_PIPE] = ACTIONS(5170),
    [anon_sym_AMP_AMP] = ACTIONS(5170),
    [anon_sym_AMP] = ACTIONS(5168),
    [anon_sym___extension__] = ACTIONS(5168),
    [anon_sym_in] = ACTIONS(5168),
    [anon_sym_out] = ACTIONS(5168),
    [anon_sym_inout] = ACTIONS(5168),
    [anon_sym_extern] = ACTIONS(5168),
    [anon_sym___attribute__] = ACTIONS(5168),
    [anon_sym_COLON_COLON] = ACTIONS(5170),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5170),
    [anon_sym___declspec] = ACTIONS(5168),
    [anon_sym___based] = ACTIONS(5168),
    [anon_sym___cdecl] = ACTIONS(5168),
    [anon_sym___clrcall] = ACTIONS(5168),
    [anon_sym___stdcall] = ACTIONS(5168),
    [anon_sym___fastcall] = ACTIONS(5168),
    [anon_sym___thiscall] = ACTIONS(5168),
    [anon_sym___vectorcall] = ACTIONS(5168),
    [anon_sym_signed] = ACTIONS(5168),
    [anon_sym_unsigned] = ACTIONS(5168),
    [anon_sym_long] = ACTIONS(5168),
    [anon_sym_short] = ACTIONS(5168),
    [anon_sym_LBRACK] = ACTIONS(5168),
    [anon_sym_static] = ACTIONS(5168),
    [anon_sym_register] = ACTIONS(5168),
    [anon_sym_inline] = ACTIONS(5168),
    [anon_sym___inline] = ACTIONS(5168),
    [anon_sym___inline__] = ACTIONS(5168),
    [anon_sym___forceinline] = ACTIONS(5168),
    [anon_sym_thread_local] = ACTIONS(5168),
    [anon_sym___thread] = ACTIONS(5168),
    [anon_sym_const] = ACTIONS(5168),
    [anon_sym_constexpr] = ACTIONS(5168),
    [anon_sym_volatile] = ACTIONS(5168),
    [anon_sym_restrict] = ACTIONS(5168),
    [anon_sym___restrict__] = ACTIONS(5168),
    [anon_sym__Atomic] = ACTIONS(5168),
    [anon_sym__Noreturn] = ACTIONS(5168),
    [anon_sym_noreturn] = ACTIONS(5168),
    [anon_sym_mutable] = ACTIONS(5168),
    [anon_sym_constinit] = ACTIONS(5168),
    [anon_sym_consteval] = ACTIONS(5168),
    [anon_sym_alignas] = ACTIONS(5168),
    [anon_sym__Alignas] = ACTIONS(5168),
    [sym_primitive_type] = ACTIONS(5168),
    [anon_sym_enum] = ACTIONS(5168),
    [anon_sym_class] = ACTIONS(5168),
    [anon_sym_struct] = ACTIONS(5168),
    [anon_sym_union] = ACTIONS(5168),
    [anon_sym_or] = ACTIONS(5168),
    [anon_sym_and] = ACTIONS(5168),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5168),
    [anon_sym_decltype] = ACTIONS(5168),
    [anon_sym_final] = ACTIONS(5168),
    [anon_sym_override] = ACTIONS(5168),
    [sym_virtual] = ACTIONS(5168),
    [anon_sym_explicit] = ACTIONS(5168),
    [anon_sym_typename] = ACTIONS(5168),
    [anon_sym_template] = ACTIONS(5168),
    [anon_sym_operator] = ACTIONS(5168),
    [anon_sym_friend] = ACTIONS(5168),
    [anon_sym_using] = ACTIONS(5168),
    [anon_sym_concept] = ACTIONS(5168),
    [anon_sym_requires] = ACTIONS(5168),
    [anon_sym_precise] = ACTIONS(5168),
    [anon_sym_shared] = ACTIONS(5168),
    [anon_sym_groupshared] = ACTIONS(5168),
    [anon_sym_uniform] = ACTIONS(5168),
    [anon_sym_row_major] = ACTIONS(5168),
    [anon_sym_column_major] = ACTIONS(5168),
    [anon_sym_globallycoherent] = ACTIONS(5168),
    [anon_sym_centroid] = ACTIONS(5168),
    [anon_sym_noperspective] = ACTIONS(5168),
    [anon_sym_nointerpolation] = ACTIONS(5168),
    [anon_sym_sample] = ACTIONS(5168),
    [anon_sym_linear] = ACTIONS(5168),
    [anon_sym_snorm] = ACTIONS(5168),
    [anon_sym_unorm] = ACTIONS(5168),
    [anon_sym_point] = ACTIONS(5168),
    [anon_sym_line] = ACTIONS(5168),
    [anon_sym_triangleadj] = ACTIONS(5168),
    [anon_sym_lineadj] = ACTIONS(5168),
    [anon_sym_triangle] = ACTIONS(5168),
  },
  [1969] = {
    [sym_catch_clause] = STATE(1966),
    [aux_sym_constructor_try_statement_repeat1] = STATE(1966),
    [sym_identifier] = ACTIONS(1963),
    [aux_sym_preproc_def_token1] = ACTIONS(1963),
    [aux_sym_preproc_if_token1] = ACTIONS(1963),
    [aux_sym_preproc_if_token2] = ACTIONS(1963),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1963),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1963),
    [sym_preproc_directive] = ACTIONS(1963),
    [anon_sym_LPAREN2] = ACTIONS(1965),
    [anon_sym_TILDE] = ACTIONS(1965),
    [anon_sym_STAR] = ACTIONS(1965),
    [anon_sym_AMP_AMP] = ACTIONS(1965),
    [anon_sym_AMP] = ACTIONS(1963),
    [anon_sym___extension__] = ACTIONS(1963),
    [anon_sym_typedef] = ACTIONS(1963),
    [anon_sym_in] = ACTIONS(1963),
    [anon_sym_out] = ACTIONS(1963),
    [anon_sym_inout] = ACTIONS(1963),
    [anon_sym_extern] = ACTIONS(1963),
    [anon_sym___attribute__] = ACTIONS(1963),
    [anon_sym_COLON_COLON] = ACTIONS(1965),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1965),
    [anon_sym___declspec] = ACTIONS(1963),
    [anon_sym___based] = ACTIONS(1963),
    [anon_sym_signed] = ACTIONS(1963),
    [anon_sym_unsigned] = ACTIONS(1963),
    [anon_sym_long] = ACTIONS(1963),
    [anon_sym_short] = ACTIONS(1963),
    [anon_sym_LBRACK] = ACTIONS(1963),
    [anon_sym_static] = ACTIONS(1963),
    [anon_sym_register] = ACTIONS(1963),
    [anon_sym_inline] = ACTIONS(1963),
    [anon_sym___inline] = ACTIONS(1963),
    [anon_sym___inline__] = ACTIONS(1963),
    [anon_sym___forceinline] = ACTIONS(1963),
    [anon_sym_thread_local] = ACTIONS(1963),
    [anon_sym___thread] = ACTIONS(1963),
    [anon_sym_const] = ACTIONS(1963),
    [anon_sym_constexpr] = ACTIONS(1963),
    [anon_sym_volatile] = ACTIONS(1963),
    [anon_sym_restrict] = ACTIONS(1963),
    [anon_sym___restrict__] = ACTIONS(1963),
    [anon_sym__Atomic] = ACTIONS(1963),
    [anon_sym__Noreturn] = ACTIONS(1963),
    [anon_sym_noreturn] = ACTIONS(1963),
    [anon_sym_mutable] = ACTIONS(1963),
    [anon_sym_constinit] = ACTIONS(1963),
    [anon_sym_consteval] = ACTIONS(1963),
    [anon_sym_alignas] = ACTIONS(1963),
    [anon_sym__Alignas] = ACTIONS(1963),
    [sym_primitive_type] = ACTIONS(1963),
    [anon_sym_enum] = ACTIONS(1963),
    [anon_sym_class] = ACTIONS(1963),
    [anon_sym_struct] = ACTIONS(1963),
    [anon_sym_union] = ACTIONS(1963),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1963),
    [anon_sym_decltype] = ACTIONS(1963),
    [sym_virtual] = ACTIONS(1963),
    [anon_sym_explicit] = ACTIONS(1963),
    [anon_sym_typename] = ACTIONS(1963),
    [anon_sym_template] = ACTIONS(1963),
    [anon_sym_operator] = ACTIONS(1963),
    [anon_sym_friend] = ACTIONS(1963),
    [anon_sym_public] = ACTIONS(1963),
    [anon_sym_private] = ACTIONS(1963),
    [anon_sym_protected] = ACTIONS(1963),
    [anon_sym_using] = ACTIONS(1963),
    [anon_sym_static_assert] = ACTIONS(1963),
    [anon_sym_catch] = ACTIONS(5117),
    [anon_sym_precise] = ACTIONS(1963),
    [anon_sym_shared] = ACTIONS(1963),
    [anon_sym_groupshared] = ACTIONS(1963),
    [anon_sym_uniform] = ACTIONS(1963),
    [anon_sym_row_major] = ACTIONS(1963),
    [anon_sym_column_major] = ACTIONS(1963),
    [anon_sym_globallycoherent] = ACTIONS(1963),
    [anon_sym_centroid] = ACTIONS(1963),
    [anon_sym_noperspective] = ACTIONS(1963),
    [anon_sym_nointerpolation] = ACTIONS(1963),
    [anon_sym_sample] = ACTIONS(1963),
    [anon_sym_linear] = ACTIONS(1963),
    [anon_sym_snorm] = ACTIONS(1963),
    [anon_sym_unorm] = ACTIONS(1963),
    [anon_sym_point] = ACTIONS(1963),
    [anon_sym_line] = ACTIONS(1963),
    [anon_sym_triangleadj] = ACTIONS(1963),
    [anon_sym_lineadj] = ACTIONS(1963),
    [anon_sym_triangle] = ACTIONS(1963),
  },
  [1970] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4839),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1971] = {
    [sym_identifier] = ACTIONS(5172),
    [anon_sym_RPAREN] = ACTIONS(5174),
    [anon_sym_LPAREN2] = ACTIONS(5174),
    [anon_sym_TILDE] = ACTIONS(5174),
    [anon_sym_STAR] = ACTIONS(5174),
    [anon_sym_PIPE_PIPE] = ACTIONS(5174),
    [anon_sym_AMP_AMP] = ACTIONS(5174),
    [anon_sym_AMP] = ACTIONS(5172),
    [anon_sym___extension__] = ACTIONS(5172),
    [anon_sym_in] = ACTIONS(5172),
    [anon_sym_out] = ACTIONS(5172),
    [anon_sym_inout] = ACTIONS(5172),
    [anon_sym_extern] = ACTIONS(5172),
    [anon_sym___attribute__] = ACTIONS(5172),
    [anon_sym_COLON_COLON] = ACTIONS(5174),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5174),
    [anon_sym___declspec] = ACTIONS(5172),
    [anon_sym___based] = ACTIONS(5172),
    [anon_sym___cdecl] = ACTIONS(5172),
    [anon_sym___clrcall] = ACTIONS(5172),
    [anon_sym___stdcall] = ACTIONS(5172),
    [anon_sym___fastcall] = ACTIONS(5172),
    [anon_sym___thiscall] = ACTIONS(5172),
    [anon_sym___vectorcall] = ACTIONS(5172),
    [anon_sym_signed] = ACTIONS(5172),
    [anon_sym_unsigned] = ACTIONS(5172),
    [anon_sym_long] = ACTIONS(5172),
    [anon_sym_short] = ACTIONS(5172),
    [anon_sym_LBRACK] = ACTIONS(5172),
    [anon_sym_static] = ACTIONS(5172),
    [anon_sym_register] = ACTIONS(5172),
    [anon_sym_inline] = ACTIONS(5172),
    [anon_sym___inline] = ACTIONS(5172),
    [anon_sym___inline__] = ACTIONS(5172),
    [anon_sym___forceinline] = ACTIONS(5172),
    [anon_sym_thread_local] = ACTIONS(5172),
    [anon_sym___thread] = ACTIONS(5172),
    [anon_sym_const] = ACTIONS(5172),
    [anon_sym_constexpr] = ACTIONS(5172),
    [anon_sym_volatile] = ACTIONS(5172),
    [anon_sym_restrict] = ACTIONS(5172),
    [anon_sym___restrict__] = ACTIONS(5172),
    [anon_sym__Atomic] = ACTIONS(5172),
    [anon_sym__Noreturn] = ACTIONS(5172),
    [anon_sym_noreturn] = ACTIONS(5172),
    [anon_sym_mutable] = ACTIONS(5172),
    [anon_sym_constinit] = ACTIONS(5172),
    [anon_sym_consteval] = ACTIONS(5172),
    [anon_sym_alignas] = ACTIONS(5172),
    [anon_sym__Alignas] = ACTIONS(5172),
    [sym_primitive_type] = ACTIONS(5172),
    [anon_sym_enum] = ACTIONS(5172),
    [anon_sym_class] = ACTIONS(5172),
    [anon_sym_struct] = ACTIONS(5172),
    [anon_sym_union] = ACTIONS(5172),
    [anon_sym_or] = ACTIONS(5172),
    [anon_sym_and] = ACTIONS(5172),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5172),
    [anon_sym_decltype] = ACTIONS(5172),
    [anon_sym_final] = ACTIONS(5172),
    [anon_sym_override] = ACTIONS(5172),
    [sym_virtual] = ACTIONS(5172),
    [anon_sym_explicit] = ACTIONS(5172),
    [anon_sym_typename] = ACTIONS(5172),
    [anon_sym_template] = ACTIONS(5172),
    [anon_sym_operator] = ACTIONS(5172),
    [anon_sym_friend] = ACTIONS(5172),
    [anon_sym_using] = ACTIONS(5172),
    [anon_sym_concept] = ACTIONS(5172),
    [anon_sym_requires] = ACTIONS(5172),
    [anon_sym_precise] = ACTIONS(5172),
    [anon_sym_shared] = ACTIONS(5172),
    [anon_sym_groupshared] = ACTIONS(5172),
    [anon_sym_uniform] = ACTIONS(5172),
    [anon_sym_row_major] = ACTIONS(5172),
    [anon_sym_column_major] = ACTIONS(5172),
    [anon_sym_globallycoherent] = ACTIONS(5172),
    [anon_sym_centroid] = ACTIONS(5172),
    [anon_sym_noperspective] = ACTIONS(5172),
    [anon_sym_nointerpolation] = ACTIONS(5172),
    [anon_sym_sample] = ACTIONS(5172),
    [anon_sym_linear] = ACTIONS(5172),
    [anon_sym_snorm] = ACTIONS(5172),
    [anon_sym_unorm] = ACTIONS(5172),
    [anon_sym_point] = ACTIONS(5172),
    [anon_sym_line] = ACTIONS(5172),
    [anon_sym_triangleadj] = ACTIONS(5172),
    [anon_sym_lineadj] = ACTIONS(5172),
    [anon_sym_triangle] = ACTIONS(5172),
  },
  [1972] = {
    [sym__declaration_modifiers] = STATE(1979),
    [sym__declaration_specifiers] = STATE(4755),
    [sym_attribute_specifier] = STATE(1979),
    [sym_attribute_declaration] = STATE(1979),
    [sym_ms_declspec_modifier] = STATE(1979),
    [sym_storage_class_specifier] = STATE(1979),
    [sym_type_qualifier] = STATE(1979),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2196),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(1979),
    [aux_sym__declaration_specifiers_repeat1] = STATE(1979),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(1260),
    [anon_sym_out] = ACTIONS(1260),
    [anon_sym_inout] = ACTIONS(1260),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(1260),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1973] = {
    [sym_identifier] = ACTIONS(5176),
    [anon_sym_RPAREN] = ACTIONS(5178),
    [anon_sym_LPAREN2] = ACTIONS(5178),
    [anon_sym_TILDE] = ACTIONS(5178),
    [anon_sym_STAR] = ACTIONS(5178),
    [anon_sym_PIPE_PIPE] = ACTIONS(5178),
    [anon_sym_AMP_AMP] = ACTIONS(5178),
    [anon_sym_AMP] = ACTIONS(5176),
    [anon_sym___extension__] = ACTIONS(5176),
    [anon_sym_in] = ACTIONS(5176),
    [anon_sym_out] = ACTIONS(5176),
    [anon_sym_inout] = ACTIONS(5176),
    [anon_sym_extern] = ACTIONS(5176),
    [anon_sym___attribute__] = ACTIONS(5176),
    [anon_sym_COLON_COLON] = ACTIONS(5178),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5178),
    [anon_sym___declspec] = ACTIONS(5176),
    [anon_sym___based] = ACTIONS(5176),
    [anon_sym___cdecl] = ACTIONS(5176),
    [anon_sym___clrcall] = ACTIONS(5176),
    [anon_sym___stdcall] = ACTIONS(5176),
    [anon_sym___fastcall] = ACTIONS(5176),
    [anon_sym___thiscall] = ACTIONS(5176),
    [anon_sym___vectorcall] = ACTIONS(5176),
    [anon_sym_signed] = ACTIONS(5176),
    [anon_sym_unsigned] = ACTIONS(5176),
    [anon_sym_long] = ACTIONS(5176),
    [anon_sym_short] = ACTIONS(5176),
    [anon_sym_LBRACK] = ACTIONS(5176),
    [anon_sym_static] = ACTIONS(5176),
    [anon_sym_register] = ACTIONS(5176),
    [anon_sym_inline] = ACTIONS(5176),
    [anon_sym___inline] = ACTIONS(5176),
    [anon_sym___inline__] = ACTIONS(5176),
    [anon_sym___forceinline] = ACTIONS(5176),
    [anon_sym_thread_local] = ACTIONS(5176),
    [anon_sym___thread] = ACTIONS(5176),
    [anon_sym_const] = ACTIONS(5176),
    [anon_sym_constexpr] = ACTIONS(5176),
    [anon_sym_volatile] = ACTIONS(5176),
    [anon_sym_restrict] = ACTIONS(5176),
    [anon_sym___restrict__] = ACTIONS(5176),
    [anon_sym__Atomic] = ACTIONS(5176),
    [anon_sym__Noreturn] = ACTIONS(5176),
    [anon_sym_noreturn] = ACTIONS(5176),
    [anon_sym_mutable] = ACTIONS(5176),
    [anon_sym_constinit] = ACTIONS(5176),
    [anon_sym_consteval] = ACTIONS(5176),
    [anon_sym_alignas] = ACTIONS(5176),
    [anon_sym__Alignas] = ACTIONS(5176),
    [sym_primitive_type] = ACTIONS(5176),
    [anon_sym_enum] = ACTIONS(5176),
    [anon_sym_class] = ACTIONS(5176),
    [anon_sym_struct] = ACTIONS(5176),
    [anon_sym_union] = ACTIONS(5176),
    [anon_sym_or] = ACTIONS(5176),
    [anon_sym_and] = ACTIONS(5176),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5176),
    [anon_sym_decltype] = ACTIONS(5176),
    [anon_sym_final] = ACTIONS(5176),
    [anon_sym_override] = ACTIONS(5176),
    [sym_virtual] = ACTIONS(5176),
    [anon_sym_explicit] = ACTIONS(5176),
    [anon_sym_typename] = ACTIONS(5176),
    [anon_sym_template] = ACTIONS(5176),
    [anon_sym_operator] = ACTIONS(5176),
    [anon_sym_friend] = ACTIONS(5176),
    [anon_sym_using] = ACTIONS(5176),
    [anon_sym_concept] = ACTIONS(5176),
    [anon_sym_requires] = ACTIONS(5176),
    [anon_sym_precise] = ACTIONS(5176),
    [anon_sym_shared] = ACTIONS(5176),
    [anon_sym_groupshared] = ACTIONS(5176),
    [anon_sym_uniform] = ACTIONS(5176),
    [anon_sym_row_major] = ACTIONS(5176),
    [anon_sym_column_major] = ACTIONS(5176),
    [anon_sym_globallycoherent] = ACTIONS(5176),
    [anon_sym_centroid] = ACTIONS(5176),
    [anon_sym_noperspective] = ACTIONS(5176),
    [anon_sym_nointerpolation] = ACTIONS(5176),
    [anon_sym_sample] = ACTIONS(5176),
    [anon_sym_linear] = ACTIONS(5176),
    [anon_sym_snorm] = ACTIONS(5176),
    [anon_sym_unorm] = ACTIONS(5176),
    [anon_sym_point] = ACTIONS(5176),
    [anon_sym_line] = ACTIONS(5176),
    [anon_sym_triangleadj] = ACTIONS(5176),
    [anon_sym_lineadj] = ACTIONS(5176),
    [anon_sym_triangle] = ACTIONS(5176),
  },
  [1974] = {
    [sym_catch_clause] = STATE(1966),
    [aux_sym_constructor_try_statement_repeat1] = STATE(1966),
    [sym_identifier] = ACTIONS(1984),
    [aux_sym_preproc_def_token1] = ACTIONS(1984),
    [aux_sym_preproc_if_token1] = ACTIONS(1984),
    [aux_sym_preproc_if_token2] = ACTIONS(1984),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1984),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1984),
    [sym_preproc_directive] = ACTIONS(1984),
    [anon_sym_LPAREN2] = ACTIONS(1986),
    [anon_sym_TILDE] = ACTIONS(1986),
    [anon_sym_STAR] = ACTIONS(1986),
    [anon_sym_AMP_AMP] = ACTIONS(1986),
    [anon_sym_AMP] = ACTIONS(1984),
    [anon_sym___extension__] = ACTIONS(1984),
    [anon_sym_typedef] = ACTIONS(1984),
    [anon_sym_in] = ACTIONS(1984),
    [anon_sym_out] = ACTIONS(1984),
    [anon_sym_inout] = ACTIONS(1984),
    [anon_sym_extern] = ACTIONS(1984),
    [anon_sym___attribute__] = ACTIONS(1984),
    [anon_sym_COLON_COLON] = ACTIONS(1986),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1986),
    [anon_sym___declspec] = ACTIONS(1984),
    [anon_sym___based] = ACTIONS(1984),
    [anon_sym_signed] = ACTIONS(1984),
    [anon_sym_unsigned] = ACTIONS(1984),
    [anon_sym_long] = ACTIONS(1984),
    [anon_sym_short] = ACTIONS(1984),
    [anon_sym_LBRACK] = ACTIONS(1984),
    [anon_sym_static] = ACTIONS(1984),
    [anon_sym_register] = ACTIONS(1984),
    [anon_sym_inline] = ACTIONS(1984),
    [anon_sym___inline] = ACTIONS(1984),
    [anon_sym___inline__] = ACTIONS(1984),
    [anon_sym___forceinline] = ACTIONS(1984),
    [anon_sym_thread_local] = ACTIONS(1984),
    [anon_sym___thread] = ACTIONS(1984),
    [anon_sym_const] = ACTIONS(1984),
    [anon_sym_constexpr] = ACTIONS(1984),
    [anon_sym_volatile] = ACTIONS(1984),
    [anon_sym_restrict] = ACTIONS(1984),
    [anon_sym___restrict__] = ACTIONS(1984),
    [anon_sym__Atomic] = ACTIONS(1984),
    [anon_sym__Noreturn] = ACTIONS(1984),
    [anon_sym_noreturn] = ACTIONS(1984),
    [anon_sym_mutable] = ACTIONS(1984),
    [anon_sym_constinit] = ACTIONS(1984),
    [anon_sym_consteval] = ACTIONS(1984),
    [anon_sym_alignas] = ACTIONS(1984),
    [anon_sym__Alignas] = ACTIONS(1984),
    [sym_primitive_type] = ACTIONS(1984),
    [anon_sym_enum] = ACTIONS(1984),
    [anon_sym_class] = ACTIONS(1984),
    [anon_sym_struct] = ACTIONS(1984),
    [anon_sym_union] = ACTIONS(1984),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1984),
    [anon_sym_decltype] = ACTIONS(1984),
    [sym_virtual] = ACTIONS(1984),
    [anon_sym_explicit] = ACTIONS(1984),
    [anon_sym_typename] = ACTIONS(1984),
    [anon_sym_template] = ACTIONS(1984),
    [anon_sym_operator] = ACTIONS(1984),
    [anon_sym_friend] = ACTIONS(1984),
    [anon_sym_public] = ACTIONS(1984),
    [anon_sym_private] = ACTIONS(1984),
    [anon_sym_protected] = ACTIONS(1984),
    [anon_sym_using] = ACTIONS(1984),
    [anon_sym_static_assert] = ACTIONS(1984),
    [anon_sym_catch] = ACTIONS(5117),
    [anon_sym_precise] = ACTIONS(1984),
    [anon_sym_shared] = ACTIONS(1984),
    [anon_sym_groupshared] = ACTIONS(1984),
    [anon_sym_uniform] = ACTIONS(1984),
    [anon_sym_row_major] = ACTIONS(1984),
    [anon_sym_column_major] = ACTIONS(1984),
    [anon_sym_globallycoherent] = ACTIONS(1984),
    [anon_sym_centroid] = ACTIONS(1984),
    [anon_sym_noperspective] = ACTIONS(1984),
    [anon_sym_nointerpolation] = ACTIONS(1984),
    [anon_sym_sample] = ACTIONS(1984),
    [anon_sym_linear] = ACTIONS(1984),
    [anon_sym_snorm] = ACTIONS(1984),
    [anon_sym_unorm] = ACTIONS(1984),
    [anon_sym_point] = ACTIONS(1984),
    [anon_sym_line] = ACTIONS(1984),
    [anon_sym_triangleadj] = ACTIONS(1984),
    [anon_sym_lineadj] = ACTIONS(1984),
    [anon_sym_triangle] = ACTIONS(1984),
  },
  [1975] = {
    [sym_catch_clause] = STATE(1975),
    [aux_sym_constructor_try_statement_repeat1] = STATE(1975),
    [sym_identifier] = ACTIONS(1973),
    [aux_sym_preproc_def_token1] = ACTIONS(1973),
    [aux_sym_preproc_if_token1] = ACTIONS(1973),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1973),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1973),
    [sym_preproc_directive] = ACTIONS(1973),
    [anon_sym_LPAREN2] = ACTIONS(1975),
    [anon_sym_TILDE] = ACTIONS(1975),
    [anon_sym_STAR] = ACTIONS(1975),
    [anon_sym_AMP_AMP] = ACTIONS(1975),
    [anon_sym_AMP] = ACTIONS(1973),
    [anon_sym___extension__] = ACTIONS(1973),
    [anon_sym_typedef] = ACTIONS(1973),
    [anon_sym_in] = ACTIONS(1973),
    [anon_sym_out] = ACTIONS(1973),
    [anon_sym_inout] = ACTIONS(1973),
    [anon_sym_extern] = ACTIONS(1973),
    [anon_sym___attribute__] = ACTIONS(1973),
    [anon_sym_COLON_COLON] = ACTIONS(1975),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1975),
    [anon_sym___declspec] = ACTIONS(1973),
    [anon_sym___based] = ACTIONS(1973),
    [anon_sym_RBRACE] = ACTIONS(1975),
    [anon_sym_signed] = ACTIONS(1973),
    [anon_sym_unsigned] = ACTIONS(1973),
    [anon_sym_long] = ACTIONS(1973),
    [anon_sym_short] = ACTIONS(1973),
    [anon_sym_LBRACK] = ACTIONS(1973),
    [anon_sym_static] = ACTIONS(1973),
    [anon_sym_register] = ACTIONS(1973),
    [anon_sym_inline] = ACTIONS(1973),
    [anon_sym___inline] = ACTIONS(1973),
    [anon_sym___inline__] = ACTIONS(1973),
    [anon_sym___forceinline] = ACTIONS(1973),
    [anon_sym_thread_local] = ACTIONS(1973),
    [anon_sym___thread] = ACTIONS(1973),
    [anon_sym_const] = ACTIONS(1973),
    [anon_sym_constexpr] = ACTIONS(1973),
    [anon_sym_volatile] = ACTIONS(1973),
    [anon_sym_restrict] = ACTIONS(1973),
    [anon_sym___restrict__] = ACTIONS(1973),
    [anon_sym__Atomic] = ACTIONS(1973),
    [anon_sym__Noreturn] = ACTIONS(1973),
    [anon_sym_noreturn] = ACTIONS(1973),
    [anon_sym_mutable] = ACTIONS(1973),
    [anon_sym_constinit] = ACTIONS(1973),
    [anon_sym_consteval] = ACTIONS(1973),
    [anon_sym_alignas] = ACTIONS(1973),
    [anon_sym__Alignas] = ACTIONS(1973),
    [sym_primitive_type] = ACTIONS(1973),
    [anon_sym_enum] = ACTIONS(1973),
    [anon_sym_class] = ACTIONS(1973),
    [anon_sym_struct] = ACTIONS(1973),
    [anon_sym_union] = ACTIONS(1973),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1973),
    [anon_sym_decltype] = ACTIONS(1973),
    [sym_virtual] = ACTIONS(1973),
    [anon_sym_explicit] = ACTIONS(1973),
    [anon_sym_typename] = ACTIONS(1973),
    [anon_sym_template] = ACTIONS(1973),
    [anon_sym_operator] = ACTIONS(1973),
    [anon_sym_friend] = ACTIONS(1973),
    [anon_sym_public] = ACTIONS(1973),
    [anon_sym_private] = ACTIONS(1973),
    [anon_sym_protected] = ACTIONS(1973),
    [anon_sym_using] = ACTIONS(1973),
    [anon_sym_static_assert] = ACTIONS(1973),
    [anon_sym_catch] = ACTIONS(5180),
    [anon_sym_precise] = ACTIONS(1973),
    [anon_sym_shared] = ACTIONS(1973),
    [anon_sym_groupshared] = ACTIONS(1973),
    [anon_sym_uniform] = ACTIONS(1973),
    [anon_sym_row_major] = ACTIONS(1973),
    [anon_sym_column_major] = ACTIONS(1973),
    [anon_sym_globallycoherent] = ACTIONS(1973),
    [anon_sym_centroid] = ACTIONS(1973),
    [anon_sym_noperspective] = ACTIONS(1973),
    [anon_sym_nointerpolation] = ACTIONS(1973),
    [anon_sym_sample] = ACTIONS(1973),
    [anon_sym_linear] = ACTIONS(1973),
    [anon_sym_snorm] = ACTIONS(1973),
    [anon_sym_unorm] = ACTIONS(1973),
    [anon_sym_point] = ACTIONS(1973),
    [anon_sym_line] = ACTIONS(1973),
    [anon_sym_triangleadj] = ACTIONS(1973),
    [anon_sym_lineadj] = ACTIONS(1973),
    [anon_sym_triangle] = ACTIONS(1973),
  },
  [1976] = {
    [sym__declaration_modifiers] = STATE(2368),
    [sym_attribute_specifier] = STATE(2368),
    [sym_attribute_declaration] = STATE(2368),
    [sym_ms_declspec_modifier] = STATE(2368),
    [sym_storage_class_specifier] = STATE(2368),
    [sym_type_qualifier] = STATE(2368),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2204),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(2368),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2368),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2659),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(5183),
    [anon_sym_out] = ACTIONS(5183),
    [anon_sym_inout] = ACTIONS(5183),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(3495),
    [anon_sym_unsigned] = ACTIONS(3495),
    [anon_sym_long] = ACTIONS(3495),
    [anon_sym_short] = ACTIONS(3495),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(3497),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(5183),
    [anon_sym_typename] = ACTIONS(3499),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1977] = {
    [sym_string_literal] = STATE(2509),
    [sym_template_argument_list] = STATE(2404),
    [sym_raw_string_literal] = STATE(2509),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2520),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_RPAREN] = ACTIONS(3826),
    [anon_sym_LPAREN2] = ACTIONS(3826),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3834),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3837),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3834),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5185),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym___extension__] = ACTIONS(3830),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5188),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_signed] = ACTIONS(5190),
    [anon_sym_unsigned] = ACTIONS(5190),
    [anon_sym_long] = ACTIONS(5190),
    [anon_sym_short] = ACTIONS(5190),
    [anon_sym_LBRACK] = ACTIONS(3850),
    [anon_sym_EQ] = ACTIONS(3832),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3830),
    [anon_sym_volatile] = ACTIONS(3830),
    [anon_sym_restrict] = ACTIONS(3830),
    [anon_sym___restrict__] = ACTIONS(3830),
    [anon_sym__Atomic] = ACTIONS(3830),
    [anon_sym__Noreturn] = ACTIONS(3830),
    [anon_sym_noreturn] = ACTIONS(3830),
    [anon_sym_mutable] = ACTIONS(3830),
    [anon_sym_constinit] = ACTIONS(3830),
    [anon_sym_consteval] = ACTIONS(3830),
    [anon_sym_alignas] = ACTIONS(3830),
    [anon_sym__Alignas] = ACTIONS(3830),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3824),
    [anon_sym_SLASH_EQ] = ACTIONS(3824),
    [anon_sym_PERCENT_EQ] = ACTIONS(3824),
    [anon_sym_PLUS_EQ] = ACTIONS(3824),
    [anon_sym_DASH_EQ] = ACTIONS(3824),
    [anon_sym_LT_LT_EQ] = ACTIONS(3824),
    [anon_sym_GT_GT_EQ] = ACTIONS(3824),
    [anon_sym_AMP_EQ] = ACTIONS(3824),
    [anon_sym_CARET_EQ] = ACTIONS(3824),
    [anon_sym_PIPE_EQ] = ACTIONS(3824),
    [anon_sym_and_eq] = ACTIONS(3824),
    [anon_sym_or_eq] = ACTIONS(3824),
    [anon_sym_xor_eq] = ACTIONS(3824),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3832),
    [anon_sym_L_DQUOTE] = ACTIONS(5192),
    [anon_sym_u_DQUOTE] = ACTIONS(5192),
    [anon_sym_U_DQUOTE] = ACTIONS(5192),
    [anon_sym_u8_DQUOTE] = ACTIONS(5192),
    [anon_sym_DQUOTE] = ACTIONS(5192),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3830),
    [anon_sym_decltype] = ACTIONS(3830),
    [anon_sym_R_DQUOTE] = ACTIONS(5194),
    [anon_sym_LR_DQUOTE] = ACTIONS(5194),
    [anon_sym_uR_DQUOTE] = ACTIONS(5194),
    [anon_sym_UR_DQUOTE] = ACTIONS(5194),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5194),
    [anon_sym_DASH_GT_STAR] = ACTIONS(3824),
  },
  [1978] = {
    [sym__declaration_modifiers] = STATE(2368),
    [sym_attribute_specifier] = STATE(2368),
    [sym_attribute_declaration] = STATE(2368),
    [sym_ms_declspec_modifier] = STATE(2368),
    [sym_storage_class_specifier] = STATE(2368),
    [sym_type_qualifier] = STATE(2368),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2204),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(2368),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2368),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(5183),
    [anon_sym_out] = ACTIONS(5183),
    [anon_sym_inout] = ACTIONS(5183),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(2619),
    [anon_sym_class] = ACTIONS(2621),
    [anon_sym_struct] = ACTIONS(2623),
    [anon_sym_union] = ACTIONS(2625),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(5183),
    [anon_sym_typename] = ACTIONS(2627),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1979] = {
    [sym__declaration_modifiers] = STATE(2368),
    [sym_attribute_specifier] = STATE(2368),
    [sym_attribute_declaration] = STATE(2368),
    [sym_ms_declspec_modifier] = STATE(2368),
    [sym_storage_class_specifier] = STATE(2368),
    [sym_type_qualifier] = STATE(2368),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2204),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6504),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(2368),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2368),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(3485),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(5183),
    [anon_sym_out] = ACTIONS(5183),
    [anon_sym_inout] = ACTIONS(5183),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(3493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(69),
    [anon_sym_class] = ACTIONS(71),
    [anon_sym_struct] = ACTIONS(73),
    [anon_sym_union] = ACTIONS(75),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(5183),
    [anon_sym_typename] = ACTIONS(127),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1980] = {
    [sym_identifier] = ACTIONS(1947),
    [aux_sym_preproc_def_token1] = ACTIONS(1947),
    [anon_sym_COMMA] = ACTIONS(2202),
    [aux_sym_preproc_if_token1] = ACTIONS(1947),
    [aux_sym_preproc_if_token2] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1947),
    [sym_preproc_directive] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1945),
    [anon_sym_TILDE] = ACTIONS(1945),
    [anon_sym_STAR] = ACTIONS(1945),
    [anon_sym_AMP_AMP] = ACTIONS(1945),
    [anon_sym_AMP] = ACTIONS(1947),
    [anon_sym_SEMI] = ACTIONS(2202),
    [anon_sym___extension__] = ACTIONS(1947),
    [anon_sym_typedef] = ACTIONS(1947),
    [anon_sym_in] = ACTIONS(1947),
    [anon_sym_out] = ACTIONS(1947),
    [anon_sym_inout] = ACTIONS(1947),
    [anon_sym_extern] = ACTIONS(1947),
    [anon_sym___attribute__] = ACTIONS(1947),
    [anon_sym_COLON_COLON] = ACTIONS(1945),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1945),
    [anon_sym___declspec] = ACTIONS(1947),
    [anon_sym___based] = ACTIONS(1947),
    [anon_sym_signed] = ACTIONS(1947),
    [anon_sym_unsigned] = ACTIONS(1947),
    [anon_sym_long] = ACTIONS(1947),
    [anon_sym_short] = ACTIONS(1947),
    [anon_sym_LBRACK] = ACTIONS(1947),
    [anon_sym_static] = ACTIONS(1947),
    [anon_sym_register] = ACTIONS(1947),
    [anon_sym_inline] = ACTIONS(1947),
    [anon_sym___inline] = ACTIONS(1947),
    [anon_sym___inline__] = ACTIONS(1947),
    [anon_sym___forceinline] = ACTIONS(1947),
    [anon_sym_thread_local] = ACTIONS(1947),
    [anon_sym___thread] = ACTIONS(1947),
    [anon_sym_const] = ACTIONS(1947),
    [anon_sym_constexpr] = ACTIONS(1947),
    [anon_sym_volatile] = ACTIONS(1947),
    [anon_sym_restrict] = ACTIONS(1947),
    [anon_sym___restrict__] = ACTIONS(1947),
    [anon_sym__Atomic] = ACTIONS(1947),
    [anon_sym__Noreturn] = ACTIONS(1947),
    [anon_sym_noreturn] = ACTIONS(1947),
    [anon_sym_mutable] = ACTIONS(1947),
    [anon_sym_constinit] = ACTIONS(1947),
    [anon_sym_consteval] = ACTIONS(1947),
    [anon_sym_alignas] = ACTIONS(1947),
    [anon_sym__Alignas] = ACTIONS(1947),
    [sym_primitive_type] = ACTIONS(1947),
    [anon_sym_enum] = ACTIONS(1947),
    [anon_sym_class] = ACTIONS(1947),
    [anon_sym_struct] = ACTIONS(1947),
    [anon_sym_union] = ACTIONS(1947),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1947),
    [anon_sym_decltype] = ACTIONS(1947),
    [sym_virtual] = ACTIONS(1947),
    [anon_sym_explicit] = ACTIONS(1947),
    [anon_sym_typename] = ACTIONS(1947),
    [anon_sym_template] = ACTIONS(1947),
    [anon_sym_operator] = ACTIONS(1947),
    [anon_sym_friend] = ACTIONS(1947),
    [anon_sym_public] = ACTIONS(1947),
    [anon_sym_private] = ACTIONS(1947),
    [anon_sym_protected] = ACTIONS(1947),
    [anon_sym_using] = ACTIONS(1947),
    [anon_sym_static_assert] = ACTIONS(1947),
    [anon_sym_precise] = ACTIONS(1947),
    [anon_sym_shared] = ACTIONS(1947),
    [anon_sym_groupshared] = ACTIONS(1947),
    [anon_sym_uniform] = ACTIONS(1947),
    [anon_sym_row_major] = ACTIONS(1947),
    [anon_sym_column_major] = ACTIONS(1947),
    [anon_sym_globallycoherent] = ACTIONS(1947),
    [anon_sym_centroid] = ACTIONS(1947),
    [anon_sym_noperspective] = ACTIONS(1947),
    [anon_sym_nointerpolation] = ACTIONS(1947),
    [anon_sym_sample] = ACTIONS(1947),
    [anon_sym_linear] = ACTIONS(1947),
    [anon_sym_snorm] = ACTIONS(1947),
    [anon_sym_unorm] = ACTIONS(1947),
    [anon_sym_point] = ACTIONS(1947),
    [anon_sym_line] = ACTIONS(1947),
    [anon_sym_triangleadj] = ACTIONS(1947),
    [anon_sym_lineadj] = ACTIONS(1947),
    [anon_sym_triangle] = ACTIONS(1947),
  },
  [1981] = {
    [sym_identifier] = ACTIONS(1947),
    [aux_sym_preproc_def_token1] = ACTIONS(1947),
    [anon_sym_COMMA] = ACTIONS(2202),
    [aux_sym_preproc_if_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1947),
    [sym_preproc_directive] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1945),
    [anon_sym_TILDE] = ACTIONS(1945),
    [anon_sym_STAR] = ACTIONS(1945),
    [anon_sym_AMP_AMP] = ACTIONS(1945),
    [anon_sym_AMP] = ACTIONS(1947),
    [anon_sym_SEMI] = ACTIONS(2202),
    [anon_sym___extension__] = ACTIONS(1947),
    [anon_sym_typedef] = ACTIONS(1947),
    [anon_sym_in] = ACTIONS(1947),
    [anon_sym_out] = ACTIONS(1947),
    [anon_sym_inout] = ACTIONS(1947),
    [anon_sym_extern] = ACTIONS(1947),
    [anon_sym___attribute__] = ACTIONS(4999),
    [anon_sym_COLON_COLON] = ACTIONS(1945),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1945),
    [anon_sym___declspec] = ACTIONS(1947),
    [anon_sym___based] = ACTIONS(1947),
    [anon_sym_RBRACE] = ACTIONS(1945),
    [anon_sym_signed] = ACTIONS(1947),
    [anon_sym_unsigned] = ACTIONS(1947),
    [anon_sym_long] = ACTIONS(1947),
    [anon_sym_short] = ACTIONS(1947),
    [anon_sym_LBRACK] = ACTIONS(1947),
    [anon_sym_static] = ACTIONS(1947),
    [anon_sym_register] = ACTIONS(1947),
    [anon_sym_inline] = ACTIONS(1947),
    [anon_sym___inline] = ACTIONS(1947),
    [anon_sym___inline__] = ACTIONS(1947),
    [anon_sym___forceinline] = ACTIONS(1947),
    [anon_sym_thread_local] = ACTIONS(1947),
    [anon_sym___thread] = ACTIONS(1947),
    [anon_sym_const] = ACTIONS(1947),
    [anon_sym_constexpr] = ACTIONS(1947),
    [anon_sym_volatile] = ACTIONS(1947),
    [anon_sym_restrict] = ACTIONS(1947),
    [anon_sym___restrict__] = ACTIONS(1947),
    [anon_sym__Atomic] = ACTIONS(1947),
    [anon_sym__Noreturn] = ACTIONS(1947),
    [anon_sym_noreturn] = ACTIONS(1947),
    [anon_sym_mutable] = ACTIONS(1947),
    [anon_sym_constinit] = ACTIONS(1947),
    [anon_sym_consteval] = ACTIONS(1947),
    [anon_sym_alignas] = ACTIONS(1947),
    [anon_sym__Alignas] = ACTIONS(1947),
    [sym_primitive_type] = ACTIONS(1947),
    [anon_sym_enum] = ACTIONS(1947),
    [anon_sym_class] = ACTIONS(1947),
    [anon_sym_struct] = ACTIONS(1947),
    [anon_sym_union] = ACTIONS(1947),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1947),
    [anon_sym_decltype] = ACTIONS(1947),
    [sym_virtual] = ACTIONS(1947),
    [anon_sym_explicit] = ACTIONS(1947),
    [anon_sym_typename] = ACTIONS(1947),
    [anon_sym_template] = ACTIONS(1947),
    [anon_sym_operator] = ACTIONS(1947),
    [anon_sym_friend] = ACTIONS(1947),
    [anon_sym_public] = ACTIONS(1947),
    [anon_sym_private] = ACTIONS(1947),
    [anon_sym_protected] = ACTIONS(1947),
    [anon_sym_using] = ACTIONS(1947),
    [anon_sym_static_assert] = ACTIONS(1947),
    [anon_sym_precise] = ACTIONS(1947),
    [anon_sym_shared] = ACTIONS(1947),
    [anon_sym_groupshared] = ACTIONS(1947),
    [anon_sym_uniform] = ACTIONS(1947),
    [anon_sym_row_major] = ACTIONS(1947),
    [anon_sym_column_major] = ACTIONS(1947),
    [anon_sym_globallycoherent] = ACTIONS(1947),
    [anon_sym_centroid] = ACTIONS(1947),
    [anon_sym_noperspective] = ACTIONS(1947),
    [anon_sym_nointerpolation] = ACTIONS(1947),
    [anon_sym_sample] = ACTIONS(1947),
    [anon_sym_linear] = ACTIONS(1947),
    [anon_sym_snorm] = ACTIONS(1947),
    [anon_sym_unorm] = ACTIONS(1947),
    [anon_sym_point] = ACTIONS(1947),
    [anon_sym_line] = ACTIONS(1947),
    [anon_sym_triangleadj] = ACTIONS(1947),
    [anon_sym_lineadj] = ACTIONS(1947),
    [anon_sym_triangle] = ACTIONS(1947),
  },
  [1982] = {
    [sym_identifier] = ACTIONS(1947),
    [aux_sym_preproc_def_token1] = ACTIONS(1947),
    [anon_sym_COMMA] = ACTIONS(2202),
    [aux_sym_preproc_if_token1] = ACTIONS(1947),
    [aux_sym_preproc_if_token2] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1947),
    [sym_preproc_directive] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1945),
    [anon_sym_TILDE] = ACTIONS(1945),
    [anon_sym_STAR] = ACTIONS(1945),
    [anon_sym_AMP_AMP] = ACTIONS(1945),
    [anon_sym_AMP] = ACTIONS(1947),
    [anon_sym_SEMI] = ACTIONS(2202),
    [anon_sym___extension__] = ACTIONS(1947),
    [anon_sym_typedef] = ACTIONS(1947),
    [anon_sym_in] = ACTIONS(1947),
    [anon_sym_out] = ACTIONS(1947),
    [anon_sym_inout] = ACTIONS(1947),
    [anon_sym_extern] = ACTIONS(1947),
    [anon_sym___attribute__] = ACTIONS(4999),
    [anon_sym_COLON_COLON] = ACTIONS(1945),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1945),
    [anon_sym___declspec] = ACTIONS(1947),
    [anon_sym___based] = ACTIONS(1947),
    [anon_sym_signed] = ACTIONS(1947),
    [anon_sym_unsigned] = ACTIONS(1947),
    [anon_sym_long] = ACTIONS(1947),
    [anon_sym_short] = ACTIONS(1947),
    [anon_sym_LBRACK] = ACTIONS(1947),
    [anon_sym_static] = ACTIONS(1947),
    [anon_sym_register] = ACTIONS(1947),
    [anon_sym_inline] = ACTIONS(1947),
    [anon_sym___inline] = ACTIONS(1947),
    [anon_sym___inline__] = ACTIONS(1947),
    [anon_sym___forceinline] = ACTIONS(1947),
    [anon_sym_thread_local] = ACTIONS(1947),
    [anon_sym___thread] = ACTIONS(1947),
    [anon_sym_const] = ACTIONS(1947),
    [anon_sym_constexpr] = ACTIONS(1947),
    [anon_sym_volatile] = ACTIONS(1947),
    [anon_sym_restrict] = ACTIONS(1947),
    [anon_sym___restrict__] = ACTIONS(1947),
    [anon_sym__Atomic] = ACTIONS(1947),
    [anon_sym__Noreturn] = ACTIONS(1947),
    [anon_sym_noreturn] = ACTIONS(1947),
    [anon_sym_mutable] = ACTIONS(1947),
    [anon_sym_constinit] = ACTIONS(1947),
    [anon_sym_consteval] = ACTIONS(1947),
    [anon_sym_alignas] = ACTIONS(1947),
    [anon_sym__Alignas] = ACTIONS(1947),
    [sym_primitive_type] = ACTIONS(1947),
    [anon_sym_enum] = ACTIONS(1947),
    [anon_sym_class] = ACTIONS(1947),
    [anon_sym_struct] = ACTIONS(1947),
    [anon_sym_union] = ACTIONS(1947),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1947),
    [anon_sym_decltype] = ACTIONS(1947),
    [sym_virtual] = ACTIONS(1947),
    [anon_sym_explicit] = ACTIONS(1947),
    [anon_sym_typename] = ACTIONS(1947),
    [anon_sym_template] = ACTIONS(1947),
    [anon_sym_operator] = ACTIONS(1947),
    [anon_sym_friend] = ACTIONS(1947),
    [anon_sym_public] = ACTIONS(1947),
    [anon_sym_private] = ACTIONS(1947),
    [anon_sym_protected] = ACTIONS(1947),
    [anon_sym_using] = ACTIONS(1947),
    [anon_sym_static_assert] = ACTIONS(1947),
    [anon_sym_precise] = ACTIONS(1947),
    [anon_sym_shared] = ACTIONS(1947),
    [anon_sym_groupshared] = ACTIONS(1947),
    [anon_sym_uniform] = ACTIONS(1947),
    [anon_sym_row_major] = ACTIONS(1947),
    [anon_sym_column_major] = ACTIONS(1947),
    [anon_sym_globallycoherent] = ACTIONS(1947),
    [anon_sym_centroid] = ACTIONS(1947),
    [anon_sym_noperspective] = ACTIONS(1947),
    [anon_sym_nointerpolation] = ACTIONS(1947),
    [anon_sym_sample] = ACTIONS(1947),
    [anon_sym_linear] = ACTIONS(1947),
    [anon_sym_snorm] = ACTIONS(1947),
    [anon_sym_unorm] = ACTIONS(1947),
    [anon_sym_point] = ACTIONS(1947),
    [anon_sym_line] = ACTIONS(1947),
    [anon_sym_triangleadj] = ACTIONS(1947),
    [anon_sym_lineadj] = ACTIONS(1947),
    [anon_sym_triangle] = ACTIONS(1947),
  },
  [1983] = {
    [sym_identifier] = ACTIONS(1947),
    [aux_sym_preproc_def_token1] = ACTIONS(1947),
    [anon_sym_COMMA] = ACTIONS(2202),
    [aux_sym_preproc_if_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1947),
    [sym_preproc_directive] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1945),
    [anon_sym_TILDE] = ACTIONS(1945),
    [anon_sym_STAR] = ACTIONS(1945),
    [anon_sym_AMP_AMP] = ACTIONS(1945),
    [anon_sym_AMP] = ACTIONS(1947),
    [anon_sym_SEMI] = ACTIONS(2202),
    [anon_sym___extension__] = ACTIONS(1947),
    [anon_sym_typedef] = ACTIONS(1947),
    [anon_sym_in] = ACTIONS(1947),
    [anon_sym_out] = ACTIONS(1947),
    [anon_sym_inout] = ACTIONS(1947),
    [anon_sym_extern] = ACTIONS(1947),
    [anon_sym___attribute__] = ACTIONS(1947),
    [anon_sym_COLON_COLON] = ACTIONS(1945),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1945),
    [anon_sym___declspec] = ACTIONS(1947),
    [anon_sym___based] = ACTIONS(1947),
    [anon_sym_RBRACE] = ACTIONS(1945),
    [anon_sym_signed] = ACTIONS(1947),
    [anon_sym_unsigned] = ACTIONS(1947),
    [anon_sym_long] = ACTIONS(1947),
    [anon_sym_short] = ACTIONS(1947),
    [anon_sym_LBRACK] = ACTIONS(1947),
    [anon_sym_static] = ACTIONS(1947),
    [anon_sym_register] = ACTIONS(1947),
    [anon_sym_inline] = ACTIONS(1947),
    [anon_sym___inline] = ACTIONS(1947),
    [anon_sym___inline__] = ACTIONS(1947),
    [anon_sym___forceinline] = ACTIONS(1947),
    [anon_sym_thread_local] = ACTIONS(1947),
    [anon_sym___thread] = ACTIONS(1947),
    [anon_sym_const] = ACTIONS(1947),
    [anon_sym_constexpr] = ACTIONS(1947),
    [anon_sym_volatile] = ACTIONS(1947),
    [anon_sym_restrict] = ACTIONS(1947),
    [anon_sym___restrict__] = ACTIONS(1947),
    [anon_sym__Atomic] = ACTIONS(1947),
    [anon_sym__Noreturn] = ACTIONS(1947),
    [anon_sym_noreturn] = ACTIONS(1947),
    [anon_sym_mutable] = ACTIONS(1947),
    [anon_sym_constinit] = ACTIONS(1947),
    [anon_sym_consteval] = ACTIONS(1947),
    [anon_sym_alignas] = ACTIONS(1947),
    [anon_sym__Alignas] = ACTIONS(1947),
    [sym_primitive_type] = ACTIONS(1947),
    [anon_sym_enum] = ACTIONS(1947),
    [anon_sym_class] = ACTIONS(1947),
    [anon_sym_struct] = ACTIONS(1947),
    [anon_sym_union] = ACTIONS(1947),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1947),
    [anon_sym_decltype] = ACTIONS(1947),
    [sym_virtual] = ACTIONS(1947),
    [anon_sym_explicit] = ACTIONS(1947),
    [anon_sym_typename] = ACTIONS(1947),
    [anon_sym_template] = ACTIONS(1947),
    [anon_sym_operator] = ACTIONS(1947),
    [anon_sym_friend] = ACTIONS(1947),
    [anon_sym_public] = ACTIONS(1947),
    [anon_sym_private] = ACTIONS(1947),
    [anon_sym_protected] = ACTIONS(1947),
    [anon_sym_using] = ACTIONS(1947),
    [anon_sym_static_assert] = ACTIONS(1947),
    [anon_sym_precise] = ACTIONS(1947),
    [anon_sym_shared] = ACTIONS(1947),
    [anon_sym_groupshared] = ACTIONS(1947),
    [anon_sym_uniform] = ACTIONS(1947),
    [anon_sym_row_major] = ACTIONS(1947),
    [anon_sym_column_major] = ACTIONS(1947),
    [anon_sym_globallycoherent] = ACTIONS(1947),
    [anon_sym_centroid] = ACTIONS(1947),
    [anon_sym_noperspective] = ACTIONS(1947),
    [anon_sym_nointerpolation] = ACTIONS(1947),
    [anon_sym_sample] = ACTIONS(1947),
    [anon_sym_linear] = ACTIONS(1947),
    [anon_sym_snorm] = ACTIONS(1947),
    [anon_sym_unorm] = ACTIONS(1947),
    [anon_sym_point] = ACTIONS(1947),
    [anon_sym_line] = ACTIONS(1947),
    [anon_sym_triangleadj] = ACTIONS(1947),
    [anon_sym_lineadj] = ACTIONS(1947),
    [anon_sym_triangle] = ACTIONS(1947),
  },
  [1984] = {
    [sym__declaration_modifiers] = STATE(2368),
    [sym_attribute_specifier] = STATE(2368),
    [sym_attribute_declaration] = STATE(2368),
    [sym_ms_declspec_modifier] = STATE(2368),
    [sym_storage_class_specifier] = STATE(2368),
    [sym_type_qualifier] = STATE(2368),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_type_specifier] = STATE(2204),
    [sym_sized_type_specifier] = STATE(2277),
    [sym_enum_specifier] = STATE(2277),
    [sym_struct_specifier] = STATE(2277),
    [sym_union_specifier] = STATE(2277),
    [sym_placeholder_type_specifier] = STATE(2277),
    [sym_decltype_auto] = STATE(2298),
    [sym_decltype] = STATE(2252),
    [sym_class_specifier] = STATE(2277),
    [sym_dependent_type] = STATE(2277),
    [sym_template_type] = STATE(2252),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(6449),
    [sym_qualified_type_identifier] = STATE(2279),
    [sym_qualifiers] = STATE(2368),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2368),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2230),
    [sym_identifier] = ACTIONS(4068),
    [anon_sym___extension__] = ACTIONS(63),
    [anon_sym_in] = ACTIONS(5183),
    [anon_sym_out] = ACTIONS(5183),
    [anon_sym_inout] = ACTIONS(5183),
    [anon_sym_extern] = ACTIONS(59),
    [anon_sym___attribute__] = ACTIONS(41),
    [anon_sym_COLON_COLON] = ACTIONS(4078),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1805),
    [anon_sym___declspec] = ACTIONS(47),
    [anon_sym_signed] = ACTIONS(55),
    [anon_sym_unsigned] = ACTIONS(55),
    [anon_sym_long] = ACTIONS(55),
    [anon_sym_short] = ACTIONS(55),
    [anon_sym_static] = ACTIONS(59),
    [anon_sym_register] = ACTIONS(59),
    [anon_sym_inline] = ACTIONS(59),
    [anon_sym___inline] = ACTIONS(59),
    [anon_sym___inline__] = ACTIONS(59),
    [anon_sym___forceinline] = ACTIONS(59),
    [anon_sym_thread_local] = ACTIONS(59),
    [anon_sym___thread] = ACTIONS(59),
    [anon_sym_const] = ACTIONS(63),
    [anon_sym_constexpr] = ACTIONS(63),
    [anon_sym_volatile] = ACTIONS(63),
    [anon_sym_restrict] = ACTIONS(63),
    [anon_sym___restrict__] = ACTIONS(63),
    [anon_sym__Atomic] = ACTIONS(63),
    [anon_sym__Noreturn] = ACTIONS(63),
    [anon_sym_noreturn] = ACTIONS(63),
    [anon_sym_mutable] = ACTIONS(63),
    [anon_sym_constinit] = ACTIONS(63),
    [anon_sym_consteval] = ACTIONS(63),
    [anon_sym_alignas] = ACTIONS(65),
    [anon_sym__Alignas] = ACTIONS(65),
    [sym_primitive_type] = ACTIONS(2617),
    [anon_sym_enum] = ACTIONS(1833),
    [anon_sym_class] = ACTIONS(1835),
    [anon_sym_struct] = ACTIONS(1837),
    [anon_sym_union] = ACTIONS(1839),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(121),
    [anon_sym_decltype] = ACTIONS(123),
    [sym_virtual] = ACTIONS(5183),
    [anon_sym_typename] = ACTIONS(1863),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_precise] = ACTIONS(159),
    [anon_sym_shared] = ACTIONS(159),
    [anon_sym_groupshared] = ACTIONS(159),
    [anon_sym_uniform] = ACTIONS(159),
    [anon_sym_row_major] = ACTIONS(159),
    [anon_sym_column_major] = ACTIONS(159),
    [anon_sym_globallycoherent] = ACTIONS(159),
    [anon_sym_centroid] = ACTIONS(159),
    [anon_sym_noperspective] = ACTIONS(159),
    [anon_sym_nointerpolation] = ACTIONS(159),
    [anon_sym_sample] = ACTIONS(159),
    [anon_sym_linear] = ACTIONS(159),
    [anon_sym_snorm] = ACTIONS(159),
    [anon_sym_unorm] = ACTIONS(159),
    [anon_sym_point] = ACTIONS(159),
    [anon_sym_line] = ACTIONS(159),
    [anon_sym_triangleadj] = ACTIONS(159),
    [anon_sym_lineadj] = ACTIONS(159),
    [anon_sym_triangle] = ACTIONS(159),
  },
  [1985] = {
    [sym_identifier] = ACTIONS(1931),
    [aux_sym_preproc_def_token1] = ACTIONS(1931),
    [aux_sym_preproc_if_token1] = ACTIONS(1931),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1931),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1931),
    [sym_preproc_directive] = ACTIONS(1931),
    [anon_sym_LPAREN2] = ACTIONS(1929),
    [anon_sym_TILDE] = ACTIONS(1929),
    [anon_sym_STAR] = ACTIONS(1929),
    [anon_sym_AMP_AMP] = ACTIONS(1929),
    [anon_sym_AMP] = ACTIONS(1931),
    [anon_sym___extension__] = ACTIONS(1931),
    [anon_sym_typedef] = ACTIONS(1931),
    [anon_sym_in] = ACTIONS(1931),
    [anon_sym_out] = ACTIONS(1931),
    [anon_sym_inout] = ACTIONS(1931),
    [anon_sym_extern] = ACTIONS(1931),
    [anon_sym___attribute__] = ACTIONS(1931),
    [anon_sym_COLON_COLON] = ACTIONS(1929),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1929),
    [anon_sym___declspec] = ACTIONS(1931),
    [anon_sym___based] = ACTIONS(1931),
    [anon_sym_RBRACE] = ACTIONS(1929),
    [anon_sym_signed] = ACTIONS(1931),
    [anon_sym_unsigned] = ACTIONS(1931),
    [anon_sym_long] = ACTIONS(1931),
    [anon_sym_short] = ACTIONS(1931),
    [anon_sym_LBRACK] = ACTIONS(1931),
    [anon_sym_static] = ACTIONS(1931),
    [anon_sym_register] = ACTIONS(1931),
    [anon_sym_inline] = ACTIONS(1931),
    [anon_sym___inline] = ACTIONS(1931),
    [anon_sym___inline__] = ACTIONS(1931),
    [anon_sym___forceinline] = ACTIONS(1931),
    [anon_sym_thread_local] = ACTIONS(1931),
    [anon_sym___thread] = ACTIONS(1931),
    [anon_sym_const] = ACTIONS(1931),
    [anon_sym_constexpr] = ACTIONS(1931),
    [anon_sym_volatile] = ACTIONS(1931),
    [anon_sym_restrict] = ACTIONS(1931),
    [anon_sym___restrict__] = ACTIONS(1931),
    [anon_sym__Atomic] = ACTIONS(1931),
    [anon_sym__Noreturn] = ACTIONS(1931),
    [anon_sym_noreturn] = ACTIONS(1931),
    [anon_sym_mutable] = ACTIONS(1931),
    [anon_sym_constinit] = ACTIONS(1931),
    [anon_sym_consteval] = ACTIONS(1931),
    [anon_sym_alignas] = ACTIONS(1931),
    [anon_sym__Alignas] = ACTIONS(1931),
    [sym_primitive_type] = ACTIONS(1931),
    [anon_sym_enum] = ACTIONS(1931),
    [anon_sym_class] = ACTIONS(1931),
    [anon_sym_struct] = ACTIONS(1931),
    [anon_sym_union] = ACTIONS(1931),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1931),
    [anon_sym_decltype] = ACTIONS(1931),
    [sym_virtual] = ACTIONS(1931),
    [anon_sym_explicit] = ACTIONS(1931),
    [anon_sym_typename] = ACTIONS(1931),
    [anon_sym_template] = ACTIONS(1931),
    [anon_sym_operator] = ACTIONS(1931),
    [anon_sym_friend] = ACTIONS(1931),
    [anon_sym_public] = ACTIONS(1931),
    [anon_sym_private] = ACTIONS(1931),
    [anon_sym_protected] = ACTIONS(1931),
    [anon_sym_using] = ACTIONS(1931),
    [anon_sym_static_assert] = ACTIONS(1931),
    [anon_sym_catch] = ACTIONS(1931),
    [anon_sym_precise] = ACTIONS(1931),
    [anon_sym_shared] = ACTIONS(1931),
    [anon_sym_groupshared] = ACTIONS(1931),
    [anon_sym_uniform] = ACTIONS(1931),
    [anon_sym_row_major] = ACTIONS(1931),
    [anon_sym_column_major] = ACTIONS(1931),
    [anon_sym_globallycoherent] = ACTIONS(1931),
    [anon_sym_centroid] = ACTIONS(1931),
    [anon_sym_noperspective] = ACTIONS(1931),
    [anon_sym_nointerpolation] = ACTIONS(1931),
    [anon_sym_sample] = ACTIONS(1931),
    [anon_sym_linear] = ACTIONS(1931),
    [anon_sym_snorm] = ACTIONS(1931),
    [anon_sym_unorm] = ACTIONS(1931),
    [anon_sym_point] = ACTIONS(1931),
    [anon_sym_line] = ACTIONS(1931),
    [anon_sym_triangleadj] = ACTIONS(1931),
    [anon_sym_lineadj] = ACTIONS(1931),
    [anon_sym_triangle] = ACTIONS(1931),
  },
  [1986] = {
    [sym_identifier] = ACTIONS(1947),
    [aux_sym_preproc_def_token1] = ACTIONS(1947),
    [aux_sym_preproc_if_token1] = ACTIONS(1947),
    [aux_sym_preproc_if_token2] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1947),
    [sym_preproc_directive] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1945),
    [anon_sym_TILDE] = ACTIONS(1945),
    [anon_sym_STAR] = ACTIONS(1945),
    [anon_sym_AMP_AMP] = ACTIONS(1945),
    [anon_sym_AMP] = ACTIONS(1947),
    [anon_sym___extension__] = ACTIONS(1947),
    [anon_sym_typedef] = ACTIONS(1947),
    [anon_sym_in] = ACTIONS(1947),
    [anon_sym_out] = ACTIONS(1947),
    [anon_sym_inout] = ACTIONS(1947),
    [anon_sym_extern] = ACTIONS(1947),
    [anon_sym___attribute__] = ACTIONS(1947),
    [anon_sym_COLON_COLON] = ACTIONS(1945),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1945),
    [anon_sym___declspec] = ACTIONS(1947),
    [anon_sym___based] = ACTIONS(1947),
    [anon_sym_signed] = ACTIONS(1947),
    [anon_sym_unsigned] = ACTIONS(1947),
    [anon_sym_long] = ACTIONS(1947),
    [anon_sym_short] = ACTIONS(1947),
    [anon_sym_LBRACK] = ACTIONS(1947),
    [anon_sym_static] = ACTIONS(1947),
    [anon_sym_register] = ACTIONS(1947),
    [anon_sym_inline] = ACTIONS(1947),
    [anon_sym___inline] = ACTIONS(1947),
    [anon_sym___inline__] = ACTIONS(1947),
    [anon_sym___forceinline] = ACTIONS(1947),
    [anon_sym_thread_local] = ACTIONS(1947),
    [anon_sym___thread] = ACTIONS(1947),
    [anon_sym_const] = ACTIONS(1947),
    [anon_sym_constexpr] = ACTIONS(1947),
    [anon_sym_volatile] = ACTIONS(1947),
    [anon_sym_restrict] = ACTIONS(1947),
    [anon_sym___restrict__] = ACTIONS(1947),
    [anon_sym__Atomic] = ACTIONS(1947),
    [anon_sym__Noreturn] = ACTIONS(1947),
    [anon_sym_noreturn] = ACTIONS(1947),
    [anon_sym_mutable] = ACTIONS(1947),
    [anon_sym_constinit] = ACTIONS(1947),
    [anon_sym_consteval] = ACTIONS(1947),
    [anon_sym_alignas] = ACTIONS(1947),
    [anon_sym__Alignas] = ACTIONS(1947),
    [sym_primitive_type] = ACTIONS(1947),
    [anon_sym_enum] = ACTIONS(1947),
    [anon_sym_class] = ACTIONS(1947),
    [anon_sym_struct] = ACTIONS(1947),
    [anon_sym_union] = ACTIONS(1947),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1947),
    [anon_sym_decltype] = ACTIONS(1947),
    [sym_virtual] = ACTIONS(1947),
    [anon_sym_explicit] = ACTIONS(1947),
    [anon_sym_typename] = ACTIONS(1947),
    [anon_sym_template] = ACTIONS(1947),
    [anon_sym_operator] = ACTIONS(1947),
    [anon_sym_friend] = ACTIONS(1947),
    [anon_sym_public] = ACTIONS(1947),
    [anon_sym_private] = ACTIONS(1947),
    [anon_sym_protected] = ACTIONS(1947),
    [anon_sym_using] = ACTIONS(1947),
    [anon_sym_static_assert] = ACTIONS(1947),
    [anon_sym_catch] = ACTIONS(1947),
    [anon_sym_precise] = ACTIONS(1947),
    [anon_sym_shared] = ACTIONS(1947),
    [anon_sym_groupshared] = ACTIONS(1947),
    [anon_sym_uniform] = ACTIONS(1947),
    [anon_sym_row_major] = ACTIONS(1947),
    [anon_sym_column_major] = ACTIONS(1947),
    [anon_sym_globallycoherent] = ACTIONS(1947),
    [anon_sym_centroid] = ACTIONS(1947),
    [anon_sym_noperspective] = ACTIONS(1947),
    [anon_sym_nointerpolation] = ACTIONS(1947),
    [anon_sym_sample] = ACTIONS(1947),
    [anon_sym_linear] = ACTIONS(1947),
    [anon_sym_snorm] = ACTIONS(1947),
    [anon_sym_unorm] = ACTIONS(1947),
    [anon_sym_point] = ACTIONS(1947),
    [anon_sym_line] = ACTIONS(1947),
    [anon_sym_triangleadj] = ACTIONS(1947),
    [anon_sym_lineadj] = ACTIONS(1947),
    [anon_sym_triangle] = ACTIONS(1947),
  },
  [1987] = {
    [sym_template_argument_list] = STATE(2212),
    [sym_identifier] = ACTIONS(1941),
    [anon_sym_LPAREN2] = ACTIONS(1943),
    [anon_sym_TILDE] = ACTIONS(1943),
    [anon_sym_STAR] = ACTIONS(1943),
    [anon_sym_PIPE_PIPE] = ACTIONS(1943),
    [anon_sym_AMP_AMP] = ACTIONS(1943),
    [anon_sym_AMP] = ACTIONS(1941),
    [anon_sym_LT] = ACTIONS(5196),
    [anon_sym___extension__] = ACTIONS(1941),
    [anon_sym_in] = ACTIONS(1941),
    [anon_sym_out] = ACTIONS(1941),
    [anon_sym_inout] = ACTIONS(1941),
    [anon_sym_extern] = ACTIONS(1941),
    [anon_sym___attribute__] = ACTIONS(1941),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1943),
    [anon_sym___declspec] = ACTIONS(1941),
    [anon_sym___based] = ACTIONS(1941),
    [anon_sym___cdecl] = ACTIONS(1941),
    [anon_sym___clrcall] = ACTIONS(1941),
    [anon_sym___stdcall] = ACTIONS(1941),
    [anon_sym___fastcall] = ACTIONS(1941),
    [anon_sym___thiscall] = ACTIONS(1941),
    [anon_sym___vectorcall] = ACTIONS(1941),
    [anon_sym_signed] = ACTIONS(1941),
    [anon_sym_unsigned] = ACTIONS(1941),
    [anon_sym_long] = ACTIONS(1941),
    [anon_sym_short] = ACTIONS(1941),
    [anon_sym_LBRACK] = ACTIONS(1941),
    [anon_sym_static] = ACTIONS(1941),
    [anon_sym_register] = ACTIONS(1941),
    [anon_sym_inline] = ACTIONS(1941),
    [anon_sym___inline] = ACTIONS(1941),
    [anon_sym___inline__] = ACTIONS(1941),
    [anon_sym___forceinline] = ACTIONS(1941),
    [anon_sym_thread_local] = ACTIONS(1941),
    [anon_sym___thread] = ACTIONS(1941),
    [anon_sym_const] = ACTIONS(1941),
    [anon_sym_constexpr] = ACTIONS(1941),
    [anon_sym_volatile] = ACTIONS(1941),
    [anon_sym_restrict] = ACTIONS(1941),
    [anon_sym___restrict__] = ACTIONS(1941),
    [anon_sym__Atomic] = ACTIONS(1941),
    [anon_sym__Noreturn] = ACTIONS(1941),
    [anon_sym_noreturn] = ACTIONS(1941),
    [anon_sym_mutable] = ACTIONS(1941),
    [anon_sym_constinit] = ACTIONS(1941),
    [anon_sym_consteval] = ACTIONS(1941),
    [anon_sym_alignas] = ACTIONS(1941),
    [anon_sym__Alignas] = ACTIONS(1941),
    [sym_primitive_type] = ACTIONS(1941),
    [anon_sym_enum] = ACTIONS(1941),
    [anon_sym_class] = ACTIONS(1941),
    [anon_sym_struct] = ACTIONS(1941),
    [anon_sym_union] = ACTIONS(1941),
    [anon_sym_or] = ACTIONS(1941),
    [anon_sym_and] = ACTIONS(1941),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1941),
    [anon_sym_decltype] = ACTIONS(1941),
    [sym_virtual] = ACTIONS(1941),
    [anon_sym_explicit] = ACTIONS(1941),
    [anon_sym_typename] = ACTIONS(1941),
    [anon_sym_template] = ACTIONS(1941),
    [anon_sym_operator] = ACTIONS(1941),
    [anon_sym_friend] = ACTIONS(1941),
    [anon_sym_using] = ACTIONS(1941),
    [anon_sym_concept] = ACTIONS(1941),
    [anon_sym_precise] = ACTIONS(1941),
    [anon_sym_shared] = ACTIONS(1941),
    [anon_sym_groupshared] = ACTIONS(1941),
    [anon_sym_uniform] = ACTIONS(1941),
    [anon_sym_row_major] = ACTIONS(1941),
    [anon_sym_column_major] = ACTIONS(1941),
    [anon_sym_globallycoherent] = ACTIONS(1941),
    [anon_sym_centroid] = ACTIONS(1941),
    [anon_sym_noperspective] = ACTIONS(1941),
    [anon_sym_nointerpolation] = ACTIONS(1941),
    [anon_sym_sample] = ACTIONS(1941),
    [anon_sym_linear] = ACTIONS(1941),
    [anon_sym_snorm] = ACTIONS(1941),
    [anon_sym_unorm] = ACTIONS(1941),
    [anon_sym_point] = ACTIONS(1941),
    [anon_sym_line] = ACTIONS(1941),
    [anon_sym_triangleadj] = ACTIONS(1941),
    [anon_sym_lineadj] = ACTIONS(1941),
    [anon_sym_triangle] = ACTIONS(1941),
  },
  [1988] = {
    [sym_template_argument_list] = STATE(2212),
    [sym_identifier] = ACTIONS(1933),
    [anon_sym_LPAREN2] = ACTIONS(1935),
    [anon_sym_TILDE] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1935),
    [anon_sym_PIPE_PIPE] = ACTIONS(1935),
    [anon_sym_AMP_AMP] = ACTIONS(1935),
    [anon_sym_AMP] = ACTIONS(1933),
    [anon_sym_LT] = ACTIONS(5196),
    [anon_sym___extension__] = ACTIONS(1933),
    [anon_sym_in] = ACTIONS(1933),
    [anon_sym_out] = ACTIONS(1933),
    [anon_sym_inout] = ACTIONS(1933),
    [anon_sym_extern] = ACTIONS(1933),
    [anon_sym___attribute__] = ACTIONS(1933),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1935),
    [anon_sym___declspec] = ACTIONS(1933),
    [anon_sym___based] = ACTIONS(1933),
    [anon_sym___cdecl] = ACTIONS(1933),
    [anon_sym___clrcall] = ACTIONS(1933),
    [anon_sym___stdcall] = ACTIONS(1933),
    [anon_sym___fastcall] = ACTIONS(1933),
    [anon_sym___thiscall] = ACTIONS(1933),
    [anon_sym___vectorcall] = ACTIONS(1933),
    [anon_sym_signed] = ACTIONS(1933),
    [anon_sym_unsigned] = ACTIONS(1933),
    [anon_sym_long] = ACTIONS(1933),
    [anon_sym_short] = ACTIONS(1933),
    [anon_sym_LBRACK] = ACTIONS(1933),
    [anon_sym_static] = ACTIONS(1933),
    [anon_sym_register] = ACTIONS(1933),
    [anon_sym_inline] = ACTIONS(1933),
    [anon_sym___inline] = ACTIONS(1933),
    [anon_sym___inline__] = ACTIONS(1933),
    [anon_sym___forceinline] = ACTIONS(1933),
    [anon_sym_thread_local] = ACTIONS(1933),
    [anon_sym___thread] = ACTIONS(1933),
    [anon_sym_const] = ACTIONS(1933),
    [anon_sym_constexpr] = ACTIONS(1933),
    [anon_sym_volatile] = ACTIONS(1933),
    [anon_sym_restrict] = ACTIONS(1933),
    [anon_sym___restrict__] = ACTIONS(1933),
    [anon_sym__Atomic] = ACTIONS(1933),
    [anon_sym__Noreturn] = ACTIONS(1933),
    [anon_sym_noreturn] = ACTIONS(1933),
    [anon_sym_mutable] = ACTIONS(1933),
    [anon_sym_constinit] = ACTIONS(1933),
    [anon_sym_consteval] = ACTIONS(1933),
    [anon_sym_alignas] = ACTIONS(1933),
    [anon_sym__Alignas] = ACTIONS(1933),
    [sym_primitive_type] = ACTIONS(1933),
    [anon_sym_enum] = ACTIONS(1933),
    [anon_sym_class] = ACTIONS(1933),
    [anon_sym_struct] = ACTIONS(1933),
    [anon_sym_union] = ACTIONS(1933),
    [anon_sym_or] = ACTIONS(1933),
    [anon_sym_and] = ACTIONS(1933),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1933),
    [anon_sym_decltype] = ACTIONS(1933),
    [sym_virtual] = ACTIONS(1933),
    [anon_sym_explicit] = ACTIONS(1933),
    [anon_sym_typename] = ACTIONS(1933),
    [anon_sym_template] = ACTIONS(1933),
    [anon_sym_operator] = ACTIONS(1933),
    [anon_sym_friend] = ACTIONS(1933),
    [anon_sym_using] = ACTIONS(1933),
    [anon_sym_concept] = ACTIONS(1933),
    [anon_sym_precise] = ACTIONS(1933),
    [anon_sym_shared] = ACTIONS(1933),
    [anon_sym_groupshared] = ACTIONS(1933),
    [anon_sym_uniform] = ACTIONS(1933),
    [anon_sym_row_major] = ACTIONS(1933),
    [anon_sym_column_major] = ACTIONS(1933),
    [anon_sym_globallycoherent] = ACTIONS(1933),
    [anon_sym_centroid] = ACTIONS(1933),
    [anon_sym_noperspective] = ACTIONS(1933),
    [anon_sym_nointerpolation] = ACTIONS(1933),
    [anon_sym_sample] = ACTIONS(1933),
    [anon_sym_linear] = ACTIONS(1933),
    [anon_sym_snorm] = ACTIONS(1933),
    [anon_sym_unorm] = ACTIONS(1933),
    [anon_sym_point] = ACTIONS(1933),
    [anon_sym_line] = ACTIONS(1933),
    [anon_sym_triangleadj] = ACTIONS(1933),
    [anon_sym_lineadj] = ACTIONS(1933),
    [anon_sym_triangle] = ACTIONS(1933),
  },
  [1989] = {
    [sym_string_literal] = STATE(2509),
    [sym_template_argument_list] = STATE(2415),
    [sym_raw_string_literal] = STATE(2509),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2520),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_RPAREN] = ACTIONS(3837),
    [anon_sym_LPAREN2] = ACTIONS(3837),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3834),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3837),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3834),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5198),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym___extension__] = ACTIONS(3830),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_signed] = ACTIONS(5190),
    [anon_sym_unsigned] = ACTIONS(5190),
    [anon_sym_long] = ACTIONS(5190),
    [anon_sym_short] = ACTIONS(5190),
    [anon_sym_LBRACK] = ACTIONS(3837),
    [anon_sym_EQ] = ACTIONS(3832),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3830),
    [anon_sym_volatile] = ACTIONS(3830),
    [anon_sym_restrict] = ACTIONS(3830),
    [anon_sym___restrict__] = ACTIONS(3830),
    [anon_sym__Atomic] = ACTIONS(3830),
    [anon_sym__Noreturn] = ACTIONS(3830),
    [anon_sym_noreturn] = ACTIONS(3830),
    [anon_sym_mutable] = ACTIONS(3830),
    [anon_sym_constinit] = ACTIONS(3830),
    [anon_sym_consteval] = ACTIONS(3830),
    [anon_sym_alignas] = ACTIONS(3830),
    [anon_sym__Alignas] = ACTIONS(3830),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3824),
    [anon_sym_SLASH_EQ] = ACTIONS(3824),
    [anon_sym_PERCENT_EQ] = ACTIONS(3824),
    [anon_sym_PLUS_EQ] = ACTIONS(3824),
    [anon_sym_DASH_EQ] = ACTIONS(3824),
    [anon_sym_LT_LT_EQ] = ACTIONS(3824),
    [anon_sym_GT_GT_EQ] = ACTIONS(3824),
    [anon_sym_AMP_EQ] = ACTIONS(3824),
    [anon_sym_CARET_EQ] = ACTIONS(3824),
    [anon_sym_PIPE_EQ] = ACTIONS(3824),
    [anon_sym_and_eq] = ACTIONS(3824),
    [anon_sym_or_eq] = ACTIONS(3824),
    [anon_sym_xor_eq] = ACTIONS(3824),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3832),
    [anon_sym_L_DQUOTE] = ACTIONS(5192),
    [anon_sym_u_DQUOTE] = ACTIONS(5192),
    [anon_sym_U_DQUOTE] = ACTIONS(5192),
    [anon_sym_u8_DQUOTE] = ACTIONS(5192),
    [anon_sym_DQUOTE] = ACTIONS(5192),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3830),
    [anon_sym_decltype] = ACTIONS(3830),
    [anon_sym_R_DQUOTE] = ACTIONS(5194),
    [anon_sym_LR_DQUOTE] = ACTIONS(5194),
    [anon_sym_uR_DQUOTE] = ACTIONS(5194),
    [anon_sym_UR_DQUOTE] = ACTIONS(5194),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5194),
    [anon_sym_DASH_GT_STAR] = ACTIONS(3824),
  },
  [1990] = {
    [sym_identifier] = ACTIONS(2012),
    [aux_sym_preproc_def_token1] = ACTIONS(2012),
    [aux_sym_preproc_if_token1] = ACTIONS(2012),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2012),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2012),
    [sym_preproc_directive] = ACTIONS(2012),
    [anon_sym_LPAREN2] = ACTIONS(2014),
    [anon_sym_TILDE] = ACTIONS(2014),
    [anon_sym_STAR] = ACTIONS(2014),
    [anon_sym_AMP_AMP] = ACTIONS(2014),
    [anon_sym_AMP] = ACTIONS(2012),
    [anon_sym___extension__] = ACTIONS(2012),
    [anon_sym_typedef] = ACTIONS(2012),
    [anon_sym_in] = ACTIONS(2012),
    [anon_sym_out] = ACTIONS(2012),
    [anon_sym_inout] = ACTIONS(2012),
    [anon_sym_extern] = ACTIONS(2012),
    [anon_sym___attribute__] = ACTIONS(2012),
    [anon_sym_COLON_COLON] = ACTIONS(2014),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2014),
    [anon_sym___declspec] = ACTIONS(2012),
    [anon_sym___based] = ACTIONS(2012),
    [anon_sym_RBRACE] = ACTIONS(2014),
    [anon_sym_signed] = ACTIONS(2012),
    [anon_sym_unsigned] = ACTIONS(2012),
    [anon_sym_long] = ACTIONS(2012),
    [anon_sym_short] = ACTIONS(2012),
    [anon_sym_LBRACK] = ACTIONS(2012),
    [anon_sym_static] = ACTIONS(2012),
    [anon_sym_register] = ACTIONS(2012),
    [anon_sym_inline] = ACTIONS(2012),
    [anon_sym___inline] = ACTIONS(2012),
    [anon_sym___inline__] = ACTIONS(2012),
    [anon_sym___forceinline] = ACTIONS(2012),
    [anon_sym_thread_local] = ACTIONS(2012),
    [anon_sym___thread] = ACTIONS(2012),
    [anon_sym_const] = ACTIONS(2012),
    [anon_sym_constexpr] = ACTIONS(2012),
    [anon_sym_volatile] = ACTIONS(2012),
    [anon_sym_restrict] = ACTIONS(2012),
    [anon_sym___restrict__] = ACTIONS(2012),
    [anon_sym__Atomic] = ACTIONS(2012),
    [anon_sym__Noreturn] = ACTIONS(2012),
    [anon_sym_noreturn] = ACTIONS(2012),
    [anon_sym_mutable] = ACTIONS(2012),
    [anon_sym_constinit] = ACTIONS(2012),
    [anon_sym_consteval] = ACTIONS(2012),
    [anon_sym_alignas] = ACTIONS(2012),
    [anon_sym__Alignas] = ACTIONS(2012),
    [sym_primitive_type] = ACTIONS(2012),
    [anon_sym_enum] = ACTIONS(2012),
    [anon_sym_class] = ACTIONS(2012),
    [anon_sym_struct] = ACTIONS(2012),
    [anon_sym_union] = ACTIONS(2012),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2012),
    [anon_sym_decltype] = ACTIONS(2012),
    [sym_virtual] = ACTIONS(2012),
    [anon_sym_explicit] = ACTIONS(2012),
    [anon_sym_typename] = ACTIONS(2012),
    [anon_sym_template] = ACTIONS(2012),
    [anon_sym_operator] = ACTIONS(2012),
    [anon_sym_friend] = ACTIONS(2012),
    [anon_sym_public] = ACTIONS(2012),
    [anon_sym_private] = ACTIONS(2012),
    [anon_sym_protected] = ACTIONS(2012),
    [anon_sym_using] = ACTIONS(2012),
    [anon_sym_static_assert] = ACTIONS(2012),
    [anon_sym_catch] = ACTIONS(2012),
    [anon_sym_precise] = ACTIONS(2012),
    [anon_sym_shared] = ACTIONS(2012),
    [anon_sym_groupshared] = ACTIONS(2012),
    [anon_sym_uniform] = ACTIONS(2012),
    [anon_sym_row_major] = ACTIONS(2012),
    [anon_sym_column_major] = ACTIONS(2012),
    [anon_sym_globallycoherent] = ACTIONS(2012),
    [anon_sym_centroid] = ACTIONS(2012),
    [anon_sym_noperspective] = ACTIONS(2012),
    [anon_sym_nointerpolation] = ACTIONS(2012),
    [anon_sym_sample] = ACTIONS(2012),
    [anon_sym_linear] = ACTIONS(2012),
    [anon_sym_snorm] = ACTIONS(2012),
    [anon_sym_unorm] = ACTIONS(2012),
    [anon_sym_point] = ACTIONS(2012),
    [anon_sym_line] = ACTIONS(2012),
    [anon_sym_triangleadj] = ACTIONS(2012),
    [anon_sym_lineadj] = ACTIONS(2012),
    [anon_sym_triangle] = ACTIONS(2012),
  },
  [1991] = {
    [sym_identifier] = ACTIONS(1947),
    [aux_sym_preproc_def_token1] = ACTIONS(1947),
    [aux_sym_preproc_if_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1947),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1947),
    [sym_preproc_directive] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1945),
    [anon_sym_TILDE] = ACTIONS(1945),
    [anon_sym_STAR] = ACTIONS(1945),
    [anon_sym_AMP_AMP] = ACTIONS(1945),
    [anon_sym_AMP] = ACTIONS(1947),
    [anon_sym___extension__] = ACTIONS(1947),
    [anon_sym_typedef] = ACTIONS(1947),
    [anon_sym_in] = ACTIONS(1947),
    [anon_sym_out] = ACTIONS(1947),
    [anon_sym_inout] = ACTIONS(1947),
    [anon_sym_extern] = ACTIONS(1947),
    [anon_sym___attribute__] = ACTIONS(1947),
    [anon_sym_COLON_COLON] = ACTIONS(1945),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1945),
    [anon_sym___declspec] = ACTIONS(1947),
    [anon_sym___based] = ACTIONS(1947),
    [anon_sym_RBRACE] = ACTIONS(1945),
    [anon_sym_signed] = ACTIONS(1947),
    [anon_sym_unsigned] = ACTIONS(1947),
    [anon_sym_long] = ACTIONS(1947),
    [anon_sym_short] = ACTIONS(1947),
    [anon_sym_LBRACK] = ACTIONS(1947),
    [anon_sym_static] = ACTIONS(1947),
    [anon_sym_register] = ACTIONS(1947),
    [anon_sym_inline] = ACTIONS(1947),
    [anon_sym___inline] = ACTIONS(1947),
    [anon_sym___inline__] = ACTIONS(1947),
    [anon_sym___forceinline] = ACTIONS(1947),
    [anon_sym_thread_local] = ACTIONS(1947),
    [anon_sym___thread] = ACTIONS(1947),
    [anon_sym_const] = ACTIONS(1947),
    [anon_sym_constexpr] = ACTIONS(1947),
    [anon_sym_volatile] = ACTIONS(1947),
    [anon_sym_restrict] = ACTIONS(1947),
    [anon_sym___restrict__] = ACTIONS(1947),
    [anon_sym__Atomic] = ACTIONS(1947),
    [anon_sym__Noreturn] = ACTIONS(1947),
    [anon_sym_noreturn] = ACTIONS(1947),
    [anon_sym_mutable] = ACTIONS(1947),
    [anon_sym_constinit] = ACTIONS(1947),
    [anon_sym_consteval] = ACTIONS(1947),
    [anon_sym_alignas] = ACTIONS(1947),
    [anon_sym__Alignas] = ACTIONS(1947),
    [sym_primitive_type] = ACTIONS(1947),
    [anon_sym_enum] = ACTIONS(1947),
    [anon_sym_class] = ACTIONS(1947),
    [anon_sym_struct] = ACTIONS(1947),
    [anon_sym_union] = ACTIONS(1947),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1947),
    [anon_sym_decltype] = ACTIONS(1947),
    [sym_virtual] = ACTIONS(1947),
    [anon_sym_explicit] = ACTIONS(1947),
    [anon_sym_typename] = ACTIONS(1947),
    [anon_sym_template] = ACTIONS(1947),
    [anon_sym_operator] = ACTIONS(1947),
    [anon_sym_friend] = ACTIONS(1947),
    [anon_sym_public] = ACTIONS(1947),
    [anon_sym_private] = ACTIONS(1947),
    [anon_sym_protected] = ACTIONS(1947),
    [anon_sym_using] = ACTIONS(1947),
    [anon_sym_static_assert] = ACTIONS(1947),
    [anon_sym_catch] = ACTIONS(1947),
    [anon_sym_precise] = ACTIONS(1947),
    [anon_sym_shared] = ACTIONS(1947),
    [anon_sym_groupshared] = ACTIONS(1947),
    [anon_sym_uniform] = ACTIONS(1947),
    [anon_sym_row_major] = ACTIONS(1947),
    [anon_sym_column_major] = ACTIONS(1947),
    [anon_sym_globallycoherent] = ACTIONS(1947),
    [anon_sym_centroid] = ACTIONS(1947),
    [anon_sym_noperspective] = ACTIONS(1947),
    [anon_sym_nointerpolation] = ACTIONS(1947),
    [anon_sym_sample] = ACTIONS(1947),
    [anon_sym_linear] = ACTIONS(1947),
    [anon_sym_snorm] = ACTIONS(1947),
    [anon_sym_unorm] = ACTIONS(1947),
    [anon_sym_point] = ACTIONS(1947),
    [anon_sym_line] = ACTIONS(1947),
    [anon_sym_triangleadj] = ACTIONS(1947),
    [anon_sym_lineadj] = ACTIONS(1947),
    [anon_sym_triangle] = ACTIONS(1947),
  },
  [1992] = {
    [sym_identifier] = ACTIONS(1931),
    [aux_sym_preproc_def_token1] = ACTIONS(1931),
    [aux_sym_preproc_if_token1] = ACTIONS(1931),
    [aux_sym_preproc_if_token2] = ACTIONS(1931),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(1931),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(1931),
    [sym_preproc_directive] = ACTIONS(1931),
    [anon_sym_LPAREN2] = ACTIONS(1929),
    [anon_sym_TILDE] = ACTIONS(1929),
    [anon_sym_STAR] = ACTIONS(1929),
    [anon_sym_AMP_AMP] = ACTIONS(1929),
    [anon_sym_AMP] = ACTIONS(1931),
    [anon_sym___extension__] = ACTIONS(1931),
    [anon_sym_typedef] = ACTIONS(1931),
    [anon_sym_in] = ACTIONS(1931),
    [anon_sym_out] = ACTIONS(1931),
    [anon_sym_inout] = ACTIONS(1931),
    [anon_sym_extern] = ACTIONS(1931),
    [anon_sym___attribute__] = ACTIONS(1931),
    [anon_sym_COLON_COLON] = ACTIONS(1929),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1929),
    [anon_sym___declspec] = ACTIONS(1931),
    [anon_sym___based] = ACTIONS(1931),
    [anon_sym_signed] = ACTIONS(1931),
    [anon_sym_unsigned] = ACTIONS(1931),
    [anon_sym_long] = ACTIONS(1931),
    [anon_sym_short] = ACTIONS(1931),
    [anon_sym_LBRACK] = ACTIONS(1931),
    [anon_sym_static] = ACTIONS(1931),
    [anon_sym_register] = ACTIONS(1931),
    [anon_sym_inline] = ACTIONS(1931),
    [anon_sym___inline] = ACTIONS(1931),
    [anon_sym___inline__] = ACTIONS(1931),
    [anon_sym___forceinline] = ACTIONS(1931),
    [anon_sym_thread_local] = ACTIONS(1931),
    [anon_sym___thread] = ACTIONS(1931),
    [anon_sym_const] = ACTIONS(1931),
    [anon_sym_constexpr] = ACTIONS(1931),
    [anon_sym_volatile] = ACTIONS(1931),
    [anon_sym_restrict] = ACTIONS(1931),
    [anon_sym___restrict__] = ACTIONS(1931),
    [anon_sym__Atomic] = ACTIONS(1931),
    [anon_sym__Noreturn] = ACTIONS(1931),
    [anon_sym_noreturn] = ACTIONS(1931),
    [anon_sym_mutable] = ACTIONS(1931),
    [anon_sym_constinit] = ACTIONS(1931),
    [anon_sym_consteval] = ACTIONS(1931),
    [anon_sym_alignas] = ACTIONS(1931),
    [anon_sym__Alignas] = ACTIONS(1931),
    [sym_primitive_type] = ACTIONS(1931),
    [anon_sym_enum] = ACTIONS(1931),
    [anon_sym_class] = ACTIONS(1931),
    [anon_sym_struct] = ACTIONS(1931),
    [anon_sym_union] = ACTIONS(1931),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1931),
    [anon_sym_decltype] = ACTIONS(1931),
    [sym_virtual] = ACTIONS(1931),
    [anon_sym_explicit] = ACTIONS(1931),
    [anon_sym_typename] = ACTIONS(1931),
    [anon_sym_template] = ACTIONS(1931),
    [anon_sym_operator] = ACTIONS(1931),
    [anon_sym_friend] = ACTIONS(1931),
    [anon_sym_public] = ACTIONS(1931),
    [anon_sym_private] = ACTIONS(1931),
    [anon_sym_protected] = ACTIONS(1931),
    [anon_sym_using] = ACTIONS(1931),
    [anon_sym_static_assert] = ACTIONS(1931),
    [anon_sym_catch] = ACTIONS(1931),
    [anon_sym_precise] = ACTIONS(1931),
    [anon_sym_shared] = ACTIONS(1931),
    [anon_sym_groupshared] = ACTIONS(1931),
    [anon_sym_uniform] = ACTIONS(1931),
    [anon_sym_row_major] = ACTIONS(1931),
    [anon_sym_column_major] = ACTIONS(1931),
    [anon_sym_globallycoherent] = ACTIONS(1931),
    [anon_sym_centroid] = ACTIONS(1931),
    [anon_sym_noperspective] = ACTIONS(1931),
    [anon_sym_nointerpolation] = ACTIONS(1931),
    [anon_sym_sample] = ACTIONS(1931),
    [anon_sym_linear] = ACTIONS(1931),
    [anon_sym_snorm] = ACTIONS(1931),
    [anon_sym_unorm] = ACTIONS(1931),
    [anon_sym_point] = ACTIONS(1931),
    [anon_sym_line] = ACTIONS(1931),
    [anon_sym_triangleadj] = ACTIONS(1931),
    [anon_sym_lineadj] = ACTIONS(1931),
    [anon_sym_triangle] = ACTIONS(1931),
  },
  [1993] = {
    [sym_identifier] = ACTIONS(2012),
    [aux_sym_preproc_def_token1] = ACTIONS(2012),
    [aux_sym_preproc_if_token1] = ACTIONS(2012),
    [aux_sym_preproc_if_token2] = ACTIONS(2012),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2012),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2012),
    [sym_preproc_directive] = ACTIONS(2012),
    [anon_sym_LPAREN2] = ACTIONS(2014),
    [anon_sym_TILDE] = ACTIONS(2014),
    [anon_sym_STAR] = ACTIONS(2014),
    [anon_sym_AMP_AMP] = ACTIONS(2014),
    [anon_sym_AMP] = ACTIONS(2012),
    [anon_sym___extension__] = ACTIONS(2012),
    [anon_sym_typedef] = ACTIONS(2012),
    [anon_sym_in] = ACTIONS(2012),
    [anon_sym_out] = ACTIONS(2012),
    [anon_sym_inout] = ACTIONS(2012),
    [anon_sym_extern] = ACTIONS(2012),
    [anon_sym___attribute__] = ACTIONS(2012),
    [anon_sym_COLON_COLON] = ACTIONS(2014),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2014),
    [anon_sym___declspec] = ACTIONS(2012),
    [anon_sym___based] = ACTIONS(2012),
    [anon_sym_signed] = ACTIONS(2012),
    [anon_sym_unsigned] = ACTIONS(2012),
    [anon_sym_long] = ACTIONS(2012),
    [anon_sym_short] = ACTIONS(2012),
    [anon_sym_LBRACK] = ACTIONS(2012),
    [anon_sym_static] = ACTIONS(2012),
    [anon_sym_register] = ACTIONS(2012),
    [anon_sym_inline] = ACTIONS(2012),
    [anon_sym___inline] = ACTIONS(2012),
    [anon_sym___inline__] = ACTIONS(2012),
    [anon_sym___forceinline] = ACTIONS(2012),
    [anon_sym_thread_local] = ACTIONS(2012),
    [anon_sym___thread] = ACTIONS(2012),
    [anon_sym_const] = ACTIONS(2012),
    [anon_sym_constexpr] = ACTIONS(2012),
    [anon_sym_volatile] = ACTIONS(2012),
    [anon_sym_restrict] = ACTIONS(2012),
    [anon_sym___restrict__] = ACTIONS(2012),
    [anon_sym__Atomic] = ACTIONS(2012),
    [anon_sym__Noreturn] = ACTIONS(2012),
    [anon_sym_noreturn] = ACTIONS(2012),
    [anon_sym_mutable] = ACTIONS(2012),
    [anon_sym_constinit] = ACTIONS(2012),
    [anon_sym_consteval] = ACTIONS(2012),
    [anon_sym_alignas] = ACTIONS(2012),
    [anon_sym__Alignas] = ACTIONS(2012),
    [sym_primitive_type] = ACTIONS(2012),
    [anon_sym_enum] = ACTIONS(2012),
    [anon_sym_class] = ACTIONS(2012),
    [anon_sym_struct] = ACTIONS(2012),
    [anon_sym_union] = ACTIONS(2012),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2012),
    [anon_sym_decltype] = ACTIONS(2012),
    [sym_virtual] = ACTIONS(2012),
    [anon_sym_explicit] = ACTIONS(2012),
    [anon_sym_typename] = ACTIONS(2012),
    [anon_sym_template] = ACTIONS(2012),
    [anon_sym_operator] = ACTIONS(2012),
    [anon_sym_friend] = ACTIONS(2012),
    [anon_sym_public] = ACTIONS(2012),
    [anon_sym_private] = ACTIONS(2012),
    [anon_sym_protected] = ACTIONS(2012),
    [anon_sym_using] = ACTIONS(2012),
    [anon_sym_static_assert] = ACTIONS(2012),
    [anon_sym_catch] = ACTIONS(2012),
    [anon_sym_precise] = ACTIONS(2012),
    [anon_sym_shared] = ACTIONS(2012),
    [anon_sym_groupshared] = ACTIONS(2012),
    [anon_sym_uniform] = ACTIONS(2012),
    [anon_sym_row_major] = ACTIONS(2012),
    [anon_sym_column_major] = ACTIONS(2012),
    [anon_sym_globallycoherent] = ACTIONS(2012),
    [anon_sym_centroid] = ACTIONS(2012),
    [anon_sym_noperspective] = ACTIONS(2012),
    [anon_sym_nointerpolation] = ACTIONS(2012),
    [anon_sym_sample] = ACTIONS(2012),
    [anon_sym_linear] = ACTIONS(2012),
    [anon_sym_snorm] = ACTIONS(2012),
    [anon_sym_unorm] = ACTIONS(2012),
    [anon_sym_point] = ACTIONS(2012),
    [anon_sym_line] = ACTIONS(2012),
    [anon_sym_triangleadj] = ACTIONS(2012),
    [anon_sym_lineadj] = ACTIONS(2012),
    [anon_sym_triangle] = ACTIONS(2012),
  },
  [1994] = {
    [sym_identifier] = ACTIONS(2462),
    [aux_sym_preproc_def_token1] = ACTIONS(2462),
    [aux_sym_preproc_if_token1] = ACTIONS(2462),
    [aux_sym_preproc_if_token2] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2462),
    [sym_preproc_directive] = ACTIONS(2462),
    [anon_sym_LPAREN2] = ACTIONS(2464),
    [anon_sym_TILDE] = ACTIONS(2464),
    [anon_sym_STAR] = ACTIONS(2464),
    [anon_sym_AMP_AMP] = ACTIONS(2464),
    [anon_sym_AMP] = ACTIONS(2462),
    [anon_sym___extension__] = ACTIONS(2462),
    [anon_sym_typedef] = ACTIONS(2462),
    [anon_sym_in] = ACTIONS(2462),
    [anon_sym_out] = ACTIONS(2462),
    [anon_sym_inout] = ACTIONS(2462),
    [anon_sym_extern] = ACTIONS(2462),
    [anon_sym___attribute__] = ACTIONS(2462),
    [anon_sym_COLON_COLON] = ACTIONS(2464),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2464),
    [anon_sym___declspec] = ACTIONS(2462),
    [anon_sym___based] = ACTIONS(2462),
    [anon_sym_signed] = ACTIONS(2462),
    [anon_sym_unsigned] = ACTIONS(2462),
    [anon_sym_long] = ACTIONS(2462),
    [anon_sym_short] = ACTIONS(2462),
    [anon_sym_LBRACK] = ACTIONS(2462),
    [anon_sym_static] = ACTIONS(2462),
    [anon_sym_register] = ACTIONS(2462),
    [anon_sym_inline] = ACTIONS(2462),
    [anon_sym___inline] = ACTIONS(2462),
    [anon_sym___inline__] = ACTIONS(2462),
    [anon_sym___forceinline] = ACTIONS(2462),
    [anon_sym_thread_local] = ACTIONS(2462),
    [anon_sym___thread] = ACTIONS(2462),
    [anon_sym_const] = ACTIONS(2462),
    [anon_sym_constexpr] = ACTIONS(2462),
    [anon_sym_volatile] = ACTIONS(2462),
    [anon_sym_restrict] = ACTIONS(2462),
    [anon_sym___restrict__] = ACTIONS(2462),
    [anon_sym__Atomic] = ACTIONS(2462),
    [anon_sym__Noreturn] = ACTIONS(2462),
    [anon_sym_noreturn] = ACTIONS(2462),
    [anon_sym_mutable] = ACTIONS(2462),
    [anon_sym_constinit] = ACTIONS(2462),
    [anon_sym_consteval] = ACTIONS(2462),
    [anon_sym_alignas] = ACTIONS(2462),
    [anon_sym__Alignas] = ACTIONS(2462),
    [sym_primitive_type] = ACTIONS(2462),
    [anon_sym_enum] = ACTIONS(2462),
    [anon_sym_class] = ACTIONS(2462),
    [anon_sym_struct] = ACTIONS(2462),
    [anon_sym_union] = ACTIONS(2462),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2462),
    [anon_sym_decltype] = ACTIONS(2462),
    [sym_virtual] = ACTIONS(2462),
    [anon_sym_explicit] = ACTIONS(2462),
    [anon_sym_typename] = ACTIONS(2462),
    [anon_sym_template] = ACTIONS(2462),
    [anon_sym_operator] = ACTIONS(2462),
    [anon_sym_friend] = ACTIONS(2462),
    [anon_sym_public] = ACTIONS(2462),
    [anon_sym_private] = ACTIONS(2462),
    [anon_sym_protected] = ACTIONS(2462),
    [anon_sym_using] = ACTIONS(2462),
    [anon_sym_static_assert] = ACTIONS(2462),
    [anon_sym_precise] = ACTIONS(2462),
    [anon_sym_shared] = ACTIONS(2462),
    [anon_sym_groupshared] = ACTIONS(2462),
    [anon_sym_uniform] = ACTIONS(2462),
    [anon_sym_row_major] = ACTIONS(2462),
    [anon_sym_column_major] = ACTIONS(2462),
    [anon_sym_globallycoherent] = ACTIONS(2462),
    [anon_sym_centroid] = ACTIONS(2462),
    [anon_sym_noperspective] = ACTIONS(2462),
    [anon_sym_nointerpolation] = ACTIONS(2462),
    [anon_sym_sample] = ACTIONS(2462),
    [anon_sym_linear] = ACTIONS(2462),
    [anon_sym_snorm] = ACTIONS(2462),
    [anon_sym_unorm] = ACTIONS(2462),
    [anon_sym_point] = ACTIONS(2462),
    [anon_sym_line] = ACTIONS(2462),
    [anon_sym_triangleadj] = ACTIONS(2462),
    [anon_sym_lineadj] = ACTIONS(2462),
    [anon_sym_triangle] = ACTIONS(2462),
  },
  [1995] = {
    [sym_identifier] = ACTIONS(5065),
    [aux_sym_preproc_def_token1] = ACTIONS(5065),
    [aux_sym_preproc_if_token1] = ACTIONS(5065),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5065),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5065),
    [sym_preproc_directive] = ACTIONS(5065),
    [anon_sym_LPAREN2] = ACTIONS(5067),
    [anon_sym_TILDE] = ACTIONS(5067),
    [anon_sym_STAR] = ACTIONS(5067),
    [anon_sym_AMP_AMP] = ACTIONS(5067),
    [anon_sym_AMP] = ACTIONS(5065),
    [anon_sym___extension__] = ACTIONS(5065),
    [anon_sym_typedef] = ACTIONS(5065),
    [anon_sym_in] = ACTIONS(5065),
    [anon_sym_out] = ACTIONS(5065),
    [anon_sym_inout] = ACTIONS(5065),
    [anon_sym_extern] = ACTIONS(5065),
    [anon_sym___attribute__] = ACTIONS(5065),
    [anon_sym_COLON_COLON] = ACTIONS(5067),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5067),
    [anon_sym___declspec] = ACTIONS(5065),
    [anon_sym___based] = ACTIONS(5065),
    [anon_sym_RBRACE] = ACTIONS(5067),
    [anon_sym_signed] = ACTIONS(5065),
    [anon_sym_unsigned] = ACTIONS(5065),
    [anon_sym_long] = ACTIONS(5065),
    [anon_sym_short] = ACTIONS(5065),
    [anon_sym_LBRACK] = ACTIONS(5065),
    [anon_sym_static] = ACTIONS(5065),
    [anon_sym_register] = ACTIONS(5065),
    [anon_sym_inline] = ACTIONS(5065),
    [anon_sym___inline] = ACTIONS(5065),
    [anon_sym___inline__] = ACTIONS(5065),
    [anon_sym___forceinline] = ACTIONS(5065),
    [anon_sym_thread_local] = ACTIONS(5065),
    [anon_sym___thread] = ACTIONS(5065),
    [anon_sym_const] = ACTIONS(5065),
    [anon_sym_constexpr] = ACTIONS(5065),
    [anon_sym_volatile] = ACTIONS(5065),
    [anon_sym_restrict] = ACTIONS(5065),
    [anon_sym___restrict__] = ACTIONS(5065),
    [anon_sym__Atomic] = ACTIONS(5065),
    [anon_sym__Noreturn] = ACTIONS(5065),
    [anon_sym_noreturn] = ACTIONS(5065),
    [anon_sym_mutable] = ACTIONS(5065),
    [anon_sym_constinit] = ACTIONS(5065),
    [anon_sym_consteval] = ACTIONS(5065),
    [anon_sym_alignas] = ACTIONS(5065),
    [anon_sym__Alignas] = ACTIONS(5065),
    [sym_primitive_type] = ACTIONS(5065),
    [anon_sym_enum] = ACTIONS(5065),
    [anon_sym_class] = ACTIONS(5065),
    [anon_sym_struct] = ACTIONS(5065),
    [anon_sym_union] = ACTIONS(5065),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5065),
    [anon_sym_decltype] = ACTIONS(5065),
    [sym_virtual] = ACTIONS(5065),
    [anon_sym_explicit] = ACTIONS(5065),
    [anon_sym_typename] = ACTIONS(5065),
    [anon_sym_template] = ACTIONS(5065),
    [anon_sym_operator] = ACTIONS(5065),
    [anon_sym_friend] = ACTIONS(5065),
    [anon_sym_public] = ACTIONS(5065),
    [anon_sym_private] = ACTIONS(5065),
    [anon_sym_protected] = ACTIONS(5065),
    [anon_sym_using] = ACTIONS(5065),
    [anon_sym_static_assert] = ACTIONS(5065),
    [anon_sym_precise] = ACTIONS(5065),
    [anon_sym_shared] = ACTIONS(5065),
    [anon_sym_groupshared] = ACTIONS(5065),
    [anon_sym_uniform] = ACTIONS(5065),
    [anon_sym_row_major] = ACTIONS(5065),
    [anon_sym_column_major] = ACTIONS(5065),
    [anon_sym_globallycoherent] = ACTIONS(5065),
    [anon_sym_centroid] = ACTIONS(5065),
    [anon_sym_noperspective] = ACTIONS(5065),
    [anon_sym_nointerpolation] = ACTIONS(5065),
    [anon_sym_sample] = ACTIONS(5065),
    [anon_sym_linear] = ACTIONS(5065),
    [anon_sym_snorm] = ACTIONS(5065),
    [anon_sym_unorm] = ACTIONS(5065),
    [anon_sym_point] = ACTIONS(5065),
    [anon_sym_line] = ACTIONS(5065),
    [anon_sym_triangleadj] = ACTIONS(5065),
    [anon_sym_lineadj] = ACTIONS(5065),
    [anon_sym_triangle] = ACTIONS(5065),
  },
  [1996] = {
    [sym_identifier] = ACTIONS(2264),
    [aux_sym_preproc_def_token1] = ACTIONS(2264),
    [aux_sym_preproc_if_token1] = ACTIONS(2264),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2264),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2264),
    [sym_preproc_directive] = ACTIONS(2264),
    [anon_sym_LPAREN2] = ACTIONS(2266),
    [anon_sym_TILDE] = ACTIONS(2266),
    [anon_sym_STAR] = ACTIONS(2266),
    [anon_sym_AMP_AMP] = ACTIONS(2266),
    [anon_sym_AMP] = ACTIONS(2264),
    [anon_sym___extension__] = ACTIONS(2264),
    [anon_sym_typedef] = ACTIONS(2264),
    [anon_sym_in] = ACTIONS(2264),
    [anon_sym_out] = ACTIONS(2264),
    [anon_sym_inout] = ACTIONS(2264),
    [anon_sym_extern] = ACTIONS(2264),
    [anon_sym___attribute__] = ACTIONS(2264),
    [anon_sym_COLON_COLON] = ACTIONS(2266),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2266),
    [anon_sym___declspec] = ACTIONS(2264),
    [anon_sym___based] = ACTIONS(2264),
    [anon_sym_RBRACE] = ACTIONS(2266),
    [anon_sym_signed] = ACTIONS(2264),
    [anon_sym_unsigned] = ACTIONS(2264),
    [anon_sym_long] = ACTIONS(2264),
    [anon_sym_short] = ACTIONS(2264),
    [anon_sym_LBRACK] = ACTIONS(2264),
    [anon_sym_static] = ACTIONS(2264),
    [anon_sym_register] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(2264),
    [anon_sym___inline] = ACTIONS(2264),
    [anon_sym___inline__] = ACTIONS(2264),
    [anon_sym___forceinline] = ACTIONS(2264),
    [anon_sym_thread_local] = ACTIONS(2264),
    [anon_sym___thread] = ACTIONS(2264),
    [anon_sym_const] = ACTIONS(2264),
    [anon_sym_constexpr] = ACTIONS(2264),
    [anon_sym_volatile] = ACTIONS(2264),
    [anon_sym_restrict] = ACTIONS(2264),
    [anon_sym___restrict__] = ACTIONS(2264),
    [anon_sym__Atomic] = ACTIONS(2264),
    [anon_sym__Noreturn] = ACTIONS(2264),
    [anon_sym_noreturn] = ACTIONS(2264),
    [anon_sym_mutable] = ACTIONS(2264),
    [anon_sym_constinit] = ACTIONS(2264),
    [anon_sym_consteval] = ACTIONS(2264),
    [anon_sym_alignas] = ACTIONS(2264),
    [anon_sym__Alignas] = ACTIONS(2264),
    [sym_primitive_type] = ACTIONS(2264),
    [anon_sym_enum] = ACTIONS(2264),
    [anon_sym_class] = ACTIONS(2264),
    [anon_sym_struct] = ACTIONS(2264),
    [anon_sym_union] = ACTIONS(2264),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2264),
    [anon_sym_decltype] = ACTIONS(2264),
    [sym_virtual] = ACTIONS(2264),
    [anon_sym_explicit] = ACTIONS(2264),
    [anon_sym_typename] = ACTIONS(2264),
    [anon_sym_template] = ACTIONS(2264),
    [anon_sym_operator] = ACTIONS(2264),
    [anon_sym_friend] = ACTIONS(2264),
    [anon_sym_public] = ACTIONS(2264),
    [anon_sym_private] = ACTIONS(2264),
    [anon_sym_protected] = ACTIONS(2264),
    [anon_sym_using] = ACTIONS(2264),
    [anon_sym_static_assert] = ACTIONS(2264),
    [anon_sym_precise] = ACTIONS(2264),
    [anon_sym_shared] = ACTIONS(2264),
    [anon_sym_groupshared] = ACTIONS(2264),
    [anon_sym_uniform] = ACTIONS(2264),
    [anon_sym_row_major] = ACTIONS(2264),
    [anon_sym_column_major] = ACTIONS(2264),
    [anon_sym_globallycoherent] = ACTIONS(2264),
    [anon_sym_centroid] = ACTIONS(2264),
    [anon_sym_noperspective] = ACTIONS(2264),
    [anon_sym_nointerpolation] = ACTIONS(2264),
    [anon_sym_sample] = ACTIONS(2264),
    [anon_sym_linear] = ACTIONS(2264),
    [anon_sym_snorm] = ACTIONS(2264),
    [anon_sym_unorm] = ACTIONS(2264),
    [anon_sym_point] = ACTIONS(2264),
    [anon_sym_line] = ACTIONS(2264),
    [anon_sym_triangleadj] = ACTIONS(2264),
    [anon_sym_lineadj] = ACTIONS(2264),
    [anon_sym_triangle] = ACTIONS(2264),
  },
  [1997] = {
    [sym_identifier] = ACTIONS(2462),
    [aux_sym_preproc_def_token1] = ACTIONS(2462),
    [aux_sym_preproc_if_token1] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2462),
    [sym_preproc_directive] = ACTIONS(2462),
    [anon_sym_LPAREN2] = ACTIONS(2464),
    [anon_sym_TILDE] = ACTIONS(2464),
    [anon_sym_STAR] = ACTIONS(2464),
    [anon_sym_AMP_AMP] = ACTIONS(2464),
    [anon_sym_AMP] = ACTIONS(2462),
    [anon_sym___extension__] = ACTIONS(2462),
    [anon_sym_typedef] = ACTIONS(2462),
    [anon_sym_in] = ACTIONS(2462),
    [anon_sym_out] = ACTIONS(2462),
    [anon_sym_inout] = ACTIONS(2462),
    [anon_sym_extern] = ACTIONS(2462),
    [anon_sym___attribute__] = ACTIONS(2462),
    [anon_sym_COLON_COLON] = ACTIONS(2464),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2464),
    [anon_sym___declspec] = ACTIONS(2462),
    [anon_sym___based] = ACTIONS(2462),
    [anon_sym_RBRACE] = ACTIONS(2464),
    [anon_sym_signed] = ACTIONS(2462),
    [anon_sym_unsigned] = ACTIONS(2462),
    [anon_sym_long] = ACTIONS(2462),
    [anon_sym_short] = ACTIONS(2462),
    [anon_sym_LBRACK] = ACTIONS(2462),
    [anon_sym_static] = ACTIONS(2462),
    [anon_sym_register] = ACTIONS(2462),
    [anon_sym_inline] = ACTIONS(2462),
    [anon_sym___inline] = ACTIONS(2462),
    [anon_sym___inline__] = ACTIONS(2462),
    [anon_sym___forceinline] = ACTIONS(2462),
    [anon_sym_thread_local] = ACTIONS(2462),
    [anon_sym___thread] = ACTIONS(2462),
    [anon_sym_const] = ACTIONS(2462),
    [anon_sym_constexpr] = ACTIONS(2462),
    [anon_sym_volatile] = ACTIONS(2462),
    [anon_sym_restrict] = ACTIONS(2462),
    [anon_sym___restrict__] = ACTIONS(2462),
    [anon_sym__Atomic] = ACTIONS(2462),
    [anon_sym__Noreturn] = ACTIONS(2462),
    [anon_sym_noreturn] = ACTIONS(2462),
    [anon_sym_mutable] = ACTIONS(2462),
    [anon_sym_constinit] = ACTIONS(2462),
    [anon_sym_consteval] = ACTIONS(2462),
    [anon_sym_alignas] = ACTIONS(2462),
    [anon_sym__Alignas] = ACTIONS(2462),
    [sym_primitive_type] = ACTIONS(2462),
    [anon_sym_enum] = ACTIONS(2462),
    [anon_sym_class] = ACTIONS(2462),
    [anon_sym_struct] = ACTIONS(2462),
    [anon_sym_union] = ACTIONS(2462),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2462),
    [anon_sym_decltype] = ACTIONS(2462),
    [sym_virtual] = ACTIONS(2462),
    [anon_sym_explicit] = ACTIONS(2462),
    [anon_sym_typename] = ACTIONS(2462),
    [anon_sym_template] = ACTIONS(2462),
    [anon_sym_operator] = ACTIONS(2462),
    [anon_sym_friend] = ACTIONS(2462),
    [anon_sym_public] = ACTIONS(2462),
    [anon_sym_private] = ACTIONS(2462),
    [anon_sym_protected] = ACTIONS(2462),
    [anon_sym_using] = ACTIONS(2462),
    [anon_sym_static_assert] = ACTIONS(2462),
    [anon_sym_precise] = ACTIONS(2462),
    [anon_sym_shared] = ACTIONS(2462),
    [anon_sym_groupshared] = ACTIONS(2462),
    [anon_sym_uniform] = ACTIONS(2462),
    [anon_sym_row_major] = ACTIONS(2462),
    [anon_sym_column_major] = ACTIONS(2462),
    [anon_sym_globallycoherent] = ACTIONS(2462),
    [anon_sym_centroid] = ACTIONS(2462),
    [anon_sym_noperspective] = ACTIONS(2462),
    [anon_sym_nointerpolation] = ACTIONS(2462),
    [anon_sym_sample] = ACTIONS(2462),
    [anon_sym_linear] = ACTIONS(2462),
    [anon_sym_snorm] = ACTIONS(2462),
    [anon_sym_unorm] = ACTIONS(2462),
    [anon_sym_point] = ACTIONS(2462),
    [anon_sym_line] = ACTIONS(2462),
    [anon_sym_triangleadj] = ACTIONS(2462),
    [anon_sym_lineadj] = ACTIONS(2462),
    [anon_sym_triangle] = ACTIONS(2462),
  },
  [1998] = {
    [sym_identifier] = ACTIONS(5061),
    [aux_sym_preproc_def_token1] = ACTIONS(5061),
    [aux_sym_preproc_if_token1] = ACTIONS(5061),
    [aux_sym_preproc_if_token2] = ACTIONS(5061),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5061),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5061),
    [sym_preproc_directive] = ACTIONS(5061),
    [anon_sym_LPAREN2] = ACTIONS(5063),
    [anon_sym_TILDE] = ACTIONS(5063),
    [anon_sym_STAR] = ACTIONS(5063),
    [anon_sym_AMP_AMP] = ACTIONS(5063),
    [anon_sym_AMP] = ACTIONS(5061),
    [anon_sym___extension__] = ACTIONS(5061),
    [anon_sym_typedef] = ACTIONS(5061),
    [anon_sym_in] = ACTIONS(5061),
    [anon_sym_out] = ACTIONS(5061),
    [anon_sym_inout] = ACTIONS(5061),
    [anon_sym_extern] = ACTIONS(5061),
    [anon_sym___attribute__] = ACTIONS(5061),
    [anon_sym_COLON_COLON] = ACTIONS(5063),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5063),
    [anon_sym___declspec] = ACTIONS(5061),
    [anon_sym___based] = ACTIONS(5061),
    [anon_sym_signed] = ACTIONS(5061),
    [anon_sym_unsigned] = ACTIONS(5061),
    [anon_sym_long] = ACTIONS(5061),
    [anon_sym_short] = ACTIONS(5061),
    [anon_sym_LBRACK] = ACTIONS(5061),
    [anon_sym_static] = ACTIONS(5061),
    [anon_sym_register] = ACTIONS(5061),
    [anon_sym_inline] = ACTIONS(5061),
    [anon_sym___inline] = ACTIONS(5061),
    [anon_sym___inline__] = ACTIONS(5061),
    [anon_sym___forceinline] = ACTIONS(5061),
    [anon_sym_thread_local] = ACTIONS(5061),
    [anon_sym___thread] = ACTIONS(5061),
    [anon_sym_const] = ACTIONS(5061),
    [anon_sym_constexpr] = ACTIONS(5061),
    [anon_sym_volatile] = ACTIONS(5061),
    [anon_sym_restrict] = ACTIONS(5061),
    [anon_sym___restrict__] = ACTIONS(5061),
    [anon_sym__Atomic] = ACTIONS(5061),
    [anon_sym__Noreturn] = ACTIONS(5061),
    [anon_sym_noreturn] = ACTIONS(5061),
    [anon_sym_mutable] = ACTIONS(5061),
    [anon_sym_constinit] = ACTIONS(5061),
    [anon_sym_consteval] = ACTIONS(5061),
    [anon_sym_alignas] = ACTIONS(5061),
    [anon_sym__Alignas] = ACTIONS(5061),
    [sym_primitive_type] = ACTIONS(5061),
    [anon_sym_enum] = ACTIONS(5061),
    [anon_sym_class] = ACTIONS(5061),
    [anon_sym_struct] = ACTIONS(5061),
    [anon_sym_union] = ACTIONS(5061),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5061),
    [anon_sym_decltype] = ACTIONS(5061),
    [sym_virtual] = ACTIONS(5061),
    [anon_sym_explicit] = ACTIONS(5061),
    [anon_sym_typename] = ACTIONS(5061),
    [anon_sym_template] = ACTIONS(5061),
    [anon_sym_operator] = ACTIONS(5061),
    [anon_sym_friend] = ACTIONS(5061),
    [anon_sym_public] = ACTIONS(5061),
    [anon_sym_private] = ACTIONS(5061),
    [anon_sym_protected] = ACTIONS(5061),
    [anon_sym_using] = ACTIONS(5061),
    [anon_sym_static_assert] = ACTIONS(5061),
    [anon_sym_precise] = ACTIONS(5061),
    [anon_sym_shared] = ACTIONS(5061),
    [anon_sym_groupshared] = ACTIONS(5061),
    [anon_sym_uniform] = ACTIONS(5061),
    [anon_sym_row_major] = ACTIONS(5061),
    [anon_sym_column_major] = ACTIONS(5061),
    [anon_sym_globallycoherent] = ACTIONS(5061),
    [anon_sym_centroid] = ACTIONS(5061),
    [anon_sym_noperspective] = ACTIONS(5061),
    [anon_sym_nointerpolation] = ACTIONS(5061),
    [anon_sym_sample] = ACTIONS(5061),
    [anon_sym_linear] = ACTIONS(5061),
    [anon_sym_snorm] = ACTIONS(5061),
    [anon_sym_unorm] = ACTIONS(5061),
    [anon_sym_point] = ACTIONS(5061),
    [anon_sym_line] = ACTIONS(5061),
    [anon_sym_triangleadj] = ACTIONS(5061),
    [anon_sym_lineadj] = ACTIONS(5061),
    [anon_sym_triangle] = ACTIONS(5061),
  },
  [1999] = {
    [sym_identifier] = ACTIONS(2462),
    [aux_sym_preproc_def_token1] = ACTIONS(2462),
    [aux_sym_preproc_if_token1] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2462),
    [sym_preproc_directive] = ACTIONS(2462),
    [anon_sym_LPAREN2] = ACTIONS(2464),
    [anon_sym_TILDE] = ACTIONS(2464),
    [anon_sym_STAR] = ACTIONS(2464),
    [anon_sym_AMP_AMP] = ACTIONS(2464),
    [anon_sym_AMP] = ACTIONS(2462),
    [anon_sym___extension__] = ACTIONS(2462),
    [anon_sym_typedef] = ACTIONS(2462),
    [anon_sym_in] = ACTIONS(2462),
    [anon_sym_out] = ACTIONS(2462),
    [anon_sym_inout] = ACTIONS(2462),
    [anon_sym_extern] = ACTIONS(2462),
    [anon_sym___attribute__] = ACTIONS(2462),
    [anon_sym_COLON_COLON] = ACTIONS(2464),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2464),
    [anon_sym___declspec] = ACTIONS(2462),
    [anon_sym___based] = ACTIONS(2462),
    [anon_sym_RBRACE] = ACTIONS(2464),
    [anon_sym_signed] = ACTIONS(2462),
    [anon_sym_unsigned] = ACTIONS(2462),
    [anon_sym_long] = ACTIONS(2462),
    [anon_sym_short] = ACTIONS(2462),
    [anon_sym_LBRACK] = ACTIONS(2462),
    [anon_sym_static] = ACTIONS(2462),
    [anon_sym_register] = ACTIONS(2462),
    [anon_sym_inline] = ACTIONS(2462),
    [anon_sym___inline] = ACTIONS(2462),
    [anon_sym___inline__] = ACTIONS(2462),
    [anon_sym___forceinline] = ACTIONS(2462),
    [anon_sym_thread_local] = ACTIONS(2462),
    [anon_sym___thread] = ACTIONS(2462),
    [anon_sym_const] = ACTIONS(2462),
    [anon_sym_constexpr] = ACTIONS(2462),
    [anon_sym_volatile] = ACTIONS(2462),
    [anon_sym_restrict] = ACTIONS(2462),
    [anon_sym___restrict__] = ACTIONS(2462),
    [anon_sym__Atomic] = ACTIONS(2462),
    [anon_sym__Noreturn] = ACTIONS(2462),
    [anon_sym_noreturn] = ACTIONS(2462),
    [anon_sym_mutable] = ACTIONS(2462),
    [anon_sym_constinit] = ACTIONS(2462),
    [anon_sym_consteval] = ACTIONS(2462),
    [anon_sym_alignas] = ACTIONS(2462),
    [anon_sym__Alignas] = ACTIONS(2462),
    [sym_primitive_type] = ACTIONS(2462),
    [anon_sym_enum] = ACTIONS(2462),
    [anon_sym_class] = ACTIONS(2462),
    [anon_sym_struct] = ACTIONS(2462),
    [anon_sym_union] = ACTIONS(2462),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2462),
    [anon_sym_decltype] = ACTIONS(2462),
    [sym_virtual] = ACTIONS(2462),
    [anon_sym_explicit] = ACTIONS(2462),
    [anon_sym_typename] = ACTIONS(2462),
    [anon_sym_template] = ACTIONS(2462),
    [anon_sym_operator] = ACTIONS(2462),
    [anon_sym_friend] = ACTIONS(2462),
    [anon_sym_public] = ACTIONS(2462),
    [anon_sym_private] = ACTIONS(2462),
    [anon_sym_protected] = ACTIONS(2462),
    [anon_sym_using] = ACTIONS(2462),
    [anon_sym_static_assert] = ACTIONS(2462),
    [anon_sym_precise] = ACTIONS(2462),
    [anon_sym_shared] = ACTIONS(2462),
    [anon_sym_groupshared] = ACTIONS(2462),
    [anon_sym_uniform] = ACTIONS(2462),
    [anon_sym_row_major] = ACTIONS(2462),
    [anon_sym_column_major] = ACTIONS(2462),
    [anon_sym_globallycoherent] = ACTIONS(2462),
    [anon_sym_centroid] = ACTIONS(2462),
    [anon_sym_noperspective] = ACTIONS(2462),
    [anon_sym_nointerpolation] = ACTIONS(2462),
    [anon_sym_sample] = ACTIONS(2462),
    [anon_sym_linear] = ACTIONS(2462),
    [anon_sym_snorm] = ACTIONS(2462),
    [anon_sym_unorm] = ACTIONS(2462),
    [anon_sym_point] = ACTIONS(2462),
    [anon_sym_line] = ACTIONS(2462),
    [anon_sym_triangleadj] = ACTIONS(2462),
    [anon_sym_lineadj] = ACTIONS(2462),
    [anon_sym_triangle] = ACTIONS(2462),
  },
  [2000] = {
    [sym_identifier] = ACTIONS(5065),
    [aux_sym_preproc_def_token1] = ACTIONS(5065),
    [aux_sym_preproc_if_token1] = ACTIONS(5065),
    [aux_sym_preproc_if_token2] = ACTIONS(5065),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5065),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5065),
    [sym_preproc_directive] = ACTIONS(5065),
    [anon_sym_LPAREN2] = ACTIONS(5067),
    [anon_sym_TILDE] = ACTIONS(5067),
    [anon_sym_STAR] = ACTIONS(5067),
    [anon_sym_AMP_AMP] = ACTIONS(5067),
    [anon_sym_AMP] = ACTIONS(5065),
    [anon_sym___extension__] = ACTIONS(5065),
    [anon_sym_typedef] = ACTIONS(5065),
    [anon_sym_in] = ACTIONS(5065),
    [anon_sym_out] = ACTIONS(5065),
    [anon_sym_inout] = ACTIONS(5065),
    [anon_sym_extern] = ACTIONS(5065),
    [anon_sym___attribute__] = ACTIONS(5065),
    [anon_sym_COLON_COLON] = ACTIONS(5067),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5067),
    [anon_sym___declspec] = ACTIONS(5065),
    [anon_sym___based] = ACTIONS(5065),
    [anon_sym_signed] = ACTIONS(5065),
    [anon_sym_unsigned] = ACTIONS(5065),
    [anon_sym_long] = ACTIONS(5065),
    [anon_sym_short] = ACTIONS(5065),
    [anon_sym_LBRACK] = ACTIONS(5065),
    [anon_sym_static] = ACTIONS(5065),
    [anon_sym_register] = ACTIONS(5065),
    [anon_sym_inline] = ACTIONS(5065),
    [anon_sym___inline] = ACTIONS(5065),
    [anon_sym___inline__] = ACTIONS(5065),
    [anon_sym___forceinline] = ACTIONS(5065),
    [anon_sym_thread_local] = ACTIONS(5065),
    [anon_sym___thread] = ACTIONS(5065),
    [anon_sym_const] = ACTIONS(5065),
    [anon_sym_constexpr] = ACTIONS(5065),
    [anon_sym_volatile] = ACTIONS(5065),
    [anon_sym_restrict] = ACTIONS(5065),
    [anon_sym___restrict__] = ACTIONS(5065),
    [anon_sym__Atomic] = ACTIONS(5065),
    [anon_sym__Noreturn] = ACTIONS(5065),
    [anon_sym_noreturn] = ACTIONS(5065),
    [anon_sym_mutable] = ACTIONS(5065),
    [anon_sym_constinit] = ACTIONS(5065),
    [anon_sym_consteval] = ACTIONS(5065),
    [anon_sym_alignas] = ACTIONS(5065),
    [anon_sym__Alignas] = ACTIONS(5065),
    [sym_primitive_type] = ACTIONS(5065),
    [anon_sym_enum] = ACTIONS(5065),
    [anon_sym_class] = ACTIONS(5065),
    [anon_sym_struct] = ACTIONS(5065),
    [anon_sym_union] = ACTIONS(5065),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5065),
    [anon_sym_decltype] = ACTIONS(5065),
    [sym_virtual] = ACTIONS(5065),
    [anon_sym_explicit] = ACTIONS(5065),
    [anon_sym_typename] = ACTIONS(5065),
    [anon_sym_template] = ACTIONS(5065),
    [anon_sym_operator] = ACTIONS(5065),
    [anon_sym_friend] = ACTIONS(5065),
    [anon_sym_public] = ACTIONS(5065),
    [anon_sym_private] = ACTIONS(5065),
    [anon_sym_protected] = ACTIONS(5065),
    [anon_sym_using] = ACTIONS(5065),
    [anon_sym_static_assert] = ACTIONS(5065),
    [anon_sym_precise] = ACTIONS(5065),
    [anon_sym_shared] = ACTIONS(5065),
    [anon_sym_groupshared] = ACTIONS(5065),
    [anon_sym_uniform] = ACTIONS(5065),
    [anon_sym_row_major] = ACTIONS(5065),
    [anon_sym_column_major] = ACTIONS(5065),
    [anon_sym_globallycoherent] = ACTIONS(5065),
    [anon_sym_centroid] = ACTIONS(5065),
    [anon_sym_noperspective] = ACTIONS(5065),
    [anon_sym_nointerpolation] = ACTIONS(5065),
    [anon_sym_sample] = ACTIONS(5065),
    [anon_sym_linear] = ACTIONS(5065),
    [anon_sym_snorm] = ACTIONS(5065),
    [anon_sym_unorm] = ACTIONS(5065),
    [anon_sym_point] = ACTIONS(5065),
    [anon_sym_line] = ACTIONS(5065),
    [anon_sym_triangleadj] = ACTIONS(5065),
    [anon_sym_lineadj] = ACTIONS(5065),
    [anon_sym_triangle] = ACTIONS(5065),
  },
  [2001] = {
    [sym_identifier] = ACTIONS(5069),
    [aux_sym_preproc_def_token1] = ACTIONS(5069),
    [aux_sym_preproc_if_token1] = ACTIONS(5069),
    [aux_sym_preproc_if_token2] = ACTIONS(5069),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5069),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5069),
    [sym_preproc_directive] = ACTIONS(5069),
    [anon_sym_LPAREN2] = ACTIONS(5071),
    [anon_sym_TILDE] = ACTIONS(5071),
    [anon_sym_STAR] = ACTIONS(5071),
    [anon_sym_AMP_AMP] = ACTIONS(5071),
    [anon_sym_AMP] = ACTIONS(5069),
    [anon_sym___extension__] = ACTIONS(5069),
    [anon_sym_typedef] = ACTIONS(5069),
    [anon_sym_in] = ACTIONS(5069),
    [anon_sym_out] = ACTIONS(5069),
    [anon_sym_inout] = ACTIONS(5069),
    [anon_sym_extern] = ACTIONS(5069),
    [anon_sym___attribute__] = ACTIONS(5069),
    [anon_sym_COLON_COLON] = ACTIONS(5071),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5071),
    [anon_sym___declspec] = ACTIONS(5069),
    [anon_sym___based] = ACTIONS(5069),
    [anon_sym_signed] = ACTIONS(5069),
    [anon_sym_unsigned] = ACTIONS(5069),
    [anon_sym_long] = ACTIONS(5069),
    [anon_sym_short] = ACTIONS(5069),
    [anon_sym_LBRACK] = ACTIONS(5069),
    [anon_sym_static] = ACTIONS(5069),
    [anon_sym_register] = ACTIONS(5069),
    [anon_sym_inline] = ACTIONS(5069),
    [anon_sym___inline] = ACTIONS(5069),
    [anon_sym___inline__] = ACTIONS(5069),
    [anon_sym___forceinline] = ACTIONS(5069),
    [anon_sym_thread_local] = ACTIONS(5069),
    [anon_sym___thread] = ACTIONS(5069),
    [anon_sym_const] = ACTIONS(5069),
    [anon_sym_constexpr] = ACTIONS(5069),
    [anon_sym_volatile] = ACTIONS(5069),
    [anon_sym_restrict] = ACTIONS(5069),
    [anon_sym___restrict__] = ACTIONS(5069),
    [anon_sym__Atomic] = ACTIONS(5069),
    [anon_sym__Noreturn] = ACTIONS(5069),
    [anon_sym_noreturn] = ACTIONS(5069),
    [anon_sym_mutable] = ACTIONS(5069),
    [anon_sym_constinit] = ACTIONS(5069),
    [anon_sym_consteval] = ACTIONS(5069),
    [anon_sym_alignas] = ACTIONS(5069),
    [anon_sym__Alignas] = ACTIONS(5069),
    [sym_primitive_type] = ACTIONS(5069),
    [anon_sym_enum] = ACTIONS(5069),
    [anon_sym_class] = ACTIONS(5069),
    [anon_sym_struct] = ACTIONS(5069),
    [anon_sym_union] = ACTIONS(5069),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5069),
    [anon_sym_decltype] = ACTIONS(5069),
    [sym_virtual] = ACTIONS(5069),
    [anon_sym_explicit] = ACTIONS(5069),
    [anon_sym_typename] = ACTIONS(5069),
    [anon_sym_template] = ACTIONS(5069),
    [anon_sym_operator] = ACTIONS(5069),
    [anon_sym_friend] = ACTIONS(5069),
    [anon_sym_public] = ACTIONS(5069),
    [anon_sym_private] = ACTIONS(5069),
    [anon_sym_protected] = ACTIONS(5069),
    [anon_sym_using] = ACTIONS(5069),
    [anon_sym_static_assert] = ACTIONS(5069),
    [anon_sym_precise] = ACTIONS(5069),
    [anon_sym_shared] = ACTIONS(5069),
    [anon_sym_groupshared] = ACTIONS(5069),
    [anon_sym_uniform] = ACTIONS(5069),
    [anon_sym_row_major] = ACTIONS(5069),
    [anon_sym_column_major] = ACTIONS(5069),
    [anon_sym_globallycoherent] = ACTIONS(5069),
    [anon_sym_centroid] = ACTIONS(5069),
    [anon_sym_noperspective] = ACTIONS(5069),
    [anon_sym_nointerpolation] = ACTIONS(5069),
    [anon_sym_sample] = ACTIONS(5069),
    [anon_sym_linear] = ACTIONS(5069),
    [anon_sym_snorm] = ACTIONS(5069),
    [anon_sym_unorm] = ACTIONS(5069),
    [anon_sym_point] = ACTIONS(5069),
    [anon_sym_line] = ACTIONS(5069),
    [anon_sym_triangleadj] = ACTIONS(5069),
    [anon_sym_lineadj] = ACTIONS(5069),
    [anon_sym_triangle] = ACTIONS(5069),
  },
  [2002] = {
    [sym_identifier] = ACTIONS(2494),
    [aux_sym_preproc_def_token1] = ACTIONS(2494),
    [aux_sym_preproc_if_token1] = ACTIONS(2494),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2494),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2494),
    [sym_preproc_directive] = ACTIONS(2494),
    [anon_sym_LPAREN2] = ACTIONS(2496),
    [anon_sym_TILDE] = ACTIONS(2496),
    [anon_sym_STAR] = ACTIONS(2496),
    [anon_sym_AMP_AMP] = ACTIONS(2496),
    [anon_sym_AMP] = ACTIONS(2494),
    [anon_sym___extension__] = ACTIONS(2494),
    [anon_sym_typedef] = ACTIONS(2494),
    [anon_sym_in] = ACTIONS(2494),
    [anon_sym_out] = ACTIONS(2494),
    [anon_sym_inout] = ACTIONS(2494),
    [anon_sym_extern] = ACTIONS(2494),
    [anon_sym___attribute__] = ACTIONS(2494),
    [anon_sym_COLON_COLON] = ACTIONS(2496),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2496),
    [anon_sym___declspec] = ACTIONS(2494),
    [anon_sym___based] = ACTIONS(2494),
    [anon_sym_RBRACE] = ACTIONS(2496),
    [anon_sym_signed] = ACTIONS(2494),
    [anon_sym_unsigned] = ACTIONS(2494),
    [anon_sym_long] = ACTIONS(2494),
    [anon_sym_short] = ACTIONS(2494),
    [anon_sym_LBRACK] = ACTIONS(2494),
    [anon_sym_static] = ACTIONS(2494),
    [anon_sym_register] = ACTIONS(2494),
    [anon_sym_inline] = ACTIONS(2494),
    [anon_sym___inline] = ACTIONS(2494),
    [anon_sym___inline__] = ACTIONS(2494),
    [anon_sym___forceinline] = ACTIONS(2494),
    [anon_sym_thread_local] = ACTIONS(2494),
    [anon_sym___thread] = ACTIONS(2494),
    [anon_sym_const] = ACTIONS(2494),
    [anon_sym_constexpr] = ACTIONS(2494),
    [anon_sym_volatile] = ACTIONS(2494),
    [anon_sym_restrict] = ACTIONS(2494),
    [anon_sym___restrict__] = ACTIONS(2494),
    [anon_sym__Atomic] = ACTIONS(2494),
    [anon_sym__Noreturn] = ACTIONS(2494),
    [anon_sym_noreturn] = ACTIONS(2494),
    [anon_sym_mutable] = ACTIONS(2494),
    [anon_sym_constinit] = ACTIONS(2494),
    [anon_sym_consteval] = ACTIONS(2494),
    [anon_sym_alignas] = ACTIONS(2494),
    [anon_sym__Alignas] = ACTIONS(2494),
    [sym_primitive_type] = ACTIONS(2494),
    [anon_sym_enum] = ACTIONS(2494),
    [anon_sym_class] = ACTIONS(2494),
    [anon_sym_struct] = ACTIONS(2494),
    [anon_sym_union] = ACTIONS(2494),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2494),
    [anon_sym_decltype] = ACTIONS(2494),
    [sym_virtual] = ACTIONS(2494),
    [anon_sym_explicit] = ACTIONS(2494),
    [anon_sym_typename] = ACTIONS(2494),
    [anon_sym_template] = ACTIONS(2494),
    [anon_sym_operator] = ACTIONS(2494),
    [anon_sym_friend] = ACTIONS(2494),
    [anon_sym_public] = ACTIONS(2494),
    [anon_sym_private] = ACTIONS(2494),
    [anon_sym_protected] = ACTIONS(2494),
    [anon_sym_using] = ACTIONS(2494),
    [anon_sym_static_assert] = ACTIONS(2494),
    [anon_sym_precise] = ACTIONS(2494),
    [anon_sym_shared] = ACTIONS(2494),
    [anon_sym_groupshared] = ACTIONS(2494),
    [anon_sym_uniform] = ACTIONS(2494),
    [anon_sym_row_major] = ACTIONS(2494),
    [anon_sym_column_major] = ACTIONS(2494),
    [anon_sym_globallycoherent] = ACTIONS(2494),
    [anon_sym_centroid] = ACTIONS(2494),
    [anon_sym_noperspective] = ACTIONS(2494),
    [anon_sym_nointerpolation] = ACTIONS(2494),
    [anon_sym_sample] = ACTIONS(2494),
    [anon_sym_linear] = ACTIONS(2494),
    [anon_sym_snorm] = ACTIONS(2494),
    [anon_sym_unorm] = ACTIONS(2494),
    [anon_sym_point] = ACTIONS(2494),
    [anon_sym_line] = ACTIONS(2494),
    [anon_sym_triangleadj] = ACTIONS(2494),
    [anon_sym_lineadj] = ACTIONS(2494),
    [anon_sym_triangle] = ACTIONS(2494),
  },
  [2003] = {
    [sym_identifier] = ACTIONS(5073),
    [aux_sym_preproc_def_token1] = ACTIONS(5073),
    [aux_sym_preproc_if_token1] = ACTIONS(5073),
    [aux_sym_preproc_if_token2] = ACTIONS(5073),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5073),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5073),
    [sym_preproc_directive] = ACTIONS(5073),
    [anon_sym_LPAREN2] = ACTIONS(5075),
    [anon_sym_TILDE] = ACTIONS(5075),
    [anon_sym_STAR] = ACTIONS(5075),
    [anon_sym_AMP_AMP] = ACTIONS(5075),
    [anon_sym_AMP] = ACTIONS(5073),
    [anon_sym___extension__] = ACTIONS(5073),
    [anon_sym_typedef] = ACTIONS(5073),
    [anon_sym_in] = ACTIONS(5073),
    [anon_sym_out] = ACTIONS(5073),
    [anon_sym_inout] = ACTIONS(5073),
    [anon_sym_extern] = ACTIONS(5073),
    [anon_sym___attribute__] = ACTIONS(5073),
    [anon_sym_COLON_COLON] = ACTIONS(5075),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5075),
    [anon_sym___declspec] = ACTIONS(5073),
    [anon_sym___based] = ACTIONS(5073),
    [anon_sym_signed] = ACTIONS(5073),
    [anon_sym_unsigned] = ACTIONS(5073),
    [anon_sym_long] = ACTIONS(5073),
    [anon_sym_short] = ACTIONS(5073),
    [anon_sym_LBRACK] = ACTIONS(5073),
    [anon_sym_static] = ACTIONS(5073),
    [anon_sym_register] = ACTIONS(5073),
    [anon_sym_inline] = ACTIONS(5073),
    [anon_sym___inline] = ACTIONS(5073),
    [anon_sym___inline__] = ACTIONS(5073),
    [anon_sym___forceinline] = ACTIONS(5073),
    [anon_sym_thread_local] = ACTIONS(5073),
    [anon_sym___thread] = ACTIONS(5073),
    [anon_sym_const] = ACTIONS(5073),
    [anon_sym_constexpr] = ACTIONS(5073),
    [anon_sym_volatile] = ACTIONS(5073),
    [anon_sym_restrict] = ACTIONS(5073),
    [anon_sym___restrict__] = ACTIONS(5073),
    [anon_sym__Atomic] = ACTIONS(5073),
    [anon_sym__Noreturn] = ACTIONS(5073),
    [anon_sym_noreturn] = ACTIONS(5073),
    [anon_sym_mutable] = ACTIONS(5073),
    [anon_sym_constinit] = ACTIONS(5073),
    [anon_sym_consteval] = ACTIONS(5073),
    [anon_sym_alignas] = ACTIONS(5073),
    [anon_sym__Alignas] = ACTIONS(5073),
    [sym_primitive_type] = ACTIONS(5073),
    [anon_sym_enum] = ACTIONS(5073),
    [anon_sym_class] = ACTIONS(5073),
    [anon_sym_struct] = ACTIONS(5073),
    [anon_sym_union] = ACTIONS(5073),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5073),
    [anon_sym_decltype] = ACTIONS(5073),
    [sym_virtual] = ACTIONS(5073),
    [anon_sym_explicit] = ACTIONS(5073),
    [anon_sym_typename] = ACTIONS(5073),
    [anon_sym_template] = ACTIONS(5073),
    [anon_sym_operator] = ACTIONS(5073),
    [anon_sym_friend] = ACTIONS(5073),
    [anon_sym_public] = ACTIONS(5073),
    [anon_sym_private] = ACTIONS(5073),
    [anon_sym_protected] = ACTIONS(5073),
    [anon_sym_using] = ACTIONS(5073),
    [anon_sym_static_assert] = ACTIONS(5073),
    [anon_sym_precise] = ACTIONS(5073),
    [anon_sym_shared] = ACTIONS(5073),
    [anon_sym_groupshared] = ACTIONS(5073),
    [anon_sym_uniform] = ACTIONS(5073),
    [anon_sym_row_major] = ACTIONS(5073),
    [anon_sym_column_major] = ACTIONS(5073),
    [anon_sym_globallycoherent] = ACTIONS(5073),
    [anon_sym_centroid] = ACTIONS(5073),
    [anon_sym_noperspective] = ACTIONS(5073),
    [anon_sym_nointerpolation] = ACTIONS(5073),
    [anon_sym_sample] = ACTIONS(5073),
    [anon_sym_linear] = ACTIONS(5073),
    [anon_sym_snorm] = ACTIONS(5073),
    [anon_sym_unorm] = ACTIONS(5073),
    [anon_sym_point] = ACTIONS(5073),
    [anon_sym_line] = ACTIONS(5073),
    [anon_sym_triangleadj] = ACTIONS(5073),
    [anon_sym_lineadj] = ACTIONS(5073),
    [anon_sym_triangle] = ACTIONS(5073),
  },
  [2004] = {
    [sym_identifier] = ACTIONS(5053),
    [aux_sym_preproc_def_token1] = ACTIONS(5053),
    [aux_sym_preproc_if_token1] = ACTIONS(5053),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5053),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5053),
    [sym_preproc_directive] = ACTIONS(5053),
    [anon_sym_LPAREN2] = ACTIONS(5055),
    [anon_sym_TILDE] = ACTIONS(5055),
    [anon_sym_STAR] = ACTIONS(5055),
    [anon_sym_AMP_AMP] = ACTIONS(5055),
    [anon_sym_AMP] = ACTIONS(5053),
    [anon_sym___extension__] = ACTIONS(5053),
    [anon_sym_typedef] = ACTIONS(5053),
    [anon_sym_in] = ACTIONS(5053),
    [anon_sym_out] = ACTIONS(5053),
    [anon_sym_inout] = ACTIONS(5053),
    [anon_sym_extern] = ACTIONS(5053),
    [anon_sym___attribute__] = ACTIONS(5053),
    [anon_sym_COLON_COLON] = ACTIONS(5055),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5055),
    [anon_sym___declspec] = ACTIONS(5053),
    [anon_sym___based] = ACTIONS(5053),
    [anon_sym_RBRACE] = ACTIONS(5055),
    [anon_sym_signed] = ACTIONS(5053),
    [anon_sym_unsigned] = ACTIONS(5053),
    [anon_sym_long] = ACTIONS(5053),
    [anon_sym_short] = ACTIONS(5053),
    [anon_sym_LBRACK] = ACTIONS(5053),
    [anon_sym_static] = ACTIONS(5053),
    [anon_sym_register] = ACTIONS(5053),
    [anon_sym_inline] = ACTIONS(5053),
    [anon_sym___inline] = ACTIONS(5053),
    [anon_sym___inline__] = ACTIONS(5053),
    [anon_sym___forceinline] = ACTIONS(5053),
    [anon_sym_thread_local] = ACTIONS(5053),
    [anon_sym___thread] = ACTIONS(5053),
    [anon_sym_const] = ACTIONS(5053),
    [anon_sym_constexpr] = ACTIONS(5053),
    [anon_sym_volatile] = ACTIONS(5053),
    [anon_sym_restrict] = ACTIONS(5053),
    [anon_sym___restrict__] = ACTIONS(5053),
    [anon_sym__Atomic] = ACTIONS(5053),
    [anon_sym__Noreturn] = ACTIONS(5053),
    [anon_sym_noreturn] = ACTIONS(5053),
    [anon_sym_mutable] = ACTIONS(5053),
    [anon_sym_constinit] = ACTIONS(5053),
    [anon_sym_consteval] = ACTIONS(5053),
    [anon_sym_alignas] = ACTIONS(5053),
    [anon_sym__Alignas] = ACTIONS(5053),
    [sym_primitive_type] = ACTIONS(5053),
    [anon_sym_enum] = ACTIONS(5053),
    [anon_sym_class] = ACTIONS(5053),
    [anon_sym_struct] = ACTIONS(5053),
    [anon_sym_union] = ACTIONS(5053),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5053),
    [anon_sym_decltype] = ACTIONS(5053),
    [sym_virtual] = ACTIONS(5053),
    [anon_sym_explicit] = ACTIONS(5053),
    [anon_sym_typename] = ACTIONS(5053),
    [anon_sym_template] = ACTIONS(5053),
    [anon_sym_operator] = ACTIONS(5053),
    [anon_sym_friend] = ACTIONS(5053),
    [anon_sym_public] = ACTIONS(5053),
    [anon_sym_private] = ACTIONS(5053),
    [anon_sym_protected] = ACTIONS(5053),
    [anon_sym_using] = ACTIONS(5053),
    [anon_sym_static_assert] = ACTIONS(5053),
    [anon_sym_precise] = ACTIONS(5053),
    [anon_sym_shared] = ACTIONS(5053),
    [anon_sym_groupshared] = ACTIONS(5053),
    [anon_sym_uniform] = ACTIONS(5053),
    [anon_sym_row_major] = ACTIONS(5053),
    [anon_sym_column_major] = ACTIONS(5053),
    [anon_sym_globallycoherent] = ACTIONS(5053),
    [anon_sym_centroid] = ACTIONS(5053),
    [anon_sym_noperspective] = ACTIONS(5053),
    [anon_sym_nointerpolation] = ACTIONS(5053),
    [anon_sym_sample] = ACTIONS(5053),
    [anon_sym_linear] = ACTIONS(5053),
    [anon_sym_snorm] = ACTIONS(5053),
    [anon_sym_unorm] = ACTIONS(5053),
    [anon_sym_point] = ACTIONS(5053),
    [anon_sym_line] = ACTIONS(5053),
    [anon_sym_triangleadj] = ACTIONS(5053),
    [anon_sym_lineadj] = ACTIONS(5053),
    [anon_sym_triangle] = ACTIONS(5053),
  },
  [2005] = {
    [sym_identifier] = ACTIONS(5073),
    [aux_sym_preproc_def_token1] = ACTIONS(5073),
    [aux_sym_preproc_if_token1] = ACTIONS(5073),
    [aux_sym_preproc_if_token2] = ACTIONS(5073),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5073),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5073),
    [sym_preproc_directive] = ACTIONS(5073),
    [anon_sym_LPAREN2] = ACTIONS(5075),
    [anon_sym_TILDE] = ACTIONS(5075),
    [anon_sym_STAR] = ACTIONS(5075),
    [anon_sym_AMP_AMP] = ACTIONS(5075),
    [anon_sym_AMP] = ACTIONS(5073),
    [anon_sym___extension__] = ACTIONS(5073),
    [anon_sym_typedef] = ACTIONS(5073),
    [anon_sym_in] = ACTIONS(5073),
    [anon_sym_out] = ACTIONS(5073),
    [anon_sym_inout] = ACTIONS(5073),
    [anon_sym_extern] = ACTIONS(5073),
    [anon_sym___attribute__] = ACTIONS(5073),
    [anon_sym_COLON_COLON] = ACTIONS(5075),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5075),
    [anon_sym___declspec] = ACTIONS(5073),
    [anon_sym___based] = ACTIONS(5073),
    [anon_sym_signed] = ACTIONS(5073),
    [anon_sym_unsigned] = ACTIONS(5073),
    [anon_sym_long] = ACTIONS(5073),
    [anon_sym_short] = ACTIONS(5073),
    [anon_sym_LBRACK] = ACTIONS(5073),
    [anon_sym_static] = ACTIONS(5073),
    [anon_sym_register] = ACTIONS(5073),
    [anon_sym_inline] = ACTIONS(5073),
    [anon_sym___inline] = ACTIONS(5073),
    [anon_sym___inline__] = ACTIONS(5073),
    [anon_sym___forceinline] = ACTIONS(5073),
    [anon_sym_thread_local] = ACTIONS(5073),
    [anon_sym___thread] = ACTIONS(5073),
    [anon_sym_const] = ACTIONS(5073),
    [anon_sym_constexpr] = ACTIONS(5073),
    [anon_sym_volatile] = ACTIONS(5073),
    [anon_sym_restrict] = ACTIONS(5073),
    [anon_sym___restrict__] = ACTIONS(5073),
    [anon_sym__Atomic] = ACTIONS(5073),
    [anon_sym__Noreturn] = ACTIONS(5073),
    [anon_sym_noreturn] = ACTIONS(5073),
    [anon_sym_mutable] = ACTIONS(5073),
    [anon_sym_constinit] = ACTIONS(5073),
    [anon_sym_consteval] = ACTIONS(5073),
    [anon_sym_alignas] = ACTIONS(5073),
    [anon_sym__Alignas] = ACTIONS(5073),
    [sym_primitive_type] = ACTIONS(5073),
    [anon_sym_enum] = ACTIONS(5073),
    [anon_sym_class] = ACTIONS(5073),
    [anon_sym_struct] = ACTIONS(5073),
    [anon_sym_union] = ACTIONS(5073),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5073),
    [anon_sym_decltype] = ACTIONS(5073),
    [sym_virtual] = ACTIONS(5073),
    [anon_sym_explicit] = ACTIONS(5073),
    [anon_sym_typename] = ACTIONS(5073),
    [anon_sym_template] = ACTIONS(5073),
    [anon_sym_operator] = ACTIONS(5073),
    [anon_sym_friend] = ACTIONS(5073),
    [anon_sym_public] = ACTIONS(5073),
    [anon_sym_private] = ACTIONS(5073),
    [anon_sym_protected] = ACTIONS(5073),
    [anon_sym_using] = ACTIONS(5073),
    [anon_sym_static_assert] = ACTIONS(5073),
    [anon_sym_precise] = ACTIONS(5073),
    [anon_sym_shared] = ACTIONS(5073),
    [anon_sym_groupshared] = ACTIONS(5073),
    [anon_sym_uniform] = ACTIONS(5073),
    [anon_sym_row_major] = ACTIONS(5073),
    [anon_sym_column_major] = ACTIONS(5073),
    [anon_sym_globallycoherent] = ACTIONS(5073),
    [anon_sym_centroid] = ACTIONS(5073),
    [anon_sym_noperspective] = ACTIONS(5073),
    [anon_sym_nointerpolation] = ACTIONS(5073),
    [anon_sym_sample] = ACTIONS(5073),
    [anon_sym_linear] = ACTIONS(5073),
    [anon_sym_snorm] = ACTIONS(5073),
    [anon_sym_unorm] = ACTIONS(5073),
    [anon_sym_point] = ACTIONS(5073),
    [anon_sym_line] = ACTIONS(5073),
    [anon_sym_triangleadj] = ACTIONS(5073),
    [anon_sym_lineadj] = ACTIONS(5073),
    [anon_sym_triangle] = ACTIONS(5073),
  },
  [2006] = {
    [sym_identifier] = ACTIONS(5077),
    [aux_sym_preproc_def_token1] = ACTIONS(5077),
    [aux_sym_preproc_if_token1] = ACTIONS(5077),
    [aux_sym_preproc_if_token2] = ACTIONS(5077),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5077),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5077),
    [sym_preproc_directive] = ACTIONS(5077),
    [anon_sym_LPAREN2] = ACTIONS(5079),
    [anon_sym_TILDE] = ACTIONS(5079),
    [anon_sym_STAR] = ACTIONS(5079),
    [anon_sym_AMP_AMP] = ACTIONS(5079),
    [anon_sym_AMP] = ACTIONS(5077),
    [anon_sym___extension__] = ACTIONS(5077),
    [anon_sym_typedef] = ACTIONS(5077),
    [anon_sym_in] = ACTIONS(5077),
    [anon_sym_out] = ACTIONS(5077),
    [anon_sym_inout] = ACTIONS(5077),
    [anon_sym_extern] = ACTIONS(5077),
    [anon_sym___attribute__] = ACTIONS(5077),
    [anon_sym_COLON_COLON] = ACTIONS(5079),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5079),
    [anon_sym___declspec] = ACTIONS(5077),
    [anon_sym___based] = ACTIONS(5077),
    [anon_sym_signed] = ACTIONS(5077),
    [anon_sym_unsigned] = ACTIONS(5077),
    [anon_sym_long] = ACTIONS(5077),
    [anon_sym_short] = ACTIONS(5077),
    [anon_sym_LBRACK] = ACTIONS(5077),
    [anon_sym_static] = ACTIONS(5077),
    [anon_sym_register] = ACTIONS(5077),
    [anon_sym_inline] = ACTIONS(5077),
    [anon_sym___inline] = ACTIONS(5077),
    [anon_sym___inline__] = ACTIONS(5077),
    [anon_sym___forceinline] = ACTIONS(5077),
    [anon_sym_thread_local] = ACTIONS(5077),
    [anon_sym___thread] = ACTIONS(5077),
    [anon_sym_const] = ACTIONS(5077),
    [anon_sym_constexpr] = ACTIONS(5077),
    [anon_sym_volatile] = ACTIONS(5077),
    [anon_sym_restrict] = ACTIONS(5077),
    [anon_sym___restrict__] = ACTIONS(5077),
    [anon_sym__Atomic] = ACTIONS(5077),
    [anon_sym__Noreturn] = ACTIONS(5077),
    [anon_sym_noreturn] = ACTIONS(5077),
    [anon_sym_mutable] = ACTIONS(5077),
    [anon_sym_constinit] = ACTIONS(5077),
    [anon_sym_consteval] = ACTIONS(5077),
    [anon_sym_alignas] = ACTIONS(5077),
    [anon_sym__Alignas] = ACTIONS(5077),
    [sym_primitive_type] = ACTIONS(5077),
    [anon_sym_enum] = ACTIONS(5077),
    [anon_sym_class] = ACTIONS(5077),
    [anon_sym_struct] = ACTIONS(5077),
    [anon_sym_union] = ACTIONS(5077),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5077),
    [anon_sym_decltype] = ACTIONS(5077),
    [sym_virtual] = ACTIONS(5077),
    [anon_sym_explicit] = ACTIONS(5077),
    [anon_sym_typename] = ACTIONS(5077),
    [anon_sym_template] = ACTIONS(5077),
    [anon_sym_operator] = ACTIONS(5077),
    [anon_sym_friend] = ACTIONS(5077),
    [anon_sym_public] = ACTIONS(5077),
    [anon_sym_private] = ACTIONS(5077),
    [anon_sym_protected] = ACTIONS(5077),
    [anon_sym_using] = ACTIONS(5077),
    [anon_sym_static_assert] = ACTIONS(5077),
    [anon_sym_precise] = ACTIONS(5077),
    [anon_sym_shared] = ACTIONS(5077),
    [anon_sym_groupshared] = ACTIONS(5077),
    [anon_sym_uniform] = ACTIONS(5077),
    [anon_sym_row_major] = ACTIONS(5077),
    [anon_sym_column_major] = ACTIONS(5077),
    [anon_sym_globallycoherent] = ACTIONS(5077),
    [anon_sym_centroid] = ACTIONS(5077),
    [anon_sym_noperspective] = ACTIONS(5077),
    [anon_sym_nointerpolation] = ACTIONS(5077),
    [anon_sym_sample] = ACTIONS(5077),
    [anon_sym_linear] = ACTIONS(5077),
    [anon_sym_snorm] = ACTIONS(5077),
    [anon_sym_unorm] = ACTIONS(5077),
    [anon_sym_point] = ACTIONS(5077),
    [anon_sym_line] = ACTIONS(5077),
    [anon_sym_triangleadj] = ACTIONS(5077),
    [anon_sym_lineadj] = ACTIONS(5077),
    [anon_sym_triangle] = ACTIONS(5077),
  },
  [2007] = {
    [sym_identifier] = ACTIONS(5085),
    [aux_sym_preproc_def_token1] = ACTIONS(5085),
    [aux_sym_preproc_if_token1] = ACTIONS(5085),
    [aux_sym_preproc_if_token2] = ACTIONS(5085),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5085),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5085),
    [sym_preproc_directive] = ACTIONS(5085),
    [anon_sym_LPAREN2] = ACTIONS(5087),
    [anon_sym_TILDE] = ACTIONS(5087),
    [anon_sym_STAR] = ACTIONS(5087),
    [anon_sym_AMP_AMP] = ACTIONS(5087),
    [anon_sym_AMP] = ACTIONS(5085),
    [anon_sym___extension__] = ACTIONS(5085),
    [anon_sym_typedef] = ACTIONS(5085),
    [anon_sym_in] = ACTIONS(5085),
    [anon_sym_out] = ACTIONS(5085),
    [anon_sym_inout] = ACTIONS(5085),
    [anon_sym_extern] = ACTIONS(5085),
    [anon_sym___attribute__] = ACTIONS(5085),
    [anon_sym_COLON_COLON] = ACTIONS(5087),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5087),
    [anon_sym___declspec] = ACTIONS(5085),
    [anon_sym___based] = ACTIONS(5085),
    [anon_sym_signed] = ACTIONS(5085),
    [anon_sym_unsigned] = ACTIONS(5085),
    [anon_sym_long] = ACTIONS(5085),
    [anon_sym_short] = ACTIONS(5085),
    [anon_sym_LBRACK] = ACTIONS(5085),
    [anon_sym_static] = ACTIONS(5085),
    [anon_sym_register] = ACTIONS(5085),
    [anon_sym_inline] = ACTIONS(5085),
    [anon_sym___inline] = ACTIONS(5085),
    [anon_sym___inline__] = ACTIONS(5085),
    [anon_sym___forceinline] = ACTIONS(5085),
    [anon_sym_thread_local] = ACTIONS(5085),
    [anon_sym___thread] = ACTIONS(5085),
    [anon_sym_const] = ACTIONS(5085),
    [anon_sym_constexpr] = ACTIONS(5085),
    [anon_sym_volatile] = ACTIONS(5085),
    [anon_sym_restrict] = ACTIONS(5085),
    [anon_sym___restrict__] = ACTIONS(5085),
    [anon_sym__Atomic] = ACTIONS(5085),
    [anon_sym__Noreturn] = ACTIONS(5085),
    [anon_sym_noreturn] = ACTIONS(5085),
    [anon_sym_mutable] = ACTIONS(5085),
    [anon_sym_constinit] = ACTIONS(5085),
    [anon_sym_consteval] = ACTIONS(5085),
    [anon_sym_alignas] = ACTIONS(5085),
    [anon_sym__Alignas] = ACTIONS(5085),
    [sym_primitive_type] = ACTIONS(5085),
    [anon_sym_enum] = ACTIONS(5085),
    [anon_sym_class] = ACTIONS(5085),
    [anon_sym_struct] = ACTIONS(5085),
    [anon_sym_union] = ACTIONS(5085),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5085),
    [anon_sym_decltype] = ACTIONS(5085),
    [sym_virtual] = ACTIONS(5085),
    [anon_sym_explicit] = ACTIONS(5085),
    [anon_sym_typename] = ACTIONS(5085),
    [anon_sym_template] = ACTIONS(5085),
    [anon_sym_operator] = ACTIONS(5085),
    [anon_sym_friend] = ACTIONS(5085),
    [anon_sym_public] = ACTIONS(5085),
    [anon_sym_private] = ACTIONS(5085),
    [anon_sym_protected] = ACTIONS(5085),
    [anon_sym_using] = ACTIONS(5085),
    [anon_sym_static_assert] = ACTIONS(5085),
    [anon_sym_precise] = ACTIONS(5085),
    [anon_sym_shared] = ACTIONS(5085),
    [anon_sym_groupshared] = ACTIONS(5085),
    [anon_sym_uniform] = ACTIONS(5085),
    [anon_sym_row_major] = ACTIONS(5085),
    [anon_sym_column_major] = ACTIONS(5085),
    [anon_sym_globallycoherent] = ACTIONS(5085),
    [anon_sym_centroid] = ACTIONS(5085),
    [anon_sym_noperspective] = ACTIONS(5085),
    [anon_sym_nointerpolation] = ACTIONS(5085),
    [anon_sym_sample] = ACTIONS(5085),
    [anon_sym_linear] = ACTIONS(5085),
    [anon_sym_snorm] = ACTIONS(5085),
    [anon_sym_unorm] = ACTIONS(5085),
    [anon_sym_point] = ACTIONS(5085),
    [anon_sym_line] = ACTIONS(5085),
    [anon_sym_triangleadj] = ACTIONS(5085),
    [anon_sym_lineadj] = ACTIONS(5085),
    [anon_sym_triangle] = ACTIONS(5085),
  },
  [2008] = {
    [sym_identifier] = ACTIONS(2577),
    [aux_sym_preproc_def_token1] = ACTIONS(2577),
    [aux_sym_preproc_if_token1] = ACTIONS(2577),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2577),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2577),
    [sym_preproc_directive] = ACTIONS(2577),
    [anon_sym_LPAREN2] = ACTIONS(2579),
    [anon_sym_TILDE] = ACTIONS(2579),
    [anon_sym_STAR] = ACTIONS(2579),
    [anon_sym_AMP_AMP] = ACTIONS(2579),
    [anon_sym_AMP] = ACTIONS(2577),
    [anon_sym___extension__] = ACTIONS(2577),
    [anon_sym_typedef] = ACTIONS(2577),
    [anon_sym_in] = ACTIONS(2577),
    [anon_sym_out] = ACTIONS(2577),
    [anon_sym_inout] = ACTIONS(2577),
    [anon_sym_extern] = ACTIONS(2577),
    [anon_sym___attribute__] = ACTIONS(2577),
    [anon_sym_COLON_COLON] = ACTIONS(2579),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2579),
    [anon_sym___declspec] = ACTIONS(2577),
    [anon_sym___based] = ACTIONS(2577),
    [anon_sym_RBRACE] = ACTIONS(2579),
    [anon_sym_signed] = ACTIONS(2577),
    [anon_sym_unsigned] = ACTIONS(2577),
    [anon_sym_long] = ACTIONS(2577),
    [anon_sym_short] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2577),
    [anon_sym_static] = ACTIONS(2577),
    [anon_sym_register] = ACTIONS(2577),
    [anon_sym_inline] = ACTIONS(2577),
    [anon_sym___inline] = ACTIONS(2577),
    [anon_sym___inline__] = ACTIONS(2577),
    [anon_sym___forceinline] = ACTIONS(2577),
    [anon_sym_thread_local] = ACTIONS(2577),
    [anon_sym___thread] = ACTIONS(2577),
    [anon_sym_const] = ACTIONS(2577),
    [anon_sym_constexpr] = ACTIONS(2577),
    [anon_sym_volatile] = ACTIONS(2577),
    [anon_sym_restrict] = ACTIONS(2577),
    [anon_sym___restrict__] = ACTIONS(2577),
    [anon_sym__Atomic] = ACTIONS(2577),
    [anon_sym__Noreturn] = ACTIONS(2577),
    [anon_sym_noreturn] = ACTIONS(2577),
    [anon_sym_mutable] = ACTIONS(2577),
    [anon_sym_constinit] = ACTIONS(2577),
    [anon_sym_consteval] = ACTIONS(2577),
    [anon_sym_alignas] = ACTIONS(2577),
    [anon_sym__Alignas] = ACTIONS(2577),
    [sym_primitive_type] = ACTIONS(2577),
    [anon_sym_enum] = ACTIONS(2577),
    [anon_sym_class] = ACTIONS(2577),
    [anon_sym_struct] = ACTIONS(2577),
    [anon_sym_union] = ACTIONS(2577),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2577),
    [anon_sym_decltype] = ACTIONS(2577),
    [sym_virtual] = ACTIONS(2577),
    [anon_sym_explicit] = ACTIONS(2577),
    [anon_sym_typename] = ACTIONS(2577),
    [anon_sym_template] = ACTIONS(2577),
    [anon_sym_operator] = ACTIONS(2577),
    [anon_sym_friend] = ACTIONS(2577),
    [anon_sym_public] = ACTIONS(2577),
    [anon_sym_private] = ACTIONS(2577),
    [anon_sym_protected] = ACTIONS(2577),
    [anon_sym_using] = ACTIONS(2577),
    [anon_sym_static_assert] = ACTIONS(2577),
    [anon_sym_precise] = ACTIONS(2577),
    [anon_sym_shared] = ACTIONS(2577),
    [anon_sym_groupshared] = ACTIONS(2577),
    [anon_sym_uniform] = ACTIONS(2577),
    [anon_sym_row_major] = ACTIONS(2577),
    [anon_sym_column_major] = ACTIONS(2577),
    [anon_sym_globallycoherent] = ACTIONS(2577),
    [anon_sym_centroid] = ACTIONS(2577),
    [anon_sym_noperspective] = ACTIONS(2577),
    [anon_sym_nointerpolation] = ACTIONS(2577),
    [anon_sym_sample] = ACTIONS(2577),
    [anon_sym_linear] = ACTIONS(2577),
    [anon_sym_snorm] = ACTIONS(2577),
    [anon_sym_unorm] = ACTIONS(2577),
    [anon_sym_point] = ACTIONS(2577),
    [anon_sym_line] = ACTIONS(2577),
    [anon_sym_triangleadj] = ACTIONS(2577),
    [anon_sym_lineadj] = ACTIONS(2577),
    [anon_sym_triangle] = ACTIONS(2577),
  },
  [2009] = {
    [sym_identifier] = ACTIONS(5093),
    [aux_sym_preproc_def_token1] = ACTIONS(5093),
    [aux_sym_preproc_if_token1] = ACTIONS(5093),
    [aux_sym_preproc_if_token2] = ACTIONS(5093),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5093),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5093),
    [sym_preproc_directive] = ACTIONS(5093),
    [anon_sym_LPAREN2] = ACTIONS(5095),
    [anon_sym_TILDE] = ACTIONS(5095),
    [anon_sym_STAR] = ACTIONS(5095),
    [anon_sym_AMP_AMP] = ACTIONS(5095),
    [anon_sym_AMP] = ACTIONS(5093),
    [anon_sym___extension__] = ACTIONS(5093),
    [anon_sym_typedef] = ACTIONS(5093),
    [anon_sym_in] = ACTIONS(5093),
    [anon_sym_out] = ACTIONS(5093),
    [anon_sym_inout] = ACTIONS(5093),
    [anon_sym_extern] = ACTIONS(5093),
    [anon_sym___attribute__] = ACTIONS(5093),
    [anon_sym_COLON_COLON] = ACTIONS(5095),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5095),
    [anon_sym___declspec] = ACTIONS(5093),
    [anon_sym___based] = ACTIONS(5093),
    [anon_sym_signed] = ACTIONS(5093),
    [anon_sym_unsigned] = ACTIONS(5093),
    [anon_sym_long] = ACTIONS(5093),
    [anon_sym_short] = ACTIONS(5093),
    [anon_sym_LBRACK] = ACTIONS(5093),
    [anon_sym_static] = ACTIONS(5093),
    [anon_sym_register] = ACTIONS(5093),
    [anon_sym_inline] = ACTIONS(5093),
    [anon_sym___inline] = ACTIONS(5093),
    [anon_sym___inline__] = ACTIONS(5093),
    [anon_sym___forceinline] = ACTIONS(5093),
    [anon_sym_thread_local] = ACTIONS(5093),
    [anon_sym___thread] = ACTIONS(5093),
    [anon_sym_const] = ACTIONS(5093),
    [anon_sym_constexpr] = ACTIONS(5093),
    [anon_sym_volatile] = ACTIONS(5093),
    [anon_sym_restrict] = ACTIONS(5093),
    [anon_sym___restrict__] = ACTIONS(5093),
    [anon_sym__Atomic] = ACTIONS(5093),
    [anon_sym__Noreturn] = ACTIONS(5093),
    [anon_sym_noreturn] = ACTIONS(5093),
    [anon_sym_mutable] = ACTIONS(5093),
    [anon_sym_constinit] = ACTIONS(5093),
    [anon_sym_consteval] = ACTIONS(5093),
    [anon_sym_alignas] = ACTIONS(5093),
    [anon_sym__Alignas] = ACTIONS(5093),
    [sym_primitive_type] = ACTIONS(5093),
    [anon_sym_enum] = ACTIONS(5093),
    [anon_sym_class] = ACTIONS(5093),
    [anon_sym_struct] = ACTIONS(5093),
    [anon_sym_union] = ACTIONS(5093),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5093),
    [anon_sym_decltype] = ACTIONS(5093),
    [sym_virtual] = ACTIONS(5093),
    [anon_sym_explicit] = ACTIONS(5093),
    [anon_sym_typename] = ACTIONS(5093),
    [anon_sym_template] = ACTIONS(5093),
    [anon_sym_operator] = ACTIONS(5093),
    [anon_sym_friend] = ACTIONS(5093),
    [anon_sym_public] = ACTIONS(5093),
    [anon_sym_private] = ACTIONS(5093),
    [anon_sym_protected] = ACTIONS(5093),
    [anon_sym_using] = ACTIONS(5093),
    [anon_sym_static_assert] = ACTIONS(5093),
    [anon_sym_precise] = ACTIONS(5093),
    [anon_sym_shared] = ACTIONS(5093),
    [anon_sym_groupshared] = ACTIONS(5093),
    [anon_sym_uniform] = ACTIONS(5093),
    [anon_sym_row_major] = ACTIONS(5093),
    [anon_sym_column_major] = ACTIONS(5093),
    [anon_sym_globallycoherent] = ACTIONS(5093),
    [anon_sym_centroid] = ACTIONS(5093),
    [anon_sym_noperspective] = ACTIONS(5093),
    [anon_sym_nointerpolation] = ACTIONS(5093),
    [anon_sym_sample] = ACTIONS(5093),
    [anon_sym_linear] = ACTIONS(5093),
    [anon_sym_snorm] = ACTIONS(5093),
    [anon_sym_unorm] = ACTIONS(5093),
    [anon_sym_point] = ACTIONS(5093),
    [anon_sym_line] = ACTIONS(5093),
    [anon_sym_triangleadj] = ACTIONS(5093),
    [anon_sym_lineadj] = ACTIONS(5093),
    [anon_sym_triangle] = ACTIONS(5093),
  },
  [2010] = {
    [sym_identifier] = ACTIONS(2276),
    [aux_sym_preproc_def_token1] = ACTIONS(2276),
    [aux_sym_preproc_if_token1] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2276),
    [sym_preproc_directive] = ACTIONS(2276),
    [anon_sym_LPAREN2] = ACTIONS(2278),
    [anon_sym_TILDE] = ACTIONS(2278),
    [anon_sym_STAR] = ACTIONS(2278),
    [anon_sym_AMP_AMP] = ACTIONS(2278),
    [anon_sym_AMP] = ACTIONS(2276),
    [anon_sym___extension__] = ACTIONS(2276),
    [anon_sym_typedef] = ACTIONS(2276),
    [anon_sym_in] = ACTIONS(2276),
    [anon_sym_out] = ACTIONS(2276),
    [anon_sym_inout] = ACTIONS(2276),
    [anon_sym_extern] = ACTIONS(2276),
    [anon_sym___attribute__] = ACTIONS(2276),
    [anon_sym_COLON_COLON] = ACTIONS(2278),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2278),
    [anon_sym___declspec] = ACTIONS(2276),
    [anon_sym___based] = ACTIONS(2276),
    [anon_sym_RBRACE] = ACTIONS(2278),
    [anon_sym_signed] = ACTIONS(2276),
    [anon_sym_unsigned] = ACTIONS(2276),
    [anon_sym_long] = ACTIONS(2276),
    [anon_sym_short] = ACTIONS(2276),
    [anon_sym_LBRACK] = ACTIONS(2276),
    [anon_sym_static] = ACTIONS(2276),
    [anon_sym_register] = ACTIONS(2276),
    [anon_sym_inline] = ACTIONS(2276),
    [anon_sym___inline] = ACTIONS(2276),
    [anon_sym___inline__] = ACTIONS(2276),
    [anon_sym___forceinline] = ACTIONS(2276),
    [anon_sym_thread_local] = ACTIONS(2276),
    [anon_sym___thread] = ACTIONS(2276),
    [anon_sym_const] = ACTIONS(2276),
    [anon_sym_constexpr] = ACTIONS(2276),
    [anon_sym_volatile] = ACTIONS(2276),
    [anon_sym_restrict] = ACTIONS(2276),
    [anon_sym___restrict__] = ACTIONS(2276),
    [anon_sym__Atomic] = ACTIONS(2276),
    [anon_sym__Noreturn] = ACTIONS(2276),
    [anon_sym_noreturn] = ACTIONS(2276),
    [anon_sym_mutable] = ACTIONS(2276),
    [anon_sym_constinit] = ACTIONS(2276),
    [anon_sym_consteval] = ACTIONS(2276),
    [anon_sym_alignas] = ACTIONS(2276),
    [anon_sym__Alignas] = ACTIONS(2276),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2276),
    [anon_sym_class] = ACTIONS(2276),
    [anon_sym_struct] = ACTIONS(2276),
    [anon_sym_union] = ACTIONS(2276),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2276),
    [anon_sym_decltype] = ACTIONS(2276),
    [sym_virtual] = ACTIONS(2276),
    [anon_sym_explicit] = ACTIONS(2276),
    [anon_sym_typename] = ACTIONS(2276),
    [anon_sym_template] = ACTIONS(2276),
    [anon_sym_operator] = ACTIONS(2276),
    [anon_sym_friend] = ACTIONS(2276),
    [anon_sym_public] = ACTIONS(2276),
    [anon_sym_private] = ACTIONS(2276),
    [anon_sym_protected] = ACTIONS(2276),
    [anon_sym_using] = ACTIONS(2276),
    [anon_sym_static_assert] = ACTIONS(2276),
    [anon_sym_precise] = ACTIONS(2276),
    [anon_sym_shared] = ACTIONS(2276),
    [anon_sym_groupshared] = ACTIONS(2276),
    [anon_sym_uniform] = ACTIONS(2276),
    [anon_sym_row_major] = ACTIONS(2276),
    [anon_sym_column_major] = ACTIONS(2276),
    [anon_sym_globallycoherent] = ACTIONS(2276),
    [anon_sym_centroid] = ACTIONS(2276),
    [anon_sym_noperspective] = ACTIONS(2276),
    [anon_sym_nointerpolation] = ACTIONS(2276),
    [anon_sym_sample] = ACTIONS(2276),
    [anon_sym_linear] = ACTIONS(2276),
    [anon_sym_snorm] = ACTIONS(2276),
    [anon_sym_unorm] = ACTIONS(2276),
    [anon_sym_point] = ACTIONS(2276),
    [anon_sym_line] = ACTIONS(2276),
    [anon_sym_triangleadj] = ACTIONS(2276),
    [anon_sym_lineadj] = ACTIONS(2276),
    [anon_sym_triangle] = ACTIONS(2276),
  },
  [2011] = {
    [sym_identifier] = ACTIONS(5045),
    [aux_sym_preproc_def_token1] = ACTIONS(5045),
    [aux_sym_preproc_if_token1] = ACTIONS(5045),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5045),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5045),
    [sym_preproc_directive] = ACTIONS(5045),
    [anon_sym_LPAREN2] = ACTIONS(5047),
    [anon_sym_TILDE] = ACTIONS(5047),
    [anon_sym_STAR] = ACTIONS(5047),
    [anon_sym_AMP_AMP] = ACTIONS(5047),
    [anon_sym_AMP] = ACTIONS(5045),
    [anon_sym___extension__] = ACTIONS(5045),
    [anon_sym_typedef] = ACTIONS(5045),
    [anon_sym_in] = ACTIONS(5045),
    [anon_sym_out] = ACTIONS(5045),
    [anon_sym_inout] = ACTIONS(5045),
    [anon_sym_extern] = ACTIONS(5045),
    [anon_sym___attribute__] = ACTIONS(5045),
    [anon_sym_COLON_COLON] = ACTIONS(5047),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5047),
    [anon_sym___declspec] = ACTIONS(5045),
    [anon_sym___based] = ACTIONS(5045),
    [anon_sym_RBRACE] = ACTIONS(5047),
    [anon_sym_signed] = ACTIONS(5045),
    [anon_sym_unsigned] = ACTIONS(5045),
    [anon_sym_long] = ACTIONS(5045),
    [anon_sym_short] = ACTIONS(5045),
    [anon_sym_LBRACK] = ACTIONS(5045),
    [anon_sym_static] = ACTIONS(5045),
    [anon_sym_register] = ACTIONS(5045),
    [anon_sym_inline] = ACTIONS(5045),
    [anon_sym___inline] = ACTIONS(5045),
    [anon_sym___inline__] = ACTIONS(5045),
    [anon_sym___forceinline] = ACTIONS(5045),
    [anon_sym_thread_local] = ACTIONS(5045),
    [anon_sym___thread] = ACTIONS(5045),
    [anon_sym_const] = ACTIONS(5045),
    [anon_sym_constexpr] = ACTIONS(5045),
    [anon_sym_volatile] = ACTIONS(5045),
    [anon_sym_restrict] = ACTIONS(5045),
    [anon_sym___restrict__] = ACTIONS(5045),
    [anon_sym__Atomic] = ACTIONS(5045),
    [anon_sym__Noreturn] = ACTIONS(5045),
    [anon_sym_noreturn] = ACTIONS(5045),
    [anon_sym_mutable] = ACTIONS(5045),
    [anon_sym_constinit] = ACTIONS(5045),
    [anon_sym_consteval] = ACTIONS(5045),
    [anon_sym_alignas] = ACTIONS(5045),
    [anon_sym__Alignas] = ACTIONS(5045),
    [sym_primitive_type] = ACTIONS(5045),
    [anon_sym_enum] = ACTIONS(5045),
    [anon_sym_class] = ACTIONS(5045),
    [anon_sym_struct] = ACTIONS(5045),
    [anon_sym_union] = ACTIONS(5045),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5045),
    [anon_sym_decltype] = ACTIONS(5045),
    [sym_virtual] = ACTIONS(5045),
    [anon_sym_explicit] = ACTIONS(5045),
    [anon_sym_typename] = ACTIONS(5045),
    [anon_sym_template] = ACTIONS(5045),
    [anon_sym_operator] = ACTIONS(5045),
    [anon_sym_friend] = ACTIONS(5045),
    [anon_sym_public] = ACTIONS(5045),
    [anon_sym_private] = ACTIONS(5045),
    [anon_sym_protected] = ACTIONS(5045),
    [anon_sym_using] = ACTIONS(5045),
    [anon_sym_static_assert] = ACTIONS(5045),
    [anon_sym_precise] = ACTIONS(5045),
    [anon_sym_shared] = ACTIONS(5045),
    [anon_sym_groupshared] = ACTIONS(5045),
    [anon_sym_uniform] = ACTIONS(5045),
    [anon_sym_row_major] = ACTIONS(5045),
    [anon_sym_column_major] = ACTIONS(5045),
    [anon_sym_globallycoherent] = ACTIONS(5045),
    [anon_sym_centroid] = ACTIONS(5045),
    [anon_sym_noperspective] = ACTIONS(5045),
    [anon_sym_nointerpolation] = ACTIONS(5045),
    [anon_sym_sample] = ACTIONS(5045),
    [anon_sym_linear] = ACTIONS(5045),
    [anon_sym_snorm] = ACTIONS(5045),
    [anon_sym_unorm] = ACTIONS(5045),
    [anon_sym_point] = ACTIONS(5045),
    [anon_sym_line] = ACTIONS(5045),
    [anon_sym_triangleadj] = ACTIONS(5045),
    [anon_sym_lineadj] = ACTIONS(5045),
    [anon_sym_triangle] = ACTIONS(5045),
  },
  [2012] = {
    [sym_identifier] = ACTIONS(2516),
    [aux_sym_preproc_def_token1] = ACTIONS(2516),
    [aux_sym_preproc_if_token1] = ACTIONS(2516),
    [aux_sym_preproc_if_token2] = ACTIONS(2516),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2516),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2516),
    [sym_preproc_directive] = ACTIONS(2516),
    [anon_sym_LPAREN2] = ACTIONS(2518),
    [anon_sym_TILDE] = ACTIONS(2518),
    [anon_sym_STAR] = ACTIONS(2518),
    [anon_sym_AMP_AMP] = ACTIONS(2518),
    [anon_sym_AMP] = ACTIONS(2516),
    [anon_sym___extension__] = ACTIONS(2516),
    [anon_sym_typedef] = ACTIONS(2516),
    [anon_sym_in] = ACTIONS(2516),
    [anon_sym_out] = ACTIONS(2516),
    [anon_sym_inout] = ACTIONS(2516),
    [anon_sym_extern] = ACTIONS(2516),
    [anon_sym___attribute__] = ACTIONS(2516),
    [anon_sym_COLON_COLON] = ACTIONS(2518),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2518),
    [anon_sym___declspec] = ACTIONS(2516),
    [anon_sym___based] = ACTIONS(2516),
    [anon_sym_signed] = ACTIONS(2516),
    [anon_sym_unsigned] = ACTIONS(2516),
    [anon_sym_long] = ACTIONS(2516),
    [anon_sym_short] = ACTIONS(2516),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_static] = ACTIONS(2516),
    [anon_sym_register] = ACTIONS(2516),
    [anon_sym_inline] = ACTIONS(2516),
    [anon_sym___inline] = ACTIONS(2516),
    [anon_sym___inline__] = ACTIONS(2516),
    [anon_sym___forceinline] = ACTIONS(2516),
    [anon_sym_thread_local] = ACTIONS(2516),
    [anon_sym___thread] = ACTIONS(2516),
    [anon_sym_const] = ACTIONS(2516),
    [anon_sym_constexpr] = ACTIONS(2516),
    [anon_sym_volatile] = ACTIONS(2516),
    [anon_sym_restrict] = ACTIONS(2516),
    [anon_sym___restrict__] = ACTIONS(2516),
    [anon_sym__Atomic] = ACTIONS(2516),
    [anon_sym__Noreturn] = ACTIONS(2516),
    [anon_sym_noreturn] = ACTIONS(2516),
    [anon_sym_mutable] = ACTIONS(2516),
    [anon_sym_constinit] = ACTIONS(2516),
    [anon_sym_consteval] = ACTIONS(2516),
    [anon_sym_alignas] = ACTIONS(2516),
    [anon_sym__Alignas] = ACTIONS(2516),
    [sym_primitive_type] = ACTIONS(2516),
    [anon_sym_enum] = ACTIONS(2516),
    [anon_sym_class] = ACTIONS(2516),
    [anon_sym_struct] = ACTIONS(2516),
    [anon_sym_union] = ACTIONS(2516),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2516),
    [anon_sym_decltype] = ACTIONS(2516),
    [sym_virtual] = ACTIONS(2516),
    [anon_sym_explicit] = ACTIONS(2516),
    [anon_sym_typename] = ACTIONS(2516),
    [anon_sym_template] = ACTIONS(2516),
    [anon_sym_operator] = ACTIONS(2516),
    [anon_sym_friend] = ACTIONS(2516),
    [anon_sym_public] = ACTIONS(2516),
    [anon_sym_private] = ACTIONS(2516),
    [anon_sym_protected] = ACTIONS(2516),
    [anon_sym_using] = ACTIONS(2516),
    [anon_sym_static_assert] = ACTIONS(2516),
    [anon_sym_precise] = ACTIONS(2516),
    [anon_sym_shared] = ACTIONS(2516),
    [anon_sym_groupshared] = ACTIONS(2516),
    [anon_sym_uniform] = ACTIONS(2516),
    [anon_sym_row_major] = ACTIONS(2516),
    [anon_sym_column_major] = ACTIONS(2516),
    [anon_sym_globallycoherent] = ACTIONS(2516),
    [anon_sym_centroid] = ACTIONS(2516),
    [anon_sym_noperspective] = ACTIONS(2516),
    [anon_sym_nointerpolation] = ACTIONS(2516),
    [anon_sym_sample] = ACTIONS(2516),
    [anon_sym_linear] = ACTIONS(2516),
    [anon_sym_snorm] = ACTIONS(2516),
    [anon_sym_unorm] = ACTIONS(2516),
    [anon_sym_point] = ACTIONS(2516),
    [anon_sym_line] = ACTIONS(2516),
    [anon_sym_triangleadj] = ACTIONS(2516),
    [anon_sym_lineadj] = ACTIONS(2516),
    [anon_sym_triangle] = ACTIONS(2516),
  },
  [2013] = {
    [sym_identifier] = ACTIONS(5049),
    [aux_sym_preproc_def_token1] = ACTIONS(5049),
    [aux_sym_preproc_if_token1] = ACTIONS(5049),
    [aux_sym_preproc_if_token2] = ACTIONS(5049),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5049),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5049),
    [sym_preproc_directive] = ACTIONS(5049),
    [anon_sym_LPAREN2] = ACTIONS(5051),
    [anon_sym_TILDE] = ACTIONS(5051),
    [anon_sym_STAR] = ACTIONS(5051),
    [anon_sym_AMP_AMP] = ACTIONS(5051),
    [anon_sym_AMP] = ACTIONS(5049),
    [anon_sym___extension__] = ACTIONS(5049),
    [anon_sym_typedef] = ACTIONS(5049),
    [anon_sym_in] = ACTIONS(5049),
    [anon_sym_out] = ACTIONS(5049),
    [anon_sym_inout] = ACTIONS(5049),
    [anon_sym_extern] = ACTIONS(5049),
    [anon_sym___attribute__] = ACTIONS(5049),
    [anon_sym_COLON_COLON] = ACTIONS(5051),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5051),
    [anon_sym___declspec] = ACTIONS(5049),
    [anon_sym___based] = ACTIONS(5049),
    [anon_sym_signed] = ACTIONS(5049),
    [anon_sym_unsigned] = ACTIONS(5049),
    [anon_sym_long] = ACTIONS(5049),
    [anon_sym_short] = ACTIONS(5049),
    [anon_sym_LBRACK] = ACTIONS(5049),
    [anon_sym_static] = ACTIONS(5049),
    [anon_sym_register] = ACTIONS(5049),
    [anon_sym_inline] = ACTIONS(5049),
    [anon_sym___inline] = ACTIONS(5049),
    [anon_sym___inline__] = ACTIONS(5049),
    [anon_sym___forceinline] = ACTIONS(5049),
    [anon_sym_thread_local] = ACTIONS(5049),
    [anon_sym___thread] = ACTIONS(5049),
    [anon_sym_const] = ACTIONS(5049),
    [anon_sym_constexpr] = ACTIONS(5049),
    [anon_sym_volatile] = ACTIONS(5049),
    [anon_sym_restrict] = ACTIONS(5049),
    [anon_sym___restrict__] = ACTIONS(5049),
    [anon_sym__Atomic] = ACTIONS(5049),
    [anon_sym__Noreturn] = ACTIONS(5049),
    [anon_sym_noreturn] = ACTIONS(5049),
    [anon_sym_mutable] = ACTIONS(5049),
    [anon_sym_constinit] = ACTIONS(5049),
    [anon_sym_consteval] = ACTIONS(5049),
    [anon_sym_alignas] = ACTIONS(5049),
    [anon_sym__Alignas] = ACTIONS(5049),
    [sym_primitive_type] = ACTIONS(5049),
    [anon_sym_enum] = ACTIONS(5049),
    [anon_sym_class] = ACTIONS(5049),
    [anon_sym_struct] = ACTIONS(5049),
    [anon_sym_union] = ACTIONS(5049),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5049),
    [anon_sym_decltype] = ACTIONS(5049),
    [sym_virtual] = ACTIONS(5049),
    [anon_sym_explicit] = ACTIONS(5049),
    [anon_sym_typename] = ACTIONS(5049),
    [anon_sym_template] = ACTIONS(5049),
    [anon_sym_operator] = ACTIONS(5049),
    [anon_sym_friend] = ACTIONS(5049),
    [anon_sym_public] = ACTIONS(5049),
    [anon_sym_private] = ACTIONS(5049),
    [anon_sym_protected] = ACTIONS(5049),
    [anon_sym_using] = ACTIONS(5049),
    [anon_sym_static_assert] = ACTIONS(5049),
    [anon_sym_precise] = ACTIONS(5049),
    [anon_sym_shared] = ACTIONS(5049),
    [anon_sym_groupshared] = ACTIONS(5049),
    [anon_sym_uniform] = ACTIONS(5049),
    [anon_sym_row_major] = ACTIONS(5049),
    [anon_sym_column_major] = ACTIONS(5049),
    [anon_sym_globallycoherent] = ACTIONS(5049),
    [anon_sym_centroid] = ACTIONS(5049),
    [anon_sym_noperspective] = ACTIONS(5049),
    [anon_sym_nointerpolation] = ACTIONS(5049),
    [anon_sym_sample] = ACTIONS(5049),
    [anon_sym_linear] = ACTIONS(5049),
    [anon_sym_snorm] = ACTIONS(5049),
    [anon_sym_unorm] = ACTIONS(5049),
    [anon_sym_point] = ACTIONS(5049),
    [anon_sym_line] = ACTIONS(5049),
    [anon_sym_triangleadj] = ACTIONS(5049),
    [anon_sym_lineadj] = ACTIONS(5049),
    [anon_sym_triangle] = ACTIONS(5049),
  },
  [2014] = {
    [sym_identifier] = ACTIONS(5033),
    [aux_sym_preproc_def_token1] = ACTIONS(5033),
    [aux_sym_preproc_if_token1] = ACTIONS(5033),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5033),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5033),
    [sym_preproc_directive] = ACTIONS(5033),
    [anon_sym_LPAREN2] = ACTIONS(5035),
    [anon_sym_TILDE] = ACTIONS(5035),
    [anon_sym_STAR] = ACTIONS(5035),
    [anon_sym_AMP_AMP] = ACTIONS(5035),
    [anon_sym_AMP] = ACTIONS(5033),
    [anon_sym___extension__] = ACTIONS(5033),
    [anon_sym_typedef] = ACTIONS(5033),
    [anon_sym_in] = ACTIONS(5033),
    [anon_sym_out] = ACTIONS(5033),
    [anon_sym_inout] = ACTIONS(5033),
    [anon_sym_extern] = ACTIONS(5033),
    [anon_sym___attribute__] = ACTIONS(5033),
    [anon_sym_COLON_COLON] = ACTIONS(5035),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5035),
    [anon_sym___declspec] = ACTIONS(5033),
    [anon_sym___based] = ACTIONS(5033),
    [anon_sym_RBRACE] = ACTIONS(5035),
    [anon_sym_signed] = ACTIONS(5033),
    [anon_sym_unsigned] = ACTIONS(5033),
    [anon_sym_long] = ACTIONS(5033),
    [anon_sym_short] = ACTIONS(5033),
    [anon_sym_LBRACK] = ACTIONS(5033),
    [anon_sym_static] = ACTIONS(5033),
    [anon_sym_register] = ACTIONS(5033),
    [anon_sym_inline] = ACTIONS(5033),
    [anon_sym___inline] = ACTIONS(5033),
    [anon_sym___inline__] = ACTIONS(5033),
    [anon_sym___forceinline] = ACTIONS(5033),
    [anon_sym_thread_local] = ACTIONS(5033),
    [anon_sym___thread] = ACTIONS(5033),
    [anon_sym_const] = ACTIONS(5033),
    [anon_sym_constexpr] = ACTIONS(5033),
    [anon_sym_volatile] = ACTIONS(5033),
    [anon_sym_restrict] = ACTIONS(5033),
    [anon_sym___restrict__] = ACTIONS(5033),
    [anon_sym__Atomic] = ACTIONS(5033),
    [anon_sym__Noreturn] = ACTIONS(5033),
    [anon_sym_noreturn] = ACTIONS(5033),
    [anon_sym_mutable] = ACTIONS(5033),
    [anon_sym_constinit] = ACTIONS(5033),
    [anon_sym_consteval] = ACTIONS(5033),
    [anon_sym_alignas] = ACTIONS(5033),
    [anon_sym__Alignas] = ACTIONS(5033),
    [sym_primitive_type] = ACTIONS(5033),
    [anon_sym_enum] = ACTIONS(5033),
    [anon_sym_class] = ACTIONS(5033),
    [anon_sym_struct] = ACTIONS(5033),
    [anon_sym_union] = ACTIONS(5033),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5033),
    [anon_sym_decltype] = ACTIONS(5033),
    [sym_virtual] = ACTIONS(5033),
    [anon_sym_explicit] = ACTIONS(5033),
    [anon_sym_typename] = ACTIONS(5033),
    [anon_sym_template] = ACTIONS(5033),
    [anon_sym_operator] = ACTIONS(5033),
    [anon_sym_friend] = ACTIONS(5033),
    [anon_sym_public] = ACTIONS(5033),
    [anon_sym_private] = ACTIONS(5033),
    [anon_sym_protected] = ACTIONS(5033),
    [anon_sym_using] = ACTIONS(5033),
    [anon_sym_static_assert] = ACTIONS(5033),
    [anon_sym_precise] = ACTIONS(5033),
    [anon_sym_shared] = ACTIONS(5033),
    [anon_sym_groupshared] = ACTIONS(5033),
    [anon_sym_uniform] = ACTIONS(5033),
    [anon_sym_row_major] = ACTIONS(5033),
    [anon_sym_column_major] = ACTIONS(5033),
    [anon_sym_globallycoherent] = ACTIONS(5033),
    [anon_sym_centroid] = ACTIONS(5033),
    [anon_sym_noperspective] = ACTIONS(5033),
    [anon_sym_nointerpolation] = ACTIONS(5033),
    [anon_sym_sample] = ACTIONS(5033),
    [anon_sym_linear] = ACTIONS(5033),
    [anon_sym_snorm] = ACTIONS(5033),
    [anon_sym_unorm] = ACTIONS(5033),
    [anon_sym_point] = ACTIONS(5033),
    [anon_sym_line] = ACTIONS(5033),
    [anon_sym_triangleadj] = ACTIONS(5033),
    [anon_sym_lineadj] = ACTIONS(5033),
    [anon_sym_triangle] = ACTIONS(5033),
  },
  [2015] = {
    [sym_identifier] = ACTIONS(5025),
    [aux_sym_preproc_def_token1] = ACTIONS(5025),
    [aux_sym_preproc_if_token1] = ACTIONS(5025),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5025),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5025),
    [sym_preproc_directive] = ACTIONS(5025),
    [anon_sym_LPAREN2] = ACTIONS(5027),
    [anon_sym_TILDE] = ACTIONS(5027),
    [anon_sym_STAR] = ACTIONS(5027),
    [anon_sym_AMP_AMP] = ACTIONS(5027),
    [anon_sym_AMP] = ACTIONS(5025),
    [anon_sym___extension__] = ACTIONS(5025),
    [anon_sym_typedef] = ACTIONS(5025),
    [anon_sym_in] = ACTIONS(5025),
    [anon_sym_out] = ACTIONS(5025),
    [anon_sym_inout] = ACTIONS(5025),
    [anon_sym_extern] = ACTIONS(5025),
    [anon_sym___attribute__] = ACTIONS(5025),
    [anon_sym_COLON_COLON] = ACTIONS(5027),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5027),
    [anon_sym___declspec] = ACTIONS(5025),
    [anon_sym___based] = ACTIONS(5025),
    [anon_sym_RBRACE] = ACTIONS(5027),
    [anon_sym_signed] = ACTIONS(5025),
    [anon_sym_unsigned] = ACTIONS(5025),
    [anon_sym_long] = ACTIONS(5025),
    [anon_sym_short] = ACTIONS(5025),
    [anon_sym_LBRACK] = ACTIONS(5025),
    [anon_sym_static] = ACTIONS(5025),
    [anon_sym_register] = ACTIONS(5025),
    [anon_sym_inline] = ACTIONS(5025),
    [anon_sym___inline] = ACTIONS(5025),
    [anon_sym___inline__] = ACTIONS(5025),
    [anon_sym___forceinline] = ACTIONS(5025),
    [anon_sym_thread_local] = ACTIONS(5025),
    [anon_sym___thread] = ACTIONS(5025),
    [anon_sym_const] = ACTIONS(5025),
    [anon_sym_constexpr] = ACTIONS(5025),
    [anon_sym_volatile] = ACTIONS(5025),
    [anon_sym_restrict] = ACTIONS(5025),
    [anon_sym___restrict__] = ACTIONS(5025),
    [anon_sym__Atomic] = ACTIONS(5025),
    [anon_sym__Noreturn] = ACTIONS(5025),
    [anon_sym_noreturn] = ACTIONS(5025),
    [anon_sym_mutable] = ACTIONS(5025),
    [anon_sym_constinit] = ACTIONS(5025),
    [anon_sym_consteval] = ACTIONS(5025),
    [anon_sym_alignas] = ACTIONS(5025),
    [anon_sym__Alignas] = ACTIONS(5025),
    [sym_primitive_type] = ACTIONS(5025),
    [anon_sym_enum] = ACTIONS(5025),
    [anon_sym_class] = ACTIONS(5025),
    [anon_sym_struct] = ACTIONS(5025),
    [anon_sym_union] = ACTIONS(5025),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5025),
    [anon_sym_decltype] = ACTIONS(5025),
    [sym_virtual] = ACTIONS(5025),
    [anon_sym_explicit] = ACTIONS(5025),
    [anon_sym_typename] = ACTIONS(5025),
    [anon_sym_template] = ACTIONS(5025),
    [anon_sym_operator] = ACTIONS(5025),
    [anon_sym_friend] = ACTIONS(5025),
    [anon_sym_public] = ACTIONS(5025),
    [anon_sym_private] = ACTIONS(5025),
    [anon_sym_protected] = ACTIONS(5025),
    [anon_sym_using] = ACTIONS(5025),
    [anon_sym_static_assert] = ACTIONS(5025),
    [anon_sym_precise] = ACTIONS(5025),
    [anon_sym_shared] = ACTIONS(5025),
    [anon_sym_groupshared] = ACTIONS(5025),
    [anon_sym_uniform] = ACTIONS(5025),
    [anon_sym_row_major] = ACTIONS(5025),
    [anon_sym_column_major] = ACTIONS(5025),
    [anon_sym_globallycoherent] = ACTIONS(5025),
    [anon_sym_centroid] = ACTIONS(5025),
    [anon_sym_noperspective] = ACTIONS(5025),
    [anon_sym_nointerpolation] = ACTIONS(5025),
    [anon_sym_sample] = ACTIONS(5025),
    [anon_sym_linear] = ACTIONS(5025),
    [anon_sym_snorm] = ACTIONS(5025),
    [anon_sym_unorm] = ACTIONS(5025),
    [anon_sym_point] = ACTIONS(5025),
    [anon_sym_line] = ACTIONS(5025),
    [anon_sym_triangleadj] = ACTIONS(5025),
    [anon_sym_lineadj] = ACTIONS(5025),
    [anon_sym_triangle] = ACTIONS(5025),
  },
  [2016] = {
    [sym_identifier] = ACTIONS(5029),
    [aux_sym_preproc_def_token1] = ACTIONS(5029),
    [aux_sym_preproc_if_token1] = ACTIONS(5029),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5029),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5029),
    [sym_preproc_directive] = ACTIONS(5029),
    [anon_sym_LPAREN2] = ACTIONS(5031),
    [anon_sym_TILDE] = ACTIONS(5031),
    [anon_sym_STAR] = ACTIONS(5031),
    [anon_sym_AMP_AMP] = ACTIONS(5031),
    [anon_sym_AMP] = ACTIONS(5029),
    [anon_sym___extension__] = ACTIONS(5029),
    [anon_sym_typedef] = ACTIONS(5029),
    [anon_sym_in] = ACTIONS(5029),
    [anon_sym_out] = ACTIONS(5029),
    [anon_sym_inout] = ACTIONS(5029),
    [anon_sym_extern] = ACTIONS(5029),
    [anon_sym___attribute__] = ACTIONS(5029),
    [anon_sym_COLON_COLON] = ACTIONS(5031),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5031),
    [anon_sym___declspec] = ACTIONS(5029),
    [anon_sym___based] = ACTIONS(5029),
    [anon_sym_RBRACE] = ACTIONS(5031),
    [anon_sym_signed] = ACTIONS(5029),
    [anon_sym_unsigned] = ACTIONS(5029),
    [anon_sym_long] = ACTIONS(5029),
    [anon_sym_short] = ACTIONS(5029),
    [anon_sym_LBRACK] = ACTIONS(5029),
    [anon_sym_static] = ACTIONS(5029),
    [anon_sym_register] = ACTIONS(5029),
    [anon_sym_inline] = ACTIONS(5029),
    [anon_sym___inline] = ACTIONS(5029),
    [anon_sym___inline__] = ACTIONS(5029),
    [anon_sym___forceinline] = ACTIONS(5029),
    [anon_sym_thread_local] = ACTIONS(5029),
    [anon_sym___thread] = ACTIONS(5029),
    [anon_sym_const] = ACTIONS(5029),
    [anon_sym_constexpr] = ACTIONS(5029),
    [anon_sym_volatile] = ACTIONS(5029),
    [anon_sym_restrict] = ACTIONS(5029),
    [anon_sym___restrict__] = ACTIONS(5029),
    [anon_sym__Atomic] = ACTIONS(5029),
    [anon_sym__Noreturn] = ACTIONS(5029),
    [anon_sym_noreturn] = ACTIONS(5029),
    [anon_sym_mutable] = ACTIONS(5029),
    [anon_sym_constinit] = ACTIONS(5029),
    [anon_sym_consteval] = ACTIONS(5029),
    [anon_sym_alignas] = ACTIONS(5029),
    [anon_sym__Alignas] = ACTIONS(5029),
    [sym_primitive_type] = ACTIONS(5029),
    [anon_sym_enum] = ACTIONS(5029),
    [anon_sym_class] = ACTIONS(5029),
    [anon_sym_struct] = ACTIONS(5029),
    [anon_sym_union] = ACTIONS(5029),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5029),
    [anon_sym_decltype] = ACTIONS(5029),
    [sym_virtual] = ACTIONS(5029),
    [anon_sym_explicit] = ACTIONS(5029),
    [anon_sym_typename] = ACTIONS(5029),
    [anon_sym_template] = ACTIONS(5029),
    [anon_sym_operator] = ACTIONS(5029),
    [anon_sym_friend] = ACTIONS(5029),
    [anon_sym_public] = ACTIONS(5029),
    [anon_sym_private] = ACTIONS(5029),
    [anon_sym_protected] = ACTIONS(5029),
    [anon_sym_using] = ACTIONS(5029),
    [anon_sym_static_assert] = ACTIONS(5029),
    [anon_sym_precise] = ACTIONS(5029),
    [anon_sym_shared] = ACTIONS(5029),
    [anon_sym_groupshared] = ACTIONS(5029),
    [anon_sym_uniform] = ACTIONS(5029),
    [anon_sym_row_major] = ACTIONS(5029),
    [anon_sym_column_major] = ACTIONS(5029),
    [anon_sym_globallycoherent] = ACTIONS(5029),
    [anon_sym_centroid] = ACTIONS(5029),
    [anon_sym_noperspective] = ACTIONS(5029),
    [anon_sym_nointerpolation] = ACTIONS(5029),
    [anon_sym_sample] = ACTIONS(5029),
    [anon_sym_linear] = ACTIONS(5029),
    [anon_sym_snorm] = ACTIONS(5029),
    [anon_sym_unorm] = ACTIONS(5029),
    [anon_sym_point] = ACTIONS(5029),
    [anon_sym_line] = ACTIONS(5029),
    [anon_sym_triangleadj] = ACTIONS(5029),
    [anon_sym_lineadj] = ACTIONS(5029),
    [anon_sym_triangle] = ACTIONS(5029),
  },
  [2017] = {
    [sym_identifier] = ACTIONS(5029),
    [aux_sym_preproc_def_token1] = ACTIONS(5029),
    [aux_sym_preproc_if_token1] = ACTIONS(5029),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5029),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5029),
    [sym_preproc_directive] = ACTIONS(5029),
    [anon_sym_LPAREN2] = ACTIONS(5031),
    [anon_sym_TILDE] = ACTIONS(5031),
    [anon_sym_STAR] = ACTIONS(5031),
    [anon_sym_AMP_AMP] = ACTIONS(5031),
    [anon_sym_AMP] = ACTIONS(5029),
    [anon_sym___extension__] = ACTIONS(5029),
    [anon_sym_typedef] = ACTIONS(5029),
    [anon_sym_in] = ACTIONS(5029),
    [anon_sym_out] = ACTIONS(5029),
    [anon_sym_inout] = ACTIONS(5029),
    [anon_sym_extern] = ACTIONS(5029),
    [anon_sym___attribute__] = ACTIONS(5029),
    [anon_sym_COLON_COLON] = ACTIONS(5031),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5031),
    [anon_sym___declspec] = ACTIONS(5029),
    [anon_sym___based] = ACTIONS(5029),
    [anon_sym_RBRACE] = ACTIONS(5031),
    [anon_sym_signed] = ACTIONS(5029),
    [anon_sym_unsigned] = ACTIONS(5029),
    [anon_sym_long] = ACTIONS(5029),
    [anon_sym_short] = ACTIONS(5029),
    [anon_sym_LBRACK] = ACTIONS(5029),
    [anon_sym_static] = ACTIONS(5029),
    [anon_sym_register] = ACTIONS(5029),
    [anon_sym_inline] = ACTIONS(5029),
    [anon_sym___inline] = ACTIONS(5029),
    [anon_sym___inline__] = ACTIONS(5029),
    [anon_sym___forceinline] = ACTIONS(5029),
    [anon_sym_thread_local] = ACTIONS(5029),
    [anon_sym___thread] = ACTIONS(5029),
    [anon_sym_const] = ACTIONS(5029),
    [anon_sym_constexpr] = ACTIONS(5029),
    [anon_sym_volatile] = ACTIONS(5029),
    [anon_sym_restrict] = ACTIONS(5029),
    [anon_sym___restrict__] = ACTIONS(5029),
    [anon_sym__Atomic] = ACTIONS(5029),
    [anon_sym__Noreturn] = ACTIONS(5029),
    [anon_sym_noreturn] = ACTIONS(5029),
    [anon_sym_mutable] = ACTIONS(5029),
    [anon_sym_constinit] = ACTIONS(5029),
    [anon_sym_consteval] = ACTIONS(5029),
    [anon_sym_alignas] = ACTIONS(5029),
    [anon_sym__Alignas] = ACTIONS(5029),
    [sym_primitive_type] = ACTIONS(5029),
    [anon_sym_enum] = ACTIONS(5029),
    [anon_sym_class] = ACTIONS(5029),
    [anon_sym_struct] = ACTIONS(5029),
    [anon_sym_union] = ACTIONS(5029),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5029),
    [anon_sym_decltype] = ACTIONS(5029),
    [sym_virtual] = ACTIONS(5029),
    [anon_sym_explicit] = ACTIONS(5029),
    [anon_sym_typename] = ACTIONS(5029),
    [anon_sym_template] = ACTIONS(5029),
    [anon_sym_operator] = ACTIONS(5029),
    [anon_sym_friend] = ACTIONS(5029),
    [anon_sym_public] = ACTIONS(5029),
    [anon_sym_private] = ACTIONS(5029),
    [anon_sym_protected] = ACTIONS(5029),
    [anon_sym_using] = ACTIONS(5029),
    [anon_sym_static_assert] = ACTIONS(5029),
    [anon_sym_precise] = ACTIONS(5029),
    [anon_sym_shared] = ACTIONS(5029),
    [anon_sym_groupshared] = ACTIONS(5029),
    [anon_sym_uniform] = ACTIONS(5029),
    [anon_sym_row_major] = ACTIONS(5029),
    [anon_sym_column_major] = ACTIONS(5029),
    [anon_sym_globallycoherent] = ACTIONS(5029),
    [anon_sym_centroid] = ACTIONS(5029),
    [anon_sym_noperspective] = ACTIONS(5029),
    [anon_sym_nointerpolation] = ACTIONS(5029),
    [anon_sym_sample] = ACTIONS(5029),
    [anon_sym_linear] = ACTIONS(5029),
    [anon_sym_snorm] = ACTIONS(5029),
    [anon_sym_unorm] = ACTIONS(5029),
    [anon_sym_point] = ACTIONS(5029),
    [anon_sym_line] = ACTIONS(5029),
    [anon_sym_triangleadj] = ACTIONS(5029),
    [anon_sym_lineadj] = ACTIONS(5029),
    [anon_sym_triangle] = ACTIONS(5029),
  },
  [2018] = {
    [sym_identifier] = ACTIONS(5029),
    [aux_sym_preproc_def_token1] = ACTIONS(5029),
    [aux_sym_preproc_if_token1] = ACTIONS(5029),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5029),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5029),
    [sym_preproc_directive] = ACTIONS(5029),
    [anon_sym_LPAREN2] = ACTIONS(5031),
    [anon_sym_TILDE] = ACTIONS(5031),
    [anon_sym_STAR] = ACTIONS(5031),
    [anon_sym_AMP_AMP] = ACTIONS(5031),
    [anon_sym_AMP] = ACTIONS(5029),
    [anon_sym___extension__] = ACTIONS(5029),
    [anon_sym_typedef] = ACTIONS(5029),
    [anon_sym_in] = ACTIONS(5029),
    [anon_sym_out] = ACTIONS(5029),
    [anon_sym_inout] = ACTIONS(5029),
    [anon_sym_extern] = ACTIONS(5029),
    [anon_sym___attribute__] = ACTIONS(5029),
    [anon_sym_COLON_COLON] = ACTIONS(5031),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5031),
    [anon_sym___declspec] = ACTIONS(5029),
    [anon_sym___based] = ACTIONS(5029),
    [anon_sym_RBRACE] = ACTIONS(5031),
    [anon_sym_signed] = ACTIONS(5029),
    [anon_sym_unsigned] = ACTIONS(5029),
    [anon_sym_long] = ACTIONS(5029),
    [anon_sym_short] = ACTIONS(5029),
    [anon_sym_LBRACK] = ACTIONS(5029),
    [anon_sym_static] = ACTIONS(5029),
    [anon_sym_register] = ACTIONS(5029),
    [anon_sym_inline] = ACTIONS(5029),
    [anon_sym___inline] = ACTIONS(5029),
    [anon_sym___inline__] = ACTIONS(5029),
    [anon_sym___forceinline] = ACTIONS(5029),
    [anon_sym_thread_local] = ACTIONS(5029),
    [anon_sym___thread] = ACTIONS(5029),
    [anon_sym_const] = ACTIONS(5029),
    [anon_sym_constexpr] = ACTIONS(5029),
    [anon_sym_volatile] = ACTIONS(5029),
    [anon_sym_restrict] = ACTIONS(5029),
    [anon_sym___restrict__] = ACTIONS(5029),
    [anon_sym__Atomic] = ACTIONS(5029),
    [anon_sym__Noreturn] = ACTIONS(5029),
    [anon_sym_noreturn] = ACTIONS(5029),
    [anon_sym_mutable] = ACTIONS(5029),
    [anon_sym_constinit] = ACTIONS(5029),
    [anon_sym_consteval] = ACTIONS(5029),
    [anon_sym_alignas] = ACTIONS(5029),
    [anon_sym__Alignas] = ACTIONS(5029),
    [sym_primitive_type] = ACTIONS(5029),
    [anon_sym_enum] = ACTIONS(5029),
    [anon_sym_class] = ACTIONS(5029),
    [anon_sym_struct] = ACTIONS(5029),
    [anon_sym_union] = ACTIONS(5029),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5029),
    [anon_sym_decltype] = ACTIONS(5029),
    [sym_virtual] = ACTIONS(5029),
    [anon_sym_explicit] = ACTIONS(5029),
    [anon_sym_typename] = ACTIONS(5029),
    [anon_sym_template] = ACTIONS(5029),
    [anon_sym_operator] = ACTIONS(5029),
    [anon_sym_friend] = ACTIONS(5029),
    [anon_sym_public] = ACTIONS(5029),
    [anon_sym_private] = ACTIONS(5029),
    [anon_sym_protected] = ACTIONS(5029),
    [anon_sym_using] = ACTIONS(5029),
    [anon_sym_static_assert] = ACTIONS(5029),
    [anon_sym_precise] = ACTIONS(5029),
    [anon_sym_shared] = ACTIONS(5029),
    [anon_sym_groupshared] = ACTIONS(5029),
    [anon_sym_uniform] = ACTIONS(5029),
    [anon_sym_row_major] = ACTIONS(5029),
    [anon_sym_column_major] = ACTIONS(5029),
    [anon_sym_globallycoherent] = ACTIONS(5029),
    [anon_sym_centroid] = ACTIONS(5029),
    [anon_sym_noperspective] = ACTIONS(5029),
    [anon_sym_nointerpolation] = ACTIONS(5029),
    [anon_sym_sample] = ACTIONS(5029),
    [anon_sym_linear] = ACTIONS(5029),
    [anon_sym_snorm] = ACTIONS(5029),
    [anon_sym_unorm] = ACTIONS(5029),
    [anon_sym_point] = ACTIONS(5029),
    [anon_sym_line] = ACTIONS(5029),
    [anon_sym_triangleadj] = ACTIONS(5029),
    [anon_sym_lineadj] = ACTIONS(5029),
    [anon_sym_triangle] = ACTIONS(5029),
  },
  [2019] = {
    [sym_identifier] = ACTIONS(5109),
    [aux_sym_preproc_def_token1] = ACTIONS(5109),
    [aux_sym_preproc_if_token1] = ACTIONS(5109),
    [aux_sym_preproc_if_token2] = ACTIONS(5109),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5109),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5109),
    [sym_preproc_directive] = ACTIONS(5109),
    [anon_sym_LPAREN2] = ACTIONS(5111),
    [anon_sym_TILDE] = ACTIONS(5111),
    [anon_sym_STAR] = ACTIONS(5111),
    [anon_sym_AMP_AMP] = ACTIONS(5111),
    [anon_sym_AMP] = ACTIONS(5109),
    [anon_sym___extension__] = ACTIONS(5109),
    [anon_sym_typedef] = ACTIONS(5109),
    [anon_sym_in] = ACTIONS(5109),
    [anon_sym_out] = ACTIONS(5109),
    [anon_sym_inout] = ACTIONS(5109),
    [anon_sym_extern] = ACTIONS(5109),
    [anon_sym___attribute__] = ACTIONS(5109),
    [anon_sym_COLON_COLON] = ACTIONS(5111),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5111),
    [anon_sym___declspec] = ACTIONS(5109),
    [anon_sym___based] = ACTIONS(5109),
    [anon_sym_signed] = ACTIONS(5109),
    [anon_sym_unsigned] = ACTIONS(5109),
    [anon_sym_long] = ACTIONS(5109),
    [anon_sym_short] = ACTIONS(5109),
    [anon_sym_LBRACK] = ACTIONS(5109),
    [anon_sym_static] = ACTIONS(5109),
    [anon_sym_register] = ACTIONS(5109),
    [anon_sym_inline] = ACTIONS(5109),
    [anon_sym___inline] = ACTIONS(5109),
    [anon_sym___inline__] = ACTIONS(5109),
    [anon_sym___forceinline] = ACTIONS(5109),
    [anon_sym_thread_local] = ACTIONS(5109),
    [anon_sym___thread] = ACTIONS(5109),
    [anon_sym_const] = ACTIONS(5109),
    [anon_sym_constexpr] = ACTIONS(5109),
    [anon_sym_volatile] = ACTIONS(5109),
    [anon_sym_restrict] = ACTIONS(5109),
    [anon_sym___restrict__] = ACTIONS(5109),
    [anon_sym__Atomic] = ACTIONS(5109),
    [anon_sym__Noreturn] = ACTIONS(5109),
    [anon_sym_noreturn] = ACTIONS(5109),
    [anon_sym_mutable] = ACTIONS(5109),
    [anon_sym_constinit] = ACTIONS(5109),
    [anon_sym_consteval] = ACTIONS(5109),
    [anon_sym_alignas] = ACTIONS(5109),
    [anon_sym__Alignas] = ACTIONS(5109),
    [sym_primitive_type] = ACTIONS(5109),
    [anon_sym_enum] = ACTIONS(5109),
    [anon_sym_class] = ACTIONS(5109),
    [anon_sym_struct] = ACTIONS(5109),
    [anon_sym_union] = ACTIONS(5109),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5109),
    [anon_sym_decltype] = ACTIONS(5109),
    [sym_virtual] = ACTIONS(5109),
    [anon_sym_explicit] = ACTIONS(5109),
    [anon_sym_typename] = ACTIONS(5109),
    [anon_sym_template] = ACTIONS(5109),
    [anon_sym_operator] = ACTIONS(5109),
    [anon_sym_friend] = ACTIONS(5109),
    [anon_sym_public] = ACTIONS(5109),
    [anon_sym_private] = ACTIONS(5109),
    [anon_sym_protected] = ACTIONS(5109),
    [anon_sym_using] = ACTIONS(5109),
    [anon_sym_static_assert] = ACTIONS(5109),
    [anon_sym_precise] = ACTIONS(5109),
    [anon_sym_shared] = ACTIONS(5109),
    [anon_sym_groupshared] = ACTIONS(5109),
    [anon_sym_uniform] = ACTIONS(5109),
    [anon_sym_row_major] = ACTIONS(5109),
    [anon_sym_column_major] = ACTIONS(5109),
    [anon_sym_globallycoherent] = ACTIONS(5109),
    [anon_sym_centroid] = ACTIONS(5109),
    [anon_sym_noperspective] = ACTIONS(5109),
    [anon_sym_nointerpolation] = ACTIONS(5109),
    [anon_sym_sample] = ACTIONS(5109),
    [anon_sym_linear] = ACTIONS(5109),
    [anon_sym_snorm] = ACTIONS(5109),
    [anon_sym_unorm] = ACTIONS(5109),
    [anon_sym_point] = ACTIONS(5109),
    [anon_sym_line] = ACTIONS(5109),
    [anon_sym_triangleadj] = ACTIONS(5109),
    [anon_sym_lineadj] = ACTIONS(5109),
    [anon_sym_triangle] = ACTIONS(5109),
  },
  [2020] = {
    [sym_identifier] = ACTIONS(5105),
    [aux_sym_preproc_def_token1] = ACTIONS(5105),
    [aux_sym_preproc_if_token1] = ACTIONS(5105),
    [aux_sym_preproc_if_token2] = ACTIONS(5105),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5105),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5105),
    [sym_preproc_directive] = ACTIONS(5105),
    [anon_sym_LPAREN2] = ACTIONS(5107),
    [anon_sym_TILDE] = ACTIONS(5107),
    [anon_sym_STAR] = ACTIONS(5107),
    [anon_sym_AMP_AMP] = ACTIONS(5107),
    [anon_sym_AMP] = ACTIONS(5105),
    [anon_sym___extension__] = ACTIONS(5105),
    [anon_sym_typedef] = ACTIONS(5105),
    [anon_sym_in] = ACTIONS(5105),
    [anon_sym_out] = ACTIONS(5105),
    [anon_sym_inout] = ACTIONS(5105),
    [anon_sym_extern] = ACTIONS(5105),
    [anon_sym___attribute__] = ACTIONS(5105),
    [anon_sym_COLON_COLON] = ACTIONS(5107),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5107),
    [anon_sym___declspec] = ACTIONS(5105),
    [anon_sym___based] = ACTIONS(5105),
    [anon_sym_signed] = ACTIONS(5105),
    [anon_sym_unsigned] = ACTIONS(5105),
    [anon_sym_long] = ACTIONS(5105),
    [anon_sym_short] = ACTIONS(5105),
    [anon_sym_LBRACK] = ACTIONS(5105),
    [anon_sym_static] = ACTIONS(5105),
    [anon_sym_register] = ACTIONS(5105),
    [anon_sym_inline] = ACTIONS(5105),
    [anon_sym___inline] = ACTIONS(5105),
    [anon_sym___inline__] = ACTIONS(5105),
    [anon_sym___forceinline] = ACTIONS(5105),
    [anon_sym_thread_local] = ACTIONS(5105),
    [anon_sym___thread] = ACTIONS(5105),
    [anon_sym_const] = ACTIONS(5105),
    [anon_sym_constexpr] = ACTIONS(5105),
    [anon_sym_volatile] = ACTIONS(5105),
    [anon_sym_restrict] = ACTIONS(5105),
    [anon_sym___restrict__] = ACTIONS(5105),
    [anon_sym__Atomic] = ACTIONS(5105),
    [anon_sym__Noreturn] = ACTIONS(5105),
    [anon_sym_noreturn] = ACTIONS(5105),
    [anon_sym_mutable] = ACTIONS(5105),
    [anon_sym_constinit] = ACTIONS(5105),
    [anon_sym_consteval] = ACTIONS(5105),
    [anon_sym_alignas] = ACTIONS(5105),
    [anon_sym__Alignas] = ACTIONS(5105),
    [sym_primitive_type] = ACTIONS(5105),
    [anon_sym_enum] = ACTIONS(5105),
    [anon_sym_class] = ACTIONS(5105),
    [anon_sym_struct] = ACTIONS(5105),
    [anon_sym_union] = ACTIONS(5105),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5105),
    [anon_sym_decltype] = ACTIONS(5105),
    [sym_virtual] = ACTIONS(5105),
    [anon_sym_explicit] = ACTIONS(5105),
    [anon_sym_typename] = ACTIONS(5105),
    [anon_sym_template] = ACTIONS(5105),
    [anon_sym_operator] = ACTIONS(5105),
    [anon_sym_friend] = ACTIONS(5105),
    [anon_sym_public] = ACTIONS(5105),
    [anon_sym_private] = ACTIONS(5105),
    [anon_sym_protected] = ACTIONS(5105),
    [anon_sym_using] = ACTIONS(5105),
    [anon_sym_static_assert] = ACTIONS(5105),
    [anon_sym_precise] = ACTIONS(5105),
    [anon_sym_shared] = ACTIONS(5105),
    [anon_sym_groupshared] = ACTIONS(5105),
    [anon_sym_uniform] = ACTIONS(5105),
    [anon_sym_row_major] = ACTIONS(5105),
    [anon_sym_column_major] = ACTIONS(5105),
    [anon_sym_globallycoherent] = ACTIONS(5105),
    [anon_sym_centroid] = ACTIONS(5105),
    [anon_sym_noperspective] = ACTIONS(5105),
    [anon_sym_nointerpolation] = ACTIONS(5105),
    [anon_sym_sample] = ACTIONS(5105),
    [anon_sym_linear] = ACTIONS(5105),
    [anon_sym_snorm] = ACTIONS(5105),
    [anon_sym_unorm] = ACTIONS(5105),
    [anon_sym_point] = ACTIONS(5105),
    [anon_sym_line] = ACTIONS(5105),
    [anon_sym_triangleadj] = ACTIONS(5105),
    [anon_sym_lineadj] = ACTIONS(5105),
    [anon_sym_triangle] = ACTIONS(5105),
  },
  [2021] = {
    [sym_identifier] = ACTIONS(5021),
    [aux_sym_preproc_def_token1] = ACTIONS(5021),
    [aux_sym_preproc_if_token1] = ACTIONS(5021),
    [aux_sym_preproc_if_token2] = ACTIONS(5021),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5021),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5021),
    [sym_preproc_directive] = ACTIONS(5021),
    [anon_sym_LPAREN2] = ACTIONS(5023),
    [anon_sym_TILDE] = ACTIONS(5023),
    [anon_sym_STAR] = ACTIONS(5023),
    [anon_sym_AMP_AMP] = ACTIONS(5023),
    [anon_sym_AMP] = ACTIONS(5021),
    [anon_sym___extension__] = ACTIONS(5021),
    [anon_sym_typedef] = ACTIONS(5021),
    [anon_sym_in] = ACTIONS(5021),
    [anon_sym_out] = ACTIONS(5021),
    [anon_sym_inout] = ACTIONS(5021),
    [anon_sym_extern] = ACTIONS(5021),
    [anon_sym___attribute__] = ACTIONS(5021),
    [anon_sym_COLON_COLON] = ACTIONS(5023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5023),
    [anon_sym___declspec] = ACTIONS(5021),
    [anon_sym___based] = ACTIONS(5021),
    [anon_sym_signed] = ACTIONS(5021),
    [anon_sym_unsigned] = ACTIONS(5021),
    [anon_sym_long] = ACTIONS(5021),
    [anon_sym_short] = ACTIONS(5021),
    [anon_sym_LBRACK] = ACTIONS(5021),
    [anon_sym_static] = ACTIONS(5021),
    [anon_sym_register] = ACTIONS(5021),
    [anon_sym_inline] = ACTIONS(5021),
    [anon_sym___inline] = ACTIONS(5021),
    [anon_sym___inline__] = ACTIONS(5021),
    [anon_sym___forceinline] = ACTIONS(5021),
    [anon_sym_thread_local] = ACTIONS(5021),
    [anon_sym___thread] = ACTIONS(5021),
    [anon_sym_const] = ACTIONS(5021),
    [anon_sym_constexpr] = ACTIONS(5021),
    [anon_sym_volatile] = ACTIONS(5021),
    [anon_sym_restrict] = ACTIONS(5021),
    [anon_sym___restrict__] = ACTIONS(5021),
    [anon_sym__Atomic] = ACTIONS(5021),
    [anon_sym__Noreturn] = ACTIONS(5021),
    [anon_sym_noreturn] = ACTIONS(5021),
    [anon_sym_mutable] = ACTIONS(5021),
    [anon_sym_constinit] = ACTIONS(5021),
    [anon_sym_consteval] = ACTIONS(5021),
    [anon_sym_alignas] = ACTIONS(5021),
    [anon_sym__Alignas] = ACTIONS(5021),
    [sym_primitive_type] = ACTIONS(5021),
    [anon_sym_enum] = ACTIONS(5021),
    [anon_sym_class] = ACTIONS(5021),
    [anon_sym_struct] = ACTIONS(5021),
    [anon_sym_union] = ACTIONS(5021),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5021),
    [anon_sym_decltype] = ACTIONS(5021),
    [sym_virtual] = ACTIONS(5021),
    [anon_sym_explicit] = ACTIONS(5021),
    [anon_sym_typename] = ACTIONS(5021),
    [anon_sym_template] = ACTIONS(5021),
    [anon_sym_operator] = ACTIONS(5021),
    [anon_sym_friend] = ACTIONS(5021),
    [anon_sym_public] = ACTIONS(5021),
    [anon_sym_private] = ACTIONS(5021),
    [anon_sym_protected] = ACTIONS(5021),
    [anon_sym_using] = ACTIONS(5021),
    [anon_sym_static_assert] = ACTIONS(5021),
    [anon_sym_precise] = ACTIONS(5021),
    [anon_sym_shared] = ACTIONS(5021),
    [anon_sym_groupshared] = ACTIONS(5021),
    [anon_sym_uniform] = ACTIONS(5021),
    [anon_sym_row_major] = ACTIONS(5021),
    [anon_sym_column_major] = ACTIONS(5021),
    [anon_sym_globallycoherent] = ACTIONS(5021),
    [anon_sym_centroid] = ACTIONS(5021),
    [anon_sym_noperspective] = ACTIONS(5021),
    [anon_sym_nointerpolation] = ACTIONS(5021),
    [anon_sym_sample] = ACTIONS(5021),
    [anon_sym_linear] = ACTIONS(5021),
    [anon_sym_snorm] = ACTIONS(5021),
    [anon_sym_unorm] = ACTIONS(5021),
    [anon_sym_point] = ACTIONS(5021),
    [anon_sym_line] = ACTIONS(5021),
    [anon_sym_triangleadj] = ACTIONS(5021),
    [anon_sym_lineadj] = ACTIONS(5021),
    [anon_sym_triangle] = ACTIONS(5021),
  },
  [2022] = {
    [sym_identifier] = ACTIONS(5025),
    [aux_sym_preproc_def_token1] = ACTIONS(5025),
    [aux_sym_preproc_if_token1] = ACTIONS(5025),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5025),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5025),
    [sym_preproc_directive] = ACTIONS(5025),
    [anon_sym_LPAREN2] = ACTIONS(5027),
    [anon_sym_TILDE] = ACTIONS(5027),
    [anon_sym_STAR] = ACTIONS(5027),
    [anon_sym_AMP_AMP] = ACTIONS(5027),
    [anon_sym_AMP] = ACTIONS(5025),
    [anon_sym___extension__] = ACTIONS(5025),
    [anon_sym_typedef] = ACTIONS(5025),
    [anon_sym_in] = ACTIONS(5025),
    [anon_sym_out] = ACTIONS(5025),
    [anon_sym_inout] = ACTIONS(5025),
    [anon_sym_extern] = ACTIONS(5025),
    [anon_sym___attribute__] = ACTIONS(5025),
    [anon_sym_COLON_COLON] = ACTIONS(5027),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5027),
    [anon_sym___declspec] = ACTIONS(5025),
    [anon_sym___based] = ACTIONS(5025),
    [anon_sym_RBRACE] = ACTIONS(5027),
    [anon_sym_signed] = ACTIONS(5025),
    [anon_sym_unsigned] = ACTIONS(5025),
    [anon_sym_long] = ACTIONS(5025),
    [anon_sym_short] = ACTIONS(5025),
    [anon_sym_LBRACK] = ACTIONS(5025),
    [anon_sym_static] = ACTIONS(5025),
    [anon_sym_register] = ACTIONS(5025),
    [anon_sym_inline] = ACTIONS(5025),
    [anon_sym___inline] = ACTIONS(5025),
    [anon_sym___inline__] = ACTIONS(5025),
    [anon_sym___forceinline] = ACTIONS(5025),
    [anon_sym_thread_local] = ACTIONS(5025),
    [anon_sym___thread] = ACTIONS(5025),
    [anon_sym_const] = ACTIONS(5025),
    [anon_sym_constexpr] = ACTIONS(5025),
    [anon_sym_volatile] = ACTIONS(5025),
    [anon_sym_restrict] = ACTIONS(5025),
    [anon_sym___restrict__] = ACTIONS(5025),
    [anon_sym__Atomic] = ACTIONS(5025),
    [anon_sym__Noreturn] = ACTIONS(5025),
    [anon_sym_noreturn] = ACTIONS(5025),
    [anon_sym_mutable] = ACTIONS(5025),
    [anon_sym_constinit] = ACTIONS(5025),
    [anon_sym_consteval] = ACTIONS(5025),
    [anon_sym_alignas] = ACTIONS(5025),
    [anon_sym__Alignas] = ACTIONS(5025),
    [sym_primitive_type] = ACTIONS(5025),
    [anon_sym_enum] = ACTIONS(5025),
    [anon_sym_class] = ACTIONS(5025),
    [anon_sym_struct] = ACTIONS(5025),
    [anon_sym_union] = ACTIONS(5025),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5025),
    [anon_sym_decltype] = ACTIONS(5025),
    [sym_virtual] = ACTIONS(5025),
    [anon_sym_explicit] = ACTIONS(5025),
    [anon_sym_typename] = ACTIONS(5025),
    [anon_sym_template] = ACTIONS(5025),
    [anon_sym_operator] = ACTIONS(5025),
    [anon_sym_friend] = ACTIONS(5025),
    [anon_sym_public] = ACTIONS(5025),
    [anon_sym_private] = ACTIONS(5025),
    [anon_sym_protected] = ACTIONS(5025),
    [anon_sym_using] = ACTIONS(5025),
    [anon_sym_static_assert] = ACTIONS(5025),
    [anon_sym_precise] = ACTIONS(5025),
    [anon_sym_shared] = ACTIONS(5025),
    [anon_sym_groupshared] = ACTIONS(5025),
    [anon_sym_uniform] = ACTIONS(5025),
    [anon_sym_row_major] = ACTIONS(5025),
    [anon_sym_column_major] = ACTIONS(5025),
    [anon_sym_globallycoherent] = ACTIONS(5025),
    [anon_sym_centroid] = ACTIONS(5025),
    [anon_sym_noperspective] = ACTIONS(5025),
    [anon_sym_nointerpolation] = ACTIONS(5025),
    [anon_sym_sample] = ACTIONS(5025),
    [anon_sym_linear] = ACTIONS(5025),
    [anon_sym_snorm] = ACTIONS(5025),
    [anon_sym_unorm] = ACTIONS(5025),
    [anon_sym_point] = ACTIONS(5025),
    [anon_sym_line] = ACTIONS(5025),
    [anon_sym_triangleadj] = ACTIONS(5025),
    [anon_sym_lineadj] = ACTIONS(5025),
    [anon_sym_triangle] = ACTIONS(5025),
  },
  [2023] = {
    [sym_identifier] = ACTIONS(2561),
    [aux_sym_preproc_def_token1] = ACTIONS(2561),
    [aux_sym_preproc_if_token1] = ACTIONS(2561),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2561),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2561),
    [sym_preproc_directive] = ACTIONS(2561),
    [anon_sym_LPAREN2] = ACTIONS(2563),
    [anon_sym_TILDE] = ACTIONS(2563),
    [anon_sym_STAR] = ACTIONS(2563),
    [anon_sym_AMP_AMP] = ACTIONS(2563),
    [anon_sym_AMP] = ACTIONS(2561),
    [anon_sym___extension__] = ACTIONS(2561),
    [anon_sym_typedef] = ACTIONS(2561),
    [anon_sym_in] = ACTIONS(2561),
    [anon_sym_out] = ACTIONS(2561),
    [anon_sym_inout] = ACTIONS(2561),
    [anon_sym_extern] = ACTIONS(2561),
    [anon_sym___attribute__] = ACTIONS(2561),
    [anon_sym_COLON_COLON] = ACTIONS(2563),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2563),
    [anon_sym___declspec] = ACTIONS(2561),
    [anon_sym___based] = ACTIONS(2561),
    [anon_sym_RBRACE] = ACTIONS(2563),
    [anon_sym_signed] = ACTIONS(2561),
    [anon_sym_unsigned] = ACTIONS(2561),
    [anon_sym_long] = ACTIONS(2561),
    [anon_sym_short] = ACTIONS(2561),
    [anon_sym_LBRACK] = ACTIONS(2561),
    [anon_sym_static] = ACTIONS(2561),
    [anon_sym_register] = ACTIONS(2561),
    [anon_sym_inline] = ACTIONS(2561),
    [anon_sym___inline] = ACTIONS(2561),
    [anon_sym___inline__] = ACTIONS(2561),
    [anon_sym___forceinline] = ACTIONS(2561),
    [anon_sym_thread_local] = ACTIONS(2561),
    [anon_sym___thread] = ACTIONS(2561),
    [anon_sym_const] = ACTIONS(2561),
    [anon_sym_constexpr] = ACTIONS(2561),
    [anon_sym_volatile] = ACTIONS(2561),
    [anon_sym_restrict] = ACTIONS(2561),
    [anon_sym___restrict__] = ACTIONS(2561),
    [anon_sym__Atomic] = ACTIONS(2561),
    [anon_sym__Noreturn] = ACTIONS(2561),
    [anon_sym_noreturn] = ACTIONS(2561),
    [anon_sym_mutable] = ACTIONS(2561),
    [anon_sym_constinit] = ACTIONS(2561),
    [anon_sym_consteval] = ACTIONS(2561),
    [anon_sym_alignas] = ACTIONS(2561),
    [anon_sym__Alignas] = ACTIONS(2561),
    [sym_primitive_type] = ACTIONS(2561),
    [anon_sym_enum] = ACTIONS(2561),
    [anon_sym_class] = ACTIONS(2561),
    [anon_sym_struct] = ACTIONS(2561),
    [anon_sym_union] = ACTIONS(2561),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2561),
    [anon_sym_decltype] = ACTIONS(2561),
    [sym_virtual] = ACTIONS(2561),
    [anon_sym_explicit] = ACTIONS(2561),
    [anon_sym_typename] = ACTIONS(2561),
    [anon_sym_template] = ACTIONS(2561),
    [anon_sym_operator] = ACTIONS(2561),
    [anon_sym_friend] = ACTIONS(2561),
    [anon_sym_public] = ACTIONS(2561),
    [anon_sym_private] = ACTIONS(2561),
    [anon_sym_protected] = ACTIONS(2561),
    [anon_sym_using] = ACTIONS(2561),
    [anon_sym_static_assert] = ACTIONS(2561),
    [anon_sym_precise] = ACTIONS(2561),
    [anon_sym_shared] = ACTIONS(2561),
    [anon_sym_groupshared] = ACTIONS(2561),
    [anon_sym_uniform] = ACTIONS(2561),
    [anon_sym_row_major] = ACTIONS(2561),
    [anon_sym_column_major] = ACTIONS(2561),
    [anon_sym_globallycoherent] = ACTIONS(2561),
    [anon_sym_centroid] = ACTIONS(2561),
    [anon_sym_noperspective] = ACTIONS(2561),
    [anon_sym_nointerpolation] = ACTIONS(2561),
    [anon_sym_sample] = ACTIONS(2561),
    [anon_sym_linear] = ACTIONS(2561),
    [anon_sym_snorm] = ACTIONS(2561),
    [anon_sym_unorm] = ACTIONS(2561),
    [anon_sym_point] = ACTIONS(2561),
    [anon_sym_line] = ACTIONS(2561),
    [anon_sym_triangleadj] = ACTIONS(2561),
    [anon_sym_lineadj] = ACTIONS(2561),
    [anon_sym_triangle] = ACTIONS(2561),
  },
  [2024] = {
    [sym_identifier] = ACTIONS(2316),
    [aux_sym_preproc_def_token1] = ACTIONS(2316),
    [aux_sym_preproc_if_token1] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2316),
    [sym_preproc_directive] = ACTIONS(2316),
    [anon_sym_LPAREN2] = ACTIONS(2318),
    [anon_sym_TILDE] = ACTIONS(2318),
    [anon_sym_STAR] = ACTIONS(2318),
    [anon_sym_AMP_AMP] = ACTIONS(2318),
    [anon_sym_AMP] = ACTIONS(2316),
    [anon_sym___extension__] = ACTIONS(2316),
    [anon_sym_typedef] = ACTIONS(2316),
    [anon_sym_in] = ACTIONS(2316),
    [anon_sym_out] = ACTIONS(2316),
    [anon_sym_inout] = ACTIONS(2316),
    [anon_sym_extern] = ACTIONS(2316),
    [anon_sym___attribute__] = ACTIONS(2316),
    [anon_sym_COLON_COLON] = ACTIONS(2318),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2318),
    [anon_sym___declspec] = ACTIONS(2316),
    [anon_sym___based] = ACTIONS(2316),
    [anon_sym_RBRACE] = ACTIONS(2318),
    [anon_sym_signed] = ACTIONS(2316),
    [anon_sym_unsigned] = ACTIONS(2316),
    [anon_sym_long] = ACTIONS(2316),
    [anon_sym_short] = ACTIONS(2316),
    [anon_sym_LBRACK] = ACTIONS(2316),
    [anon_sym_static] = ACTIONS(2316),
    [anon_sym_register] = ACTIONS(2316),
    [anon_sym_inline] = ACTIONS(2316),
    [anon_sym___inline] = ACTIONS(2316),
    [anon_sym___inline__] = ACTIONS(2316),
    [anon_sym___forceinline] = ACTIONS(2316),
    [anon_sym_thread_local] = ACTIONS(2316),
    [anon_sym___thread] = ACTIONS(2316),
    [anon_sym_const] = ACTIONS(2316),
    [anon_sym_constexpr] = ACTIONS(2316),
    [anon_sym_volatile] = ACTIONS(2316),
    [anon_sym_restrict] = ACTIONS(2316),
    [anon_sym___restrict__] = ACTIONS(2316),
    [anon_sym__Atomic] = ACTIONS(2316),
    [anon_sym__Noreturn] = ACTIONS(2316),
    [anon_sym_noreturn] = ACTIONS(2316),
    [anon_sym_mutable] = ACTIONS(2316),
    [anon_sym_constinit] = ACTIONS(2316),
    [anon_sym_consteval] = ACTIONS(2316),
    [anon_sym_alignas] = ACTIONS(2316),
    [anon_sym__Alignas] = ACTIONS(2316),
    [sym_primitive_type] = ACTIONS(2316),
    [anon_sym_enum] = ACTIONS(2316),
    [anon_sym_class] = ACTIONS(2316),
    [anon_sym_struct] = ACTIONS(2316),
    [anon_sym_union] = ACTIONS(2316),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2316),
    [anon_sym_decltype] = ACTIONS(2316),
    [sym_virtual] = ACTIONS(2316),
    [anon_sym_explicit] = ACTIONS(2316),
    [anon_sym_typename] = ACTIONS(2316),
    [anon_sym_template] = ACTIONS(2316),
    [anon_sym_operator] = ACTIONS(2316),
    [anon_sym_friend] = ACTIONS(2316),
    [anon_sym_public] = ACTIONS(2316),
    [anon_sym_private] = ACTIONS(2316),
    [anon_sym_protected] = ACTIONS(2316),
    [anon_sym_using] = ACTIONS(2316),
    [anon_sym_static_assert] = ACTIONS(2316),
    [anon_sym_precise] = ACTIONS(2316),
    [anon_sym_shared] = ACTIONS(2316),
    [anon_sym_groupshared] = ACTIONS(2316),
    [anon_sym_uniform] = ACTIONS(2316),
    [anon_sym_row_major] = ACTIONS(2316),
    [anon_sym_column_major] = ACTIONS(2316),
    [anon_sym_globallycoherent] = ACTIONS(2316),
    [anon_sym_centroid] = ACTIONS(2316),
    [anon_sym_noperspective] = ACTIONS(2316),
    [anon_sym_nointerpolation] = ACTIONS(2316),
    [anon_sym_sample] = ACTIONS(2316),
    [anon_sym_linear] = ACTIONS(2316),
    [anon_sym_snorm] = ACTIONS(2316),
    [anon_sym_unorm] = ACTIONS(2316),
    [anon_sym_point] = ACTIONS(2316),
    [anon_sym_line] = ACTIONS(2316),
    [anon_sym_triangleadj] = ACTIONS(2316),
    [anon_sym_lineadj] = ACTIONS(2316),
    [anon_sym_triangle] = ACTIONS(2316),
  },
  [2025] = {
    [sym_identifier] = ACTIONS(2248),
    [aux_sym_preproc_def_token1] = ACTIONS(2248),
    [aux_sym_preproc_if_token1] = ACTIONS(2248),
    [aux_sym_preproc_if_token2] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2248),
    [sym_preproc_directive] = ACTIONS(2248),
    [anon_sym_LPAREN2] = ACTIONS(2250),
    [anon_sym_TILDE] = ACTIONS(2250),
    [anon_sym_STAR] = ACTIONS(2250),
    [anon_sym_AMP_AMP] = ACTIONS(2250),
    [anon_sym_AMP] = ACTIONS(2248),
    [anon_sym___extension__] = ACTIONS(2248),
    [anon_sym_typedef] = ACTIONS(2248),
    [anon_sym_in] = ACTIONS(2248),
    [anon_sym_out] = ACTIONS(2248),
    [anon_sym_inout] = ACTIONS(2248),
    [anon_sym_extern] = ACTIONS(2248),
    [anon_sym___attribute__] = ACTIONS(2248),
    [anon_sym_COLON_COLON] = ACTIONS(2250),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2250),
    [anon_sym___declspec] = ACTIONS(2248),
    [anon_sym___based] = ACTIONS(2248),
    [anon_sym_signed] = ACTIONS(2248),
    [anon_sym_unsigned] = ACTIONS(2248),
    [anon_sym_long] = ACTIONS(2248),
    [anon_sym_short] = ACTIONS(2248),
    [anon_sym_LBRACK] = ACTIONS(2248),
    [anon_sym_static] = ACTIONS(2248),
    [anon_sym_register] = ACTIONS(2248),
    [anon_sym_inline] = ACTIONS(2248),
    [anon_sym___inline] = ACTIONS(2248),
    [anon_sym___inline__] = ACTIONS(2248),
    [anon_sym___forceinline] = ACTIONS(2248),
    [anon_sym_thread_local] = ACTIONS(2248),
    [anon_sym___thread] = ACTIONS(2248),
    [anon_sym_const] = ACTIONS(2248),
    [anon_sym_constexpr] = ACTIONS(2248),
    [anon_sym_volatile] = ACTIONS(2248),
    [anon_sym_restrict] = ACTIONS(2248),
    [anon_sym___restrict__] = ACTIONS(2248),
    [anon_sym__Atomic] = ACTIONS(2248),
    [anon_sym__Noreturn] = ACTIONS(2248),
    [anon_sym_noreturn] = ACTIONS(2248),
    [anon_sym_mutable] = ACTIONS(2248),
    [anon_sym_constinit] = ACTIONS(2248),
    [anon_sym_consteval] = ACTIONS(2248),
    [anon_sym_alignas] = ACTIONS(2248),
    [anon_sym__Alignas] = ACTIONS(2248),
    [sym_primitive_type] = ACTIONS(2248),
    [anon_sym_enum] = ACTIONS(2248),
    [anon_sym_class] = ACTIONS(2248),
    [anon_sym_struct] = ACTIONS(2248),
    [anon_sym_union] = ACTIONS(2248),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2248),
    [anon_sym_decltype] = ACTIONS(2248),
    [sym_virtual] = ACTIONS(2248),
    [anon_sym_explicit] = ACTIONS(2248),
    [anon_sym_typename] = ACTIONS(2248),
    [anon_sym_template] = ACTIONS(2248),
    [anon_sym_operator] = ACTIONS(2248),
    [anon_sym_friend] = ACTIONS(2248),
    [anon_sym_public] = ACTIONS(2248),
    [anon_sym_private] = ACTIONS(2248),
    [anon_sym_protected] = ACTIONS(2248),
    [anon_sym_using] = ACTIONS(2248),
    [anon_sym_static_assert] = ACTIONS(2248),
    [anon_sym_precise] = ACTIONS(2248),
    [anon_sym_shared] = ACTIONS(2248),
    [anon_sym_groupshared] = ACTIONS(2248),
    [anon_sym_uniform] = ACTIONS(2248),
    [anon_sym_row_major] = ACTIONS(2248),
    [anon_sym_column_major] = ACTIONS(2248),
    [anon_sym_globallycoherent] = ACTIONS(2248),
    [anon_sym_centroid] = ACTIONS(2248),
    [anon_sym_noperspective] = ACTIONS(2248),
    [anon_sym_nointerpolation] = ACTIONS(2248),
    [anon_sym_sample] = ACTIONS(2248),
    [anon_sym_linear] = ACTIONS(2248),
    [anon_sym_snorm] = ACTIONS(2248),
    [anon_sym_unorm] = ACTIONS(2248),
    [anon_sym_point] = ACTIONS(2248),
    [anon_sym_line] = ACTIONS(2248),
    [anon_sym_triangleadj] = ACTIONS(2248),
    [anon_sym_lineadj] = ACTIONS(2248),
    [anon_sym_triangle] = ACTIONS(2248),
  },
  [2026] = {
    [sym_identifier] = ACTIONS(5017),
    [aux_sym_preproc_def_token1] = ACTIONS(5017),
    [aux_sym_preproc_if_token1] = ACTIONS(5017),
    [aux_sym_preproc_if_token2] = ACTIONS(5017),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5017),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5017),
    [sym_preproc_directive] = ACTIONS(5017),
    [anon_sym_LPAREN2] = ACTIONS(5019),
    [anon_sym_TILDE] = ACTIONS(5019),
    [anon_sym_STAR] = ACTIONS(5019),
    [anon_sym_AMP_AMP] = ACTIONS(5019),
    [anon_sym_AMP] = ACTIONS(5017),
    [anon_sym___extension__] = ACTIONS(5017),
    [anon_sym_typedef] = ACTIONS(5017),
    [anon_sym_in] = ACTIONS(5017),
    [anon_sym_out] = ACTIONS(5017),
    [anon_sym_inout] = ACTIONS(5017),
    [anon_sym_extern] = ACTIONS(5017),
    [anon_sym___attribute__] = ACTIONS(5017),
    [anon_sym_COLON_COLON] = ACTIONS(5019),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5019),
    [anon_sym___declspec] = ACTIONS(5017),
    [anon_sym___based] = ACTIONS(5017),
    [anon_sym_signed] = ACTIONS(5017),
    [anon_sym_unsigned] = ACTIONS(5017),
    [anon_sym_long] = ACTIONS(5017),
    [anon_sym_short] = ACTIONS(5017),
    [anon_sym_LBRACK] = ACTIONS(5017),
    [anon_sym_static] = ACTIONS(5017),
    [anon_sym_register] = ACTIONS(5017),
    [anon_sym_inline] = ACTIONS(5017),
    [anon_sym___inline] = ACTIONS(5017),
    [anon_sym___inline__] = ACTIONS(5017),
    [anon_sym___forceinline] = ACTIONS(5017),
    [anon_sym_thread_local] = ACTIONS(5017),
    [anon_sym___thread] = ACTIONS(5017),
    [anon_sym_const] = ACTIONS(5017),
    [anon_sym_constexpr] = ACTIONS(5017),
    [anon_sym_volatile] = ACTIONS(5017),
    [anon_sym_restrict] = ACTIONS(5017),
    [anon_sym___restrict__] = ACTIONS(5017),
    [anon_sym__Atomic] = ACTIONS(5017),
    [anon_sym__Noreturn] = ACTIONS(5017),
    [anon_sym_noreturn] = ACTIONS(5017),
    [anon_sym_mutable] = ACTIONS(5017),
    [anon_sym_constinit] = ACTIONS(5017),
    [anon_sym_consteval] = ACTIONS(5017),
    [anon_sym_alignas] = ACTIONS(5017),
    [anon_sym__Alignas] = ACTIONS(5017),
    [sym_primitive_type] = ACTIONS(5017),
    [anon_sym_enum] = ACTIONS(5017),
    [anon_sym_class] = ACTIONS(5017),
    [anon_sym_struct] = ACTIONS(5017),
    [anon_sym_union] = ACTIONS(5017),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5017),
    [anon_sym_decltype] = ACTIONS(5017),
    [sym_virtual] = ACTIONS(5017),
    [anon_sym_explicit] = ACTIONS(5017),
    [anon_sym_typename] = ACTIONS(5017),
    [anon_sym_template] = ACTIONS(5017),
    [anon_sym_operator] = ACTIONS(5017),
    [anon_sym_friend] = ACTIONS(5017),
    [anon_sym_public] = ACTIONS(5017),
    [anon_sym_private] = ACTIONS(5017),
    [anon_sym_protected] = ACTIONS(5017),
    [anon_sym_using] = ACTIONS(5017),
    [anon_sym_static_assert] = ACTIONS(5017),
    [anon_sym_precise] = ACTIONS(5017),
    [anon_sym_shared] = ACTIONS(5017),
    [anon_sym_groupshared] = ACTIONS(5017),
    [anon_sym_uniform] = ACTIONS(5017),
    [anon_sym_row_major] = ACTIONS(5017),
    [anon_sym_column_major] = ACTIONS(5017),
    [anon_sym_globallycoherent] = ACTIONS(5017),
    [anon_sym_centroid] = ACTIONS(5017),
    [anon_sym_noperspective] = ACTIONS(5017),
    [anon_sym_nointerpolation] = ACTIONS(5017),
    [anon_sym_sample] = ACTIONS(5017),
    [anon_sym_linear] = ACTIONS(5017),
    [anon_sym_snorm] = ACTIONS(5017),
    [anon_sym_unorm] = ACTIONS(5017),
    [anon_sym_point] = ACTIONS(5017),
    [anon_sym_line] = ACTIONS(5017),
    [anon_sym_triangleadj] = ACTIONS(5017),
    [anon_sym_lineadj] = ACTIONS(5017),
    [anon_sym_triangle] = ACTIONS(5017),
  },
  [2027] = {
    [sym_identifier] = ACTIONS(5005),
    [aux_sym_preproc_def_token1] = ACTIONS(5005),
    [aux_sym_preproc_if_token1] = ACTIONS(5005),
    [aux_sym_preproc_if_token2] = ACTIONS(5005),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5005),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5005),
    [sym_preproc_directive] = ACTIONS(5005),
    [anon_sym_LPAREN2] = ACTIONS(5007),
    [anon_sym_TILDE] = ACTIONS(5007),
    [anon_sym_STAR] = ACTIONS(5007),
    [anon_sym_AMP_AMP] = ACTIONS(5007),
    [anon_sym_AMP] = ACTIONS(5005),
    [anon_sym___extension__] = ACTIONS(5005),
    [anon_sym_typedef] = ACTIONS(5005),
    [anon_sym_in] = ACTIONS(5005),
    [anon_sym_out] = ACTIONS(5005),
    [anon_sym_inout] = ACTIONS(5005),
    [anon_sym_extern] = ACTIONS(5005),
    [anon_sym___attribute__] = ACTIONS(5005),
    [anon_sym_COLON_COLON] = ACTIONS(5007),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5007),
    [anon_sym___declspec] = ACTIONS(5005),
    [anon_sym___based] = ACTIONS(5005),
    [anon_sym_signed] = ACTIONS(5005),
    [anon_sym_unsigned] = ACTIONS(5005),
    [anon_sym_long] = ACTIONS(5005),
    [anon_sym_short] = ACTIONS(5005),
    [anon_sym_LBRACK] = ACTIONS(5005),
    [anon_sym_static] = ACTIONS(5005),
    [anon_sym_register] = ACTIONS(5005),
    [anon_sym_inline] = ACTIONS(5005),
    [anon_sym___inline] = ACTIONS(5005),
    [anon_sym___inline__] = ACTIONS(5005),
    [anon_sym___forceinline] = ACTIONS(5005),
    [anon_sym_thread_local] = ACTIONS(5005),
    [anon_sym___thread] = ACTIONS(5005),
    [anon_sym_const] = ACTIONS(5005),
    [anon_sym_constexpr] = ACTIONS(5005),
    [anon_sym_volatile] = ACTIONS(5005),
    [anon_sym_restrict] = ACTIONS(5005),
    [anon_sym___restrict__] = ACTIONS(5005),
    [anon_sym__Atomic] = ACTIONS(5005),
    [anon_sym__Noreturn] = ACTIONS(5005),
    [anon_sym_noreturn] = ACTIONS(5005),
    [anon_sym_mutable] = ACTIONS(5005),
    [anon_sym_constinit] = ACTIONS(5005),
    [anon_sym_consteval] = ACTIONS(5005),
    [anon_sym_alignas] = ACTIONS(5005),
    [anon_sym__Alignas] = ACTIONS(5005),
    [sym_primitive_type] = ACTIONS(5005),
    [anon_sym_enum] = ACTIONS(5005),
    [anon_sym_class] = ACTIONS(5005),
    [anon_sym_struct] = ACTIONS(5005),
    [anon_sym_union] = ACTIONS(5005),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5005),
    [anon_sym_decltype] = ACTIONS(5005),
    [sym_virtual] = ACTIONS(5005),
    [anon_sym_explicit] = ACTIONS(5005),
    [anon_sym_typename] = ACTIONS(5005),
    [anon_sym_template] = ACTIONS(5005),
    [anon_sym_operator] = ACTIONS(5005),
    [anon_sym_friend] = ACTIONS(5005),
    [anon_sym_public] = ACTIONS(5005),
    [anon_sym_private] = ACTIONS(5005),
    [anon_sym_protected] = ACTIONS(5005),
    [anon_sym_using] = ACTIONS(5005),
    [anon_sym_static_assert] = ACTIONS(5005),
    [anon_sym_precise] = ACTIONS(5005),
    [anon_sym_shared] = ACTIONS(5005),
    [anon_sym_groupshared] = ACTIONS(5005),
    [anon_sym_uniform] = ACTIONS(5005),
    [anon_sym_row_major] = ACTIONS(5005),
    [anon_sym_column_major] = ACTIONS(5005),
    [anon_sym_globallycoherent] = ACTIONS(5005),
    [anon_sym_centroid] = ACTIONS(5005),
    [anon_sym_noperspective] = ACTIONS(5005),
    [anon_sym_nointerpolation] = ACTIONS(5005),
    [anon_sym_sample] = ACTIONS(5005),
    [anon_sym_linear] = ACTIONS(5005),
    [anon_sym_snorm] = ACTIONS(5005),
    [anon_sym_unorm] = ACTIONS(5005),
    [anon_sym_point] = ACTIONS(5005),
    [anon_sym_line] = ACTIONS(5005),
    [anon_sym_triangleadj] = ACTIONS(5005),
    [anon_sym_lineadj] = ACTIONS(5005),
    [anon_sym_triangle] = ACTIONS(5005),
  },
  [2028] = {
    [sym_identifier] = ACTIONS(5017),
    [aux_sym_preproc_def_token1] = ACTIONS(5017),
    [aux_sym_preproc_if_token1] = ACTIONS(5017),
    [aux_sym_preproc_if_token2] = ACTIONS(5017),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5017),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5017),
    [sym_preproc_directive] = ACTIONS(5017),
    [anon_sym_LPAREN2] = ACTIONS(5019),
    [anon_sym_TILDE] = ACTIONS(5019),
    [anon_sym_STAR] = ACTIONS(5019),
    [anon_sym_AMP_AMP] = ACTIONS(5019),
    [anon_sym_AMP] = ACTIONS(5017),
    [anon_sym___extension__] = ACTIONS(5017),
    [anon_sym_typedef] = ACTIONS(5017),
    [anon_sym_in] = ACTIONS(5017),
    [anon_sym_out] = ACTIONS(5017),
    [anon_sym_inout] = ACTIONS(5017),
    [anon_sym_extern] = ACTIONS(5017),
    [anon_sym___attribute__] = ACTIONS(5017),
    [anon_sym_COLON_COLON] = ACTIONS(5019),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5019),
    [anon_sym___declspec] = ACTIONS(5017),
    [anon_sym___based] = ACTIONS(5017),
    [anon_sym_signed] = ACTIONS(5017),
    [anon_sym_unsigned] = ACTIONS(5017),
    [anon_sym_long] = ACTIONS(5017),
    [anon_sym_short] = ACTIONS(5017),
    [anon_sym_LBRACK] = ACTIONS(5017),
    [anon_sym_static] = ACTIONS(5017),
    [anon_sym_register] = ACTIONS(5017),
    [anon_sym_inline] = ACTIONS(5017),
    [anon_sym___inline] = ACTIONS(5017),
    [anon_sym___inline__] = ACTIONS(5017),
    [anon_sym___forceinline] = ACTIONS(5017),
    [anon_sym_thread_local] = ACTIONS(5017),
    [anon_sym___thread] = ACTIONS(5017),
    [anon_sym_const] = ACTIONS(5017),
    [anon_sym_constexpr] = ACTIONS(5017),
    [anon_sym_volatile] = ACTIONS(5017),
    [anon_sym_restrict] = ACTIONS(5017),
    [anon_sym___restrict__] = ACTIONS(5017),
    [anon_sym__Atomic] = ACTIONS(5017),
    [anon_sym__Noreturn] = ACTIONS(5017),
    [anon_sym_noreturn] = ACTIONS(5017),
    [anon_sym_mutable] = ACTIONS(5017),
    [anon_sym_constinit] = ACTIONS(5017),
    [anon_sym_consteval] = ACTIONS(5017),
    [anon_sym_alignas] = ACTIONS(5017),
    [anon_sym__Alignas] = ACTIONS(5017),
    [sym_primitive_type] = ACTIONS(5017),
    [anon_sym_enum] = ACTIONS(5017),
    [anon_sym_class] = ACTIONS(5017),
    [anon_sym_struct] = ACTIONS(5017),
    [anon_sym_union] = ACTIONS(5017),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5017),
    [anon_sym_decltype] = ACTIONS(5017),
    [sym_virtual] = ACTIONS(5017),
    [anon_sym_explicit] = ACTIONS(5017),
    [anon_sym_typename] = ACTIONS(5017),
    [anon_sym_template] = ACTIONS(5017),
    [anon_sym_operator] = ACTIONS(5017),
    [anon_sym_friend] = ACTIONS(5017),
    [anon_sym_public] = ACTIONS(5017),
    [anon_sym_private] = ACTIONS(5017),
    [anon_sym_protected] = ACTIONS(5017),
    [anon_sym_using] = ACTIONS(5017),
    [anon_sym_static_assert] = ACTIONS(5017),
    [anon_sym_precise] = ACTIONS(5017),
    [anon_sym_shared] = ACTIONS(5017),
    [anon_sym_groupshared] = ACTIONS(5017),
    [anon_sym_uniform] = ACTIONS(5017),
    [anon_sym_row_major] = ACTIONS(5017),
    [anon_sym_column_major] = ACTIONS(5017),
    [anon_sym_globallycoherent] = ACTIONS(5017),
    [anon_sym_centroid] = ACTIONS(5017),
    [anon_sym_noperspective] = ACTIONS(5017),
    [anon_sym_nointerpolation] = ACTIONS(5017),
    [anon_sym_sample] = ACTIONS(5017),
    [anon_sym_linear] = ACTIONS(5017),
    [anon_sym_snorm] = ACTIONS(5017),
    [anon_sym_unorm] = ACTIONS(5017),
    [anon_sym_point] = ACTIONS(5017),
    [anon_sym_line] = ACTIONS(5017),
    [anon_sym_triangleadj] = ACTIONS(5017),
    [anon_sym_lineadj] = ACTIONS(5017),
    [anon_sym_triangle] = ACTIONS(5017),
  },
  [2029] = {
    [sym_identifier] = ACTIONS(2348),
    [aux_sym_preproc_def_token1] = ACTIONS(2348),
    [aux_sym_preproc_if_token1] = ACTIONS(2348),
    [aux_sym_preproc_if_token2] = ACTIONS(2348),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2348),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2348),
    [sym_preproc_directive] = ACTIONS(2348),
    [anon_sym_LPAREN2] = ACTIONS(2350),
    [anon_sym_TILDE] = ACTIONS(2350),
    [anon_sym_STAR] = ACTIONS(2350),
    [anon_sym_AMP_AMP] = ACTIONS(2350),
    [anon_sym_AMP] = ACTIONS(2348),
    [anon_sym___extension__] = ACTIONS(2348),
    [anon_sym_typedef] = ACTIONS(2348),
    [anon_sym_in] = ACTIONS(2348),
    [anon_sym_out] = ACTIONS(2348),
    [anon_sym_inout] = ACTIONS(2348),
    [anon_sym_extern] = ACTIONS(2348),
    [anon_sym___attribute__] = ACTIONS(2348),
    [anon_sym_COLON_COLON] = ACTIONS(2350),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2350),
    [anon_sym___declspec] = ACTIONS(2348),
    [anon_sym___based] = ACTIONS(2348),
    [anon_sym_signed] = ACTIONS(2348),
    [anon_sym_unsigned] = ACTIONS(2348),
    [anon_sym_long] = ACTIONS(2348),
    [anon_sym_short] = ACTIONS(2348),
    [anon_sym_LBRACK] = ACTIONS(2348),
    [anon_sym_static] = ACTIONS(2348),
    [anon_sym_register] = ACTIONS(2348),
    [anon_sym_inline] = ACTIONS(2348),
    [anon_sym___inline] = ACTIONS(2348),
    [anon_sym___inline__] = ACTIONS(2348),
    [anon_sym___forceinline] = ACTIONS(2348),
    [anon_sym_thread_local] = ACTIONS(2348),
    [anon_sym___thread] = ACTIONS(2348),
    [anon_sym_const] = ACTIONS(2348),
    [anon_sym_constexpr] = ACTIONS(2348),
    [anon_sym_volatile] = ACTIONS(2348),
    [anon_sym_restrict] = ACTIONS(2348),
    [anon_sym___restrict__] = ACTIONS(2348),
    [anon_sym__Atomic] = ACTIONS(2348),
    [anon_sym__Noreturn] = ACTIONS(2348),
    [anon_sym_noreturn] = ACTIONS(2348),
    [anon_sym_mutable] = ACTIONS(2348),
    [anon_sym_constinit] = ACTIONS(2348),
    [anon_sym_consteval] = ACTIONS(2348),
    [anon_sym_alignas] = ACTIONS(2348),
    [anon_sym__Alignas] = ACTIONS(2348),
    [sym_primitive_type] = ACTIONS(2348),
    [anon_sym_enum] = ACTIONS(2348),
    [anon_sym_class] = ACTIONS(2348),
    [anon_sym_struct] = ACTIONS(2348),
    [anon_sym_union] = ACTIONS(2348),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2348),
    [anon_sym_decltype] = ACTIONS(2348),
    [sym_virtual] = ACTIONS(2348),
    [anon_sym_explicit] = ACTIONS(2348),
    [anon_sym_typename] = ACTIONS(2348),
    [anon_sym_template] = ACTIONS(2348),
    [anon_sym_operator] = ACTIONS(2348),
    [anon_sym_friend] = ACTIONS(2348),
    [anon_sym_public] = ACTIONS(2348),
    [anon_sym_private] = ACTIONS(2348),
    [anon_sym_protected] = ACTIONS(2348),
    [anon_sym_using] = ACTIONS(2348),
    [anon_sym_static_assert] = ACTIONS(2348),
    [anon_sym_precise] = ACTIONS(2348),
    [anon_sym_shared] = ACTIONS(2348),
    [anon_sym_groupshared] = ACTIONS(2348),
    [anon_sym_uniform] = ACTIONS(2348),
    [anon_sym_row_major] = ACTIONS(2348),
    [anon_sym_column_major] = ACTIONS(2348),
    [anon_sym_globallycoherent] = ACTIONS(2348),
    [anon_sym_centroid] = ACTIONS(2348),
    [anon_sym_noperspective] = ACTIONS(2348),
    [anon_sym_nointerpolation] = ACTIONS(2348),
    [anon_sym_sample] = ACTIONS(2348),
    [anon_sym_linear] = ACTIONS(2348),
    [anon_sym_snorm] = ACTIONS(2348),
    [anon_sym_unorm] = ACTIONS(2348),
    [anon_sym_point] = ACTIONS(2348),
    [anon_sym_line] = ACTIONS(2348),
    [anon_sym_triangleadj] = ACTIONS(2348),
    [anon_sym_lineadj] = ACTIONS(2348),
    [anon_sym_triangle] = ACTIONS(2348),
  },
  [2030] = {
    [sym_identifier] = ACTIONS(5001),
    [aux_sym_preproc_def_token1] = ACTIONS(5001),
    [aux_sym_preproc_if_token1] = ACTIONS(5001),
    [aux_sym_preproc_if_token2] = ACTIONS(5001),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5001),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5001),
    [sym_preproc_directive] = ACTIONS(5001),
    [anon_sym_LPAREN2] = ACTIONS(5003),
    [anon_sym_TILDE] = ACTIONS(5003),
    [anon_sym_STAR] = ACTIONS(5003),
    [anon_sym_AMP_AMP] = ACTIONS(5003),
    [anon_sym_AMP] = ACTIONS(5001),
    [anon_sym___extension__] = ACTIONS(5001),
    [anon_sym_typedef] = ACTIONS(5001),
    [anon_sym_in] = ACTIONS(5001),
    [anon_sym_out] = ACTIONS(5001),
    [anon_sym_inout] = ACTIONS(5001),
    [anon_sym_extern] = ACTIONS(5001),
    [anon_sym___attribute__] = ACTIONS(5001),
    [anon_sym_COLON_COLON] = ACTIONS(5003),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5003),
    [anon_sym___declspec] = ACTIONS(5001),
    [anon_sym___based] = ACTIONS(5001),
    [anon_sym_signed] = ACTIONS(5001),
    [anon_sym_unsigned] = ACTIONS(5001),
    [anon_sym_long] = ACTIONS(5001),
    [anon_sym_short] = ACTIONS(5001),
    [anon_sym_LBRACK] = ACTIONS(5001),
    [anon_sym_static] = ACTIONS(5001),
    [anon_sym_register] = ACTIONS(5001),
    [anon_sym_inline] = ACTIONS(5001),
    [anon_sym___inline] = ACTIONS(5001),
    [anon_sym___inline__] = ACTIONS(5001),
    [anon_sym___forceinline] = ACTIONS(5001),
    [anon_sym_thread_local] = ACTIONS(5001),
    [anon_sym___thread] = ACTIONS(5001),
    [anon_sym_const] = ACTIONS(5001),
    [anon_sym_constexpr] = ACTIONS(5001),
    [anon_sym_volatile] = ACTIONS(5001),
    [anon_sym_restrict] = ACTIONS(5001),
    [anon_sym___restrict__] = ACTIONS(5001),
    [anon_sym__Atomic] = ACTIONS(5001),
    [anon_sym__Noreturn] = ACTIONS(5001),
    [anon_sym_noreturn] = ACTIONS(5001),
    [anon_sym_mutable] = ACTIONS(5001),
    [anon_sym_constinit] = ACTIONS(5001),
    [anon_sym_consteval] = ACTIONS(5001),
    [anon_sym_alignas] = ACTIONS(5001),
    [anon_sym__Alignas] = ACTIONS(5001),
    [sym_primitive_type] = ACTIONS(5001),
    [anon_sym_enum] = ACTIONS(5001),
    [anon_sym_class] = ACTIONS(5001),
    [anon_sym_struct] = ACTIONS(5001),
    [anon_sym_union] = ACTIONS(5001),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5001),
    [anon_sym_decltype] = ACTIONS(5001),
    [sym_virtual] = ACTIONS(5001),
    [anon_sym_explicit] = ACTIONS(5001),
    [anon_sym_typename] = ACTIONS(5001),
    [anon_sym_template] = ACTIONS(5001),
    [anon_sym_operator] = ACTIONS(5001),
    [anon_sym_friend] = ACTIONS(5001),
    [anon_sym_public] = ACTIONS(5001),
    [anon_sym_private] = ACTIONS(5001),
    [anon_sym_protected] = ACTIONS(5001),
    [anon_sym_using] = ACTIONS(5001),
    [anon_sym_static_assert] = ACTIONS(5001),
    [anon_sym_precise] = ACTIONS(5001),
    [anon_sym_shared] = ACTIONS(5001),
    [anon_sym_groupshared] = ACTIONS(5001),
    [anon_sym_uniform] = ACTIONS(5001),
    [anon_sym_row_major] = ACTIONS(5001),
    [anon_sym_column_major] = ACTIONS(5001),
    [anon_sym_globallycoherent] = ACTIONS(5001),
    [anon_sym_centroid] = ACTIONS(5001),
    [anon_sym_noperspective] = ACTIONS(5001),
    [anon_sym_nointerpolation] = ACTIONS(5001),
    [anon_sym_sample] = ACTIONS(5001),
    [anon_sym_linear] = ACTIONS(5001),
    [anon_sym_snorm] = ACTIONS(5001),
    [anon_sym_unorm] = ACTIONS(5001),
    [anon_sym_point] = ACTIONS(5001),
    [anon_sym_line] = ACTIONS(5001),
    [anon_sym_triangleadj] = ACTIONS(5001),
    [anon_sym_lineadj] = ACTIONS(5001),
    [anon_sym_triangle] = ACTIONS(5001),
  },
  [2031] = {
    [sym_identifier] = ACTIONS(5001),
    [aux_sym_preproc_def_token1] = ACTIONS(5001),
    [aux_sym_preproc_if_token1] = ACTIONS(5001),
    [aux_sym_preproc_if_token2] = ACTIONS(5001),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5001),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5001),
    [sym_preproc_directive] = ACTIONS(5001),
    [anon_sym_LPAREN2] = ACTIONS(5003),
    [anon_sym_TILDE] = ACTIONS(5003),
    [anon_sym_STAR] = ACTIONS(5003),
    [anon_sym_AMP_AMP] = ACTIONS(5003),
    [anon_sym_AMP] = ACTIONS(5001),
    [anon_sym___extension__] = ACTIONS(5001),
    [anon_sym_typedef] = ACTIONS(5001),
    [anon_sym_in] = ACTIONS(5001),
    [anon_sym_out] = ACTIONS(5001),
    [anon_sym_inout] = ACTIONS(5001),
    [anon_sym_extern] = ACTIONS(5001),
    [anon_sym___attribute__] = ACTIONS(5001),
    [anon_sym_COLON_COLON] = ACTIONS(5003),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5003),
    [anon_sym___declspec] = ACTIONS(5001),
    [anon_sym___based] = ACTIONS(5001),
    [anon_sym_signed] = ACTIONS(5001),
    [anon_sym_unsigned] = ACTIONS(5001),
    [anon_sym_long] = ACTIONS(5001),
    [anon_sym_short] = ACTIONS(5001),
    [anon_sym_LBRACK] = ACTIONS(5001),
    [anon_sym_static] = ACTIONS(5001),
    [anon_sym_register] = ACTIONS(5001),
    [anon_sym_inline] = ACTIONS(5001),
    [anon_sym___inline] = ACTIONS(5001),
    [anon_sym___inline__] = ACTIONS(5001),
    [anon_sym___forceinline] = ACTIONS(5001),
    [anon_sym_thread_local] = ACTIONS(5001),
    [anon_sym___thread] = ACTIONS(5001),
    [anon_sym_const] = ACTIONS(5001),
    [anon_sym_constexpr] = ACTIONS(5001),
    [anon_sym_volatile] = ACTIONS(5001),
    [anon_sym_restrict] = ACTIONS(5001),
    [anon_sym___restrict__] = ACTIONS(5001),
    [anon_sym__Atomic] = ACTIONS(5001),
    [anon_sym__Noreturn] = ACTIONS(5001),
    [anon_sym_noreturn] = ACTIONS(5001),
    [anon_sym_mutable] = ACTIONS(5001),
    [anon_sym_constinit] = ACTIONS(5001),
    [anon_sym_consteval] = ACTIONS(5001),
    [anon_sym_alignas] = ACTIONS(5001),
    [anon_sym__Alignas] = ACTIONS(5001),
    [sym_primitive_type] = ACTIONS(5001),
    [anon_sym_enum] = ACTIONS(5001),
    [anon_sym_class] = ACTIONS(5001),
    [anon_sym_struct] = ACTIONS(5001),
    [anon_sym_union] = ACTIONS(5001),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5001),
    [anon_sym_decltype] = ACTIONS(5001),
    [sym_virtual] = ACTIONS(5001),
    [anon_sym_explicit] = ACTIONS(5001),
    [anon_sym_typename] = ACTIONS(5001),
    [anon_sym_template] = ACTIONS(5001),
    [anon_sym_operator] = ACTIONS(5001),
    [anon_sym_friend] = ACTIONS(5001),
    [anon_sym_public] = ACTIONS(5001),
    [anon_sym_private] = ACTIONS(5001),
    [anon_sym_protected] = ACTIONS(5001),
    [anon_sym_using] = ACTIONS(5001),
    [anon_sym_static_assert] = ACTIONS(5001),
    [anon_sym_precise] = ACTIONS(5001),
    [anon_sym_shared] = ACTIONS(5001),
    [anon_sym_groupshared] = ACTIONS(5001),
    [anon_sym_uniform] = ACTIONS(5001),
    [anon_sym_row_major] = ACTIONS(5001),
    [anon_sym_column_major] = ACTIONS(5001),
    [anon_sym_globallycoherent] = ACTIONS(5001),
    [anon_sym_centroid] = ACTIONS(5001),
    [anon_sym_noperspective] = ACTIONS(5001),
    [anon_sym_nointerpolation] = ACTIONS(5001),
    [anon_sym_sample] = ACTIONS(5001),
    [anon_sym_linear] = ACTIONS(5001),
    [anon_sym_snorm] = ACTIONS(5001),
    [anon_sym_unorm] = ACTIONS(5001),
    [anon_sym_point] = ACTIONS(5001),
    [anon_sym_line] = ACTIONS(5001),
    [anon_sym_triangleadj] = ACTIONS(5001),
    [anon_sym_lineadj] = ACTIONS(5001),
    [anon_sym_triangle] = ACTIONS(5001),
  },
  [2032] = {
    [sym_identifier] = ACTIONS(5005),
    [aux_sym_preproc_def_token1] = ACTIONS(5005),
    [aux_sym_preproc_if_token1] = ACTIONS(5005),
    [aux_sym_preproc_if_token2] = ACTIONS(5005),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5005),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5005),
    [sym_preproc_directive] = ACTIONS(5005),
    [anon_sym_LPAREN2] = ACTIONS(5007),
    [anon_sym_TILDE] = ACTIONS(5007),
    [anon_sym_STAR] = ACTIONS(5007),
    [anon_sym_AMP_AMP] = ACTIONS(5007),
    [anon_sym_AMP] = ACTIONS(5005),
    [anon_sym___extension__] = ACTIONS(5005),
    [anon_sym_typedef] = ACTIONS(5005),
    [anon_sym_in] = ACTIONS(5005),
    [anon_sym_out] = ACTIONS(5005),
    [anon_sym_inout] = ACTIONS(5005),
    [anon_sym_extern] = ACTIONS(5005),
    [anon_sym___attribute__] = ACTIONS(5005),
    [anon_sym_COLON_COLON] = ACTIONS(5007),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5007),
    [anon_sym___declspec] = ACTIONS(5005),
    [anon_sym___based] = ACTIONS(5005),
    [anon_sym_signed] = ACTIONS(5005),
    [anon_sym_unsigned] = ACTIONS(5005),
    [anon_sym_long] = ACTIONS(5005),
    [anon_sym_short] = ACTIONS(5005),
    [anon_sym_LBRACK] = ACTIONS(5005),
    [anon_sym_static] = ACTIONS(5005),
    [anon_sym_register] = ACTIONS(5005),
    [anon_sym_inline] = ACTIONS(5005),
    [anon_sym___inline] = ACTIONS(5005),
    [anon_sym___inline__] = ACTIONS(5005),
    [anon_sym___forceinline] = ACTIONS(5005),
    [anon_sym_thread_local] = ACTIONS(5005),
    [anon_sym___thread] = ACTIONS(5005),
    [anon_sym_const] = ACTIONS(5005),
    [anon_sym_constexpr] = ACTIONS(5005),
    [anon_sym_volatile] = ACTIONS(5005),
    [anon_sym_restrict] = ACTIONS(5005),
    [anon_sym___restrict__] = ACTIONS(5005),
    [anon_sym__Atomic] = ACTIONS(5005),
    [anon_sym__Noreturn] = ACTIONS(5005),
    [anon_sym_noreturn] = ACTIONS(5005),
    [anon_sym_mutable] = ACTIONS(5005),
    [anon_sym_constinit] = ACTIONS(5005),
    [anon_sym_consteval] = ACTIONS(5005),
    [anon_sym_alignas] = ACTIONS(5005),
    [anon_sym__Alignas] = ACTIONS(5005),
    [sym_primitive_type] = ACTIONS(5005),
    [anon_sym_enum] = ACTIONS(5005),
    [anon_sym_class] = ACTIONS(5005),
    [anon_sym_struct] = ACTIONS(5005),
    [anon_sym_union] = ACTIONS(5005),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5005),
    [anon_sym_decltype] = ACTIONS(5005),
    [sym_virtual] = ACTIONS(5005),
    [anon_sym_explicit] = ACTIONS(5005),
    [anon_sym_typename] = ACTIONS(5005),
    [anon_sym_template] = ACTIONS(5005),
    [anon_sym_operator] = ACTIONS(5005),
    [anon_sym_friend] = ACTIONS(5005),
    [anon_sym_public] = ACTIONS(5005),
    [anon_sym_private] = ACTIONS(5005),
    [anon_sym_protected] = ACTIONS(5005),
    [anon_sym_using] = ACTIONS(5005),
    [anon_sym_static_assert] = ACTIONS(5005),
    [anon_sym_precise] = ACTIONS(5005),
    [anon_sym_shared] = ACTIONS(5005),
    [anon_sym_groupshared] = ACTIONS(5005),
    [anon_sym_uniform] = ACTIONS(5005),
    [anon_sym_row_major] = ACTIONS(5005),
    [anon_sym_column_major] = ACTIONS(5005),
    [anon_sym_globallycoherent] = ACTIONS(5005),
    [anon_sym_centroid] = ACTIONS(5005),
    [anon_sym_noperspective] = ACTIONS(5005),
    [anon_sym_nointerpolation] = ACTIONS(5005),
    [anon_sym_sample] = ACTIONS(5005),
    [anon_sym_linear] = ACTIONS(5005),
    [anon_sym_snorm] = ACTIONS(5005),
    [anon_sym_unorm] = ACTIONS(5005),
    [anon_sym_point] = ACTIONS(5005),
    [anon_sym_line] = ACTIONS(5005),
    [anon_sym_triangleadj] = ACTIONS(5005),
    [anon_sym_lineadj] = ACTIONS(5005),
    [anon_sym_triangle] = ACTIONS(5005),
  },
  [2033] = {
    [sym_identifier] = ACTIONS(2248),
    [aux_sym_preproc_def_token1] = ACTIONS(2248),
    [aux_sym_preproc_if_token1] = ACTIONS(2248),
    [aux_sym_preproc_if_token2] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2248),
    [sym_preproc_directive] = ACTIONS(2248),
    [anon_sym_LPAREN2] = ACTIONS(2250),
    [anon_sym_TILDE] = ACTIONS(2250),
    [anon_sym_STAR] = ACTIONS(2250),
    [anon_sym_AMP_AMP] = ACTIONS(2250),
    [anon_sym_AMP] = ACTIONS(2248),
    [anon_sym___extension__] = ACTIONS(2248),
    [anon_sym_typedef] = ACTIONS(2248),
    [anon_sym_in] = ACTIONS(2248),
    [anon_sym_out] = ACTIONS(2248),
    [anon_sym_inout] = ACTIONS(2248),
    [anon_sym_extern] = ACTIONS(2248),
    [anon_sym___attribute__] = ACTIONS(2248),
    [anon_sym_COLON_COLON] = ACTIONS(2250),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2250),
    [anon_sym___declspec] = ACTIONS(2248),
    [anon_sym___based] = ACTIONS(2248),
    [anon_sym_signed] = ACTIONS(2248),
    [anon_sym_unsigned] = ACTIONS(2248),
    [anon_sym_long] = ACTIONS(2248),
    [anon_sym_short] = ACTIONS(2248),
    [anon_sym_LBRACK] = ACTIONS(2248),
    [anon_sym_static] = ACTIONS(2248),
    [anon_sym_register] = ACTIONS(2248),
    [anon_sym_inline] = ACTIONS(2248),
    [anon_sym___inline] = ACTIONS(2248),
    [anon_sym___inline__] = ACTIONS(2248),
    [anon_sym___forceinline] = ACTIONS(2248),
    [anon_sym_thread_local] = ACTIONS(2248),
    [anon_sym___thread] = ACTIONS(2248),
    [anon_sym_const] = ACTIONS(2248),
    [anon_sym_constexpr] = ACTIONS(2248),
    [anon_sym_volatile] = ACTIONS(2248),
    [anon_sym_restrict] = ACTIONS(2248),
    [anon_sym___restrict__] = ACTIONS(2248),
    [anon_sym__Atomic] = ACTIONS(2248),
    [anon_sym__Noreturn] = ACTIONS(2248),
    [anon_sym_noreturn] = ACTIONS(2248),
    [anon_sym_mutable] = ACTIONS(2248),
    [anon_sym_constinit] = ACTIONS(2248),
    [anon_sym_consteval] = ACTIONS(2248),
    [anon_sym_alignas] = ACTIONS(2248),
    [anon_sym__Alignas] = ACTIONS(2248),
    [sym_primitive_type] = ACTIONS(2248),
    [anon_sym_enum] = ACTIONS(2248),
    [anon_sym_class] = ACTIONS(2248),
    [anon_sym_struct] = ACTIONS(2248),
    [anon_sym_union] = ACTIONS(2248),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2248),
    [anon_sym_decltype] = ACTIONS(2248),
    [sym_virtual] = ACTIONS(2248),
    [anon_sym_explicit] = ACTIONS(2248),
    [anon_sym_typename] = ACTIONS(2248),
    [anon_sym_template] = ACTIONS(2248),
    [anon_sym_operator] = ACTIONS(2248),
    [anon_sym_friend] = ACTIONS(2248),
    [anon_sym_public] = ACTIONS(2248),
    [anon_sym_private] = ACTIONS(2248),
    [anon_sym_protected] = ACTIONS(2248),
    [anon_sym_using] = ACTIONS(2248),
    [anon_sym_static_assert] = ACTIONS(2248),
    [anon_sym_precise] = ACTIONS(2248),
    [anon_sym_shared] = ACTIONS(2248),
    [anon_sym_groupshared] = ACTIONS(2248),
    [anon_sym_uniform] = ACTIONS(2248),
    [anon_sym_row_major] = ACTIONS(2248),
    [anon_sym_column_major] = ACTIONS(2248),
    [anon_sym_globallycoherent] = ACTIONS(2248),
    [anon_sym_centroid] = ACTIONS(2248),
    [anon_sym_noperspective] = ACTIONS(2248),
    [anon_sym_nointerpolation] = ACTIONS(2248),
    [anon_sym_sample] = ACTIONS(2248),
    [anon_sym_linear] = ACTIONS(2248),
    [anon_sym_snorm] = ACTIONS(2248),
    [anon_sym_unorm] = ACTIONS(2248),
    [anon_sym_point] = ACTIONS(2248),
    [anon_sym_line] = ACTIONS(2248),
    [anon_sym_triangleadj] = ACTIONS(2248),
    [anon_sym_lineadj] = ACTIONS(2248),
    [anon_sym_triangle] = ACTIONS(2248),
  },
  [2034] = {
    [sym_identifier] = ACTIONS(5101),
    [aux_sym_preproc_def_token1] = ACTIONS(5101),
    [aux_sym_preproc_if_token1] = ACTIONS(5101),
    [aux_sym_preproc_if_token2] = ACTIONS(5101),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5101),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5101),
    [sym_preproc_directive] = ACTIONS(5101),
    [anon_sym_LPAREN2] = ACTIONS(5103),
    [anon_sym_TILDE] = ACTIONS(5103),
    [anon_sym_STAR] = ACTIONS(5103),
    [anon_sym_AMP_AMP] = ACTIONS(5103),
    [anon_sym_AMP] = ACTIONS(5101),
    [anon_sym___extension__] = ACTIONS(5101),
    [anon_sym_typedef] = ACTIONS(5101),
    [anon_sym_in] = ACTIONS(5101),
    [anon_sym_out] = ACTIONS(5101),
    [anon_sym_inout] = ACTIONS(5101),
    [anon_sym_extern] = ACTIONS(5101),
    [anon_sym___attribute__] = ACTIONS(5101),
    [anon_sym_COLON_COLON] = ACTIONS(5103),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5103),
    [anon_sym___declspec] = ACTIONS(5101),
    [anon_sym___based] = ACTIONS(5101),
    [anon_sym_signed] = ACTIONS(5101),
    [anon_sym_unsigned] = ACTIONS(5101),
    [anon_sym_long] = ACTIONS(5101),
    [anon_sym_short] = ACTIONS(5101),
    [anon_sym_LBRACK] = ACTIONS(5101),
    [anon_sym_static] = ACTIONS(5101),
    [anon_sym_register] = ACTIONS(5101),
    [anon_sym_inline] = ACTIONS(5101),
    [anon_sym___inline] = ACTIONS(5101),
    [anon_sym___inline__] = ACTIONS(5101),
    [anon_sym___forceinline] = ACTIONS(5101),
    [anon_sym_thread_local] = ACTIONS(5101),
    [anon_sym___thread] = ACTIONS(5101),
    [anon_sym_const] = ACTIONS(5101),
    [anon_sym_constexpr] = ACTIONS(5101),
    [anon_sym_volatile] = ACTIONS(5101),
    [anon_sym_restrict] = ACTIONS(5101),
    [anon_sym___restrict__] = ACTIONS(5101),
    [anon_sym__Atomic] = ACTIONS(5101),
    [anon_sym__Noreturn] = ACTIONS(5101),
    [anon_sym_noreturn] = ACTIONS(5101),
    [anon_sym_mutable] = ACTIONS(5101),
    [anon_sym_constinit] = ACTIONS(5101),
    [anon_sym_consteval] = ACTIONS(5101),
    [anon_sym_alignas] = ACTIONS(5101),
    [anon_sym__Alignas] = ACTIONS(5101),
    [sym_primitive_type] = ACTIONS(5101),
    [anon_sym_enum] = ACTIONS(5101),
    [anon_sym_class] = ACTIONS(5101),
    [anon_sym_struct] = ACTIONS(5101),
    [anon_sym_union] = ACTIONS(5101),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5101),
    [anon_sym_decltype] = ACTIONS(5101),
    [sym_virtual] = ACTIONS(5101),
    [anon_sym_explicit] = ACTIONS(5101),
    [anon_sym_typename] = ACTIONS(5101),
    [anon_sym_template] = ACTIONS(5101),
    [anon_sym_operator] = ACTIONS(5101),
    [anon_sym_friend] = ACTIONS(5101),
    [anon_sym_public] = ACTIONS(5101),
    [anon_sym_private] = ACTIONS(5101),
    [anon_sym_protected] = ACTIONS(5101),
    [anon_sym_using] = ACTIONS(5101),
    [anon_sym_static_assert] = ACTIONS(5101),
    [anon_sym_precise] = ACTIONS(5101),
    [anon_sym_shared] = ACTIONS(5101),
    [anon_sym_groupshared] = ACTIONS(5101),
    [anon_sym_uniform] = ACTIONS(5101),
    [anon_sym_row_major] = ACTIONS(5101),
    [anon_sym_column_major] = ACTIONS(5101),
    [anon_sym_globallycoherent] = ACTIONS(5101),
    [anon_sym_centroid] = ACTIONS(5101),
    [anon_sym_noperspective] = ACTIONS(5101),
    [anon_sym_nointerpolation] = ACTIONS(5101),
    [anon_sym_sample] = ACTIONS(5101),
    [anon_sym_linear] = ACTIONS(5101),
    [anon_sym_snorm] = ACTIONS(5101),
    [anon_sym_unorm] = ACTIONS(5101),
    [anon_sym_point] = ACTIONS(5101),
    [anon_sym_line] = ACTIONS(5101),
    [anon_sym_triangleadj] = ACTIONS(5101),
    [anon_sym_lineadj] = ACTIONS(5101),
    [anon_sym_triangle] = ACTIONS(5101),
  },
  [2035] = {
    [sym_identifier] = ACTIONS(5097),
    [aux_sym_preproc_def_token1] = ACTIONS(5097),
    [aux_sym_preproc_if_token1] = ACTIONS(5097),
    [aux_sym_preproc_if_token2] = ACTIONS(5097),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5097),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5097),
    [sym_preproc_directive] = ACTIONS(5097),
    [anon_sym_LPAREN2] = ACTIONS(5099),
    [anon_sym_TILDE] = ACTIONS(5099),
    [anon_sym_STAR] = ACTIONS(5099),
    [anon_sym_AMP_AMP] = ACTIONS(5099),
    [anon_sym_AMP] = ACTIONS(5097),
    [anon_sym___extension__] = ACTIONS(5097),
    [anon_sym_typedef] = ACTIONS(5097),
    [anon_sym_in] = ACTIONS(5097),
    [anon_sym_out] = ACTIONS(5097),
    [anon_sym_inout] = ACTIONS(5097),
    [anon_sym_extern] = ACTIONS(5097),
    [anon_sym___attribute__] = ACTIONS(5097),
    [anon_sym_COLON_COLON] = ACTIONS(5099),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5099),
    [anon_sym___declspec] = ACTIONS(5097),
    [anon_sym___based] = ACTIONS(5097),
    [anon_sym_signed] = ACTIONS(5097),
    [anon_sym_unsigned] = ACTIONS(5097),
    [anon_sym_long] = ACTIONS(5097),
    [anon_sym_short] = ACTIONS(5097),
    [anon_sym_LBRACK] = ACTIONS(5097),
    [anon_sym_static] = ACTIONS(5097),
    [anon_sym_register] = ACTIONS(5097),
    [anon_sym_inline] = ACTIONS(5097),
    [anon_sym___inline] = ACTIONS(5097),
    [anon_sym___inline__] = ACTIONS(5097),
    [anon_sym___forceinline] = ACTIONS(5097),
    [anon_sym_thread_local] = ACTIONS(5097),
    [anon_sym___thread] = ACTIONS(5097),
    [anon_sym_const] = ACTIONS(5097),
    [anon_sym_constexpr] = ACTIONS(5097),
    [anon_sym_volatile] = ACTIONS(5097),
    [anon_sym_restrict] = ACTIONS(5097),
    [anon_sym___restrict__] = ACTIONS(5097),
    [anon_sym__Atomic] = ACTIONS(5097),
    [anon_sym__Noreturn] = ACTIONS(5097),
    [anon_sym_noreturn] = ACTIONS(5097),
    [anon_sym_mutable] = ACTIONS(5097),
    [anon_sym_constinit] = ACTIONS(5097),
    [anon_sym_consteval] = ACTIONS(5097),
    [anon_sym_alignas] = ACTIONS(5097),
    [anon_sym__Alignas] = ACTIONS(5097),
    [sym_primitive_type] = ACTIONS(5097),
    [anon_sym_enum] = ACTIONS(5097),
    [anon_sym_class] = ACTIONS(5097),
    [anon_sym_struct] = ACTIONS(5097),
    [anon_sym_union] = ACTIONS(5097),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5097),
    [anon_sym_decltype] = ACTIONS(5097),
    [sym_virtual] = ACTIONS(5097),
    [anon_sym_explicit] = ACTIONS(5097),
    [anon_sym_typename] = ACTIONS(5097),
    [anon_sym_template] = ACTIONS(5097),
    [anon_sym_operator] = ACTIONS(5097),
    [anon_sym_friend] = ACTIONS(5097),
    [anon_sym_public] = ACTIONS(5097),
    [anon_sym_private] = ACTIONS(5097),
    [anon_sym_protected] = ACTIONS(5097),
    [anon_sym_using] = ACTIONS(5097),
    [anon_sym_static_assert] = ACTIONS(5097),
    [anon_sym_precise] = ACTIONS(5097),
    [anon_sym_shared] = ACTIONS(5097),
    [anon_sym_groupshared] = ACTIONS(5097),
    [anon_sym_uniform] = ACTIONS(5097),
    [anon_sym_row_major] = ACTIONS(5097),
    [anon_sym_column_major] = ACTIONS(5097),
    [anon_sym_globallycoherent] = ACTIONS(5097),
    [anon_sym_centroid] = ACTIONS(5097),
    [anon_sym_noperspective] = ACTIONS(5097),
    [anon_sym_nointerpolation] = ACTIONS(5097),
    [anon_sym_sample] = ACTIONS(5097),
    [anon_sym_linear] = ACTIONS(5097),
    [anon_sym_snorm] = ACTIONS(5097),
    [anon_sym_unorm] = ACTIONS(5097),
    [anon_sym_point] = ACTIONS(5097),
    [anon_sym_line] = ACTIONS(5097),
    [anon_sym_triangleadj] = ACTIONS(5097),
    [anon_sym_lineadj] = ACTIONS(5097),
    [anon_sym_triangle] = ACTIONS(5097),
  },
  [2036] = {
    [sym_identifier] = ACTIONS(5089),
    [aux_sym_preproc_def_token1] = ACTIONS(5089),
    [aux_sym_preproc_if_token1] = ACTIONS(5089),
    [aux_sym_preproc_if_token2] = ACTIONS(5089),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5089),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5089),
    [sym_preproc_directive] = ACTIONS(5089),
    [anon_sym_LPAREN2] = ACTIONS(5091),
    [anon_sym_TILDE] = ACTIONS(5091),
    [anon_sym_STAR] = ACTIONS(5091),
    [anon_sym_AMP_AMP] = ACTIONS(5091),
    [anon_sym_AMP] = ACTIONS(5089),
    [anon_sym___extension__] = ACTIONS(5089),
    [anon_sym_typedef] = ACTIONS(5089),
    [anon_sym_in] = ACTIONS(5089),
    [anon_sym_out] = ACTIONS(5089),
    [anon_sym_inout] = ACTIONS(5089),
    [anon_sym_extern] = ACTIONS(5089),
    [anon_sym___attribute__] = ACTIONS(5089),
    [anon_sym_COLON_COLON] = ACTIONS(5091),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5091),
    [anon_sym___declspec] = ACTIONS(5089),
    [anon_sym___based] = ACTIONS(5089),
    [anon_sym_signed] = ACTIONS(5089),
    [anon_sym_unsigned] = ACTIONS(5089),
    [anon_sym_long] = ACTIONS(5089),
    [anon_sym_short] = ACTIONS(5089),
    [anon_sym_LBRACK] = ACTIONS(5089),
    [anon_sym_static] = ACTIONS(5089),
    [anon_sym_register] = ACTIONS(5089),
    [anon_sym_inline] = ACTIONS(5089),
    [anon_sym___inline] = ACTIONS(5089),
    [anon_sym___inline__] = ACTIONS(5089),
    [anon_sym___forceinline] = ACTIONS(5089),
    [anon_sym_thread_local] = ACTIONS(5089),
    [anon_sym___thread] = ACTIONS(5089),
    [anon_sym_const] = ACTIONS(5089),
    [anon_sym_constexpr] = ACTIONS(5089),
    [anon_sym_volatile] = ACTIONS(5089),
    [anon_sym_restrict] = ACTIONS(5089),
    [anon_sym___restrict__] = ACTIONS(5089),
    [anon_sym__Atomic] = ACTIONS(5089),
    [anon_sym__Noreturn] = ACTIONS(5089),
    [anon_sym_noreturn] = ACTIONS(5089),
    [anon_sym_mutable] = ACTIONS(5089),
    [anon_sym_constinit] = ACTIONS(5089),
    [anon_sym_consteval] = ACTIONS(5089),
    [anon_sym_alignas] = ACTIONS(5089),
    [anon_sym__Alignas] = ACTIONS(5089),
    [sym_primitive_type] = ACTIONS(5089),
    [anon_sym_enum] = ACTIONS(5089),
    [anon_sym_class] = ACTIONS(5089),
    [anon_sym_struct] = ACTIONS(5089),
    [anon_sym_union] = ACTIONS(5089),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5089),
    [anon_sym_decltype] = ACTIONS(5089),
    [sym_virtual] = ACTIONS(5089),
    [anon_sym_explicit] = ACTIONS(5089),
    [anon_sym_typename] = ACTIONS(5089),
    [anon_sym_template] = ACTIONS(5089),
    [anon_sym_operator] = ACTIONS(5089),
    [anon_sym_friend] = ACTIONS(5089),
    [anon_sym_public] = ACTIONS(5089),
    [anon_sym_private] = ACTIONS(5089),
    [anon_sym_protected] = ACTIONS(5089),
    [anon_sym_using] = ACTIONS(5089),
    [anon_sym_static_assert] = ACTIONS(5089),
    [anon_sym_precise] = ACTIONS(5089),
    [anon_sym_shared] = ACTIONS(5089),
    [anon_sym_groupshared] = ACTIONS(5089),
    [anon_sym_uniform] = ACTIONS(5089),
    [anon_sym_row_major] = ACTIONS(5089),
    [anon_sym_column_major] = ACTIONS(5089),
    [anon_sym_globallycoherent] = ACTIONS(5089),
    [anon_sym_centroid] = ACTIONS(5089),
    [anon_sym_noperspective] = ACTIONS(5089),
    [anon_sym_nointerpolation] = ACTIONS(5089),
    [anon_sym_sample] = ACTIONS(5089),
    [anon_sym_linear] = ACTIONS(5089),
    [anon_sym_snorm] = ACTIONS(5089),
    [anon_sym_unorm] = ACTIONS(5089),
    [anon_sym_point] = ACTIONS(5089),
    [anon_sym_line] = ACTIONS(5089),
    [anon_sym_triangleadj] = ACTIONS(5089),
    [anon_sym_lineadj] = ACTIONS(5089),
    [anon_sym_triangle] = ACTIONS(5089),
  },
  [2037] = {
    [sym_identifier] = ACTIONS(5081),
    [aux_sym_preproc_def_token1] = ACTIONS(5081),
    [aux_sym_preproc_if_token1] = ACTIONS(5081),
    [aux_sym_preproc_if_token2] = ACTIONS(5081),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5081),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5081),
    [sym_preproc_directive] = ACTIONS(5081),
    [anon_sym_LPAREN2] = ACTIONS(5083),
    [anon_sym_TILDE] = ACTIONS(5083),
    [anon_sym_STAR] = ACTIONS(5083),
    [anon_sym_AMP_AMP] = ACTIONS(5083),
    [anon_sym_AMP] = ACTIONS(5081),
    [anon_sym___extension__] = ACTIONS(5081),
    [anon_sym_typedef] = ACTIONS(5081),
    [anon_sym_in] = ACTIONS(5081),
    [anon_sym_out] = ACTIONS(5081),
    [anon_sym_inout] = ACTIONS(5081),
    [anon_sym_extern] = ACTIONS(5081),
    [anon_sym___attribute__] = ACTIONS(5081),
    [anon_sym_COLON_COLON] = ACTIONS(5083),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5083),
    [anon_sym___declspec] = ACTIONS(5081),
    [anon_sym___based] = ACTIONS(5081),
    [anon_sym_signed] = ACTIONS(5081),
    [anon_sym_unsigned] = ACTIONS(5081),
    [anon_sym_long] = ACTIONS(5081),
    [anon_sym_short] = ACTIONS(5081),
    [anon_sym_LBRACK] = ACTIONS(5081),
    [anon_sym_static] = ACTIONS(5081),
    [anon_sym_register] = ACTIONS(5081),
    [anon_sym_inline] = ACTIONS(5081),
    [anon_sym___inline] = ACTIONS(5081),
    [anon_sym___inline__] = ACTIONS(5081),
    [anon_sym___forceinline] = ACTIONS(5081),
    [anon_sym_thread_local] = ACTIONS(5081),
    [anon_sym___thread] = ACTIONS(5081),
    [anon_sym_const] = ACTIONS(5081),
    [anon_sym_constexpr] = ACTIONS(5081),
    [anon_sym_volatile] = ACTIONS(5081),
    [anon_sym_restrict] = ACTIONS(5081),
    [anon_sym___restrict__] = ACTIONS(5081),
    [anon_sym__Atomic] = ACTIONS(5081),
    [anon_sym__Noreturn] = ACTIONS(5081),
    [anon_sym_noreturn] = ACTIONS(5081),
    [anon_sym_mutable] = ACTIONS(5081),
    [anon_sym_constinit] = ACTIONS(5081),
    [anon_sym_consteval] = ACTIONS(5081),
    [anon_sym_alignas] = ACTIONS(5081),
    [anon_sym__Alignas] = ACTIONS(5081),
    [sym_primitive_type] = ACTIONS(5081),
    [anon_sym_enum] = ACTIONS(5081),
    [anon_sym_class] = ACTIONS(5081),
    [anon_sym_struct] = ACTIONS(5081),
    [anon_sym_union] = ACTIONS(5081),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5081),
    [anon_sym_decltype] = ACTIONS(5081),
    [sym_virtual] = ACTIONS(5081),
    [anon_sym_explicit] = ACTIONS(5081),
    [anon_sym_typename] = ACTIONS(5081),
    [anon_sym_template] = ACTIONS(5081),
    [anon_sym_operator] = ACTIONS(5081),
    [anon_sym_friend] = ACTIONS(5081),
    [anon_sym_public] = ACTIONS(5081),
    [anon_sym_private] = ACTIONS(5081),
    [anon_sym_protected] = ACTIONS(5081),
    [anon_sym_using] = ACTIONS(5081),
    [anon_sym_static_assert] = ACTIONS(5081),
    [anon_sym_precise] = ACTIONS(5081),
    [anon_sym_shared] = ACTIONS(5081),
    [anon_sym_groupshared] = ACTIONS(5081),
    [anon_sym_uniform] = ACTIONS(5081),
    [anon_sym_row_major] = ACTIONS(5081),
    [anon_sym_column_major] = ACTIONS(5081),
    [anon_sym_globallycoherent] = ACTIONS(5081),
    [anon_sym_centroid] = ACTIONS(5081),
    [anon_sym_noperspective] = ACTIONS(5081),
    [anon_sym_nointerpolation] = ACTIONS(5081),
    [anon_sym_sample] = ACTIONS(5081),
    [anon_sym_linear] = ACTIONS(5081),
    [anon_sym_snorm] = ACTIONS(5081),
    [anon_sym_unorm] = ACTIONS(5081),
    [anon_sym_point] = ACTIONS(5081),
    [anon_sym_line] = ACTIONS(5081),
    [anon_sym_triangleadj] = ACTIONS(5081),
    [anon_sym_lineadj] = ACTIONS(5081),
    [anon_sym_triangle] = ACTIONS(5081),
  },
  [2038] = {
    [sym_identifier] = ACTIONS(5009),
    [aux_sym_preproc_def_token1] = ACTIONS(5009),
    [aux_sym_preproc_if_token1] = ACTIONS(5009),
    [aux_sym_preproc_if_token2] = ACTIONS(5009),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5009),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5009),
    [sym_preproc_directive] = ACTIONS(5009),
    [anon_sym_LPAREN2] = ACTIONS(5011),
    [anon_sym_TILDE] = ACTIONS(5011),
    [anon_sym_STAR] = ACTIONS(5011),
    [anon_sym_AMP_AMP] = ACTIONS(5011),
    [anon_sym_AMP] = ACTIONS(5009),
    [anon_sym___extension__] = ACTIONS(5009),
    [anon_sym_typedef] = ACTIONS(5009),
    [anon_sym_in] = ACTIONS(5009),
    [anon_sym_out] = ACTIONS(5009),
    [anon_sym_inout] = ACTIONS(5009),
    [anon_sym_extern] = ACTIONS(5009),
    [anon_sym___attribute__] = ACTIONS(5009),
    [anon_sym_COLON_COLON] = ACTIONS(5011),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5011),
    [anon_sym___declspec] = ACTIONS(5009),
    [anon_sym___based] = ACTIONS(5009),
    [anon_sym_signed] = ACTIONS(5009),
    [anon_sym_unsigned] = ACTIONS(5009),
    [anon_sym_long] = ACTIONS(5009),
    [anon_sym_short] = ACTIONS(5009),
    [anon_sym_LBRACK] = ACTIONS(5009),
    [anon_sym_static] = ACTIONS(5009),
    [anon_sym_register] = ACTIONS(5009),
    [anon_sym_inline] = ACTIONS(5009),
    [anon_sym___inline] = ACTIONS(5009),
    [anon_sym___inline__] = ACTIONS(5009),
    [anon_sym___forceinline] = ACTIONS(5009),
    [anon_sym_thread_local] = ACTIONS(5009),
    [anon_sym___thread] = ACTIONS(5009),
    [anon_sym_const] = ACTIONS(5009),
    [anon_sym_constexpr] = ACTIONS(5009),
    [anon_sym_volatile] = ACTIONS(5009),
    [anon_sym_restrict] = ACTIONS(5009),
    [anon_sym___restrict__] = ACTIONS(5009),
    [anon_sym__Atomic] = ACTIONS(5009),
    [anon_sym__Noreturn] = ACTIONS(5009),
    [anon_sym_noreturn] = ACTIONS(5009),
    [anon_sym_mutable] = ACTIONS(5009),
    [anon_sym_constinit] = ACTIONS(5009),
    [anon_sym_consteval] = ACTIONS(5009),
    [anon_sym_alignas] = ACTIONS(5009),
    [anon_sym__Alignas] = ACTIONS(5009),
    [sym_primitive_type] = ACTIONS(5009),
    [anon_sym_enum] = ACTIONS(5009),
    [anon_sym_class] = ACTIONS(5009),
    [anon_sym_struct] = ACTIONS(5009),
    [anon_sym_union] = ACTIONS(5009),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5009),
    [anon_sym_decltype] = ACTIONS(5009),
    [sym_virtual] = ACTIONS(5009),
    [anon_sym_explicit] = ACTIONS(5009),
    [anon_sym_typename] = ACTIONS(5009),
    [anon_sym_template] = ACTIONS(5009),
    [anon_sym_operator] = ACTIONS(5009),
    [anon_sym_friend] = ACTIONS(5009),
    [anon_sym_public] = ACTIONS(5009),
    [anon_sym_private] = ACTIONS(5009),
    [anon_sym_protected] = ACTIONS(5009),
    [anon_sym_using] = ACTIONS(5009),
    [anon_sym_static_assert] = ACTIONS(5009),
    [anon_sym_precise] = ACTIONS(5009),
    [anon_sym_shared] = ACTIONS(5009),
    [anon_sym_groupshared] = ACTIONS(5009),
    [anon_sym_uniform] = ACTIONS(5009),
    [anon_sym_row_major] = ACTIONS(5009),
    [anon_sym_column_major] = ACTIONS(5009),
    [anon_sym_globallycoherent] = ACTIONS(5009),
    [anon_sym_centroid] = ACTIONS(5009),
    [anon_sym_noperspective] = ACTIONS(5009),
    [anon_sym_nointerpolation] = ACTIONS(5009),
    [anon_sym_sample] = ACTIONS(5009),
    [anon_sym_linear] = ACTIONS(5009),
    [anon_sym_snorm] = ACTIONS(5009),
    [anon_sym_unorm] = ACTIONS(5009),
    [anon_sym_point] = ACTIONS(5009),
    [anon_sym_line] = ACTIONS(5009),
    [anon_sym_triangleadj] = ACTIONS(5009),
    [anon_sym_lineadj] = ACTIONS(5009),
    [anon_sym_triangle] = ACTIONS(5009),
  },
  [2039] = {
    [sym_identifier] = ACTIONS(2502),
    [aux_sym_preproc_def_token1] = ACTIONS(2502),
    [aux_sym_preproc_if_token1] = ACTIONS(2502),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2502),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2502),
    [sym_preproc_directive] = ACTIONS(2502),
    [anon_sym_LPAREN2] = ACTIONS(2504),
    [anon_sym_TILDE] = ACTIONS(2504),
    [anon_sym_STAR] = ACTIONS(2504),
    [anon_sym_AMP_AMP] = ACTIONS(2504),
    [anon_sym_AMP] = ACTIONS(2502),
    [anon_sym___extension__] = ACTIONS(2502),
    [anon_sym_typedef] = ACTIONS(2502),
    [anon_sym_in] = ACTIONS(2502),
    [anon_sym_out] = ACTIONS(2502),
    [anon_sym_inout] = ACTIONS(2502),
    [anon_sym_extern] = ACTIONS(2502),
    [anon_sym___attribute__] = ACTIONS(2502),
    [anon_sym_COLON_COLON] = ACTIONS(2504),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2504),
    [anon_sym___declspec] = ACTIONS(2502),
    [anon_sym___based] = ACTIONS(2502),
    [anon_sym_RBRACE] = ACTIONS(2504),
    [anon_sym_signed] = ACTIONS(2502),
    [anon_sym_unsigned] = ACTIONS(2502),
    [anon_sym_long] = ACTIONS(2502),
    [anon_sym_short] = ACTIONS(2502),
    [anon_sym_LBRACK] = ACTIONS(2502),
    [anon_sym_static] = ACTIONS(2502),
    [anon_sym_register] = ACTIONS(2502),
    [anon_sym_inline] = ACTIONS(2502),
    [anon_sym___inline] = ACTIONS(2502),
    [anon_sym___inline__] = ACTIONS(2502),
    [anon_sym___forceinline] = ACTIONS(2502),
    [anon_sym_thread_local] = ACTIONS(2502),
    [anon_sym___thread] = ACTIONS(2502),
    [anon_sym_const] = ACTIONS(2502),
    [anon_sym_constexpr] = ACTIONS(2502),
    [anon_sym_volatile] = ACTIONS(2502),
    [anon_sym_restrict] = ACTIONS(2502),
    [anon_sym___restrict__] = ACTIONS(2502),
    [anon_sym__Atomic] = ACTIONS(2502),
    [anon_sym__Noreturn] = ACTIONS(2502),
    [anon_sym_noreturn] = ACTIONS(2502),
    [anon_sym_mutable] = ACTIONS(2502),
    [anon_sym_constinit] = ACTIONS(2502),
    [anon_sym_consteval] = ACTIONS(2502),
    [anon_sym_alignas] = ACTIONS(2502),
    [anon_sym__Alignas] = ACTIONS(2502),
    [sym_primitive_type] = ACTIONS(2502),
    [anon_sym_enum] = ACTIONS(2502),
    [anon_sym_class] = ACTIONS(2502),
    [anon_sym_struct] = ACTIONS(2502),
    [anon_sym_union] = ACTIONS(2502),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2502),
    [anon_sym_decltype] = ACTIONS(2502),
    [sym_virtual] = ACTIONS(2502),
    [anon_sym_explicit] = ACTIONS(2502),
    [anon_sym_typename] = ACTIONS(2502),
    [anon_sym_template] = ACTIONS(2502),
    [anon_sym_operator] = ACTIONS(2502),
    [anon_sym_friend] = ACTIONS(2502),
    [anon_sym_public] = ACTIONS(2502),
    [anon_sym_private] = ACTIONS(2502),
    [anon_sym_protected] = ACTIONS(2502),
    [anon_sym_using] = ACTIONS(2502),
    [anon_sym_static_assert] = ACTIONS(2502),
    [anon_sym_precise] = ACTIONS(2502),
    [anon_sym_shared] = ACTIONS(2502),
    [anon_sym_groupshared] = ACTIONS(2502),
    [anon_sym_uniform] = ACTIONS(2502),
    [anon_sym_row_major] = ACTIONS(2502),
    [anon_sym_column_major] = ACTIONS(2502),
    [anon_sym_globallycoherent] = ACTIONS(2502),
    [anon_sym_centroid] = ACTIONS(2502),
    [anon_sym_noperspective] = ACTIONS(2502),
    [anon_sym_nointerpolation] = ACTIONS(2502),
    [anon_sym_sample] = ACTIONS(2502),
    [anon_sym_linear] = ACTIONS(2502),
    [anon_sym_snorm] = ACTIONS(2502),
    [anon_sym_unorm] = ACTIONS(2502),
    [anon_sym_point] = ACTIONS(2502),
    [anon_sym_line] = ACTIONS(2502),
    [anon_sym_triangleadj] = ACTIONS(2502),
    [anon_sym_lineadj] = ACTIONS(2502),
    [anon_sym_triangle] = ACTIONS(2502),
  },
  [2040] = {
    [sym_identifier] = ACTIONS(5013),
    [aux_sym_preproc_def_token1] = ACTIONS(5013),
    [aux_sym_preproc_if_token1] = ACTIONS(5013),
    [aux_sym_preproc_if_token2] = ACTIONS(5013),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5013),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5013),
    [sym_preproc_directive] = ACTIONS(5013),
    [anon_sym_LPAREN2] = ACTIONS(5015),
    [anon_sym_TILDE] = ACTIONS(5015),
    [anon_sym_STAR] = ACTIONS(5015),
    [anon_sym_AMP_AMP] = ACTIONS(5015),
    [anon_sym_AMP] = ACTIONS(5013),
    [anon_sym___extension__] = ACTIONS(5013),
    [anon_sym_typedef] = ACTIONS(5013),
    [anon_sym_in] = ACTIONS(5013),
    [anon_sym_out] = ACTIONS(5013),
    [anon_sym_inout] = ACTIONS(5013),
    [anon_sym_extern] = ACTIONS(5013),
    [anon_sym___attribute__] = ACTIONS(5013),
    [anon_sym_COLON_COLON] = ACTIONS(5015),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5015),
    [anon_sym___declspec] = ACTIONS(5013),
    [anon_sym___based] = ACTIONS(5013),
    [anon_sym_signed] = ACTIONS(5013),
    [anon_sym_unsigned] = ACTIONS(5013),
    [anon_sym_long] = ACTIONS(5013),
    [anon_sym_short] = ACTIONS(5013),
    [anon_sym_LBRACK] = ACTIONS(5013),
    [anon_sym_static] = ACTIONS(5013),
    [anon_sym_register] = ACTIONS(5013),
    [anon_sym_inline] = ACTIONS(5013),
    [anon_sym___inline] = ACTIONS(5013),
    [anon_sym___inline__] = ACTIONS(5013),
    [anon_sym___forceinline] = ACTIONS(5013),
    [anon_sym_thread_local] = ACTIONS(5013),
    [anon_sym___thread] = ACTIONS(5013),
    [anon_sym_const] = ACTIONS(5013),
    [anon_sym_constexpr] = ACTIONS(5013),
    [anon_sym_volatile] = ACTIONS(5013),
    [anon_sym_restrict] = ACTIONS(5013),
    [anon_sym___restrict__] = ACTIONS(5013),
    [anon_sym__Atomic] = ACTIONS(5013),
    [anon_sym__Noreturn] = ACTIONS(5013),
    [anon_sym_noreturn] = ACTIONS(5013),
    [anon_sym_mutable] = ACTIONS(5013),
    [anon_sym_constinit] = ACTIONS(5013),
    [anon_sym_consteval] = ACTIONS(5013),
    [anon_sym_alignas] = ACTIONS(5013),
    [anon_sym__Alignas] = ACTIONS(5013),
    [sym_primitive_type] = ACTIONS(5013),
    [anon_sym_enum] = ACTIONS(5013),
    [anon_sym_class] = ACTIONS(5013),
    [anon_sym_struct] = ACTIONS(5013),
    [anon_sym_union] = ACTIONS(5013),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5013),
    [anon_sym_decltype] = ACTIONS(5013),
    [sym_virtual] = ACTIONS(5013),
    [anon_sym_explicit] = ACTIONS(5013),
    [anon_sym_typename] = ACTIONS(5013),
    [anon_sym_template] = ACTIONS(5013),
    [anon_sym_operator] = ACTIONS(5013),
    [anon_sym_friend] = ACTIONS(5013),
    [anon_sym_public] = ACTIONS(5013),
    [anon_sym_private] = ACTIONS(5013),
    [anon_sym_protected] = ACTIONS(5013),
    [anon_sym_using] = ACTIONS(5013),
    [anon_sym_static_assert] = ACTIONS(5013),
    [anon_sym_precise] = ACTIONS(5013),
    [anon_sym_shared] = ACTIONS(5013),
    [anon_sym_groupshared] = ACTIONS(5013),
    [anon_sym_uniform] = ACTIONS(5013),
    [anon_sym_row_major] = ACTIONS(5013),
    [anon_sym_column_major] = ACTIONS(5013),
    [anon_sym_globallycoherent] = ACTIONS(5013),
    [anon_sym_centroid] = ACTIONS(5013),
    [anon_sym_noperspective] = ACTIONS(5013),
    [anon_sym_nointerpolation] = ACTIONS(5013),
    [anon_sym_sample] = ACTIONS(5013),
    [anon_sym_linear] = ACTIONS(5013),
    [anon_sym_snorm] = ACTIONS(5013),
    [anon_sym_unorm] = ACTIONS(5013),
    [anon_sym_point] = ACTIONS(5013),
    [anon_sym_line] = ACTIONS(5013),
    [anon_sym_triangleadj] = ACTIONS(5013),
    [anon_sym_lineadj] = ACTIONS(5013),
    [anon_sym_triangle] = ACTIONS(5013),
  },
  [2041] = {
    [sym_identifier] = ACTIONS(5013),
    [aux_sym_preproc_def_token1] = ACTIONS(5013),
    [aux_sym_preproc_if_token1] = ACTIONS(5013),
    [aux_sym_preproc_if_token2] = ACTIONS(5013),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5013),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5013),
    [sym_preproc_directive] = ACTIONS(5013),
    [anon_sym_LPAREN2] = ACTIONS(5015),
    [anon_sym_TILDE] = ACTIONS(5015),
    [anon_sym_STAR] = ACTIONS(5015),
    [anon_sym_AMP_AMP] = ACTIONS(5015),
    [anon_sym_AMP] = ACTIONS(5013),
    [anon_sym___extension__] = ACTIONS(5013),
    [anon_sym_typedef] = ACTIONS(5013),
    [anon_sym_in] = ACTIONS(5013),
    [anon_sym_out] = ACTIONS(5013),
    [anon_sym_inout] = ACTIONS(5013),
    [anon_sym_extern] = ACTIONS(5013),
    [anon_sym___attribute__] = ACTIONS(5013),
    [anon_sym_COLON_COLON] = ACTIONS(5015),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5015),
    [anon_sym___declspec] = ACTIONS(5013),
    [anon_sym___based] = ACTIONS(5013),
    [anon_sym_signed] = ACTIONS(5013),
    [anon_sym_unsigned] = ACTIONS(5013),
    [anon_sym_long] = ACTIONS(5013),
    [anon_sym_short] = ACTIONS(5013),
    [anon_sym_LBRACK] = ACTIONS(5013),
    [anon_sym_static] = ACTIONS(5013),
    [anon_sym_register] = ACTIONS(5013),
    [anon_sym_inline] = ACTIONS(5013),
    [anon_sym___inline] = ACTIONS(5013),
    [anon_sym___inline__] = ACTIONS(5013),
    [anon_sym___forceinline] = ACTIONS(5013),
    [anon_sym_thread_local] = ACTIONS(5013),
    [anon_sym___thread] = ACTIONS(5013),
    [anon_sym_const] = ACTIONS(5013),
    [anon_sym_constexpr] = ACTIONS(5013),
    [anon_sym_volatile] = ACTIONS(5013),
    [anon_sym_restrict] = ACTIONS(5013),
    [anon_sym___restrict__] = ACTIONS(5013),
    [anon_sym__Atomic] = ACTIONS(5013),
    [anon_sym__Noreturn] = ACTIONS(5013),
    [anon_sym_noreturn] = ACTIONS(5013),
    [anon_sym_mutable] = ACTIONS(5013),
    [anon_sym_constinit] = ACTIONS(5013),
    [anon_sym_consteval] = ACTIONS(5013),
    [anon_sym_alignas] = ACTIONS(5013),
    [anon_sym__Alignas] = ACTIONS(5013),
    [sym_primitive_type] = ACTIONS(5013),
    [anon_sym_enum] = ACTIONS(5013),
    [anon_sym_class] = ACTIONS(5013),
    [anon_sym_struct] = ACTIONS(5013),
    [anon_sym_union] = ACTIONS(5013),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5013),
    [anon_sym_decltype] = ACTIONS(5013),
    [sym_virtual] = ACTIONS(5013),
    [anon_sym_explicit] = ACTIONS(5013),
    [anon_sym_typename] = ACTIONS(5013),
    [anon_sym_template] = ACTIONS(5013),
    [anon_sym_operator] = ACTIONS(5013),
    [anon_sym_friend] = ACTIONS(5013),
    [anon_sym_public] = ACTIONS(5013),
    [anon_sym_private] = ACTIONS(5013),
    [anon_sym_protected] = ACTIONS(5013),
    [anon_sym_using] = ACTIONS(5013),
    [anon_sym_static_assert] = ACTIONS(5013),
    [anon_sym_precise] = ACTIONS(5013),
    [anon_sym_shared] = ACTIONS(5013),
    [anon_sym_groupshared] = ACTIONS(5013),
    [anon_sym_uniform] = ACTIONS(5013),
    [anon_sym_row_major] = ACTIONS(5013),
    [anon_sym_column_major] = ACTIONS(5013),
    [anon_sym_globallycoherent] = ACTIONS(5013),
    [anon_sym_centroid] = ACTIONS(5013),
    [anon_sym_noperspective] = ACTIONS(5013),
    [anon_sym_nointerpolation] = ACTIONS(5013),
    [anon_sym_sample] = ACTIONS(5013),
    [anon_sym_linear] = ACTIONS(5013),
    [anon_sym_snorm] = ACTIONS(5013),
    [anon_sym_unorm] = ACTIONS(5013),
    [anon_sym_point] = ACTIONS(5013),
    [anon_sym_line] = ACTIONS(5013),
    [anon_sym_triangleadj] = ACTIONS(5013),
    [anon_sym_lineadj] = ACTIONS(5013),
    [anon_sym_triangle] = ACTIONS(5013),
  },
  [2042] = {
    [sym_identifier] = ACTIONS(2400),
    [aux_sym_preproc_def_token1] = ACTIONS(2400),
    [aux_sym_preproc_if_token1] = ACTIONS(2400),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2400),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2400),
    [sym_preproc_directive] = ACTIONS(2400),
    [anon_sym_LPAREN2] = ACTIONS(2402),
    [anon_sym_TILDE] = ACTIONS(2402),
    [anon_sym_STAR] = ACTIONS(2402),
    [anon_sym_AMP_AMP] = ACTIONS(2402),
    [anon_sym_AMP] = ACTIONS(2400),
    [anon_sym___extension__] = ACTIONS(2400),
    [anon_sym_typedef] = ACTIONS(2400),
    [anon_sym_in] = ACTIONS(2400),
    [anon_sym_out] = ACTIONS(2400),
    [anon_sym_inout] = ACTIONS(2400),
    [anon_sym_extern] = ACTIONS(2400),
    [anon_sym___attribute__] = ACTIONS(2400),
    [anon_sym_COLON_COLON] = ACTIONS(2402),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2402),
    [anon_sym___declspec] = ACTIONS(2400),
    [anon_sym___based] = ACTIONS(2400),
    [anon_sym_RBRACE] = ACTIONS(2402),
    [anon_sym_signed] = ACTIONS(2400),
    [anon_sym_unsigned] = ACTIONS(2400),
    [anon_sym_long] = ACTIONS(2400),
    [anon_sym_short] = ACTIONS(2400),
    [anon_sym_LBRACK] = ACTIONS(2400),
    [anon_sym_static] = ACTIONS(2400),
    [anon_sym_register] = ACTIONS(2400),
    [anon_sym_inline] = ACTIONS(2400),
    [anon_sym___inline] = ACTIONS(2400),
    [anon_sym___inline__] = ACTIONS(2400),
    [anon_sym___forceinline] = ACTIONS(2400),
    [anon_sym_thread_local] = ACTIONS(2400),
    [anon_sym___thread] = ACTIONS(2400),
    [anon_sym_const] = ACTIONS(2400),
    [anon_sym_constexpr] = ACTIONS(2400),
    [anon_sym_volatile] = ACTIONS(2400),
    [anon_sym_restrict] = ACTIONS(2400),
    [anon_sym___restrict__] = ACTIONS(2400),
    [anon_sym__Atomic] = ACTIONS(2400),
    [anon_sym__Noreturn] = ACTIONS(2400),
    [anon_sym_noreturn] = ACTIONS(2400),
    [anon_sym_mutable] = ACTIONS(2400),
    [anon_sym_constinit] = ACTIONS(2400),
    [anon_sym_consteval] = ACTIONS(2400),
    [anon_sym_alignas] = ACTIONS(2400),
    [anon_sym__Alignas] = ACTIONS(2400),
    [sym_primitive_type] = ACTIONS(2400),
    [anon_sym_enum] = ACTIONS(2400),
    [anon_sym_class] = ACTIONS(2400),
    [anon_sym_struct] = ACTIONS(2400),
    [anon_sym_union] = ACTIONS(2400),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2400),
    [anon_sym_decltype] = ACTIONS(2400),
    [sym_virtual] = ACTIONS(2400),
    [anon_sym_explicit] = ACTIONS(2400),
    [anon_sym_typename] = ACTIONS(2400),
    [anon_sym_template] = ACTIONS(2400),
    [anon_sym_operator] = ACTIONS(2400),
    [anon_sym_friend] = ACTIONS(2400),
    [anon_sym_public] = ACTIONS(2400),
    [anon_sym_private] = ACTIONS(2400),
    [anon_sym_protected] = ACTIONS(2400),
    [anon_sym_using] = ACTIONS(2400),
    [anon_sym_static_assert] = ACTIONS(2400),
    [anon_sym_precise] = ACTIONS(2400),
    [anon_sym_shared] = ACTIONS(2400),
    [anon_sym_groupshared] = ACTIONS(2400),
    [anon_sym_uniform] = ACTIONS(2400),
    [anon_sym_row_major] = ACTIONS(2400),
    [anon_sym_column_major] = ACTIONS(2400),
    [anon_sym_globallycoherent] = ACTIONS(2400),
    [anon_sym_centroid] = ACTIONS(2400),
    [anon_sym_noperspective] = ACTIONS(2400),
    [anon_sym_nointerpolation] = ACTIONS(2400),
    [anon_sym_sample] = ACTIONS(2400),
    [anon_sym_linear] = ACTIONS(2400),
    [anon_sym_snorm] = ACTIONS(2400),
    [anon_sym_unorm] = ACTIONS(2400),
    [anon_sym_point] = ACTIONS(2400),
    [anon_sym_line] = ACTIONS(2400),
    [anon_sym_triangleadj] = ACTIONS(2400),
    [anon_sym_lineadj] = ACTIONS(2400),
    [anon_sym_triangle] = ACTIONS(2400),
  },
  [2043] = {
    [sym_identifier] = ACTIONS(2272),
    [aux_sym_preproc_def_token1] = ACTIONS(2272),
    [aux_sym_preproc_if_token1] = ACTIONS(2272),
    [aux_sym_preproc_if_token2] = ACTIONS(2272),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2272),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2272),
    [sym_preproc_directive] = ACTIONS(2272),
    [anon_sym_LPAREN2] = ACTIONS(2274),
    [anon_sym_TILDE] = ACTIONS(2274),
    [anon_sym_STAR] = ACTIONS(2274),
    [anon_sym_AMP_AMP] = ACTIONS(2274),
    [anon_sym_AMP] = ACTIONS(2272),
    [anon_sym___extension__] = ACTIONS(2272),
    [anon_sym_typedef] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2272),
    [anon_sym_out] = ACTIONS(2272),
    [anon_sym_inout] = ACTIONS(2272),
    [anon_sym_extern] = ACTIONS(2272),
    [anon_sym___attribute__] = ACTIONS(2272),
    [anon_sym_COLON_COLON] = ACTIONS(2274),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2274),
    [anon_sym___declspec] = ACTIONS(2272),
    [anon_sym___based] = ACTIONS(2272),
    [anon_sym_signed] = ACTIONS(2272),
    [anon_sym_unsigned] = ACTIONS(2272),
    [anon_sym_long] = ACTIONS(2272),
    [anon_sym_short] = ACTIONS(2272),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(2272),
    [anon_sym_register] = ACTIONS(2272),
    [anon_sym_inline] = ACTIONS(2272),
    [anon_sym___inline] = ACTIONS(2272),
    [anon_sym___inline__] = ACTIONS(2272),
    [anon_sym___forceinline] = ACTIONS(2272),
    [anon_sym_thread_local] = ACTIONS(2272),
    [anon_sym___thread] = ACTIONS(2272),
    [anon_sym_const] = ACTIONS(2272),
    [anon_sym_constexpr] = ACTIONS(2272),
    [anon_sym_volatile] = ACTIONS(2272),
    [anon_sym_restrict] = ACTIONS(2272),
    [anon_sym___restrict__] = ACTIONS(2272),
    [anon_sym__Atomic] = ACTIONS(2272),
    [anon_sym__Noreturn] = ACTIONS(2272),
    [anon_sym_noreturn] = ACTIONS(2272),
    [anon_sym_mutable] = ACTIONS(2272),
    [anon_sym_constinit] = ACTIONS(2272),
    [anon_sym_consteval] = ACTIONS(2272),
    [anon_sym_alignas] = ACTIONS(2272),
    [anon_sym__Alignas] = ACTIONS(2272),
    [sym_primitive_type] = ACTIONS(2272),
    [anon_sym_enum] = ACTIONS(2272),
    [anon_sym_class] = ACTIONS(2272),
    [anon_sym_struct] = ACTIONS(2272),
    [anon_sym_union] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2272),
    [anon_sym_decltype] = ACTIONS(2272),
    [sym_virtual] = ACTIONS(2272),
    [anon_sym_explicit] = ACTIONS(2272),
    [anon_sym_typename] = ACTIONS(2272),
    [anon_sym_template] = ACTIONS(2272),
    [anon_sym_operator] = ACTIONS(2272),
    [anon_sym_friend] = ACTIONS(2272),
    [anon_sym_public] = ACTIONS(2272),
    [anon_sym_private] = ACTIONS(2272),
    [anon_sym_protected] = ACTIONS(2272),
    [anon_sym_using] = ACTIONS(2272),
    [anon_sym_static_assert] = ACTIONS(2272),
    [anon_sym_precise] = ACTIONS(2272),
    [anon_sym_shared] = ACTIONS(2272),
    [anon_sym_groupshared] = ACTIONS(2272),
    [anon_sym_uniform] = ACTIONS(2272),
    [anon_sym_row_major] = ACTIONS(2272),
    [anon_sym_column_major] = ACTIONS(2272),
    [anon_sym_globallycoherent] = ACTIONS(2272),
    [anon_sym_centroid] = ACTIONS(2272),
    [anon_sym_noperspective] = ACTIONS(2272),
    [anon_sym_nointerpolation] = ACTIONS(2272),
    [anon_sym_sample] = ACTIONS(2272),
    [anon_sym_linear] = ACTIONS(2272),
    [anon_sym_snorm] = ACTIONS(2272),
    [anon_sym_unorm] = ACTIONS(2272),
    [anon_sym_point] = ACTIONS(2272),
    [anon_sym_line] = ACTIONS(2272),
    [anon_sym_triangleadj] = ACTIONS(2272),
    [anon_sym_lineadj] = ACTIONS(2272),
    [anon_sym_triangle] = ACTIONS(2272),
  },
  [2044] = {
    [sym_identifier] = ACTIONS(2510),
    [aux_sym_preproc_def_token1] = ACTIONS(2510),
    [aux_sym_preproc_if_token1] = ACTIONS(2510),
    [aux_sym_preproc_if_token2] = ACTIONS(2510),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2510),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2510),
    [sym_preproc_directive] = ACTIONS(2510),
    [anon_sym_LPAREN2] = ACTIONS(2512),
    [anon_sym_TILDE] = ACTIONS(2512),
    [anon_sym_STAR] = ACTIONS(2512),
    [anon_sym_AMP_AMP] = ACTIONS(2512),
    [anon_sym_AMP] = ACTIONS(2510),
    [anon_sym___extension__] = ACTIONS(2510),
    [anon_sym_typedef] = ACTIONS(2510),
    [anon_sym_in] = ACTIONS(2510),
    [anon_sym_out] = ACTIONS(2510),
    [anon_sym_inout] = ACTIONS(2510),
    [anon_sym_extern] = ACTIONS(2510),
    [anon_sym___attribute__] = ACTIONS(2510),
    [anon_sym_COLON_COLON] = ACTIONS(2512),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2512),
    [anon_sym___declspec] = ACTIONS(2510),
    [anon_sym___based] = ACTIONS(2510),
    [anon_sym_signed] = ACTIONS(2510),
    [anon_sym_unsigned] = ACTIONS(2510),
    [anon_sym_long] = ACTIONS(2510),
    [anon_sym_short] = ACTIONS(2510),
    [anon_sym_LBRACK] = ACTIONS(2510),
    [anon_sym_static] = ACTIONS(2510),
    [anon_sym_register] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(2510),
    [anon_sym___inline] = ACTIONS(2510),
    [anon_sym___inline__] = ACTIONS(2510),
    [anon_sym___forceinline] = ACTIONS(2510),
    [anon_sym_thread_local] = ACTIONS(2510),
    [anon_sym___thread] = ACTIONS(2510),
    [anon_sym_const] = ACTIONS(2510),
    [anon_sym_constexpr] = ACTIONS(2510),
    [anon_sym_volatile] = ACTIONS(2510),
    [anon_sym_restrict] = ACTIONS(2510),
    [anon_sym___restrict__] = ACTIONS(2510),
    [anon_sym__Atomic] = ACTIONS(2510),
    [anon_sym__Noreturn] = ACTIONS(2510),
    [anon_sym_noreturn] = ACTIONS(2510),
    [anon_sym_mutable] = ACTIONS(2510),
    [anon_sym_constinit] = ACTIONS(2510),
    [anon_sym_consteval] = ACTIONS(2510),
    [anon_sym_alignas] = ACTIONS(2510),
    [anon_sym__Alignas] = ACTIONS(2510),
    [sym_primitive_type] = ACTIONS(2510),
    [anon_sym_enum] = ACTIONS(2510),
    [anon_sym_class] = ACTIONS(2510),
    [anon_sym_struct] = ACTIONS(2510),
    [anon_sym_union] = ACTIONS(2510),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2510),
    [anon_sym_decltype] = ACTIONS(2510),
    [sym_virtual] = ACTIONS(2510),
    [anon_sym_explicit] = ACTIONS(2510),
    [anon_sym_typename] = ACTIONS(2510),
    [anon_sym_template] = ACTIONS(2510),
    [anon_sym_operator] = ACTIONS(2510),
    [anon_sym_friend] = ACTIONS(2510),
    [anon_sym_public] = ACTIONS(2510),
    [anon_sym_private] = ACTIONS(2510),
    [anon_sym_protected] = ACTIONS(2510),
    [anon_sym_using] = ACTIONS(2510),
    [anon_sym_static_assert] = ACTIONS(2510),
    [anon_sym_precise] = ACTIONS(2510),
    [anon_sym_shared] = ACTIONS(2510),
    [anon_sym_groupshared] = ACTIONS(2510),
    [anon_sym_uniform] = ACTIONS(2510),
    [anon_sym_row_major] = ACTIONS(2510),
    [anon_sym_column_major] = ACTIONS(2510),
    [anon_sym_globallycoherent] = ACTIONS(2510),
    [anon_sym_centroid] = ACTIONS(2510),
    [anon_sym_noperspective] = ACTIONS(2510),
    [anon_sym_nointerpolation] = ACTIONS(2510),
    [anon_sym_sample] = ACTIONS(2510),
    [anon_sym_linear] = ACTIONS(2510),
    [anon_sym_snorm] = ACTIONS(2510),
    [anon_sym_unorm] = ACTIONS(2510),
    [anon_sym_point] = ACTIONS(2510),
    [anon_sym_line] = ACTIONS(2510),
    [anon_sym_triangleadj] = ACTIONS(2510),
    [anon_sym_lineadj] = ACTIONS(2510),
    [anon_sym_triangle] = ACTIONS(2510),
  },
  [2045] = {
    [sym_identifier] = ACTIONS(2204),
    [aux_sym_preproc_def_token1] = ACTIONS(2204),
    [aux_sym_preproc_if_token1] = ACTIONS(2204),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2204),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2204),
    [sym_preproc_directive] = ACTIONS(2204),
    [anon_sym_LPAREN2] = ACTIONS(2206),
    [anon_sym_TILDE] = ACTIONS(2206),
    [anon_sym_STAR] = ACTIONS(2206),
    [anon_sym_AMP_AMP] = ACTIONS(2206),
    [anon_sym_AMP] = ACTIONS(2204),
    [anon_sym___extension__] = ACTIONS(2204),
    [anon_sym_typedef] = ACTIONS(2204),
    [anon_sym_in] = ACTIONS(2204),
    [anon_sym_out] = ACTIONS(2204),
    [anon_sym_inout] = ACTIONS(2204),
    [anon_sym_extern] = ACTIONS(2204),
    [anon_sym___attribute__] = ACTIONS(2204),
    [anon_sym_COLON_COLON] = ACTIONS(2206),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2206),
    [anon_sym___declspec] = ACTIONS(2204),
    [anon_sym___based] = ACTIONS(2204),
    [anon_sym_RBRACE] = ACTIONS(2206),
    [anon_sym_signed] = ACTIONS(2204),
    [anon_sym_unsigned] = ACTIONS(2204),
    [anon_sym_long] = ACTIONS(2204),
    [anon_sym_short] = ACTIONS(2204),
    [anon_sym_LBRACK] = ACTIONS(2204),
    [anon_sym_static] = ACTIONS(2204),
    [anon_sym_register] = ACTIONS(2204),
    [anon_sym_inline] = ACTIONS(2204),
    [anon_sym___inline] = ACTIONS(2204),
    [anon_sym___inline__] = ACTIONS(2204),
    [anon_sym___forceinline] = ACTIONS(2204),
    [anon_sym_thread_local] = ACTIONS(2204),
    [anon_sym___thread] = ACTIONS(2204),
    [anon_sym_const] = ACTIONS(2204),
    [anon_sym_constexpr] = ACTIONS(2204),
    [anon_sym_volatile] = ACTIONS(2204),
    [anon_sym_restrict] = ACTIONS(2204),
    [anon_sym___restrict__] = ACTIONS(2204),
    [anon_sym__Atomic] = ACTIONS(2204),
    [anon_sym__Noreturn] = ACTIONS(2204),
    [anon_sym_noreturn] = ACTIONS(2204),
    [anon_sym_mutable] = ACTIONS(2204),
    [anon_sym_constinit] = ACTIONS(2204),
    [anon_sym_consteval] = ACTIONS(2204),
    [anon_sym_alignas] = ACTIONS(2204),
    [anon_sym__Alignas] = ACTIONS(2204),
    [sym_primitive_type] = ACTIONS(2204),
    [anon_sym_enum] = ACTIONS(2204),
    [anon_sym_class] = ACTIONS(2204),
    [anon_sym_struct] = ACTIONS(2204),
    [anon_sym_union] = ACTIONS(2204),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2204),
    [anon_sym_decltype] = ACTIONS(2204),
    [sym_virtual] = ACTIONS(2204),
    [anon_sym_explicit] = ACTIONS(2204),
    [anon_sym_typename] = ACTIONS(2204),
    [anon_sym_template] = ACTIONS(2204),
    [anon_sym_operator] = ACTIONS(2204),
    [anon_sym_friend] = ACTIONS(2204),
    [anon_sym_public] = ACTIONS(2204),
    [anon_sym_private] = ACTIONS(2204),
    [anon_sym_protected] = ACTIONS(2204),
    [anon_sym_using] = ACTIONS(2204),
    [anon_sym_static_assert] = ACTIONS(2204),
    [anon_sym_precise] = ACTIONS(2204),
    [anon_sym_shared] = ACTIONS(2204),
    [anon_sym_groupshared] = ACTIONS(2204),
    [anon_sym_uniform] = ACTIONS(2204),
    [anon_sym_row_major] = ACTIONS(2204),
    [anon_sym_column_major] = ACTIONS(2204),
    [anon_sym_globallycoherent] = ACTIONS(2204),
    [anon_sym_centroid] = ACTIONS(2204),
    [anon_sym_noperspective] = ACTIONS(2204),
    [anon_sym_nointerpolation] = ACTIONS(2204),
    [anon_sym_sample] = ACTIONS(2204),
    [anon_sym_linear] = ACTIONS(2204),
    [anon_sym_snorm] = ACTIONS(2204),
    [anon_sym_unorm] = ACTIONS(2204),
    [anon_sym_point] = ACTIONS(2204),
    [anon_sym_line] = ACTIONS(2204),
    [anon_sym_triangleadj] = ACTIONS(2204),
    [anon_sym_lineadj] = ACTIONS(2204),
    [anon_sym_triangle] = ACTIONS(2204),
  },
  [2046] = {
    [sym_identifier] = ACTIONS(2498),
    [aux_sym_preproc_def_token1] = ACTIONS(2498),
    [aux_sym_preproc_if_token1] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2498),
    [sym_preproc_directive] = ACTIONS(2498),
    [anon_sym_LPAREN2] = ACTIONS(2500),
    [anon_sym_TILDE] = ACTIONS(2500),
    [anon_sym_STAR] = ACTIONS(2500),
    [anon_sym_AMP_AMP] = ACTIONS(2500),
    [anon_sym_AMP] = ACTIONS(2498),
    [anon_sym___extension__] = ACTIONS(2498),
    [anon_sym_typedef] = ACTIONS(2498),
    [anon_sym_in] = ACTIONS(2498),
    [anon_sym_out] = ACTIONS(2498),
    [anon_sym_inout] = ACTIONS(2498),
    [anon_sym_extern] = ACTIONS(2498),
    [anon_sym___attribute__] = ACTIONS(2498),
    [anon_sym_COLON_COLON] = ACTIONS(2500),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2500),
    [anon_sym___declspec] = ACTIONS(2498),
    [anon_sym___based] = ACTIONS(2498),
    [anon_sym_RBRACE] = ACTIONS(2500),
    [anon_sym_signed] = ACTIONS(2498),
    [anon_sym_unsigned] = ACTIONS(2498),
    [anon_sym_long] = ACTIONS(2498),
    [anon_sym_short] = ACTIONS(2498),
    [anon_sym_LBRACK] = ACTIONS(2498),
    [anon_sym_static] = ACTIONS(2498),
    [anon_sym_register] = ACTIONS(2498),
    [anon_sym_inline] = ACTIONS(2498),
    [anon_sym___inline] = ACTIONS(2498),
    [anon_sym___inline__] = ACTIONS(2498),
    [anon_sym___forceinline] = ACTIONS(2498),
    [anon_sym_thread_local] = ACTIONS(2498),
    [anon_sym___thread] = ACTIONS(2498),
    [anon_sym_const] = ACTIONS(2498),
    [anon_sym_constexpr] = ACTIONS(2498),
    [anon_sym_volatile] = ACTIONS(2498),
    [anon_sym_restrict] = ACTIONS(2498),
    [anon_sym___restrict__] = ACTIONS(2498),
    [anon_sym__Atomic] = ACTIONS(2498),
    [anon_sym__Noreturn] = ACTIONS(2498),
    [anon_sym_noreturn] = ACTIONS(2498),
    [anon_sym_mutable] = ACTIONS(2498),
    [anon_sym_constinit] = ACTIONS(2498),
    [anon_sym_consteval] = ACTIONS(2498),
    [anon_sym_alignas] = ACTIONS(2498),
    [anon_sym__Alignas] = ACTIONS(2498),
    [sym_primitive_type] = ACTIONS(2498),
    [anon_sym_enum] = ACTIONS(2498),
    [anon_sym_class] = ACTIONS(2498),
    [anon_sym_struct] = ACTIONS(2498),
    [anon_sym_union] = ACTIONS(2498),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2498),
    [anon_sym_decltype] = ACTIONS(2498),
    [sym_virtual] = ACTIONS(2498),
    [anon_sym_explicit] = ACTIONS(2498),
    [anon_sym_typename] = ACTIONS(2498),
    [anon_sym_template] = ACTIONS(2498),
    [anon_sym_operator] = ACTIONS(2498),
    [anon_sym_friend] = ACTIONS(2498),
    [anon_sym_public] = ACTIONS(2498),
    [anon_sym_private] = ACTIONS(2498),
    [anon_sym_protected] = ACTIONS(2498),
    [anon_sym_using] = ACTIONS(2498),
    [anon_sym_static_assert] = ACTIONS(2498),
    [anon_sym_precise] = ACTIONS(2498),
    [anon_sym_shared] = ACTIONS(2498),
    [anon_sym_groupshared] = ACTIONS(2498),
    [anon_sym_uniform] = ACTIONS(2498),
    [anon_sym_row_major] = ACTIONS(2498),
    [anon_sym_column_major] = ACTIONS(2498),
    [anon_sym_globallycoherent] = ACTIONS(2498),
    [anon_sym_centroid] = ACTIONS(2498),
    [anon_sym_noperspective] = ACTIONS(2498),
    [anon_sym_nointerpolation] = ACTIONS(2498),
    [anon_sym_sample] = ACTIONS(2498),
    [anon_sym_linear] = ACTIONS(2498),
    [anon_sym_snorm] = ACTIONS(2498),
    [anon_sym_unorm] = ACTIONS(2498),
    [anon_sym_point] = ACTIONS(2498),
    [anon_sym_line] = ACTIONS(2498),
    [anon_sym_triangleadj] = ACTIONS(2498),
    [anon_sym_lineadj] = ACTIONS(2498),
    [anon_sym_triangle] = ACTIONS(2498),
  },
  [2047] = {
    [sym_identifier] = ACTIONS(2276),
    [aux_sym_preproc_def_token1] = ACTIONS(2276),
    [aux_sym_preproc_if_token1] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2276),
    [sym_preproc_directive] = ACTIONS(2276),
    [anon_sym_LPAREN2] = ACTIONS(2278),
    [anon_sym_TILDE] = ACTIONS(2278),
    [anon_sym_STAR] = ACTIONS(2278),
    [anon_sym_AMP_AMP] = ACTIONS(2278),
    [anon_sym_AMP] = ACTIONS(2276),
    [anon_sym___extension__] = ACTIONS(2276),
    [anon_sym_typedef] = ACTIONS(2276),
    [anon_sym_in] = ACTIONS(2276),
    [anon_sym_out] = ACTIONS(2276),
    [anon_sym_inout] = ACTIONS(2276),
    [anon_sym_extern] = ACTIONS(2276),
    [anon_sym___attribute__] = ACTIONS(2276),
    [anon_sym_COLON_COLON] = ACTIONS(2278),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2278),
    [anon_sym___declspec] = ACTIONS(2276),
    [anon_sym___based] = ACTIONS(2276),
    [anon_sym_RBRACE] = ACTIONS(2278),
    [anon_sym_signed] = ACTIONS(2276),
    [anon_sym_unsigned] = ACTIONS(2276),
    [anon_sym_long] = ACTIONS(2276),
    [anon_sym_short] = ACTIONS(2276),
    [anon_sym_LBRACK] = ACTIONS(2276),
    [anon_sym_static] = ACTIONS(2276),
    [anon_sym_register] = ACTIONS(2276),
    [anon_sym_inline] = ACTIONS(2276),
    [anon_sym___inline] = ACTIONS(2276),
    [anon_sym___inline__] = ACTIONS(2276),
    [anon_sym___forceinline] = ACTIONS(2276),
    [anon_sym_thread_local] = ACTIONS(2276),
    [anon_sym___thread] = ACTIONS(2276),
    [anon_sym_const] = ACTIONS(2276),
    [anon_sym_constexpr] = ACTIONS(2276),
    [anon_sym_volatile] = ACTIONS(2276),
    [anon_sym_restrict] = ACTIONS(2276),
    [anon_sym___restrict__] = ACTIONS(2276),
    [anon_sym__Atomic] = ACTIONS(2276),
    [anon_sym__Noreturn] = ACTIONS(2276),
    [anon_sym_noreturn] = ACTIONS(2276),
    [anon_sym_mutable] = ACTIONS(2276),
    [anon_sym_constinit] = ACTIONS(2276),
    [anon_sym_consteval] = ACTIONS(2276),
    [anon_sym_alignas] = ACTIONS(2276),
    [anon_sym__Alignas] = ACTIONS(2276),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2276),
    [anon_sym_class] = ACTIONS(2276),
    [anon_sym_struct] = ACTIONS(2276),
    [anon_sym_union] = ACTIONS(2276),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2276),
    [anon_sym_decltype] = ACTIONS(2276),
    [sym_virtual] = ACTIONS(2276),
    [anon_sym_explicit] = ACTIONS(2276),
    [anon_sym_typename] = ACTIONS(2276),
    [anon_sym_template] = ACTIONS(2276),
    [anon_sym_operator] = ACTIONS(2276),
    [anon_sym_friend] = ACTIONS(2276),
    [anon_sym_public] = ACTIONS(2276),
    [anon_sym_private] = ACTIONS(2276),
    [anon_sym_protected] = ACTIONS(2276),
    [anon_sym_using] = ACTIONS(2276),
    [anon_sym_static_assert] = ACTIONS(2276),
    [anon_sym_precise] = ACTIONS(2276),
    [anon_sym_shared] = ACTIONS(2276),
    [anon_sym_groupshared] = ACTIONS(2276),
    [anon_sym_uniform] = ACTIONS(2276),
    [anon_sym_row_major] = ACTIONS(2276),
    [anon_sym_column_major] = ACTIONS(2276),
    [anon_sym_globallycoherent] = ACTIONS(2276),
    [anon_sym_centroid] = ACTIONS(2276),
    [anon_sym_noperspective] = ACTIONS(2276),
    [anon_sym_nointerpolation] = ACTIONS(2276),
    [anon_sym_sample] = ACTIONS(2276),
    [anon_sym_linear] = ACTIONS(2276),
    [anon_sym_snorm] = ACTIONS(2276),
    [anon_sym_unorm] = ACTIONS(2276),
    [anon_sym_point] = ACTIONS(2276),
    [anon_sym_line] = ACTIONS(2276),
    [anon_sym_triangleadj] = ACTIONS(2276),
    [anon_sym_lineadj] = ACTIONS(2276),
    [anon_sym_triangle] = ACTIONS(2276),
  },
  [2048] = {
    [sym_identifier] = ACTIONS(2118),
    [aux_sym_preproc_def_token1] = ACTIONS(2118),
    [aux_sym_preproc_if_token1] = ACTIONS(2118),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2118),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2118),
    [sym_preproc_directive] = ACTIONS(2118),
    [anon_sym_LPAREN2] = ACTIONS(2120),
    [anon_sym_TILDE] = ACTIONS(2120),
    [anon_sym_STAR] = ACTIONS(2120),
    [anon_sym_AMP_AMP] = ACTIONS(2120),
    [anon_sym_AMP] = ACTIONS(2118),
    [anon_sym___extension__] = ACTIONS(2118),
    [anon_sym_typedef] = ACTIONS(2118),
    [anon_sym_in] = ACTIONS(2118),
    [anon_sym_out] = ACTIONS(2118),
    [anon_sym_inout] = ACTIONS(2118),
    [anon_sym_extern] = ACTIONS(2118),
    [anon_sym___attribute__] = ACTIONS(2118),
    [anon_sym_COLON_COLON] = ACTIONS(2120),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2120),
    [anon_sym___declspec] = ACTIONS(2118),
    [anon_sym___based] = ACTIONS(2118),
    [anon_sym_RBRACE] = ACTIONS(2120),
    [anon_sym_signed] = ACTIONS(2118),
    [anon_sym_unsigned] = ACTIONS(2118),
    [anon_sym_long] = ACTIONS(2118),
    [anon_sym_short] = ACTIONS(2118),
    [anon_sym_LBRACK] = ACTIONS(2118),
    [anon_sym_static] = ACTIONS(2118),
    [anon_sym_register] = ACTIONS(2118),
    [anon_sym_inline] = ACTIONS(2118),
    [anon_sym___inline] = ACTIONS(2118),
    [anon_sym___inline__] = ACTIONS(2118),
    [anon_sym___forceinline] = ACTIONS(2118),
    [anon_sym_thread_local] = ACTIONS(2118),
    [anon_sym___thread] = ACTIONS(2118),
    [anon_sym_const] = ACTIONS(2118),
    [anon_sym_constexpr] = ACTIONS(2118),
    [anon_sym_volatile] = ACTIONS(2118),
    [anon_sym_restrict] = ACTIONS(2118),
    [anon_sym___restrict__] = ACTIONS(2118),
    [anon_sym__Atomic] = ACTIONS(2118),
    [anon_sym__Noreturn] = ACTIONS(2118),
    [anon_sym_noreturn] = ACTIONS(2118),
    [anon_sym_mutable] = ACTIONS(2118),
    [anon_sym_constinit] = ACTIONS(2118),
    [anon_sym_consteval] = ACTIONS(2118),
    [anon_sym_alignas] = ACTIONS(2118),
    [anon_sym__Alignas] = ACTIONS(2118),
    [sym_primitive_type] = ACTIONS(2118),
    [anon_sym_enum] = ACTIONS(2118),
    [anon_sym_class] = ACTIONS(2118),
    [anon_sym_struct] = ACTIONS(2118),
    [anon_sym_union] = ACTIONS(2118),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2118),
    [anon_sym_decltype] = ACTIONS(2118),
    [sym_virtual] = ACTIONS(2118),
    [anon_sym_explicit] = ACTIONS(2118),
    [anon_sym_typename] = ACTIONS(2118),
    [anon_sym_template] = ACTIONS(2118),
    [anon_sym_operator] = ACTIONS(2118),
    [anon_sym_friend] = ACTIONS(2118),
    [anon_sym_public] = ACTIONS(2118),
    [anon_sym_private] = ACTIONS(2118),
    [anon_sym_protected] = ACTIONS(2118),
    [anon_sym_using] = ACTIONS(2118),
    [anon_sym_static_assert] = ACTIONS(2118),
    [anon_sym_precise] = ACTIONS(2118),
    [anon_sym_shared] = ACTIONS(2118),
    [anon_sym_groupshared] = ACTIONS(2118),
    [anon_sym_uniform] = ACTIONS(2118),
    [anon_sym_row_major] = ACTIONS(2118),
    [anon_sym_column_major] = ACTIONS(2118),
    [anon_sym_globallycoherent] = ACTIONS(2118),
    [anon_sym_centroid] = ACTIONS(2118),
    [anon_sym_noperspective] = ACTIONS(2118),
    [anon_sym_nointerpolation] = ACTIONS(2118),
    [anon_sym_sample] = ACTIONS(2118),
    [anon_sym_linear] = ACTIONS(2118),
    [anon_sym_snorm] = ACTIONS(2118),
    [anon_sym_unorm] = ACTIONS(2118),
    [anon_sym_point] = ACTIONS(2118),
    [anon_sym_line] = ACTIONS(2118),
    [anon_sym_triangleadj] = ACTIONS(2118),
    [anon_sym_lineadj] = ACTIONS(2118),
    [anon_sym_triangle] = ACTIONS(2118),
  },
  [2049] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token2] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_friend] = ACTIONS(2324),
    [anon_sym_public] = ACTIONS(2324),
    [anon_sym_private] = ACTIONS(2324),
    [anon_sym_protected] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
  },
  [2050] = {
    [sym_identifier] = ACTIONS(2340),
    [aux_sym_preproc_def_token1] = ACTIONS(2340),
    [aux_sym_preproc_if_token1] = ACTIONS(2340),
    [aux_sym_preproc_if_token2] = ACTIONS(2340),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2340),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2340),
    [sym_preproc_directive] = ACTIONS(2340),
    [anon_sym_LPAREN2] = ACTIONS(2342),
    [anon_sym_TILDE] = ACTIONS(2342),
    [anon_sym_STAR] = ACTIONS(2342),
    [anon_sym_AMP_AMP] = ACTIONS(2342),
    [anon_sym_AMP] = ACTIONS(2340),
    [anon_sym___extension__] = ACTIONS(2340),
    [anon_sym_typedef] = ACTIONS(2340),
    [anon_sym_in] = ACTIONS(2340),
    [anon_sym_out] = ACTIONS(2340),
    [anon_sym_inout] = ACTIONS(2340),
    [anon_sym_extern] = ACTIONS(2340),
    [anon_sym___attribute__] = ACTIONS(2340),
    [anon_sym_COLON_COLON] = ACTIONS(2342),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2342),
    [anon_sym___declspec] = ACTIONS(2340),
    [anon_sym___based] = ACTIONS(2340),
    [anon_sym_signed] = ACTIONS(2340),
    [anon_sym_unsigned] = ACTIONS(2340),
    [anon_sym_long] = ACTIONS(2340),
    [anon_sym_short] = ACTIONS(2340),
    [anon_sym_LBRACK] = ACTIONS(2340),
    [anon_sym_static] = ACTIONS(2340),
    [anon_sym_register] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(2340),
    [anon_sym___inline] = ACTIONS(2340),
    [anon_sym___inline__] = ACTIONS(2340),
    [anon_sym___forceinline] = ACTIONS(2340),
    [anon_sym_thread_local] = ACTIONS(2340),
    [anon_sym___thread] = ACTIONS(2340),
    [anon_sym_const] = ACTIONS(2340),
    [anon_sym_constexpr] = ACTIONS(2340),
    [anon_sym_volatile] = ACTIONS(2340),
    [anon_sym_restrict] = ACTIONS(2340),
    [anon_sym___restrict__] = ACTIONS(2340),
    [anon_sym__Atomic] = ACTIONS(2340),
    [anon_sym__Noreturn] = ACTIONS(2340),
    [anon_sym_noreturn] = ACTIONS(2340),
    [anon_sym_mutable] = ACTIONS(2340),
    [anon_sym_constinit] = ACTIONS(2340),
    [anon_sym_consteval] = ACTIONS(2340),
    [anon_sym_alignas] = ACTIONS(2340),
    [anon_sym__Alignas] = ACTIONS(2340),
    [sym_primitive_type] = ACTIONS(2340),
    [anon_sym_enum] = ACTIONS(2340),
    [anon_sym_class] = ACTIONS(2340),
    [anon_sym_struct] = ACTIONS(2340),
    [anon_sym_union] = ACTIONS(2340),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2340),
    [anon_sym_decltype] = ACTIONS(2340),
    [sym_virtual] = ACTIONS(2340),
    [anon_sym_explicit] = ACTIONS(2340),
    [anon_sym_typename] = ACTIONS(2340),
    [anon_sym_template] = ACTIONS(2340),
    [anon_sym_operator] = ACTIONS(2340),
    [anon_sym_friend] = ACTIONS(2340),
    [anon_sym_public] = ACTIONS(2340),
    [anon_sym_private] = ACTIONS(2340),
    [anon_sym_protected] = ACTIONS(2340),
    [anon_sym_using] = ACTIONS(2340),
    [anon_sym_static_assert] = ACTIONS(2340),
    [anon_sym_precise] = ACTIONS(2340),
    [anon_sym_shared] = ACTIONS(2340),
    [anon_sym_groupshared] = ACTIONS(2340),
    [anon_sym_uniform] = ACTIONS(2340),
    [anon_sym_row_major] = ACTIONS(2340),
    [anon_sym_column_major] = ACTIONS(2340),
    [anon_sym_globallycoherent] = ACTIONS(2340),
    [anon_sym_centroid] = ACTIONS(2340),
    [anon_sym_noperspective] = ACTIONS(2340),
    [anon_sym_nointerpolation] = ACTIONS(2340),
    [anon_sym_sample] = ACTIONS(2340),
    [anon_sym_linear] = ACTIONS(2340),
    [anon_sym_snorm] = ACTIONS(2340),
    [anon_sym_unorm] = ACTIONS(2340),
    [anon_sym_point] = ACTIONS(2340),
    [anon_sym_line] = ACTIONS(2340),
    [anon_sym_triangleadj] = ACTIONS(2340),
    [anon_sym_lineadj] = ACTIONS(2340),
    [anon_sym_triangle] = ACTIONS(2340),
  },
  [2051] = {
    [sym_identifier] = ACTIONS(2356),
    [aux_sym_preproc_def_token1] = ACTIONS(2356),
    [aux_sym_preproc_if_token1] = ACTIONS(2356),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2356),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2356),
    [sym_preproc_directive] = ACTIONS(2356),
    [anon_sym_LPAREN2] = ACTIONS(2358),
    [anon_sym_TILDE] = ACTIONS(2358),
    [anon_sym_STAR] = ACTIONS(2358),
    [anon_sym_AMP_AMP] = ACTIONS(2358),
    [anon_sym_AMP] = ACTIONS(2356),
    [anon_sym___extension__] = ACTIONS(2356),
    [anon_sym_typedef] = ACTIONS(2356),
    [anon_sym_in] = ACTIONS(2356),
    [anon_sym_out] = ACTIONS(2356),
    [anon_sym_inout] = ACTIONS(2356),
    [anon_sym_extern] = ACTIONS(2356),
    [anon_sym___attribute__] = ACTIONS(2356),
    [anon_sym_COLON_COLON] = ACTIONS(2358),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2358),
    [anon_sym___declspec] = ACTIONS(2356),
    [anon_sym___based] = ACTIONS(2356),
    [anon_sym_RBRACE] = ACTIONS(2358),
    [anon_sym_signed] = ACTIONS(2356),
    [anon_sym_unsigned] = ACTIONS(2356),
    [anon_sym_long] = ACTIONS(2356),
    [anon_sym_short] = ACTIONS(2356),
    [anon_sym_LBRACK] = ACTIONS(2356),
    [anon_sym_static] = ACTIONS(2356),
    [anon_sym_register] = ACTIONS(2356),
    [anon_sym_inline] = ACTIONS(2356),
    [anon_sym___inline] = ACTIONS(2356),
    [anon_sym___inline__] = ACTIONS(2356),
    [anon_sym___forceinline] = ACTIONS(2356),
    [anon_sym_thread_local] = ACTIONS(2356),
    [anon_sym___thread] = ACTIONS(2356),
    [anon_sym_const] = ACTIONS(2356),
    [anon_sym_constexpr] = ACTIONS(2356),
    [anon_sym_volatile] = ACTIONS(2356),
    [anon_sym_restrict] = ACTIONS(2356),
    [anon_sym___restrict__] = ACTIONS(2356),
    [anon_sym__Atomic] = ACTIONS(2356),
    [anon_sym__Noreturn] = ACTIONS(2356),
    [anon_sym_noreturn] = ACTIONS(2356),
    [anon_sym_mutable] = ACTIONS(2356),
    [anon_sym_constinit] = ACTIONS(2356),
    [anon_sym_consteval] = ACTIONS(2356),
    [anon_sym_alignas] = ACTIONS(2356),
    [anon_sym__Alignas] = ACTIONS(2356),
    [sym_primitive_type] = ACTIONS(2356),
    [anon_sym_enum] = ACTIONS(2356),
    [anon_sym_class] = ACTIONS(2356),
    [anon_sym_struct] = ACTIONS(2356),
    [anon_sym_union] = ACTIONS(2356),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2356),
    [anon_sym_decltype] = ACTIONS(2356),
    [sym_virtual] = ACTIONS(2356),
    [anon_sym_explicit] = ACTIONS(2356),
    [anon_sym_typename] = ACTIONS(2356),
    [anon_sym_template] = ACTIONS(2356),
    [anon_sym_operator] = ACTIONS(2356),
    [anon_sym_friend] = ACTIONS(2356),
    [anon_sym_public] = ACTIONS(2356),
    [anon_sym_private] = ACTIONS(2356),
    [anon_sym_protected] = ACTIONS(2356),
    [anon_sym_using] = ACTIONS(2356),
    [anon_sym_static_assert] = ACTIONS(2356),
    [anon_sym_precise] = ACTIONS(2356),
    [anon_sym_shared] = ACTIONS(2356),
    [anon_sym_groupshared] = ACTIONS(2356),
    [anon_sym_uniform] = ACTIONS(2356),
    [anon_sym_row_major] = ACTIONS(2356),
    [anon_sym_column_major] = ACTIONS(2356),
    [anon_sym_globallycoherent] = ACTIONS(2356),
    [anon_sym_centroid] = ACTIONS(2356),
    [anon_sym_noperspective] = ACTIONS(2356),
    [anon_sym_nointerpolation] = ACTIONS(2356),
    [anon_sym_sample] = ACTIONS(2356),
    [anon_sym_linear] = ACTIONS(2356),
    [anon_sym_snorm] = ACTIONS(2356),
    [anon_sym_unorm] = ACTIONS(2356),
    [anon_sym_point] = ACTIONS(2356),
    [anon_sym_line] = ACTIONS(2356),
    [anon_sym_triangleadj] = ACTIONS(2356),
    [anon_sym_lineadj] = ACTIONS(2356),
    [anon_sym_triangle] = ACTIONS(2356),
  },
  [2052] = {
    [sym_identifier] = ACTIONS(2336),
    [aux_sym_preproc_def_token1] = ACTIONS(2336),
    [aux_sym_preproc_if_token1] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2336),
    [sym_preproc_directive] = ACTIONS(2336),
    [anon_sym_LPAREN2] = ACTIONS(2338),
    [anon_sym_TILDE] = ACTIONS(2338),
    [anon_sym_STAR] = ACTIONS(2338),
    [anon_sym_AMP_AMP] = ACTIONS(2338),
    [anon_sym_AMP] = ACTIONS(2336),
    [anon_sym___extension__] = ACTIONS(2336),
    [anon_sym_typedef] = ACTIONS(2336),
    [anon_sym_in] = ACTIONS(2336),
    [anon_sym_out] = ACTIONS(2336),
    [anon_sym_inout] = ACTIONS(2336),
    [anon_sym_extern] = ACTIONS(2336),
    [anon_sym___attribute__] = ACTIONS(2336),
    [anon_sym_COLON_COLON] = ACTIONS(2338),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2338),
    [anon_sym___declspec] = ACTIONS(2336),
    [anon_sym___based] = ACTIONS(2336),
    [anon_sym_RBRACE] = ACTIONS(2338),
    [anon_sym_signed] = ACTIONS(2336),
    [anon_sym_unsigned] = ACTIONS(2336),
    [anon_sym_long] = ACTIONS(2336),
    [anon_sym_short] = ACTIONS(2336),
    [anon_sym_LBRACK] = ACTIONS(2336),
    [anon_sym_static] = ACTIONS(2336),
    [anon_sym_register] = ACTIONS(2336),
    [anon_sym_inline] = ACTIONS(2336),
    [anon_sym___inline] = ACTIONS(2336),
    [anon_sym___inline__] = ACTIONS(2336),
    [anon_sym___forceinline] = ACTIONS(2336),
    [anon_sym_thread_local] = ACTIONS(2336),
    [anon_sym___thread] = ACTIONS(2336),
    [anon_sym_const] = ACTIONS(2336),
    [anon_sym_constexpr] = ACTIONS(2336),
    [anon_sym_volatile] = ACTIONS(2336),
    [anon_sym_restrict] = ACTIONS(2336),
    [anon_sym___restrict__] = ACTIONS(2336),
    [anon_sym__Atomic] = ACTIONS(2336),
    [anon_sym__Noreturn] = ACTIONS(2336),
    [anon_sym_noreturn] = ACTIONS(2336),
    [anon_sym_mutable] = ACTIONS(2336),
    [anon_sym_constinit] = ACTIONS(2336),
    [anon_sym_consteval] = ACTIONS(2336),
    [anon_sym_alignas] = ACTIONS(2336),
    [anon_sym__Alignas] = ACTIONS(2336),
    [sym_primitive_type] = ACTIONS(2336),
    [anon_sym_enum] = ACTIONS(2336),
    [anon_sym_class] = ACTIONS(2336),
    [anon_sym_struct] = ACTIONS(2336),
    [anon_sym_union] = ACTIONS(2336),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2336),
    [anon_sym_decltype] = ACTIONS(2336),
    [sym_virtual] = ACTIONS(2336),
    [anon_sym_explicit] = ACTIONS(2336),
    [anon_sym_typename] = ACTIONS(2336),
    [anon_sym_template] = ACTIONS(2336),
    [anon_sym_operator] = ACTIONS(2336),
    [anon_sym_friend] = ACTIONS(2336),
    [anon_sym_public] = ACTIONS(2336),
    [anon_sym_private] = ACTIONS(2336),
    [anon_sym_protected] = ACTIONS(2336),
    [anon_sym_using] = ACTIONS(2336),
    [anon_sym_static_assert] = ACTIONS(2336),
    [anon_sym_precise] = ACTIONS(2336),
    [anon_sym_shared] = ACTIONS(2336),
    [anon_sym_groupshared] = ACTIONS(2336),
    [anon_sym_uniform] = ACTIONS(2336),
    [anon_sym_row_major] = ACTIONS(2336),
    [anon_sym_column_major] = ACTIONS(2336),
    [anon_sym_globallycoherent] = ACTIONS(2336),
    [anon_sym_centroid] = ACTIONS(2336),
    [anon_sym_noperspective] = ACTIONS(2336),
    [anon_sym_nointerpolation] = ACTIONS(2336),
    [anon_sym_sample] = ACTIONS(2336),
    [anon_sym_linear] = ACTIONS(2336),
    [anon_sym_snorm] = ACTIONS(2336),
    [anon_sym_unorm] = ACTIONS(2336),
    [anon_sym_point] = ACTIONS(2336),
    [anon_sym_line] = ACTIONS(2336),
    [anon_sym_triangleadj] = ACTIONS(2336),
    [anon_sym_lineadj] = ACTIONS(2336),
    [anon_sym_triangle] = ACTIONS(2336),
  },
  [2053] = {
    [sym_identifier] = ACTIONS(2336),
    [aux_sym_preproc_def_token1] = ACTIONS(2336),
    [aux_sym_preproc_if_token1] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2336),
    [sym_preproc_directive] = ACTIONS(2336),
    [anon_sym_LPAREN2] = ACTIONS(2338),
    [anon_sym_TILDE] = ACTIONS(2338),
    [anon_sym_STAR] = ACTIONS(2338),
    [anon_sym_AMP_AMP] = ACTIONS(2338),
    [anon_sym_AMP] = ACTIONS(2336),
    [anon_sym___extension__] = ACTIONS(2336),
    [anon_sym_typedef] = ACTIONS(2336),
    [anon_sym_in] = ACTIONS(2336),
    [anon_sym_out] = ACTIONS(2336),
    [anon_sym_inout] = ACTIONS(2336),
    [anon_sym_extern] = ACTIONS(2336),
    [anon_sym___attribute__] = ACTIONS(2336),
    [anon_sym_COLON_COLON] = ACTIONS(2338),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2338),
    [anon_sym___declspec] = ACTIONS(2336),
    [anon_sym___based] = ACTIONS(2336),
    [anon_sym_RBRACE] = ACTIONS(2338),
    [anon_sym_signed] = ACTIONS(2336),
    [anon_sym_unsigned] = ACTIONS(2336),
    [anon_sym_long] = ACTIONS(2336),
    [anon_sym_short] = ACTIONS(2336),
    [anon_sym_LBRACK] = ACTIONS(2336),
    [anon_sym_static] = ACTIONS(2336),
    [anon_sym_register] = ACTIONS(2336),
    [anon_sym_inline] = ACTIONS(2336),
    [anon_sym___inline] = ACTIONS(2336),
    [anon_sym___inline__] = ACTIONS(2336),
    [anon_sym___forceinline] = ACTIONS(2336),
    [anon_sym_thread_local] = ACTIONS(2336),
    [anon_sym___thread] = ACTIONS(2336),
    [anon_sym_const] = ACTIONS(2336),
    [anon_sym_constexpr] = ACTIONS(2336),
    [anon_sym_volatile] = ACTIONS(2336),
    [anon_sym_restrict] = ACTIONS(2336),
    [anon_sym___restrict__] = ACTIONS(2336),
    [anon_sym__Atomic] = ACTIONS(2336),
    [anon_sym__Noreturn] = ACTIONS(2336),
    [anon_sym_noreturn] = ACTIONS(2336),
    [anon_sym_mutable] = ACTIONS(2336),
    [anon_sym_constinit] = ACTIONS(2336),
    [anon_sym_consteval] = ACTIONS(2336),
    [anon_sym_alignas] = ACTIONS(2336),
    [anon_sym__Alignas] = ACTIONS(2336),
    [sym_primitive_type] = ACTIONS(2336),
    [anon_sym_enum] = ACTIONS(2336),
    [anon_sym_class] = ACTIONS(2336),
    [anon_sym_struct] = ACTIONS(2336),
    [anon_sym_union] = ACTIONS(2336),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2336),
    [anon_sym_decltype] = ACTIONS(2336),
    [sym_virtual] = ACTIONS(2336),
    [anon_sym_explicit] = ACTIONS(2336),
    [anon_sym_typename] = ACTIONS(2336),
    [anon_sym_template] = ACTIONS(2336),
    [anon_sym_operator] = ACTIONS(2336),
    [anon_sym_friend] = ACTIONS(2336),
    [anon_sym_public] = ACTIONS(2336),
    [anon_sym_private] = ACTIONS(2336),
    [anon_sym_protected] = ACTIONS(2336),
    [anon_sym_using] = ACTIONS(2336),
    [anon_sym_static_assert] = ACTIONS(2336),
    [anon_sym_precise] = ACTIONS(2336),
    [anon_sym_shared] = ACTIONS(2336),
    [anon_sym_groupshared] = ACTIONS(2336),
    [anon_sym_uniform] = ACTIONS(2336),
    [anon_sym_row_major] = ACTIONS(2336),
    [anon_sym_column_major] = ACTIONS(2336),
    [anon_sym_globallycoherent] = ACTIONS(2336),
    [anon_sym_centroid] = ACTIONS(2336),
    [anon_sym_noperspective] = ACTIONS(2336),
    [anon_sym_nointerpolation] = ACTIONS(2336),
    [anon_sym_sample] = ACTIONS(2336),
    [anon_sym_linear] = ACTIONS(2336),
    [anon_sym_snorm] = ACTIONS(2336),
    [anon_sym_unorm] = ACTIONS(2336),
    [anon_sym_point] = ACTIONS(2336),
    [anon_sym_line] = ACTIONS(2336),
    [anon_sym_triangleadj] = ACTIONS(2336),
    [anon_sym_lineadj] = ACTIONS(2336),
    [anon_sym_triangle] = ACTIONS(2336),
  },
  [2054] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym_RBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_friend] = ACTIONS(2332),
    [anon_sym_public] = ACTIONS(2332),
    [anon_sym_private] = ACTIONS(2332),
    [anon_sym_protected] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
  },
  [2055] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym_RBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_friend] = ACTIONS(2332),
    [anon_sym_public] = ACTIONS(2332),
    [anon_sym_private] = ACTIONS(2332),
    [anon_sym_protected] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
  },
  [2056] = {
    [sym_identifier] = ACTIONS(2316),
    [aux_sym_preproc_def_token1] = ACTIONS(2316),
    [aux_sym_preproc_if_token1] = ACTIONS(2316),
    [aux_sym_preproc_if_token2] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2316),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2316),
    [sym_preproc_directive] = ACTIONS(2316),
    [anon_sym_LPAREN2] = ACTIONS(2318),
    [anon_sym_TILDE] = ACTIONS(2318),
    [anon_sym_STAR] = ACTIONS(2318),
    [anon_sym_AMP_AMP] = ACTIONS(2318),
    [anon_sym_AMP] = ACTIONS(2316),
    [anon_sym___extension__] = ACTIONS(2316),
    [anon_sym_typedef] = ACTIONS(2316),
    [anon_sym_in] = ACTIONS(2316),
    [anon_sym_out] = ACTIONS(2316),
    [anon_sym_inout] = ACTIONS(2316),
    [anon_sym_extern] = ACTIONS(2316),
    [anon_sym___attribute__] = ACTIONS(2316),
    [anon_sym_COLON_COLON] = ACTIONS(2318),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2318),
    [anon_sym___declspec] = ACTIONS(2316),
    [anon_sym___based] = ACTIONS(2316),
    [anon_sym_signed] = ACTIONS(2316),
    [anon_sym_unsigned] = ACTIONS(2316),
    [anon_sym_long] = ACTIONS(2316),
    [anon_sym_short] = ACTIONS(2316),
    [anon_sym_LBRACK] = ACTIONS(2316),
    [anon_sym_static] = ACTIONS(2316),
    [anon_sym_register] = ACTIONS(2316),
    [anon_sym_inline] = ACTIONS(2316),
    [anon_sym___inline] = ACTIONS(2316),
    [anon_sym___inline__] = ACTIONS(2316),
    [anon_sym___forceinline] = ACTIONS(2316),
    [anon_sym_thread_local] = ACTIONS(2316),
    [anon_sym___thread] = ACTIONS(2316),
    [anon_sym_const] = ACTIONS(2316),
    [anon_sym_constexpr] = ACTIONS(2316),
    [anon_sym_volatile] = ACTIONS(2316),
    [anon_sym_restrict] = ACTIONS(2316),
    [anon_sym___restrict__] = ACTIONS(2316),
    [anon_sym__Atomic] = ACTIONS(2316),
    [anon_sym__Noreturn] = ACTIONS(2316),
    [anon_sym_noreturn] = ACTIONS(2316),
    [anon_sym_mutable] = ACTIONS(2316),
    [anon_sym_constinit] = ACTIONS(2316),
    [anon_sym_consteval] = ACTIONS(2316),
    [anon_sym_alignas] = ACTIONS(2316),
    [anon_sym__Alignas] = ACTIONS(2316),
    [sym_primitive_type] = ACTIONS(2316),
    [anon_sym_enum] = ACTIONS(2316),
    [anon_sym_class] = ACTIONS(2316),
    [anon_sym_struct] = ACTIONS(2316),
    [anon_sym_union] = ACTIONS(2316),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2316),
    [anon_sym_decltype] = ACTIONS(2316),
    [sym_virtual] = ACTIONS(2316),
    [anon_sym_explicit] = ACTIONS(2316),
    [anon_sym_typename] = ACTIONS(2316),
    [anon_sym_template] = ACTIONS(2316),
    [anon_sym_operator] = ACTIONS(2316),
    [anon_sym_friend] = ACTIONS(2316),
    [anon_sym_public] = ACTIONS(2316),
    [anon_sym_private] = ACTIONS(2316),
    [anon_sym_protected] = ACTIONS(2316),
    [anon_sym_using] = ACTIONS(2316),
    [anon_sym_static_assert] = ACTIONS(2316),
    [anon_sym_precise] = ACTIONS(2316),
    [anon_sym_shared] = ACTIONS(2316),
    [anon_sym_groupshared] = ACTIONS(2316),
    [anon_sym_uniform] = ACTIONS(2316),
    [anon_sym_row_major] = ACTIONS(2316),
    [anon_sym_column_major] = ACTIONS(2316),
    [anon_sym_globallycoherent] = ACTIONS(2316),
    [anon_sym_centroid] = ACTIONS(2316),
    [anon_sym_noperspective] = ACTIONS(2316),
    [anon_sym_nointerpolation] = ACTIONS(2316),
    [anon_sym_sample] = ACTIONS(2316),
    [anon_sym_linear] = ACTIONS(2316),
    [anon_sym_snorm] = ACTIONS(2316),
    [anon_sym_unorm] = ACTIONS(2316),
    [anon_sym_point] = ACTIONS(2316),
    [anon_sym_line] = ACTIONS(2316),
    [anon_sym_triangleadj] = ACTIONS(2316),
    [anon_sym_lineadj] = ACTIONS(2316),
    [anon_sym_triangle] = ACTIONS(2316),
  },
  [2057] = {
    [sym_identifier] = ACTIONS(2420),
    [aux_sym_preproc_def_token1] = ACTIONS(2420),
    [aux_sym_preproc_if_token1] = ACTIONS(2420),
    [aux_sym_preproc_if_token2] = ACTIONS(2420),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2420),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2420),
    [sym_preproc_directive] = ACTIONS(2420),
    [anon_sym_LPAREN2] = ACTIONS(2422),
    [anon_sym_TILDE] = ACTIONS(2422),
    [anon_sym_STAR] = ACTIONS(2422),
    [anon_sym_AMP_AMP] = ACTIONS(2422),
    [anon_sym_AMP] = ACTIONS(2420),
    [anon_sym___extension__] = ACTIONS(2420),
    [anon_sym_typedef] = ACTIONS(2420),
    [anon_sym_in] = ACTIONS(2420),
    [anon_sym_out] = ACTIONS(2420),
    [anon_sym_inout] = ACTIONS(2420),
    [anon_sym_extern] = ACTIONS(2420),
    [anon_sym___attribute__] = ACTIONS(2420),
    [anon_sym_COLON_COLON] = ACTIONS(2422),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2422),
    [anon_sym___declspec] = ACTIONS(2420),
    [anon_sym___based] = ACTIONS(2420),
    [anon_sym_signed] = ACTIONS(2420),
    [anon_sym_unsigned] = ACTIONS(2420),
    [anon_sym_long] = ACTIONS(2420),
    [anon_sym_short] = ACTIONS(2420),
    [anon_sym_LBRACK] = ACTIONS(2420),
    [anon_sym_static] = ACTIONS(2420),
    [anon_sym_register] = ACTIONS(2420),
    [anon_sym_inline] = ACTIONS(2420),
    [anon_sym___inline] = ACTIONS(2420),
    [anon_sym___inline__] = ACTIONS(2420),
    [anon_sym___forceinline] = ACTIONS(2420),
    [anon_sym_thread_local] = ACTIONS(2420),
    [anon_sym___thread] = ACTIONS(2420),
    [anon_sym_const] = ACTIONS(2420),
    [anon_sym_constexpr] = ACTIONS(2420),
    [anon_sym_volatile] = ACTIONS(2420),
    [anon_sym_restrict] = ACTIONS(2420),
    [anon_sym___restrict__] = ACTIONS(2420),
    [anon_sym__Atomic] = ACTIONS(2420),
    [anon_sym__Noreturn] = ACTIONS(2420),
    [anon_sym_noreturn] = ACTIONS(2420),
    [anon_sym_mutable] = ACTIONS(2420),
    [anon_sym_constinit] = ACTIONS(2420),
    [anon_sym_consteval] = ACTIONS(2420),
    [anon_sym_alignas] = ACTIONS(2420),
    [anon_sym__Alignas] = ACTIONS(2420),
    [sym_primitive_type] = ACTIONS(2420),
    [anon_sym_enum] = ACTIONS(2420),
    [anon_sym_class] = ACTIONS(2420),
    [anon_sym_struct] = ACTIONS(2420),
    [anon_sym_union] = ACTIONS(2420),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2420),
    [anon_sym_decltype] = ACTIONS(2420),
    [sym_virtual] = ACTIONS(2420),
    [anon_sym_explicit] = ACTIONS(2420),
    [anon_sym_typename] = ACTIONS(2420),
    [anon_sym_template] = ACTIONS(2420),
    [anon_sym_operator] = ACTIONS(2420),
    [anon_sym_friend] = ACTIONS(2420),
    [anon_sym_public] = ACTIONS(2420),
    [anon_sym_private] = ACTIONS(2420),
    [anon_sym_protected] = ACTIONS(2420),
    [anon_sym_using] = ACTIONS(2420),
    [anon_sym_static_assert] = ACTIONS(2420),
    [anon_sym_precise] = ACTIONS(2420),
    [anon_sym_shared] = ACTIONS(2420),
    [anon_sym_groupshared] = ACTIONS(2420),
    [anon_sym_uniform] = ACTIONS(2420),
    [anon_sym_row_major] = ACTIONS(2420),
    [anon_sym_column_major] = ACTIONS(2420),
    [anon_sym_globallycoherent] = ACTIONS(2420),
    [anon_sym_centroid] = ACTIONS(2420),
    [anon_sym_noperspective] = ACTIONS(2420),
    [anon_sym_nointerpolation] = ACTIONS(2420),
    [anon_sym_sample] = ACTIONS(2420),
    [anon_sym_linear] = ACTIONS(2420),
    [anon_sym_snorm] = ACTIONS(2420),
    [anon_sym_unorm] = ACTIONS(2420),
    [anon_sym_point] = ACTIONS(2420),
    [anon_sym_line] = ACTIONS(2420),
    [anon_sym_triangleadj] = ACTIONS(2420),
    [anon_sym_lineadj] = ACTIONS(2420),
    [anon_sym_triangle] = ACTIONS(2420),
  },
  [2058] = {
    [sym_identifier] = ACTIONS(2312),
    [aux_sym_preproc_def_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2312),
    [sym_preproc_directive] = ACTIONS(2312),
    [anon_sym_LPAREN2] = ACTIONS(2314),
    [anon_sym_TILDE] = ACTIONS(2314),
    [anon_sym_STAR] = ACTIONS(2314),
    [anon_sym_AMP_AMP] = ACTIONS(2314),
    [anon_sym_AMP] = ACTIONS(2312),
    [anon_sym___extension__] = ACTIONS(2312),
    [anon_sym_typedef] = ACTIONS(2312),
    [anon_sym_in] = ACTIONS(2312),
    [anon_sym_out] = ACTIONS(2312),
    [anon_sym_inout] = ACTIONS(2312),
    [anon_sym_extern] = ACTIONS(2312),
    [anon_sym___attribute__] = ACTIONS(2312),
    [anon_sym_COLON_COLON] = ACTIONS(2314),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2314),
    [anon_sym___declspec] = ACTIONS(2312),
    [anon_sym___based] = ACTIONS(2312),
    [anon_sym_RBRACE] = ACTIONS(2314),
    [anon_sym_signed] = ACTIONS(2312),
    [anon_sym_unsigned] = ACTIONS(2312),
    [anon_sym_long] = ACTIONS(2312),
    [anon_sym_short] = ACTIONS(2312),
    [anon_sym_LBRACK] = ACTIONS(2312),
    [anon_sym_static] = ACTIONS(2312),
    [anon_sym_register] = ACTIONS(2312),
    [anon_sym_inline] = ACTIONS(2312),
    [anon_sym___inline] = ACTIONS(2312),
    [anon_sym___inline__] = ACTIONS(2312),
    [anon_sym___forceinline] = ACTIONS(2312),
    [anon_sym_thread_local] = ACTIONS(2312),
    [anon_sym___thread] = ACTIONS(2312),
    [anon_sym_const] = ACTIONS(2312),
    [anon_sym_constexpr] = ACTIONS(2312),
    [anon_sym_volatile] = ACTIONS(2312),
    [anon_sym_restrict] = ACTIONS(2312),
    [anon_sym___restrict__] = ACTIONS(2312),
    [anon_sym__Atomic] = ACTIONS(2312),
    [anon_sym__Noreturn] = ACTIONS(2312),
    [anon_sym_noreturn] = ACTIONS(2312),
    [anon_sym_mutable] = ACTIONS(2312),
    [anon_sym_constinit] = ACTIONS(2312),
    [anon_sym_consteval] = ACTIONS(2312),
    [anon_sym_alignas] = ACTIONS(2312),
    [anon_sym__Alignas] = ACTIONS(2312),
    [sym_primitive_type] = ACTIONS(2312),
    [anon_sym_enum] = ACTIONS(2312),
    [anon_sym_class] = ACTIONS(2312),
    [anon_sym_struct] = ACTIONS(2312),
    [anon_sym_union] = ACTIONS(2312),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2312),
    [anon_sym_decltype] = ACTIONS(2312),
    [sym_virtual] = ACTIONS(2312),
    [anon_sym_explicit] = ACTIONS(2312),
    [anon_sym_typename] = ACTIONS(2312),
    [anon_sym_template] = ACTIONS(2312),
    [anon_sym_operator] = ACTIONS(2312),
    [anon_sym_friend] = ACTIONS(2312),
    [anon_sym_public] = ACTIONS(2312),
    [anon_sym_private] = ACTIONS(2312),
    [anon_sym_protected] = ACTIONS(2312),
    [anon_sym_using] = ACTIONS(2312),
    [anon_sym_static_assert] = ACTIONS(2312),
    [anon_sym_precise] = ACTIONS(2312),
    [anon_sym_shared] = ACTIONS(2312),
    [anon_sym_groupshared] = ACTIONS(2312),
    [anon_sym_uniform] = ACTIONS(2312),
    [anon_sym_row_major] = ACTIONS(2312),
    [anon_sym_column_major] = ACTIONS(2312),
    [anon_sym_globallycoherent] = ACTIONS(2312),
    [anon_sym_centroid] = ACTIONS(2312),
    [anon_sym_noperspective] = ACTIONS(2312),
    [anon_sym_nointerpolation] = ACTIONS(2312),
    [anon_sym_sample] = ACTIONS(2312),
    [anon_sym_linear] = ACTIONS(2312),
    [anon_sym_snorm] = ACTIONS(2312),
    [anon_sym_unorm] = ACTIONS(2312),
    [anon_sym_point] = ACTIONS(2312),
    [anon_sym_line] = ACTIONS(2312),
    [anon_sym_triangleadj] = ACTIONS(2312),
    [anon_sym_lineadj] = ACTIONS(2312),
    [anon_sym_triangle] = ACTIONS(2312),
  },
  [2059] = {
    [sym_identifier] = ACTIONS(2428),
    [aux_sym_preproc_def_token1] = ACTIONS(2428),
    [aux_sym_preproc_if_token1] = ACTIONS(2428),
    [aux_sym_preproc_if_token2] = ACTIONS(2428),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2428),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2428),
    [sym_preproc_directive] = ACTIONS(2428),
    [anon_sym_LPAREN2] = ACTIONS(2430),
    [anon_sym_TILDE] = ACTIONS(2430),
    [anon_sym_STAR] = ACTIONS(2430),
    [anon_sym_AMP_AMP] = ACTIONS(2430),
    [anon_sym_AMP] = ACTIONS(2428),
    [anon_sym___extension__] = ACTIONS(2428),
    [anon_sym_typedef] = ACTIONS(2428),
    [anon_sym_in] = ACTIONS(2428),
    [anon_sym_out] = ACTIONS(2428),
    [anon_sym_inout] = ACTIONS(2428),
    [anon_sym_extern] = ACTIONS(2428),
    [anon_sym___attribute__] = ACTIONS(2428),
    [anon_sym_COLON_COLON] = ACTIONS(2430),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2430),
    [anon_sym___declspec] = ACTIONS(2428),
    [anon_sym___based] = ACTIONS(2428),
    [anon_sym_signed] = ACTIONS(2428),
    [anon_sym_unsigned] = ACTIONS(2428),
    [anon_sym_long] = ACTIONS(2428),
    [anon_sym_short] = ACTIONS(2428),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [anon_sym_static] = ACTIONS(2428),
    [anon_sym_register] = ACTIONS(2428),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym___inline] = ACTIONS(2428),
    [anon_sym___inline__] = ACTIONS(2428),
    [anon_sym___forceinline] = ACTIONS(2428),
    [anon_sym_thread_local] = ACTIONS(2428),
    [anon_sym___thread] = ACTIONS(2428),
    [anon_sym_const] = ACTIONS(2428),
    [anon_sym_constexpr] = ACTIONS(2428),
    [anon_sym_volatile] = ACTIONS(2428),
    [anon_sym_restrict] = ACTIONS(2428),
    [anon_sym___restrict__] = ACTIONS(2428),
    [anon_sym__Atomic] = ACTIONS(2428),
    [anon_sym__Noreturn] = ACTIONS(2428),
    [anon_sym_noreturn] = ACTIONS(2428),
    [anon_sym_mutable] = ACTIONS(2428),
    [anon_sym_constinit] = ACTIONS(2428),
    [anon_sym_consteval] = ACTIONS(2428),
    [anon_sym_alignas] = ACTIONS(2428),
    [anon_sym__Alignas] = ACTIONS(2428),
    [sym_primitive_type] = ACTIONS(2428),
    [anon_sym_enum] = ACTIONS(2428),
    [anon_sym_class] = ACTIONS(2428),
    [anon_sym_struct] = ACTIONS(2428),
    [anon_sym_union] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2428),
    [anon_sym_decltype] = ACTIONS(2428),
    [sym_virtual] = ACTIONS(2428),
    [anon_sym_explicit] = ACTIONS(2428),
    [anon_sym_typename] = ACTIONS(2428),
    [anon_sym_template] = ACTIONS(2428),
    [anon_sym_operator] = ACTIONS(2428),
    [anon_sym_friend] = ACTIONS(2428),
    [anon_sym_public] = ACTIONS(2428),
    [anon_sym_private] = ACTIONS(2428),
    [anon_sym_protected] = ACTIONS(2428),
    [anon_sym_using] = ACTIONS(2428),
    [anon_sym_static_assert] = ACTIONS(2428),
    [anon_sym_precise] = ACTIONS(2428),
    [anon_sym_shared] = ACTIONS(2428),
    [anon_sym_groupshared] = ACTIONS(2428),
    [anon_sym_uniform] = ACTIONS(2428),
    [anon_sym_row_major] = ACTIONS(2428),
    [anon_sym_column_major] = ACTIONS(2428),
    [anon_sym_globallycoherent] = ACTIONS(2428),
    [anon_sym_centroid] = ACTIONS(2428),
    [anon_sym_noperspective] = ACTIONS(2428),
    [anon_sym_nointerpolation] = ACTIONS(2428),
    [anon_sym_sample] = ACTIONS(2428),
    [anon_sym_linear] = ACTIONS(2428),
    [anon_sym_snorm] = ACTIONS(2428),
    [anon_sym_unorm] = ACTIONS(2428),
    [anon_sym_point] = ACTIONS(2428),
    [anon_sym_line] = ACTIONS(2428),
    [anon_sym_triangleadj] = ACTIONS(2428),
    [anon_sym_lineadj] = ACTIONS(2428),
    [anon_sym_triangle] = ACTIONS(2428),
  },
  [2060] = {
    [sym_identifier] = ACTIONS(2432),
    [aux_sym_preproc_def_token1] = ACTIONS(2432),
    [aux_sym_preproc_if_token1] = ACTIONS(2432),
    [aux_sym_preproc_if_token2] = ACTIONS(2432),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2432),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2432),
    [sym_preproc_directive] = ACTIONS(2432),
    [anon_sym_LPAREN2] = ACTIONS(2434),
    [anon_sym_TILDE] = ACTIONS(2434),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_AMP_AMP] = ACTIONS(2434),
    [anon_sym_AMP] = ACTIONS(2432),
    [anon_sym___extension__] = ACTIONS(2432),
    [anon_sym_typedef] = ACTIONS(2432),
    [anon_sym_in] = ACTIONS(2432),
    [anon_sym_out] = ACTIONS(2432),
    [anon_sym_inout] = ACTIONS(2432),
    [anon_sym_extern] = ACTIONS(2432),
    [anon_sym___attribute__] = ACTIONS(2432),
    [anon_sym_COLON_COLON] = ACTIONS(2434),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2434),
    [anon_sym___declspec] = ACTIONS(2432),
    [anon_sym___based] = ACTIONS(2432),
    [anon_sym_signed] = ACTIONS(2432),
    [anon_sym_unsigned] = ACTIONS(2432),
    [anon_sym_long] = ACTIONS(2432),
    [anon_sym_short] = ACTIONS(2432),
    [anon_sym_LBRACK] = ACTIONS(2432),
    [anon_sym_static] = ACTIONS(2432),
    [anon_sym_register] = ACTIONS(2432),
    [anon_sym_inline] = ACTIONS(2432),
    [anon_sym___inline] = ACTIONS(2432),
    [anon_sym___inline__] = ACTIONS(2432),
    [anon_sym___forceinline] = ACTIONS(2432),
    [anon_sym_thread_local] = ACTIONS(2432),
    [anon_sym___thread] = ACTIONS(2432),
    [anon_sym_const] = ACTIONS(2432),
    [anon_sym_constexpr] = ACTIONS(2432),
    [anon_sym_volatile] = ACTIONS(2432),
    [anon_sym_restrict] = ACTIONS(2432),
    [anon_sym___restrict__] = ACTIONS(2432),
    [anon_sym__Atomic] = ACTIONS(2432),
    [anon_sym__Noreturn] = ACTIONS(2432),
    [anon_sym_noreturn] = ACTIONS(2432),
    [anon_sym_mutable] = ACTIONS(2432),
    [anon_sym_constinit] = ACTIONS(2432),
    [anon_sym_consteval] = ACTIONS(2432),
    [anon_sym_alignas] = ACTIONS(2432),
    [anon_sym__Alignas] = ACTIONS(2432),
    [sym_primitive_type] = ACTIONS(2432),
    [anon_sym_enum] = ACTIONS(2432),
    [anon_sym_class] = ACTIONS(2432),
    [anon_sym_struct] = ACTIONS(2432),
    [anon_sym_union] = ACTIONS(2432),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2432),
    [anon_sym_decltype] = ACTIONS(2432),
    [sym_virtual] = ACTIONS(2432),
    [anon_sym_explicit] = ACTIONS(2432),
    [anon_sym_typename] = ACTIONS(2432),
    [anon_sym_template] = ACTIONS(2432),
    [anon_sym_operator] = ACTIONS(2432),
    [anon_sym_friend] = ACTIONS(2432),
    [anon_sym_public] = ACTIONS(2432),
    [anon_sym_private] = ACTIONS(2432),
    [anon_sym_protected] = ACTIONS(2432),
    [anon_sym_using] = ACTIONS(2432),
    [anon_sym_static_assert] = ACTIONS(2432),
    [anon_sym_precise] = ACTIONS(2432),
    [anon_sym_shared] = ACTIONS(2432),
    [anon_sym_groupshared] = ACTIONS(2432),
    [anon_sym_uniform] = ACTIONS(2432),
    [anon_sym_row_major] = ACTIONS(2432),
    [anon_sym_column_major] = ACTIONS(2432),
    [anon_sym_globallycoherent] = ACTIONS(2432),
    [anon_sym_centroid] = ACTIONS(2432),
    [anon_sym_noperspective] = ACTIONS(2432),
    [anon_sym_nointerpolation] = ACTIONS(2432),
    [anon_sym_sample] = ACTIONS(2432),
    [anon_sym_linear] = ACTIONS(2432),
    [anon_sym_snorm] = ACTIONS(2432),
    [anon_sym_unorm] = ACTIONS(2432),
    [anon_sym_point] = ACTIONS(2432),
    [anon_sym_line] = ACTIONS(2432),
    [anon_sym_triangleadj] = ACTIONS(2432),
    [anon_sym_lineadj] = ACTIONS(2432),
    [anon_sym_triangle] = ACTIONS(2432),
  },
  [2061] = {
    [sym_identifier] = ACTIONS(2308),
    [aux_sym_preproc_def_token1] = ACTIONS(2308),
    [aux_sym_preproc_if_token1] = ACTIONS(2308),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2308),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2308),
    [sym_preproc_directive] = ACTIONS(2308),
    [anon_sym_LPAREN2] = ACTIONS(2310),
    [anon_sym_TILDE] = ACTIONS(2310),
    [anon_sym_STAR] = ACTIONS(2310),
    [anon_sym_AMP_AMP] = ACTIONS(2310),
    [anon_sym_AMP] = ACTIONS(2308),
    [anon_sym___extension__] = ACTIONS(2308),
    [anon_sym_typedef] = ACTIONS(2308),
    [anon_sym_in] = ACTIONS(2308),
    [anon_sym_out] = ACTIONS(2308),
    [anon_sym_inout] = ACTIONS(2308),
    [anon_sym_extern] = ACTIONS(2308),
    [anon_sym___attribute__] = ACTIONS(2308),
    [anon_sym_COLON_COLON] = ACTIONS(2310),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2310),
    [anon_sym___declspec] = ACTIONS(2308),
    [anon_sym___based] = ACTIONS(2308),
    [anon_sym_RBRACE] = ACTIONS(2310),
    [anon_sym_signed] = ACTIONS(2308),
    [anon_sym_unsigned] = ACTIONS(2308),
    [anon_sym_long] = ACTIONS(2308),
    [anon_sym_short] = ACTIONS(2308),
    [anon_sym_LBRACK] = ACTIONS(2308),
    [anon_sym_static] = ACTIONS(2308),
    [anon_sym_register] = ACTIONS(2308),
    [anon_sym_inline] = ACTIONS(2308),
    [anon_sym___inline] = ACTIONS(2308),
    [anon_sym___inline__] = ACTIONS(2308),
    [anon_sym___forceinline] = ACTIONS(2308),
    [anon_sym_thread_local] = ACTIONS(2308),
    [anon_sym___thread] = ACTIONS(2308),
    [anon_sym_const] = ACTIONS(2308),
    [anon_sym_constexpr] = ACTIONS(2308),
    [anon_sym_volatile] = ACTIONS(2308),
    [anon_sym_restrict] = ACTIONS(2308),
    [anon_sym___restrict__] = ACTIONS(2308),
    [anon_sym__Atomic] = ACTIONS(2308),
    [anon_sym__Noreturn] = ACTIONS(2308),
    [anon_sym_noreturn] = ACTIONS(2308),
    [anon_sym_mutable] = ACTIONS(2308),
    [anon_sym_constinit] = ACTIONS(2308),
    [anon_sym_consteval] = ACTIONS(2308),
    [anon_sym_alignas] = ACTIONS(2308),
    [anon_sym__Alignas] = ACTIONS(2308),
    [sym_primitive_type] = ACTIONS(2308),
    [anon_sym_enum] = ACTIONS(2308),
    [anon_sym_class] = ACTIONS(2308),
    [anon_sym_struct] = ACTIONS(2308),
    [anon_sym_union] = ACTIONS(2308),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2308),
    [anon_sym_decltype] = ACTIONS(2308),
    [sym_virtual] = ACTIONS(2308),
    [anon_sym_explicit] = ACTIONS(2308),
    [anon_sym_typename] = ACTIONS(2308),
    [anon_sym_template] = ACTIONS(2308),
    [anon_sym_operator] = ACTIONS(2308),
    [anon_sym_friend] = ACTIONS(2308),
    [anon_sym_public] = ACTIONS(2308),
    [anon_sym_private] = ACTIONS(2308),
    [anon_sym_protected] = ACTIONS(2308),
    [anon_sym_using] = ACTIONS(2308),
    [anon_sym_static_assert] = ACTIONS(2308),
    [anon_sym_precise] = ACTIONS(2308),
    [anon_sym_shared] = ACTIONS(2308),
    [anon_sym_groupshared] = ACTIONS(2308),
    [anon_sym_uniform] = ACTIONS(2308),
    [anon_sym_row_major] = ACTIONS(2308),
    [anon_sym_column_major] = ACTIONS(2308),
    [anon_sym_globallycoherent] = ACTIONS(2308),
    [anon_sym_centroid] = ACTIONS(2308),
    [anon_sym_noperspective] = ACTIONS(2308),
    [anon_sym_nointerpolation] = ACTIONS(2308),
    [anon_sym_sample] = ACTIONS(2308),
    [anon_sym_linear] = ACTIONS(2308),
    [anon_sym_snorm] = ACTIONS(2308),
    [anon_sym_unorm] = ACTIONS(2308),
    [anon_sym_point] = ACTIONS(2308),
    [anon_sym_line] = ACTIONS(2308),
    [anon_sym_triangleadj] = ACTIONS(2308),
    [anon_sym_lineadj] = ACTIONS(2308),
    [anon_sym_triangle] = ACTIONS(2308),
  },
  [2062] = {
    [sym_identifier] = ACTIONS(2336),
    [aux_sym_preproc_def_token1] = ACTIONS(2336),
    [aux_sym_preproc_if_token1] = ACTIONS(2336),
    [aux_sym_preproc_if_token2] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2336),
    [sym_preproc_directive] = ACTIONS(2336),
    [anon_sym_LPAREN2] = ACTIONS(2338),
    [anon_sym_TILDE] = ACTIONS(2338),
    [anon_sym_STAR] = ACTIONS(2338),
    [anon_sym_AMP_AMP] = ACTIONS(2338),
    [anon_sym_AMP] = ACTIONS(2336),
    [anon_sym___extension__] = ACTIONS(2336),
    [anon_sym_typedef] = ACTIONS(2336),
    [anon_sym_in] = ACTIONS(2336),
    [anon_sym_out] = ACTIONS(2336),
    [anon_sym_inout] = ACTIONS(2336),
    [anon_sym_extern] = ACTIONS(2336),
    [anon_sym___attribute__] = ACTIONS(2336),
    [anon_sym_COLON_COLON] = ACTIONS(2338),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2338),
    [anon_sym___declspec] = ACTIONS(2336),
    [anon_sym___based] = ACTIONS(2336),
    [anon_sym_signed] = ACTIONS(2336),
    [anon_sym_unsigned] = ACTIONS(2336),
    [anon_sym_long] = ACTIONS(2336),
    [anon_sym_short] = ACTIONS(2336),
    [anon_sym_LBRACK] = ACTIONS(2336),
    [anon_sym_static] = ACTIONS(2336),
    [anon_sym_register] = ACTIONS(2336),
    [anon_sym_inline] = ACTIONS(2336),
    [anon_sym___inline] = ACTIONS(2336),
    [anon_sym___inline__] = ACTIONS(2336),
    [anon_sym___forceinline] = ACTIONS(2336),
    [anon_sym_thread_local] = ACTIONS(2336),
    [anon_sym___thread] = ACTIONS(2336),
    [anon_sym_const] = ACTIONS(2336),
    [anon_sym_constexpr] = ACTIONS(2336),
    [anon_sym_volatile] = ACTIONS(2336),
    [anon_sym_restrict] = ACTIONS(2336),
    [anon_sym___restrict__] = ACTIONS(2336),
    [anon_sym__Atomic] = ACTIONS(2336),
    [anon_sym__Noreturn] = ACTIONS(2336),
    [anon_sym_noreturn] = ACTIONS(2336),
    [anon_sym_mutable] = ACTIONS(2336),
    [anon_sym_constinit] = ACTIONS(2336),
    [anon_sym_consteval] = ACTIONS(2336),
    [anon_sym_alignas] = ACTIONS(2336),
    [anon_sym__Alignas] = ACTIONS(2336),
    [sym_primitive_type] = ACTIONS(2336),
    [anon_sym_enum] = ACTIONS(2336),
    [anon_sym_class] = ACTIONS(2336),
    [anon_sym_struct] = ACTIONS(2336),
    [anon_sym_union] = ACTIONS(2336),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2336),
    [anon_sym_decltype] = ACTIONS(2336),
    [sym_virtual] = ACTIONS(2336),
    [anon_sym_explicit] = ACTIONS(2336),
    [anon_sym_typename] = ACTIONS(2336),
    [anon_sym_template] = ACTIONS(2336),
    [anon_sym_operator] = ACTIONS(2336),
    [anon_sym_friend] = ACTIONS(2336),
    [anon_sym_public] = ACTIONS(2336),
    [anon_sym_private] = ACTIONS(2336),
    [anon_sym_protected] = ACTIONS(2336),
    [anon_sym_using] = ACTIONS(2336),
    [anon_sym_static_assert] = ACTIONS(2336),
    [anon_sym_precise] = ACTIONS(2336),
    [anon_sym_shared] = ACTIONS(2336),
    [anon_sym_groupshared] = ACTIONS(2336),
    [anon_sym_uniform] = ACTIONS(2336),
    [anon_sym_row_major] = ACTIONS(2336),
    [anon_sym_column_major] = ACTIONS(2336),
    [anon_sym_globallycoherent] = ACTIONS(2336),
    [anon_sym_centroid] = ACTIONS(2336),
    [anon_sym_noperspective] = ACTIONS(2336),
    [anon_sym_nointerpolation] = ACTIONS(2336),
    [anon_sym_sample] = ACTIONS(2336),
    [anon_sym_linear] = ACTIONS(2336),
    [anon_sym_snorm] = ACTIONS(2336),
    [anon_sym_unorm] = ACTIONS(2336),
    [anon_sym_point] = ACTIONS(2336),
    [anon_sym_line] = ACTIONS(2336),
    [anon_sym_triangleadj] = ACTIONS(2336),
    [anon_sym_lineadj] = ACTIONS(2336),
    [anon_sym_triangle] = ACTIONS(2336),
  },
  [2063] = {
    [sym_identifier] = ACTIONS(2440),
    [aux_sym_preproc_def_token1] = ACTIONS(2440),
    [aux_sym_preproc_if_token1] = ACTIONS(2440),
    [aux_sym_preproc_if_token2] = ACTIONS(2440),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2440),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2440),
    [sym_preproc_directive] = ACTIONS(2440),
    [anon_sym_LPAREN2] = ACTIONS(2442),
    [anon_sym_TILDE] = ACTIONS(2442),
    [anon_sym_STAR] = ACTIONS(2442),
    [anon_sym_AMP_AMP] = ACTIONS(2442),
    [anon_sym_AMP] = ACTIONS(2440),
    [anon_sym___extension__] = ACTIONS(2440),
    [anon_sym_typedef] = ACTIONS(2440),
    [anon_sym_in] = ACTIONS(2440),
    [anon_sym_out] = ACTIONS(2440),
    [anon_sym_inout] = ACTIONS(2440),
    [anon_sym_extern] = ACTIONS(2440),
    [anon_sym___attribute__] = ACTIONS(2440),
    [anon_sym_COLON_COLON] = ACTIONS(2442),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2442),
    [anon_sym___declspec] = ACTIONS(2440),
    [anon_sym___based] = ACTIONS(2440),
    [anon_sym_signed] = ACTIONS(2440),
    [anon_sym_unsigned] = ACTIONS(2440),
    [anon_sym_long] = ACTIONS(2440),
    [anon_sym_short] = ACTIONS(2440),
    [anon_sym_LBRACK] = ACTIONS(2440),
    [anon_sym_static] = ACTIONS(2440),
    [anon_sym_register] = ACTIONS(2440),
    [anon_sym_inline] = ACTIONS(2440),
    [anon_sym___inline] = ACTIONS(2440),
    [anon_sym___inline__] = ACTIONS(2440),
    [anon_sym___forceinline] = ACTIONS(2440),
    [anon_sym_thread_local] = ACTIONS(2440),
    [anon_sym___thread] = ACTIONS(2440),
    [anon_sym_const] = ACTIONS(2440),
    [anon_sym_constexpr] = ACTIONS(2440),
    [anon_sym_volatile] = ACTIONS(2440),
    [anon_sym_restrict] = ACTIONS(2440),
    [anon_sym___restrict__] = ACTIONS(2440),
    [anon_sym__Atomic] = ACTIONS(2440),
    [anon_sym__Noreturn] = ACTIONS(2440),
    [anon_sym_noreturn] = ACTIONS(2440),
    [anon_sym_mutable] = ACTIONS(2440),
    [anon_sym_constinit] = ACTIONS(2440),
    [anon_sym_consteval] = ACTIONS(2440),
    [anon_sym_alignas] = ACTIONS(2440),
    [anon_sym__Alignas] = ACTIONS(2440),
    [sym_primitive_type] = ACTIONS(2440),
    [anon_sym_enum] = ACTIONS(2440),
    [anon_sym_class] = ACTIONS(2440),
    [anon_sym_struct] = ACTIONS(2440),
    [anon_sym_union] = ACTIONS(2440),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2440),
    [anon_sym_decltype] = ACTIONS(2440),
    [sym_virtual] = ACTIONS(2440),
    [anon_sym_explicit] = ACTIONS(2440),
    [anon_sym_typename] = ACTIONS(2440),
    [anon_sym_template] = ACTIONS(2440),
    [anon_sym_operator] = ACTIONS(2440),
    [anon_sym_friend] = ACTIONS(2440),
    [anon_sym_public] = ACTIONS(2440),
    [anon_sym_private] = ACTIONS(2440),
    [anon_sym_protected] = ACTIONS(2440),
    [anon_sym_using] = ACTIONS(2440),
    [anon_sym_static_assert] = ACTIONS(2440),
    [anon_sym_precise] = ACTIONS(2440),
    [anon_sym_shared] = ACTIONS(2440),
    [anon_sym_groupshared] = ACTIONS(2440),
    [anon_sym_uniform] = ACTIONS(2440),
    [anon_sym_row_major] = ACTIONS(2440),
    [anon_sym_column_major] = ACTIONS(2440),
    [anon_sym_globallycoherent] = ACTIONS(2440),
    [anon_sym_centroid] = ACTIONS(2440),
    [anon_sym_noperspective] = ACTIONS(2440),
    [anon_sym_nointerpolation] = ACTIONS(2440),
    [anon_sym_sample] = ACTIONS(2440),
    [anon_sym_linear] = ACTIONS(2440),
    [anon_sym_snorm] = ACTIONS(2440),
    [anon_sym_unorm] = ACTIONS(2440),
    [anon_sym_point] = ACTIONS(2440),
    [anon_sym_line] = ACTIONS(2440),
    [anon_sym_triangleadj] = ACTIONS(2440),
    [anon_sym_lineadj] = ACTIONS(2440),
    [anon_sym_triangle] = ACTIONS(2440),
  },
  [2064] = {
    [sym_identifier] = ACTIONS(2400),
    [aux_sym_preproc_def_token1] = ACTIONS(2400),
    [aux_sym_preproc_if_token1] = ACTIONS(2400),
    [aux_sym_preproc_if_token2] = ACTIONS(2400),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2400),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2400),
    [sym_preproc_directive] = ACTIONS(2400),
    [anon_sym_LPAREN2] = ACTIONS(2402),
    [anon_sym_TILDE] = ACTIONS(2402),
    [anon_sym_STAR] = ACTIONS(2402),
    [anon_sym_AMP_AMP] = ACTIONS(2402),
    [anon_sym_AMP] = ACTIONS(2400),
    [anon_sym___extension__] = ACTIONS(2400),
    [anon_sym_typedef] = ACTIONS(2400),
    [anon_sym_in] = ACTIONS(2400),
    [anon_sym_out] = ACTIONS(2400),
    [anon_sym_inout] = ACTIONS(2400),
    [anon_sym_extern] = ACTIONS(2400),
    [anon_sym___attribute__] = ACTIONS(2400),
    [anon_sym_COLON_COLON] = ACTIONS(2402),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2402),
    [anon_sym___declspec] = ACTIONS(2400),
    [anon_sym___based] = ACTIONS(2400),
    [anon_sym_signed] = ACTIONS(2400),
    [anon_sym_unsigned] = ACTIONS(2400),
    [anon_sym_long] = ACTIONS(2400),
    [anon_sym_short] = ACTIONS(2400),
    [anon_sym_LBRACK] = ACTIONS(2400),
    [anon_sym_static] = ACTIONS(2400),
    [anon_sym_register] = ACTIONS(2400),
    [anon_sym_inline] = ACTIONS(2400),
    [anon_sym___inline] = ACTIONS(2400),
    [anon_sym___inline__] = ACTIONS(2400),
    [anon_sym___forceinline] = ACTIONS(2400),
    [anon_sym_thread_local] = ACTIONS(2400),
    [anon_sym___thread] = ACTIONS(2400),
    [anon_sym_const] = ACTIONS(2400),
    [anon_sym_constexpr] = ACTIONS(2400),
    [anon_sym_volatile] = ACTIONS(2400),
    [anon_sym_restrict] = ACTIONS(2400),
    [anon_sym___restrict__] = ACTIONS(2400),
    [anon_sym__Atomic] = ACTIONS(2400),
    [anon_sym__Noreturn] = ACTIONS(2400),
    [anon_sym_noreturn] = ACTIONS(2400),
    [anon_sym_mutable] = ACTIONS(2400),
    [anon_sym_constinit] = ACTIONS(2400),
    [anon_sym_consteval] = ACTIONS(2400),
    [anon_sym_alignas] = ACTIONS(2400),
    [anon_sym__Alignas] = ACTIONS(2400),
    [sym_primitive_type] = ACTIONS(2400),
    [anon_sym_enum] = ACTIONS(2400),
    [anon_sym_class] = ACTIONS(2400),
    [anon_sym_struct] = ACTIONS(2400),
    [anon_sym_union] = ACTIONS(2400),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2400),
    [anon_sym_decltype] = ACTIONS(2400),
    [sym_virtual] = ACTIONS(2400),
    [anon_sym_explicit] = ACTIONS(2400),
    [anon_sym_typename] = ACTIONS(2400),
    [anon_sym_template] = ACTIONS(2400),
    [anon_sym_operator] = ACTIONS(2400),
    [anon_sym_friend] = ACTIONS(2400),
    [anon_sym_public] = ACTIONS(2400),
    [anon_sym_private] = ACTIONS(2400),
    [anon_sym_protected] = ACTIONS(2400),
    [anon_sym_using] = ACTIONS(2400),
    [anon_sym_static_assert] = ACTIONS(2400),
    [anon_sym_precise] = ACTIONS(2400),
    [anon_sym_shared] = ACTIONS(2400),
    [anon_sym_groupshared] = ACTIONS(2400),
    [anon_sym_uniform] = ACTIONS(2400),
    [anon_sym_row_major] = ACTIONS(2400),
    [anon_sym_column_major] = ACTIONS(2400),
    [anon_sym_globallycoherent] = ACTIONS(2400),
    [anon_sym_centroid] = ACTIONS(2400),
    [anon_sym_noperspective] = ACTIONS(2400),
    [anon_sym_nointerpolation] = ACTIONS(2400),
    [anon_sym_sample] = ACTIONS(2400),
    [anon_sym_linear] = ACTIONS(2400),
    [anon_sym_snorm] = ACTIONS(2400),
    [anon_sym_unorm] = ACTIONS(2400),
    [anon_sym_point] = ACTIONS(2400),
    [anon_sym_line] = ACTIONS(2400),
    [anon_sym_triangleadj] = ACTIONS(2400),
    [anon_sym_lineadj] = ACTIONS(2400),
    [anon_sym_triangle] = ACTIONS(2400),
  },
  [2065] = {
    [sym_identifier] = ACTIONS(2498),
    [aux_sym_preproc_def_token1] = ACTIONS(2498),
    [aux_sym_preproc_if_token1] = ACTIONS(2498),
    [aux_sym_preproc_if_token2] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2498),
    [sym_preproc_directive] = ACTIONS(2498),
    [anon_sym_LPAREN2] = ACTIONS(2500),
    [anon_sym_TILDE] = ACTIONS(2500),
    [anon_sym_STAR] = ACTIONS(2500),
    [anon_sym_AMP_AMP] = ACTIONS(2500),
    [anon_sym_AMP] = ACTIONS(2498),
    [anon_sym___extension__] = ACTIONS(2498),
    [anon_sym_typedef] = ACTIONS(2498),
    [anon_sym_in] = ACTIONS(2498),
    [anon_sym_out] = ACTIONS(2498),
    [anon_sym_inout] = ACTIONS(2498),
    [anon_sym_extern] = ACTIONS(2498),
    [anon_sym___attribute__] = ACTIONS(2498),
    [anon_sym_COLON_COLON] = ACTIONS(2500),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2500),
    [anon_sym___declspec] = ACTIONS(2498),
    [anon_sym___based] = ACTIONS(2498),
    [anon_sym_signed] = ACTIONS(2498),
    [anon_sym_unsigned] = ACTIONS(2498),
    [anon_sym_long] = ACTIONS(2498),
    [anon_sym_short] = ACTIONS(2498),
    [anon_sym_LBRACK] = ACTIONS(2498),
    [anon_sym_static] = ACTIONS(2498),
    [anon_sym_register] = ACTIONS(2498),
    [anon_sym_inline] = ACTIONS(2498),
    [anon_sym___inline] = ACTIONS(2498),
    [anon_sym___inline__] = ACTIONS(2498),
    [anon_sym___forceinline] = ACTIONS(2498),
    [anon_sym_thread_local] = ACTIONS(2498),
    [anon_sym___thread] = ACTIONS(2498),
    [anon_sym_const] = ACTIONS(2498),
    [anon_sym_constexpr] = ACTIONS(2498),
    [anon_sym_volatile] = ACTIONS(2498),
    [anon_sym_restrict] = ACTIONS(2498),
    [anon_sym___restrict__] = ACTIONS(2498),
    [anon_sym__Atomic] = ACTIONS(2498),
    [anon_sym__Noreturn] = ACTIONS(2498),
    [anon_sym_noreturn] = ACTIONS(2498),
    [anon_sym_mutable] = ACTIONS(2498),
    [anon_sym_constinit] = ACTIONS(2498),
    [anon_sym_consteval] = ACTIONS(2498),
    [anon_sym_alignas] = ACTIONS(2498),
    [anon_sym__Alignas] = ACTIONS(2498),
    [sym_primitive_type] = ACTIONS(2498),
    [anon_sym_enum] = ACTIONS(2498),
    [anon_sym_class] = ACTIONS(2498),
    [anon_sym_struct] = ACTIONS(2498),
    [anon_sym_union] = ACTIONS(2498),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2498),
    [anon_sym_decltype] = ACTIONS(2498),
    [sym_virtual] = ACTIONS(2498),
    [anon_sym_explicit] = ACTIONS(2498),
    [anon_sym_typename] = ACTIONS(2498),
    [anon_sym_template] = ACTIONS(2498),
    [anon_sym_operator] = ACTIONS(2498),
    [anon_sym_friend] = ACTIONS(2498),
    [anon_sym_public] = ACTIONS(2498),
    [anon_sym_private] = ACTIONS(2498),
    [anon_sym_protected] = ACTIONS(2498),
    [anon_sym_using] = ACTIONS(2498),
    [anon_sym_static_assert] = ACTIONS(2498),
    [anon_sym_precise] = ACTIONS(2498),
    [anon_sym_shared] = ACTIONS(2498),
    [anon_sym_groupshared] = ACTIONS(2498),
    [anon_sym_uniform] = ACTIONS(2498),
    [anon_sym_row_major] = ACTIONS(2498),
    [anon_sym_column_major] = ACTIONS(2498),
    [anon_sym_globallycoherent] = ACTIONS(2498),
    [anon_sym_centroid] = ACTIONS(2498),
    [anon_sym_noperspective] = ACTIONS(2498),
    [anon_sym_nointerpolation] = ACTIONS(2498),
    [anon_sym_sample] = ACTIONS(2498),
    [anon_sym_linear] = ACTIONS(2498),
    [anon_sym_snorm] = ACTIONS(2498),
    [anon_sym_unorm] = ACTIONS(2498),
    [anon_sym_point] = ACTIONS(2498),
    [anon_sym_line] = ACTIONS(2498),
    [anon_sym_triangleadj] = ACTIONS(2498),
    [anon_sym_lineadj] = ACTIONS(2498),
    [anon_sym_triangle] = ACTIONS(2498),
  },
  [2066] = {
    [sym_identifier] = ACTIONS(5041),
    [aux_sym_preproc_def_token1] = ACTIONS(5041),
    [aux_sym_preproc_if_token1] = ACTIONS(5041),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5041),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5041),
    [sym_preproc_directive] = ACTIONS(5041),
    [anon_sym_LPAREN2] = ACTIONS(5043),
    [anon_sym_TILDE] = ACTIONS(5043),
    [anon_sym_STAR] = ACTIONS(5043),
    [anon_sym_AMP_AMP] = ACTIONS(5043),
    [anon_sym_AMP] = ACTIONS(5041),
    [anon_sym___extension__] = ACTIONS(5041),
    [anon_sym_typedef] = ACTIONS(5041),
    [anon_sym_in] = ACTIONS(5041),
    [anon_sym_out] = ACTIONS(5041),
    [anon_sym_inout] = ACTIONS(5041),
    [anon_sym_extern] = ACTIONS(5041),
    [anon_sym___attribute__] = ACTIONS(5041),
    [anon_sym_COLON_COLON] = ACTIONS(5043),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5043),
    [anon_sym___declspec] = ACTIONS(5041),
    [anon_sym___based] = ACTIONS(5041),
    [anon_sym_RBRACE] = ACTIONS(5043),
    [anon_sym_signed] = ACTIONS(5041),
    [anon_sym_unsigned] = ACTIONS(5041),
    [anon_sym_long] = ACTIONS(5041),
    [anon_sym_short] = ACTIONS(5041),
    [anon_sym_LBRACK] = ACTIONS(5041),
    [anon_sym_static] = ACTIONS(5041),
    [anon_sym_register] = ACTIONS(5041),
    [anon_sym_inline] = ACTIONS(5041),
    [anon_sym___inline] = ACTIONS(5041),
    [anon_sym___inline__] = ACTIONS(5041),
    [anon_sym___forceinline] = ACTIONS(5041),
    [anon_sym_thread_local] = ACTIONS(5041),
    [anon_sym___thread] = ACTIONS(5041),
    [anon_sym_const] = ACTIONS(5041),
    [anon_sym_constexpr] = ACTIONS(5041),
    [anon_sym_volatile] = ACTIONS(5041),
    [anon_sym_restrict] = ACTIONS(5041),
    [anon_sym___restrict__] = ACTIONS(5041),
    [anon_sym__Atomic] = ACTIONS(5041),
    [anon_sym__Noreturn] = ACTIONS(5041),
    [anon_sym_noreturn] = ACTIONS(5041),
    [anon_sym_mutable] = ACTIONS(5041),
    [anon_sym_constinit] = ACTIONS(5041),
    [anon_sym_consteval] = ACTIONS(5041),
    [anon_sym_alignas] = ACTIONS(5041),
    [anon_sym__Alignas] = ACTIONS(5041),
    [sym_primitive_type] = ACTIONS(5041),
    [anon_sym_enum] = ACTIONS(5041),
    [anon_sym_class] = ACTIONS(5041),
    [anon_sym_struct] = ACTIONS(5041),
    [anon_sym_union] = ACTIONS(5041),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5041),
    [anon_sym_decltype] = ACTIONS(5041),
    [sym_virtual] = ACTIONS(5041),
    [anon_sym_explicit] = ACTIONS(5041),
    [anon_sym_typename] = ACTIONS(5041),
    [anon_sym_template] = ACTIONS(5041),
    [anon_sym_operator] = ACTIONS(5041),
    [anon_sym_friend] = ACTIONS(5041),
    [anon_sym_public] = ACTIONS(5041),
    [anon_sym_private] = ACTIONS(5041),
    [anon_sym_protected] = ACTIONS(5041),
    [anon_sym_using] = ACTIONS(5041),
    [anon_sym_static_assert] = ACTIONS(5041),
    [anon_sym_precise] = ACTIONS(5041),
    [anon_sym_shared] = ACTIONS(5041),
    [anon_sym_groupshared] = ACTIONS(5041),
    [anon_sym_uniform] = ACTIONS(5041),
    [anon_sym_row_major] = ACTIONS(5041),
    [anon_sym_column_major] = ACTIONS(5041),
    [anon_sym_globallycoherent] = ACTIONS(5041),
    [anon_sym_centroid] = ACTIONS(5041),
    [anon_sym_noperspective] = ACTIONS(5041),
    [anon_sym_nointerpolation] = ACTIONS(5041),
    [anon_sym_sample] = ACTIONS(5041),
    [anon_sym_linear] = ACTIONS(5041),
    [anon_sym_snorm] = ACTIONS(5041),
    [anon_sym_unorm] = ACTIONS(5041),
    [anon_sym_point] = ACTIONS(5041),
    [anon_sym_line] = ACTIONS(5041),
    [anon_sym_triangleadj] = ACTIONS(5041),
    [anon_sym_lineadj] = ACTIONS(5041),
    [anon_sym_triangle] = ACTIONS(5041),
  },
  [2067] = {
    [sym_identifier] = ACTIONS(2138),
    [aux_sym_preproc_def_token1] = ACTIONS(2138),
    [aux_sym_preproc_if_token1] = ACTIONS(2138),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2138),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2138),
    [sym_preproc_directive] = ACTIONS(2138),
    [anon_sym_LPAREN2] = ACTIONS(2140),
    [anon_sym_TILDE] = ACTIONS(2140),
    [anon_sym_STAR] = ACTIONS(2140),
    [anon_sym_AMP_AMP] = ACTIONS(2140),
    [anon_sym_AMP] = ACTIONS(2138),
    [anon_sym___extension__] = ACTIONS(2138),
    [anon_sym_typedef] = ACTIONS(2138),
    [anon_sym_in] = ACTIONS(2138),
    [anon_sym_out] = ACTIONS(2138),
    [anon_sym_inout] = ACTIONS(2138),
    [anon_sym_extern] = ACTIONS(2138),
    [anon_sym___attribute__] = ACTIONS(2138),
    [anon_sym_COLON_COLON] = ACTIONS(2140),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2140),
    [anon_sym___declspec] = ACTIONS(2138),
    [anon_sym___based] = ACTIONS(2138),
    [anon_sym_RBRACE] = ACTIONS(2140),
    [anon_sym_signed] = ACTIONS(2138),
    [anon_sym_unsigned] = ACTIONS(2138),
    [anon_sym_long] = ACTIONS(2138),
    [anon_sym_short] = ACTIONS(2138),
    [anon_sym_LBRACK] = ACTIONS(2138),
    [anon_sym_static] = ACTIONS(2138),
    [anon_sym_register] = ACTIONS(2138),
    [anon_sym_inline] = ACTIONS(2138),
    [anon_sym___inline] = ACTIONS(2138),
    [anon_sym___inline__] = ACTIONS(2138),
    [anon_sym___forceinline] = ACTIONS(2138),
    [anon_sym_thread_local] = ACTIONS(2138),
    [anon_sym___thread] = ACTIONS(2138),
    [anon_sym_const] = ACTIONS(2138),
    [anon_sym_constexpr] = ACTIONS(2138),
    [anon_sym_volatile] = ACTIONS(2138),
    [anon_sym_restrict] = ACTIONS(2138),
    [anon_sym___restrict__] = ACTIONS(2138),
    [anon_sym__Atomic] = ACTIONS(2138),
    [anon_sym__Noreturn] = ACTIONS(2138),
    [anon_sym_noreturn] = ACTIONS(2138),
    [anon_sym_mutable] = ACTIONS(2138),
    [anon_sym_constinit] = ACTIONS(2138),
    [anon_sym_consteval] = ACTIONS(2138),
    [anon_sym_alignas] = ACTIONS(2138),
    [anon_sym__Alignas] = ACTIONS(2138),
    [sym_primitive_type] = ACTIONS(2138),
    [anon_sym_enum] = ACTIONS(2138),
    [anon_sym_class] = ACTIONS(2138),
    [anon_sym_struct] = ACTIONS(2138),
    [anon_sym_union] = ACTIONS(2138),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2138),
    [anon_sym_decltype] = ACTIONS(2138),
    [sym_virtual] = ACTIONS(2138),
    [anon_sym_explicit] = ACTIONS(2138),
    [anon_sym_typename] = ACTIONS(2138),
    [anon_sym_template] = ACTIONS(2138),
    [anon_sym_operator] = ACTIONS(2138),
    [anon_sym_friend] = ACTIONS(2138),
    [anon_sym_public] = ACTIONS(2138),
    [anon_sym_private] = ACTIONS(2138),
    [anon_sym_protected] = ACTIONS(2138),
    [anon_sym_using] = ACTIONS(2138),
    [anon_sym_static_assert] = ACTIONS(2138),
    [anon_sym_precise] = ACTIONS(2138),
    [anon_sym_shared] = ACTIONS(2138),
    [anon_sym_groupshared] = ACTIONS(2138),
    [anon_sym_uniform] = ACTIONS(2138),
    [anon_sym_row_major] = ACTIONS(2138),
    [anon_sym_column_major] = ACTIONS(2138),
    [anon_sym_globallycoherent] = ACTIONS(2138),
    [anon_sym_centroid] = ACTIONS(2138),
    [anon_sym_noperspective] = ACTIONS(2138),
    [anon_sym_nointerpolation] = ACTIONS(2138),
    [anon_sym_sample] = ACTIONS(2138),
    [anon_sym_linear] = ACTIONS(2138),
    [anon_sym_snorm] = ACTIONS(2138),
    [anon_sym_unorm] = ACTIONS(2138),
    [anon_sym_point] = ACTIONS(2138),
    [anon_sym_line] = ACTIONS(2138),
    [anon_sym_triangleadj] = ACTIONS(2138),
    [anon_sym_lineadj] = ACTIONS(2138),
    [anon_sym_triangle] = ACTIONS(2138),
  },
  [2068] = {
    [sym_identifier] = ACTIONS(2134),
    [aux_sym_preproc_def_token1] = ACTIONS(2134),
    [aux_sym_preproc_if_token1] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2134),
    [sym_preproc_directive] = ACTIONS(2134),
    [anon_sym_LPAREN2] = ACTIONS(2136),
    [anon_sym_TILDE] = ACTIONS(2136),
    [anon_sym_STAR] = ACTIONS(2136),
    [anon_sym_AMP_AMP] = ACTIONS(2136),
    [anon_sym_AMP] = ACTIONS(2134),
    [anon_sym___extension__] = ACTIONS(2134),
    [anon_sym_typedef] = ACTIONS(2134),
    [anon_sym_in] = ACTIONS(2134),
    [anon_sym_out] = ACTIONS(2134),
    [anon_sym_inout] = ACTIONS(2134),
    [anon_sym_extern] = ACTIONS(2134),
    [anon_sym___attribute__] = ACTIONS(2134),
    [anon_sym_COLON_COLON] = ACTIONS(2136),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2136),
    [anon_sym___declspec] = ACTIONS(2134),
    [anon_sym___based] = ACTIONS(2134),
    [anon_sym_RBRACE] = ACTIONS(2136),
    [anon_sym_signed] = ACTIONS(2134),
    [anon_sym_unsigned] = ACTIONS(2134),
    [anon_sym_long] = ACTIONS(2134),
    [anon_sym_short] = ACTIONS(2134),
    [anon_sym_LBRACK] = ACTIONS(2134),
    [anon_sym_static] = ACTIONS(2134),
    [anon_sym_register] = ACTIONS(2134),
    [anon_sym_inline] = ACTIONS(2134),
    [anon_sym___inline] = ACTIONS(2134),
    [anon_sym___inline__] = ACTIONS(2134),
    [anon_sym___forceinline] = ACTIONS(2134),
    [anon_sym_thread_local] = ACTIONS(2134),
    [anon_sym___thread] = ACTIONS(2134),
    [anon_sym_const] = ACTIONS(2134),
    [anon_sym_constexpr] = ACTIONS(2134),
    [anon_sym_volatile] = ACTIONS(2134),
    [anon_sym_restrict] = ACTIONS(2134),
    [anon_sym___restrict__] = ACTIONS(2134),
    [anon_sym__Atomic] = ACTIONS(2134),
    [anon_sym__Noreturn] = ACTIONS(2134),
    [anon_sym_noreturn] = ACTIONS(2134),
    [anon_sym_mutable] = ACTIONS(2134),
    [anon_sym_constinit] = ACTIONS(2134),
    [anon_sym_consteval] = ACTIONS(2134),
    [anon_sym_alignas] = ACTIONS(2134),
    [anon_sym__Alignas] = ACTIONS(2134),
    [sym_primitive_type] = ACTIONS(2134),
    [anon_sym_enum] = ACTIONS(2134),
    [anon_sym_class] = ACTIONS(2134),
    [anon_sym_struct] = ACTIONS(2134),
    [anon_sym_union] = ACTIONS(2134),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2134),
    [anon_sym_decltype] = ACTIONS(2134),
    [sym_virtual] = ACTIONS(2134),
    [anon_sym_explicit] = ACTIONS(2134),
    [anon_sym_typename] = ACTIONS(2134),
    [anon_sym_template] = ACTIONS(2134),
    [anon_sym_operator] = ACTIONS(2134),
    [anon_sym_friend] = ACTIONS(2134),
    [anon_sym_public] = ACTIONS(2134),
    [anon_sym_private] = ACTIONS(2134),
    [anon_sym_protected] = ACTIONS(2134),
    [anon_sym_using] = ACTIONS(2134),
    [anon_sym_static_assert] = ACTIONS(2134),
    [anon_sym_precise] = ACTIONS(2134),
    [anon_sym_shared] = ACTIONS(2134),
    [anon_sym_groupshared] = ACTIONS(2134),
    [anon_sym_uniform] = ACTIONS(2134),
    [anon_sym_row_major] = ACTIONS(2134),
    [anon_sym_column_major] = ACTIONS(2134),
    [anon_sym_globallycoherent] = ACTIONS(2134),
    [anon_sym_centroid] = ACTIONS(2134),
    [anon_sym_noperspective] = ACTIONS(2134),
    [anon_sym_nointerpolation] = ACTIONS(2134),
    [anon_sym_sample] = ACTIONS(2134),
    [anon_sym_linear] = ACTIONS(2134),
    [anon_sym_snorm] = ACTIONS(2134),
    [anon_sym_unorm] = ACTIONS(2134),
    [anon_sym_point] = ACTIONS(2134),
    [anon_sym_line] = ACTIONS(2134),
    [anon_sym_triangleadj] = ACTIONS(2134),
    [anon_sym_lineadj] = ACTIONS(2134),
    [anon_sym_triangle] = ACTIONS(2134),
  },
  [2069] = {
    [sym_identifier] = ACTIONS(2336),
    [aux_sym_preproc_def_token1] = ACTIONS(2336),
    [aux_sym_preproc_if_token1] = ACTIONS(2336),
    [aux_sym_preproc_if_token2] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2336),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2336),
    [sym_preproc_directive] = ACTIONS(2336),
    [anon_sym_LPAREN2] = ACTIONS(2338),
    [anon_sym_TILDE] = ACTIONS(2338),
    [anon_sym_STAR] = ACTIONS(2338),
    [anon_sym_AMP_AMP] = ACTIONS(2338),
    [anon_sym_AMP] = ACTIONS(2336),
    [anon_sym___extension__] = ACTIONS(2336),
    [anon_sym_typedef] = ACTIONS(2336),
    [anon_sym_in] = ACTIONS(2336),
    [anon_sym_out] = ACTIONS(2336),
    [anon_sym_inout] = ACTIONS(2336),
    [anon_sym_extern] = ACTIONS(2336),
    [anon_sym___attribute__] = ACTIONS(2336),
    [anon_sym_COLON_COLON] = ACTIONS(2338),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2338),
    [anon_sym___declspec] = ACTIONS(2336),
    [anon_sym___based] = ACTIONS(2336),
    [anon_sym_signed] = ACTIONS(2336),
    [anon_sym_unsigned] = ACTIONS(2336),
    [anon_sym_long] = ACTIONS(2336),
    [anon_sym_short] = ACTIONS(2336),
    [anon_sym_LBRACK] = ACTIONS(2336),
    [anon_sym_static] = ACTIONS(2336),
    [anon_sym_register] = ACTIONS(2336),
    [anon_sym_inline] = ACTIONS(2336),
    [anon_sym___inline] = ACTIONS(2336),
    [anon_sym___inline__] = ACTIONS(2336),
    [anon_sym___forceinline] = ACTIONS(2336),
    [anon_sym_thread_local] = ACTIONS(2336),
    [anon_sym___thread] = ACTIONS(2336),
    [anon_sym_const] = ACTIONS(2336),
    [anon_sym_constexpr] = ACTIONS(2336),
    [anon_sym_volatile] = ACTIONS(2336),
    [anon_sym_restrict] = ACTIONS(2336),
    [anon_sym___restrict__] = ACTIONS(2336),
    [anon_sym__Atomic] = ACTIONS(2336),
    [anon_sym__Noreturn] = ACTIONS(2336),
    [anon_sym_noreturn] = ACTIONS(2336),
    [anon_sym_mutable] = ACTIONS(2336),
    [anon_sym_constinit] = ACTIONS(2336),
    [anon_sym_consteval] = ACTIONS(2336),
    [anon_sym_alignas] = ACTIONS(2336),
    [anon_sym__Alignas] = ACTIONS(2336),
    [sym_primitive_type] = ACTIONS(2336),
    [anon_sym_enum] = ACTIONS(2336),
    [anon_sym_class] = ACTIONS(2336),
    [anon_sym_struct] = ACTIONS(2336),
    [anon_sym_union] = ACTIONS(2336),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2336),
    [anon_sym_decltype] = ACTIONS(2336),
    [sym_virtual] = ACTIONS(2336),
    [anon_sym_explicit] = ACTIONS(2336),
    [anon_sym_typename] = ACTIONS(2336),
    [anon_sym_template] = ACTIONS(2336),
    [anon_sym_operator] = ACTIONS(2336),
    [anon_sym_friend] = ACTIONS(2336),
    [anon_sym_public] = ACTIONS(2336),
    [anon_sym_private] = ACTIONS(2336),
    [anon_sym_protected] = ACTIONS(2336),
    [anon_sym_using] = ACTIONS(2336),
    [anon_sym_static_assert] = ACTIONS(2336),
    [anon_sym_precise] = ACTIONS(2336),
    [anon_sym_shared] = ACTIONS(2336),
    [anon_sym_groupshared] = ACTIONS(2336),
    [anon_sym_uniform] = ACTIONS(2336),
    [anon_sym_row_major] = ACTIONS(2336),
    [anon_sym_column_major] = ACTIONS(2336),
    [anon_sym_globallycoherent] = ACTIONS(2336),
    [anon_sym_centroid] = ACTIONS(2336),
    [anon_sym_noperspective] = ACTIONS(2336),
    [anon_sym_nointerpolation] = ACTIONS(2336),
    [anon_sym_sample] = ACTIONS(2336),
    [anon_sym_linear] = ACTIONS(2336),
    [anon_sym_snorm] = ACTIONS(2336),
    [anon_sym_unorm] = ACTIONS(2336),
    [anon_sym_point] = ACTIONS(2336),
    [anon_sym_line] = ACTIONS(2336),
    [anon_sym_triangleadj] = ACTIONS(2336),
    [anon_sym_lineadj] = ACTIONS(2336),
    [anon_sym_triangle] = ACTIONS(2336),
  },
  [2070] = {
    [sym_identifier] = ACTIONS(2516),
    [aux_sym_preproc_def_token1] = ACTIONS(2516),
    [aux_sym_preproc_if_token1] = ACTIONS(2516),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2516),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2516),
    [sym_preproc_directive] = ACTIONS(2516),
    [anon_sym_LPAREN2] = ACTIONS(2518),
    [anon_sym_TILDE] = ACTIONS(2518),
    [anon_sym_STAR] = ACTIONS(2518),
    [anon_sym_AMP_AMP] = ACTIONS(2518),
    [anon_sym_AMP] = ACTIONS(2516),
    [anon_sym___extension__] = ACTIONS(2516),
    [anon_sym_typedef] = ACTIONS(2516),
    [anon_sym_in] = ACTIONS(2516),
    [anon_sym_out] = ACTIONS(2516),
    [anon_sym_inout] = ACTIONS(2516),
    [anon_sym_extern] = ACTIONS(2516),
    [anon_sym___attribute__] = ACTIONS(2516),
    [anon_sym_COLON_COLON] = ACTIONS(2518),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2518),
    [anon_sym___declspec] = ACTIONS(2516),
    [anon_sym___based] = ACTIONS(2516),
    [anon_sym_RBRACE] = ACTIONS(2518),
    [anon_sym_signed] = ACTIONS(2516),
    [anon_sym_unsigned] = ACTIONS(2516),
    [anon_sym_long] = ACTIONS(2516),
    [anon_sym_short] = ACTIONS(2516),
    [anon_sym_LBRACK] = ACTIONS(2516),
    [anon_sym_static] = ACTIONS(2516),
    [anon_sym_register] = ACTIONS(2516),
    [anon_sym_inline] = ACTIONS(2516),
    [anon_sym___inline] = ACTIONS(2516),
    [anon_sym___inline__] = ACTIONS(2516),
    [anon_sym___forceinline] = ACTIONS(2516),
    [anon_sym_thread_local] = ACTIONS(2516),
    [anon_sym___thread] = ACTIONS(2516),
    [anon_sym_const] = ACTIONS(2516),
    [anon_sym_constexpr] = ACTIONS(2516),
    [anon_sym_volatile] = ACTIONS(2516),
    [anon_sym_restrict] = ACTIONS(2516),
    [anon_sym___restrict__] = ACTIONS(2516),
    [anon_sym__Atomic] = ACTIONS(2516),
    [anon_sym__Noreturn] = ACTIONS(2516),
    [anon_sym_noreturn] = ACTIONS(2516),
    [anon_sym_mutable] = ACTIONS(2516),
    [anon_sym_constinit] = ACTIONS(2516),
    [anon_sym_consteval] = ACTIONS(2516),
    [anon_sym_alignas] = ACTIONS(2516),
    [anon_sym__Alignas] = ACTIONS(2516),
    [sym_primitive_type] = ACTIONS(2516),
    [anon_sym_enum] = ACTIONS(2516),
    [anon_sym_class] = ACTIONS(2516),
    [anon_sym_struct] = ACTIONS(2516),
    [anon_sym_union] = ACTIONS(2516),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2516),
    [anon_sym_decltype] = ACTIONS(2516),
    [sym_virtual] = ACTIONS(2516),
    [anon_sym_explicit] = ACTIONS(2516),
    [anon_sym_typename] = ACTIONS(2516),
    [anon_sym_template] = ACTIONS(2516),
    [anon_sym_operator] = ACTIONS(2516),
    [anon_sym_friend] = ACTIONS(2516),
    [anon_sym_public] = ACTIONS(2516),
    [anon_sym_private] = ACTIONS(2516),
    [anon_sym_protected] = ACTIONS(2516),
    [anon_sym_using] = ACTIONS(2516),
    [anon_sym_static_assert] = ACTIONS(2516),
    [anon_sym_precise] = ACTIONS(2516),
    [anon_sym_shared] = ACTIONS(2516),
    [anon_sym_groupshared] = ACTIONS(2516),
    [anon_sym_uniform] = ACTIONS(2516),
    [anon_sym_row_major] = ACTIONS(2516),
    [anon_sym_column_major] = ACTIONS(2516),
    [anon_sym_globallycoherent] = ACTIONS(2516),
    [anon_sym_centroid] = ACTIONS(2516),
    [anon_sym_noperspective] = ACTIONS(2516),
    [anon_sym_nointerpolation] = ACTIONS(2516),
    [anon_sym_sample] = ACTIONS(2516),
    [anon_sym_linear] = ACTIONS(2516),
    [anon_sym_snorm] = ACTIONS(2516),
    [anon_sym_unorm] = ACTIONS(2516),
    [anon_sym_point] = ACTIONS(2516),
    [anon_sym_line] = ACTIONS(2516),
    [anon_sym_triangleadj] = ACTIONS(2516),
    [anon_sym_lineadj] = ACTIONS(2516),
    [anon_sym_triangle] = ACTIONS(2516),
  },
  [2071] = {
    [sym_identifier] = ACTIONS(2498),
    [aux_sym_preproc_def_token1] = ACTIONS(2498),
    [aux_sym_preproc_if_token1] = ACTIONS(2498),
    [aux_sym_preproc_if_token2] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2498),
    [sym_preproc_directive] = ACTIONS(2498),
    [anon_sym_LPAREN2] = ACTIONS(2500),
    [anon_sym_TILDE] = ACTIONS(2500),
    [anon_sym_STAR] = ACTIONS(2500),
    [anon_sym_AMP_AMP] = ACTIONS(2500),
    [anon_sym_AMP] = ACTIONS(2498),
    [anon_sym___extension__] = ACTIONS(2498),
    [anon_sym_typedef] = ACTIONS(2498),
    [anon_sym_in] = ACTIONS(2498),
    [anon_sym_out] = ACTIONS(2498),
    [anon_sym_inout] = ACTIONS(2498),
    [anon_sym_extern] = ACTIONS(2498),
    [anon_sym___attribute__] = ACTIONS(2498),
    [anon_sym_COLON_COLON] = ACTIONS(2500),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2500),
    [anon_sym___declspec] = ACTIONS(2498),
    [anon_sym___based] = ACTIONS(2498),
    [anon_sym_signed] = ACTIONS(2498),
    [anon_sym_unsigned] = ACTIONS(2498),
    [anon_sym_long] = ACTIONS(2498),
    [anon_sym_short] = ACTIONS(2498),
    [anon_sym_LBRACK] = ACTIONS(2498),
    [anon_sym_static] = ACTIONS(2498),
    [anon_sym_register] = ACTIONS(2498),
    [anon_sym_inline] = ACTIONS(2498),
    [anon_sym___inline] = ACTIONS(2498),
    [anon_sym___inline__] = ACTIONS(2498),
    [anon_sym___forceinline] = ACTIONS(2498),
    [anon_sym_thread_local] = ACTIONS(2498),
    [anon_sym___thread] = ACTIONS(2498),
    [anon_sym_const] = ACTIONS(2498),
    [anon_sym_constexpr] = ACTIONS(2498),
    [anon_sym_volatile] = ACTIONS(2498),
    [anon_sym_restrict] = ACTIONS(2498),
    [anon_sym___restrict__] = ACTIONS(2498),
    [anon_sym__Atomic] = ACTIONS(2498),
    [anon_sym__Noreturn] = ACTIONS(2498),
    [anon_sym_noreturn] = ACTIONS(2498),
    [anon_sym_mutable] = ACTIONS(2498),
    [anon_sym_constinit] = ACTIONS(2498),
    [anon_sym_consteval] = ACTIONS(2498),
    [anon_sym_alignas] = ACTIONS(2498),
    [anon_sym__Alignas] = ACTIONS(2498),
    [sym_primitive_type] = ACTIONS(2498),
    [anon_sym_enum] = ACTIONS(2498),
    [anon_sym_class] = ACTIONS(2498),
    [anon_sym_struct] = ACTIONS(2498),
    [anon_sym_union] = ACTIONS(2498),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2498),
    [anon_sym_decltype] = ACTIONS(2498),
    [sym_virtual] = ACTIONS(2498),
    [anon_sym_explicit] = ACTIONS(2498),
    [anon_sym_typename] = ACTIONS(2498),
    [anon_sym_template] = ACTIONS(2498),
    [anon_sym_operator] = ACTIONS(2498),
    [anon_sym_friend] = ACTIONS(2498),
    [anon_sym_public] = ACTIONS(2498),
    [anon_sym_private] = ACTIONS(2498),
    [anon_sym_protected] = ACTIONS(2498),
    [anon_sym_using] = ACTIONS(2498),
    [anon_sym_static_assert] = ACTIONS(2498),
    [anon_sym_precise] = ACTIONS(2498),
    [anon_sym_shared] = ACTIONS(2498),
    [anon_sym_groupshared] = ACTIONS(2498),
    [anon_sym_uniform] = ACTIONS(2498),
    [anon_sym_row_major] = ACTIONS(2498),
    [anon_sym_column_major] = ACTIONS(2498),
    [anon_sym_globallycoherent] = ACTIONS(2498),
    [anon_sym_centroid] = ACTIONS(2498),
    [anon_sym_noperspective] = ACTIONS(2498),
    [anon_sym_nointerpolation] = ACTIONS(2498),
    [anon_sym_sample] = ACTIONS(2498),
    [anon_sym_linear] = ACTIONS(2498),
    [anon_sym_snorm] = ACTIONS(2498),
    [anon_sym_unorm] = ACTIONS(2498),
    [anon_sym_point] = ACTIONS(2498),
    [anon_sym_line] = ACTIONS(2498),
    [anon_sym_triangleadj] = ACTIONS(2498),
    [anon_sym_lineadj] = ACTIONS(2498),
    [anon_sym_triangle] = ACTIONS(2498),
  },
  [2072] = {
    [sym_identifier] = ACTIONS(2444),
    [aux_sym_preproc_def_token1] = ACTIONS(2444),
    [aux_sym_preproc_if_token1] = ACTIONS(2444),
    [aux_sym_preproc_if_token2] = ACTIONS(2444),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2444),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2444),
    [sym_preproc_directive] = ACTIONS(2444),
    [anon_sym_LPAREN2] = ACTIONS(2446),
    [anon_sym_TILDE] = ACTIONS(2446),
    [anon_sym_STAR] = ACTIONS(2446),
    [anon_sym_AMP_AMP] = ACTIONS(2446),
    [anon_sym_AMP] = ACTIONS(2444),
    [anon_sym___extension__] = ACTIONS(2444),
    [anon_sym_typedef] = ACTIONS(2444),
    [anon_sym_in] = ACTIONS(2444),
    [anon_sym_out] = ACTIONS(2444),
    [anon_sym_inout] = ACTIONS(2444),
    [anon_sym_extern] = ACTIONS(2444),
    [anon_sym___attribute__] = ACTIONS(2444),
    [anon_sym_COLON_COLON] = ACTIONS(2446),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2446),
    [anon_sym___declspec] = ACTIONS(2444),
    [anon_sym___based] = ACTIONS(2444),
    [anon_sym_signed] = ACTIONS(2444),
    [anon_sym_unsigned] = ACTIONS(2444),
    [anon_sym_long] = ACTIONS(2444),
    [anon_sym_short] = ACTIONS(2444),
    [anon_sym_LBRACK] = ACTIONS(2444),
    [anon_sym_static] = ACTIONS(2444),
    [anon_sym_register] = ACTIONS(2444),
    [anon_sym_inline] = ACTIONS(2444),
    [anon_sym___inline] = ACTIONS(2444),
    [anon_sym___inline__] = ACTIONS(2444),
    [anon_sym___forceinline] = ACTIONS(2444),
    [anon_sym_thread_local] = ACTIONS(2444),
    [anon_sym___thread] = ACTIONS(2444),
    [anon_sym_const] = ACTIONS(2444),
    [anon_sym_constexpr] = ACTIONS(2444),
    [anon_sym_volatile] = ACTIONS(2444),
    [anon_sym_restrict] = ACTIONS(2444),
    [anon_sym___restrict__] = ACTIONS(2444),
    [anon_sym__Atomic] = ACTIONS(2444),
    [anon_sym__Noreturn] = ACTIONS(2444),
    [anon_sym_noreturn] = ACTIONS(2444),
    [anon_sym_mutable] = ACTIONS(2444),
    [anon_sym_constinit] = ACTIONS(2444),
    [anon_sym_consteval] = ACTIONS(2444),
    [anon_sym_alignas] = ACTIONS(2444),
    [anon_sym__Alignas] = ACTIONS(2444),
    [sym_primitive_type] = ACTIONS(2444),
    [anon_sym_enum] = ACTIONS(2444),
    [anon_sym_class] = ACTIONS(2444),
    [anon_sym_struct] = ACTIONS(2444),
    [anon_sym_union] = ACTIONS(2444),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2444),
    [anon_sym_decltype] = ACTIONS(2444),
    [sym_virtual] = ACTIONS(2444),
    [anon_sym_explicit] = ACTIONS(2444),
    [anon_sym_typename] = ACTIONS(2444),
    [anon_sym_template] = ACTIONS(2444),
    [anon_sym_operator] = ACTIONS(2444),
    [anon_sym_friend] = ACTIONS(2444),
    [anon_sym_public] = ACTIONS(2444),
    [anon_sym_private] = ACTIONS(2444),
    [anon_sym_protected] = ACTIONS(2444),
    [anon_sym_using] = ACTIONS(2444),
    [anon_sym_static_assert] = ACTIONS(2444),
    [anon_sym_precise] = ACTIONS(2444),
    [anon_sym_shared] = ACTIONS(2444),
    [anon_sym_groupshared] = ACTIONS(2444),
    [anon_sym_uniform] = ACTIONS(2444),
    [anon_sym_row_major] = ACTIONS(2444),
    [anon_sym_column_major] = ACTIONS(2444),
    [anon_sym_globallycoherent] = ACTIONS(2444),
    [anon_sym_centroid] = ACTIONS(2444),
    [anon_sym_noperspective] = ACTIONS(2444),
    [anon_sym_nointerpolation] = ACTIONS(2444),
    [anon_sym_sample] = ACTIONS(2444),
    [anon_sym_linear] = ACTIONS(2444),
    [anon_sym_snorm] = ACTIONS(2444),
    [anon_sym_unorm] = ACTIONS(2444),
    [anon_sym_point] = ACTIONS(2444),
    [anon_sym_line] = ACTIONS(2444),
    [anon_sym_triangleadj] = ACTIONS(2444),
    [anon_sym_lineadj] = ACTIONS(2444),
    [anon_sym_triangle] = ACTIONS(2444),
  },
  [2073] = {
    [sym_identifier] = ACTIONS(2448),
    [aux_sym_preproc_def_token1] = ACTIONS(2448),
    [aux_sym_preproc_if_token1] = ACTIONS(2448),
    [aux_sym_preproc_if_token2] = ACTIONS(2448),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2448),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2448),
    [sym_preproc_directive] = ACTIONS(2448),
    [anon_sym_LPAREN2] = ACTIONS(2450),
    [anon_sym_TILDE] = ACTIONS(2450),
    [anon_sym_STAR] = ACTIONS(2450),
    [anon_sym_AMP_AMP] = ACTIONS(2450),
    [anon_sym_AMP] = ACTIONS(2448),
    [anon_sym___extension__] = ACTIONS(2448),
    [anon_sym_typedef] = ACTIONS(2448),
    [anon_sym_in] = ACTIONS(2448),
    [anon_sym_out] = ACTIONS(2448),
    [anon_sym_inout] = ACTIONS(2448),
    [anon_sym_extern] = ACTIONS(2448),
    [anon_sym___attribute__] = ACTIONS(2448),
    [anon_sym_COLON_COLON] = ACTIONS(2450),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2450),
    [anon_sym___declspec] = ACTIONS(2448),
    [anon_sym___based] = ACTIONS(2448),
    [anon_sym_signed] = ACTIONS(2448),
    [anon_sym_unsigned] = ACTIONS(2448),
    [anon_sym_long] = ACTIONS(2448),
    [anon_sym_short] = ACTIONS(2448),
    [anon_sym_LBRACK] = ACTIONS(2448),
    [anon_sym_static] = ACTIONS(2448),
    [anon_sym_register] = ACTIONS(2448),
    [anon_sym_inline] = ACTIONS(2448),
    [anon_sym___inline] = ACTIONS(2448),
    [anon_sym___inline__] = ACTIONS(2448),
    [anon_sym___forceinline] = ACTIONS(2448),
    [anon_sym_thread_local] = ACTIONS(2448),
    [anon_sym___thread] = ACTIONS(2448),
    [anon_sym_const] = ACTIONS(2448),
    [anon_sym_constexpr] = ACTIONS(2448),
    [anon_sym_volatile] = ACTIONS(2448),
    [anon_sym_restrict] = ACTIONS(2448),
    [anon_sym___restrict__] = ACTIONS(2448),
    [anon_sym__Atomic] = ACTIONS(2448),
    [anon_sym__Noreturn] = ACTIONS(2448),
    [anon_sym_noreturn] = ACTIONS(2448),
    [anon_sym_mutable] = ACTIONS(2448),
    [anon_sym_constinit] = ACTIONS(2448),
    [anon_sym_consteval] = ACTIONS(2448),
    [anon_sym_alignas] = ACTIONS(2448),
    [anon_sym__Alignas] = ACTIONS(2448),
    [sym_primitive_type] = ACTIONS(2448),
    [anon_sym_enum] = ACTIONS(2448),
    [anon_sym_class] = ACTIONS(2448),
    [anon_sym_struct] = ACTIONS(2448),
    [anon_sym_union] = ACTIONS(2448),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2448),
    [anon_sym_decltype] = ACTIONS(2448),
    [sym_virtual] = ACTIONS(2448),
    [anon_sym_explicit] = ACTIONS(2448),
    [anon_sym_typename] = ACTIONS(2448),
    [anon_sym_template] = ACTIONS(2448),
    [anon_sym_operator] = ACTIONS(2448),
    [anon_sym_friend] = ACTIONS(2448),
    [anon_sym_public] = ACTIONS(2448),
    [anon_sym_private] = ACTIONS(2448),
    [anon_sym_protected] = ACTIONS(2448),
    [anon_sym_using] = ACTIONS(2448),
    [anon_sym_static_assert] = ACTIONS(2448),
    [anon_sym_precise] = ACTIONS(2448),
    [anon_sym_shared] = ACTIONS(2448),
    [anon_sym_groupshared] = ACTIONS(2448),
    [anon_sym_uniform] = ACTIONS(2448),
    [anon_sym_row_major] = ACTIONS(2448),
    [anon_sym_column_major] = ACTIONS(2448),
    [anon_sym_globallycoherent] = ACTIONS(2448),
    [anon_sym_centroid] = ACTIONS(2448),
    [anon_sym_noperspective] = ACTIONS(2448),
    [anon_sym_nointerpolation] = ACTIONS(2448),
    [anon_sym_sample] = ACTIONS(2448),
    [anon_sym_linear] = ACTIONS(2448),
    [anon_sym_snorm] = ACTIONS(2448),
    [anon_sym_unorm] = ACTIONS(2448),
    [anon_sym_point] = ACTIONS(2448),
    [anon_sym_line] = ACTIONS(2448),
    [anon_sym_triangleadj] = ACTIONS(2448),
    [anon_sym_lineadj] = ACTIONS(2448),
    [anon_sym_triangle] = ACTIONS(2448),
  },
  [2074] = {
    [sym_identifier] = ACTIONS(2466),
    [aux_sym_preproc_def_token1] = ACTIONS(2466),
    [aux_sym_preproc_if_token1] = ACTIONS(2466),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2466),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2466),
    [sym_preproc_directive] = ACTIONS(2466),
    [anon_sym_LPAREN2] = ACTIONS(2468),
    [anon_sym_TILDE] = ACTIONS(2468),
    [anon_sym_STAR] = ACTIONS(2468),
    [anon_sym_AMP_AMP] = ACTIONS(2468),
    [anon_sym_AMP] = ACTIONS(2466),
    [anon_sym___extension__] = ACTIONS(2466),
    [anon_sym_typedef] = ACTIONS(2466),
    [anon_sym_in] = ACTIONS(2466),
    [anon_sym_out] = ACTIONS(2466),
    [anon_sym_inout] = ACTIONS(2466),
    [anon_sym_extern] = ACTIONS(2466),
    [anon_sym___attribute__] = ACTIONS(2466),
    [anon_sym_COLON_COLON] = ACTIONS(2468),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2468),
    [anon_sym___declspec] = ACTIONS(2466),
    [anon_sym___based] = ACTIONS(2466),
    [anon_sym_RBRACE] = ACTIONS(2468),
    [anon_sym_signed] = ACTIONS(2466),
    [anon_sym_unsigned] = ACTIONS(2466),
    [anon_sym_long] = ACTIONS(2466),
    [anon_sym_short] = ACTIONS(2466),
    [anon_sym_LBRACK] = ACTIONS(2466),
    [anon_sym_static] = ACTIONS(2466),
    [anon_sym_register] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2466),
    [anon_sym___inline] = ACTIONS(2466),
    [anon_sym___inline__] = ACTIONS(2466),
    [anon_sym___forceinline] = ACTIONS(2466),
    [anon_sym_thread_local] = ACTIONS(2466),
    [anon_sym___thread] = ACTIONS(2466),
    [anon_sym_const] = ACTIONS(2466),
    [anon_sym_constexpr] = ACTIONS(2466),
    [anon_sym_volatile] = ACTIONS(2466),
    [anon_sym_restrict] = ACTIONS(2466),
    [anon_sym___restrict__] = ACTIONS(2466),
    [anon_sym__Atomic] = ACTIONS(2466),
    [anon_sym__Noreturn] = ACTIONS(2466),
    [anon_sym_noreturn] = ACTIONS(2466),
    [anon_sym_mutable] = ACTIONS(2466),
    [anon_sym_constinit] = ACTIONS(2466),
    [anon_sym_consteval] = ACTIONS(2466),
    [anon_sym_alignas] = ACTIONS(2466),
    [anon_sym__Alignas] = ACTIONS(2466),
    [sym_primitive_type] = ACTIONS(2466),
    [anon_sym_enum] = ACTIONS(2466),
    [anon_sym_class] = ACTIONS(2466),
    [anon_sym_struct] = ACTIONS(2466),
    [anon_sym_union] = ACTIONS(2466),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2466),
    [anon_sym_decltype] = ACTIONS(2466),
    [sym_virtual] = ACTIONS(2466),
    [anon_sym_explicit] = ACTIONS(2466),
    [anon_sym_typename] = ACTIONS(2466),
    [anon_sym_template] = ACTIONS(2466),
    [anon_sym_operator] = ACTIONS(2466),
    [anon_sym_friend] = ACTIONS(2466),
    [anon_sym_public] = ACTIONS(2466),
    [anon_sym_private] = ACTIONS(2466),
    [anon_sym_protected] = ACTIONS(2466),
    [anon_sym_using] = ACTIONS(2466),
    [anon_sym_static_assert] = ACTIONS(2466),
    [anon_sym_precise] = ACTIONS(2466),
    [anon_sym_shared] = ACTIONS(2466),
    [anon_sym_groupshared] = ACTIONS(2466),
    [anon_sym_uniform] = ACTIONS(2466),
    [anon_sym_row_major] = ACTIONS(2466),
    [anon_sym_column_major] = ACTIONS(2466),
    [anon_sym_globallycoherent] = ACTIONS(2466),
    [anon_sym_centroid] = ACTIONS(2466),
    [anon_sym_noperspective] = ACTIONS(2466),
    [anon_sym_nointerpolation] = ACTIONS(2466),
    [anon_sym_sample] = ACTIONS(2466),
    [anon_sym_linear] = ACTIONS(2466),
    [anon_sym_snorm] = ACTIONS(2466),
    [anon_sym_unorm] = ACTIONS(2466),
    [anon_sym_point] = ACTIONS(2466),
    [anon_sym_line] = ACTIONS(2466),
    [anon_sym_triangleadj] = ACTIONS(2466),
    [anon_sym_lineadj] = ACTIONS(2466),
    [anon_sym_triangle] = ACTIONS(2466),
  },
  [2075] = {
    [sym_identifier] = ACTIONS(2490),
    [aux_sym_preproc_def_token1] = ACTIONS(2490),
    [aux_sym_preproc_if_token1] = ACTIONS(2490),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2490),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2490),
    [sym_preproc_directive] = ACTIONS(2490),
    [anon_sym_LPAREN2] = ACTIONS(2492),
    [anon_sym_TILDE] = ACTIONS(2492),
    [anon_sym_STAR] = ACTIONS(2492),
    [anon_sym_AMP_AMP] = ACTIONS(2492),
    [anon_sym_AMP] = ACTIONS(2490),
    [anon_sym___extension__] = ACTIONS(2490),
    [anon_sym_typedef] = ACTIONS(2490),
    [anon_sym_in] = ACTIONS(2490),
    [anon_sym_out] = ACTIONS(2490),
    [anon_sym_inout] = ACTIONS(2490),
    [anon_sym_extern] = ACTIONS(2490),
    [anon_sym___attribute__] = ACTIONS(2490),
    [anon_sym_COLON_COLON] = ACTIONS(2492),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2492),
    [anon_sym___declspec] = ACTIONS(2490),
    [anon_sym___based] = ACTIONS(2490),
    [anon_sym_RBRACE] = ACTIONS(2492),
    [anon_sym_signed] = ACTIONS(2490),
    [anon_sym_unsigned] = ACTIONS(2490),
    [anon_sym_long] = ACTIONS(2490),
    [anon_sym_short] = ACTIONS(2490),
    [anon_sym_LBRACK] = ACTIONS(2490),
    [anon_sym_static] = ACTIONS(2490),
    [anon_sym_register] = ACTIONS(2490),
    [anon_sym_inline] = ACTIONS(2490),
    [anon_sym___inline] = ACTIONS(2490),
    [anon_sym___inline__] = ACTIONS(2490),
    [anon_sym___forceinline] = ACTIONS(2490),
    [anon_sym_thread_local] = ACTIONS(2490),
    [anon_sym___thread] = ACTIONS(2490),
    [anon_sym_const] = ACTIONS(2490),
    [anon_sym_constexpr] = ACTIONS(2490),
    [anon_sym_volatile] = ACTIONS(2490),
    [anon_sym_restrict] = ACTIONS(2490),
    [anon_sym___restrict__] = ACTIONS(2490),
    [anon_sym__Atomic] = ACTIONS(2490),
    [anon_sym__Noreturn] = ACTIONS(2490),
    [anon_sym_noreturn] = ACTIONS(2490),
    [anon_sym_mutable] = ACTIONS(2490),
    [anon_sym_constinit] = ACTIONS(2490),
    [anon_sym_consteval] = ACTIONS(2490),
    [anon_sym_alignas] = ACTIONS(2490),
    [anon_sym__Alignas] = ACTIONS(2490),
    [sym_primitive_type] = ACTIONS(2490),
    [anon_sym_enum] = ACTIONS(2490),
    [anon_sym_class] = ACTIONS(2490),
    [anon_sym_struct] = ACTIONS(2490),
    [anon_sym_union] = ACTIONS(2490),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2490),
    [anon_sym_decltype] = ACTIONS(2490),
    [sym_virtual] = ACTIONS(2490),
    [anon_sym_explicit] = ACTIONS(2490),
    [anon_sym_typename] = ACTIONS(2490),
    [anon_sym_template] = ACTIONS(2490),
    [anon_sym_operator] = ACTIONS(2490),
    [anon_sym_friend] = ACTIONS(2490),
    [anon_sym_public] = ACTIONS(2490),
    [anon_sym_private] = ACTIONS(2490),
    [anon_sym_protected] = ACTIONS(2490),
    [anon_sym_using] = ACTIONS(2490),
    [anon_sym_static_assert] = ACTIONS(2490),
    [anon_sym_precise] = ACTIONS(2490),
    [anon_sym_shared] = ACTIONS(2490),
    [anon_sym_groupshared] = ACTIONS(2490),
    [anon_sym_uniform] = ACTIONS(2490),
    [anon_sym_row_major] = ACTIONS(2490),
    [anon_sym_column_major] = ACTIONS(2490),
    [anon_sym_globallycoherent] = ACTIONS(2490),
    [anon_sym_centroid] = ACTIONS(2490),
    [anon_sym_noperspective] = ACTIONS(2490),
    [anon_sym_nointerpolation] = ACTIONS(2490),
    [anon_sym_sample] = ACTIONS(2490),
    [anon_sym_linear] = ACTIONS(2490),
    [anon_sym_snorm] = ACTIONS(2490),
    [anon_sym_unorm] = ACTIONS(2490),
    [anon_sym_point] = ACTIONS(2490),
    [anon_sym_line] = ACTIONS(2490),
    [anon_sym_triangleadj] = ACTIONS(2490),
    [anon_sym_lineadj] = ACTIONS(2490),
    [anon_sym_triangle] = ACTIONS(2490),
  },
  [2076] = {
    [sym_identifier] = ACTIONS(5009),
    [aux_sym_preproc_def_token1] = ACTIONS(5009),
    [aux_sym_preproc_if_token1] = ACTIONS(5009),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5009),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5009),
    [sym_preproc_directive] = ACTIONS(5009),
    [anon_sym_LPAREN2] = ACTIONS(5011),
    [anon_sym_TILDE] = ACTIONS(5011),
    [anon_sym_STAR] = ACTIONS(5011),
    [anon_sym_AMP_AMP] = ACTIONS(5011),
    [anon_sym_AMP] = ACTIONS(5009),
    [anon_sym___extension__] = ACTIONS(5009),
    [anon_sym_typedef] = ACTIONS(5009),
    [anon_sym_in] = ACTIONS(5009),
    [anon_sym_out] = ACTIONS(5009),
    [anon_sym_inout] = ACTIONS(5009),
    [anon_sym_extern] = ACTIONS(5009),
    [anon_sym___attribute__] = ACTIONS(5009),
    [anon_sym_COLON_COLON] = ACTIONS(5011),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5011),
    [anon_sym___declspec] = ACTIONS(5009),
    [anon_sym___based] = ACTIONS(5009),
    [anon_sym_RBRACE] = ACTIONS(5011),
    [anon_sym_signed] = ACTIONS(5009),
    [anon_sym_unsigned] = ACTIONS(5009),
    [anon_sym_long] = ACTIONS(5009),
    [anon_sym_short] = ACTIONS(5009),
    [anon_sym_LBRACK] = ACTIONS(5009),
    [anon_sym_static] = ACTIONS(5009),
    [anon_sym_register] = ACTIONS(5009),
    [anon_sym_inline] = ACTIONS(5009),
    [anon_sym___inline] = ACTIONS(5009),
    [anon_sym___inline__] = ACTIONS(5009),
    [anon_sym___forceinline] = ACTIONS(5009),
    [anon_sym_thread_local] = ACTIONS(5009),
    [anon_sym___thread] = ACTIONS(5009),
    [anon_sym_const] = ACTIONS(5009),
    [anon_sym_constexpr] = ACTIONS(5009),
    [anon_sym_volatile] = ACTIONS(5009),
    [anon_sym_restrict] = ACTIONS(5009),
    [anon_sym___restrict__] = ACTIONS(5009),
    [anon_sym__Atomic] = ACTIONS(5009),
    [anon_sym__Noreturn] = ACTIONS(5009),
    [anon_sym_noreturn] = ACTIONS(5009),
    [anon_sym_mutable] = ACTIONS(5009),
    [anon_sym_constinit] = ACTIONS(5009),
    [anon_sym_consteval] = ACTIONS(5009),
    [anon_sym_alignas] = ACTIONS(5009),
    [anon_sym__Alignas] = ACTIONS(5009),
    [sym_primitive_type] = ACTIONS(5009),
    [anon_sym_enum] = ACTIONS(5009),
    [anon_sym_class] = ACTIONS(5009),
    [anon_sym_struct] = ACTIONS(5009),
    [anon_sym_union] = ACTIONS(5009),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5009),
    [anon_sym_decltype] = ACTIONS(5009),
    [sym_virtual] = ACTIONS(5009),
    [anon_sym_explicit] = ACTIONS(5009),
    [anon_sym_typename] = ACTIONS(5009),
    [anon_sym_template] = ACTIONS(5009),
    [anon_sym_operator] = ACTIONS(5009),
    [anon_sym_friend] = ACTIONS(5009),
    [anon_sym_public] = ACTIONS(5009),
    [anon_sym_private] = ACTIONS(5009),
    [anon_sym_protected] = ACTIONS(5009),
    [anon_sym_using] = ACTIONS(5009),
    [anon_sym_static_assert] = ACTIONS(5009),
    [anon_sym_precise] = ACTIONS(5009),
    [anon_sym_shared] = ACTIONS(5009),
    [anon_sym_groupshared] = ACTIONS(5009),
    [anon_sym_uniform] = ACTIONS(5009),
    [anon_sym_row_major] = ACTIONS(5009),
    [anon_sym_column_major] = ACTIONS(5009),
    [anon_sym_globallycoherent] = ACTIONS(5009),
    [anon_sym_centroid] = ACTIONS(5009),
    [anon_sym_noperspective] = ACTIONS(5009),
    [anon_sym_nointerpolation] = ACTIONS(5009),
    [anon_sym_sample] = ACTIONS(5009),
    [anon_sym_linear] = ACTIONS(5009),
    [anon_sym_snorm] = ACTIONS(5009),
    [anon_sym_unorm] = ACTIONS(5009),
    [anon_sym_point] = ACTIONS(5009),
    [anon_sym_line] = ACTIONS(5009),
    [anon_sym_triangleadj] = ACTIONS(5009),
    [anon_sym_lineadj] = ACTIONS(5009),
    [anon_sym_triangle] = ACTIONS(5009),
  },
  [2077] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token2] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_friend] = ACTIONS(2332),
    [anon_sym_public] = ACTIONS(2332),
    [anon_sym_private] = ACTIONS(2332),
    [anon_sym_protected] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
  },
  [2078] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token2] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_friend] = ACTIONS(2332),
    [anon_sym_public] = ACTIONS(2332),
    [anon_sym_private] = ACTIONS(2332),
    [anon_sym_protected] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
  },
  [2079] = {
    [sym_identifier] = ACTIONS(2498),
    [aux_sym_preproc_def_token1] = ACTIONS(2498),
    [aux_sym_preproc_if_token1] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2498),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2498),
    [sym_preproc_directive] = ACTIONS(2498),
    [anon_sym_LPAREN2] = ACTIONS(2500),
    [anon_sym_TILDE] = ACTIONS(2500),
    [anon_sym_STAR] = ACTIONS(2500),
    [anon_sym_AMP_AMP] = ACTIONS(2500),
    [anon_sym_AMP] = ACTIONS(2498),
    [anon_sym___extension__] = ACTIONS(2498),
    [anon_sym_typedef] = ACTIONS(2498),
    [anon_sym_in] = ACTIONS(2498),
    [anon_sym_out] = ACTIONS(2498),
    [anon_sym_inout] = ACTIONS(2498),
    [anon_sym_extern] = ACTIONS(2498),
    [anon_sym___attribute__] = ACTIONS(2498),
    [anon_sym_COLON_COLON] = ACTIONS(2500),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2500),
    [anon_sym___declspec] = ACTIONS(2498),
    [anon_sym___based] = ACTIONS(2498),
    [anon_sym_RBRACE] = ACTIONS(2500),
    [anon_sym_signed] = ACTIONS(2498),
    [anon_sym_unsigned] = ACTIONS(2498),
    [anon_sym_long] = ACTIONS(2498),
    [anon_sym_short] = ACTIONS(2498),
    [anon_sym_LBRACK] = ACTIONS(2498),
    [anon_sym_static] = ACTIONS(2498),
    [anon_sym_register] = ACTIONS(2498),
    [anon_sym_inline] = ACTIONS(2498),
    [anon_sym___inline] = ACTIONS(2498),
    [anon_sym___inline__] = ACTIONS(2498),
    [anon_sym___forceinline] = ACTIONS(2498),
    [anon_sym_thread_local] = ACTIONS(2498),
    [anon_sym___thread] = ACTIONS(2498),
    [anon_sym_const] = ACTIONS(2498),
    [anon_sym_constexpr] = ACTIONS(2498),
    [anon_sym_volatile] = ACTIONS(2498),
    [anon_sym_restrict] = ACTIONS(2498),
    [anon_sym___restrict__] = ACTIONS(2498),
    [anon_sym__Atomic] = ACTIONS(2498),
    [anon_sym__Noreturn] = ACTIONS(2498),
    [anon_sym_noreturn] = ACTIONS(2498),
    [anon_sym_mutable] = ACTIONS(2498),
    [anon_sym_constinit] = ACTIONS(2498),
    [anon_sym_consteval] = ACTIONS(2498),
    [anon_sym_alignas] = ACTIONS(2498),
    [anon_sym__Alignas] = ACTIONS(2498),
    [sym_primitive_type] = ACTIONS(2498),
    [anon_sym_enum] = ACTIONS(2498),
    [anon_sym_class] = ACTIONS(2498),
    [anon_sym_struct] = ACTIONS(2498),
    [anon_sym_union] = ACTIONS(2498),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2498),
    [anon_sym_decltype] = ACTIONS(2498),
    [sym_virtual] = ACTIONS(2498),
    [anon_sym_explicit] = ACTIONS(2498),
    [anon_sym_typename] = ACTIONS(2498),
    [anon_sym_template] = ACTIONS(2498),
    [anon_sym_operator] = ACTIONS(2498),
    [anon_sym_friend] = ACTIONS(2498),
    [anon_sym_public] = ACTIONS(2498),
    [anon_sym_private] = ACTIONS(2498),
    [anon_sym_protected] = ACTIONS(2498),
    [anon_sym_using] = ACTIONS(2498),
    [anon_sym_static_assert] = ACTIONS(2498),
    [anon_sym_precise] = ACTIONS(2498),
    [anon_sym_shared] = ACTIONS(2498),
    [anon_sym_groupshared] = ACTIONS(2498),
    [anon_sym_uniform] = ACTIONS(2498),
    [anon_sym_row_major] = ACTIONS(2498),
    [anon_sym_column_major] = ACTIONS(2498),
    [anon_sym_globallycoherent] = ACTIONS(2498),
    [anon_sym_centroid] = ACTIONS(2498),
    [anon_sym_noperspective] = ACTIONS(2498),
    [anon_sym_nointerpolation] = ACTIONS(2498),
    [anon_sym_sample] = ACTIONS(2498),
    [anon_sym_linear] = ACTIONS(2498),
    [anon_sym_snorm] = ACTIONS(2498),
    [anon_sym_unorm] = ACTIONS(2498),
    [anon_sym_point] = ACTIONS(2498),
    [anon_sym_line] = ACTIONS(2498),
    [anon_sym_triangleadj] = ACTIONS(2498),
    [anon_sym_lineadj] = ACTIONS(2498),
    [anon_sym_triangle] = ACTIONS(2498),
  },
  [2080] = {
    [sym_identifier] = ACTIONS(2328),
    [aux_sym_preproc_def_token1] = ACTIONS(2328),
    [aux_sym_preproc_if_token1] = ACTIONS(2328),
    [aux_sym_preproc_if_token2] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2328),
    [sym_preproc_directive] = ACTIONS(2328),
    [anon_sym_LPAREN2] = ACTIONS(2330),
    [anon_sym_TILDE] = ACTIONS(2330),
    [anon_sym_STAR] = ACTIONS(2330),
    [anon_sym_AMP_AMP] = ACTIONS(2330),
    [anon_sym_AMP] = ACTIONS(2328),
    [anon_sym___extension__] = ACTIONS(2328),
    [anon_sym_typedef] = ACTIONS(2328),
    [anon_sym_in] = ACTIONS(2328),
    [anon_sym_out] = ACTIONS(2328),
    [anon_sym_inout] = ACTIONS(2328),
    [anon_sym_extern] = ACTIONS(2328),
    [anon_sym___attribute__] = ACTIONS(2328),
    [anon_sym_COLON_COLON] = ACTIONS(2330),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2330),
    [anon_sym___declspec] = ACTIONS(2328),
    [anon_sym___based] = ACTIONS(2328),
    [anon_sym_signed] = ACTIONS(2328),
    [anon_sym_unsigned] = ACTIONS(2328),
    [anon_sym_long] = ACTIONS(2328),
    [anon_sym_short] = ACTIONS(2328),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_static] = ACTIONS(2328),
    [anon_sym_register] = ACTIONS(2328),
    [anon_sym_inline] = ACTIONS(2328),
    [anon_sym___inline] = ACTIONS(2328),
    [anon_sym___inline__] = ACTIONS(2328),
    [anon_sym___forceinline] = ACTIONS(2328),
    [anon_sym_thread_local] = ACTIONS(2328),
    [anon_sym___thread] = ACTIONS(2328),
    [anon_sym_const] = ACTIONS(2328),
    [anon_sym_constexpr] = ACTIONS(2328),
    [anon_sym_volatile] = ACTIONS(2328),
    [anon_sym_restrict] = ACTIONS(2328),
    [anon_sym___restrict__] = ACTIONS(2328),
    [anon_sym__Atomic] = ACTIONS(2328),
    [anon_sym__Noreturn] = ACTIONS(2328),
    [anon_sym_noreturn] = ACTIONS(2328),
    [anon_sym_mutable] = ACTIONS(2328),
    [anon_sym_constinit] = ACTIONS(2328),
    [anon_sym_consteval] = ACTIONS(2328),
    [anon_sym_alignas] = ACTIONS(2328),
    [anon_sym__Alignas] = ACTIONS(2328),
    [sym_primitive_type] = ACTIONS(2328),
    [anon_sym_enum] = ACTIONS(2328),
    [anon_sym_class] = ACTIONS(2328),
    [anon_sym_struct] = ACTIONS(2328),
    [anon_sym_union] = ACTIONS(2328),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2328),
    [anon_sym_decltype] = ACTIONS(2328),
    [sym_virtual] = ACTIONS(2328),
    [anon_sym_explicit] = ACTIONS(2328),
    [anon_sym_typename] = ACTIONS(2328),
    [anon_sym_template] = ACTIONS(2328),
    [anon_sym_operator] = ACTIONS(2328),
    [anon_sym_friend] = ACTIONS(2328),
    [anon_sym_public] = ACTIONS(2328),
    [anon_sym_private] = ACTIONS(2328),
    [anon_sym_protected] = ACTIONS(2328),
    [anon_sym_using] = ACTIONS(2328),
    [anon_sym_static_assert] = ACTIONS(2328),
    [anon_sym_precise] = ACTIONS(2328),
    [anon_sym_shared] = ACTIONS(2328),
    [anon_sym_groupshared] = ACTIONS(2328),
    [anon_sym_uniform] = ACTIONS(2328),
    [anon_sym_row_major] = ACTIONS(2328),
    [anon_sym_column_major] = ACTIONS(2328),
    [anon_sym_globallycoherent] = ACTIONS(2328),
    [anon_sym_centroid] = ACTIONS(2328),
    [anon_sym_noperspective] = ACTIONS(2328),
    [anon_sym_nointerpolation] = ACTIONS(2328),
    [anon_sym_sample] = ACTIONS(2328),
    [anon_sym_linear] = ACTIONS(2328),
    [anon_sym_snorm] = ACTIONS(2328),
    [anon_sym_unorm] = ACTIONS(2328),
    [anon_sym_point] = ACTIONS(2328),
    [anon_sym_line] = ACTIONS(2328),
    [anon_sym_triangleadj] = ACTIONS(2328),
    [anon_sym_lineadj] = ACTIONS(2328),
    [anon_sym_triangle] = ACTIONS(2328),
  },
  [2081] = {
    [sym_identifier] = ACTIONS(2389),
    [aux_sym_preproc_def_token1] = ACTIONS(2389),
    [aux_sym_preproc_if_token1] = ACTIONS(2389),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2389),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2389),
    [sym_preproc_directive] = ACTIONS(2389),
    [anon_sym_LPAREN2] = ACTIONS(2391),
    [anon_sym_TILDE] = ACTIONS(2391),
    [anon_sym_STAR] = ACTIONS(2391),
    [anon_sym_AMP_AMP] = ACTIONS(2391),
    [anon_sym_AMP] = ACTIONS(2389),
    [anon_sym___extension__] = ACTIONS(2389),
    [anon_sym_typedef] = ACTIONS(2389),
    [anon_sym_in] = ACTIONS(2389),
    [anon_sym_out] = ACTIONS(2389),
    [anon_sym_inout] = ACTIONS(2389),
    [anon_sym_extern] = ACTIONS(2389),
    [anon_sym___attribute__] = ACTIONS(2389),
    [anon_sym_COLON_COLON] = ACTIONS(2391),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2391),
    [anon_sym___declspec] = ACTIONS(2389),
    [anon_sym___based] = ACTIONS(2389),
    [anon_sym_RBRACE] = ACTIONS(2391),
    [anon_sym_signed] = ACTIONS(2389),
    [anon_sym_unsigned] = ACTIONS(2389),
    [anon_sym_long] = ACTIONS(2389),
    [anon_sym_short] = ACTIONS(2389),
    [anon_sym_LBRACK] = ACTIONS(2389),
    [anon_sym_static] = ACTIONS(2389),
    [anon_sym_register] = ACTIONS(2389),
    [anon_sym_inline] = ACTIONS(2389),
    [anon_sym___inline] = ACTIONS(2389),
    [anon_sym___inline__] = ACTIONS(2389),
    [anon_sym___forceinline] = ACTIONS(2389),
    [anon_sym_thread_local] = ACTIONS(2389),
    [anon_sym___thread] = ACTIONS(2389),
    [anon_sym_const] = ACTIONS(2389),
    [anon_sym_constexpr] = ACTIONS(2389),
    [anon_sym_volatile] = ACTIONS(2389),
    [anon_sym_restrict] = ACTIONS(2389),
    [anon_sym___restrict__] = ACTIONS(2389),
    [anon_sym__Atomic] = ACTIONS(2389),
    [anon_sym__Noreturn] = ACTIONS(2389),
    [anon_sym_noreturn] = ACTIONS(2389),
    [anon_sym_mutable] = ACTIONS(2389),
    [anon_sym_constinit] = ACTIONS(2389),
    [anon_sym_consteval] = ACTIONS(2389),
    [anon_sym_alignas] = ACTIONS(2389),
    [anon_sym__Alignas] = ACTIONS(2389),
    [sym_primitive_type] = ACTIONS(2389),
    [anon_sym_enum] = ACTIONS(2389),
    [anon_sym_class] = ACTIONS(2389),
    [anon_sym_struct] = ACTIONS(2389),
    [anon_sym_union] = ACTIONS(2389),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2389),
    [anon_sym_decltype] = ACTIONS(2389),
    [sym_virtual] = ACTIONS(2389),
    [anon_sym_explicit] = ACTIONS(2389),
    [anon_sym_typename] = ACTIONS(2389),
    [anon_sym_template] = ACTIONS(2389),
    [anon_sym_operator] = ACTIONS(2389),
    [anon_sym_friend] = ACTIONS(2389),
    [anon_sym_public] = ACTIONS(2389),
    [anon_sym_private] = ACTIONS(2389),
    [anon_sym_protected] = ACTIONS(2389),
    [anon_sym_using] = ACTIONS(2389),
    [anon_sym_static_assert] = ACTIONS(2389),
    [anon_sym_precise] = ACTIONS(2389),
    [anon_sym_shared] = ACTIONS(2389),
    [anon_sym_groupshared] = ACTIONS(2389),
    [anon_sym_uniform] = ACTIONS(2389),
    [anon_sym_row_major] = ACTIONS(2389),
    [anon_sym_column_major] = ACTIONS(2389),
    [anon_sym_globallycoherent] = ACTIONS(2389),
    [anon_sym_centroid] = ACTIONS(2389),
    [anon_sym_noperspective] = ACTIONS(2389),
    [anon_sym_nointerpolation] = ACTIONS(2389),
    [anon_sym_sample] = ACTIONS(2389),
    [anon_sym_linear] = ACTIONS(2389),
    [anon_sym_snorm] = ACTIONS(2389),
    [anon_sym_unorm] = ACTIONS(2389),
    [anon_sym_point] = ACTIONS(2389),
    [anon_sym_line] = ACTIONS(2389),
    [anon_sym_triangleadj] = ACTIONS(2389),
    [anon_sym_lineadj] = ACTIONS(2389),
    [anon_sym_triangle] = ACTIONS(2389),
  },
  [2082] = {
    [sym_identifier] = ACTIONS(2360),
    [aux_sym_preproc_def_token1] = ACTIONS(2360),
    [aux_sym_preproc_if_token1] = ACTIONS(2360),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2360),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2360),
    [sym_preproc_directive] = ACTIONS(2360),
    [anon_sym_LPAREN2] = ACTIONS(2362),
    [anon_sym_TILDE] = ACTIONS(2362),
    [anon_sym_STAR] = ACTIONS(2362),
    [anon_sym_AMP_AMP] = ACTIONS(2362),
    [anon_sym_AMP] = ACTIONS(2360),
    [anon_sym___extension__] = ACTIONS(2360),
    [anon_sym_typedef] = ACTIONS(2360),
    [anon_sym_in] = ACTIONS(2360),
    [anon_sym_out] = ACTIONS(2360),
    [anon_sym_inout] = ACTIONS(2360),
    [anon_sym_extern] = ACTIONS(2360),
    [anon_sym___attribute__] = ACTIONS(2360),
    [anon_sym_COLON_COLON] = ACTIONS(2362),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2362),
    [anon_sym___declspec] = ACTIONS(2360),
    [anon_sym___based] = ACTIONS(2360),
    [anon_sym_RBRACE] = ACTIONS(2362),
    [anon_sym_signed] = ACTIONS(2360),
    [anon_sym_unsigned] = ACTIONS(2360),
    [anon_sym_long] = ACTIONS(2360),
    [anon_sym_short] = ACTIONS(2360),
    [anon_sym_LBRACK] = ACTIONS(2360),
    [anon_sym_static] = ACTIONS(2360),
    [anon_sym_register] = ACTIONS(2360),
    [anon_sym_inline] = ACTIONS(2360),
    [anon_sym___inline] = ACTIONS(2360),
    [anon_sym___inline__] = ACTIONS(2360),
    [anon_sym___forceinline] = ACTIONS(2360),
    [anon_sym_thread_local] = ACTIONS(2360),
    [anon_sym___thread] = ACTIONS(2360),
    [anon_sym_const] = ACTIONS(2360),
    [anon_sym_constexpr] = ACTIONS(2360),
    [anon_sym_volatile] = ACTIONS(2360),
    [anon_sym_restrict] = ACTIONS(2360),
    [anon_sym___restrict__] = ACTIONS(2360),
    [anon_sym__Atomic] = ACTIONS(2360),
    [anon_sym__Noreturn] = ACTIONS(2360),
    [anon_sym_noreturn] = ACTIONS(2360),
    [anon_sym_mutable] = ACTIONS(2360),
    [anon_sym_constinit] = ACTIONS(2360),
    [anon_sym_consteval] = ACTIONS(2360),
    [anon_sym_alignas] = ACTIONS(2360),
    [anon_sym__Alignas] = ACTIONS(2360),
    [sym_primitive_type] = ACTIONS(2360),
    [anon_sym_enum] = ACTIONS(2360),
    [anon_sym_class] = ACTIONS(2360),
    [anon_sym_struct] = ACTIONS(2360),
    [anon_sym_union] = ACTIONS(2360),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2360),
    [anon_sym_decltype] = ACTIONS(2360),
    [sym_virtual] = ACTIONS(2360),
    [anon_sym_explicit] = ACTIONS(2360),
    [anon_sym_typename] = ACTIONS(2360),
    [anon_sym_template] = ACTIONS(2360),
    [anon_sym_operator] = ACTIONS(2360),
    [anon_sym_friend] = ACTIONS(2360),
    [anon_sym_public] = ACTIONS(2360),
    [anon_sym_private] = ACTIONS(2360),
    [anon_sym_protected] = ACTIONS(2360),
    [anon_sym_using] = ACTIONS(2360),
    [anon_sym_static_assert] = ACTIONS(2360),
    [anon_sym_precise] = ACTIONS(2360),
    [anon_sym_shared] = ACTIONS(2360),
    [anon_sym_groupshared] = ACTIONS(2360),
    [anon_sym_uniform] = ACTIONS(2360),
    [anon_sym_row_major] = ACTIONS(2360),
    [anon_sym_column_major] = ACTIONS(2360),
    [anon_sym_globallycoherent] = ACTIONS(2360),
    [anon_sym_centroid] = ACTIONS(2360),
    [anon_sym_noperspective] = ACTIONS(2360),
    [anon_sym_nointerpolation] = ACTIONS(2360),
    [anon_sym_sample] = ACTIONS(2360),
    [anon_sym_linear] = ACTIONS(2360),
    [anon_sym_snorm] = ACTIONS(2360),
    [anon_sym_unorm] = ACTIONS(2360),
    [anon_sym_point] = ACTIONS(2360),
    [anon_sym_line] = ACTIONS(2360),
    [anon_sym_triangleadj] = ACTIONS(2360),
    [anon_sym_lineadj] = ACTIONS(2360),
    [anon_sym_triangle] = ACTIONS(2360),
  },
  [2083] = {
    [sym_identifier] = ACTIONS(2540),
    [aux_sym_preproc_def_token1] = ACTIONS(2540),
    [aux_sym_preproc_if_token1] = ACTIONS(2540),
    [aux_sym_preproc_if_token2] = ACTIONS(2540),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2540),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2540),
    [sym_preproc_directive] = ACTIONS(2540),
    [anon_sym_LPAREN2] = ACTIONS(2542),
    [anon_sym_TILDE] = ACTIONS(2542),
    [anon_sym_STAR] = ACTIONS(2542),
    [anon_sym_AMP_AMP] = ACTIONS(2542),
    [anon_sym_AMP] = ACTIONS(2540),
    [anon_sym___extension__] = ACTIONS(2540),
    [anon_sym_typedef] = ACTIONS(2540),
    [anon_sym_in] = ACTIONS(2540),
    [anon_sym_out] = ACTIONS(2540),
    [anon_sym_inout] = ACTIONS(2540),
    [anon_sym_extern] = ACTIONS(2540),
    [anon_sym___attribute__] = ACTIONS(2540),
    [anon_sym_COLON_COLON] = ACTIONS(2542),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2542),
    [anon_sym___declspec] = ACTIONS(2540),
    [anon_sym___based] = ACTIONS(2540),
    [anon_sym_signed] = ACTIONS(2540),
    [anon_sym_unsigned] = ACTIONS(2540),
    [anon_sym_long] = ACTIONS(2540),
    [anon_sym_short] = ACTIONS(2540),
    [anon_sym_LBRACK] = ACTIONS(2540),
    [anon_sym_static] = ACTIONS(2540),
    [anon_sym_register] = ACTIONS(2540),
    [anon_sym_inline] = ACTIONS(2540),
    [anon_sym___inline] = ACTIONS(2540),
    [anon_sym___inline__] = ACTIONS(2540),
    [anon_sym___forceinline] = ACTIONS(2540),
    [anon_sym_thread_local] = ACTIONS(2540),
    [anon_sym___thread] = ACTIONS(2540),
    [anon_sym_const] = ACTIONS(2540),
    [anon_sym_constexpr] = ACTIONS(2540),
    [anon_sym_volatile] = ACTIONS(2540),
    [anon_sym_restrict] = ACTIONS(2540),
    [anon_sym___restrict__] = ACTIONS(2540),
    [anon_sym__Atomic] = ACTIONS(2540),
    [anon_sym__Noreturn] = ACTIONS(2540),
    [anon_sym_noreturn] = ACTIONS(2540),
    [anon_sym_mutable] = ACTIONS(2540),
    [anon_sym_constinit] = ACTIONS(2540),
    [anon_sym_consteval] = ACTIONS(2540),
    [anon_sym_alignas] = ACTIONS(2540),
    [anon_sym__Alignas] = ACTIONS(2540),
    [sym_primitive_type] = ACTIONS(2540),
    [anon_sym_enum] = ACTIONS(2540),
    [anon_sym_class] = ACTIONS(2540),
    [anon_sym_struct] = ACTIONS(2540),
    [anon_sym_union] = ACTIONS(2540),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2540),
    [anon_sym_decltype] = ACTIONS(2540),
    [sym_virtual] = ACTIONS(2540),
    [anon_sym_explicit] = ACTIONS(2540),
    [anon_sym_typename] = ACTIONS(2540),
    [anon_sym_template] = ACTIONS(2540),
    [anon_sym_operator] = ACTIONS(2540),
    [anon_sym_friend] = ACTIONS(2540),
    [anon_sym_public] = ACTIONS(2540),
    [anon_sym_private] = ACTIONS(2540),
    [anon_sym_protected] = ACTIONS(2540),
    [anon_sym_using] = ACTIONS(2540),
    [anon_sym_static_assert] = ACTIONS(2540),
    [anon_sym_precise] = ACTIONS(2540),
    [anon_sym_shared] = ACTIONS(2540),
    [anon_sym_groupshared] = ACTIONS(2540),
    [anon_sym_uniform] = ACTIONS(2540),
    [anon_sym_row_major] = ACTIONS(2540),
    [anon_sym_column_major] = ACTIONS(2540),
    [anon_sym_globallycoherent] = ACTIONS(2540),
    [anon_sym_centroid] = ACTIONS(2540),
    [anon_sym_noperspective] = ACTIONS(2540),
    [anon_sym_nointerpolation] = ACTIONS(2540),
    [anon_sym_sample] = ACTIONS(2540),
    [anon_sym_linear] = ACTIONS(2540),
    [anon_sym_snorm] = ACTIONS(2540),
    [anon_sym_unorm] = ACTIONS(2540),
    [anon_sym_point] = ACTIONS(2540),
    [anon_sym_line] = ACTIONS(2540),
    [anon_sym_triangleadj] = ACTIONS(2540),
    [anon_sym_lineadj] = ACTIONS(2540),
    [anon_sym_triangle] = ACTIONS(2540),
  },
  [2084] = {
    [sym_identifier] = ACTIONS(2549),
    [aux_sym_preproc_def_token1] = ACTIONS(2549),
    [aux_sym_preproc_if_token1] = ACTIONS(2549),
    [aux_sym_preproc_if_token2] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2549),
    [sym_preproc_directive] = ACTIONS(2549),
    [anon_sym_LPAREN2] = ACTIONS(2551),
    [anon_sym_TILDE] = ACTIONS(2551),
    [anon_sym_STAR] = ACTIONS(2551),
    [anon_sym_AMP_AMP] = ACTIONS(2551),
    [anon_sym_AMP] = ACTIONS(2549),
    [anon_sym___extension__] = ACTIONS(2549),
    [anon_sym_typedef] = ACTIONS(2549),
    [anon_sym_in] = ACTIONS(2549),
    [anon_sym_out] = ACTIONS(2549),
    [anon_sym_inout] = ACTIONS(2549),
    [anon_sym_extern] = ACTIONS(2549),
    [anon_sym___attribute__] = ACTIONS(2549),
    [anon_sym_COLON_COLON] = ACTIONS(2551),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2551),
    [anon_sym___declspec] = ACTIONS(2549),
    [anon_sym___based] = ACTIONS(2549),
    [anon_sym_signed] = ACTIONS(2549),
    [anon_sym_unsigned] = ACTIONS(2549),
    [anon_sym_long] = ACTIONS(2549),
    [anon_sym_short] = ACTIONS(2549),
    [anon_sym_LBRACK] = ACTIONS(2549),
    [anon_sym_static] = ACTIONS(2549),
    [anon_sym_register] = ACTIONS(2549),
    [anon_sym_inline] = ACTIONS(2549),
    [anon_sym___inline] = ACTIONS(2549),
    [anon_sym___inline__] = ACTIONS(2549),
    [anon_sym___forceinline] = ACTIONS(2549),
    [anon_sym_thread_local] = ACTIONS(2549),
    [anon_sym___thread] = ACTIONS(2549),
    [anon_sym_const] = ACTIONS(2549),
    [anon_sym_constexpr] = ACTIONS(2549),
    [anon_sym_volatile] = ACTIONS(2549),
    [anon_sym_restrict] = ACTIONS(2549),
    [anon_sym___restrict__] = ACTIONS(2549),
    [anon_sym__Atomic] = ACTIONS(2549),
    [anon_sym__Noreturn] = ACTIONS(2549),
    [anon_sym_noreturn] = ACTIONS(2549),
    [anon_sym_mutable] = ACTIONS(2549),
    [anon_sym_constinit] = ACTIONS(2549),
    [anon_sym_consteval] = ACTIONS(2549),
    [anon_sym_alignas] = ACTIONS(2549),
    [anon_sym__Alignas] = ACTIONS(2549),
    [sym_primitive_type] = ACTIONS(2549),
    [anon_sym_enum] = ACTIONS(2549),
    [anon_sym_class] = ACTIONS(2549),
    [anon_sym_struct] = ACTIONS(2549),
    [anon_sym_union] = ACTIONS(2549),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2549),
    [anon_sym_decltype] = ACTIONS(2549),
    [sym_virtual] = ACTIONS(2549),
    [anon_sym_explicit] = ACTIONS(2549),
    [anon_sym_typename] = ACTIONS(2549),
    [anon_sym_template] = ACTIONS(2549),
    [anon_sym_operator] = ACTIONS(2549),
    [anon_sym_friend] = ACTIONS(2549),
    [anon_sym_public] = ACTIONS(2549),
    [anon_sym_private] = ACTIONS(2549),
    [anon_sym_protected] = ACTIONS(2549),
    [anon_sym_using] = ACTIONS(2549),
    [anon_sym_static_assert] = ACTIONS(2549),
    [anon_sym_precise] = ACTIONS(2549),
    [anon_sym_shared] = ACTIONS(2549),
    [anon_sym_groupshared] = ACTIONS(2549),
    [anon_sym_uniform] = ACTIONS(2549),
    [anon_sym_row_major] = ACTIONS(2549),
    [anon_sym_column_major] = ACTIONS(2549),
    [anon_sym_globallycoherent] = ACTIONS(2549),
    [anon_sym_centroid] = ACTIONS(2549),
    [anon_sym_noperspective] = ACTIONS(2549),
    [anon_sym_nointerpolation] = ACTIONS(2549),
    [anon_sym_sample] = ACTIONS(2549),
    [anon_sym_linear] = ACTIONS(2549),
    [anon_sym_snorm] = ACTIONS(2549),
    [anon_sym_unorm] = ACTIONS(2549),
    [anon_sym_point] = ACTIONS(2549),
    [anon_sym_line] = ACTIONS(2549),
    [anon_sym_triangleadj] = ACTIONS(2549),
    [anon_sym_lineadj] = ACTIONS(2549),
    [anon_sym_triangle] = ACTIONS(2549),
  },
  [2085] = {
    [sym_identifier] = ACTIONS(2393),
    [aux_sym_preproc_def_token1] = ACTIONS(2393),
    [aux_sym_preproc_if_token1] = ACTIONS(2393),
    [aux_sym_preproc_if_token2] = ACTIONS(2393),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2393),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2393),
    [sym_preproc_directive] = ACTIONS(2393),
    [anon_sym_LPAREN2] = ACTIONS(2395),
    [anon_sym_TILDE] = ACTIONS(2395),
    [anon_sym_STAR] = ACTIONS(2395),
    [anon_sym_AMP_AMP] = ACTIONS(2395),
    [anon_sym_AMP] = ACTIONS(2393),
    [anon_sym___extension__] = ACTIONS(2393),
    [anon_sym_typedef] = ACTIONS(2393),
    [anon_sym_in] = ACTIONS(2393),
    [anon_sym_out] = ACTIONS(2393),
    [anon_sym_inout] = ACTIONS(2393),
    [anon_sym_extern] = ACTIONS(2393),
    [anon_sym___attribute__] = ACTIONS(2393),
    [anon_sym_COLON_COLON] = ACTIONS(2395),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2395),
    [anon_sym___declspec] = ACTIONS(2393),
    [anon_sym___based] = ACTIONS(2393),
    [anon_sym_signed] = ACTIONS(2393),
    [anon_sym_unsigned] = ACTIONS(2393),
    [anon_sym_long] = ACTIONS(2393),
    [anon_sym_short] = ACTIONS(2393),
    [anon_sym_LBRACK] = ACTIONS(2393),
    [anon_sym_static] = ACTIONS(2393),
    [anon_sym_register] = ACTIONS(2393),
    [anon_sym_inline] = ACTIONS(2393),
    [anon_sym___inline] = ACTIONS(2393),
    [anon_sym___inline__] = ACTIONS(2393),
    [anon_sym___forceinline] = ACTIONS(2393),
    [anon_sym_thread_local] = ACTIONS(2393),
    [anon_sym___thread] = ACTIONS(2393),
    [anon_sym_const] = ACTIONS(2393),
    [anon_sym_constexpr] = ACTIONS(2393),
    [anon_sym_volatile] = ACTIONS(2393),
    [anon_sym_restrict] = ACTIONS(2393),
    [anon_sym___restrict__] = ACTIONS(2393),
    [anon_sym__Atomic] = ACTIONS(2393),
    [anon_sym__Noreturn] = ACTIONS(2393),
    [anon_sym_noreturn] = ACTIONS(2393),
    [anon_sym_mutable] = ACTIONS(2393),
    [anon_sym_constinit] = ACTIONS(2393),
    [anon_sym_consteval] = ACTIONS(2393),
    [anon_sym_alignas] = ACTIONS(2393),
    [anon_sym__Alignas] = ACTIONS(2393),
    [sym_primitive_type] = ACTIONS(2393),
    [anon_sym_enum] = ACTIONS(2393),
    [anon_sym_class] = ACTIONS(2393),
    [anon_sym_struct] = ACTIONS(2393),
    [anon_sym_union] = ACTIONS(2393),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2393),
    [anon_sym_decltype] = ACTIONS(2393),
    [sym_virtual] = ACTIONS(2393),
    [anon_sym_explicit] = ACTIONS(2393),
    [anon_sym_typename] = ACTIONS(2393),
    [anon_sym_template] = ACTIONS(2393),
    [anon_sym_operator] = ACTIONS(2393),
    [anon_sym_friend] = ACTIONS(2393),
    [anon_sym_public] = ACTIONS(2393),
    [anon_sym_private] = ACTIONS(2393),
    [anon_sym_protected] = ACTIONS(2393),
    [anon_sym_using] = ACTIONS(2393),
    [anon_sym_static_assert] = ACTIONS(2393),
    [anon_sym_precise] = ACTIONS(2393),
    [anon_sym_shared] = ACTIONS(2393),
    [anon_sym_groupshared] = ACTIONS(2393),
    [anon_sym_uniform] = ACTIONS(2393),
    [anon_sym_row_major] = ACTIONS(2393),
    [anon_sym_column_major] = ACTIONS(2393),
    [anon_sym_globallycoherent] = ACTIONS(2393),
    [anon_sym_centroid] = ACTIONS(2393),
    [anon_sym_noperspective] = ACTIONS(2393),
    [anon_sym_nointerpolation] = ACTIONS(2393),
    [anon_sym_sample] = ACTIONS(2393),
    [anon_sym_linear] = ACTIONS(2393),
    [anon_sym_snorm] = ACTIONS(2393),
    [anon_sym_unorm] = ACTIONS(2393),
    [anon_sym_point] = ACTIONS(2393),
    [anon_sym_line] = ACTIONS(2393),
    [anon_sym_triangleadj] = ACTIONS(2393),
    [anon_sym_lineadj] = ACTIONS(2393),
    [anon_sym_triangle] = ACTIONS(2393),
  },
  [2086] = {
    [sym_identifier] = ACTIONS(2532),
    [aux_sym_preproc_def_token1] = ACTIONS(2532),
    [aux_sym_preproc_if_token1] = ACTIONS(2532),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2532),
    [sym_preproc_directive] = ACTIONS(2532),
    [anon_sym_LPAREN2] = ACTIONS(2534),
    [anon_sym_TILDE] = ACTIONS(2534),
    [anon_sym_STAR] = ACTIONS(2534),
    [anon_sym_AMP_AMP] = ACTIONS(2534),
    [anon_sym_AMP] = ACTIONS(2532),
    [anon_sym___extension__] = ACTIONS(2532),
    [anon_sym_typedef] = ACTIONS(2532),
    [anon_sym_in] = ACTIONS(2532),
    [anon_sym_out] = ACTIONS(2532),
    [anon_sym_inout] = ACTIONS(2532),
    [anon_sym_extern] = ACTIONS(2532),
    [anon_sym___attribute__] = ACTIONS(2532),
    [anon_sym_COLON_COLON] = ACTIONS(2534),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2534),
    [anon_sym___declspec] = ACTIONS(2532),
    [anon_sym___based] = ACTIONS(2532),
    [anon_sym_RBRACE] = ACTIONS(2534),
    [anon_sym_signed] = ACTIONS(2532),
    [anon_sym_unsigned] = ACTIONS(2532),
    [anon_sym_long] = ACTIONS(2532),
    [anon_sym_short] = ACTIONS(2532),
    [anon_sym_LBRACK] = ACTIONS(2532),
    [anon_sym_static] = ACTIONS(2532),
    [anon_sym_register] = ACTIONS(2532),
    [anon_sym_inline] = ACTIONS(2532),
    [anon_sym___inline] = ACTIONS(2532),
    [anon_sym___inline__] = ACTIONS(2532),
    [anon_sym___forceinline] = ACTIONS(2532),
    [anon_sym_thread_local] = ACTIONS(2532),
    [anon_sym___thread] = ACTIONS(2532),
    [anon_sym_const] = ACTIONS(2532),
    [anon_sym_constexpr] = ACTIONS(2532),
    [anon_sym_volatile] = ACTIONS(2532),
    [anon_sym_restrict] = ACTIONS(2532),
    [anon_sym___restrict__] = ACTIONS(2532),
    [anon_sym__Atomic] = ACTIONS(2532),
    [anon_sym__Noreturn] = ACTIONS(2532),
    [anon_sym_noreturn] = ACTIONS(2532),
    [anon_sym_mutable] = ACTIONS(2532),
    [anon_sym_constinit] = ACTIONS(2532),
    [anon_sym_consteval] = ACTIONS(2532),
    [anon_sym_alignas] = ACTIONS(2532),
    [anon_sym__Alignas] = ACTIONS(2532),
    [sym_primitive_type] = ACTIONS(2532),
    [anon_sym_enum] = ACTIONS(2532),
    [anon_sym_class] = ACTIONS(2532),
    [anon_sym_struct] = ACTIONS(2532),
    [anon_sym_union] = ACTIONS(2532),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2532),
    [anon_sym_decltype] = ACTIONS(2532),
    [sym_virtual] = ACTIONS(2532),
    [anon_sym_explicit] = ACTIONS(2532),
    [anon_sym_typename] = ACTIONS(2532),
    [anon_sym_template] = ACTIONS(2532),
    [anon_sym_operator] = ACTIONS(2532),
    [anon_sym_friend] = ACTIONS(2532),
    [anon_sym_public] = ACTIONS(2532),
    [anon_sym_private] = ACTIONS(2532),
    [anon_sym_protected] = ACTIONS(2532),
    [anon_sym_using] = ACTIONS(2532),
    [anon_sym_static_assert] = ACTIONS(2532),
    [anon_sym_precise] = ACTIONS(2532),
    [anon_sym_shared] = ACTIONS(2532),
    [anon_sym_groupshared] = ACTIONS(2532),
    [anon_sym_uniform] = ACTIONS(2532),
    [anon_sym_row_major] = ACTIONS(2532),
    [anon_sym_column_major] = ACTIONS(2532),
    [anon_sym_globallycoherent] = ACTIONS(2532),
    [anon_sym_centroid] = ACTIONS(2532),
    [anon_sym_noperspective] = ACTIONS(2532),
    [anon_sym_nointerpolation] = ACTIONS(2532),
    [anon_sym_sample] = ACTIONS(2532),
    [anon_sym_linear] = ACTIONS(2532),
    [anon_sym_snorm] = ACTIONS(2532),
    [anon_sym_unorm] = ACTIONS(2532),
    [anon_sym_point] = ACTIONS(2532),
    [anon_sym_line] = ACTIONS(2532),
    [anon_sym_triangleadj] = ACTIONS(2532),
    [anon_sym_lineadj] = ACTIONS(2532),
    [anon_sym_triangle] = ACTIONS(2532),
  },
  [2087] = {
    [sym_identifier] = ACTIONS(5037),
    [aux_sym_preproc_def_token1] = ACTIONS(5037),
    [aux_sym_preproc_if_token1] = ACTIONS(5037),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5037),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5037),
    [sym_preproc_directive] = ACTIONS(5037),
    [anon_sym_LPAREN2] = ACTIONS(5039),
    [anon_sym_TILDE] = ACTIONS(5039),
    [anon_sym_STAR] = ACTIONS(5039),
    [anon_sym_AMP_AMP] = ACTIONS(5039),
    [anon_sym_AMP] = ACTIONS(5037),
    [anon_sym___extension__] = ACTIONS(5037),
    [anon_sym_typedef] = ACTIONS(5037),
    [anon_sym_in] = ACTIONS(5037),
    [anon_sym_out] = ACTIONS(5037),
    [anon_sym_inout] = ACTIONS(5037),
    [anon_sym_extern] = ACTIONS(5037),
    [anon_sym___attribute__] = ACTIONS(5037),
    [anon_sym_COLON_COLON] = ACTIONS(5039),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5039),
    [anon_sym___declspec] = ACTIONS(5037),
    [anon_sym___based] = ACTIONS(5037),
    [anon_sym_RBRACE] = ACTIONS(5039),
    [anon_sym_signed] = ACTIONS(5037),
    [anon_sym_unsigned] = ACTIONS(5037),
    [anon_sym_long] = ACTIONS(5037),
    [anon_sym_short] = ACTIONS(5037),
    [anon_sym_LBRACK] = ACTIONS(5037),
    [anon_sym_static] = ACTIONS(5037),
    [anon_sym_register] = ACTIONS(5037),
    [anon_sym_inline] = ACTIONS(5037),
    [anon_sym___inline] = ACTIONS(5037),
    [anon_sym___inline__] = ACTIONS(5037),
    [anon_sym___forceinline] = ACTIONS(5037),
    [anon_sym_thread_local] = ACTIONS(5037),
    [anon_sym___thread] = ACTIONS(5037),
    [anon_sym_const] = ACTIONS(5037),
    [anon_sym_constexpr] = ACTIONS(5037),
    [anon_sym_volatile] = ACTIONS(5037),
    [anon_sym_restrict] = ACTIONS(5037),
    [anon_sym___restrict__] = ACTIONS(5037),
    [anon_sym__Atomic] = ACTIONS(5037),
    [anon_sym__Noreturn] = ACTIONS(5037),
    [anon_sym_noreturn] = ACTIONS(5037),
    [anon_sym_mutable] = ACTIONS(5037),
    [anon_sym_constinit] = ACTIONS(5037),
    [anon_sym_consteval] = ACTIONS(5037),
    [anon_sym_alignas] = ACTIONS(5037),
    [anon_sym__Alignas] = ACTIONS(5037),
    [sym_primitive_type] = ACTIONS(5037),
    [anon_sym_enum] = ACTIONS(5037),
    [anon_sym_class] = ACTIONS(5037),
    [anon_sym_struct] = ACTIONS(5037),
    [anon_sym_union] = ACTIONS(5037),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5037),
    [anon_sym_decltype] = ACTIONS(5037),
    [sym_virtual] = ACTIONS(5037),
    [anon_sym_explicit] = ACTIONS(5037),
    [anon_sym_typename] = ACTIONS(5037),
    [anon_sym_template] = ACTIONS(5037),
    [anon_sym_operator] = ACTIONS(5037),
    [anon_sym_friend] = ACTIONS(5037),
    [anon_sym_public] = ACTIONS(5037),
    [anon_sym_private] = ACTIONS(5037),
    [anon_sym_protected] = ACTIONS(5037),
    [anon_sym_using] = ACTIONS(5037),
    [anon_sym_static_assert] = ACTIONS(5037),
    [anon_sym_precise] = ACTIONS(5037),
    [anon_sym_shared] = ACTIONS(5037),
    [anon_sym_groupshared] = ACTIONS(5037),
    [anon_sym_uniform] = ACTIONS(5037),
    [anon_sym_row_major] = ACTIONS(5037),
    [anon_sym_column_major] = ACTIONS(5037),
    [anon_sym_globallycoherent] = ACTIONS(5037),
    [anon_sym_centroid] = ACTIONS(5037),
    [anon_sym_noperspective] = ACTIONS(5037),
    [anon_sym_nointerpolation] = ACTIONS(5037),
    [anon_sym_sample] = ACTIONS(5037),
    [anon_sym_linear] = ACTIONS(5037),
    [anon_sym_snorm] = ACTIONS(5037),
    [anon_sym_unorm] = ACTIONS(5037),
    [anon_sym_point] = ACTIONS(5037),
    [anon_sym_line] = ACTIONS(5037),
    [anon_sym_triangleadj] = ACTIONS(5037),
    [anon_sym_lineadj] = ACTIONS(5037),
    [anon_sym_triangle] = ACTIONS(5037),
  },
  [2088] = {
    [sym_identifier] = ACTIONS(2458),
    [aux_sym_preproc_def_token1] = ACTIONS(2458),
    [aux_sym_preproc_if_token1] = ACTIONS(2458),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2458),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2458),
    [sym_preproc_directive] = ACTIONS(2458),
    [anon_sym_LPAREN2] = ACTIONS(2460),
    [anon_sym_TILDE] = ACTIONS(2460),
    [anon_sym_STAR] = ACTIONS(2460),
    [anon_sym_AMP_AMP] = ACTIONS(2460),
    [anon_sym_AMP] = ACTIONS(2458),
    [anon_sym___extension__] = ACTIONS(2458),
    [anon_sym_typedef] = ACTIONS(2458),
    [anon_sym_in] = ACTIONS(2458),
    [anon_sym_out] = ACTIONS(2458),
    [anon_sym_inout] = ACTIONS(2458),
    [anon_sym_extern] = ACTIONS(2458),
    [anon_sym___attribute__] = ACTIONS(2458),
    [anon_sym_COLON_COLON] = ACTIONS(2460),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2460),
    [anon_sym___declspec] = ACTIONS(2458),
    [anon_sym___based] = ACTIONS(2458),
    [anon_sym_RBRACE] = ACTIONS(2460),
    [anon_sym_signed] = ACTIONS(2458),
    [anon_sym_unsigned] = ACTIONS(2458),
    [anon_sym_long] = ACTIONS(2458),
    [anon_sym_short] = ACTIONS(2458),
    [anon_sym_LBRACK] = ACTIONS(2458),
    [anon_sym_static] = ACTIONS(2458),
    [anon_sym_register] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(2458),
    [anon_sym___inline] = ACTIONS(2458),
    [anon_sym___inline__] = ACTIONS(2458),
    [anon_sym___forceinline] = ACTIONS(2458),
    [anon_sym_thread_local] = ACTIONS(2458),
    [anon_sym___thread] = ACTIONS(2458),
    [anon_sym_const] = ACTIONS(2458),
    [anon_sym_constexpr] = ACTIONS(2458),
    [anon_sym_volatile] = ACTIONS(2458),
    [anon_sym_restrict] = ACTIONS(2458),
    [anon_sym___restrict__] = ACTIONS(2458),
    [anon_sym__Atomic] = ACTIONS(2458),
    [anon_sym__Noreturn] = ACTIONS(2458),
    [anon_sym_noreturn] = ACTIONS(2458),
    [anon_sym_mutable] = ACTIONS(2458),
    [anon_sym_constinit] = ACTIONS(2458),
    [anon_sym_consteval] = ACTIONS(2458),
    [anon_sym_alignas] = ACTIONS(2458),
    [anon_sym__Alignas] = ACTIONS(2458),
    [sym_primitive_type] = ACTIONS(2458),
    [anon_sym_enum] = ACTIONS(2458),
    [anon_sym_class] = ACTIONS(2458),
    [anon_sym_struct] = ACTIONS(2458),
    [anon_sym_union] = ACTIONS(2458),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2458),
    [anon_sym_decltype] = ACTIONS(2458),
    [sym_virtual] = ACTIONS(2458),
    [anon_sym_explicit] = ACTIONS(2458),
    [anon_sym_typename] = ACTIONS(2458),
    [anon_sym_template] = ACTIONS(2458),
    [anon_sym_operator] = ACTIONS(2458),
    [anon_sym_friend] = ACTIONS(2458),
    [anon_sym_public] = ACTIONS(2458),
    [anon_sym_private] = ACTIONS(2458),
    [anon_sym_protected] = ACTIONS(2458),
    [anon_sym_using] = ACTIONS(2458),
    [anon_sym_static_assert] = ACTIONS(2458),
    [anon_sym_precise] = ACTIONS(2458),
    [anon_sym_shared] = ACTIONS(2458),
    [anon_sym_groupshared] = ACTIONS(2458),
    [anon_sym_uniform] = ACTIONS(2458),
    [anon_sym_row_major] = ACTIONS(2458),
    [anon_sym_column_major] = ACTIONS(2458),
    [anon_sym_globallycoherent] = ACTIONS(2458),
    [anon_sym_centroid] = ACTIONS(2458),
    [anon_sym_noperspective] = ACTIONS(2458),
    [anon_sym_nointerpolation] = ACTIONS(2458),
    [anon_sym_sample] = ACTIONS(2458),
    [anon_sym_linear] = ACTIONS(2458),
    [anon_sym_snorm] = ACTIONS(2458),
    [anon_sym_unorm] = ACTIONS(2458),
    [anon_sym_point] = ACTIONS(2458),
    [anon_sym_line] = ACTIONS(2458),
    [anon_sym_triangleadj] = ACTIONS(2458),
    [anon_sym_lineadj] = ACTIONS(2458),
    [anon_sym_triangle] = ACTIONS(2458),
  },
  [2089] = {
    [sym_identifier] = ACTIONS(5081),
    [aux_sym_preproc_def_token1] = ACTIONS(5081),
    [aux_sym_preproc_if_token1] = ACTIONS(5081),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5081),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5081),
    [sym_preproc_directive] = ACTIONS(5081),
    [anon_sym_LPAREN2] = ACTIONS(5083),
    [anon_sym_TILDE] = ACTIONS(5083),
    [anon_sym_STAR] = ACTIONS(5083),
    [anon_sym_AMP_AMP] = ACTIONS(5083),
    [anon_sym_AMP] = ACTIONS(5081),
    [anon_sym___extension__] = ACTIONS(5081),
    [anon_sym_typedef] = ACTIONS(5081),
    [anon_sym_in] = ACTIONS(5081),
    [anon_sym_out] = ACTIONS(5081),
    [anon_sym_inout] = ACTIONS(5081),
    [anon_sym_extern] = ACTIONS(5081),
    [anon_sym___attribute__] = ACTIONS(5081),
    [anon_sym_COLON_COLON] = ACTIONS(5083),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5083),
    [anon_sym___declspec] = ACTIONS(5081),
    [anon_sym___based] = ACTIONS(5081),
    [anon_sym_RBRACE] = ACTIONS(5083),
    [anon_sym_signed] = ACTIONS(5081),
    [anon_sym_unsigned] = ACTIONS(5081),
    [anon_sym_long] = ACTIONS(5081),
    [anon_sym_short] = ACTIONS(5081),
    [anon_sym_LBRACK] = ACTIONS(5081),
    [anon_sym_static] = ACTIONS(5081),
    [anon_sym_register] = ACTIONS(5081),
    [anon_sym_inline] = ACTIONS(5081),
    [anon_sym___inline] = ACTIONS(5081),
    [anon_sym___inline__] = ACTIONS(5081),
    [anon_sym___forceinline] = ACTIONS(5081),
    [anon_sym_thread_local] = ACTIONS(5081),
    [anon_sym___thread] = ACTIONS(5081),
    [anon_sym_const] = ACTIONS(5081),
    [anon_sym_constexpr] = ACTIONS(5081),
    [anon_sym_volatile] = ACTIONS(5081),
    [anon_sym_restrict] = ACTIONS(5081),
    [anon_sym___restrict__] = ACTIONS(5081),
    [anon_sym__Atomic] = ACTIONS(5081),
    [anon_sym__Noreturn] = ACTIONS(5081),
    [anon_sym_noreturn] = ACTIONS(5081),
    [anon_sym_mutable] = ACTIONS(5081),
    [anon_sym_constinit] = ACTIONS(5081),
    [anon_sym_consteval] = ACTIONS(5081),
    [anon_sym_alignas] = ACTIONS(5081),
    [anon_sym__Alignas] = ACTIONS(5081),
    [sym_primitive_type] = ACTIONS(5081),
    [anon_sym_enum] = ACTIONS(5081),
    [anon_sym_class] = ACTIONS(5081),
    [anon_sym_struct] = ACTIONS(5081),
    [anon_sym_union] = ACTIONS(5081),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5081),
    [anon_sym_decltype] = ACTIONS(5081),
    [sym_virtual] = ACTIONS(5081),
    [anon_sym_explicit] = ACTIONS(5081),
    [anon_sym_typename] = ACTIONS(5081),
    [anon_sym_template] = ACTIONS(5081),
    [anon_sym_operator] = ACTIONS(5081),
    [anon_sym_friend] = ACTIONS(5081),
    [anon_sym_public] = ACTIONS(5081),
    [anon_sym_private] = ACTIONS(5081),
    [anon_sym_protected] = ACTIONS(5081),
    [anon_sym_using] = ACTIONS(5081),
    [anon_sym_static_assert] = ACTIONS(5081),
    [anon_sym_precise] = ACTIONS(5081),
    [anon_sym_shared] = ACTIONS(5081),
    [anon_sym_groupshared] = ACTIONS(5081),
    [anon_sym_uniform] = ACTIONS(5081),
    [anon_sym_row_major] = ACTIONS(5081),
    [anon_sym_column_major] = ACTIONS(5081),
    [anon_sym_globallycoherent] = ACTIONS(5081),
    [anon_sym_centroid] = ACTIONS(5081),
    [anon_sym_noperspective] = ACTIONS(5081),
    [anon_sym_nointerpolation] = ACTIONS(5081),
    [anon_sym_sample] = ACTIONS(5081),
    [anon_sym_linear] = ACTIONS(5081),
    [anon_sym_snorm] = ACTIONS(5081),
    [anon_sym_unorm] = ACTIONS(5081),
    [anon_sym_point] = ACTIONS(5081),
    [anon_sym_line] = ACTIONS(5081),
    [anon_sym_triangleadj] = ACTIONS(5081),
    [anon_sym_lineadj] = ACTIONS(5081),
    [anon_sym_triangle] = ACTIONS(5081),
  },
  [2090] = {
    [sym_identifier] = ACTIONS(2536),
    [aux_sym_preproc_def_token1] = ACTIONS(2536),
    [aux_sym_preproc_if_token1] = ACTIONS(2536),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2536),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2536),
    [sym_preproc_directive] = ACTIONS(2536),
    [anon_sym_LPAREN2] = ACTIONS(2538),
    [anon_sym_TILDE] = ACTIONS(2538),
    [anon_sym_STAR] = ACTIONS(2538),
    [anon_sym_AMP_AMP] = ACTIONS(2538),
    [anon_sym_AMP] = ACTIONS(2536),
    [anon_sym___extension__] = ACTIONS(2536),
    [anon_sym_typedef] = ACTIONS(2536),
    [anon_sym_in] = ACTIONS(2536),
    [anon_sym_out] = ACTIONS(2536),
    [anon_sym_inout] = ACTIONS(2536),
    [anon_sym_extern] = ACTIONS(2536),
    [anon_sym___attribute__] = ACTIONS(2536),
    [anon_sym_COLON_COLON] = ACTIONS(2538),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2538),
    [anon_sym___declspec] = ACTIONS(2536),
    [anon_sym___based] = ACTIONS(2536),
    [anon_sym_RBRACE] = ACTIONS(2538),
    [anon_sym_signed] = ACTIONS(2536),
    [anon_sym_unsigned] = ACTIONS(2536),
    [anon_sym_long] = ACTIONS(2536),
    [anon_sym_short] = ACTIONS(2536),
    [anon_sym_LBRACK] = ACTIONS(2536),
    [anon_sym_static] = ACTIONS(2536),
    [anon_sym_register] = ACTIONS(2536),
    [anon_sym_inline] = ACTIONS(2536),
    [anon_sym___inline] = ACTIONS(2536),
    [anon_sym___inline__] = ACTIONS(2536),
    [anon_sym___forceinline] = ACTIONS(2536),
    [anon_sym_thread_local] = ACTIONS(2536),
    [anon_sym___thread] = ACTIONS(2536),
    [anon_sym_const] = ACTIONS(2536),
    [anon_sym_constexpr] = ACTIONS(2536),
    [anon_sym_volatile] = ACTIONS(2536),
    [anon_sym_restrict] = ACTIONS(2536),
    [anon_sym___restrict__] = ACTIONS(2536),
    [anon_sym__Atomic] = ACTIONS(2536),
    [anon_sym__Noreturn] = ACTIONS(2536),
    [anon_sym_noreturn] = ACTIONS(2536),
    [anon_sym_mutable] = ACTIONS(2536),
    [anon_sym_constinit] = ACTIONS(2536),
    [anon_sym_consteval] = ACTIONS(2536),
    [anon_sym_alignas] = ACTIONS(2536),
    [anon_sym__Alignas] = ACTIONS(2536),
    [sym_primitive_type] = ACTIONS(2536),
    [anon_sym_enum] = ACTIONS(2536),
    [anon_sym_class] = ACTIONS(2536),
    [anon_sym_struct] = ACTIONS(2536),
    [anon_sym_union] = ACTIONS(2536),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2536),
    [anon_sym_decltype] = ACTIONS(2536),
    [sym_virtual] = ACTIONS(2536),
    [anon_sym_explicit] = ACTIONS(2536),
    [anon_sym_typename] = ACTIONS(2536),
    [anon_sym_template] = ACTIONS(2536),
    [anon_sym_operator] = ACTIONS(2536),
    [anon_sym_friend] = ACTIONS(2536),
    [anon_sym_public] = ACTIONS(2536),
    [anon_sym_private] = ACTIONS(2536),
    [anon_sym_protected] = ACTIONS(2536),
    [anon_sym_using] = ACTIONS(2536),
    [anon_sym_static_assert] = ACTIONS(2536),
    [anon_sym_precise] = ACTIONS(2536),
    [anon_sym_shared] = ACTIONS(2536),
    [anon_sym_groupshared] = ACTIONS(2536),
    [anon_sym_uniform] = ACTIONS(2536),
    [anon_sym_row_major] = ACTIONS(2536),
    [anon_sym_column_major] = ACTIONS(2536),
    [anon_sym_globallycoherent] = ACTIONS(2536),
    [anon_sym_centroid] = ACTIONS(2536),
    [anon_sym_noperspective] = ACTIONS(2536),
    [anon_sym_nointerpolation] = ACTIONS(2536),
    [anon_sym_sample] = ACTIONS(2536),
    [anon_sym_linear] = ACTIONS(2536),
    [anon_sym_snorm] = ACTIONS(2536),
    [anon_sym_unorm] = ACTIONS(2536),
    [anon_sym_point] = ACTIONS(2536),
    [anon_sym_line] = ACTIONS(2536),
    [anon_sym_triangleadj] = ACTIONS(2536),
    [anon_sym_lineadj] = ACTIONS(2536),
    [anon_sym_triangle] = ACTIONS(2536),
  },
  [2091] = {
    [sym_identifier] = ACTIONS(2458),
    [aux_sym_preproc_def_token1] = ACTIONS(2458),
    [aux_sym_preproc_if_token1] = ACTIONS(2458),
    [aux_sym_preproc_if_token2] = ACTIONS(2458),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2458),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2458),
    [sym_preproc_directive] = ACTIONS(2458),
    [anon_sym_LPAREN2] = ACTIONS(2460),
    [anon_sym_TILDE] = ACTIONS(2460),
    [anon_sym_STAR] = ACTIONS(2460),
    [anon_sym_AMP_AMP] = ACTIONS(2460),
    [anon_sym_AMP] = ACTIONS(2458),
    [anon_sym___extension__] = ACTIONS(2458),
    [anon_sym_typedef] = ACTIONS(2458),
    [anon_sym_in] = ACTIONS(2458),
    [anon_sym_out] = ACTIONS(2458),
    [anon_sym_inout] = ACTIONS(2458),
    [anon_sym_extern] = ACTIONS(2458),
    [anon_sym___attribute__] = ACTIONS(2458),
    [anon_sym_COLON_COLON] = ACTIONS(2460),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2460),
    [anon_sym___declspec] = ACTIONS(2458),
    [anon_sym___based] = ACTIONS(2458),
    [anon_sym_signed] = ACTIONS(2458),
    [anon_sym_unsigned] = ACTIONS(2458),
    [anon_sym_long] = ACTIONS(2458),
    [anon_sym_short] = ACTIONS(2458),
    [anon_sym_LBRACK] = ACTIONS(2458),
    [anon_sym_static] = ACTIONS(2458),
    [anon_sym_register] = ACTIONS(2458),
    [anon_sym_inline] = ACTIONS(2458),
    [anon_sym___inline] = ACTIONS(2458),
    [anon_sym___inline__] = ACTIONS(2458),
    [anon_sym___forceinline] = ACTIONS(2458),
    [anon_sym_thread_local] = ACTIONS(2458),
    [anon_sym___thread] = ACTIONS(2458),
    [anon_sym_const] = ACTIONS(2458),
    [anon_sym_constexpr] = ACTIONS(2458),
    [anon_sym_volatile] = ACTIONS(2458),
    [anon_sym_restrict] = ACTIONS(2458),
    [anon_sym___restrict__] = ACTIONS(2458),
    [anon_sym__Atomic] = ACTIONS(2458),
    [anon_sym__Noreturn] = ACTIONS(2458),
    [anon_sym_noreturn] = ACTIONS(2458),
    [anon_sym_mutable] = ACTIONS(2458),
    [anon_sym_constinit] = ACTIONS(2458),
    [anon_sym_consteval] = ACTIONS(2458),
    [anon_sym_alignas] = ACTIONS(2458),
    [anon_sym__Alignas] = ACTIONS(2458),
    [sym_primitive_type] = ACTIONS(2458),
    [anon_sym_enum] = ACTIONS(2458),
    [anon_sym_class] = ACTIONS(2458),
    [anon_sym_struct] = ACTIONS(2458),
    [anon_sym_union] = ACTIONS(2458),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2458),
    [anon_sym_decltype] = ACTIONS(2458),
    [sym_virtual] = ACTIONS(2458),
    [anon_sym_explicit] = ACTIONS(2458),
    [anon_sym_typename] = ACTIONS(2458),
    [anon_sym_template] = ACTIONS(2458),
    [anon_sym_operator] = ACTIONS(2458),
    [anon_sym_friend] = ACTIONS(2458),
    [anon_sym_public] = ACTIONS(2458),
    [anon_sym_private] = ACTIONS(2458),
    [anon_sym_protected] = ACTIONS(2458),
    [anon_sym_using] = ACTIONS(2458),
    [anon_sym_static_assert] = ACTIONS(2458),
    [anon_sym_precise] = ACTIONS(2458),
    [anon_sym_shared] = ACTIONS(2458),
    [anon_sym_groupshared] = ACTIONS(2458),
    [anon_sym_uniform] = ACTIONS(2458),
    [anon_sym_row_major] = ACTIONS(2458),
    [anon_sym_column_major] = ACTIONS(2458),
    [anon_sym_globallycoherent] = ACTIONS(2458),
    [anon_sym_centroid] = ACTIONS(2458),
    [anon_sym_noperspective] = ACTIONS(2458),
    [anon_sym_nointerpolation] = ACTIONS(2458),
    [anon_sym_sample] = ACTIONS(2458),
    [anon_sym_linear] = ACTIONS(2458),
    [anon_sym_snorm] = ACTIONS(2458),
    [anon_sym_unorm] = ACTIONS(2458),
    [anon_sym_point] = ACTIONS(2458),
    [anon_sym_line] = ACTIONS(2458),
    [anon_sym_triangleadj] = ACTIONS(2458),
    [anon_sym_lineadj] = ACTIONS(2458),
    [anon_sym_triangle] = ACTIONS(2458),
  },
  [2092] = {
    [sym_identifier] = ACTIONS(2404),
    [aux_sym_preproc_def_token1] = ACTIONS(2404),
    [aux_sym_preproc_if_token1] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2404),
    [sym_preproc_directive] = ACTIONS(2404),
    [anon_sym_LPAREN2] = ACTIONS(2406),
    [anon_sym_TILDE] = ACTIONS(2406),
    [anon_sym_STAR] = ACTIONS(2406),
    [anon_sym_AMP_AMP] = ACTIONS(2406),
    [anon_sym_AMP] = ACTIONS(2404),
    [anon_sym___extension__] = ACTIONS(2404),
    [anon_sym_typedef] = ACTIONS(2404),
    [anon_sym_in] = ACTIONS(2404),
    [anon_sym_out] = ACTIONS(2404),
    [anon_sym_inout] = ACTIONS(2404),
    [anon_sym_extern] = ACTIONS(2404),
    [anon_sym___attribute__] = ACTIONS(2404),
    [anon_sym_COLON_COLON] = ACTIONS(2406),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2406),
    [anon_sym___declspec] = ACTIONS(2404),
    [anon_sym___based] = ACTIONS(2404),
    [anon_sym_RBRACE] = ACTIONS(2406),
    [anon_sym_signed] = ACTIONS(2404),
    [anon_sym_unsigned] = ACTIONS(2404),
    [anon_sym_long] = ACTIONS(2404),
    [anon_sym_short] = ACTIONS(2404),
    [anon_sym_LBRACK] = ACTIONS(2404),
    [anon_sym_static] = ACTIONS(2404),
    [anon_sym_register] = ACTIONS(2404),
    [anon_sym_inline] = ACTIONS(2404),
    [anon_sym___inline] = ACTIONS(2404),
    [anon_sym___inline__] = ACTIONS(2404),
    [anon_sym___forceinline] = ACTIONS(2404),
    [anon_sym_thread_local] = ACTIONS(2404),
    [anon_sym___thread] = ACTIONS(2404),
    [anon_sym_const] = ACTIONS(2404),
    [anon_sym_constexpr] = ACTIONS(2404),
    [anon_sym_volatile] = ACTIONS(2404),
    [anon_sym_restrict] = ACTIONS(2404),
    [anon_sym___restrict__] = ACTIONS(2404),
    [anon_sym__Atomic] = ACTIONS(2404),
    [anon_sym__Noreturn] = ACTIONS(2404),
    [anon_sym_noreturn] = ACTIONS(2404),
    [anon_sym_mutable] = ACTIONS(2404),
    [anon_sym_constinit] = ACTIONS(2404),
    [anon_sym_consteval] = ACTIONS(2404),
    [anon_sym_alignas] = ACTIONS(2404),
    [anon_sym__Alignas] = ACTIONS(2404),
    [sym_primitive_type] = ACTIONS(2404),
    [anon_sym_enum] = ACTIONS(2404),
    [anon_sym_class] = ACTIONS(2404),
    [anon_sym_struct] = ACTIONS(2404),
    [anon_sym_union] = ACTIONS(2404),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2404),
    [anon_sym_decltype] = ACTIONS(2404),
    [sym_virtual] = ACTIONS(2404),
    [anon_sym_explicit] = ACTIONS(2404),
    [anon_sym_typename] = ACTIONS(2404),
    [anon_sym_template] = ACTIONS(2404),
    [anon_sym_operator] = ACTIONS(2404),
    [anon_sym_friend] = ACTIONS(2404),
    [anon_sym_public] = ACTIONS(2404),
    [anon_sym_private] = ACTIONS(2404),
    [anon_sym_protected] = ACTIONS(2404),
    [anon_sym_using] = ACTIONS(2404),
    [anon_sym_static_assert] = ACTIONS(2404),
    [anon_sym_precise] = ACTIONS(2404),
    [anon_sym_shared] = ACTIONS(2404),
    [anon_sym_groupshared] = ACTIONS(2404),
    [anon_sym_uniform] = ACTIONS(2404),
    [anon_sym_row_major] = ACTIONS(2404),
    [anon_sym_column_major] = ACTIONS(2404),
    [anon_sym_globallycoherent] = ACTIONS(2404),
    [anon_sym_centroid] = ACTIONS(2404),
    [anon_sym_noperspective] = ACTIONS(2404),
    [anon_sym_nointerpolation] = ACTIONS(2404),
    [anon_sym_sample] = ACTIONS(2404),
    [anon_sym_linear] = ACTIONS(2404),
    [anon_sym_snorm] = ACTIONS(2404),
    [anon_sym_unorm] = ACTIONS(2404),
    [anon_sym_point] = ACTIONS(2404),
    [anon_sym_line] = ACTIONS(2404),
    [anon_sym_triangleadj] = ACTIONS(2404),
    [anon_sym_lineadj] = ACTIONS(2404),
    [anon_sym_triangle] = ACTIONS(2404),
  },
  [2093] = {
    [sym_identifier] = ACTIONS(2404),
    [aux_sym_preproc_def_token1] = ACTIONS(2404),
    [aux_sym_preproc_if_token1] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2404),
    [sym_preproc_directive] = ACTIONS(2404),
    [anon_sym_LPAREN2] = ACTIONS(2406),
    [anon_sym_TILDE] = ACTIONS(2406),
    [anon_sym_STAR] = ACTIONS(2406),
    [anon_sym_AMP_AMP] = ACTIONS(2406),
    [anon_sym_AMP] = ACTIONS(2404),
    [anon_sym___extension__] = ACTIONS(2404),
    [anon_sym_typedef] = ACTIONS(2404),
    [anon_sym_in] = ACTIONS(2404),
    [anon_sym_out] = ACTIONS(2404),
    [anon_sym_inout] = ACTIONS(2404),
    [anon_sym_extern] = ACTIONS(2404),
    [anon_sym___attribute__] = ACTIONS(2404),
    [anon_sym_COLON_COLON] = ACTIONS(2406),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2406),
    [anon_sym___declspec] = ACTIONS(2404),
    [anon_sym___based] = ACTIONS(2404),
    [anon_sym_RBRACE] = ACTIONS(2406),
    [anon_sym_signed] = ACTIONS(2404),
    [anon_sym_unsigned] = ACTIONS(2404),
    [anon_sym_long] = ACTIONS(2404),
    [anon_sym_short] = ACTIONS(2404),
    [anon_sym_LBRACK] = ACTIONS(2404),
    [anon_sym_static] = ACTIONS(2404),
    [anon_sym_register] = ACTIONS(2404),
    [anon_sym_inline] = ACTIONS(2404),
    [anon_sym___inline] = ACTIONS(2404),
    [anon_sym___inline__] = ACTIONS(2404),
    [anon_sym___forceinline] = ACTIONS(2404),
    [anon_sym_thread_local] = ACTIONS(2404),
    [anon_sym___thread] = ACTIONS(2404),
    [anon_sym_const] = ACTIONS(2404),
    [anon_sym_constexpr] = ACTIONS(2404),
    [anon_sym_volatile] = ACTIONS(2404),
    [anon_sym_restrict] = ACTIONS(2404),
    [anon_sym___restrict__] = ACTIONS(2404),
    [anon_sym__Atomic] = ACTIONS(2404),
    [anon_sym__Noreturn] = ACTIONS(2404),
    [anon_sym_noreturn] = ACTIONS(2404),
    [anon_sym_mutable] = ACTIONS(2404),
    [anon_sym_constinit] = ACTIONS(2404),
    [anon_sym_consteval] = ACTIONS(2404),
    [anon_sym_alignas] = ACTIONS(2404),
    [anon_sym__Alignas] = ACTIONS(2404),
    [sym_primitive_type] = ACTIONS(2404),
    [anon_sym_enum] = ACTIONS(2404),
    [anon_sym_class] = ACTIONS(2404),
    [anon_sym_struct] = ACTIONS(2404),
    [anon_sym_union] = ACTIONS(2404),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2404),
    [anon_sym_decltype] = ACTIONS(2404),
    [sym_virtual] = ACTIONS(2404),
    [anon_sym_explicit] = ACTIONS(2404),
    [anon_sym_typename] = ACTIONS(2404),
    [anon_sym_template] = ACTIONS(2404),
    [anon_sym_operator] = ACTIONS(2404),
    [anon_sym_friend] = ACTIONS(2404),
    [anon_sym_public] = ACTIONS(2404),
    [anon_sym_private] = ACTIONS(2404),
    [anon_sym_protected] = ACTIONS(2404),
    [anon_sym_using] = ACTIONS(2404),
    [anon_sym_static_assert] = ACTIONS(2404),
    [anon_sym_precise] = ACTIONS(2404),
    [anon_sym_shared] = ACTIONS(2404),
    [anon_sym_groupshared] = ACTIONS(2404),
    [anon_sym_uniform] = ACTIONS(2404),
    [anon_sym_row_major] = ACTIONS(2404),
    [anon_sym_column_major] = ACTIONS(2404),
    [anon_sym_globallycoherent] = ACTIONS(2404),
    [anon_sym_centroid] = ACTIONS(2404),
    [anon_sym_noperspective] = ACTIONS(2404),
    [anon_sym_nointerpolation] = ACTIONS(2404),
    [anon_sym_sample] = ACTIONS(2404),
    [anon_sym_linear] = ACTIONS(2404),
    [anon_sym_snorm] = ACTIONS(2404),
    [anon_sym_unorm] = ACTIONS(2404),
    [anon_sym_point] = ACTIONS(2404),
    [anon_sym_line] = ACTIONS(2404),
    [anon_sym_triangleadj] = ACTIONS(2404),
    [anon_sym_lineadj] = ACTIONS(2404),
    [anon_sym_triangle] = ACTIONS(2404),
  },
  [2094] = {
    [sym_identifier] = ACTIONS(2510),
    [aux_sym_preproc_def_token1] = ACTIONS(2510),
    [aux_sym_preproc_if_token1] = ACTIONS(2510),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2510),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2510),
    [sym_preproc_directive] = ACTIONS(2510),
    [anon_sym_LPAREN2] = ACTIONS(2512),
    [anon_sym_TILDE] = ACTIONS(2512),
    [anon_sym_STAR] = ACTIONS(2512),
    [anon_sym_AMP_AMP] = ACTIONS(2512),
    [anon_sym_AMP] = ACTIONS(2510),
    [anon_sym___extension__] = ACTIONS(2510),
    [anon_sym_typedef] = ACTIONS(2510),
    [anon_sym_in] = ACTIONS(2510),
    [anon_sym_out] = ACTIONS(2510),
    [anon_sym_inout] = ACTIONS(2510),
    [anon_sym_extern] = ACTIONS(2510),
    [anon_sym___attribute__] = ACTIONS(2510),
    [anon_sym_COLON_COLON] = ACTIONS(2512),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2512),
    [anon_sym___declspec] = ACTIONS(2510),
    [anon_sym___based] = ACTIONS(2510),
    [anon_sym_RBRACE] = ACTIONS(2512),
    [anon_sym_signed] = ACTIONS(2510),
    [anon_sym_unsigned] = ACTIONS(2510),
    [anon_sym_long] = ACTIONS(2510),
    [anon_sym_short] = ACTIONS(2510),
    [anon_sym_LBRACK] = ACTIONS(2510),
    [anon_sym_static] = ACTIONS(2510),
    [anon_sym_register] = ACTIONS(2510),
    [anon_sym_inline] = ACTIONS(2510),
    [anon_sym___inline] = ACTIONS(2510),
    [anon_sym___inline__] = ACTIONS(2510),
    [anon_sym___forceinline] = ACTIONS(2510),
    [anon_sym_thread_local] = ACTIONS(2510),
    [anon_sym___thread] = ACTIONS(2510),
    [anon_sym_const] = ACTIONS(2510),
    [anon_sym_constexpr] = ACTIONS(2510),
    [anon_sym_volatile] = ACTIONS(2510),
    [anon_sym_restrict] = ACTIONS(2510),
    [anon_sym___restrict__] = ACTIONS(2510),
    [anon_sym__Atomic] = ACTIONS(2510),
    [anon_sym__Noreturn] = ACTIONS(2510),
    [anon_sym_noreturn] = ACTIONS(2510),
    [anon_sym_mutable] = ACTIONS(2510),
    [anon_sym_constinit] = ACTIONS(2510),
    [anon_sym_consteval] = ACTIONS(2510),
    [anon_sym_alignas] = ACTIONS(2510),
    [anon_sym__Alignas] = ACTIONS(2510),
    [sym_primitive_type] = ACTIONS(2510),
    [anon_sym_enum] = ACTIONS(2510),
    [anon_sym_class] = ACTIONS(2510),
    [anon_sym_struct] = ACTIONS(2510),
    [anon_sym_union] = ACTIONS(2510),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2510),
    [anon_sym_decltype] = ACTIONS(2510),
    [sym_virtual] = ACTIONS(2510),
    [anon_sym_explicit] = ACTIONS(2510),
    [anon_sym_typename] = ACTIONS(2510),
    [anon_sym_template] = ACTIONS(2510),
    [anon_sym_operator] = ACTIONS(2510),
    [anon_sym_friend] = ACTIONS(2510),
    [anon_sym_public] = ACTIONS(2510),
    [anon_sym_private] = ACTIONS(2510),
    [anon_sym_protected] = ACTIONS(2510),
    [anon_sym_using] = ACTIONS(2510),
    [anon_sym_static_assert] = ACTIONS(2510),
    [anon_sym_precise] = ACTIONS(2510),
    [anon_sym_shared] = ACTIONS(2510),
    [anon_sym_groupshared] = ACTIONS(2510),
    [anon_sym_uniform] = ACTIONS(2510),
    [anon_sym_row_major] = ACTIONS(2510),
    [anon_sym_column_major] = ACTIONS(2510),
    [anon_sym_globallycoherent] = ACTIONS(2510),
    [anon_sym_centroid] = ACTIONS(2510),
    [anon_sym_noperspective] = ACTIONS(2510),
    [anon_sym_nointerpolation] = ACTIONS(2510),
    [anon_sym_sample] = ACTIONS(2510),
    [anon_sym_linear] = ACTIONS(2510),
    [anon_sym_snorm] = ACTIONS(2510),
    [anon_sym_unorm] = ACTIONS(2510),
    [anon_sym_point] = ACTIONS(2510),
    [anon_sym_line] = ACTIONS(2510),
    [anon_sym_triangleadj] = ACTIONS(2510),
    [anon_sym_lineadj] = ACTIONS(2510),
    [anon_sym_triangle] = ACTIONS(2510),
  },
  [2095] = {
    [sym_identifier] = ACTIONS(5089),
    [aux_sym_preproc_def_token1] = ACTIONS(5089),
    [aux_sym_preproc_if_token1] = ACTIONS(5089),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5089),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5089),
    [sym_preproc_directive] = ACTIONS(5089),
    [anon_sym_LPAREN2] = ACTIONS(5091),
    [anon_sym_TILDE] = ACTIONS(5091),
    [anon_sym_STAR] = ACTIONS(5091),
    [anon_sym_AMP_AMP] = ACTIONS(5091),
    [anon_sym_AMP] = ACTIONS(5089),
    [anon_sym___extension__] = ACTIONS(5089),
    [anon_sym_typedef] = ACTIONS(5089),
    [anon_sym_in] = ACTIONS(5089),
    [anon_sym_out] = ACTIONS(5089),
    [anon_sym_inout] = ACTIONS(5089),
    [anon_sym_extern] = ACTIONS(5089),
    [anon_sym___attribute__] = ACTIONS(5089),
    [anon_sym_COLON_COLON] = ACTIONS(5091),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5091),
    [anon_sym___declspec] = ACTIONS(5089),
    [anon_sym___based] = ACTIONS(5089),
    [anon_sym_RBRACE] = ACTIONS(5091),
    [anon_sym_signed] = ACTIONS(5089),
    [anon_sym_unsigned] = ACTIONS(5089),
    [anon_sym_long] = ACTIONS(5089),
    [anon_sym_short] = ACTIONS(5089),
    [anon_sym_LBRACK] = ACTIONS(5089),
    [anon_sym_static] = ACTIONS(5089),
    [anon_sym_register] = ACTIONS(5089),
    [anon_sym_inline] = ACTIONS(5089),
    [anon_sym___inline] = ACTIONS(5089),
    [anon_sym___inline__] = ACTIONS(5089),
    [anon_sym___forceinline] = ACTIONS(5089),
    [anon_sym_thread_local] = ACTIONS(5089),
    [anon_sym___thread] = ACTIONS(5089),
    [anon_sym_const] = ACTIONS(5089),
    [anon_sym_constexpr] = ACTIONS(5089),
    [anon_sym_volatile] = ACTIONS(5089),
    [anon_sym_restrict] = ACTIONS(5089),
    [anon_sym___restrict__] = ACTIONS(5089),
    [anon_sym__Atomic] = ACTIONS(5089),
    [anon_sym__Noreturn] = ACTIONS(5089),
    [anon_sym_noreturn] = ACTIONS(5089),
    [anon_sym_mutable] = ACTIONS(5089),
    [anon_sym_constinit] = ACTIONS(5089),
    [anon_sym_consteval] = ACTIONS(5089),
    [anon_sym_alignas] = ACTIONS(5089),
    [anon_sym__Alignas] = ACTIONS(5089),
    [sym_primitive_type] = ACTIONS(5089),
    [anon_sym_enum] = ACTIONS(5089),
    [anon_sym_class] = ACTIONS(5089),
    [anon_sym_struct] = ACTIONS(5089),
    [anon_sym_union] = ACTIONS(5089),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5089),
    [anon_sym_decltype] = ACTIONS(5089),
    [sym_virtual] = ACTIONS(5089),
    [anon_sym_explicit] = ACTIONS(5089),
    [anon_sym_typename] = ACTIONS(5089),
    [anon_sym_template] = ACTIONS(5089),
    [anon_sym_operator] = ACTIONS(5089),
    [anon_sym_friend] = ACTIONS(5089),
    [anon_sym_public] = ACTIONS(5089),
    [anon_sym_private] = ACTIONS(5089),
    [anon_sym_protected] = ACTIONS(5089),
    [anon_sym_using] = ACTIONS(5089),
    [anon_sym_static_assert] = ACTIONS(5089),
    [anon_sym_precise] = ACTIONS(5089),
    [anon_sym_shared] = ACTIONS(5089),
    [anon_sym_groupshared] = ACTIONS(5089),
    [anon_sym_uniform] = ACTIONS(5089),
    [anon_sym_row_major] = ACTIONS(5089),
    [anon_sym_column_major] = ACTIONS(5089),
    [anon_sym_globallycoherent] = ACTIONS(5089),
    [anon_sym_centroid] = ACTIONS(5089),
    [anon_sym_noperspective] = ACTIONS(5089),
    [anon_sym_nointerpolation] = ACTIONS(5089),
    [anon_sym_sample] = ACTIONS(5089),
    [anon_sym_linear] = ACTIONS(5089),
    [anon_sym_snorm] = ACTIONS(5089),
    [anon_sym_unorm] = ACTIONS(5089),
    [anon_sym_point] = ACTIONS(5089),
    [anon_sym_line] = ACTIONS(5089),
    [anon_sym_triangleadj] = ACTIONS(5089),
    [anon_sym_lineadj] = ACTIONS(5089),
    [anon_sym_triangle] = ACTIONS(5089),
  },
  [2096] = {
    [sym_identifier] = ACTIONS(5097),
    [aux_sym_preproc_def_token1] = ACTIONS(5097),
    [aux_sym_preproc_if_token1] = ACTIONS(5097),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5097),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5097),
    [sym_preproc_directive] = ACTIONS(5097),
    [anon_sym_LPAREN2] = ACTIONS(5099),
    [anon_sym_TILDE] = ACTIONS(5099),
    [anon_sym_STAR] = ACTIONS(5099),
    [anon_sym_AMP_AMP] = ACTIONS(5099),
    [anon_sym_AMP] = ACTIONS(5097),
    [anon_sym___extension__] = ACTIONS(5097),
    [anon_sym_typedef] = ACTIONS(5097),
    [anon_sym_in] = ACTIONS(5097),
    [anon_sym_out] = ACTIONS(5097),
    [anon_sym_inout] = ACTIONS(5097),
    [anon_sym_extern] = ACTIONS(5097),
    [anon_sym___attribute__] = ACTIONS(5097),
    [anon_sym_COLON_COLON] = ACTIONS(5099),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5099),
    [anon_sym___declspec] = ACTIONS(5097),
    [anon_sym___based] = ACTIONS(5097),
    [anon_sym_RBRACE] = ACTIONS(5099),
    [anon_sym_signed] = ACTIONS(5097),
    [anon_sym_unsigned] = ACTIONS(5097),
    [anon_sym_long] = ACTIONS(5097),
    [anon_sym_short] = ACTIONS(5097),
    [anon_sym_LBRACK] = ACTIONS(5097),
    [anon_sym_static] = ACTIONS(5097),
    [anon_sym_register] = ACTIONS(5097),
    [anon_sym_inline] = ACTIONS(5097),
    [anon_sym___inline] = ACTIONS(5097),
    [anon_sym___inline__] = ACTIONS(5097),
    [anon_sym___forceinline] = ACTIONS(5097),
    [anon_sym_thread_local] = ACTIONS(5097),
    [anon_sym___thread] = ACTIONS(5097),
    [anon_sym_const] = ACTIONS(5097),
    [anon_sym_constexpr] = ACTIONS(5097),
    [anon_sym_volatile] = ACTIONS(5097),
    [anon_sym_restrict] = ACTIONS(5097),
    [anon_sym___restrict__] = ACTIONS(5097),
    [anon_sym__Atomic] = ACTIONS(5097),
    [anon_sym__Noreturn] = ACTIONS(5097),
    [anon_sym_noreturn] = ACTIONS(5097),
    [anon_sym_mutable] = ACTIONS(5097),
    [anon_sym_constinit] = ACTIONS(5097),
    [anon_sym_consteval] = ACTIONS(5097),
    [anon_sym_alignas] = ACTIONS(5097),
    [anon_sym__Alignas] = ACTIONS(5097),
    [sym_primitive_type] = ACTIONS(5097),
    [anon_sym_enum] = ACTIONS(5097),
    [anon_sym_class] = ACTIONS(5097),
    [anon_sym_struct] = ACTIONS(5097),
    [anon_sym_union] = ACTIONS(5097),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5097),
    [anon_sym_decltype] = ACTIONS(5097),
    [sym_virtual] = ACTIONS(5097),
    [anon_sym_explicit] = ACTIONS(5097),
    [anon_sym_typename] = ACTIONS(5097),
    [anon_sym_template] = ACTIONS(5097),
    [anon_sym_operator] = ACTIONS(5097),
    [anon_sym_friend] = ACTIONS(5097),
    [anon_sym_public] = ACTIONS(5097),
    [anon_sym_private] = ACTIONS(5097),
    [anon_sym_protected] = ACTIONS(5097),
    [anon_sym_using] = ACTIONS(5097),
    [anon_sym_static_assert] = ACTIONS(5097),
    [anon_sym_precise] = ACTIONS(5097),
    [anon_sym_shared] = ACTIONS(5097),
    [anon_sym_groupshared] = ACTIONS(5097),
    [anon_sym_uniform] = ACTIONS(5097),
    [anon_sym_row_major] = ACTIONS(5097),
    [anon_sym_column_major] = ACTIONS(5097),
    [anon_sym_globallycoherent] = ACTIONS(5097),
    [anon_sym_centroid] = ACTIONS(5097),
    [anon_sym_noperspective] = ACTIONS(5097),
    [anon_sym_nointerpolation] = ACTIONS(5097),
    [anon_sym_sample] = ACTIONS(5097),
    [anon_sym_linear] = ACTIONS(5097),
    [anon_sym_snorm] = ACTIONS(5097),
    [anon_sym_unorm] = ACTIONS(5097),
    [anon_sym_point] = ACTIONS(5097),
    [anon_sym_line] = ACTIONS(5097),
    [anon_sym_triangleadj] = ACTIONS(5097),
    [anon_sym_lineadj] = ACTIONS(5097),
    [anon_sym_triangle] = ACTIONS(5097),
  },
  [2097] = {
    [sym_identifier] = ACTIONS(5025),
    [aux_sym_preproc_def_token1] = ACTIONS(5025),
    [aux_sym_preproc_if_token1] = ACTIONS(5025),
    [aux_sym_preproc_if_token2] = ACTIONS(5025),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5025),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5025),
    [sym_preproc_directive] = ACTIONS(5025),
    [anon_sym_LPAREN2] = ACTIONS(5027),
    [anon_sym_TILDE] = ACTIONS(5027),
    [anon_sym_STAR] = ACTIONS(5027),
    [anon_sym_AMP_AMP] = ACTIONS(5027),
    [anon_sym_AMP] = ACTIONS(5025),
    [anon_sym___extension__] = ACTIONS(5025),
    [anon_sym_typedef] = ACTIONS(5025),
    [anon_sym_in] = ACTIONS(5025),
    [anon_sym_out] = ACTIONS(5025),
    [anon_sym_inout] = ACTIONS(5025),
    [anon_sym_extern] = ACTIONS(5025),
    [anon_sym___attribute__] = ACTIONS(5025),
    [anon_sym_COLON_COLON] = ACTIONS(5027),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5027),
    [anon_sym___declspec] = ACTIONS(5025),
    [anon_sym___based] = ACTIONS(5025),
    [anon_sym_signed] = ACTIONS(5025),
    [anon_sym_unsigned] = ACTIONS(5025),
    [anon_sym_long] = ACTIONS(5025),
    [anon_sym_short] = ACTIONS(5025),
    [anon_sym_LBRACK] = ACTIONS(5025),
    [anon_sym_static] = ACTIONS(5025),
    [anon_sym_register] = ACTIONS(5025),
    [anon_sym_inline] = ACTIONS(5025),
    [anon_sym___inline] = ACTIONS(5025),
    [anon_sym___inline__] = ACTIONS(5025),
    [anon_sym___forceinline] = ACTIONS(5025),
    [anon_sym_thread_local] = ACTIONS(5025),
    [anon_sym___thread] = ACTIONS(5025),
    [anon_sym_const] = ACTIONS(5025),
    [anon_sym_constexpr] = ACTIONS(5025),
    [anon_sym_volatile] = ACTIONS(5025),
    [anon_sym_restrict] = ACTIONS(5025),
    [anon_sym___restrict__] = ACTIONS(5025),
    [anon_sym__Atomic] = ACTIONS(5025),
    [anon_sym__Noreturn] = ACTIONS(5025),
    [anon_sym_noreturn] = ACTIONS(5025),
    [anon_sym_mutable] = ACTIONS(5025),
    [anon_sym_constinit] = ACTIONS(5025),
    [anon_sym_consteval] = ACTIONS(5025),
    [anon_sym_alignas] = ACTIONS(5025),
    [anon_sym__Alignas] = ACTIONS(5025),
    [sym_primitive_type] = ACTIONS(5025),
    [anon_sym_enum] = ACTIONS(5025),
    [anon_sym_class] = ACTIONS(5025),
    [anon_sym_struct] = ACTIONS(5025),
    [anon_sym_union] = ACTIONS(5025),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5025),
    [anon_sym_decltype] = ACTIONS(5025),
    [sym_virtual] = ACTIONS(5025),
    [anon_sym_explicit] = ACTIONS(5025),
    [anon_sym_typename] = ACTIONS(5025),
    [anon_sym_template] = ACTIONS(5025),
    [anon_sym_operator] = ACTIONS(5025),
    [anon_sym_friend] = ACTIONS(5025),
    [anon_sym_public] = ACTIONS(5025),
    [anon_sym_private] = ACTIONS(5025),
    [anon_sym_protected] = ACTIONS(5025),
    [anon_sym_using] = ACTIONS(5025),
    [anon_sym_static_assert] = ACTIONS(5025),
    [anon_sym_precise] = ACTIONS(5025),
    [anon_sym_shared] = ACTIONS(5025),
    [anon_sym_groupshared] = ACTIONS(5025),
    [anon_sym_uniform] = ACTIONS(5025),
    [anon_sym_row_major] = ACTIONS(5025),
    [anon_sym_column_major] = ACTIONS(5025),
    [anon_sym_globallycoherent] = ACTIONS(5025),
    [anon_sym_centroid] = ACTIONS(5025),
    [anon_sym_noperspective] = ACTIONS(5025),
    [anon_sym_nointerpolation] = ACTIONS(5025),
    [anon_sym_sample] = ACTIONS(5025),
    [anon_sym_linear] = ACTIONS(5025),
    [anon_sym_snorm] = ACTIONS(5025),
    [anon_sym_unorm] = ACTIONS(5025),
    [anon_sym_point] = ACTIONS(5025),
    [anon_sym_line] = ACTIONS(5025),
    [anon_sym_triangleadj] = ACTIONS(5025),
    [anon_sym_lineadj] = ACTIONS(5025),
    [anon_sym_triangle] = ACTIONS(5025),
  },
  [2098] = {
    [sym_identifier] = ACTIONS(5029),
    [aux_sym_preproc_def_token1] = ACTIONS(5029),
    [aux_sym_preproc_if_token1] = ACTIONS(5029),
    [aux_sym_preproc_if_token2] = ACTIONS(5029),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5029),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5029),
    [sym_preproc_directive] = ACTIONS(5029),
    [anon_sym_LPAREN2] = ACTIONS(5031),
    [anon_sym_TILDE] = ACTIONS(5031),
    [anon_sym_STAR] = ACTIONS(5031),
    [anon_sym_AMP_AMP] = ACTIONS(5031),
    [anon_sym_AMP] = ACTIONS(5029),
    [anon_sym___extension__] = ACTIONS(5029),
    [anon_sym_typedef] = ACTIONS(5029),
    [anon_sym_in] = ACTIONS(5029),
    [anon_sym_out] = ACTIONS(5029),
    [anon_sym_inout] = ACTIONS(5029),
    [anon_sym_extern] = ACTIONS(5029),
    [anon_sym___attribute__] = ACTIONS(5029),
    [anon_sym_COLON_COLON] = ACTIONS(5031),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5031),
    [anon_sym___declspec] = ACTIONS(5029),
    [anon_sym___based] = ACTIONS(5029),
    [anon_sym_signed] = ACTIONS(5029),
    [anon_sym_unsigned] = ACTIONS(5029),
    [anon_sym_long] = ACTIONS(5029),
    [anon_sym_short] = ACTIONS(5029),
    [anon_sym_LBRACK] = ACTIONS(5029),
    [anon_sym_static] = ACTIONS(5029),
    [anon_sym_register] = ACTIONS(5029),
    [anon_sym_inline] = ACTIONS(5029),
    [anon_sym___inline] = ACTIONS(5029),
    [anon_sym___inline__] = ACTIONS(5029),
    [anon_sym___forceinline] = ACTIONS(5029),
    [anon_sym_thread_local] = ACTIONS(5029),
    [anon_sym___thread] = ACTIONS(5029),
    [anon_sym_const] = ACTIONS(5029),
    [anon_sym_constexpr] = ACTIONS(5029),
    [anon_sym_volatile] = ACTIONS(5029),
    [anon_sym_restrict] = ACTIONS(5029),
    [anon_sym___restrict__] = ACTIONS(5029),
    [anon_sym__Atomic] = ACTIONS(5029),
    [anon_sym__Noreturn] = ACTIONS(5029),
    [anon_sym_noreturn] = ACTIONS(5029),
    [anon_sym_mutable] = ACTIONS(5029),
    [anon_sym_constinit] = ACTIONS(5029),
    [anon_sym_consteval] = ACTIONS(5029),
    [anon_sym_alignas] = ACTIONS(5029),
    [anon_sym__Alignas] = ACTIONS(5029),
    [sym_primitive_type] = ACTIONS(5029),
    [anon_sym_enum] = ACTIONS(5029),
    [anon_sym_class] = ACTIONS(5029),
    [anon_sym_struct] = ACTIONS(5029),
    [anon_sym_union] = ACTIONS(5029),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5029),
    [anon_sym_decltype] = ACTIONS(5029),
    [sym_virtual] = ACTIONS(5029),
    [anon_sym_explicit] = ACTIONS(5029),
    [anon_sym_typename] = ACTIONS(5029),
    [anon_sym_template] = ACTIONS(5029),
    [anon_sym_operator] = ACTIONS(5029),
    [anon_sym_friend] = ACTIONS(5029),
    [anon_sym_public] = ACTIONS(5029),
    [anon_sym_private] = ACTIONS(5029),
    [anon_sym_protected] = ACTIONS(5029),
    [anon_sym_using] = ACTIONS(5029),
    [anon_sym_static_assert] = ACTIONS(5029),
    [anon_sym_precise] = ACTIONS(5029),
    [anon_sym_shared] = ACTIONS(5029),
    [anon_sym_groupshared] = ACTIONS(5029),
    [anon_sym_uniform] = ACTIONS(5029),
    [anon_sym_row_major] = ACTIONS(5029),
    [anon_sym_column_major] = ACTIONS(5029),
    [anon_sym_globallycoherent] = ACTIONS(5029),
    [anon_sym_centroid] = ACTIONS(5029),
    [anon_sym_noperspective] = ACTIONS(5029),
    [anon_sym_nointerpolation] = ACTIONS(5029),
    [anon_sym_sample] = ACTIONS(5029),
    [anon_sym_linear] = ACTIONS(5029),
    [anon_sym_snorm] = ACTIONS(5029),
    [anon_sym_unorm] = ACTIONS(5029),
    [anon_sym_point] = ACTIONS(5029),
    [anon_sym_line] = ACTIONS(5029),
    [anon_sym_triangleadj] = ACTIONS(5029),
    [anon_sym_lineadj] = ACTIONS(5029),
    [anon_sym_triangle] = ACTIONS(5029),
  },
  [2099] = {
    [sym_identifier] = ACTIONS(5029),
    [aux_sym_preproc_def_token1] = ACTIONS(5029),
    [aux_sym_preproc_if_token1] = ACTIONS(5029),
    [aux_sym_preproc_if_token2] = ACTIONS(5029),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5029),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5029),
    [sym_preproc_directive] = ACTIONS(5029),
    [anon_sym_LPAREN2] = ACTIONS(5031),
    [anon_sym_TILDE] = ACTIONS(5031),
    [anon_sym_STAR] = ACTIONS(5031),
    [anon_sym_AMP_AMP] = ACTIONS(5031),
    [anon_sym_AMP] = ACTIONS(5029),
    [anon_sym___extension__] = ACTIONS(5029),
    [anon_sym_typedef] = ACTIONS(5029),
    [anon_sym_in] = ACTIONS(5029),
    [anon_sym_out] = ACTIONS(5029),
    [anon_sym_inout] = ACTIONS(5029),
    [anon_sym_extern] = ACTIONS(5029),
    [anon_sym___attribute__] = ACTIONS(5029),
    [anon_sym_COLON_COLON] = ACTIONS(5031),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5031),
    [anon_sym___declspec] = ACTIONS(5029),
    [anon_sym___based] = ACTIONS(5029),
    [anon_sym_signed] = ACTIONS(5029),
    [anon_sym_unsigned] = ACTIONS(5029),
    [anon_sym_long] = ACTIONS(5029),
    [anon_sym_short] = ACTIONS(5029),
    [anon_sym_LBRACK] = ACTIONS(5029),
    [anon_sym_static] = ACTIONS(5029),
    [anon_sym_register] = ACTIONS(5029),
    [anon_sym_inline] = ACTIONS(5029),
    [anon_sym___inline] = ACTIONS(5029),
    [anon_sym___inline__] = ACTIONS(5029),
    [anon_sym___forceinline] = ACTIONS(5029),
    [anon_sym_thread_local] = ACTIONS(5029),
    [anon_sym___thread] = ACTIONS(5029),
    [anon_sym_const] = ACTIONS(5029),
    [anon_sym_constexpr] = ACTIONS(5029),
    [anon_sym_volatile] = ACTIONS(5029),
    [anon_sym_restrict] = ACTIONS(5029),
    [anon_sym___restrict__] = ACTIONS(5029),
    [anon_sym__Atomic] = ACTIONS(5029),
    [anon_sym__Noreturn] = ACTIONS(5029),
    [anon_sym_noreturn] = ACTIONS(5029),
    [anon_sym_mutable] = ACTIONS(5029),
    [anon_sym_constinit] = ACTIONS(5029),
    [anon_sym_consteval] = ACTIONS(5029),
    [anon_sym_alignas] = ACTIONS(5029),
    [anon_sym__Alignas] = ACTIONS(5029),
    [sym_primitive_type] = ACTIONS(5029),
    [anon_sym_enum] = ACTIONS(5029),
    [anon_sym_class] = ACTIONS(5029),
    [anon_sym_struct] = ACTIONS(5029),
    [anon_sym_union] = ACTIONS(5029),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5029),
    [anon_sym_decltype] = ACTIONS(5029),
    [sym_virtual] = ACTIONS(5029),
    [anon_sym_explicit] = ACTIONS(5029),
    [anon_sym_typename] = ACTIONS(5029),
    [anon_sym_template] = ACTIONS(5029),
    [anon_sym_operator] = ACTIONS(5029),
    [anon_sym_friend] = ACTIONS(5029),
    [anon_sym_public] = ACTIONS(5029),
    [anon_sym_private] = ACTIONS(5029),
    [anon_sym_protected] = ACTIONS(5029),
    [anon_sym_using] = ACTIONS(5029),
    [anon_sym_static_assert] = ACTIONS(5029),
    [anon_sym_precise] = ACTIONS(5029),
    [anon_sym_shared] = ACTIONS(5029),
    [anon_sym_groupshared] = ACTIONS(5029),
    [anon_sym_uniform] = ACTIONS(5029),
    [anon_sym_row_major] = ACTIONS(5029),
    [anon_sym_column_major] = ACTIONS(5029),
    [anon_sym_globallycoherent] = ACTIONS(5029),
    [anon_sym_centroid] = ACTIONS(5029),
    [anon_sym_noperspective] = ACTIONS(5029),
    [anon_sym_nointerpolation] = ACTIONS(5029),
    [anon_sym_sample] = ACTIONS(5029),
    [anon_sym_linear] = ACTIONS(5029),
    [anon_sym_snorm] = ACTIONS(5029),
    [anon_sym_unorm] = ACTIONS(5029),
    [anon_sym_point] = ACTIONS(5029),
    [anon_sym_line] = ACTIONS(5029),
    [anon_sym_triangleadj] = ACTIONS(5029),
    [anon_sym_lineadj] = ACTIONS(5029),
    [anon_sym_triangle] = ACTIONS(5029),
  },
  [2100] = {
    [sym_identifier] = ACTIONS(5029),
    [aux_sym_preproc_def_token1] = ACTIONS(5029),
    [aux_sym_preproc_if_token1] = ACTIONS(5029),
    [aux_sym_preproc_if_token2] = ACTIONS(5029),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5029),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5029),
    [sym_preproc_directive] = ACTIONS(5029),
    [anon_sym_LPAREN2] = ACTIONS(5031),
    [anon_sym_TILDE] = ACTIONS(5031),
    [anon_sym_STAR] = ACTIONS(5031),
    [anon_sym_AMP_AMP] = ACTIONS(5031),
    [anon_sym_AMP] = ACTIONS(5029),
    [anon_sym___extension__] = ACTIONS(5029),
    [anon_sym_typedef] = ACTIONS(5029),
    [anon_sym_in] = ACTIONS(5029),
    [anon_sym_out] = ACTIONS(5029),
    [anon_sym_inout] = ACTIONS(5029),
    [anon_sym_extern] = ACTIONS(5029),
    [anon_sym___attribute__] = ACTIONS(5029),
    [anon_sym_COLON_COLON] = ACTIONS(5031),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5031),
    [anon_sym___declspec] = ACTIONS(5029),
    [anon_sym___based] = ACTIONS(5029),
    [anon_sym_signed] = ACTIONS(5029),
    [anon_sym_unsigned] = ACTIONS(5029),
    [anon_sym_long] = ACTIONS(5029),
    [anon_sym_short] = ACTIONS(5029),
    [anon_sym_LBRACK] = ACTIONS(5029),
    [anon_sym_static] = ACTIONS(5029),
    [anon_sym_register] = ACTIONS(5029),
    [anon_sym_inline] = ACTIONS(5029),
    [anon_sym___inline] = ACTIONS(5029),
    [anon_sym___inline__] = ACTIONS(5029),
    [anon_sym___forceinline] = ACTIONS(5029),
    [anon_sym_thread_local] = ACTIONS(5029),
    [anon_sym___thread] = ACTIONS(5029),
    [anon_sym_const] = ACTIONS(5029),
    [anon_sym_constexpr] = ACTIONS(5029),
    [anon_sym_volatile] = ACTIONS(5029),
    [anon_sym_restrict] = ACTIONS(5029),
    [anon_sym___restrict__] = ACTIONS(5029),
    [anon_sym__Atomic] = ACTIONS(5029),
    [anon_sym__Noreturn] = ACTIONS(5029),
    [anon_sym_noreturn] = ACTIONS(5029),
    [anon_sym_mutable] = ACTIONS(5029),
    [anon_sym_constinit] = ACTIONS(5029),
    [anon_sym_consteval] = ACTIONS(5029),
    [anon_sym_alignas] = ACTIONS(5029),
    [anon_sym__Alignas] = ACTIONS(5029),
    [sym_primitive_type] = ACTIONS(5029),
    [anon_sym_enum] = ACTIONS(5029),
    [anon_sym_class] = ACTIONS(5029),
    [anon_sym_struct] = ACTIONS(5029),
    [anon_sym_union] = ACTIONS(5029),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5029),
    [anon_sym_decltype] = ACTIONS(5029),
    [sym_virtual] = ACTIONS(5029),
    [anon_sym_explicit] = ACTIONS(5029),
    [anon_sym_typename] = ACTIONS(5029),
    [anon_sym_template] = ACTIONS(5029),
    [anon_sym_operator] = ACTIONS(5029),
    [anon_sym_friend] = ACTIONS(5029),
    [anon_sym_public] = ACTIONS(5029),
    [anon_sym_private] = ACTIONS(5029),
    [anon_sym_protected] = ACTIONS(5029),
    [anon_sym_using] = ACTIONS(5029),
    [anon_sym_static_assert] = ACTIONS(5029),
    [anon_sym_precise] = ACTIONS(5029),
    [anon_sym_shared] = ACTIONS(5029),
    [anon_sym_groupshared] = ACTIONS(5029),
    [anon_sym_uniform] = ACTIONS(5029),
    [anon_sym_row_major] = ACTIONS(5029),
    [anon_sym_column_major] = ACTIONS(5029),
    [anon_sym_globallycoherent] = ACTIONS(5029),
    [anon_sym_centroid] = ACTIONS(5029),
    [anon_sym_noperspective] = ACTIONS(5029),
    [anon_sym_nointerpolation] = ACTIONS(5029),
    [anon_sym_sample] = ACTIONS(5029),
    [anon_sym_linear] = ACTIONS(5029),
    [anon_sym_snorm] = ACTIONS(5029),
    [anon_sym_unorm] = ACTIONS(5029),
    [anon_sym_point] = ACTIONS(5029),
    [anon_sym_line] = ACTIONS(5029),
    [anon_sym_triangleadj] = ACTIONS(5029),
    [anon_sym_lineadj] = ACTIONS(5029),
    [anon_sym_triangle] = ACTIONS(5029),
  },
  [2101] = {
    [sym_identifier] = ACTIONS(5025),
    [aux_sym_preproc_def_token1] = ACTIONS(5025),
    [aux_sym_preproc_if_token1] = ACTIONS(5025),
    [aux_sym_preproc_if_token2] = ACTIONS(5025),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5025),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5025),
    [sym_preproc_directive] = ACTIONS(5025),
    [anon_sym_LPAREN2] = ACTIONS(5027),
    [anon_sym_TILDE] = ACTIONS(5027),
    [anon_sym_STAR] = ACTIONS(5027),
    [anon_sym_AMP_AMP] = ACTIONS(5027),
    [anon_sym_AMP] = ACTIONS(5025),
    [anon_sym___extension__] = ACTIONS(5025),
    [anon_sym_typedef] = ACTIONS(5025),
    [anon_sym_in] = ACTIONS(5025),
    [anon_sym_out] = ACTIONS(5025),
    [anon_sym_inout] = ACTIONS(5025),
    [anon_sym_extern] = ACTIONS(5025),
    [anon_sym___attribute__] = ACTIONS(5025),
    [anon_sym_COLON_COLON] = ACTIONS(5027),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5027),
    [anon_sym___declspec] = ACTIONS(5025),
    [anon_sym___based] = ACTIONS(5025),
    [anon_sym_signed] = ACTIONS(5025),
    [anon_sym_unsigned] = ACTIONS(5025),
    [anon_sym_long] = ACTIONS(5025),
    [anon_sym_short] = ACTIONS(5025),
    [anon_sym_LBRACK] = ACTIONS(5025),
    [anon_sym_static] = ACTIONS(5025),
    [anon_sym_register] = ACTIONS(5025),
    [anon_sym_inline] = ACTIONS(5025),
    [anon_sym___inline] = ACTIONS(5025),
    [anon_sym___inline__] = ACTIONS(5025),
    [anon_sym___forceinline] = ACTIONS(5025),
    [anon_sym_thread_local] = ACTIONS(5025),
    [anon_sym___thread] = ACTIONS(5025),
    [anon_sym_const] = ACTIONS(5025),
    [anon_sym_constexpr] = ACTIONS(5025),
    [anon_sym_volatile] = ACTIONS(5025),
    [anon_sym_restrict] = ACTIONS(5025),
    [anon_sym___restrict__] = ACTIONS(5025),
    [anon_sym__Atomic] = ACTIONS(5025),
    [anon_sym__Noreturn] = ACTIONS(5025),
    [anon_sym_noreturn] = ACTIONS(5025),
    [anon_sym_mutable] = ACTIONS(5025),
    [anon_sym_constinit] = ACTIONS(5025),
    [anon_sym_consteval] = ACTIONS(5025),
    [anon_sym_alignas] = ACTIONS(5025),
    [anon_sym__Alignas] = ACTIONS(5025),
    [sym_primitive_type] = ACTIONS(5025),
    [anon_sym_enum] = ACTIONS(5025),
    [anon_sym_class] = ACTIONS(5025),
    [anon_sym_struct] = ACTIONS(5025),
    [anon_sym_union] = ACTIONS(5025),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5025),
    [anon_sym_decltype] = ACTIONS(5025),
    [sym_virtual] = ACTIONS(5025),
    [anon_sym_explicit] = ACTIONS(5025),
    [anon_sym_typename] = ACTIONS(5025),
    [anon_sym_template] = ACTIONS(5025),
    [anon_sym_operator] = ACTIONS(5025),
    [anon_sym_friend] = ACTIONS(5025),
    [anon_sym_public] = ACTIONS(5025),
    [anon_sym_private] = ACTIONS(5025),
    [anon_sym_protected] = ACTIONS(5025),
    [anon_sym_using] = ACTIONS(5025),
    [anon_sym_static_assert] = ACTIONS(5025),
    [anon_sym_precise] = ACTIONS(5025),
    [anon_sym_shared] = ACTIONS(5025),
    [anon_sym_groupshared] = ACTIONS(5025),
    [anon_sym_uniform] = ACTIONS(5025),
    [anon_sym_row_major] = ACTIONS(5025),
    [anon_sym_column_major] = ACTIONS(5025),
    [anon_sym_globallycoherent] = ACTIONS(5025),
    [anon_sym_centroid] = ACTIONS(5025),
    [anon_sym_noperspective] = ACTIONS(5025),
    [anon_sym_nointerpolation] = ACTIONS(5025),
    [anon_sym_sample] = ACTIONS(5025),
    [anon_sym_linear] = ACTIONS(5025),
    [anon_sym_snorm] = ACTIONS(5025),
    [anon_sym_unorm] = ACTIONS(5025),
    [anon_sym_point] = ACTIONS(5025),
    [anon_sym_line] = ACTIONS(5025),
    [anon_sym_triangleadj] = ACTIONS(5025),
    [anon_sym_lineadj] = ACTIONS(5025),
    [anon_sym_triangle] = ACTIONS(5025),
  },
  [2102] = {
    [sym_identifier] = ACTIONS(5033),
    [aux_sym_preproc_def_token1] = ACTIONS(5033),
    [aux_sym_preproc_if_token1] = ACTIONS(5033),
    [aux_sym_preproc_if_token2] = ACTIONS(5033),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5033),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5033),
    [sym_preproc_directive] = ACTIONS(5033),
    [anon_sym_LPAREN2] = ACTIONS(5035),
    [anon_sym_TILDE] = ACTIONS(5035),
    [anon_sym_STAR] = ACTIONS(5035),
    [anon_sym_AMP_AMP] = ACTIONS(5035),
    [anon_sym_AMP] = ACTIONS(5033),
    [anon_sym___extension__] = ACTIONS(5033),
    [anon_sym_typedef] = ACTIONS(5033),
    [anon_sym_in] = ACTIONS(5033),
    [anon_sym_out] = ACTIONS(5033),
    [anon_sym_inout] = ACTIONS(5033),
    [anon_sym_extern] = ACTIONS(5033),
    [anon_sym___attribute__] = ACTIONS(5033),
    [anon_sym_COLON_COLON] = ACTIONS(5035),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5035),
    [anon_sym___declspec] = ACTIONS(5033),
    [anon_sym___based] = ACTIONS(5033),
    [anon_sym_signed] = ACTIONS(5033),
    [anon_sym_unsigned] = ACTIONS(5033),
    [anon_sym_long] = ACTIONS(5033),
    [anon_sym_short] = ACTIONS(5033),
    [anon_sym_LBRACK] = ACTIONS(5033),
    [anon_sym_static] = ACTIONS(5033),
    [anon_sym_register] = ACTIONS(5033),
    [anon_sym_inline] = ACTIONS(5033),
    [anon_sym___inline] = ACTIONS(5033),
    [anon_sym___inline__] = ACTIONS(5033),
    [anon_sym___forceinline] = ACTIONS(5033),
    [anon_sym_thread_local] = ACTIONS(5033),
    [anon_sym___thread] = ACTIONS(5033),
    [anon_sym_const] = ACTIONS(5033),
    [anon_sym_constexpr] = ACTIONS(5033),
    [anon_sym_volatile] = ACTIONS(5033),
    [anon_sym_restrict] = ACTIONS(5033),
    [anon_sym___restrict__] = ACTIONS(5033),
    [anon_sym__Atomic] = ACTIONS(5033),
    [anon_sym__Noreturn] = ACTIONS(5033),
    [anon_sym_noreturn] = ACTIONS(5033),
    [anon_sym_mutable] = ACTIONS(5033),
    [anon_sym_constinit] = ACTIONS(5033),
    [anon_sym_consteval] = ACTIONS(5033),
    [anon_sym_alignas] = ACTIONS(5033),
    [anon_sym__Alignas] = ACTIONS(5033),
    [sym_primitive_type] = ACTIONS(5033),
    [anon_sym_enum] = ACTIONS(5033),
    [anon_sym_class] = ACTIONS(5033),
    [anon_sym_struct] = ACTIONS(5033),
    [anon_sym_union] = ACTIONS(5033),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5033),
    [anon_sym_decltype] = ACTIONS(5033),
    [sym_virtual] = ACTIONS(5033),
    [anon_sym_explicit] = ACTIONS(5033),
    [anon_sym_typename] = ACTIONS(5033),
    [anon_sym_template] = ACTIONS(5033),
    [anon_sym_operator] = ACTIONS(5033),
    [anon_sym_friend] = ACTIONS(5033),
    [anon_sym_public] = ACTIONS(5033),
    [anon_sym_private] = ACTIONS(5033),
    [anon_sym_protected] = ACTIONS(5033),
    [anon_sym_using] = ACTIONS(5033),
    [anon_sym_static_assert] = ACTIONS(5033),
    [anon_sym_precise] = ACTIONS(5033),
    [anon_sym_shared] = ACTIONS(5033),
    [anon_sym_groupshared] = ACTIONS(5033),
    [anon_sym_uniform] = ACTIONS(5033),
    [anon_sym_row_major] = ACTIONS(5033),
    [anon_sym_column_major] = ACTIONS(5033),
    [anon_sym_globallycoherent] = ACTIONS(5033),
    [anon_sym_centroid] = ACTIONS(5033),
    [anon_sym_noperspective] = ACTIONS(5033),
    [anon_sym_nointerpolation] = ACTIONS(5033),
    [anon_sym_sample] = ACTIONS(5033),
    [anon_sym_linear] = ACTIONS(5033),
    [anon_sym_snorm] = ACTIONS(5033),
    [anon_sym_unorm] = ACTIONS(5033),
    [anon_sym_point] = ACTIONS(5033),
    [anon_sym_line] = ACTIONS(5033),
    [anon_sym_triangleadj] = ACTIONS(5033),
    [anon_sym_lineadj] = ACTIONS(5033),
    [anon_sym_triangle] = ACTIONS(5033),
  },
  [2103] = {
    [sym_identifier] = ACTIONS(5045),
    [aux_sym_preproc_def_token1] = ACTIONS(5045),
    [aux_sym_preproc_if_token1] = ACTIONS(5045),
    [aux_sym_preproc_if_token2] = ACTIONS(5045),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5045),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5045),
    [sym_preproc_directive] = ACTIONS(5045),
    [anon_sym_LPAREN2] = ACTIONS(5047),
    [anon_sym_TILDE] = ACTIONS(5047),
    [anon_sym_STAR] = ACTIONS(5047),
    [anon_sym_AMP_AMP] = ACTIONS(5047),
    [anon_sym_AMP] = ACTIONS(5045),
    [anon_sym___extension__] = ACTIONS(5045),
    [anon_sym_typedef] = ACTIONS(5045),
    [anon_sym_in] = ACTIONS(5045),
    [anon_sym_out] = ACTIONS(5045),
    [anon_sym_inout] = ACTIONS(5045),
    [anon_sym_extern] = ACTIONS(5045),
    [anon_sym___attribute__] = ACTIONS(5045),
    [anon_sym_COLON_COLON] = ACTIONS(5047),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5047),
    [anon_sym___declspec] = ACTIONS(5045),
    [anon_sym___based] = ACTIONS(5045),
    [anon_sym_signed] = ACTIONS(5045),
    [anon_sym_unsigned] = ACTIONS(5045),
    [anon_sym_long] = ACTIONS(5045),
    [anon_sym_short] = ACTIONS(5045),
    [anon_sym_LBRACK] = ACTIONS(5045),
    [anon_sym_static] = ACTIONS(5045),
    [anon_sym_register] = ACTIONS(5045),
    [anon_sym_inline] = ACTIONS(5045),
    [anon_sym___inline] = ACTIONS(5045),
    [anon_sym___inline__] = ACTIONS(5045),
    [anon_sym___forceinline] = ACTIONS(5045),
    [anon_sym_thread_local] = ACTIONS(5045),
    [anon_sym___thread] = ACTIONS(5045),
    [anon_sym_const] = ACTIONS(5045),
    [anon_sym_constexpr] = ACTIONS(5045),
    [anon_sym_volatile] = ACTIONS(5045),
    [anon_sym_restrict] = ACTIONS(5045),
    [anon_sym___restrict__] = ACTIONS(5045),
    [anon_sym__Atomic] = ACTIONS(5045),
    [anon_sym__Noreturn] = ACTIONS(5045),
    [anon_sym_noreturn] = ACTIONS(5045),
    [anon_sym_mutable] = ACTIONS(5045),
    [anon_sym_constinit] = ACTIONS(5045),
    [anon_sym_consteval] = ACTIONS(5045),
    [anon_sym_alignas] = ACTIONS(5045),
    [anon_sym__Alignas] = ACTIONS(5045),
    [sym_primitive_type] = ACTIONS(5045),
    [anon_sym_enum] = ACTIONS(5045),
    [anon_sym_class] = ACTIONS(5045),
    [anon_sym_struct] = ACTIONS(5045),
    [anon_sym_union] = ACTIONS(5045),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5045),
    [anon_sym_decltype] = ACTIONS(5045),
    [sym_virtual] = ACTIONS(5045),
    [anon_sym_explicit] = ACTIONS(5045),
    [anon_sym_typename] = ACTIONS(5045),
    [anon_sym_template] = ACTIONS(5045),
    [anon_sym_operator] = ACTIONS(5045),
    [anon_sym_friend] = ACTIONS(5045),
    [anon_sym_public] = ACTIONS(5045),
    [anon_sym_private] = ACTIONS(5045),
    [anon_sym_protected] = ACTIONS(5045),
    [anon_sym_using] = ACTIONS(5045),
    [anon_sym_static_assert] = ACTIONS(5045),
    [anon_sym_precise] = ACTIONS(5045),
    [anon_sym_shared] = ACTIONS(5045),
    [anon_sym_groupshared] = ACTIONS(5045),
    [anon_sym_uniform] = ACTIONS(5045),
    [anon_sym_row_major] = ACTIONS(5045),
    [anon_sym_column_major] = ACTIONS(5045),
    [anon_sym_globallycoherent] = ACTIONS(5045),
    [anon_sym_centroid] = ACTIONS(5045),
    [anon_sym_noperspective] = ACTIONS(5045),
    [anon_sym_nointerpolation] = ACTIONS(5045),
    [anon_sym_sample] = ACTIONS(5045),
    [anon_sym_linear] = ACTIONS(5045),
    [anon_sym_snorm] = ACTIONS(5045),
    [anon_sym_unorm] = ACTIONS(5045),
    [anon_sym_point] = ACTIONS(5045),
    [anon_sym_line] = ACTIONS(5045),
    [anon_sym_triangleadj] = ACTIONS(5045),
    [anon_sym_lineadj] = ACTIONS(5045),
    [anon_sym_triangle] = ACTIONS(5045),
  },
  [2104] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym_RBRACE] = ACTIONS(2326),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_friend] = ACTIONS(2324),
    [anon_sym_public] = ACTIONS(2324),
    [anon_sym_private] = ACTIONS(2324),
    [anon_sym_protected] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
  },
  [2105] = {
    [sym_identifier] = ACTIONS(2573),
    [aux_sym_preproc_def_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2573),
    [sym_preproc_directive] = ACTIONS(2573),
    [anon_sym_LPAREN2] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(2575),
    [anon_sym_STAR] = ACTIONS(2575),
    [anon_sym_AMP_AMP] = ACTIONS(2575),
    [anon_sym_AMP] = ACTIONS(2573),
    [anon_sym___extension__] = ACTIONS(2573),
    [anon_sym_typedef] = ACTIONS(2573),
    [anon_sym_in] = ACTIONS(2573),
    [anon_sym_out] = ACTIONS(2573),
    [anon_sym_inout] = ACTIONS(2573),
    [anon_sym_extern] = ACTIONS(2573),
    [anon_sym___attribute__] = ACTIONS(2573),
    [anon_sym_COLON_COLON] = ACTIONS(2575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2575),
    [anon_sym___declspec] = ACTIONS(2573),
    [anon_sym___based] = ACTIONS(2573),
    [anon_sym_RBRACE] = ACTIONS(2575),
    [anon_sym_signed] = ACTIONS(2573),
    [anon_sym_unsigned] = ACTIONS(2573),
    [anon_sym_long] = ACTIONS(2573),
    [anon_sym_short] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2573),
    [anon_sym_static] = ACTIONS(2573),
    [anon_sym_register] = ACTIONS(2573),
    [anon_sym_inline] = ACTIONS(2573),
    [anon_sym___inline] = ACTIONS(2573),
    [anon_sym___inline__] = ACTIONS(2573),
    [anon_sym___forceinline] = ACTIONS(2573),
    [anon_sym_thread_local] = ACTIONS(2573),
    [anon_sym___thread] = ACTIONS(2573),
    [anon_sym_const] = ACTIONS(2573),
    [anon_sym_constexpr] = ACTIONS(2573),
    [anon_sym_volatile] = ACTIONS(2573),
    [anon_sym_restrict] = ACTIONS(2573),
    [anon_sym___restrict__] = ACTIONS(2573),
    [anon_sym__Atomic] = ACTIONS(2573),
    [anon_sym__Noreturn] = ACTIONS(2573),
    [anon_sym_noreturn] = ACTIONS(2573),
    [anon_sym_mutable] = ACTIONS(2573),
    [anon_sym_constinit] = ACTIONS(2573),
    [anon_sym_consteval] = ACTIONS(2573),
    [anon_sym_alignas] = ACTIONS(2573),
    [anon_sym__Alignas] = ACTIONS(2573),
    [sym_primitive_type] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_class] = ACTIONS(2573),
    [anon_sym_struct] = ACTIONS(2573),
    [anon_sym_union] = ACTIONS(2573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2573),
    [anon_sym_decltype] = ACTIONS(2573),
    [sym_virtual] = ACTIONS(2573),
    [anon_sym_explicit] = ACTIONS(2573),
    [anon_sym_typename] = ACTIONS(2573),
    [anon_sym_template] = ACTIONS(2573),
    [anon_sym_operator] = ACTIONS(2573),
    [anon_sym_friend] = ACTIONS(2573),
    [anon_sym_public] = ACTIONS(2573),
    [anon_sym_private] = ACTIONS(2573),
    [anon_sym_protected] = ACTIONS(2573),
    [anon_sym_using] = ACTIONS(2573),
    [anon_sym_static_assert] = ACTIONS(2573),
    [anon_sym_precise] = ACTIONS(2573),
    [anon_sym_shared] = ACTIONS(2573),
    [anon_sym_groupshared] = ACTIONS(2573),
    [anon_sym_uniform] = ACTIONS(2573),
    [anon_sym_row_major] = ACTIONS(2573),
    [anon_sym_column_major] = ACTIONS(2573),
    [anon_sym_globallycoherent] = ACTIONS(2573),
    [anon_sym_centroid] = ACTIONS(2573),
    [anon_sym_noperspective] = ACTIONS(2573),
    [anon_sym_nointerpolation] = ACTIONS(2573),
    [anon_sym_sample] = ACTIONS(2573),
    [anon_sym_linear] = ACTIONS(2573),
    [anon_sym_snorm] = ACTIONS(2573),
    [anon_sym_unorm] = ACTIONS(2573),
    [anon_sym_point] = ACTIONS(2573),
    [anon_sym_line] = ACTIONS(2573),
    [anon_sym_triangleadj] = ACTIONS(2573),
    [anon_sym_lineadj] = ACTIONS(2573),
    [anon_sym_triangle] = ACTIONS(2573),
  },
  [2106] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym_RBRACE] = ACTIONS(2326),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_friend] = ACTIONS(2324),
    [anon_sym_public] = ACTIONS(2324),
    [anon_sym_private] = ACTIONS(2324),
    [anon_sym_protected] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
  },
  [2107] = {
    [sym_identifier] = ACTIONS(2565),
    [aux_sym_preproc_def_token1] = ACTIONS(2565),
    [aux_sym_preproc_if_token1] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2565),
    [sym_preproc_directive] = ACTIONS(2565),
    [anon_sym_LPAREN2] = ACTIONS(2567),
    [anon_sym_TILDE] = ACTIONS(2567),
    [anon_sym_STAR] = ACTIONS(2567),
    [anon_sym_AMP_AMP] = ACTIONS(2567),
    [anon_sym_AMP] = ACTIONS(2565),
    [anon_sym___extension__] = ACTIONS(2565),
    [anon_sym_typedef] = ACTIONS(2565),
    [anon_sym_in] = ACTIONS(2565),
    [anon_sym_out] = ACTIONS(2565),
    [anon_sym_inout] = ACTIONS(2565),
    [anon_sym_extern] = ACTIONS(2565),
    [anon_sym___attribute__] = ACTIONS(2565),
    [anon_sym_COLON_COLON] = ACTIONS(2567),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2567),
    [anon_sym___declspec] = ACTIONS(2565),
    [anon_sym___based] = ACTIONS(2565),
    [anon_sym_RBRACE] = ACTIONS(2567),
    [anon_sym_signed] = ACTIONS(2565),
    [anon_sym_unsigned] = ACTIONS(2565),
    [anon_sym_long] = ACTIONS(2565),
    [anon_sym_short] = ACTIONS(2565),
    [anon_sym_LBRACK] = ACTIONS(2565),
    [anon_sym_static] = ACTIONS(2565),
    [anon_sym_register] = ACTIONS(2565),
    [anon_sym_inline] = ACTIONS(2565),
    [anon_sym___inline] = ACTIONS(2565),
    [anon_sym___inline__] = ACTIONS(2565),
    [anon_sym___forceinline] = ACTIONS(2565),
    [anon_sym_thread_local] = ACTIONS(2565),
    [anon_sym___thread] = ACTIONS(2565),
    [anon_sym_const] = ACTIONS(2565),
    [anon_sym_constexpr] = ACTIONS(2565),
    [anon_sym_volatile] = ACTIONS(2565),
    [anon_sym_restrict] = ACTIONS(2565),
    [anon_sym___restrict__] = ACTIONS(2565),
    [anon_sym__Atomic] = ACTIONS(2565),
    [anon_sym__Noreturn] = ACTIONS(2565),
    [anon_sym_noreturn] = ACTIONS(2565),
    [anon_sym_mutable] = ACTIONS(2565),
    [anon_sym_constinit] = ACTIONS(2565),
    [anon_sym_consteval] = ACTIONS(2565),
    [anon_sym_alignas] = ACTIONS(2565),
    [anon_sym__Alignas] = ACTIONS(2565),
    [sym_primitive_type] = ACTIONS(2565),
    [anon_sym_enum] = ACTIONS(2565),
    [anon_sym_class] = ACTIONS(2565),
    [anon_sym_struct] = ACTIONS(2565),
    [anon_sym_union] = ACTIONS(2565),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2565),
    [anon_sym_decltype] = ACTIONS(2565),
    [sym_virtual] = ACTIONS(2565),
    [anon_sym_explicit] = ACTIONS(2565),
    [anon_sym_typename] = ACTIONS(2565),
    [anon_sym_template] = ACTIONS(2565),
    [anon_sym_operator] = ACTIONS(2565),
    [anon_sym_friend] = ACTIONS(2565),
    [anon_sym_public] = ACTIONS(2565),
    [anon_sym_private] = ACTIONS(2565),
    [anon_sym_protected] = ACTIONS(2565),
    [anon_sym_using] = ACTIONS(2565),
    [anon_sym_static_assert] = ACTIONS(2565),
    [anon_sym_precise] = ACTIONS(2565),
    [anon_sym_shared] = ACTIONS(2565),
    [anon_sym_groupshared] = ACTIONS(2565),
    [anon_sym_uniform] = ACTIONS(2565),
    [anon_sym_row_major] = ACTIONS(2565),
    [anon_sym_column_major] = ACTIONS(2565),
    [anon_sym_globallycoherent] = ACTIONS(2565),
    [anon_sym_centroid] = ACTIONS(2565),
    [anon_sym_noperspective] = ACTIONS(2565),
    [anon_sym_nointerpolation] = ACTIONS(2565),
    [anon_sym_sample] = ACTIONS(2565),
    [anon_sym_linear] = ACTIONS(2565),
    [anon_sym_snorm] = ACTIONS(2565),
    [anon_sym_unorm] = ACTIONS(2565),
    [anon_sym_point] = ACTIONS(2565),
    [anon_sym_line] = ACTIONS(2565),
    [anon_sym_triangleadj] = ACTIONS(2565),
    [anon_sym_lineadj] = ACTIONS(2565),
    [anon_sym_triangle] = ACTIONS(2565),
  },
  [2108] = {
    [sym_identifier] = ACTIONS(2549),
    [aux_sym_preproc_def_token1] = ACTIONS(2549),
    [aux_sym_preproc_if_token1] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2549),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2549),
    [sym_preproc_directive] = ACTIONS(2549),
    [anon_sym_LPAREN2] = ACTIONS(2551),
    [anon_sym_TILDE] = ACTIONS(2551),
    [anon_sym_STAR] = ACTIONS(2551),
    [anon_sym_AMP_AMP] = ACTIONS(2551),
    [anon_sym_AMP] = ACTIONS(2549),
    [anon_sym___extension__] = ACTIONS(2549),
    [anon_sym_typedef] = ACTIONS(2549),
    [anon_sym_in] = ACTIONS(2549),
    [anon_sym_out] = ACTIONS(2549),
    [anon_sym_inout] = ACTIONS(2549),
    [anon_sym_extern] = ACTIONS(2549),
    [anon_sym___attribute__] = ACTIONS(2549),
    [anon_sym_COLON_COLON] = ACTIONS(2551),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2551),
    [anon_sym___declspec] = ACTIONS(2549),
    [anon_sym___based] = ACTIONS(2549),
    [anon_sym_RBRACE] = ACTIONS(2551),
    [anon_sym_signed] = ACTIONS(2549),
    [anon_sym_unsigned] = ACTIONS(2549),
    [anon_sym_long] = ACTIONS(2549),
    [anon_sym_short] = ACTIONS(2549),
    [anon_sym_LBRACK] = ACTIONS(2549),
    [anon_sym_static] = ACTIONS(2549),
    [anon_sym_register] = ACTIONS(2549),
    [anon_sym_inline] = ACTIONS(2549),
    [anon_sym___inline] = ACTIONS(2549),
    [anon_sym___inline__] = ACTIONS(2549),
    [anon_sym___forceinline] = ACTIONS(2549),
    [anon_sym_thread_local] = ACTIONS(2549),
    [anon_sym___thread] = ACTIONS(2549),
    [anon_sym_const] = ACTIONS(2549),
    [anon_sym_constexpr] = ACTIONS(2549),
    [anon_sym_volatile] = ACTIONS(2549),
    [anon_sym_restrict] = ACTIONS(2549),
    [anon_sym___restrict__] = ACTIONS(2549),
    [anon_sym__Atomic] = ACTIONS(2549),
    [anon_sym__Noreturn] = ACTIONS(2549),
    [anon_sym_noreturn] = ACTIONS(2549),
    [anon_sym_mutable] = ACTIONS(2549),
    [anon_sym_constinit] = ACTIONS(2549),
    [anon_sym_consteval] = ACTIONS(2549),
    [anon_sym_alignas] = ACTIONS(2549),
    [anon_sym__Alignas] = ACTIONS(2549),
    [sym_primitive_type] = ACTIONS(2549),
    [anon_sym_enum] = ACTIONS(2549),
    [anon_sym_class] = ACTIONS(2549),
    [anon_sym_struct] = ACTIONS(2549),
    [anon_sym_union] = ACTIONS(2549),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2549),
    [anon_sym_decltype] = ACTIONS(2549),
    [sym_virtual] = ACTIONS(2549),
    [anon_sym_explicit] = ACTIONS(2549),
    [anon_sym_typename] = ACTIONS(2549),
    [anon_sym_template] = ACTIONS(2549),
    [anon_sym_operator] = ACTIONS(2549),
    [anon_sym_friend] = ACTIONS(2549),
    [anon_sym_public] = ACTIONS(2549),
    [anon_sym_private] = ACTIONS(2549),
    [anon_sym_protected] = ACTIONS(2549),
    [anon_sym_using] = ACTIONS(2549),
    [anon_sym_static_assert] = ACTIONS(2549),
    [anon_sym_precise] = ACTIONS(2549),
    [anon_sym_shared] = ACTIONS(2549),
    [anon_sym_groupshared] = ACTIONS(2549),
    [anon_sym_uniform] = ACTIONS(2549),
    [anon_sym_row_major] = ACTIONS(2549),
    [anon_sym_column_major] = ACTIONS(2549),
    [anon_sym_globallycoherent] = ACTIONS(2549),
    [anon_sym_centroid] = ACTIONS(2549),
    [anon_sym_noperspective] = ACTIONS(2549),
    [anon_sym_nointerpolation] = ACTIONS(2549),
    [anon_sym_sample] = ACTIONS(2549),
    [anon_sym_linear] = ACTIONS(2549),
    [anon_sym_snorm] = ACTIONS(2549),
    [anon_sym_unorm] = ACTIONS(2549),
    [anon_sym_point] = ACTIONS(2549),
    [anon_sym_line] = ACTIONS(2549),
    [anon_sym_triangleadj] = ACTIONS(2549),
    [anon_sym_lineadj] = ACTIONS(2549),
    [anon_sym_triangle] = ACTIONS(2549),
  },
  [2109] = {
    [sym_identifier] = ACTIONS(5053),
    [aux_sym_preproc_def_token1] = ACTIONS(5053),
    [aux_sym_preproc_if_token1] = ACTIONS(5053),
    [aux_sym_preproc_if_token2] = ACTIONS(5053),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5053),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5053),
    [sym_preproc_directive] = ACTIONS(5053),
    [anon_sym_LPAREN2] = ACTIONS(5055),
    [anon_sym_TILDE] = ACTIONS(5055),
    [anon_sym_STAR] = ACTIONS(5055),
    [anon_sym_AMP_AMP] = ACTIONS(5055),
    [anon_sym_AMP] = ACTIONS(5053),
    [anon_sym___extension__] = ACTIONS(5053),
    [anon_sym_typedef] = ACTIONS(5053),
    [anon_sym_in] = ACTIONS(5053),
    [anon_sym_out] = ACTIONS(5053),
    [anon_sym_inout] = ACTIONS(5053),
    [anon_sym_extern] = ACTIONS(5053),
    [anon_sym___attribute__] = ACTIONS(5053),
    [anon_sym_COLON_COLON] = ACTIONS(5055),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5055),
    [anon_sym___declspec] = ACTIONS(5053),
    [anon_sym___based] = ACTIONS(5053),
    [anon_sym_signed] = ACTIONS(5053),
    [anon_sym_unsigned] = ACTIONS(5053),
    [anon_sym_long] = ACTIONS(5053),
    [anon_sym_short] = ACTIONS(5053),
    [anon_sym_LBRACK] = ACTIONS(5053),
    [anon_sym_static] = ACTIONS(5053),
    [anon_sym_register] = ACTIONS(5053),
    [anon_sym_inline] = ACTIONS(5053),
    [anon_sym___inline] = ACTIONS(5053),
    [anon_sym___inline__] = ACTIONS(5053),
    [anon_sym___forceinline] = ACTIONS(5053),
    [anon_sym_thread_local] = ACTIONS(5053),
    [anon_sym___thread] = ACTIONS(5053),
    [anon_sym_const] = ACTIONS(5053),
    [anon_sym_constexpr] = ACTIONS(5053),
    [anon_sym_volatile] = ACTIONS(5053),
    [anon_sym_restrict] = ACTIONS(5053),
    [anon_sym___restrict__] = ACTIONS(5053),
    [anon_sym__Atomic] = ACTIONS(5053),
    [anon_sym__Noreturn] = ACTIONS(5053),
    [anon_sym_noreturn] = ACTIONS(5053),
    [anon_sym_mutable] = ACTIONS(5053),
    [anon_sym_constinit] = ACTIONS(5053),
    [anon_sym_consteval] = ACTIONS(5053),
    [anon_sym_alignas] = ACTIONS(5053),
    [anon_sym__Alignas] = ACTIONS(5053),
    [sym_primitive_type] = ACTIONS(5053),
    [anon_sym_enum] = ACTIONS(5053),
    [anon_sym_class] = ACTIONS(5053),
    [anon_sym_struct] = ACTIONS(5053),
    [anon_sym_union] = ACTIONS(5053),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5053),
    [anon_sym_decltype] = ACTIONS(5053),
    [sym_virtual] = ACTIONS(5053),
    [anon_sym_explicit] = ACTIONS(5053),
    [anon_sym_typename] = ACTIONS(5053),
    [anon_sym_template] = ACTIONS(5053),
    [anon_sym_operator] = ACTIONS(5053),
    [anon_sym_friend] = ACTIONS(5053),
    [anon_sym_public] = ACTIONS(5053),
    [anon_sym_private] = ACTIONS(5053),
    [anon_sym_protected] = ACTIONS(5053),
    [anon_sym_using] = ACTIONS(5053),
    [anon_sym_static_assert] = ACTIONS(5053),
    [anon_sym_precise] = ACTIONS(5053),
    [anon_sym_shared] = ACTIONS(5053),
    [anon_sym_groupshared] = ACTIONS(5053),
    [anon_sym_uniform] = ACTIONS(5053),
    [anon_sym_row_major] = ACTIONS(5053),
    [anon_sym_column_major] = ACTIONS(5053),
    [anon_sym_globallycoherent] = ACTIONS(5053),
    [anon_sym_centroid] = ACTIONS(5053),
    [anon_sym_noperspective] = ACTIONS(5053),
    [anon_sym_nointerpolation] = ACTIONS(5053),
    [anon_sym_sample] = ACTIONS(5053),
    [anon_sym_linear] = ACTIONS(5053),
    [anon_sym_snorm] = ACTIONS(5053),
    [anon_sym_unorm] = ACTIONS(5053),
    [anon_sym_point] = ACTIONS(5053),
    [anon_sym_line] = ACTIONS(5053),
    [anon_sym_triangleadj] = ACTIONS(5053),
    [anon_sym_lineadj] = ACTIONS(5053),
    [anon_sym_triangle] = ACTIONS(5053),
  },
  [2110] = {
    [sym_string_literal] = STATE(3630),
    [sym_template_argument_list] = STATE(3195),
    [sym_raw_string_literal] = STATE(3630),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2666),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3837),
    [anon_sym_COMMA] = ACTIONS(3837),
    [anon_sym_LPAREN2] = ACTIONS(3837),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3834),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3837),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3834),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3832),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5201),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym___extension__] = ACTIONS(3830),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_signed] = ACTIONS(5204),
    [anon_sym_unsigned] = ACTIONS(5204),
    [anon_sym_long] = ACTIONS(5204),
    [anon_sym_short] = ACTIONS(5204),
    [anon_sym_LBRACK] = ACTIONS(3837),
    [anon_sym_EQ] = ACTIONS(5206),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3830),
    [anon_sym_volatile] = ACTIONS(3830),
    [anon_sym_restrict] = ACTIONS(3830),
    [anon_sym___restrict__] = ACTIONS(3830),
    [anon_sym__Atomic] = ACTIONS(3830),
    [anon_sym__Noreturn] = ACTIONS(3830),
    [anon_sym_noreturn] = ACTIONS(3830),
    [anon_sym_mutable] = ACTIONS(3830),
    [anon_sym_constinit] = ACTIONS(3830),
    [anon_sym_consteval] = ACTIONS(3830),
    [anon_sym_alignas] = ACTIONS(3830),
    [anon_sym__Alignas] = ACTIONS(3830),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(5208),
    [anon_sym_SLASH_EQ] = ACTIONS(5208),
    [anon_sym_PERCENT_EQ] = ACTIONS(5208),
    [anon_sym_PLUS_EQ] = ACTIONS(5208),
    [anon_sym_DASH_EQ] = ACTIONS(5208),
    [anon_sym_LT_LT_EQ] = ACTIONS(5208),
    [anon_sym_GT_GT_EQ] = ACTIONS(5206),
    [anon_sym_AMP_EQ] = ACTIONS(5208),
    [anon_sym_CARET_EQ] = ACTIONS(5208),
    [anon_sym_PIPE_EQ] = ACTIONS(5208),
    [anon_sym_and_eq] = ACTIONS(5208),
    [anon_sym_or_eq] = ACTIONS(5208),
    [anon_sym_xor_eq] = ACTIONS(5208),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(5210),
    [anon_sym_u_DQUOTE] = ACTIONS(5210),
    [anon_sym_U_DQUOTE] = ACTIONS(5210),
    [anon_sym_u8_DQUOTE] = ACTIONS(5210),
    [anon_sym_DQUOTE] = ACTIONS(5210),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3830),
    [anon_sym_decltype] = ACTIONS(3830),
    [anon_sym_GT2] = ACTIONS(3837),
    [anon_sym_R_DQUOTE] = ACTIONS(5212),
    [anon_sym_LR_DQUOTE] = ACTIONS(5212),
    [anon_sym_uR_DQUOTE] = ACTIONS(5212),
    [anon_sym_UR_DQUOTE] = ACTIONS(5212),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5212),
  },
  [2111] = {
    [sym_identifier] = ACTIONS(2393),
    [aux_sym_preproc_def_token1] = ACTIONS(2393),
    [aux_sym_preproc_if_token1] = ACTIONS(2393),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2393),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2393),
    [sym_preproc_directive] = ACTIONS(2393),
    [anon_sym_LPAREN2] = ACTIONS(2395),
    [anon_sym_TILDE] = ACTIONS(2395),
    [anon_sym_STAR] = ACTIONS(2395),
    [anon_sym_AMP_AMP] = ACTIONS(2395),
    [anon_sym_AMP] = ACTIONS(2393),
    [anon_sym___extension__] = ACTIONS(2393),
    [anon_sym_typedef] = ACTIONS(2393),
    [anon_sym_in] = ACTIONS(2393),
    [anon_sym_out] = ACTIONS(2393),
    [anon_sym_inout] = ACTIONS(2393),
    [anon_sym_extern] = ACTIONS(2393),
    [anon_sym___attribute__] = ACTIONS(2393),
    [anon_sym_COLON_COLON] = ACTIONS(2395),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2395),
    [anon_sym___declspec] = ACTIONS(2393),
    [anon_sym___based] = ACTIONS(2393),
    [anon_sym_RBRACE] = ACTIONS(2395),
    [anon_sym_signed] = ACTIONS(2393),
    [anon_sym_unsigned] = ACTIONS(2393),
    [anon_sym_long] = ACTIONS(2393),
    [anon_sym_short] = ACTIONS(2393),
    [anon_sym_LBRACK] = ACTIONS(2393),
    [anon_sym_static] = ACTIONS(2393),
    [anon_sym_register] = ACTIONS(2393),
    [anon_sym_inline] = ACTIONS(2393),
    [anon_sym___inline] = ACTIONS(2393),
    [anon_sym___inline__] = ACTIONS(2393),
    [anon_sym___forceinline] = ACTIONS(2393),
    [anon_sym_thread_local] = ACTIONS(2393),
    [anon_sym___thread] = ACTIONS(2393),
    [anon_sym_const] = ACTIONS(2393),
    [anon_sym_constexpr] = ACTIONS(2393),
    [anon_sym_volatile] = ACTIONS(2393),
    [anon_sym_restrict] = ACTIONS(2393),
    [anon_sym___restrict__] = ACTIONS(2393),
    [anon_sym__Atomic] = ACTIONS(2393),
    [anon_sym__Noreturn] = ACTIONS(2393),
    [anon_sym_noreturn] = ACTIONS(2393),
    [anon_sym_mutable] = ACTIONS(2393),
    [anon_sym_constinit] = ACTIONS(2393),
    [anon_sym_consteval] = ACTIONS(2393),
    [anon_sym_alignas] = ACTIONS(2393),
    [anon_sym__Alignas] = ACTIONS(2393),
    [sym_primitive_type] = ACTIONS(2393),
    [anon_sym_enum] = ACTIONS(2393),
    [anon_sym_class] = ACTIONS(2393),
    [anon_sym_struct] = ACTIONS(2393),
    [anon_sym_union] = ACTIONS(2393),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2393),
    [anon_sym_decltype] = ACTIONS(2393),
    [sym_virtual] = ACTIONS(2393),
    [anon_sym_explicit] = ACTIONS(2393),
    [anon_sym_typename] = ACTIONS(2393),
    [anon_sym_template] = ACTIONS(2393),
    [anon_sym_operator] = ACTIONS(2393),
    [anon_sym_friend] = ACTIONS(2393),
    [anon_sym_public] = ACTIONS(2393),
    [anon_sym_private] = ACTIONS(2393),
    [anon_sym_protected] = ACTIONS(2393),
    [anon_sym_using] = ACTIONS(2393),
    [anon_sym_static_assert] = ACTIONS(2393),
    [anon_sym_precise] = ACTIONS(2393),
    [anon_sym_shared] = ACTIONS(2393),
    [anon_sym_groupshared] = ACTIONS(2393),
    [anon_sym_uniform] = ACTIONS(2393),
    [anon_sym_row_major] = ACTIONS(2393),
    [anon_sym_column_major] = ACTIONS(2393),
    [anon_sym_globallycoherent] = ACTIONS(2393),
    [anon_sym_centroid] = ACTIONS(2393),
    [anon_sym_noperspective] = ACTIONS(2393),
    [anon_sym_nointerpolation] = ACTIONS(2393),
    [anon_sym_sample] = ACTIONS(2393),
    [anon_sym_linear] = ACTIONS(2393),
    [anon_sym_snorm] = ACTIONS(2393),
    [anon_sym_unorm] = ACTIONS(2393),
    [anon_sym_point] = ACTIONS(2393),
    [anon_sym_line] = ACTIONS(2393),
    [anon_sym_triangleadj] = ACTIONS(2393),
    [anon_sym_lineadj] = ACTIONS(2393),
    [anon_sym_triangle] = ACTIONS(2393),
  },
  [2112] = {
    [sym_identifier] = ACTIONS(2540),
    [aux_sym_preproc_def_token1] = ACTIONS(2540),
    [aux_sym_preproc_if_token1] = ACTIONS(2540),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2540),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2540),
    [sym_preproc_directive] = ACTIONS(2540),
    [anon_sym_LPAREN2] = ACTIONS(2542),
    [anon_sym_TILDE] = ACTIONS(2542),
    [anon_sym_STAR] = ACTIONS(2542),
    [anon_sym_AMP_AMP] = ACTIONS(2542),
    [anon_sym_AMP] = ACTIONS(2540),
    [anon_sym___extension__] = ACTIONS(2540),
    [anon_sym_typedef] = ACTIONS(2540),
    [anon_sym_in] = ACTIONS(2540),
    [anon_sym_out] = ACTIONS(2540),
    [anon_sym_inout] = ACTIONS(2540),
    [anon_sym_extern] = ACTIONS(2540),
    [anon_sym___attribute__] = ACTIONS(2540),
    [anon_sym_COLON_COLON] = ACTIONS(2542),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2542),
    [anon_sym___declspec] = ACTIONS(2540),
    [anon_sym___based] = ACTIONS(2540),
    [anon_sym_RBRACE] = ACTIONS(2542),
    [anon_sym_signed] = ACTIONS(2540),
    [anon_sym_unsigned] = ACTIONS(2540),
    [anon_sym_long] = ACTIONS(2540),
    [anon_sym_short] = ACTIONS(2540),
    [anon_sym_LBRACK] = ACTIONS(2540),
    [anon_sym_static] = ACTIONS(2540),
    [anon_sym_register] = ACTIONS(2540),
    [anon_sym_inline] = ACTIONS(2540),
    [anon_sym___inline] = ACTIONS(2540),
    [anon_sym___inline__] = ACTIONS(2540),
    [anon_sym___forceinline] = ACTIONS(2540),
    [anon_sym_thread_local] = ACTIONS(2540),
    [anon_sym___thread] = ACTIONS(2540),
    [anon_sym_const] = ACTIONS(2540),
    [anon_sym_constexpr] = ACTIONS(2540),
    [anon_sym_volatile] = ACTIONS(2540),
    [anon_sym_restrict] = ACTIONS(2540),
    [anon_sym___restrict__] = ACTIONS(2540),
    [anon_sym__Atomic] = ACTIONS(2540),
    [anon_sym__Noreturn] = ACTIONS(2540),
    [anon_sym_noreturn] = ACTIONS(2540),
    [anon_sym_mutable] = ACTIONS(2540),
    [anon_sym_constinit] = ACTIONS(2540),
    [anon_sym_consteval] = ACTIONS(2540),
    [anon_sym_alignas] = ACTIONS(2540),
    [anon_sym__Alignas] = ACTIONS(2540),
    [sym_primitive_type] = ACTIONS(2540),
    [anon_sym_enum] = ACTIONS(2540),
    [anon_sym_class] = ACTIONS(2540),
    [anon_sym_struct] = ACTIONS(2540),
    [anon_sym_union] = ACTIONS(2540),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2540),
    [anon_sym_decltype] = ACTIONS(2540),
    [sym_virtual] = ACTIONS(2540),
    [anon_sym_explicit] = ACTIONS(2540),
    [anon_sym_typename] = ACTIONS(2540),
    [anon_sym_template] = ACTIONS(2540),
    [anon_sym_operator] = ACTIONS(2540),
    [anon_sym_friend] = ACTIONS(2540),
    [anon_sym_public] = ACTIONS(2540),
    [anon_sym_private] = ACTIONS(2540),
    [anon_sym_protected] = ACTIONS(2540),
    [anon_sym_using] = ACTIONS(2540),
    [anon_sym_static_assert] = ACTIONS(2540),
    [anon_sym_precise] = ACTIONS(2540),
    [anon_sym_shared] = ACTIONS(2540),
    [anon_sym_groupshared] = ACTIONS(2540),
    [anon_sym_uniform] = ACTIONS(2540),
    [anon_sym_row_major] = ACTIONS(2540),
    [anon_sym_column_major] = ACTIONS(2540),
    [anon_sym_globallycoherent] = ACTIONS(2540),
    [anon_sym_centroid] = ACTIONS(2540),
    [anon_sym_noperspective] = ACTIONS(2540),
    [anon_sym_nointerpolation] = ACTIONS(2540),
    [anon_sym_sample] = ACTIONS(2540),
    [anon_sym_linear] = ACTIONS(2540),
    [anon_sym_snorm] = ACTIONS(2540),
    [anon_sym_unorm] = ACTIONS(2540),
    [anon_sym_point] = ACTIONS(2540),
    [anon_sym_line] = ACTIONS(2540),
    [anon_sym_triangleadj] = ACTIONS(2540),
    [anon_sym_lineadj] = ACTIONS(2540),
    [anon_sym_triangle] = ACTIONS(2540),
  },
  [2113] = {
    [sym_identifier] = ACTIONS(2454),
    [aux_sym_preproc_def_token1] = ACTIONS(2454),
    [aux_sym_preproc_if_token1] = ACTIONS(2454),
    [aux_sym_preproc_if_token2] = ACTIONS(2454),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2454),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2454),
    [sym_preproc_directive] = ACTIONS(2454),
    [anon_sym_LPAREN2] = ACTIONS(2456),
    [anon_sym_TILDE] = ACTIONS(2456),
    [anon_sym_STAR] = ACTIONS(2456),
    [anon_sym_AMP_AMP] = ACTIONS(2456),
    [anon_sym_AMP] = ACTIONS(2454),
    [anon_sym___extension__] = ACTIONS(2454),
    [anon_sym_typedef] = ACTIONS(2454),
    [anon_sym_in] = ACTIONS(2454),
    [anon_sym_out] = ACTIONS(2454),
    [anon_sym_inout] = ACTIONS(2454),
    [anon_sym_extern] = ACTIONS(2454),
    [anon_sym___attribute__] = ACTIONS(2454),
    [anon_sym_COLON_COLON] = ACTIONS(2456),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2456),
    [anon_sym___declspec] = ACTIONS(2454),
    [anon_sym___based] = ACTIONS(2454),
    [anon_sym_signed] = ACTIONS(2454),
    [anon_sym_unsigned] = ACTIONS(2454),
    [anon_sym_long] = ACTIONS(2454),
    [anon_sym_short] = ACTIONS(2454),
    [anon_sym_LBRACK] = ACTIONS(2454),
    [anon_sym_static] = ACTIONS(2454),
    [anon_sym_register] = ACTIONS(2454),
    [anon_sym_inline] = ACTIONS(2454),
    [anon_sym___inline] = ACTIONS(2454),
    [anon_sym___inline__] = ACTIONS(2454),
    [anon_sym___forceinline] = ACTIONS(2454),
    [anon_sym_thread_local] = ACTIONS(2454),
    [anon_sym___thread] = ACTIONS(2454),
    [anon_sym_const] = ACTIONS(2454),
    [anon_sym_constexpr] = ACTIONS(2454),
    [anon_sym_volatile] = ACTIONS(2454),
    [anon_sym_restrict] = ACTIONS(2454),
    [anon_sym___restrict__] = ACTIONS(2454),
    [anon_sym__Atomic] = ACTIONS(2454),
    [anon_sym__Noreturn] = ACTIONS(2454),
    [anon_sym_noreturn] = ACTIONS(2454),
    [anon_sym_mutable] = ACTIONS(2454),
    [anon_sym_constinit] = ACTIONS(2454),
    [anon_sym_consteval] = ACTIONS(2454),
    [anon_sym_alignas] = ACTIONS(2454),
    [anon_sym__Alignas] = ACTIONS(2454),
    [sym_primitive_type] = ACTIONS(2454),
    [anon_sym_enum] = ACTIONS(2454),
    [anon_sym_class] = ACTIONS(2454),
    [anon_sym_struct] = ACTIONS(2454),
    [anon_sym_union] = ACTIONS(2454),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2454),
    [anon_sym_decltype] = ACTIONS(2454),
    [sym_virtual] = ACTIONS(2454),
    [anon_sym_explicit] = ACTIONS(2454),
    [anon_sym_typename] = ACTIONS(2454),
    [anon_sym_template] = ACTIONS(2454),
    [anon_sym_operator] = ACTIONS(2454),
    [anon_sym_friend] = ACTIONS(2454),
    [anon_sym_public] = ACTIONS(2454),
    [anon_sym_private] = ACTIONS(2454),
    [anon_sym_protected] = ACTIONS(2454),
    [anon_sym_using] = ACTIONS(2454),
    [anon_sym_static_assert] = ACTIONS(2454),
    [anon_sym_precise] = ACTIONS(2454),
    [anon_sym_shared] = ACTIONS(2454),
    [anon_sym_groupshared] = ACTIONS(2454),
    [anon_sym_uniform] = ACTIONS(2454),
    [anon_sym_row_major] = ACTIONS(2454),
    [anon_sym_column_major] = ACTIONS(2454),
    [anon_sym_globallycoherent] = ACTIONS(2454),
    [anon_sym_centroid] = ACTIONS(2454),
    [anon_sym_noperspective] = ACTIONS(2454),
    [anon_sym_nointerpolation] = ACTIONS(2454),
    [anon_sym_sample] = ACTIONS(2454),
    [anon_sym_linear] = ACTIONS(2454),
    [anon_sym_snorm] = ACTIONS(2454),
    [anon_sym_unorm] = ACTIONS(2454),
    [anon_sym_point] = ACTIONS(2454),
    [anon_sym_line] = ACTIONS(2454),
    [anon_sym_triangleadj] = ACTIONS(2454),
    [anon_sym_lineadj] = ACTIONS(2454),
    [anon_sym_triangle] = ACTIONS(2454),
  },
  [2114] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token2] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_friend] = ACTIONS(2332),
    [anon_sym_public] = ACTIONS(2332),
    [anon_sym_private] = ACTIONS(2332),
    [anon_sym_protected] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
  },
  [2115] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token2] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_friend] = ACTIONS(2332),
    [anon_sym_public] = ACTIONS(2332),
    [anon_sym_private] = ACTIONS(2332),
    [anon_sym_protected] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
  },
  [2116] = {
    [sym_identifier] = ACTIONS(2328),
    [aux_sym_preproc_def_token1] = ACTIONS(2328),
    [aux_sym_preproc_if_token1] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2328),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2328),
    [sym_preproc_directive] = ACTIONS(2328),
    [anon_sym_LPAREN2] = ACTIONS(2330),
    [anon_sym_TILDE] = ACTIONS(2330),
    [anon_sym_STAR] = ACTIONS(2330),
    [anon_sym_AMP_AMP] = ACTIONS(2330),
    [anon_sym_AMP] = ACTIONS(2328),
    [anon_sym___extension__] = ACTIONS(2328),
    [anon_sym_typedef] = ACTIONS(2328),
    [anon_sym_in] = ACTIONS(2328),
    [anon_sym_out] = ACTIONS(2328),
    [anon_sym_inout] = ACTIONS(2328),
    [anon_sym_extern] = ACTIONS(2328),
    [anon_sym___attribute__] = ACTIONS(2328),
    [anon_sym_COLON_COLON] = ACTIONS(2330),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2330),
    [anon_sym___declspec] = ACTIONS(2328),
    [anon_sym___based] = ACTIONS(2328),
    [anon_sym_RBRACE] = ACTIONS(2330),
    [anon_sym_signed] = ACTIONS(2328),
    [anon_sym_unsigned] = ACTIONS(2328),
    [anon_sym_long] = ACTIONS(2328),
    [anon_sym_short] = ACTIONS(2328),
    [anon_sym_LBRACK] = ACTIONS(2328),
    [anon_sym_static] = ACTIONS(2328),
    [anon_sym_register] = ACTIONS(2328),
    [anon_sym_inline] = ACTIONS(2328),
    [anon_sym___inline] = ACTIONS(2328),
    [anon_sym___inline__] = ACTIONS(2328),
    [anon_sym___forceinline] = ACTIONS(2328),
    [anon_sym_thread_local] = ACTIONS(2328),
    [anon_sym___thread] = ACTIONS(2328),
    [anon_sym_const] = ACTIONS(2328),
    [anon_sym_constexpr] = ACTIONS(2328),
    [anon_sym_volatile] = ACTIONS(2328),
    [anon_sym_restrict] = ACTIONS(2328),
    [anon_sym___restrict__] = ACTIONS(2328),
    [anon_sym__Atomic] = ACTIONS(2328),
    [anon_sym__Noreturn] = ACTIONS(2328),
    [anon_sym_noreturn] = ACTIONS(2328),
    [anon_sym_mutable] = ACTIONS(2328),
    [anon_sym_constinit] = ACTIONS(2328),
    [anon_sym_consteval] = ACTIONS(2328),
    [anon_sym_alignas] = ACTIONS(2328),
    [anon_sym__Alignas] = ACTIONS(2328),
    [sym_primitive_type] = ACTIONS(2328),
    [anon_sym_enum] = ACTIONS(2328),
    [anon_sym_class] = ACTIONS(2328),
    [anon_sym_struct] = ACTIONS(2328),
    [anon_sym_union] = ACTIONS(2328),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2328),
    [anon_sym_decltype] = ACTIONS(2328),
    [sym_virtual] = ACTIONS(2328),
    [anon_sym_explicit] = ACTIONS(2328),
    [anon_sym_typename] = ACTIONS(2328),
    [anon_sym_template] = ACTIONS(2328),
    [anon_sym_operator] = ACTIONS(2328),
    [anon_sym_friend] = ACTIONS(2328),
    [anon_sym_public] = ACTIONS(2328),
    [anon_sym_private] = ACTIONS(2328),
    [anon_sym_protected] = ACTIONS(2328),
    [anon_sym_using] = ACTIONS(2328),
    [anon_sym_static_assert] = ACTIONS(2328),
    [anon_sym_precise] = ACTIONS(2328),
    [anon_sym_shared] = ACTIONS(2328),
    [anon_sym_groupshared] = ACTIONS(2328),
    [anon_sym_uniform] = ACTIONS(2328),
    [anon_sym_row_major] = ACTIONS(2328),
    [anon_sym_column_major] = ACTIONS(2328),
    [anon_sym_globallycoherent] = ACTIONS(2328),
    [anon_sym_centroid] = ACTIONS(2328),
    [anon_sym_noperspective] = ACTIONS(2328),
    [anon_sym_nointerpolation] = ACTIONS(2328),
    [anon_sym_sample] = ACTIONS(2328),
    [anon_sym_linear] = ACTIONS(2328),
    [anon_sym_snorm] = ACTIONS(2328),
    [anon_sym_unorm] = ACTIONS(2328),
    [anon_sym_point] = ACTIONS(2328),
    [anon_sym_line] = ACTIONS(2328),
    [anon_sym_triangleadj] = ACTIONS(2328),
    [anon_sym_lineadj] = ACTIONS(2328),
    [anon_sym_triangle] = ACTIONS(2328),
  },
  [2117] = {
    [sym_identifier] = ACTIONS(2360),
    [aux_sym_preproc_def_token1] = ACTIONS(2360),
    [aux_sym_preproc_if_token1] = ACTIONS(2360),
    [aux_sym_preproc_if_token2] = ACTIONS(2360),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2360),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2360),
    [sym_preproc_directive] = ACTIONS(2360),
    [anon_sym_LPAREN2] = ACTIONS(2362),
    [anon_sym_TILDE] = ACTIONS(2362),
    [anon_sym_STAR] = ACTIONS(2362),
    [anon_sym_AMP_AMP] = ACTIONS(2362),
    [anon_sym_AMP] = ACTIONS(2360),
    [anon_sym___extension__] = ACTIONS(2360),
    [anon_sym_typedef] = ACTIONS(2360),
    [anon_sym_in] = ACTIONS(2360),
    [anon_sym_out] = ACTIONS(2360),
    [anon_sym_inout] = ACTIONS(2360),
    [anon_sym_extern] = ACTIONS(2360),
    [anon_sym___attribute__] = ACTIONS(2360),
    [anon_sym_COLON_COLON] = ACTIONS(2362),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2362),
    [anon_sym___declspec] = ACTIONS(2360),
    [anon_sym___based] = ACTIONS(2360),
    [anon_sym_signed] = ACTIONS(2360),
    [anon_sym_unsigned] = ACTIONS(2360),
    [anon_sym_long] = ACTIONS(2360),
    [anon_sym_short] = ACTIONS(2360),
    [anon_sym_LBRACK] = ACTIONS(2360),
    [anon_sym_static] = ACTIONS(2360),
    [anon_sym_register] = ACTIONS(2360),
    [anon_sym_inline] = ACTIONS(2360),
    [anon_sym___inline] = ACTIONS(2360),
    [anon_sym___inline__] = ACTIONS(2360),
    [anon_sym___forceinline] = ACTIONS(2360),
    [anon_sym_thread_local] = ACTIONS(2360),
    [anon_sym___thread] = ACTIONS(2360),
    [anon_sym_const] = ACTIONS(2360),
    [anon_sym_constexpr] = ACTIONS(2360),
    [anon_sym_volatile] = ACTIONS(2360),
    [anon_sym_restrict] = ACTIONS(2360),
    [anon_sym___restrict__] = ACTIONS(2360),
    [anon_sym__Atomic] = ACTIONS(2360),
    [anon_sym__Noreturn] = ACTIONS(2360),
    [anon_sym_noreturn] = ACTIONS(2360),
    [anon_sym_mutable] = ACTIONS(2360),
    [anon_sym_constinit] = ACTIONS(2360),
    [anon_sym_consteval] = ACTIONS(2360),
    [anon_sym_alignas] = ACTIONS(2360),
    [anon_sym__Alignas] = ACTIONS(2360),
    [sym_primitive_type] = ACTIONS(2360),
    [anon_sym_enum] = ACTIONS(2360),
    [anon_sym_class] = ACTIONS(2360),
    [anon_sym_struct] = ACTIONS(2360),
    [anon_sym_union] = ACTIONS(2360),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2360),
    [anon_sym_decltype] = ACTIONS(2360),
    [sym_virtual] = ACTIONS(2360),
    [anon_sym_explicit] = ACTIONS(2360),
    [anon_sym_typename] = ACTIONS(2360),
    [anon_sym_template] = ACTIONS(2360),
    [anon_sym_operator] = ACTIONS(2360),
    [anon_sym_friend] = ACTIONS(2360),
    [anon_sym_public] = ACTIONS(2360),
    [anon_sym_private] = ACTIONS(2360),
    [anon_sym_protected] = ACTIONS(2360),
    [anon_sym_using] = ACTIONS(2360),
    [anon_sym_static_assert] = ACTIONS(2360),
    [anon_sym_precise] = ACTIONS(2360),
    [anon_sym_shared] = ACTIONS(2360),
    [anon_sym_groupshared] = ACTIONS(2360),
    [anon_sym_uniform] = ACTIONS(2360),
    [anon_sym_row_major] = ACTIONS(2360),
    [anon_sym_column_major] = ACTIONS(2360),
    [anon_sym_globallycoherent] = ACTIONS(2360),
    [anon_sym_centroid] = ACTIONS(2360),
    [anon_sym_noperspective] = ACTIONS(2360),
    [anon_sym_nointerpolation] = ACTIONS(2360),
    [anon_sym_sample] = ACTIONS(2360),
    [anon_sym_linear] = ACTIONS(2360),
    [anon_sym_snorm] = ACTIONS(2360),
    [anon_sym_unorm] = ACTIONS(2360),
    [anon_sym_point] = ACTIONS(2360),
    [anon_sym_line] = ACTIONS(2360),
    [anon_sym_triangleadj] = ACTIONS(2360),
    [anon_sym_lineadj] = ACTIONS(2360),
    [anon_sym_triangle] = ACTIONS(2360),
  },
  [2118] = {
    [sym_identifier] = ACTIONS(2389),
    [aux_sym_preproc_def_token1] = ACTIONS(2389),
    [aux_sym_preproc_if_token1] = ACTIONS(2389),
    [aux_sym_preproc_if_token2] = ACTIONS(2389),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2389),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2389),
    [sym_preproc_directive] = ACTIONS(2389),
    [anon_sym_LPAREN2] = ACTIONS(2391),
    [anon_sym_TILDE] = ACTIONS(2391),
    [anon_sym_STAR] = ACTIONS(2391),
    [anon_sym_AMP_AMP] = ACTIONS(2391),
    [anon_sym_AMP] = ACTIONS(2389),
    [anon_sym___extension__] = ACTIONS(2389),
    [anon_sym_typedef] = ACTIONS(2389),
    [anon_sym_in] = ACTIONS(2389),
    [anon_sym_out] = ACTIONS(2389),
    [anon_sym_inout] = ACTIONS(2389),
    [anon_sym_extern] = ACTIONS(2389),
    [anon_sym___attribute__] = ACTIONS(2389),
    [anon_sym_COLON_COLON] = ACTIONS(2391),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2391),
    [anon_sym___declspec] = ACTIONS(2389),
    [anon_sym___based] = ACTIONS(2389),
    [anon_sym_signed] = ACTIONS(2389),
    [anon_sym_unsigned] = ACTIONS(2389),
    [anon_sym_long] = ACTIONS(2389),
    [anon_sym_short] = ACTIONS(2389),
    [anon_sym_LBRACK] = ACTIONS(2389),
    [anon_sym_static] = ACTIONS(2389),
    [anon_sym_register] = ACTIONS(2389),
    [anon_sym_inline] = ACTIONS(2389),
    [anon_sym___inline] = ACTIONS(2389),
    [anon_sym___inline__] = ACTIONS(2389),
    [anon_sym___forceinline] = ACTIONS(2389),
    [anon_sym_thread_local] = ACTIONS(2389),
    [anon_sym___thread] = ACTIONS(2389),
    [anon_sym_const] = ACTIONS(2389),
    [anon_sym_constexpr] = ACTIONS(2389),
    [anon_sym_volatile] = ACTIONS(2389),
    [anon_sym_restrict] = ACTIONS(2389),
    [anon_sym___restrict__] = ACTIONS(2389),
    [anon_sym__Atomic] = ACTIONS(2389),
    [anon_sym__Noreturn] = ACTIONS(2389),
    [anon_sym_noreturn] = ACTIONS(2389),
    [anon_sym_mutable] = ACTIONS(2389),
    [anon_sym_constinit] = ACTIONS(2389),
    [anon_sym_consteval] = ACTIONS(2389),
    [anon_sym_alignas] = ACTIONS(2389),
    [anon_sym__Alignas] = ACTIONS(2389),
    [sym_primitive_type] = ACTIONS(2389),
    [anon_sym_enum] = ACTIONS(2389),
    [anon_sym_class] = ACTIONS(2389),
    [anon_sym_struct] = ACTIONS(2389),
    [anon_sym_union] = ACTIONS(2389),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2389),
    [anon_sym_decltype] = ACTIONS(2389),
    [sym_virtual] = ACTIONS(2389),
    [anon_sym_explicit] = ACTIONS(2389),
    [anon_sym_typename] = ACTIONS(2389),
    [anon_sym_template] = ACTIONS(2389),
    [anon_sym_operator] = ACTIONS(2389),
    [anon_sym_friend] = ACTIONS(2389),
    [anon_sym_public] = ACTIONS(2389),
    [anon_sym_private] = ACTIONS(2389),
    [anon_sym_protected] = ACTIONS(2389),
    [anon_sym_using] = ACTIONS(2389),
    [anon_sym_static_assert] = ACTIONS(2389),
    [anon_sym_precise] = ACTIONS(2389),
    [anon_sym_shared] = ACTIONS(2389),
    [anon_sym_groupshared] = ACTIONS(2389),
    [anon_sym_uniform] = ACTIONS(2389),
    [anon_sym_row_major] = ACTIONS(2389),
    [anon_sym_column_major] = ACTIONS(2389),
    [anon_sym_globallycoherent] = ACTIONS(2389),
    [anon_sym_centroid] = ACTIONS(2389),
    [anon_sym_noperspective] = ACTIONS(2389),
    [anon_sym_nointerpolation] = ACTIONS(2389),
    [anon_sym_sample] = ACTIONS(2389),
    [anon_sym_linear] = ACTIONS(2389),
    [anon_sym_snorm] = ACTIONS(2389),
    [anon_sym_unorm] = ACTIONS(2389),
    [anon_sym_point] = ACTIONS(2389),
    [anon_sym_line] = ACTIONS(2389),
    [anon_sym_triangleadj] = ACTIONS(2389),
    [anon_sym_lineadj] = ACTIONS(2389),
    [anon_sym_triangle] = ACTIONS(2389),
  },
  [2119] = {
    [sym_identifier] = ACTIONS(5001),
    [aux_sym_preproc_def_token1] = ACTIONS(5001),
    [aux_sym_preproc_if_token1] = ACTIONS(5001),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5001),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5001),
    [sym_preproc_directive] = ACTIONS(5001),
    [anon_sym_LPAREN2] = ACTIONS(5003),
    [anon_sym_TILDE] = ACTIONS(5003),
    [anon_sym_STAR] = ACTIONS(5003),
    [anon_sym_AMP_AMP] = ACTIONS(5003),
    [anon_sym_AMP] = ACTIONS(5001),
    [anon_sym___extension__] = ACTIONS(5001),
    [anon_sym_typedef] = ACTIONS(5001),
    [anon_sym_in] = ACTIONS(5001),
    [anon_sym_out] = ACTIONS(5001),
    [anon_sym_inout] = ACTIONS(5001),
    [anon_sym_extern] = ACTIONS(5001),
    [anon_sym___attribute__] = ACTIONS(5001),
    [anon_sym_COLON_COLON] = ACTIONS(5003),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5003),
    [anon_sym___declspec] = ACTIONS(5001),
    [anon_sym___based] = ACTIONS(5001),
    [anon_sym_RBRACE] = ACTIONS(5003),
    [anon_sym_signed] = ACTIONS(5001),
    [anon_sym_unsigned] = ACTIONS(5001),
    [anon_sym_long] = ACTIONS(5001),
    [anon_sym_short] = ACTIONS(5001),
    [anon_sym_LBRACK] = ACTIONS(5001),
    [anon_sym_static] = ACTIONS(5001),
    [anon_sym_register] = ACTIONS(5001),
    [anon_sym_inline] = ACTIONS(5001),
    [anon_sym___inline] = ACTIONS(5001),
    [anon_sym___inline__] = ACTIONS(5001),
    [anon_sym___forceinline] = ACTIONS(5001),
    [anon_sym_thread_local] = ACTIONS(5001),
    [anon_sym___thread] = ACTIONS(5001),
    [anon_sym_const] = ACTIONS(5001),
    [anon_sym_constexpr] = ACTIONS(5001),
    [anon_sym_volatile] = ACTIONS(5001),
    [anon_sym_restrict] = ACTIONS(5001),
    [anon_sym___restrict__] = ACTIONS(5001),
    [anon_sym__Atomic] = ACTIONS(5001),
    [anon_sym__Noreturn] = ACTIONS(5001),
    [anon_sym_noreturn] = ACTIONS(5001),
    [anon_sym_mutable] = ACTIONS(5001),
    [anon_sym_constinit] = ACTIONS(5001),
    [anon_sym_consteval] = ACTIONS(5001),
    [anon_sym_alignas] = ACTIONS(5001),
    [anon_sym__Alignas] = ACTIONS(5001),
    [sym_primitive_type] = ACTIONS(5001),
    [anon_sym_enum] = ACTIONS(5001),
    [anon_sym_class] = ACTIONS(5001),
    [anon_sym_struct] = ACTIONS(5001),
    [anon_sym_union] = ACTIONS(5001),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5001),
    [anon_sym_decltype] = ACTIONS(5001),
    [sym_virtual] = ACTIONS(5001),
    [anon_sym_explicit] = ACTIONS(5001),
    [anon_sym_typename] = ACTIONS(5001),
    [anon_sym_template] = ACTIONS(5001),
    [anon_sym_operator] = ACTIONS(5001),
    [anon_sym_friend] = ACTIONS(5001),
    [anon_sym_public] = ACTIONS(5001),
    [anon_sym_private] = ACTIONS(5001),
    [anon_sym_protected] = ACTIONS(5001),
    [anon_sym_using] = ACTIONS(5001),
    [anon_sym_static_assert] = ACTIONS(5001),
    [anon_sym_precise] = ACTIONS(5001),
    [anon_sym_shared] = ACTIONS(5001),
    [anon_sym_groupshared] = ACTIONS(5001),
    [anon_sym_uniform] = ACTIONS(5001),
    [anon_sym_row_major] = ACTIONS(5001),
    [anon_sym_column_major] = ACTIONS(5001),
    [anon_sym_globallycoherent] = ACTIONS(5001),
    [anon_sym_centroid] = ACTIONS(5001),
    [anon_sym_noperspective] = ACTIONS(5001),
    [anon_sym_nointerpolation] = ACTIONS(5001),
    [anon_sym_sample] = ACTIONS(5001),
    [anon_sym_linear] = ACTIONS(5001),
    [anon_sym_snorm] = ACTIONS(5001),
    [anon_sym_unorm] = ACTIONS(5001),
    [anon_sym_point] = ACTIONS(5001),
    [anon_sym_line] = ACTIONS(5001),
    [anon_sym_triangleadj] = ACTIONS(5001),
    [anon_sym_lineadj] = ACTIONS(5001),
    [anon_sym_triangle] = ACTIONS(5001),
  },
  [2120] = {
    [sym_identifier] = ACTIONS(5001),
    [aux_sym_preproc_def_token1] = ACTIONS(5001),
    [aux_sym_preproc_if_token1] = ACTIONS(5001),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5001),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5001),
    [sym_preproc_directive] = ACTIONS(5001),
    [anon_sym_LPAREN2] = ACTIONS(5003),
    [anon_sym_TILDE] = ACTIONS(5003),
    [anon_sym_STAR] = ACTIONS(5003),
    [anon_sym_AMP_AMP] = ACTIONS(5003),
    [anon_sym_AMP] = ACTIONS(5001),
    [anon_sym___extension__] = ACTIONS(5001),
    [anon_sym_typedef] = ACTIONS(5001),
    [anon_sym_in] = ACTIONS(5001),
    [anon_sym_out] = ACTIONS(5001),
    [anon_sym_inout] = ACTIONS(5001),
    [anon_sym_extern] = ACTIONS(5001),
    [anon_sym___attribute__] = ACTIONS(5001),
    [anon_sym_COLON_COLON] = ACTIONS(5003),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5003),
    [anon_sym___declspec] = ACTIONS(5001),
    [anon_sym___based] = ACTIONS(5001),
    [anon_sym_RBRACE] = ACTIONS(5003),
    [anon_sym_signed] = ACTIONS(5001),
    [anon_sym_unsigned] = ACTIONS(5001),
    [anon_sym_long] = ACTIONS(5001),
    [anon_sym_short] = ACTIONS(5001),
    [anon_sym_LBRACK] = ACTIONS(5001),
    [anon_sym_static] = ACTIONS(5001),
    [anon_sym_register] = ACTIONS(5001),
    [anon_sym_inline] = ACTIONS(5001),
    [anon_sym___inline] = ACTIONS(5001),
    [anon_sym___inline__] = ACTIONS(5001),
    [anon_sym___forceinline] = ACTIONS(5001),
    [anon_sym_thread_local] = ACTIONS(5001),
    [anon_sym___thread] = ACTIONS(5001),
    [anon_sym_const] = ACTIONS(5001),
    [anon_sym_constexpr] = ACTIONS(5001),
    [anon_sym_volatile] = ACTIONS(5001),
    [anon_sym_restrict] = ACTIONS(5001),
    [anon_sym___restrict__] = ACTIONS(5001),
    [anon_sym__Atomic] = ACTIONS(5001),
    [anon_sym__Noreturn] = ACTIONS(5001),
    [anon_sym_noreturn] = ACTIONS(5001),
    [anon_sym_mutable] = ACTIONS(5001),
    [anon_sym_constinit] = ACTIONS(5001),
    [anon_sym_consteval] = ACTIONS(5001),
    [anon_sym_alignas] = ACTIONS(5001),
    [anon_sym__Alignas] = ACTIONS(5001),
    [sym_primitive_type] = ACTIONS(5001),
    [anon_sym_enum] = ACTIONS(5001),
    [anon_sym_class] = ACTIONS(5001),
    [anon_sym_struct] = ACTIONS(5001),
    [anon_sym_union] = ACTIONS(5001),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5001),
    [anon_sym_decltype] = ACTIONS(5001),
    [sym_virtual] = ACTIONS(5001),
    [anon_sym_explicit] = ACTIONS(5001),
    [anon_sym_typename] = ACTIONS(5001),
    [anon_sym_template] = ACTIONS(5001),
    [anon_sym_operator] = ACTIONS(5001),
    [anon_sym_friend] = ACTIONS(5001),
    [anon_sym_public] = ACTIONS(5001),
    [anon_sym_private] = ACTIONS(5001),
    [anon_sym_protected] = ACTIONS(5001),
    [anon_sym_using] = ACTIONS(5001),
    [anon_sym_static_assert] = ACTIONS(5001),
    [anon_sym_precise] = ACTIONS(5001),
    [anon_sym_shared] = ACTIONS(5001),
    [anon_sym_groupshared] = ACTIONS(5001),
    [anon_sym_uniform] = ACTIONS(5001),
    [anon_sym_row_major] = ACTIONS(5001),
    [anon_sym_column_major] = ACTIONS(5001),
    [anon_sym_globallycoherent] = ACTIONS(5001),
    [anon_sym_centroid] = ACTIONS(5001),
    [anon_sym_noperspective] = ACTIONS(5001),
    [anon_sym_nointerpolation] = ACTIONS(5001),
    [anon_sym_sample] = ACTIONS(5001),
    [anon_sym_linear] = ACTIONS(5001),
    [anon_sym_snorm] = ACTIONS(5001),
    [anon_sym_unorm] = ACTIONS(5001),
    [anon_sym_point] = ACTIONS(5001),
    [anon_sym_line] = ACTIONS(5001),
    [anon_sym_triangleadj] = ACTIONS(5001),
    [anon_sym_lineadj] = ACTIONS(5001),
    [anon_sym_triangle] = ACTIONS(5001),
  },
  [2121] = {
    [sym_identifier] = ACTIONS(5105),
    [aux_sym_preproc_def_token1] = ACTIONS(5105),
    [aux_sym_preproc_if_token1] = ACTIONS(5105),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5105),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5105),
    [sym_preproc_directive] = ACTIONS(5105),
    [anon_sym_LPAREN2] = ACTIONS(5107),
    [anon_sym_TILDE] = ACTIONS(5107),
    [anon_sym_STAR] = ACTIONS(5107),
    [anon_sym_AMP_AMP] = ACTIONS(5107),
    [anon_sym_AMP] = ACTIONS(5105),
    [anon_sym___extension__] = ACTIONS(5105),
    [anon_sym_typedef] = ACTIONS(5105),
    [anon_sym_in] = ACTIONS(5105),
    [anon_sym_out] = ACTIONS(5105),
    [anon_sym_inout] = ACTIONS(5105),
    [anon_sym_extern] = ACTIONS(5105),
    [anon_sym___attribute__] = ACTIONS(5105),
    [anon_sym_COLON_COLON] = ACTIONS(5107),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5107),
    [anon_sym___declspec] = ACTIONS(5105),
    [anon_sym___based] = ACTIONS(5105),
    [anon_sym_RBRACE] = ACTIONS(5107),
    [anon_sym_signed] = ACTIONS(5105),
    [anon_sym_unsigned] = ACTIONS(5105),
    [anon_sym_long] = ACTIONS(5105),
    [anon_sym_short] = ACTIONS(5105),
    [anon_sym_LBRACK] = ACTIONS(5105),
    [anon_sym_static] = ACTIONS(5105),
    [anon_sym_register] = ACTIONS(5105),
    [anon_sym_inline] = ACTIONS(5105),
    [anon_sym___inline] = ACTIONS(5105),
    [anon_sym___inline__] = ACTIONS(5105),
    [anon_sym___forceinline] = ACTIONS(5105),
    [anon_sym_thread_local] = ACTIONS(5105),
    [anon_sym___thread] = ACTIONS(5105),
    [anon_sym_const] = ACTIONS(5105),
    [anon_sym_constexpr] = ACTIONS(5105),
    [anon_sym_volatile] = ACTIONS(5105),
    [anon_sym_restrict] = ACTIONS(5105),
    [anon_sym___restrict__] = ACTIONS(5105),
    [anon_sym__Atomic] = ACTIONS(5105),
    [anon_sym__Noreturn] = ACTIONS(5105),
    [anon_sym_noreturn] = ACTIONS(5105),
    [anon_sym_mutable] = ACTIONS(5105),
    [anon_sym_constinit] = ACTIONS(5105),
    [anon_sym_consteval] = ACTIONS(5105),
    [anon_sym_alignas] = ACTIONS(5105),
    [anon_sym__Alignas] = ACTIONS(5105),
    [sym_primitive_type] = ACTIONS(5105),
    [anon_sym_enum] = ACTIONS(5105),
    [anon_sym_class] = ACTIONS(5105),
    [anon_sym_struct] = ACTIONS(5105),
    [anon_sym_union] = ACTIONS(5105),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5105),
    [anon_sym_decltype] = ACTIONS(5105),
    [sym_virtual] = ACTIONS(5105),
    [anon_sym_explicit] = ACTIONS(5105),
    [anon_sym_typename] = ACTIONS(5105),
    [anon_sym_template] = ACTIONS(5105),
    [anon_sym_operator] = ACTIONS(5105),
    [anon_sym_friend] = ACTIONS(5105),
    [anon_sym_public] = ACTIONS(5105),
    [anon_sym_private] = ACTIONS(5105),
    [anon_sym_protected] = ACTIONS(5105),
    [anon_sym_using] = ACTIONS(5105),
    [anon_sym_static_assert] = ACTIONS(5105),
    [anon_sym_precise] = ACTIONS(5105),
    [anon_sym_shared] = ACTIONS(5105),
    [anon_sym_groupshared] = ACTIONS(5105),
    [anon_sym_uniform] = ACTIONS(5105),
    [anon_sym_row_major] = ACTIONS(5105),
    [anon_sym_column_major] = ACTIONS(5105),
    [anon_sym_globallycoherent] = ACTIONS(5105),
    [anon_sym_centroid] = ACTIONS(5105),
    [anon_sym_noperspective] = ACTIONS(5105),
    [anon_sym_nointerpolation] = ACTIONS(5105),
    [anon_sym_sample] = ACTIONS(5105),
    [anon_sym_linear] = ACTIONS(5105),
    [anon_sym_snorm] = ACTIONS(5105),
    [anon_sym_unorm] = ACTIONS(5105),
    [anon_sym_point] = ACTIONS(5105),
    [anon_sym_line] = ACTIONS(5105),
    [anon_sym_triangleadj] = ACTIONS(5105),
    [anon_sym_lineadj] = ACTIONS(5105),
    [anon_sym_triangle] = ACTIONS(5105),
  },
  [2122] = {
    [sym_identifier] = ACTIONS(2577),
    [aux_sym_preproc_def_token1] = ACTIONS(2577),
    [aux_sym_preproc_if_token1] = ACTIONS(2577),
    [aux_sym_preproc_if_token2] = ACTIONS(2577),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2577),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2577),
    [sym_preproc_directive] = ACTIONS(2577),
    [anon_sym_LPAREN2] = ACTIONS(2579),
    [anon_sym_TILDE] = ACTIONS(2579),
    [anon_sym_STAR] = ACTIONS(2579),
    [anon_sym_AMP_AMP] = ACTIONS(2579),
    [anon_sym_AMP] = ACTIONS(2577),
    [anon_sym___extension__] = ACTIONS(2577),
    [anon_sym_typedef] = ACTIONS(2577),
    [anon_sym_in] = ACTIONS(2577),
    [anon_sym_out] = ACTIONS(2577),
    [anon_sym_inout] = ACTIONS(2577),
    [anon_sym_extern] = ACTIONS(2577),
    [anon_sym___attribute__] = ACTIONS(2577),
    [anon_sym_COLON_COLON] = ACTIONS(2579),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2579),
    [anon_sym___declspec] = ACTIONS(2577),
    [anon_sym___based] = ACTIONS(2577),
    [anon_sym_signed] = ACTIONS(2577),
    [anon_sym_unsigned] = ACTIONS(2577),
    [anon_sym_long] = ACTIONS(2577),
    [anon_sym_short] = ACTIONS(2577),
    [anon_sym_LBRACK] = ACTIONS(2577),
    [anon_sym_static] = ACTIONS(2577),
    [anon_sym_register] = ACTIONS(2577),
    [anon_sym_inline] = ACTIONS(2577),
    [anon_sym___inline] = ACTIONS(2577),
    [anon_sym___inline__] = ACTIONS(2577),
    [anon_sym___forceinline] = ACTIONS(2577),
    [anon_sym_thread_local] = ACTIONS(2577),
    [anon_sym___thread] = ACTIONS(2577),
    [anon_sym_const] = ACTIONS(2577),
    [anon_sym_constexpr] = ACTIONS(2577),
    [anon_sym_volatile] = ACTIONS(2577),
    [anon_sym_restrict] = ACTIONS(2577),
    [anon_sym___restrict__] = ACTIONS(2577),
    [anon_sym__Atomic] = ACTIONS(2577),
    [anon_sym__Noreturn] = ACTIONS(2577),
    [anon_sym_noreturn] = ACTIONS(2577),
    [anon_sym_mutable] = ACTIONS(2577),
    [anon_sym_constinit] = ACTIONS(2577),
    [anon_sym_consteval] = ACTIONS(2577),
    [anon_sym_alignas] = ACTIONS(2577),
    [anon_sym__Alignas] = ACTIONS(2577),
    [sym_primitive_type] = ACTIONS(2577),
    [anon_sym_enum] = ACTIONS(2577),
    [anon_sym_class] = ACTIONS(2577),
    [anon_sym_struct] = ACTIONS(2577),
    [anon_sym_union] = ACTIONS(2577),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2577),
    [anon_sym_decltype] = ACTIONS(2577),
    [sym_virtual] = ACTIONS(2577),
    [anon_sym_explicit] = ACTIONS(2577),
    [anon_sym_typename] = ACTIONS(2577),
    [anon_sym_template] = ACTIONS(2577),
    [anon_sym_operator] = ACTIONS(2577),
    [anon_sym_friend] = ACTIONS(2577),
    [anon_sym_public] = ACTIONS(2577),
    [anon_sym_private] = ACTIONS(2577),
    [anon_sym_protected] = ACTIONS(2577),
    [anon_sym_using] = ACTIONS(2577),
    [anon_sym_static_assert] = ACTIONS(2577),
    [anon_sym_precise] = ACTIONS(2577),
    [anon_sym_shared] = ACTIONS(2577),
    [anon_sym_groupshared] = ACTIONS(2577),
    [anon_sym_uniform] = ACTIONS(2577),
    [anon_sym_row_major] = ACTIONS(2577),
    [anon_sym_column_major] = ACTIONS(2577),
    [anon_sym_globallycoherent] = ACTIONS(2577),
    [anon_sym_centroid] = ACTIONS(2577),
    [anon_sym_noperspective] = ACTIONS(2577),
    [anon_sym_nointerpolation] = ACTIONS(2577),
    [anon_sym_sample] = ACTIONS(2577),
    [anon_sym_linear] = ACTIONS(2577),
    [anon_sym_snorm] = ACTIONS(2577),
    [anon_sym_unorm] = ACTIONS(2577),
    [anon_sym_point] = ACTIONS(2577),
    [anon_sym_line] = ACTIONS(2577),
    [anon_sym_triangleadj] = ACTIONS(2577),
    [anon_sym_lineadj] = ACTIONS(2577),
    [anon_sym_triangle] = ACTIONS(2577),
  },
  [2123] = {
    [sym_identifier] = ACTIONS(2561),
    [aux_sym_preproc_def_token1] = ACTIONS(2561),
    [aux_sym_preproc_if_token1] = ACTIONS(2561),
    [aux_sym_preproc_if_token2] = ACTIONS(2561),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2561),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2561),
    [sym_preproc_directive] = ACTIONS(2561),
    [anon_sym_LPAREN2] = ACTIONS(2563),
    [anon_sym_TILDE] = ACTIONS(2563),
    [anon_sym_STAR] = ACTIONS(2563),
    [anon_sym_AMP_AMP] = ACTIONS(2563),
    [anon_sym_AMP] = ACTIONS(2561),
    [anon_sym___extension__] = ACTIONS(2561),
    [anon_sym_typedef] = ACTIONS(2561),
    [anon_sym_in] = ACTIONS(2561),
    [anon_sym_out] = ACTIONS(2561),
    [anon_sym_inout] = ACTIONS(2561),
    [anon_sym_extern] = ACTIONS(2561),
    [anon_sym___attribute__] = ACTIONS(2561),
    [anon_sym_COLON_COLON] = ACTIONS(2563),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2563),
    [anon_sym___declspec] = ACTIONS(2561),
    [anon_sym___based] = ACTIONS(2561),
    [anon_sym_signed] = ACTIONS(2561),
    [anon_sym_unsigned] = ACTIONS(2561),
    [anon_sym_long] = ACTIONS(2561),
    [anon_sym_short] = ACTIONS(2561),
    [anon_sym_LBRACK] = ACTIONS(2561),
    [anon_sym_static] = ACTIONS(2561),
    [anon_sym_register] = ACTIONS(2561),
    [anon_sym_inline] = ACTIONS(2561),
    [anon_sym___inline] = ACTIONS(2561),
    [anon_sym___inline__] = ACTIONS(2561),
    [anon_sym___forceinline] = ACTIONS(2561),
    [anon_sym_thread_local] = ACTIONS(2561),
    [anon_sym___thread] = ACTIONS(2561),
    [anon_sym_const] = ACTIONS(2561),
    [anon_sym_constexpr] = ACTIONS(2561),
    [anon_sym_volatile] = ACTIONS(2561),
    [anon_sym_restrict] = ACTIONS(2561),
    [anon_sym___restrict__] = ACTIONS(2561),
    [anon_sym__Atomic] = ACTIONS(2561),
    [anon_sym__Noreturn] = ACTIONS(2561),
    [anon_sym_noreturn] = ACTIONS(2561),
    [anon_sym_mutable] = ACTIONS(2561),
    [anon_sym_constinit] = ACTIONS(2561),
    [anon_sym_consteval] = ACTIONS(2561),
    [anon_sym_alignas] = ACTIONS(2561),
    [anon_sym__Alignas] = ACTIONS(2561),
    [sym_primitive_type] = ACTIONS(2561),
    [anon_sym_enum] = ACTIONS(2561),
    [anon_sym_class] = ACTIONS(2561),
    [anon_sym_struct] = ACTIONS(2561),
    [anon_sym_union] = ACTIONS(2561),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2561),
    [anon_sym_decltype] = ACTIONS(2561),
    [sym_virtual] = ACTIONS(2561),
    [anon_sym_explicit] = ACTIONS(2561),
    [anon_sym_typename] = ACTIONS(2561),
    [anon_sym_template] = ACTIONS(2561),
    [anon_sym_operator] = ACTIONS(2561),
    [anon_sym_friend] = ACTIONS(2561),
    [anon_sym_public] = ACTIONS(2561),
    [anon_sym_private] = ACTIONS(2561),
    [anon_sym_protected] = ACTIONS(2561),
    [anon_sym_using] = ACTIONS(2561),
    [anon_sym_static_assert] = ACTIONS(2561),
    [anon_sym_precise] = ACTIONS(2561),
    [anon_sym_shared] = ACTIONS(2561),
    [anon_sym_groupshared] = ACTIONS(2561),
    [anon_sym_uniform] = ACTIONS(2561),
    [anon_sym_row_major] = ACTIONS(2561),
    [anon_sym_column_major] = ACTIONS(2561),
    [anon_sym_globallycoherent] = ACTIONS(2561),
    [anon_sym_centroid] = ACTIONS(2561),
    [anon_sym_noperspective] = ACTIONS(2561),
    [anon_sym_nointerpolation] = ACTIONS(2561),
    [anon_sym_sample] = ACTIONS(2561),
    [anon_sym_linear] = ACTIONS(2561),
    [anon_sym_snorm] = ACTIONS(2561),
    [anon_sym_unorm] = ACTIONS(2561),
    [anon_sym_point] = ACTIONS(2561),
    [anon_sym_line] = ACTIONS(2561),
    [anon_sym_triangleadj] = ACTIONS(2561),
    [anon_sym_lineadj] = ACTIONS(2561),
    [anon_sym_triangle] = ACTIONS(2561),
  },
  [2124] = {
    [sym_identifier] = ACTIONS(5109),
    [aux_sym_preproc_def_token1] = ACTIONS(5109),
    [aux_sym_preproc_if_token1] = ACTIONS(5109),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5109),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5109),
    [sym_preproc_directive] = ACTIONS(5109),
    [anon_sym_LPAREN2] = ACTIONS(5111),
    [anon_sym_TILDE] = ACTIONS(5111),
    [anon_sym_STAR] = ACTIONS(5111),
    [anon_sym_AMP_AMP] = ACTIONS(5111),
    [anon_sym_AMP] = ACTIONS(5109),
    [anon_sym___extension__] = ACTIONS(5109),
    [anon_sym_typedef] = ACTIONS(5109),
    [anon_sym_in] = ACTIONS(5109),
    [anon_sym_out] = ACTIONS(5109),
    [anon_sym_inout] = ACTIONS(5109),
    [anon_sym_extern] = ACTIONS(5109),
    [anon_sym___attribute__] = ACTIONS(5109),
    [anon_sym_COLON_COLON] = ACTIONS(5111),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5111),
    [anon_sym___declspec] = ACTIONS(5109),
    [anon_sym___based] = ACTIONS(5109),
    [anon_sym_RBRACE] = ACTIONS(5111),
    [anon_sym_signed] = ACTIONS(5109),
    [anon_sym_unsigned] = ACTIONS(5109),
    [anon_sym_long] = ACTIONS(5109),
    [anon_sym_short] = ACTIONS(5109),
    [anon_sym_LBRACK] = ACTIONS(5109),
    [anon_sym_static] = ACTIONS(5109),
    [anon_sym_register] = ACTIONS(5109),
    [anon_sym_inline] = ACTIONS(5109),
    [anon_sym___inline] = ACTIONS(5109),
    [anon_sym___inline__] = ACTIONS(5109),
    [anon_sym___forceinline] = ACTIONS(5109),
    [anon_sym_thread_local] = ACTIONS(5109),
    [anon_sym___thread] = ACTIONS(5109),
    [anon_sym_const] = ACTIONS(5109),
    [anon_sym_constexpr] = ACTIONS(5109),
    [anon_sym_volatile] = ACTIONS(5109),
    [anon_sym_restrict] = ACTIONS(5109),
    [anon_sym___restrict__] = ACTIONS(5109),
    [anon_sym__Atomic] = ACTIONS(5109),
    [anon_sym__Noreturn] = ACTIONS(5109),
    [anon_sym_noreturn] = ACTIONS(5109),
    [anon_sym_mutable] = ACTIONS(5109),
    [anon_sym_constinit] = ACTIONS(5109),
    [anon_sym_consteval] = ACTIONS(5109),
    [anon_sym_alignas] = ACTIONS(5109),
    [anon_sym__Alignas] = ACTIONS(5109),
    [sym_primitive_type] = ACTIONS(5109),
    [anon_sym_enum] = ACTIONS(5109),
    [anon_sym_class] = ACTIONS(5109),
    [anon_sym_struct] = ACTIONS(5109),
    [anon_sym_union] = ACTIONS(5109),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5109),
    [anon_sym_decltype] = ACTIONS(5109),
    [sym_virtual] = ACTIONS(5109),
    [anon_sym_explicit] = ACTIONS(5109),
    [anon_sym_typename] = ACTIONS(5109),
    [anon_sym_template] = ACTIONS(5109),
    [anon_sym_operator] = ACTIONS(5109),
    [anon_sym_friend] = ACTIONS(5109),
    [anon_sym_public] = ACTIONS(5109),
    [anon_sym_private] = ACTIONS(5109),
    [anon_sym_protected] = ACTIONS(5109),
    [anon_sym_using] = ACTIONS(5109),
    [anon_sym_static_assert] = ACTIONS(5109),
    [anon_sym_precise] = ACTIONS(5109),
    [anon_sym_shared] = ACTIONS(5109),
    [anon_sym_groupshared] = ACTIONS(5109),
    [anon_sym_uniform] = ACTIONS(5109),
    [anon_sym_row_major] = ACTIONS(5109),
    [anon_sym_column_major] = ACTIONS(5109),
    [anon_sym_globallycoherent] = ACTIONS(5109),
    [anon_sym_centroid] = ACTIONS(5109),
    [anon_sym_noperspective] = ACTIONS(5109),
    [anon_sym_nointerpolation] = ACTIONS(5109),
    [anon_sym_sample] = ACTIONS(5109),
    [anon_sym_linear] = ACTIONS(5109),
    [anon_sym_snorm] = ACTIONS(5109),
    [anon_sym_unorm] = ACTIONS(5109),
    [anon_sym_point] = ACTIONS(5109),
    [anon_sym_line] = ACTIONS(5109),
    [anon_sym_triangleadj] = ACTIONS(5109),
    [anon_sym_lineadj] = ACTIONS(5109),
    [anon_sym_triangle] = ACTIONS(5109),
  },
  [2125] = {
    [sym_identifier] = ACTIONS(2276),
    [aux_sym_preproc_def_token1] = ACTIONS(2276),
    [aux_sym_preproc_if_token1] = ACTIONS(2276),
    [aux_sym_preproc_if_token2] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2276),
    [sym_preproc_directive] = ACTIONS(2276),
    [anon_sym_LPAREN2] = ACTIONS(2278),
    [anon_sym_TILDE] = ACTIONS(2278),
    [anon_sym_STAR] = ACTIONS(2278),
    [anon_sym_AMP_AMP] = ACTIONS(2278),
    [anon_sym_AMP] = ACTIONS(2276),
    [anon_sym___extension__] = ACTIONS(2276),
    [anon_sym_typedef] = ACTIONS(2276),
    [anon_sym_in] = ACTIONS(2276),
    [anon_sym_out] = ACTIONS(2276),
    [anon_sym_inout] = ACTIONS(2276),
    [anon_sym_extern] = ACTIONS(2276),
    [anon_sym___attribute__] = ACTIONS(2276),
    [anon_sym_COLON_COLON] = ACTIONS(2278),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2278),
    [anon_sym___declspec] = ACTIONS(2276),
    [anon_sym___based] = ACTIONS(2276),
    [anon_sym_signed] = ACTIONS(2276),
    [anon_sym_unsigned] = ACTIONS(2276),
    [anon_sym_long] = ACTIONS(2276),
    [anon_sym_short] = ACTIONS(2276),
    [anon_sym_LBRACK] = ACTIONS(2276),
    [anon_sym_static] = ACTIONS(2276),
    [anon_sym_register] = ACTIONS(2276),
    [anon_sym_inline] = ACTIONS(2276),
    [anon_sym___inline] = ACTIONS(2276),
    [anon_sym___inline__] = ACTIONS(2276),
    [anon_sym___forceinline] = ACTIONS(2276),
    [anon_sym_thread_local] = ACTIONS(2276),
    [anon_sym___thread] = ACTIONS(2276),
    [anon_sym_const] = ACTIONS(2276),
    [anon_sym_constexpr] = ACTIONS(2276),
    [anon_sym_volatile] = ACTIONS(2276),
    [anon_sym_restrict] = ACTIONS(2276),
    [anon_sym___restrict__] = ACTIONS(2276),
    [anon_sym__Atomic] = ACTIONS(2276),
    [anon_sym__Noreturn] = ACTIONS(2276),
    [anon_sym_noreturn] = ACTIONS(2276),
    [anon_sym_mutable] = ACTIONS(2276),
    [anon_sym_constinit] = ACTIONS(2276),
    [anon_sym_consteval] = ACTIONS(2276),
    [anon_sym_alignas] = ACTIONS(2276),
    [anon_sym__Alignas] = ACTIONS(2276),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2276),
    [anon_sym_class] = ACTIONS(2276),
    [anon_sym_struct] = ACTIONS(2276),
    [anon_sym_union] = ACTIONS(2276),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2276),
    [anon_sym_decltype] = ACTIONS(2276),
    [sym_virtual] = ACTIONS(2276),
    [anon_sym_explicit] = ACTIONS(2276),
    [anon_sym_typename] = ACTIONS(2276),
    [anon_sym_template] = ACTIONS(2276),
    [anon_sym_operator] = ACTIONS(2276),
    [anon_sym_friend] = ACTIONS(2276),
    [anon_sym_public] = ACTIONS(2276),
    [anon_sym_private] = ACTIONS(2276),
    [anon_sym_protected] = ACTIONS(2276),
    [anon_sym_using] = ACTIONS(2276),
    [anon_sym_static_assert] = ACTIONS(2276),
    [anon_sym_precise] = ACTIONS(2276),
    [anon_sym_shared] = ACTIONS(2276),
    [anon_sym_groupshared] = ACTIONS(2276),
    [anon_sym_uniform] = ACTIONS(2276),
    [anon_sym_row_major] = ACTIONS(2276),
    [anon_sym_column_major] = ACTIONS(2276),
    [anon_sym_globallycoherent] = ACTIONS(2276),
    [anon_sym_centroid] = ACTIONS(2276),
    [anon_sym_noperspective] = ACTIONS(2276),
    [anon_sym_nointerpolation] = ACTIONS(2276),
    [anon_sym_sample] = ACTIONS(2276),
    [anon_sym_linear] = ACTIONS(2276),
    [anon_sym_snorm] = ACTIONS(2276),
    [anon_sym_unorm] = ACTIONS(2276),
    [anon_sym_point] = ACTIONS(2276),
    [anon_sym_line] = ACTIONS(2276),
    [anon_sym_triangleadj] = ACTIONS(2276),
    [anon_sym_lineadj] = ACTIONS(2276),
    [anon_sym_triangle] = ACTIONS(2276),
  },
  [2126] = {
    [sym_identifier] = ACTIONS(2276),
    [aux_sym_preproc_def_token1] = ACTIONS(2276),
    [aux_sym_preproc_if_token1] = ACTIONS(2276),
    [aux_sym_preproc_if_token2] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2276),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2276),
    [sym_preproc_directive] = ACTIONS(2276),
    [anon_sym_LPAREN2] = ACTIONS(2278),
    [anon_sym_TILDE] = ACTIONS(2278),
    [anon_sym_STAR] = ACTIONS(2278),
    [anon_sym_AMP_AMP] = ACTIONS(2278),
    [anon_sym_AMP] = ACTIONS(2276),
    [anon_sym___extension__] = ACTIONS(2276),
    [anon_sym_typedef] = ACTIONS(2276),
    [anon_sym_in] = ACTIONS(2276),
    [anon_sym_out] = ACTIONS(2276),
    [anon_sym_inout] = ACTIONS(2276),
    [anon_sym_extern] = ACTIONS(2276),
    [anon_sym___attribute__] = ACTIONS(2276),
    [anon_sym_COLON_COLON] = ACTIONS(2278),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2278),
    [anon_sym___declspec] = ACTIONS(2276),
    [anon_sym___based] = ACTIONS(2276),
    [anon_sym_signed] = ACTIONS(2276),
    [anon_sym_unsigned] = ACTIONS(2276),
    [anon_sym_long] = ACTIONS(2276),
    [anon_sym_short] = ACTIONS(2276),
    [anon_sym_LBRACK] = ACTIONS(2276),
    [anon_sym_static] = ACTIONS(2276),
    [anon_sym_register] = ACTIONS(2276),
    [anon_sym_inline] = ACTIONS(2276),
    [anon_sym___inline] = ACTIONS(2276),
    [anon_sym___inline__] = ACTIONS(2276),
    [anon_sym___forceinline] = ACTIONS(2276),
    [anon_sym_thread_local] = ACTIONS(2276),
    [anon_sym___thread] = ACTIONS(2276),
    [anon_sym_const] = ACTIONS(2276),
    [anon_sym_constexpr] = ACTIONS(2276),
    [anon_sym_volatile] = ACTIONS(2276),
    [anon_sym_restrict] = ACTIONS(2276),
    [anon_sym___restrict__] = ACTIONS(2276),
    [anon_sym__Atomic] = ACTIONS(2276),
    [anon_sym__Noreturn] = ACTIONS(2276),
    [anon_sym_noreturn] = ACTIONS(2276),
    [anon_sym_mutable] = ACTIONS(2276),
    [anon_sym_constinit] = ACTIONS(2276),
    [anon_sym_consteval] = ACTIONS(2276),
    [anon_sym_alignas] = ACTIONS(2276),
    [anon_sym__Alignas] = ACTIONS(2276),
    [sym_primitive_type] = ACTIONS(2276),
    [anon_sym_enum] = ACTIONS(2276),
    [anon_sym_class] = ACTIONS(2276),
    [anon_sym_struct] = ACTIONS(2276),
    [anon_sym_union] = ACTIONS(2276),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2276),
    [anon_sym_decltype] = ACTIONS(2276),
    [sym_virtual] = ACTIONS(2276),
    [anon_sym_explicit] = ACTIONS(2276),
    [anon_sym_typename] = ACTIONS(2276),
    [anon_sym_template] = ACTIONS(2276),
    [anon_sym_operator] = ACTIONS(2276),
    [anon_sym_friend] = ACTIONS(2276),
    [anon_sym_public] = ACTIONS(2276),
    [anon_sym_private] = ACTIONS(2276),
    [anon_sym_protected] = ACTIONS(2276),
    [anon_sym_using] = ACTIONS(2276),
    [anon_sym_static_assert] = ACTIONS(2276),
    [anon_sym_precise] = ACTIONS(2276),
    [anon_sym_shared] = ACTIONS(2276),
    [anon_sym_groupshared] = ACTIONS(2276),
    [anon_sym_uniform] = ACTIONS(2276),
    [anon_sym_row_major] = ACTIONS(2276),
    [anon_sym_column_major] = ACTIONS(2276),
    [anon_sym_globallycoherent] = ACTIONS(2276),
    [anon_sym_centroid] = ACTIONS(2276),
    [anon_sym_noperspective] = ACTIONS(2276),
    [anon_sym_nointerpolation] = ACTIONS(2276),
    [anon_sym_sample] = ACTIONS(2276),
    [anon_sym_linear] = ACTIONS(2276),
    [anon_sym_snorm] = ACTIONS(2276),
    [anon_sym_unorm] = ACTIONS(2276),
    [anon_sym_point] = ACTIONS(2276),
    [anon_sym_line] = ACTIONS(2276),
    [anon_sym_triangleadj] = ACTIONS(2276),
    [anon_sym_lineadj] = ACTIONS(2276),
    [anon_sym_triangle] = ACTIONS(2276),
  },
  [2127] = {
    [sym_identifier] = ACTIONS(2462),
    [aux_sym_preproc_def_token1] = ACTIONS(2462),
    [aux_sym_preproc_if_token1] = ACTIONS(2462),
    [aux_sym_preproc_if_token2] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2462),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2462),
    [sym_preproc_directive] = ACTIONS(2462),
    [anon_sym_LPAREN2] = ACTIONS(2464),
    [anon_sym_TILDE] = ACTIONS(2464),
    [anon_sym_STAR] = ACTIONS(2464),
    [anon_sym_AMP_AMP] = ACTIONS(2464),
    [anon_sym_AMP] = ACTIONS(2462),
    [anon_sym___extension__] = ACTIONS(2462),
    [anon_sym_typedef] = ACTIONS(2462),
    [anon_sym_in] = ACTIONS(2462),
    [anon_sym_out] = ACTIONS(2462),
    [anon_sym_inout] = ACTIONS(2462),
    [anon_sym_extern] = ACTIONS(2462),
    [anon_sym___attribute__] = ACTIONS(2462),
    [anon_sym_COLON_COLON] = ACTIONS(2464),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2464),
    [anon_sym___declspec] = ACTIONS(2462),
    [anon_sym___based] = ACTIONS(2462),
    [anon_sym_signed] = ACTIONS(2462),
    [anon_sym_unsigned] = ACTIONS(2462),
    [anon_sym_long] = ACTIONS(2462),
    [anon_sym_short] = ACTIONS(2462),
    [anon_sym_LBRACK] = ACTIONS(2462),
    [anon_sym_static] = ACTIONS(2462),
    [anon_sym_register] = ACTIONS(2462),
    [anon_sym_inline] = ACTIONS(2462),
    [anon_sym___inline] = ACTIONS(2462),
    [anon_sym___inline__] = ACTIONS(2462),
    [anon_sym___forceinline] = ACTIONS(2462),
    [anon_sym_thread_local] = ACTIONS(2462),
    [anon_sym___thread] = ACTIONS(2462),
    [anon_sym_const] = ACTIONS(2462),
    [anon_sym_constexpr] = ACTIONS(2462),
    [anon_sym_volatile] = ACTIONS(2462),
    [anon_sym_restrict] = ACTIONS(2462),
    [anon_sym___restrict__] = ACTIONS(2462),
    [anon_sym__Atomic] = ACTIONS(2462),
    [anon_sym__Noreturn] = ACTIONS(2462),
    [anon_sym_noreturn] = ACTIONS(2462),
    [anon_sym_mutable] = ACTIONS(2462),
    [anon_sym_constinit] = ACTIONS(2462),
    [anon_sym_consteval] = ACTIONS(2462),
    [anon_sym_alignas] = ACTIONS(2462),
    [anon_sym__Alignas] = ACTIONS(2462),
    [sym_primitive_type] = ACTIONS(2462),
    [anon_sym_enum] = ACTIONS(2462),
    [anon_sym_class] = ACTIONS(2462),
    [anon_sym_struct] = ACTIONS(2462),
    [anon_sym_union] = ACTIONS(2462),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2462),
    [anon_sym_decltype] = ACTIONS(2462),
    [sym_virtual] = ACTIONS(2462),
    [anon_sym_explicit] = ACTIONS(2462),
    [anon_sym_typename] = ACTIONS(2462),
    [anon_sym_template] = ACTIONS(2462),
    [anon_sym_operator] = ACTIONS(2462),
    [anon_sym_friend] = ACTIONS(2462),
    [anon_sym_public] = ACTIONS(2462),
    [anon_sym_private] = ACTIONS(2462),
    [anon_sym_protected] = ACTIONS(2462),
    [anon_sym_using] = ACTIONS(2462),
    [anon_sym_static_assert] = ACTIONS(2462),
    [anon_sym_precise] = ACTIONS(2462),
    [anon_sym_shared] = ACTIONS(2462),
    [anon_sym_groupshared] = ACTIONS(2462),
    [anon_sym_uniform] = ACTIONS(2462),
    [anon_sym_row_major] = ACTIONS(2462),
    [anon_sym_column_major] = ACTIONS(2462),
    [anon_sym_globallycoherent] = ACTIONS(2462),
    [anon_sym_centroid] = ACTIONS(2462),
    [anon_sym_noperspective] = ACTIONS(2462),
    [anon_sym_nointerpolation] = ACTIONS(2462),
    [anon_sym_sample] = ACTIONS(2462),
    [anon_sym_linear] = ACTIONS(2462),
    [anon_sym_snorm] = ACTIONS(2462),
    [anon_sym_unorm] = ACTIONS(2462),
    [anon_sym_point] = ACTIONS(2462),
    [anon_sym_line] = ACTIONS(2462),
    [anon_sym_triangleadj] = ACTIONS(2462),
    [anon_sym_lineadj] = ACTIONS(2462),
    [anon_sym_triangle] = ACTIONS(2462),
  },
  [2128] = {
    [sym_identifier] = ACTIONS(2134),
    [aux_sym_preproc_def_token1] = ACTIONS(2134),
    [aux_sym_preproc_if_token1] = ACTIONS(2134),
    [aux_sym_preproc_if_token2] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2134),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2134),
    [sym_preproc_directive] = ACTIONS(2134),
    [anon_sym_LPAREN2] = ACTIONS(2136),
    [anon_sym_TILDE] = ACTIONS(2136),
    [anon_sym_STAR] = ACTIONS(2136),
    [anon_sym_AMP_AMP] = ACTIONS(2136),
    [anon_sym_AMP] = ACTIONS(2134),
    [anon_sym___extension__] = ACTIONS(2134),
    [anon_sym_typedef] = ACTIONS(2134),
    [anon_sym_in] = ACTIONS(2134),
    [anon_sym_out] = ACTIONS(2134),
    [anon_sym_inout] = ACTIONS(2134),
    [anon_sym_extern] = ACTIONS(2134),
    [anon_sym___attribute__] = ACTIONS(2134),
    [anon_sym_COLON_COLON] = ACTIONS(2136),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2136),
    [anon_sym___declspec] = ACTIONS(2134),
    [anon_sym___based] = ACTIONS(2134),
    [anon_sym_signed] = ACTIONS(2134),
    [anon_sym_unsigned] = ACTIONS(2134),
    [anon_sym_long] = ACTIONS(2134),
    [anon_sym_short] = ACTIONS(2134),
    [anon_sym_LBRACK] = ACTIONS(2134),
    [anon_sym_static] = ACTIONS(2134),
    [anon_sym_register] = ACTIONS(2134),
    [anon_sym_inline] = ACTIONS(2134),
    [anon_sym___inline] = ACTIONS(2134),
    [anon_sym___inline__] = ACTIONS(2134),
    [anon_sym___forceinline] = ACTIONS(2134),
    [anon_sym_thread_local] = ACTIONS(2134),
    [anon_sym___thread] = ACTIONS(2134),
    [anon_sym_const] = ACTIONS(2134),
    [anon_sym_constexpr] = ACTIONS(2134),
    [anon_sym_volatile] = ACTIONS(2134),
    [anon_sym_restrict] = ACTIONS(2134),
    [anon_sym___restrict__] = ACTIONS(2134),
    [anon_sym__Atomic] = ACTIONS(2134),
    [anon_sym__Noreturn] = ACTIONS(2134),
    [anon_sym_noreturn] = ACTIONS(2134),
    [anon_sym_mutable] = ACTIONS(2134),
    [anon_sym_constinit] = ACTIONS(2134),
    [anon_sym_consteval] = ACTIONS(2134),
    [anon_sym_alignas] = ACTIONS(2134),
    [anon_sym__Alignas] = ACTIONS(2134),
    [sym_primitive_type] = ACTIONS(2134),
    [anon_sym_enum] = ACTIONS(2134),
    [anon_sym_class] = ACTIONS(2134),
    [anon_sym_struct] = ACTIONS(2134),
    [anon_sym_union] = ACTIONS(2134),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2134),
    [anon_sym_decltype] = ACTIONS(2134),
    [sym_virtual] = ACTIONS(2134),
    [anon_sym_explicit] = ACTIONS(2134),
    [anon_sym_typename] = ACTIONS(2134),
    [anon_sym_template] = ACTIONS(2134),
    [anon_sym_operator] = ACTIONS(2134),
    [anon_sym_friend] = ACTIONS(2134),
    [anon_sym_public] = ACTIONS(2134),
    [anon_sym_private] = ACTIONS(2134),
    [anon_sym_protected] = ACTIONS(2134),
    [anon_sym_using] = ACTIONS(2134),
    [anon_sym_static_assert] = ACTIONS(2134),
    [anon_sym_precise] = ACTIONS(2134),
    [anon_sym_shared] = ACTIONS(2134),
    [anon_sym_groupshared] = ACTIONS(2134),
    [anon_sym_uniform] = ACTIONS(2134),
    [anon_sym_row_major] = ACTIONS(2134),
    [anon_sym_column_major] = ACTIONS(2134),
    [anon_sym_globallycoherent] = ACTIONS(2134),
    [anon_sym_centroid] = ACTIONS(2134),
    [anon_sym_noperspective] = ACTIONS(2134),
    [anon_sym_nointerpolation] = ACTIONS(2134),
    [anon_sym_sample] = ACTIONS(2134),
    [anon_sym_linear] = ACTIONS(2134),
    [anon_sym_snorm] = ACTIONS(2134),
    [anon_sym_unorm] = ACTIONS(2134),
    [anon_sym_point] = ACTIONS(2134),
    [anon_sym_line] = ACTIONS(2134),
    [anon_sym_triangleadj] = ACTIONS(2134),
    [anon_sym_lineadj] = ACTIONS(2134),
    [anon_sym_triangle] = ACTIONS(2134),
  },
  [2129] = {
    [sym_identifier] = ACTIONS(2138),
    [aux_sym_preproc_def_token1] = ACTIONS(2138),
    [aux_sym_preproc_if_token1] = ACTIONS(2138),
    [aux_sym_preproc_if_token2] = ACTIONS(2138),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2138),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2138),
    [sym_preproc_directive] = ACTIONS(2138),
    [anon_sym_LPAREN2] = ACTIONS(2140),
    [anon_sym_TILDE] = ACTIONS(2140),
    [anon_sym_STAR] = ACTIONS(2140),
    [anon_sym_AMP_AMP] = ACTIONS(2140),
    [anon_sym_AMP] = ACTIONS(2138),
    [anon_sym___extension__] = ACTIONS(2138),
    [anon_sym_typedef] = ACTIONS(2138),
    [anon_sym_in] = ACTIONS(2138),
    [anon_sym_out] = ACTIONS(2138),
    [anon_sym_inout] = ACTIONS(2138),
    [anon_sym_extern] = ACTIONS(2138),
    [anon_sym___attribute__] = ACTIONS(2138),
    [anon_sym_COLON_COLON] = ACTIONS(2140),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2140),
    [anon_sym___declspec] = ACTIONS(2138),
    [anon_sym___based] = ACTIONS(2138),
    [anon_sym_signed] = ACTIONS(2138),
    [anon_sym_unsigned] = ACTIONS(2138),
    [anon_sym_long] = ACTIONS(2138),
    [anon_sym_short] = ACTIONS(2138),
    [anon_sym_LBRACK] = ACTIONS(2138),
    [anon_sym_static] = ACTIONS(2138),
    [anon_sym_register] = ACTIONS(2138),
    [anon_sym_inline] = ACTIONS(2138),
    [anon_sym___inline] = ACTIONS(2138),
    [anon_sym___inline__] = ACTIONS(2138),
    [anon_sym___forceinline] = ACTIONS(2138),
    [anon_sym_thread_local] = ACTIONS(2138),
    [anon_sym___thread] = ACTIONS(2138),
    [anon_sym_const] = ACTIONS(2138),
    [anon_sym_constexpr] = ACTIONS(2138),
    [anon_sym_volatile] = ACTIONS(2138),
    [anon_sym_restrict] = ACTIONS(2138),
    [anon_sym___restrict__] = ACTIONS(2138),
    [anon_sym__Atomic] = ACTIONS(2138),
    [anon_sym__Noreturn] = ACTIONS(2138),
    [anon_sym_noreturn] = ACTIONS(2138),
    [anon_sym_mutable] = ACTIONS(2138),
    [anon_sym_constinit] = ACTIONS(2138),
    [anon_sym_consteval] = ACTIONS(2138),
    [anon_sym_alignas] = ACTIONS(2138),
    [anon_sym__Alignas] = ACTIONS(2138),
    [sym_primitive_type] = ACTIONS(2138),
    [anon_sym_enum] = ACTIONS(2138),
    [anon_sym_class] = ACTIONS(2138),
    [anon_sym_struct] = ACTIONS(2138),
    [anon_sym_union] = ACTIONS(2138),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2138),
    [anon_sym_decltype] = ACTIONS(2138),
    [sym_virtual] = ACTIONS(2138),
    [anon_sym_explicit] = ACTIONS(2138),
    [anon_sym_typename] = ACTIONS(2138),
    [anon_sym_template] = ACTIONS(2138),
    [anon_sym_operator] = ACTIONS(2138),
    [anon_sym_friend] = ACTIONS(2138),
    [anon_sym_public] = ACTIONS(2138),
    [anon_sym_private] = ACTIONS(2138),
    [anon_sym_protected] = ACTIONS(2138),
    [anon_sym_using] = ACTIONS(2138),
    [anon_sym_static_assert] = ACTIONS(2138),
    [anon_sym_precise] = ACTIONS(2138),
    [anon_sym_shared] = ACTIONS(2138),
    [anon_sym_groupshared] = ACTIONS(2138),
    [anon_sym_uniform] = ACTIONS(2138),
    [anon_sym_row_major] = ACTIONS(2138),
    [anon_sym_column_major] = ACTIONS(2138),
    [anon_sym_globallycoherent] = ACTIONS(2138),
    [anon_sym_centroid] = ACTIONS(2138),
    [anon_sym_noperspective] = ACTIONS(2138),
    [anon_sym_nointerpolation] = ACTIONS(2138),
    [anon_sym_sample] = ACTIONS(2138),
    [anon_sym_linear] = ACTIONS(2138),
    [anon_sym_snorm] = ACTIONS(2138),
    [anon_sym_unorm] = ACTIONS(2138),
    [anon_sym_point] = ACTIONS(2138),
    [anon_sym_line] = ACTIONS(2138),
    [anon_sym_triangleadj] = ACTIONS(2138),
    [anon_sym_lineadj] = ACTIONS(2138),
    [anon_sym_triangle] = ACTIONS(2138),
  },
  [2130] = {
    [sym_identifier] = ACTIONS(2340),
    [aux_sym_preproc_def_token1] = ACTIONS(2340),
    [aux_sym_preproc_if_token1] = ACTIONS(2340),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2340),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2340),
    [sym_preproc_directive] = ACTIONS(2340),
    [anon_sym_LPAREN2] = ACTIONS(2342),
    [anon_sym_TILDE] = ACTIONS(2342),
    [anon_sym_STAR] = ACTIONS(2342),
    [anon_sym_AMP_AMP] = ACTIONS(2342),
    [anon_sym_AMP] = ACTIONS(2340),
    [anon_sym___extension__] = ACTIONS(2340),
    [anon_sym_typedef] = ACTIONS(2340),
    [anon_sym_in] = ACTIONS(2340),
    [anon_sym_out] = ACTIONS(2340),
    [anon_sym_inout] = ACTIONS(2340),
    [anon_sym_extern] = ACTIONS(2340),
    [anon_sym___attribute__] = ACTIONS(2340),
    [anon_sym_COLON_COLON] = ACTIONS(2342),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2342),
    [anon_sym___declspec] = ACTIONS(2340),
    [anon_sym___based] = ACTIONS(2340),
    [anon_sym_RBRACE] = ACTIONS(2342),
    [anon_sym_signed] = ACTIONS(2340),
    [anon_sym_unsigned] = ACTIONS(2340),
    [anon_sym_long] = ACTIONS(2340),
    [anon_sym_short] = ACTIONS(2340),
    [anon_sym_LBRACK] = ACTIONS(2340),
    [anon_sym_static] = ACTIONS(2340),
    [anon_sym_register] = ACTIONS(2340),
    [anon_sym_inline] = ACTIONS(2340),
    [anon_sym___inline] = ACTIONS(2340),
    [anon_sym___inline__] = ACTIONS(2340),
    [anon_sym___forceinline] = ACTIONS(2340),
    [anon_sym_thread_local] = ACTIONS(2340),
    [anon_sym___thread] = ACTIONS(2340),
    [anon_sym_const] = ACTIONS(2340),
    [anon_sym_constexpr] = ACTIONS(2340),
    [anon_sym_volatile] = ACTIONS(2340),
    [anon_sym_restrict] = ACTIONS(2340),
    [anon_sym___restrict__] = ACTIONS(2340),
    [anon_sym__Atomic] = ACTIONS(2340),
    [anon_sym__Noreturn] = ACTIONS(2340),
    [anon_sym_noreturn] = ACTIONS(2340),
    [anon_sym_mutable] = ACTIONS(2340),
    [anon_sym_constinit] = ACTIONS(2340),
    [anon_sym_consteval] = ACTIONS(2340),
    [anon_sym_alignas] = ACTIONS(2340),
    [anon_sym__Alignas] = ACTIONS(2340),
    [sym_primitive_type] = ACTIONS(2340),
    [anon_sym_enum] = ACTIONS(2340),
    [anon_sym_class] = ACTIONS(2340),
    [anon_sym_struct] = ACTIONS(2340),
    [anon_sym_union] = ACTIONS(2340),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2340),
    [anon_sym_decltype] = ACTIONS(2340),
    [sym_virtual] = ACTIONS(2340),
    [anon_sym_explicit] = ACTIONS(2340),
    [anon_sym_typename] = ACTIONS(2340),
    [anon_sym_template] = ACTIONS(2340),
    [anon_sym_operator] = ACTIONS(2340),
    [anon_sym_friend] = ACTIONS(2340),
    [anon_sym_public] = ACTIONS(2340),
    [anon_sym_private] = ACTIONS(2340),
    [anon_sym_protected] = ACTIONS(2340),
    [anon_sym_using] = ACTIONS(2340),
    [anon_sym_static_assert] = ACTIONS(2340),
    [anon_sym_precise] = ACTIONS(2340),
    [anon_sym_shared] = ACTIONS(2340),
    [anon_sym_groupshared] = ACTIONS(2340),
    [anon_sym_uniform] = ACTIONS(2340),
    [anon_sym_row_major] = ACTIONS(2340),
    [anon_sym_column_major] = ACTIONS(2340),
    [anon_sym_globallycoherent] = ACTIONS(2340),
    [anon_sym_centroid] = ACTIONS(2340),
    [anon_sym_noperspective] = ACTIONS(2340),
    [anon_sym_nointerpolation] = ACTIONS(2340),
    [anon_sym_sample] = ACTIONS(2340),
    [anon_sym_linear] = ACTIONS(2340),
    [anon_sym_snorm] = ACTIONS(2340),
    [anon_sym_unorm] = ACTIONS(2340),
    [anon_sym_point] = ACTIONS(2340),
    [anon_sym_line] = ACTIONS(2340),
    [anon_sym_triangleadj] = ACTIONS(2340),
    [anon_sym_lineadj] = ACTIONS(2340),
    [anon_sym_triangle] = ACTIONS(2340),
  },
  [2131] = {
    [sym_identifier] = ACTIONS(2348),
    [aux_sym_preproc_def_token1] = ACTIONS(2348),
    [aux_sym_preproc_if_token1] = ACTIONS(2348),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2348),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2348),
    [sym_preproc_directive] = ACTIONS(2348),
    [anon_sym_LPAREN2] = ACTIONS(2350),
    [anon_sym_TILDE] = ACTIONS(2350),
    [anon_sym_STAR] = ACTIONS(2350),
    [anon_sym_AMP_AMP] = ACTIONS(2350),
    [anon_sym_AMP] = ACTIONS(2348),
    [anon_sym___extension__] = ACTIONS(2348),
    [anon_sym_typedef] = ACTIONS(2348),
    [anon_sym_in] = ACTIONS(2348),
    [anon_sym_out] = ACTIONS(2348),
    [anon_sym_inout] = ACTIONS(2348),
    [anon_sym_extern] = ACTIONS(2348),
    [anon_sym___attribute__] = ACTIONS(2348),
    [anon_sym_COLON_COLON] = ACTIONS(2350),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2350),
    [anon_sym___declspec] = ACTIONS(2348),
    [anon_sym___based] = ACTIONS(2348),
    [anon_sym_RBRACE] = ACTIONS(2350),
    [anon_sym_signed] = ACTIONS(2348),
    [anon_sym_unsigned] = ACTIONS(2348),
    [anon_sym_long] = ACTIONS(2348),
    [anon_sym_short] = ACTIONS(2348),
    [anon_sym_LBRACK] = ACTIONS(2348),
    [anon_sym_static] = ACTIONS(2348),
    [anon_sym_register] = ACTIONS(2348),
    [anon_sym_inline] = ACTIONS(2348),
    [anon_sym___inline] = ACTIONS(2348),
    [anon_sym___inline__] = ACTIONS(2348),
    [anon_sym___forceinline] = ACTIONS(2348),
    [anon_sym_thread_local] = ACTIONS(2348),
    [anon_sym___thread] = ACTIONS(2348),
    [anon_sym_const] = ACTIONS(2348),
    [anon_sym_constexpr] = ACTIONS(2348),
    [anon_sym_volatile] = ACTIONS(2348),
    [anon_sym_restrict] = ACTIONS(2348),
    [anon_sym___restrict__] = ACTIONS(2348),
    [anon_sym__Atomic] = ACTIONS(2348),
    [anon_sym__Noreturn] = ACTIONS(2348),
    [anon_sym_noreturn] = ACTIONS(2348),
    [anon_sym_mutable] = ACTIONS(2348),
    [anon_sym_constinit] = ACTIONS(2348),
    [anon_sym_consteval] = ACTIONS(2348),
    [anon_sym_alignas] = ACTIONS(2348),
    [anon_sym__Alignas] = ACTIONS(2348),
    [sym_primitive_type] = ACTIONS(2348),
    [anon_sym_enum] = ACTIONS(2348),
    [anon_sym_class] = ACTIONS(2348),
    [anon_sym_struct] = ACTIONS(2348),
    [anon_sym_union] = ACTIONS(2348),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2348),
    [anon_sym_decltype] = ACTIONS(2348),
    [sym_virtual] = ACTIONS(2348),
    [anon_sym_explicit] = ACTIONS(2348),
    [anon_sym_typename] = ACTIONS(2348),
    [anon_sym_template] = ACTIONS(2348),
    [anon_sym_operator] = ACTIONS(2348),
    [anon_sym_friend] = ACTIONS(2348),
    [anon_sym_public] = ACTIONS(2348),
    [anon_sym_private] = ACTIONS(2348),
    [anon_sym_protected] = ACTIONS(2348),
    [anon_sym_using] = ACTIONS(2348),
    [anon_sym_static_assert] = ACTIONS(2348),
    [anon_sym_precise] = ACTIONS(2348),
    [anon_sym_shared] = ACTIONS(2348),
    [anon_sym_groupshared] = ACTIONS(2348),
    [anon_sym_uniform] = ACTIONS(2348),
    [anon_sym_row_major] = ACTIONS(2348),
    [anon_sym_column_major] = ACTIONS(2348),
    [anon_sym_globallycoherent] = ACTIONS(2348),
    [anon_sym_centroid] = ACTIONS(2348),
    [anon_sym_noperspective] = ACTIONS(2348),
    [anon_sym_nointerpolation] = ACTIONS(2348),
    [anon_sym_sample] = ACTIONS(2348),
    [anon_sym_linear] = ACTIONS(2348),
    [anon_sym_snorm] = ACTIONS(2348),
    [anon_sym_unorm] = ACTIONS(2348),
    [anon_sym_point] = ACTIONS(2348),
    [anon_sym_line] = ACTIONS(2348),
    [anon_sym_triangleadj] = ACTIONS(2348),
    [anon_sym_lineadj] = ACTIONS(2348),
    [anon_sym_triangle] = ACTIONS(2348),
  },
  [2132] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym_RBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_friend] = ACTIONS(2332),
    [anon_sym_public] = ACTIONS(2332),
    [anon_sym_private] = ACTIONS(2332),
    [anon_sym_protected] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
  },
  [2133] = {
    [sym_identifier] = ACTIONS(2356),
    [aux_sym_preproc_def_token1] = ACTIONS(2356),
    [aux_sym_preproc_if_token1] = ACTIONS(2356),
    [aux_sym_preproc_if_token2] = ACTIONS(2356),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2356),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2356),
    [sym_preproc_directive] = ACTIONS(2356),
    [anon_sym_LPAREN2] = ACTIONS(2358),
    [anon_sym_TILDE] = ACTIONS(2358),
    [anon_sym_STAR] = ACTIONS(2358),
    [anon_sym_AMP_AMP] = ACTIONS(2358),
    [anon_sym_AMP] = ACTIONS(2356),
    [anon_sym___extension__] = ACTIONS(2356),
    [anon_sym_typedef] = ACTIONS(2356),
    [anon_sym_in] = ACTIONS(2356),
    [anon_sym_out] = ACTIONS(2356),
    [anon_sym_inout] = ACTIONS(2356),
    [anon_sym_extern] = ACTIONS(2356),
    [anon_sym___attribute__] = ACTIONS(2356),
    [anon_sym_COLON_COLON] = ACTIONS(2358),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2358),
    [anon_sym___declspec] = ACTIONS(2356),
    [anon_sym___based] = ACTIONS(2356),
    [anon_sym_signed] = ACTIONS(2356),
    [anon_sym_unsigned] = ACTIONS(2356),
    [anon_sym_long] = ACTIONS(2356),
    [anon_sym_short] = ACTIONS(2356),
    [anon_sym_LBRACK] = ACTIONS(2356),
    [anon_sym_static] = ACTIONS(2356),
    [anon_sym_register] = ACTIONS(2356),
    [anon_sym_inline] = ACTIONS(2356),
    [anon_sym___inline] = ACTIONS(2356),
    [anon_sym___inline__] = ACTIONS(2356),
    [anon_sym___forceinline] = ACTIONS(2356),
    [anon_sym_thread_local] = ACTIONS(2356),
    [anon_sym___thread] = ACTIONS(2356),
    [anon_sym_const] = ACTIONS(2356),
    [anon_sym_constexpr] = ACTIONS(2356),
    [anon_sym_volatile] = ACTIONS(2356),
    [anon_sym_restrict] = ACTIONS(2356),
    [anon_sym___restrict__] = ACTIONS(2356),
    [anon_sym__Atomic] = ACTIONS(2356),
    [anon_sym__Noreturn] = ACTIONS(2356),
    [anon_sym_noreturn] = ACTIONS(2356),
    [anon_sym_mutable] = ACTIONS(2356),
    [anon_sym_constinit] = ACTIONS(2356),
    [anon_sym_consteval] = ACTIONS(2356),
    [anon_sym_alignas] = ACTIONS(2356),
    [anon_sym__Alignas] = ACTIONS(2356),
    [sym_primitive_type] = ACTIONS(2356),
    [anon_sym_enum] = ACTIONS(2356),
    [anon_sym_class] = ACTIONS(2356),
    [anon_sym_struct] = ACTIONS(2356),
    [anon_sym_union] = ACTIONS(2356),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2356),
    [anon_sym_decltype] = ACTIONS(2356),
    [sym_virtual] = ACTIONS(2356),
    [anon_sym_explicit] = ACTIONS(2356),
    [anon_sym_typename] = ACTIONS(2356),
    [anon_sym_template] = ACTIONS(2356),
    [anon_sym_operator] = ACTIONS(2356),
    [anon_sym_friend] = ACTIONS(2356),
    [anon_sym_public] = ACTIONS(2356),
    [anon_sym_private] = ACTIONS(2356),
    [anon_sym_protected] = ACTIONS(2356),
    [anon_sym_using] = ACTIONS(2356),
    [anon_sym_static_assert] = ACTIONS(2356),
    [anon_sym_precise] = ACTIONS(2356),
    [anon_sym_shared] = ACTIONS(2356),
    [anon_sym_groupshared] = ACTIONS(2356),
    [anon_sym_uniform] = ACTIONS(2356),
    [anon_sym_row_major] = ACTIONS(2356),
    [anon_sym_column_major] = ACTIONS(2356),
    [anon_sym_globallycoherent] = ACTIONS(2356),
    [anon_sym_centroid] = ACTIONS(2356),
    [anon_sym_noperspective] = ACTIONS(2356),
    [anon_sym_nointerpolation] = ACTIONS(2356),
    [anon_sym_sample] = ACTIONS(2356),
    [anon_sym_linear] = ACTIONS(2356),
    [anon_sym_snorm] = ACTIONS(2356),
    [anon_sym_unorm] = ACTIONS(2356),
    [anon_sym_point] = ACTIONS(2356),
    [anon_sym_line] = ACTIONS(2356),
    [anon_sym_triangleadj] = ACTIONS(2356),
    [anon_sym_lineadj] = ACTIONS(2356),
    [anon_sym_triangle] = ACTIONS(2356),
  },
  [2134] = {
    [sym_identifier] = ACTIONS(2470),
    [aux_sym_preproc_def_token1] = ACTIONS(2470),
    [aux_sym_preproc_if_token1] = ACTIONS(2470),
    [aux_sym_preproc_if_token2] = ACTIONS(2470),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2470),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2470),
    [sym_preproc_directive] = ACTIONS(2470),
    [anon_sym_LPAREN2] = ACTIONS(2472),
    [anon_sym_TILDE] = ACTIONS(2472),
    [anon_sym_STAR] = ACTIONS(2472),
    [anon_sym_AMP_AMP] = ACTIONS(2472),
    [anon_sym_AMP] = ACTIONS(2470),
    [anon_sym___extension__] = ACTIONS(2470),
    [anon_sym_typedef] = ACTIONS(2470),
    [anon_sym_in] = ACTIONS(2470),
    [anon_sym_out] = ACTIONS(2470),
    [anon_sym_inout] = ACTIONS(2470),
    [anon_sym_extern] = ACTIONS(2470),
    [anon_sym___attribute__] = ACTIONS(2470),
    [anon_sym_COLON_COLON] = ACTIONS(2472),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2472),
    [anon_sym___declspec] = ACTIONS(2470),
    [anon_sym___based] = ACTIONS(2470),
    [anon_sym_signed] = ACTIONS(2470),
    [anon_sym_unsigned] = ACTIONS(2470),
    [anon_sym_long] = ACTIONS(2470),
    [anon_sym_short] = ACTIONS(2470),
    [anon_sym_LBRACK] = ACTIONS(2470),
    [anon_sym_static] = ACTIONS(2470),
    [anon_sym_register] = ACTIONS(2470),
    [anon_sym_inline] = ACTIONS(2470),
    [anon_sym___inline] = ACTIONS(2470),
    [anon_sym___inline__] = ACTIONS(2470),
    [anon_sym___forceinline] = ACTIONS(2470),
    [anon_sym_thread_local] = ACTIONS(2470),
    [anon_sym___thread] = ACTIONS(2470),
    [anon_sym_const] = ACTIONS(2470),
    [anon_sym_constexpr] = ACTIONS(2470),
    [anon_sym_volatile] = ACTIONS(2470),
    [anon_sym_restrict] = ACTIONS(2470),
    [anon_sym___restrict__] = ACTIONS(2470),
    [anon_sym__Atomic] = ACTIONS(2470),
    [anon_sym__Noreturn] = ACTIONS(2470),
    [anon_sym_noreturn] = ACTIONS(2470),
    [anon_sym_mutable] = ACTIONS(2470),
    [anon_sym_constinit] = ACTIONS(2470),
    [anon_sym_consteval] = ACTIONS(2470),
    [anon_sym_alignas] = ACTIONS(2470),
    [anon_sym__Alignas] = ACTIONS(2470),
    [sym_primitive_type] = ACTIONS(2470),
    [anon_sym_enum] = ACTIONS(2470),
    [anon_sym_class] = ACTIONS(2470),
    [anon_sym_struct] = ACTIONS(2470),
    [anon_sym_union] = ACTIONS(2470),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2470),
    [anon_sym_decltype] = ACTIONS(2470),
    [sym_virtual] = ACTIONS(2470),
    [anon_sym_explicit] = ACTIONS(2470),
    [anon_sym_typename] = ACTIONS(2470),
    [anon_sym_template] = ACTIONS(2470),
    [anon_sym_operator] = ACTIONS(2470),
    [anon_sym_friend] = ACTIONS(2470),
    [anon_sym_public] = ACTIONS(2470),
    [anon_sym_private] = ACTIONS(2470),
    [anon_sym_protected] = ACTIONS(2470),
    [anon_sym_using] = ACTIONS(2470),
    [anon_sym_static_assert] = ACTIONS(2470),
    [anon_sym_precise] = ACTIONS(2470),
    [anon_sym_shared] = ACTIONS(2470),
    [anon_sym_groupshared] = ACTIONS(2470),
    [anon_sym_uniform] = ACTIONS(2470),
    [anon_sym_row_major] = ACTIONS(2470),
    [anon_sym_column_major] = ACTIONS(2470),
    [anon_sym_globallycoherent] = ACTIONS(2470),
    [anon_sym_centroid] = ACTIONS(2470),
    [anon_sym_noperspective] = ACTIONS(2470),
    [anon_sym_nointerpolation] = ACTIONS(2470),
    [anon_sym_sample] = ACTIONS(2470),
    [anon_sym_linear] = ACTIONS(2470),
    [anon_sym_snorm] = ACTIONS(2470),
    [anon_sym_unorm] = ACTIONS(2470),
    [anon_sym_point] = ACTIONS(2470),
    [anon_sym_line] = ACTIONS(2470),
    [anon_sym_triangleadj] = ACTIONS(2470),
    [anon_sym_lineadj] = ACTIONS(2470),
    [anon_sym_triangle] = ACTIONS(2470),
  },
  [2135] = {
    [sym_identifier] = ACTIONS(2404),
    [aux_sym_preproc_def_token1] = ACTIONS(2404),
    [aux_sym_preproc_if_token1] = ACTIONS(2404),
    [aux_sym_preproc_if_token2] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2404),
    [sym_preproc_directive] = ACTIONS(2404),
    [anon_sym_LPAREN2] = ACTIONS(2406),
    [anon_sym_TILDE] = ACTIONS(2406),
    [anon_sym_STAR] = ACTIONS(2406),
    [anon_sym_AMP_AMP] = ACTIONS(2406),
    [anon_sym_AMP] = ACTIONS(2404),
    [anon_sym___extension__] = ACTIONS(2404),
    [anon_sym_typedef] = ACTIONS(2404),
    [anon_sym_in] = ACTIONS(2404),
    [anon_sym_out] = ACTIONS(2404),
    [anon_sym_inout] = ACTIONS(2404),
    [anon_sym_extern] = ACTIONS(2404),
    [anon_sym___attribute__] = ACTIONS(2404),
    [anon_sym_COLON_COLON] = ACTIONS(2406),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2406),
    [anon_sym___declspec] = ACTIONS(2404),
    [anon_sym___based] = ACTIONS(2404),
    [anon_sym_signed] = ACTIONS(2404),
    [anon_sym_unsigned] = ACTIONS(2404),
    [anon_sym_long] = ACTIONS(2404),
    [anon_sym_short] = ACTIONS(2404),
    [anon_sym_LBRACK] = ACTIONS(2404),
    [anon_sym_static] = ACTIONS(2404),
    [anon_sym_register] = ACTIONS(2404),
    [anon_sym_inline] = ACTIONS(2404),
    [anon_sym___inline] = ACTIONS(2404),
    [anon_sym___inline__] = ACTIONS(2404),
    [anon_sym___forceinline] = ACTIONS(2404),
    [anon_sym_thread_local] = ACTIONS(2404),
    [anon_sym___thread] = ACTIONS(2404),
    [anon_sym_const] = ACTIONS(2404),
    [anon_sym_constexpr] = ACTIONS(2404),
    [anon_sym_volatile] = ACTIONS(2404),
    [anon_sym_restrict] = ACTIONS(2404),
    [anon_sym___restrict__] = ACTIONS(2404),
    [anon_sym__Atomic] = ACTIONS(2404),
    [anon_sym__Noreturn] = ACTIONS(2404),
    [anon_sym_noreturn] = ACTIONS(2404),
    [anon_sym_mutable] = ACTIONS(2404),
    [anon_sym_constinit] = ACTIONS(2404),
    [anon_sym_consteval] = ACTIONS(2404),
    [anon_sym_alignas] = ACTIONS(2404),
    [anon_sym__Alignas] = ACTIONS(2404),
    [sym_primitive_type] = ACTIONS(2404),
    [anon_sym_enum] = ACTIONS(2404),
    [anon_sym_class] = ACTIONS(2404),
    [anon_sym_struct] = ACTIONS(2404),
    [anon_sym_union] = ACTIONS(2404),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2404),
    [anon_sym_decltype] = ACTIONS(2404),
    [sym_virtual] = ACTIONS(2404),
    [anon_sym_explicit] = ACTIONS(2404),
    [anon_sym_typename] = ACTIONS(2404),
    [anon_sym_template] = ACTIONS(2404),
    [anon_sym_operator] = ACTIONS(2404),
    [anon_sym_friend] = ACTIONS(2404),
    [anon_sym_public] = ACTIONS(2404),
    [anon_sym_private] = ACTIONS(2404),
    [anon_sym_protected] = ACTIONS(2404),
    [anon_sym_using] = ACTIONS(2404),
    [anon_sym_static_assert] = ACTIONS(2404),
    [anon_sym_precise] = ACTIONS(2404),
    [anon_sym_shared] = ACTIONS(2404),
    [anon_sym_groupshared] = ACTIONS(2404),
    [anon_sym_uniform] = ACTIONS(2404),
    [anon_sym_row_major] = ACTIONS(2404),
    [anon_sym_column_major] = ACTIONS(2404),
    [anon_sym_globallycoherent] = ACTIONS(2404),
    [anon_sym_centroid] = ACTIONS(2404),
    [anon_sym_noperspective] = ACTIONS(2404),
    [anon_sym_nointerpolation] = ACTIONS(2404),
    [anon_sym_sample] = ACTIONS(2404),
    [anon_sym_linear] = ACTIONS(2404),
    [anon_sym_snorm] = ACTIONS(2404),
    [anon_sym_unorm] = ACTIONS(2404),
    [anon_sym_point] = ACTIONS(2404),
    [anon_sym_line] = ACTIONS(2404),
    [anon_sym_triangleadj] = ACTIONS(2404),
    [anon_sym_lineadj] = ACTIONS(2404),
    [anon_sym_triangle] = ACTIONS(2404),
  },
  [2136] = {
    [sym_identifier] = ACTIONS(2332),
    [aux_sym_preproc_def_token1] = ACTIONS(2332),
    [aux_sym_preproc_if_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2332),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2332),
    [sym_preproc_directive] = ACTIONS(2332),
    [anon_sym_LPAREN2] = ACTIONS(2334),
    [anon_sym_TILDE] = ACTIONS(2334),
    [anon_sym_STAR] = ACTIONS(2334),
    [anon_sym_AMP_AMP] = ACTIONS(2334),
    [anon_sym_AMP] = ACTIONS(2332),
    [anon_sym___extension__] = ACTIONS(2332),
    [anon_sym_typedef] = ACTIONS(2332),
    [anon_sym_in] = ACTIONS(2332),
    [anon_sym_out] = ACTIONS(2332),
    [anon_sym_inout] = ACTIONS(2332),
    [anon_sym_extern] = ACTIONS(2332),
    [anon_sym___attribute__] = ACTIONS(2332),
    [anon_sym_COLON_COLON] = ACTIONS(2334),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2334),
    [anon_sym___declspec] = ACTIONS(2332),
    [anon_sym___based] = ACTIONS(2332),
    [anon_sym_RBRACE] = ACTIONS(2334),
    [anon_sym_signed] = ACTIONS(2332),
    [anon_sym_unsigned] = ACTIONS(2332),
    [anon_sym_long] = ACTIONS(2332),
    [anon_sym_short] = ACTIONS(2332),
    [anon_sym_LBRACK] = ACTIONS(2332),
    [anon_sym_static] = ACTIONS(2332),
    [anon_sym_register] = ACTIONS(2332),
    [anon_sym_inline] = ACTIONS(2332),
    [anon_sym___inline] = ACTIONS(2332),
    [anon_sym___inline__] = ACTIONS(2332),
    [anon_sym___forceinline] = ACTIONS(2332),
    [anon_sym_thread_local] = ACTIONS(2332),
    [anon_sym___thread] = ACTIONS(2332),
    [anon_sym_const] = ACTIONS(2332),
    [anon_sym_constexpr] = ACTIONS(2332),
    [anon_sym_volatile] = ACTIONS(2332),
    [anon_sym_restrict] = ACTIONS(2332),
    [anon_sym___restrict__] = ACTIONS(2332),
    [anon_sym__Atomic] = ACTIONS(2332),
    [anon_sym__Noreturn] = ACTIONS(2332),
    [anon_sym_noreturn] = ACTIONS(2332),
    [anon_sym_mutable] = ACTIONS(2332),
    [anon_sym_constinit] = ACTIONS(2332),
    [anon_sym_consteval] = ACTIONS(2332),
    [anon_sym_alignas] = ACTIONS(2332),
    [anon_sym__Alignas] = ACTIONS(2332),
    [sym_primitive_type] = ACTIONS(2332),
    [anon_sym_enum] = ACTIONS(2332),
    [anon_sym_class] = ACTIONS(2332),
    [anon_sym_struct] = ACTIONS(2332),
    [anon_sym_union] = ACTIONS(2332),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2332),
    [anon_sym_decltype] = ACTIONS(2332),
    [sym_virtual] = ACTIONS(2332),
    [anon_sym_explicit] = ACTIONS(2332),
    [anon_sym_typename] = ACTIONS(2332),
    [anon_sym_template] = ACTIONS(2332),
    [anon_sym_operator] = ACTIONS(2332),
    [anon_sym_friend] = ACTIONS(2332),
    [anon_sym_public] = ACTIONS(2332),
    [anon_sym_private] = ACTIONS(2332),
    [anon_sym_protected] = ACTIONS(2332),
    [anon_sym_using] = ACTIONS(2332),
    [anon_sym_static_assert] = ACTIONS(2332),
    [anon_sym_precise] = ACTIONS(2332),
    [anon_sym_shared] = ACTIONS(2332),
    [anon_sym_groupshared] = ACTIONS(2332),
    [anon_sym_uniform] = ACTIONS(2332),
    [anon_sym_row_major] = ACTIONS(2332),
    [anon_sym_column_major] = ACTIONS(2332),
    [anon_sym_globallycoherent] = ACTIONS(2332),
    [anon_sym_centroid] = ACTIONS(2332),
    [anon_sym_noperspective] = ACTIONS(2332),
    [anon_sym_nointerpolation] = ACTIONS(2332),
    [anon_sym_sample] = ACTIONS(2332),
    [anon_sym_linear] = ACTIONS(2332),
    [anon_sym_snorm] = ACTIONS(2332),
    [anon_sym_unorm] = ACTIONS(2332),
    [anon_sym_point] = ACTIONS(2332),
    [anon_sym_line] = ACTIONS(2332),
    [anon_sym_triangleadj] = ACTIONS(2332),
    [anon_sym_lineadj] = ACTIONS(2332),
    [anon_sym_triangle] = ACTIONS(2332),
  },
  [2137] = {
    [sym_identifier] = ACTIONS(2482),
    [aux_sym_preproc_def_token1] = ACTIONS(2482),
    [aux_sym_preproc_if_token1] = ACTIONS(2482),
    [aux_sym_preproc_if_token2] = ACTIONS(2482),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2482),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2482),
    [sym_preproc_directive] = ACTIONS(2482),
    [anon_sym_LPAREN2] = ACTIONS(2484),
    [anon_sym_TILDE] = ACTIONS(2484),
    [anon_sym_STAR] = ACTIONS(2484),
    [anon_sym_AMP_AMP] = ACTIONS(2484),
    [anon_sym_AMP] = ACTIONS(2482),
    [anon_sym___extension__] = ACTIONS(2482),
    [anon_sym_typedef] = ACTIONS(2482),
    [anon_sym_in] = ACTIONS(2482),
    [anon_sym_out] = ACTIONS(2482),
    [anon_sym_inout] = ACTIONS(2482),
    [anon_sym_extern] = ACTIONS(2482),
    [anon_sym___attribute__] = ACTIONS(2482),
    [anon_sym_COLON_COLON] = ACTIONS(2484),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2484),
    [anon_sym___declspec] = ACTIONS(2482),
    [anon_sym___based] = ACTIONS(2482),
    [anon_sym_signed] = ACTIONS(2482),
    [anon_sym_unsigned] = ACTIONS(2482),
    [anon_sym_long] = ACTIONS(2482),
    [anon_sym_short] = ACTIONS(2482),
    [anon_sym_LBRACK] = ACTIONS(2482),
    [anon_sym_static] = ACTIONS(2482),
    [anon_sym_register] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(2482),
    [anon_sym___inline] = ACTIONS(2482),
    [anon_sym___inline__] = ACTIONS(2482),
    [anon_sym___forceinline] = ACTIONS(2482),
    [anon_sym_thread_local] = ACTIONS(2482),
    [anon_sym___thread] = ACTIONS(2482),
    [anon_sym_const] = ACTIONS(2482),
    [anon_sym_constexpr] = ACTIONS(2482),
    [anon_sym_volatile] = ACTIONS(2482),
    [anon_sym_restrict] = ACTIONS(2482),
    [anon_sym___restrict__] = ACTIONS(2482),
    [anon_sym__Atomic] = ACTIONS(2482),
    [anon_sym__Noreturn] = ACTIONS(2482),
    [anon_sym_noreturn] = ACTIONS(2482),
    [anon_sym_mutable] = ACTIONS(2482),
    [anon_sym_constinit] = ACTIONS(2482),
    [anon_sym_consteval] = ACTIONS(2482),
    [anon_sym_alignas] = ACTIONS(2482),
    [anon_sym__Alignas] = ACTIONS(2482),
    [sym_primitive_type] = ACTIONS(2482),
    [anon_sym_enum] = ACTIONS(2482),
    [anon_sym_class] = ACTIONS(2482),
    [anon_sym_struct] = ACTIONS(2482),
    [anon_sym_union] = ACTIONS(2482),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2482),
    [anon_sym_decltype] = ACTIONS(2482),
    [sym_virtual] = ACTIONS(2482),
    [anon_sym_explicit] = ACTIONS(2482),
    [anon_sym_typename] = ACTIONS(2482),
    [anon_sym_template] = ACTIONS(2482),
    [anon_sym_operator] = ACTIONS(2482),
    [anon_sym_friend] = ACTIONS(2482),
    [anon_sym_public] = ACTIONS(2482),
    [anon_sym_private] = ACTIONS(2482),
    [anon_sym_protected] = ACTIONS(2482),
    [anon_sym_using] = ACTIONS(2482),
    [anon_sym_static_assert] = ACTIONS(2482),
    [anon_sym_precise] = ACTIONS(2482),
    [anon_sym_shared] = ACTIONS(2482),
    [anon_sym_groupshared] = ACTIONS(2482),
    [anon_sym_uniform] = ACTIONS(2482),
    [anon_sym_row_major] = ACTIONS(2482),
    [anon_sym_column_major] = ACTIONS(2482),
    [anon_sym_globallycoherent] = ACTIONS(2482),
    [anon_sym_centroid] = ACTIONS(2482),
    [anon_sym_noperspective] = ACTIONS(2482),
    [anon_sym_nointerpolation] = ACTIONS(2482),
    [anon_sym_sample] = ACTIONS(2482),
    [anon_sym_linear] = ACTIONS(2482),
    [anon_sym_snorm] = ACTIONS(2482),
    [anon_sym_unorm] = ACTIONS(2482),
    [anon_sym_point] = ACTIONS(2482),
    [anon_sym_line] = ACTIONS(2482),
    [anon_sym_triangleadj] = ACTIONS(2482),
    [anon_sym_lineadj] = ACTIONS(2482),
    [anon_sym_triangle] = ACTIONS(2482),
  },
  [2138] = {
    [sym_identifier] = ACTIONS(2404),
    [aux_sym_preproc_def_token1] = ACTIONS(2404),
    [aux_sym_preproc_if_token1] = ACTIONS(2404),
    [aux_sym_preproc_if_token2] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2404),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2404),
    [sym_preproc_directive] = ACTIONS(2404),
    [anon_sym_LPAREN2] = ACTIONS(2406),
    [anon_sym_TILDE] = ACTIONS(2406),
    [anon_sym_STAR] = ACTIONS(2406),
    [anon_sym_AMP_AMP] = ACTIONS(2406),
    [anon_sym_AMP] = ACTIONS(2404),
    [anon_sym___extension__] = ACTIONS(2404),
    [anon_sym_typedef] = ACTIONS(2404),
    [anon_sym_in] = ACTIONS(2404),
    [anon_sym_out] = ACTIONS(2404),
    [anon_sym_inout] = ACTIONS(2404),
    [anon_sym_extern] = ACTIONS(2404),
    [anon_sym___attribute__] = ACTIONS(2404),
    [anon_sym_COLON_COLON] = ACTIONS(2406),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2406),
    [anon_sym___declspec] = ACTIONS(2404),
    [anon_sym___based] = ACTIONS(2404),
    [anon_sym_signed] = ACTIONS(2404),
    [anon_sym_unsigned] = ACTIONS(2404),
    [anon_sym_long] = ACTIONS(2404),
    [anon_sym_short] = ACTIONS(2404),
    [anon_sym_LBRACK] = ACTIONS(2404),
    [anon_sym_static] = ACTIONS(2404),
    [anon_sym_register] = ACTIONS(2404),
    [anon_sym_inline] = ACTIONS(2404),
    [anon_sym___inline] = ACTIONS(2404),
    [anon_sym___inline__] = ACTIONS(2404),
    [anon_sym___forceinline] = ACTIONS(2404),
    [anon_sym_thread_local] = ACTIONS(2404),
    [anon_sym___thread] = ACTIONS(2404),
    [anon_sym_const] = ACTIONS(2404),
    [anon_sym_constexpr] = ACTIONS(2404),
    [anon_sym_volatile] = ACTIONS(2404),
    [anon_sym_restrict] = ACTIONS(2404),
    [anon_sym___restrict__] = ACTIONS(2404),
    [anon_sym__Atomic] = ACTIONS(2404),
    [anon_sym__Noreturn] = ACTIONS(2404),
    [anon_sym_noreturn] = ACTIONS(2404),
    [anon_sym_mutable] = ACTIONS(2404),
    [anon_sym_constinit] = ACTIONS(2404),
    [anon_sym_consteval] = ACTIONS(2404),
    [anon_sym_alignas] = ACTIONS(2404),
    [anon_sym__Alignas] = ACTIONS(2404),
    [sym_primitive_type] = ACTIONS(2404),
    [anon_sym_enum] = ACTIONS(2404),
    [anon_sym_class] = ACTIONS(2404),
    [anon_sym_struct] = ACTIONS(2404),
    [anon_sym_union] = ACTIONS(2404),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2404),
    [anon_sym_decltype] = ACTIONS(2404),
    [sym_virtual] = ACTIONS(2404),
    [anon_sym_explicit] = ACTIONS(2404),
    [anon_sym_typename] = ACTIONS(2404),
    [anon_sym_template] = ACTIONS(2404),
    [anon_sym_operator] = ACTIONS(2404),
    [anon_sym_friend] = ACTIONS(2404),
    [anon_sym_public] = ACTIONS(2404),
    [anon_sym_private] = ACTIONS(2404),
    [anon_sym_protected] = ACTIONS(2404),
    [anon_sym_using] = ACTIONS(2404),
    [anon_sym_static_assert] = ACTIONS(2404),
    [anon_sym_precise] = ACTIONS(2404),
    [anon_sym_shared] = ACTIONS(2404),
    [anon_sym_groupshared] = ACTIONS(2404),
    [anon_sym_uniform] = ACTIONS(2404),
    [anon_sym_row_major] = ACTIONS(2404),
    [anon_sym_column_major] = ACTIONS(2404),
    [anon_sym_globallycoherent] = ACTIONS(2404),
    [anon_sym_centroid] = ACTIONS(2404),
    [anon_sym_noperspective] = ACTIONS(2404),
    [anon_sym_nointerpolation] = ACTIONS(2404),
    [anon_sym_sample] = ACTIONS(2404),
    [anon_sym_linear] = ACTIONS(2404),
    [anon_sym_snorm] = ACTIONS(2404),
    [anon_sym_unorm] = ACTIONS(2404),
    [anon_sym_point] = ACTIONS(2404),
    [anon_sym_line] = ACTIONS(2404),
    [anon_sym_triangleadj] = ACTIONS(2404),
    [anon_sym_lineadj] = ACTIONS(2404),
    [anon_sym_triangle] = ACTIONS(2404),
  },
  [2139] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym_RBRACE] = ACTIONS(2326),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_friend] = ACTIONS(2324),
    [anon_sym_public] = ACTIONS(2324),
    [anon_sym_private] = ACTIONS(2324),
    [anon_sym_protected] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
  },
  [2140] = {
    [sym_identifier] = ACTIONS(5093),
    [aux_sym_preproc_def_token1] = ACTIONS(5093),
    [aux_sym_preproc_if_token1] = ACTIONS(5093),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5093),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5093),
    [sym_preproc_directive] = ACTIONS(5093),
    [anon_sym_LPAREN2] = ACTIONS(5095),
    [anon_sym_TILDE] = ACTIONS(5095),
    [anon_sym_STAR] = ACTIONS(5095),
    [anon_sym_AMP_AMP] = ACTIONS(5095),
    [anon_sym_AMP] = ACTIONS(5093),
    [anon_sym___extension__] = ACTIONS(5093),
    [anon_sym_typedef] = ACTIONS(5093),
    [anon_sym_in] = ACTIONS(5093),
    [anon_sym_out] = ACTIONS(5093),
    [anon_sym_inout] = ACTIONS(5093),
    [anon_sym_extern] = ACTIONS(5093),
    [anon_sym___attribute__] = ACTIONS(5093),
    [anon_sym_COLON_COLON] = ACTIONS(5095),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5095),
    [anon_sym___declspec] = ACTIONS(5093),
    [anon_sym___based] = ACTIONS(5093),
    [anon_sym_RBRACE] = ACTIONS(5095),
    [anon_sym_signed] = ACTIONS(5093),
    [anon_sym_unsigned] = ACTIONS(5093),
    [anon_sym_long] = ACTIONS(5093),
    [anon_sym_short] = ACTIONS(5093),
    [anon_sym_LBRACK] = ACTIONS(5093),
    [anon_sym_static] = ACTIONS(5093),
    [anon_sym_register] = ACTIONS(5093),
    [anon_sym_inline] = ACTIONS(5093),
    [anon_sym___inline] = ACTIONS(5093),
    [anon_sym___inline__] = ACTIONS(5093),
    [anon_sym___forceinline] = ACTIONS(5093),
    [anon_sym_thread_local] = ACTIONS(5093),
    [anon_sym___thread] = ACTIONS(5093),
    [anon_sym_const] = ACTIONS(5093),
    [anon_sym_constexpr] = ACTIONS(5093),
    [anon_sym_volatile] = ACTIONS(5093),
    [anon_sym_restrict] = ACTIONS(5093),
    [anon_sym___restrict__] = ACTIONS(5093),
    [anon_sym__Atomic] = ACTIONS(5093),
    [anon_sym__Noreturn] = ACTIONS(5093),
    [anon_sym_noreturn] = ACTIONS(5093),
    [anon_sym_mutable] = ACTIONS(5093),
    [anon_sym_constinit] = ACTIONS(5093),
    [anon_sym_consteval] = ACTIONS(5093),
    [anon_sym_alignas] = ACTIONS(5093),
    [anon_sym__Alignas] = ACTIONS(5093),
    [sym_primitive_type] = ACTIONS(5093),
    [anon_sym_enum] = ACTIONS(5093),
    [anon_sym_class] = ACTIONS(5093),
    [anon_sym_struct] = ACTIONS(5093),
    [anon_sym_union] = ACTIONS(5093),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5093),
    [anon_sym_decltype] = ACTIONS(5093),
    [sym_virtual] = ACTIONS(5093),
    [anon_sym_explicit] = ACTIONS(5093),
    [anon_sym_typename] = ACTIONS(5093),
    [anon_sym_template] = ACTIONS(5093),
    [anon_sym_operator] = ACTIONS(5093),
    [anon_sym_friend] = ACTIONS(5093),
    [anon_sym_public] = ACTIONS(5093),
    [anon_sym_private] = ACTIONS(5093),
    [anon_sym_protected] = ACTIONS(5093),
    [anon_sym_using] = ACTIONS(5093),
    [anon_sym_static_assert] = ACTIONS(5093),
    [anon_sym_precise] = ACTIONS(5093),
    [anon_sym_shared] = ACTIONS(5093),
    [anon_sym_groupshared] = ACTIONS(5093),
    [anon_sym_uniform] = ACTIONS(5093),
    [anon_sym_row_major] = ACTIONS(5093),
    [anon_sym_column_major] = ACTIONS(5093),
    [anon_sym_globallycoherent] = ACTIONS(5093),
    [anon_sym_centroid] = ACTIONS(5093),
    [anon_sym_noperspective] = ACTIONS(5093),
    [anon_sym_nointerpolation] = ACTIONS(5093),
    [anon_sym_sample] = ACTIONS(5093),
    [anon_sym_linear] = ACTIONS(5093),
    [anon_sym_snorm] = ACTIONS(5093),
    [anon_sym_unorm] = ACTIONS(5093),
    [anon_sym_point] = ACTIONS(5093),
    [anon_sym_line] = ACTIONS(5093),
    [anon_sym_triangleadj] = ACTIONS(5093),
    [anon_sym_lineadj] = ACTIONS(5093),
    [anon_sym_triangle] = ACTIONS(5093),
  },
  [2141] = {
    [sym_identifier] = ACTIONS(5085),
    [aux_sym_preproc_def_token1] = ACTIONS(5085),
    [aux_sym_preproc_if_token1] = ACTIONS(5085),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5085),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5085),
    [sym_preproc_directive] = ACTIONS(5085),
    [anon_sym_LPAREN2] = ACTIONS(5087),
    [anon_sym_TILDE] = ACTIONS(5087),
    [anon_sym_STAR] = ACTIONS(5087),
    [anon_sym_AMP_AMP] = ACTIONS(5087),
    [anon_sym_AMP] = ACTIONS(5085),
    [anon_sym___extension__] = ACTIONS(5085),
    [anon_sym_typedef] = ACTIONS(5085),
    [anon_sym_in] = ACTIONS(5085),
    [anon_sym_out] = ACTIONS(5085),
    [anon_sym_inout] = ACTIONS(5085),
    [anon_sym_extern] = ACTIONS(5085),
    [anon_sym___attribute__] = ACTIONS(5085),
    [anon_sym_COLON_COLON] = ACTIONS(5087),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5087),
    [anon_sym___declspec] = ACTIONS(5085),
    [anon_sym___based] = ACTIONS(5085),
    [anon_sym_RBRACE] = ACTIONS(5087),
    [anon_sym_signed] = ACTIONS(5085),
    [anon_sym_unsigned] = ACTIONS(5085),
    [anon_sym_long] = ACTIONS(5085),
    [anon_sym_short] = ACTIONS(5085),
    [anon_sym_LBRACK] = ACTIONS(5085),
    [anon_sym_static] = ACTIONS(5085),
    [anon_sym_register] = ACTIONS(5085),
    [anon_sym_inline] = ACTIONS(5085),
    [anon_sym___inline] = ACTIONS(5085),
    [anon_sym___inline__] = ACTIONS(5085),
    [anon_sym___forceinline] = ACTIONS(5085),
    [anon_sym_thread_local] = ACTIONS(5085),
    [anon_sym___thread] = ACTIONS(5085),
    [anon_sym_const] = ACTIONS(5085),
    [anon_sym_constexpr] = ACTIONS(5085),
    [anon_sym_volatile] = ACTIONS(5085),
    [anon_sym_restrict] = ACTIONS(5085),
    [anon_sym___restrict__] = ACTIONS(5085),
    [anon_sym__Atomic] = ACTIONS(5085),
    [anon_sym__Noreturn] = ACTIONS(5085),
    [anon_sym_noreturn] = ACTIONS(5085),
    [anon_sym_mutable] = ACTIONS(5085),
    [anon_sym_constinit] = ACTIONS(5085),
    [anon_sym_consteval] = ACTIONS(5085),
    [anon_sym_alignas] = ACTIONS(5085),
    [anon_sym__Alignas] = ACTIONS(5085),
    [sym_primitive_type] = ACTIONS(5085),
    [anon_sym_enum] = ACTIONS(5085),
    [anon_sym_class] = ACTIONS(5085),
    [anon_sym_struct] = ACTIONS(5085),
    [anon_sym_union] = ACTIONS(5085),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5085),
    [anon_sym_decltype] = ACTIONS(5085),
    [sym_virtual] = ACTIONS(5085),
    [anon_sym_explicit] = ACTIONS(5085),
    [anon_sym_typename] = ACTIONS(5085),
    [anon_sym_template] = ACTIONS(5085),
    [anon_sym_operator] = ACTIONS(5085),
    [anon_sym_friend] = ACTIONS(5085),
    [anon_sym_public] = ACTIONS(5085),
    [anon_sym_private] = ACTIONS(5085),
    [anon_sym_protected] = ACTIONS(5085),
    [anon_sym_using] = ACTIONS(5085),
    [anon_sym_static_assert] = ACTIONS(5085),
    [anon_sym_precise] = ACTIONS(5085),
    [anon_sym_shared] = ACTIONS(5085),
    [anon_sym_groupshared] = ACTIONS(5085),
    [anon_sym_uniform] = ACTIONS(5085),
    [anon_sym_row_major] = ACTIONS(5085),
    [anon_sym_column_major] = ACTIONS(5085),
    [anon_sym_globallycoherent] = ACTIONS(5085),
    [anon_sym_centroid] = ACTIONS(5085),
    [anon_sym_noperspective] = ACTIONS(5085),
    [anon_sym_nointerpolation] = ACTIONS(5085),
    [anon_sym_sample] = ACTIONS(5085),
    [anon_sym_linear] = ACTIONS(5085),
    [anon_sym_snorm] = ACTIONS(5085),
    [anon_sym_unorm] = ACTIONS(5085),
    [anon_sym_point] = ACTIONS(5085),
    [anon_sym_line] = ACTIONS(5085),
    [anon_sym_triangleadj] = ACTIONS(5085),
    [anon_sym_lineadj] = ACTIONS(5085),
    [anon_sym_triangle] = ACTIONS(5085),
  },
  [2142] = {
    [sym_identifier] = ACTIONS(2272),
    [aux_sym_preproc_def_token1] = ACTIONS(2272),
    [aux_sym_preproc_if_token1] = ACTIONS(2272),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2272),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2272),
    [sym_preproc_directive] = ACTIONS(2272),
    [anon_sym_LPAREN2] = ACTIONS(2274),
    [anon_sym_TILDE] = ACTIONS(2274),
    [anon_sym_STAR] = ACTIONS(2274),
    [anon_sym_AMP_AMP] = ACTIONS(2274),
    [anon_sym_AMP] = ACTIONS(2272),
    [anon_sym___extension__] = ACTIONS(2272),
    [anon_sym_typedef] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2272),
    [anon_sym_out] = ACTIONS(2272),
    [anon_sym_inout] = ACTIONS(2272),
    [anon_sym_extern] = ACTIONS(2272),
    [anon_sym___attribute__] = ACTIONS(2272),
    [anon_sym_COLON_COLON] = ACTIONS(2274),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2274),
    [anon_sym___declspec] = ACTIONS(2272),
    [anon_sym___based] = ACTIONS(2272),
    [anon_sym_RBRACE] = ACTIONS(2274),
    [anon_sym_signed] = ACTIONS(2272),
    [anon_sym_unsigned] = ACTIONS(2272),
    [anon_sym_long] = ACTIONS(2272),
    [anon_sym_short] = ACTIONS(2272),
    [anon_sym_LBRACK] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(2272),
    [anon_sym_register] = ACTIONS(2272),
    [anon_sym_inline] = ACTIONS(2272),
    [anon_sym___inline] = ACTIONS(2272),
    [anon_sym___inline__] = ACTIONS(2272),
    [anon_sym___forceinline] = ACTIONS(2272),
    [anon_sym_thread_local] = ACTIONS(2272),
    [anon_sym___thread] = ACTIONS(2272),
    [anon_sym_const] = ACTIONS(2272),
    [anon_sym_constexpr] = ACTIONS(2272),
    [anon_sym_volatile] = ACTIONS(2272),
    [anon_sym_restrict] = ACTIONS(2272),
    [anon_sym___restrict__] = ACTIONS(2272),
    [anon_sym__Atomic] = ACTIONS(2272),
    [anon_sym__Noreturn] = ACTIONS(2272),
    [anon_sym_noreturn] = ACTIONS(2272),
    [anon_sym_mutable] = ACTIONS(2272),
    [anon_sym_constinit] = ACTIONS(2272),
    [anon_sym_consteval] = ACTIONS(2272),
    [anon_sym_alignas] = ACTIONS(2272),
    [anon_sym__Alignas] = ACTIONS(2272),
    [sym_primitive_type] = ACTIONS(2272),
    [anon_sym_enum] = ACTIONS(2272),
    [anon_sym_class] = ACTIONS(2272),
    [anon_sym_struct] = ACTIONS(2272),
    [anon_sym_union] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2272),
    [anon_sym_decltype] = ACTIONS(2272),
    [sym_virtual] = ACTIONS(2272),
    [anon_sym_explicit] = ACTIONS(2272),
    [anon_sym_typename] = ACTIONS(2272),
    [anon_sym_template] = ACTIONS(2272),
    [anon_sym_operator] = ACTIONS(2272),
    [anon_sym_friend] = ACTIONS(2272),
    [anon_sym_public] = ACTIONS(2272),
    [anon_sym_private] = ACTIONS(2272),
    [anon_sym_protected] = ACTIONS(2272),
    [anon_sym_using] = ACTIONS(2272),
    [anon_sym_static_assert] = ACTIONS(2272),
    [anon_sym_precise] = ACTIONS(2272),
    [anon_sym_shared] = ACTIONS(2272),
    [anon_sym_groupshared] = ACTIONS(2272),
    [anon_sym_uniform] = ACTIONS(2272),
    [anon_sym_row_major] = ACTIONS(2272),
    [anon_sym_column_major] = ACTIONS(2272),
    [anon_sym_globallycoherent] = ACTIONS(2272),
    [anon_sym_centroid] = ACTIONS(2272),
    [anon_sym_noperspective] = ACTIONS(2272),
    [anon_sym_nointerpolation] = ACTIONS(2272),
    [anon_sym_sample] = ACTIONS(2272),
    [anon_sym_linear] = ACTIONS(2272),
    [anon_sym_snorm] = ACTIONS(2272),
    [anon_sym_unorm] = ACTIONS(2272),
    [anon_sym_point] = ACTIONS(2272),
    [anon_sym_line] = ACTIONS(2272),
    [anon_sym_triangleadj] = ACTIONS(2272),
    [anon_sym_lineadj] = ACTIONS(2272),
    [anon_sym_triangle] = ACTIONS(2272),
  },
  [2143] = {
    [sym_identifier] = ACTIONS(2312),
    [aux_sym_preproc_def_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token1] = ACTIONS(2312),
    [aux_sym_preproc_if_token2] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2312),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2312),
    [sym_preproc_directive] = ACTIONS(2312),
    [anon_sym_LPAREN2] = ACTIONS(2314),
    [anon_sym_TILDE] = ACTIONS(2314),
    [anon_sym_STAR] = ACTIONS(2314),
    [anon_sym_AMP_AMP] = ACTIONS(2314),
    [anon_sym_AMP] = ACTIONS(2312),
    [anon_sym___extension__] = ACTIONS(2312),
    [anon_sym_typedef] = ACTIONS(2312),
    [anon_sym_in] = ACTIONS(2312),
    [anon_sym_out] = ACTIONS(2312),
    [anon_sym_inout] = ACTIONS(2312),
    [anon_sym_extern] = ACTIONS(2312),
    [anon_sym___attribute__] = ACTIONS(2312),
    [anon_sym_COLON_COLON] = ACTIONS(2314),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2314),
    [anon_sym___declspec] = ACTIONS(2312),
    [anon_sym___based] = ACTIONS(2312),
    [anon_sym_signed] = ACTIONS(2312),
    [anon_sym_unsigned] = ACTIONS(2312),
    [anon_sym_long] = ACTIONS(2312),
    [anon_sym_short] = ACTIONS(2312),
    [anon_sym_LBRACK] = ACTIONS(2312),
    [anon_sym_static] = ACTIONS(2312),
    [anon_sym_register] = ACTIONS(2312),
    [anon_sym_inline] = ACTIONS(2312),
    [anon_sym___inline] = ACTIONS(2312),
    [anon_sym___inline__] = ACTIONS(2312),
    [anon_sym___forceinline] = ACTIONS(2312),
    [anon_sym_thread_local] = ACTIONS(2312),
    [anon_sym___thread] = ACTIONS(2312),
    [anon_sym_const] = ACTIONS(2312),
    [anon_sym_constexpr] = ACTIONS(2312),
    [anon_sym_volatile] = ACTIONS(2312),
    [anon_sym_restrict] = ACTIONS(2312),
    [anon_sym___restrict__] = ACTIONS(2312),
    [anon_sym__Atomic] = ACTIONS(2312),
    [anon_sym__Noreturn] = ACTIONS(2312),
    [anon_sym_noreturn] = ACTIONS(2312),
    [anon_sym_mutable] = ACTIONS(2312),
    [anon_sym_constinit] = ACTIONS(2312),
    [anon_sym_consteval] = ACTIONS(2312),
    [anon_sym_alignas] = ACTIONS(2312),
    [anon_sym__Alignas] = ACTIONS(2312),
    [sym_primitive_type] = ACTIONS(2312),
    [anon_sym_enum] = ACTIONS(2312),
    [anon_sym_class] = ACTIONS(2312),
    [anon_sym_struct] = ACTIONS(2312),
    [anon_sym_union] = ACTIONS(2312),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2312),
    [anon_sym_decltype] = ACTIONS(2312),
    [sym_virtual] = ACTIONS(2312),
    [anon_sym_explicit] = ACTIONS(2312),
    [anon_sym_typename] = ACTIONS(2312),
    [anon_sym_template] = ACTIONS(2312),
    [anon_sym_operator] = ACTIONS(2312),
    [anon_sym_friend] = ACTIONS(2312),
    [anon_sym_public] = ACTIONS(2312),
    [anon_sym_private] = ACTIONS(2312),
    [anon_sym_protected] = ACTIONS(2312),
    [anon_sym_using] = ACTIONS(2312),
    [anon_sym_static_assert] = ACTIONS(2312),
    [anon_sym_precise] = ACTIONS(2312),
    [anon_sym_shared] = ACTIONS(2312),
    [anon_sym_groupshared] = ACTIONS(2312),
    [anon_sym_uniform] = ACTIONS(2312),
    [anon_sym_row_major] = ACTIONS(2312),
    [anon_sym_column_major] = ACTIONS(2312),
    [anon_sym_globallycoherent] = ACTIONS(2312),
    [anon_sym_centroid] = ACTIONS(2312),
    [anon_sym_noperspective] = ACTIONS(2312),
    [anon_sym_nointerpolation] = ACTIONS(2312),
    [anon_sym_sample] = ACTIONS(2312),
    [anon_sym_linear] = ACTIONS(2312),
    [anon_sym_snorm] = ACTIONS(2312),
    [anon_sym_unorm] = ACTIONS(2312),
    [anon_sym_point] = ACTIONS(2312),
    [anon_sym_line] = ACTIONS(2312),
    [anon_sym_triangleadj] = ACTIONS(2312),
    [anon_sym_lineadj] = ACTIONS(2312),
    [anon_sym_triangle] = ACTIONS(2312),
  },
  [2144] = {
    [sym_identifier] = ACTIONS(2320),
    [aux_sym_preproc_def_token1] = ACTIONS(2320),
    [aux_sym_preproc_if_token1] = ACTIONS(2320),
    [aux_sym_preproc_if_token2] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2320),
    [sym_preproc_directive] = ACTIONS(2320),
    [anon_sym_LPAREN2] = ACTIONS(2322),
    [anon_sym_TILDE] = ACTIONS(2322),
    [anon_sym_STAR] = ACTIONS(2322),
    [anon_sym_AMP_AMP] = ACTIONS(2322),
    [anon_sym_AMP] = ACTIONS(2320),
    [anon_sym___extension__] = ACTIONS(2320),
    [anon_sym_typedef] = ACTIONS(2320),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_out] = ACTIONS(2320),
    [anon_sym_inout] = ACTIONS(2320),
    [anon_sym_extern] = ACTIONS(2320),
    [anon_sym___attribute__] = ACTIONS(2320),
    [anon_sym_COLON_COLON] = ACTIONS(2322),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2322),
    [anon_sym___declspec] = ACTIONS(2320),
    [anon_sym___based] = ACTIONS(2320),
    [anon_sym_signed] = ACTIONS(2320),
    [anon_sym_unsigned] = ACTIONS(2320),
    [anon_sym_long] = ACTIONS(2320),
    [anon_sym_short] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2320),
    [anon_sym_static] = ACTIONS(2320),
    [anon_sym_register] = ACTIONS(2320),
    [anon_sym_inline] = ACTIONS(2320),
    [anon_sym___inline] = ACTIONS(2320),
    [anon_sym___inline__] = ACTIONS(2320),
    [anon_sym___forceinline] = ACTIONS(2320),
    [anon_sym_thread_local] = ACTIONS(2320),
    [anon_sym___thread] = ACTIONS(2320),
    [anon_sym_const] = ACTIONS(2320),
    [anon_sym_constexpr] = ACTIONS(2320),
    [anon_sym_volatile] = ACTIONS(2320),
    [anon_sym_restrict] = ACTIONS(2320),
    [anon_sym___restrict__] = ACTIONS(2320),
    [anon_sym__Atomic] = ACTIONS(2320),
    [anon_sym__Noreturn] = ACTIONS(2320),
    [anon_sym_noreturn] = ACTIONS(2320),
    [anon_sym_mutable] = ACTIONS(2320),
    [anon_sym_constinit] = ACTIONS(2320),
    [anon_sym_consteval] = ACTIONS(2320),
    [anon_sym_alignas] = ACTIONS(2320),
    [anon_sym__Alignas] = ACTIONS(2320),
    [sym_primitive_type] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_class] = ACTIONS(2320),
    [anon_sym_struct] = ACTIONS(2320),
    [anon_sym_union] = ACTIONS(2320),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2320),
    [anon_sym_decltype] = ACTIONS(2320),
    [sym_virtual] = ACTIONS(2320),
    [anon_sym_explicit] = ACTIONS(2320),
    [anon_sym_typename] = ACTIONS(2320),
    [anon_sym_template] = ACTIONS(2320),
    [anon_sym_operator] = ACTIONS(2320),
    [anon_sym_friend] = ACTIONS(2320),
    [anon_sym_public] = ACTIONS(2320),
    [anon_sym_private] = ACTIONS(2320),
    [anon_sym_protected] = ACTIONS(2320),
    [anon_sym_using] = ACTIONS(2320),
    [anon_sym_static_assert] = ACTIONS(2320),
    [anon_sym_precise] = ACTIONS(2320),
    [anon_sym_shared] = ACTIONS(2320),
    [anon_sym_groupshared] = ACTIONS(2320),
    [anon_sym_uniform] = ACTIONS(2320),
    [anon_sym_row_major] = ACTIONS(2320),
    [anon_sym_column_major] = ACTIONS(2320),
    [anon_sym_globallycoherent] = ACTIONS(2320),
    [anon_sym_centroid] = ACTIONS(2320),
    [anon_sym_noperspective] = ACTIONS(2320),
    [anon_sym_nointerpolation] = ACTIONS(2320),
    [anon_sym_sample] = ACTIONS(2320),
    [anon_sym_linear] = ACTIONS(2320),
    [anon_sym_snorm] = ACTIONS(2320),
    [anon_sym_unorm] = ACTIONS(2320),
    [anon_sym_point] = ACTIONS(2320),
    [anon_sym_line] = ACTIONS(2320),
    [anon_sym_triangleadj] = ACTIONS(2320),
    [anon_sym_lineadj] = ACTIONS(2320),
    [anon_sym_triangle] = ACTIONS(2320),
  },
  [2145] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym_RBRACE] = ACTIONS(2326),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_friend] = ACTIONS(2324),
    [anon_sym_public] = ACTIONS(2324),
    [anon_sym_private] = ACTIONS(2324),
    [anon_sym_protected] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
  },
  [2146] = {
    [sym_identifier] = ACTIONS(2482),
    [aux_sym_preproc_def_token1] = ACTIONS(2482),
    [aux_sym_preproc_if_token1] = ACTIONS(2482),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2482),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2482),
    [sym_preproc_directive] = ACTIONS(2482),
    [anon_sym_LPAREN2] = ACTIONS(2484),
    [anon_sym_TILDE] = ACTIONS(2484),
    [anon_sym_STAR] = ACTIONS(2484),
    [anon_sym_AMP_AMP] = ACTIONS(2484),
    [anon_sym_AMP] = ACTIONS(2482),
    [anon_sym___extension__] = ACTIONS(2482),
    [anon_sym_typedef] = ACTIONS(2482),
    [anon_sym_in] = ACTIONS(2482),
    [anon_sym_out] = ACTIONS(2482),
    [anon_sym_inout] = ACTIONS(2482),
    [anon_sym_extern] = ACTIONS(2482),
    [anon_sym___attribute__] = ACTIONS(2482),
    [anon_sym_COLON_COLON] = ACTIONS(2484),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2484),
    [anon_sym___declspec] = ACTIONS(2482),
    [anon_sym___based] = ACTIONS(2482),
    [anon_sym_RBRACE] = ACTIONS(2484),
    [anon_sym_signed] = ACTIONS(2482),
    [anon_sym_unsigned] = ACTIONS(2482),
    [anon_sym_long] = ACTIONS(2482),
    [anon_sym_short] = ACTIONS(2482),
    [anon_sym_LBRACK] = ACTIONS(2482),
    [anon_sym_static] = ACTIONS(2482),
    [anon_sym_register] = ACTIONS(2482),
    [anon_sym_inline] = ACTIONS(2482),
    [anon_sym___inline] = ACTIONS(2482),
    [anon_sym___inline__] = ACTIONS(2482),
    [anon_sym___forceinline] = ACTIONS(2482),
    [anon_sym_thread_local] = ACTIONS(2482),
    [anon_sym___thread] = ACTIONS(2482),
    [anon_sym_const] = ACTIONS(2482),
    [anon_sym_constexpr] = ACTIONS(2482),
    [anon_sym_volatile] = ACTIONS(2482),
    [anon_sym_restrict] = ACTIONS(2482),
    [anon_sym___restrict__] = ACTIONS(2482),
    [anon_sym__Atomic] = ACTIONS(2482),
    [anon_sym__Noreturn] = ACTIONS(2482),
    [anon_sym_noreturn] = ACTIONS(2482),
    [anon_sym_mutable] = ACTIONS(2482),
    [anon_sym_constinit] = ACTIONS(2482),
    [anon_sym_consteval] = ACTIONS(2482),
    [anon_sym_alignas] = ACTIONS(2482),
    [anon_sym__Alignas] = ACTIONS(2482),
    [sym_primitive_type] = ACTIONS(2482),
    [anon_sym_enum] = ACTIONS(2482),
    [anon_sym_class] = ACTIONS(2482),
    [anon_sym_struct] = ACTIONS(2482),
    [anon_sym_union] = ACTIONS(2482),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2482),
    [anon_sym_decltype] = ACTIONS(2482),
    [sym_virtual] = ACTIONS(2482),
    [anon_sym_explicit] = ACTIONS(2482),
    [anon_sym_typename] = ACTIONS(2482),
    [anon_sym_template] = ACTIONS(2482),
    [anon_sym_operator] = ACTIONS(2482),
    [anon_sym_friend] = ACTIONS(2482),
    [anon_sym_public] = ACTIONS(2482),
    [anon_sym_private] = ACTIONS(2482),
    [anon_sym_protected] = ACTIONS(2482),
    [anon_sym_using] = ACTIONS(2482),
    [anon_sym_static_assert] = ACTIONS(2482),
    [anon_sym_precise] = ACTIONS(2482),
    [anon_sym_shared] = ACTIONS(2482),
    [anon_sym_groupshared] = ACTIONS(2482),
    [anon_sym_uniform] = ACTIONS(2482),
    [anon_sym_row_major] = ACTIONS(2482),
    [anon_sym_column_major] = ACTIONS(2482),
    [anon_sym_globallycoherent] = ACTIONS(2482),
    [anon_sym_centroid] = ACTIONS(2482),
    [anon_sym_noperspective] = ACTIONS(2482),
    [anon_sym_nointerpolation] = ACTIONS(2482),
    [anon_sym_sample] = ACTIONS(2482),
    [anon_sym_linear] = ACTIONS(2482),
    [anon_sym_snorm] = ACTIONS(2482),
    [anon_sym_unorm] = ACTIONS(2482),
    [anon_sym_point] = ACTIONS(2482),
    [anon_sym_line] = ACTIONS(2482),
    [anon_sym_triangleadj] = ACTIONS(2482),
    [anon_sym_lineadj] = ACTIONS(2482),
    [anon_sym_triangle] = ACTIONS(2482),
  },
  [2147] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token2] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_friend] = ACTIONS(2324),
    [anon_sym_public] = ACTIONS(2324),
    [anon_sym_private] = ACTIONS(2324),
    [anon_sym_protected] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
  },
  [2148] = {
    [sym_identifier] = ACTIONS(5077),
    [aux_sym_preproc_def_token1] = ACTIONS(5077),
    [aux_sym_preproc_if_token1] = ACTIONS(5077),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5077),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5077),
    [sym_preproc_directive] = ACTIONS(5077),
    [anon_sym_LPAREN2] = ACTIONS(5079),
    [anon_sym_TILDE] = ACTIONS(5079),
    [anon_sym_STAR] = ACTIONS(5079),
    [anon_sym_AMP_AMP] = ACTIONS(5079),
    [anon_sym_AMP] = ACTIONS(5077),
    [anon_sym___extension__] = ACTIONS(5077),
    [anon_sym_typedef] = ACTIONS(5077),
    [anon_sym_in] = ACTIONS(5077),
    [anon_sym_out] = ACTIONS(5077),
    [anon_sym_inout] = ACTIONS(5077),
    [anon_sym_extern] = ACTIONS(5077),
    [anon_sym___attribute__] = ACTIONS(5077),
    [anon_sym_COLON_COLON] = ACTIONS(5079),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5079),
    [anon_sym___declspec] = ACTIONS(5077),
    [anon_sym___based] = ACTIONS(5077),
    [anon_sym_RBRACE] = ACTIONS(5079),
    [anon_sym_signed] = ACTIONS(5077),
    [anon_sym_unsigned] = ACTIONS(5077),
    [anon_sym_long] = ACTIONS(5077),
    [anon_sym_short] = ACTIONS(5077),
    [anon_sym_LBRACK] = ACTIONS(5077),
    [anon_sym_static] = ACTIONS(5077),
    [anon_sym_register] = ACTIONS(5077),
    [anon_sym_inline] = ACTIONS(5077),
    [anon_sym___inline] = ACTIONS(5077),
    [anon_sym___inline__] = ACTIONS(5077),
    [anon_sym___forceinline] = ACTIONS(5077),
    [anon_sym_thread_local] = ACTIONS(5077),
    [anon_sym___thread] = ACTIONS(5077),
    [anon_sym_const] = ACTIONS(5077),
    [anon_sym_constexpr] = ACTIONS(5077),
    [anon_sym_volatile] = ACTIONS(5077),
    [anon_sym_restrict] = ACTIONS(5077),
    [anon_sym___restrict__] = ACTIONS(5077),
    [anon_sym__Atomic] = ACTIONS(5077),
    [anon_sym__Noreturn] = ACTIONS(5077),
    [anon_sym_noreturn] = ACTIONS(5077),
    [anon_sym_mutable] = ACTIONS(5077),
    [anon_sym_constinit] = ACTIONS(5077),
    [anon_sym_consteval] = ACTIONS(5077),
    [anon_sym_alignas] = ACTIONS(5077),
    [anon_sym__Alignas] = ACTIONS(5077),
    [sym_primitive_type] = ACTIONS(5077),
    [anon_sym_enum] = ACTIONS(5077),
    [anon_sym_class] = ACTIONS(5077),
    [anon_sym_struct] = ACTIONS(5077),
    [anon_sym_union] = ACTIONS(5077),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5077),
    [anon_sym_decltype] = ACTIONS(5077),
    [sym_virtual] = ACTIONS(5077),
    [anon_sym_explicit] = ACTIONS(5077),
    [anon_sym_typename] = ACTIONS(5077),
    [anon_sym_template] = ACTIONS(5077),
    [anon_sym_operator] = ACTIONS(5077),
    [anon_sym_friend] = ACTIONS(5077),
    [anon_sym_public] = ACTIONS(5077),
    [anon_sym_private] = ACTIONS(5077),
    [anon_sym_protected] = ACTIONS(5077),
    [anon_sym_using] = ACTIONS(5077),
    [anon_sym_static_assert] = ACTIONS(5077),
    [anon_sym_precise] = ACTIONS(5077),
    [anon_sym_shared] = ACTIONS(5077),
    [anon_sym_groupshared] = ACTIONS(5077),
    [anon_sym_uniform] = ACTIONS(5077),
    [anon_sym_row_major] = ACTIONS(5077),
    [anon_sym_column_major] = ACTIONS(5077),
    [anon_sym_globallycoherent] = ACTIONS(5077),
    [anon_sym_centroid] = ACTIONS(5077),
    [anon_sym_noperspective] = ACTIONS(5077),
    [anon_sym_nointerpolation] = ACTIONS(5077),
    [anon_sym_sample] = ACTIONS(5077),
    [anon_sym_linear] = ACTIONS(5077),
    [anon_sym_snorm] = ACTIONS(5077),
    [anon_sym_unorm] = ACTIONS(5077),
    [anon_sym_point] = ACTIONS(5077),
    [anon_sym_line] = ACTIONS(5077),
    [anon_sym_triangleadj] = ACTIONS(5077),
    [anon_sym_lineadj] = ACTIONS(5077),
    [anon_sym_triangle] = ACTIONS(5077),
  },
  [2149] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token2] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_friend] = ACTIONS(2324),
    [anon_sym_public] = ACTIONS(2324),
    [anon_sym_private] = ACTIONS(2324),
    [anon_sym_protected] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
  },
  [2150] = {
    [sym_identifier] = ACTIONS(2466),
    [aux_sym_preproc_def_token1] = ACTIONS(2466),
    [aux_sym_preproc_if_token1] = ACTIONS(2466),
    [aux_sym_preproc_if_token2] = ACTIONS(2466),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2466),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2466),
    [sym_preproc_directive] = ACTIONS(2466),
    [anon_sym_LPAREN2] = ACTIONS(2468),
    [anon_sym_TILDE] = ACTIONS(2468),
    [anon_sym_STAR] = ACTIONS(2468),
    [anon_sym_AMP_AMP] = ACTIONS(2468),
    [anon_sym_AMP] = ACTIONS(2466),
    [anon_sym___extension__] = ACTIONS(2466),
    [anon_sym_typedef] = ACTIONS(2466),
    [anon_sym_in] = ACTIONS(2466),
    [anon_sym_out] = ACTIONS(2466),
    [anon_sym_inout] = ACTIONS(2466),
    [anon_sym_extern] = ACTIONS(2466),
    [anon_sym___attribute__] = ACTIONS(2466),
    [anon_sym_COLON_COLON] = ACTIONS(2468),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2468),
    [anon_sym___declspec] = ACTIONS(2466),
    [anon_sym___based] = ACTIONS(2466),
    [anon_sym_signed] = ACTIONS(2466),
    [anon_sym_unsigned] = ACTIONS(2466),
    [anon_sym_long] = ACTIONS(2466),
    [anon_sym_short] = ACTIONS(2466),
    [anon_sym_LBRACK] = ACTIONS(2466),
    [anon_sym_static] = ACTIONS(2466),
    [anon_sym_register] = ACTIONS(2466),
    [anon_sym_inline] = ACTIONS(2466),
    [anon_sym___inline] = ACTIONS(2466),
    [anon_sym___inline__] = ACTIONS(2466),
    [anon_sym___forceinline] = ACTIONS(2466),
    [anon_sym_thread_local] = ACTIONS(2466),
    [anon_sym___thread] = ACTIONS(2466),
    [anon_sym_const] = ACTIONS(2466),
    [anon_sym_constexpr] = ACTIONS(2466),
    [anon_sym_volatile] = ACTIONS(2466),
    [anon_sym_restrict] = ACTIONS(2466),
    [anon_sym___restrict__] = ACTIONS(2466),
    [anon_sym__Atomic] = ACTIONS(2466),
    [anon_sym__Noreturn] = ACTIONS(2466),
    [anon_sym_noreturn] = ACTIONS(2466),
    [anon_sym_mutable] = ACTIONS(2466),
    [anon_sym_constinit] = ACTIONS(2466),
    [anon_sym_consteval] = ACTIONS(2466),
    [anon_sym_alignas] = ACTIONS(2466),
    [anon_sym__Alignas] = ACTIONS(2466),
    [sym_primitive_type] = ACTIONS(2466),
    [anon_sym_enum] = ACTIONS(2466),
    [anon_sym_class] = ACTIONS(2466),
    [anon_sym_struct] = ACTIONS(2466),
    [anon_sym_union] = ACTIONS(2466),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2466),
    [anon_sym_decltype] = ACTIONS(2466),
    [sym_virtual] = ACTIONS(2466),
    [anon_sym_explicit] = ACTIONS(2466),
    [anon_sym_typename] = ACTIONS(2466),
    [anon_sym_template] = ACTIONS(2466),
    [anon_sym_operator] = ACTIONS(2466),
    [anon_sym_friend] = ACTIONS(2466),
    [anon_sym_public] = ACTIONS(2466),
    [anon_sym_private] = ACTIONS(2466),
    [anon_sym_protected] = ACTIONS(2466),
    [anon_sym_using] = ACTIONS(2466),
    [anon_sym_static_assert] = ACTIONS(2466),
    [anon_sym_precise] = ACTIONS(2466),
    [anon_sym_shared] = ACTIONS(2466),
    [anon_sym_groupshared] = ACTIONS(2466),
    [anon_sym_uniform] = ACTIONS(2466),
    [anon_sym_row_major] = ACTIONS(2466),
    [anon_sym_column_major] = ACTIONS(2466),
    [anon_sym_globallycoherent] = ACTIONS(2466),
    [anon_sym_centroid] = ACTIONS(2466),
    [anon_sym_noperspective] = ACTIONS(2466),
    [anon_sym_nointerpolation] = ACTIONS(2466),
    [anon_sym_sample] = ACTIONS(2466),
    [anon_sym_linear] = ACTIONS(2466),
    [anon_sym_snorm] = ACTIONS(2466),
    [anon_sym_unorm] = ACTIONS(2466),
    [anon_sym_point] = ACTIONS(2466),
    [anon_sym_line] = ACTIONS(2466),
    [anon_sym_triangleadj] = ACTIONS(2466),
    [anon_sym_lineadj] = ACTIONS(2466),
    [anon_sym_triangle] = ACTIONS(2466),
  },
  [2151] = {
    [sym_identifier] = ACTIONS(2320),
    [aux_sym_preproc_def_token1] = ACTIONS(2320),
    [aux_sym_preproc_if_token1] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2320),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2320),
    [sym_preproc_directive] = ACTIONS(2320),
    [anon_sym_LPAREN2] = ACTIONS(2322),
    [anon_sym_TILDE] = ACTIONS(2322),
    [anon_sym_STAR] = ACTIONS(2322),
    [anon_sym_AMP_AMP] = ACTIONS(2322),
    [anon_sym_AMP] = ACTIONS(2320),
    [anon_sym___extension__] = ACTIONS(2320),
    [anon_sym_typedef] = ACTIONS(2320),
    [anon_sym_in] = ACTIONS(2320),
    [anon_sym_out] = ACTIONS(2320),
    [anon_sym_inout] = ACTIONS(2320),
    [anon_sym_extern] = ACTIONS(2320),
    [anon_sym___attribute__] = ACTIONS(2320),
    [anon_sym_COLON_COLON] = ACTIONS(2322),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2322),
    [anon_sym___declspec] = ACTIONS(2320),
    [anon_sym___based] = ACTIONS(2320),
    [anon_sym_RBRACE] = ACTIONS(2322),
    [anon_sym_signed] = ACTIONS(2320),
    [anon_sym_unsigned] = ACTIONS(2320),
    [anon_sym_long] = ACTIONS(2320),
    [anon_sym_short] = ACTIONS(2320),
    [anon_sym_LBRACK] = ACTIONS(2320),
    [anon_sym_static] = ACTIONS(2320),
    [anon_sym_register] = ACTIONS(2320),
    [anon_sym_inline] = ACTIONS(2320),
    [anon_sym___inline] = ACTIONS(2320),
    [anon_sym___inline__] = ACTIONS(2320),
    [anon_sym___forceinline] = ACTIONS(2320),
    [anon_sym_thread_local] = ACTIONS(2320),
    [anon_sym___thread] = ACTIONS(2320),
    [anon_sym_const] = ACTIONS(2320),
    [anon_sym_constexpr] = ACTIONS(2320),
    [anon_sym_volatile] = ACTIONS(2320),
    [anon_sym_restrict] = ACTIONS(2320),
    [anon_sym___restrict__] = ACTIONS(2320),
    [anon_sym__Atomic] = ACTIONS(2320),
    [anon_sym__Noreturn] = ACTIONS(2320),
    [anon_sym_noreturn] = ACTIONS(2320),
    [anon_sym_mutable] = ACTIONS(2320),
    [anon_sym_constinit] = ACTIONS(2320),
    [anon_sym_consteval] = ACTIONS(2320),
    [anon_sym_alignas] = ACTIONS(2320),
    [anon_sym__Alignas] = ACTIONS(2320),
    [sym_primitive_type] = ACTIONS(2320),
    [anon_sym_enum] = ACTIONS(2320),
    [anon_sym_class] = ACTIONS(2320),
    [anon_sym_struct] = ACTIONS(2320),
    [anon_sym_union] = ACTIONS(2320),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2320),
    [anon_sym_decltype] = ACTIONS(2320),
    [sym_virtual] = ACTIONS(2320),
    [anon_sym_explicit] = ACTIONS(2320),
    [anon_sym_typename] = ACTIONS(2320),
    [anon_sym_template] = ACTIONS(2320),
    [anon_sym_operator] = ACTIONS(2320),
    [anon_sym_friend] = ACTIONS(2320),
    [anon_sym_public] = ACTIONS(2320),
    [anon_sym_private] = ACTIONS(2320),
    [anon_sym_protected] = ACTIONS(2320),
    [anon_sym_using] = ACTIONS(2320),
    [anon_sym_static_assert] = ACTIONS(2320),
    [anon_sym_precise] = ACTIONS(2320),
    [anon_sym_shared] = ACTIONS(2320),
    [anon_sym_groupshared] = ACTIONS(2320),
    [anon_sym_uniform] = ACTIONS(2320),
    [anon_sym_row_major] = ACTIONS(2320),
    [anon_sym_column_major] = ACTIONS(2320),
    [anon_sym_globallycoherent] = ACTIONS(2320),
    [anon_sym_centroid] = ACTIONS(2320),
    [anon_sym_noperspective] = ACTIONS(2320),
    [anon_sym_nointerpolation] = ACTIONS(2320),
    [anon_sym_sample] = ACTIONS(2320),
    [anon_sym_linear] = ACTIONS(2320),
    [anon_sym_snorm] = ACTIONS(2320),
    [anon_sym_unorm] = ACTIONS(2320),
    [anon_sym_point] = ACTIONS(2320),
    [anon_sym_line] = ACTIONS(2320),
    [anon_sym_triangleadj] = ACTIONS(2320),
    [anon_sym_lineadj] = ACTIONS(2320),
    [anon_sym_triangle] = ACTIONS(2320),
  },
  [2152] = {
    [sym_identifier] = ACTIONS(5073),
    [aux_sym_preproc_def_token1] = ACTIONS(5073),
    [aux_sym_preproc_if_token1] = ACTIONS(5073),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5073),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5073),
    [sym_preproc_directive] = ACTIONS(5073),
    [anon_sym_LPAREN2] = ACTIONS(5075),
    [anon_sym_TILDE] = ACTIONS(5075),
    [anon_sym_STAR] = ACTIONS(5075),
    [anon_sym_AMP_AMP] = ACTIONS(5075),
    [anon_sym_AMP] = ACTIONS(5073),
    [anon_sym___extension__] = ACTIONS(5073),
    [anon_sym_typedef] = ACTIONS(5073),
    [anon_sym_in] = ACTIONS(5073),
    [anon_sym_out] = ACTIONS(5073),
    [anon_sym_inout] = ACTIONS(5073),
    [anon_sym_extern] = ACTIONS(5073),
    [anon_sym___attribute__] = ACTIONS(5073),
    [anon_sym_COLON_COLON] = ACTIONS(5075),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5075),
    [anon_sym___declspec] = ACTIONS(5073),
    [anon_sym___based] = ACTIONS(5073),
    [anon_sym_RBRACE] = ACTIONS(5075),
    [anon_sym_signed] = ACTIONS(5073),
    [anon_sym_unsigned] = ACTIONS(5073),
    [anon_sym_long] = ACTIONS(5073),
    [anon_sym_short] = ACTIONS(5073),
    [anon_sym_LBRACK] = ACTIONS(5073),
    [anon_sym_static] = ACTIONS(5073),
    [anon_sym_register] = ACTIONS(5073),
    [anon_sym_inline] = ACTIONS(5073),
    [anon_sym___inline] = ACTIONS(5073),
    [anon_sym___inline__] = ACTIONS(5073),
    [anon_sym___forceinline] = ACTIONS(5073),
    [anon_sym_thread_local] = ACTIONS(5073),
    [anon_sym___thread] = ACTIONS(5073),
    [anon_sym_const] = ACTIONS(5073),
    [anon_sym_constexpr] = ACTIONS(5073),
    [anon_sym_volatile] = ACTIONS(5073),
    [anon_sym_restrict] = ACTIONS(5073),
    [anon_sym___restrict__] = ACTIONS(5073),
    [anon_sym__Atomic] = ACTIONS(5073),
    [anon_sym__Noreturn] = ACTIONS(5073),
    [anon_sym_noreturn] = ACTIONS(5073),
    [anon_sym_mutable] = ACTIONS(5073),
    [anon_sym_constinit] = ACTIONS(5073),
    [anon_sym_consteval] = ACTIONS(5073),
    [anon_sym_alignas] = ACTIONS(5073),
    [anon_sym__Alignas] = ACTIONS(5073),
    [sym_primitive_type] = ACTIONS(5073),
    [anon_sym_enum] = ACTIONS(5073),
    [anon_sym_class] = ACTIONS(5073),
    [anon_sym_struct] = ACTIONS(5073),
    [anon_sym_union] = ACTIONS(5073),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5073),
    [anon_sym_decltype] = ACTIONS(5073),
    [sym_virtual] = ACTIONS(5073),
    [anon_sym_explicit] = ACTIONS(5073),
    [anon_sym_typename] = ACTIONS(5073),
    [anon_sym_template] = ACTIONS(5073),
    [anon_sym_operator] = ACTIONS(5073),
    [anon_sym_friend] = ACTIONS(5073),
    [anon_sym_public] = ACTIONS(5073),
    [anon_sym_private] = ACTIONS(5073),
    [anon_sym_protected] = ACTIONS(5073),
    [anon_sym_using] = ACTIONS(5073),
    [anon_sym_static_assert] = ACTIONS(5073),
    [anon_sym_precise] = ACTIONS(5073),
    [anon_sym_shared] = ACTIONS(5073),
    [anon_sym_groupshared] = ACTIONS(5073),
    [anon_sym_uniform] = ACTIONS(5073),
    [anon_sym_row_major] = ACTIONS(5073),
    [anon_sym_column_major] = ACTIONS(5073),
    [anon_sym_globallycoherent] = ACTIONS(5073),
    [anon_sym_centroid] = ACTIONS(5073),
    [anon_sym_noperspective] = ACTIONS(5073),
    [anon_sym_nointerpolation] = ACTIONS(5073),
    [anon_sym_sample] = ACTIONS(5073),
    [anon_sym_linear] = ACTIONS(5073),
    [anon_sym_snorm] = ACTIONS(5073),
    [anon_sym_unorm] = ACTIONS(5073),
    [anon_sym_point] = ACTIONS(5073),
    [anon_sym_line] = ACTIONS(5073),
    [anon_sym_triangleadj] = ACTIONS(5073),
    [anon_sym_lineadj] = ACTIONS(5073),
    [anon_sym_triangle] = ACTIONS(5073),
  },
  [2153] = {
    [sym_identifier] = ACTIONS(5073),
    [aux_sym_preproc_def_token1] = ACTIONS(5073),
    [aux_sym_preproc_if_token1] = ACTIONS(5073),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5073),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5073),
    [sym_preproc_directive] = ACTIONS(5073),
    [anon_sym_LPAREN2] = ACTIONS(5075),
    [anon_sym_TILDE] = ACTIONS(5075),
    [anon_sym_STAR] = ACTIONS(5075),
    [anon_sym_AMP_AMP] = ACTIONS(5075),
    [anon_sym_AMP] = ACTIONS(5073),
    [anon_sym___extension__] = ACTIONS(5073),
    [anon_sym_typedef] = ACTIONS(5073),
    [anon_sym_in] = ACTIONS(5073),
    [anon_sym_out] = ACTIONS(5073),
    [anon_sym_inout] = ACTIONS(5073),
    [anon_sym_extern] = ACTIONS(5073),
    [anon_sym___attribute__] = ACTIONS(5073),
    [anon_sym_COLON_COLON] = ACTIONS(5075),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5075),
    [anon_sym___declspec] = ACTIONS(5073),
    [anon_sym___based] = ACTIONS(5073),
    [anon_sym_RBRACE] = ACTIONS(5075),
    [anon_sym_signed] = ACTIONS(5073),
    [anon_sym_unsigned] = ACTIONS(5073),
    [anon_sym_long] = ACTIONS(5073),
    [anon_sym_short] = ACTIONS(5073),
    [anon_sym_LBRACK] = ACTIONS(5073),
    [anon_sym_static] = ACTIONS(5073),
    [anon_sym_register] = ACTIONS(5073),
    [anon_sym_inline] = ACTIONS(5073),
    [anon_sym___inline] = ACTIONS(5073),
    [anon_sym___inline__] = ACTIONS(5073),
    [anon_sym___forceinline] = ACTIONS(5073),
    [anon_sym_thread_local] = ACTIONS(5073),
    [anon_sym___thread] = ACTIONS(5073),
    [anon_sym_const] = ACTIONS(5073),
    [anon_sym_constexpr] = ACTIONS(5073),
    [anon_sym_volatile] = ACTIONS(5073),
    [anon_sym_restrict] = ACTIONS(5073),
    [anon_sym___restrict__] = ACTIONS(5073),
    [anon_sym__Atomic] = ACTIONS(5073),
    [anon_sym__Noreturn] = ACTIONS(5073),
    [anon_sym_noreturn] = ACTIONS(5073),
    [anon_sym_mutable] = ACTIONS(5073),
    [anon_sym_constinit] = ACTIONS(5073),
    [anon_sym_consteval] = ACTIONS(5073),
    [anon_sym_alignas] = ACTIONS(5073),
    [anon_sym__Alignas] = ACTIONS(5073),
    [sym_primitive_type] = ACTIONS(5073),
    [anon_sym_enum] = ACTIONS(5073),
    [anon_sym_class] = ACTIONS(5073),
    [anon_sym_struct] = ACTIONS(5073),
    [anon_sym_union] = ACTIONS(5073),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5073),
    [anon_sym_decltype] = ACTIONS(5073),
    [sym_virtual] = ACTIONS(5073),
    [anon_sym_explicit] = ACTIONS(5073),
    [anon_sym_typename] = ACTIONS(5073),
    [anon_sym_template] = ACTIONS(5073),
    [anon_sym_operator] = ACTIONS(5073),
    [anon_sym_friend] = ACTIONS(5073),
    [anon_sym_public] = ACTIONS(5073),
    [anon_sym_private] = ACTIONS(5073),
    [anon_sym_protected] = ACTIONS(5073),
    [anon_sym_using] = ACTIONS(5073),
    [anon_sym_static_assert] = ACTIONS(5073),
    [anon_sym_precise] = ACTIONS(5073),
    [anon_sym_shared] = ACTIONS(5073),
    [anon_sym_groupshared] = ACTIONS(5073),
    [anon_sym_uniform] = ACTIONS(5073),
    [anon_sym_row_major] = ACTIONS(5073),
    [anon_sym_column_major] = ACTIONS(5073),
    [anon_sym_globallycoherent] = ACTIONS(5073),
    [anon_sym_centroid] = ACTIONS(5073),
    [anon_sym_noperspective] = ACTIONS(5073),
    [anon_sym_nointerpolation] = ACTIONS(5073),
    [anon_sym_sample] = ACTIONS(5073),
    [anon_sym_linear] = ACTIONS(5073),
    [anon_sym_snorm] = ACTIONS(5073),
    [anon_sym_unorm] = ACTIONS(5073),
    [anon_sym_point] = ACTIONS(5073),
    [anon_sym_line] = ACTIONS(5073),
    [anon_sym_triangleadj] = ACTIONS(5073),
    [anon_sym_lineadj] = ACTIONS(5073),
    [anon_sym_triangle] = ACTIONS(5073),
  },
  [2154] = {
    [sym_identifier] = ACTIONS(5069),
    [aux_sym_preproc_def_token1] = ACTIONS(5069),
    [aux_sym_preproc_if_token1] = ACTIONS(5069),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5069),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5069),
    [sym_preproc_directive] = ACTIONS(5069),
    [anon_sym_LPAREN2] = ACTIONS(5071),
    [anon_sym_TILDE] = ACTIONS(5071),
    [anon_sym_STAR] = ACTIONS(5071),
    [anon_sym_AMP_AMP] = ACTIONS(5071),
    [anon_sym_AMP] = ACTIONS(5069),
    [anon_sym___extension__] = ACTIONS(5069),
    [anon_sym_typedef] = ACTIONS(5069),
    [anon_sym_in] = ACTIONS(5069),
    [anon_sym_out] = ACTIONS(5069),
    [anon_sym_inout] = ACTIONS(5069),
    [anon_sym_extern] = ACTIONS(5069),
    [anon_sym___attribute__] = ACTIONS(5069),
    [anon_sym_COLON_COLON] = ACTIONS(5071),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5071),
    [anon_sym___declspec] = ACTIONS(5069),
    [anon_sym___based] = ACTIONS(5069),
    [anon_sym_RBRACE] = ACTIONS(5071),
    [anon_sym_signed] = ACTIONS(5069),
    [anon_sym_unsigned] = ACTIONS(5069),
    [anon_sym_long] = ACTIONS(5069),
    [anon_sym_short] = ACTIONS(5069),
    [anon_sym_LBRACK] = ACTIONS(5069),
    [anon_sym_static] = ACTIONS(5069),
    [anon_sym_register] = ACTIONS(5069),
    [anon_sym_inline] = ACTIONS(5069),
    [anon_sym___inline] = ACTIONS(5069),
    [anon_sym___inline__] = ACTIONS(5069),
    [anon_sym___forceinline] = ACTIONS(5069),
    [anon_sym_thread_local] = ACTIONS(5069),
    [anon_sym___thread] = ACTIONS(5069),
    [anon_sym_const] = ACTIONS(5069),
    [anon_sym_constexpr] = ACTIONS(5069),
    [anon_sym_volatile] = ACTIONS(5069),
    [anon_sym_restrict] = ACTIONS(5069),
    [anon_sym___restrict__] = ACTIONS(5069),
    [anon_sym__Atomic] = ACTIONS(5069),
    [anon_sym__Noreturn] = ACTIONS(5069),
    [anon_sym_noreturn] = ACTIONS(5069),
    [anon_sym_mutable] = ACTIONS(5069),
    [anon_sym_constinit] = ACTIONS(5069),
    [anon_sym_consteval] = ACTIONS(5069),
    [anon_sym_alignas] = ACTIONS(5069),
    [anon_sym__Alignas] = ACTIONS(5069),
    [sym_primitive_type] = ACTIONS(5069),
    [anon_sym_enum] = ACTIONS(5069),
    [anon_sym_class] = ACTIONS(5069),
    [anon_sym_struct] = ACTIONS(5069),
    [anon_sym_union] = ACTIONS(5069),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5069),
    [anon_sym_decltype] = ACTIONS(5069),
    [sym_virtual] = ACTIONS(5069),
    [anon_sym_explicit] = ACTIONS(5069),
    [anon_sym_typename] = ACTIONS(5069),
    [anon_sym_template] = ACTIONS(5069),
    [anon_sym_operator] = ACTIONS(5069),
    [anon_sym_friend] = ACTIONS(5069),
    [anon_sym_public] = ACTIONS(5069),
    [anon_sym_private] = ACTIONS(5069),
    [anon_sym_protected] = ACTIONS(5069),
    [anon_sym_using] = ACTIONS(5069),
    [anon_sym_static_assert] = ACTIONS(5069),
    [anon_sym_precise] = ACTIONS(5069),
    [anon_sym_shared] = ACTIONS(5069),
    [anon_sym_groupshared] = ACTIONS(5069),
    [anon_sym_uniform] = ACTIONS(5069),
    [anon_sym_row_major] = ACTIONS(5069),
    [anon_sym_column_major] = ACTIONS(5069),
    [anon_sym_globallycoherent] = ACTIONS(5069),
    [anon_sym_centroid] = ACTIONS(5069),
    [anon_sym_noperspective] = ACTIONS(5069),
    [anon_sym_nointerpolation] = ACTIONS(5069),
    [anon_sym_sample] = ACTIONS(5069),
    [anon_sym_linear] = ACTIONS(5069),
    [anon_sym_snorm] = ACTIONS(5069),
    [anon_sym_unorm] = ACTIONS(5069),
    [anon_sym_point] = ACTIONS(5069),
    [anon_sym_line] = ACTIONS(5069),
    [anon_sym_triangleadj] = ACTIONS(5069),
    [anon_sym_lineadj] = ACTIONS(5069),
    [anon_sym_triangle] = ACTIONS(5069),
  },
  [2155] = {
    [sym_identifier] = ACTIONS(5057),
    [aux_sym_preproc_def_token1] = ACTIONS(5057),
    [aux_sym_preproc_if_token1] = ACTIONS(5057),
    [aux_sym_preproc_if_token2] = ACTIONS(5057),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5057),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5057),
    [sym_preproc_directive] = ACTIONS(5057),
    [anon_sym_LPAREN2] = ACTIONS(5059),
    [anon_sym_TILDE] = ACTIONS(5059),
    [anon_sym_STAR] = ACTIONS(5059),
    [anon_sym_AMP_AMP] = ACTIONS(5059),
    [anon_sym_AMP] = ACTIONS(5057),
    [anon_sym___extension__] = ACTIONS(5057),
    [anon_sym_typedef] = ACTIONS(5057),
    [anon_sym_in] = ACTIONS(5057),
    [anon_sym_out] = ACTIONS(5057),
    [anon_sym_inout] = ACTIONS(5057),
    [anon_sym_extern] = ACTIONS(5057),
    [anon_sym___attribute__] = ACTIONS(5057),
    [anon_sym_COLON_COLON] = ACTIONS(5059),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5059),
    [anon_sym___declspec] = ACTIONS(5057),
    [anon_sym___based] = ACTIONS(5057),
    [anon_sym_signed] = ACTIONS(5057),
    [anon_sym_unsigned] = ACTIONS(5057),
    [anon_sym_long] = ACTIONS(5057),
    [anon_sym_short] = ACTIONS(5057),
    [anon_sym_LBRACK] = ACTIONS(5057),
    [anon_sym_static] = ACTIONS(5057),
    [anon_sym_register] = ACTIONS(5057),
    [anon_sym_inline] = ACTIONS(5057),
    [anon_sym___inline] = ACTIONS(5057),
    [anon_sym___inline__] = ACTIONS(5057),
    [anon_sym___forceinline] = ACTIONS(5057),
    [anon_sym_thread_local] = ACTIONS(5057),
    [anon_sym___thread] = ACTIONS(5057),
    [anon_sym_const] = ACTIONS(5057),
    [anon_sym_constexpr] = ACTIONS(5057),
    [anon_sym_volatile] = ACTIONS(5057),
    [anon_sym_restrict] = ACTIONS(5057),
    [anon_sym___restrict__] = ACTIONS(5057),
    [anon_sym__Atomic] = ACTIONS(5057),
    [anon_sym__Noreturn] = ACTIONS(5057),
    [anon_sym_noreturn] = ACTIONS(5057),
    [anon_sym_mutable] = ACTIONS(5057),
    [anon_sym_constinit] = ACTIONS(5057),
    [anon_sym_consteval] = ACTIONS(5057),
    [anon_sym_alignas] = ACTIONS(5057),
    [anon_sym__Alignas] = ACTIONS(5057),
    [sym_primitive_type] = ACTIONS(5057),
    [anon_sym_enum] = ACTIONS(5057),
    [anon_sym_class] = ACTIONS(5057),
    [anon_sym_struct] = ACTIONS(5057),
    [anon_sym_union] = ACTIONS(5057),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5057),
    [anon_sym_decltype] = ACTIONS(5057),
    [sym_virtual] = ACTIONS(5057),
    [anon_sym_explicit] = ACTIONS(5057),
    [anon_sym_typename] = ACTIONS(5057),
    [anon_sym_template] = ACTIONS(5057),
    [anon_sym_operator] = ACTIONS(5057),
    [anon_sym_friend] = ACTIONS(5057),
    [anon_sym_public] = ACTIONS(5057),
    [anon_sym_private] = ACTIONS(5057),
    [anon_sym_protected] = ACTIONS(5057),
    [anon_sym_using] = ACTIONS(5057),
    [anon_sym_static_assert] = ACTIONS(5057),
    [anon_sym_precise] = ACTIONS(5057),
    [anon_sym_shared] = ACTIONS(5057),
    [anon_sym_groupshared] = ACTIONS(5057),
    [anon_sym_uniform] = ACTIONS(5057),
    [anon_sym_row_major] = ACTIONS(5057),
    [anon_sym_column_major] = ACTIONS(5057),
    [anon_sym_globallycoherent] = ACTIONS(5057),
    [anon_sym_centroid] = ACTIONS(5057),
    [anon_sym_noperspective] = ACTIONS(5057),
    [anon_sym_nointerpolation] = ACTIONS(5057),
    [anon_sym_sample] = ACTIONS(5057),
    [anon_sym_linear] = ACTIONS(5057),
    [anon_sym_snorm] = ACTIONS(5057),
    [anon_sym_unorm] = ACTIONS(5057),
    [anon_sym_point] = ACTIONS(5057),
    [anon_sym_line] = ACTIONS(5057),
    [anon_sym_triangleadj] = ACTIONS(5057),
    [anon_sym_lineadj] = ACTIONS(5057),
    [anon_sym_triangle] = ACTIONS(5057),
  },
  [2156] = {
    [sym_identifier] = ACTIONS(2470),
    [aux_sym_preproc_def_token1] = ACTIONS(2470),
    [aux_sym_preproc_if_token1] = ACTIONS(2470),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2470),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2470),
    [sym_preproc_directive] = ACTIONS(2470),
    [anon_sym_LPAREN2] = ACTIONS(2472),
    [anon_sym_TILDE] = ACTIONS(2472),
    [anon_sym_STAR] = ACTIONS(2472),
    [anon_sym_AMP_AMP] = ACTIONS(2472),
    [anon_sym_AMP] = ACTIONS(2470),
    [anon_sym___extension__] = ACTIONS(2470),
    [anon_sym_typedef] = ACTIONS(2470),
    [anon_sym_in] = ACTIONS(2470),
    [anon_sym_out] = ACTIONS(2470),
    [anon_sym_inout] = ACTIONS(2470),
    [anon_sym_extern] = ACTIONS(2470),
    [anon_sym___attribute__] = ACTIONS(2470),
    [anon_sym_COLON_COLON] = ACTIONS(2472),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2472),
    [anon_sym___declspec] = ACTIONS(2470),
    [anon_sym___based] = ACTIONS(2470),
    [anon_sym_RBRACE] = ACTIONS(2472),
    [anon_sym_signed] = ACTIONS(2470),
    [anon_sym_unsigned] = ACTIONS(2470),
    [anon_sym_long] = ACTIONS(2470),
    [anon_sym_short] = ACTIONS(2470),
    [anon_sym_LBRACK] = ACTIONS(2470),
    [anon_sym_static] = ACTIONS(2470),
    [anon_sym_register] = ACTIONS(2470),
    [anon_sym_inline] = ACTIONS(2470),
    [anon_sym___inline] = ACTIONS(2470),
    [anon_sym___inline__] = ACTIONS(2470),
    [anon_sym___forceinline] = ACTIONS(2470),
    [anon_sym_thread_local] = ACTIONS(2470),
    [anon_sym___thread] = ACTIONS(2470),
    [anon_sym_const] = ACTIONS(2470),
    [anon_sym_constexpr] = ACTIONS(2470),
    [anon_sym_volatile] = ACTIONS(2470),
    [anon_sym_restrict] = ACTIONS(2470),
    [anon_sym___restrict__] = ACTIONS(2470),
    [anon_sym__Atomic] = ACTIONS(2470),
    [anon_sym__Noreturn] = ACTIONS(2470),
    [anon_sym_noreturn] = ACTIONS(2470),
    [anon_sym_mutable] = ACTIONS(2470),
    [anon_sym_constinit] = ACTIONS(2470),
    [anon_sym_consteval] = ACTIONS(2470),
    [anon_sym_alignas] = ACTIONS(2470),
    [anon_sym__Alignas] = ACTIONS(2470),
    [sym_primitive_type] = ACTIONS(2470),
    [anon_sym_enum] = ACTIONS(2470),
    [anon_sym_class] = ACTIONS(2470),
    [anon_sym_struct] = ACTIONS(2470),
    [anon_sym_union] = ACTIONS(2470),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2470),
    [anon_sym_decltype] = ACTIONS(2470),
    [sym_virtual] = ACTIONS(2470),
    [anon_sym_explicit] = ACTIONS(2470),
    [anon_sym_typename] = ACTIONS(2470),
    [anon_sym_template] = ACTIONS(2470),
    [anon_sym_operator] = ACTIONS(2470),
    [anon_sym_friend] = ACTIONS(2470),
    [anon_sym_public] = ACTIONS(2470),
    [anon_sym_private] = ACTIONS(2470),
    [anon_sym_protected] = ACTIONS(2470),
    [anon_sym_using] = ACTIONS(2470),
    [anon_sym_static_assert] = ACTIONS(2470),
    [anon_sym_precise] = ACTIONS(2470),
    [anon_sym_shared] = ACTIONS(2470),
    [anon_sym_groupshared] = ACTIONS(2470),
    [anon_sym_uniform] = ACTIONS(2470),
    [anon_sym_row_major] = ACTIONS(2470),
    [anon_sym_column_major] = ACTIONS(2470),
    [anon_sym_globallycoherent] = ACTIONS(2470),
    [anon_sym_centroid] = ACTIONS(2470),
    [anon_sym_noperspective] = ACTIONS(2470),
    [anon_sym_nointerpolation] = ACTIONS(2470),
    [anon_sym_sample] = ACTIONS(2470),
    [anon_sym_linear] = ACTIONS(2470),
    [anon_sym_snorm] = ACTIONS(2470),
    [anon_sym_unorm] = ACTIONS(2470),
    [anon_sym_point] = ACTIONS(2470),
    [anon_sym_line] = ACTIONS(2470),
    [anon_sym_triangleadj] = ACTIONS(2470),
    [anon_sym_lineadj] = ACTIONS(2470),
    [anon_sym_triangle] = ACTIONS(2470),
  },
  [2157] = {
    [sym_identifier] = ACTIONS(5013),
    [aux_sym_preproc_def_token1] = ACTIONS(5013),
    [aux_sym_preproc_if_token1] = ACTIONS(5013),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5013),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5013),
    [sym_preproc_directive] = ACTIONS(5013),
    [anon_sym_LPAREN2] = ACTIONS(5015),
    [anon_sym_TILDE] = ACTIONS(5015),
    [anon_sym_STAR] = ACTIONS(5015),
    [anon_sym_AMP_AMP] = ACTIONS(5015),
    [anon_sym_AMP] = ACTIONS(5013),
    [anon_sym___extension__] = ACTIONS(5013),
    [anon_sym_typedef] = ACTIONS(5013),
    [anon_sym_in] = ACTIONS(5013),
    [anon_sym_out] = ACTIONS(5013),
    [anon_sym_inout] = ACTIONS(5013),
    [anon_sym_extern] = ACTIONS(5013),
    [anon_sym___attribute__] = ACTIONS(5013),
    [anon_sym_COLON_COLON] = ACTIONS(5015),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5015),
    [anon_sym___declspec] = ACTIONS(5013),
    [anon_sym___based] = ACTIONS(5013),
    [anon_sym_RBRACE] = ACTIONS(5015),
    [anon_sym_signed] = ACTIONS(5013),
    [anon_sym_unsigned] = ACTIONS(5013),
    [anon_sym_long] = ACTIONS(5013),
    [anon_sym_short] = ACTIONS(5013),
    [anon_sym_LBRACK] = ACTIONS(5013),
    [anon_sym_static] = ACTIONS(5013),
    [anon_sym_register] = ACTIONS(5013),
    [anon_sym_inline] = ACTIONS(5013),
    [anon_sym___inline] = ACTIONS(5013),
    [anon_sym___inline__] = ACTIONS(5013),
    [anon_sym___forceinline] = ACTIONS(5013),
    [anon_sym_thread_local] = ACTIONS(5013),
    [anon_sym___thread] = ACTIONS(5013),
    [anon_sym_const] = ACTIONS(5013),
    [anon_sym_constexpr] = ACTIONS(5013),
    [anon_sym_volatile] = ACTIONS(5013),
    [anon_sym_restrict] = ACTIONS(5013),
    [anon_sym___restrict__] = ACTIONS(5013),
    [anon_sym__Atomic] = ACTIONS(5013),
    [anon_sym__Noreturn] = ACTIONS(5013),
    [anon_sym_noreturn] = ACTIONS(5013),
    [anon_sym_mutable] = ACTIONS(5013),
    [anon_sym_constinit] = ACTIONS(5013),
    [anon_sym_consteval] = ACTIONS(5013),
    [anon_sym_alignas] = ACTIONS(5013),
    [anon_sym__Alignas] = ACTIONS(5013),
    [sym_primitive_type] = ACTIONS(5013),
    [anon_sym_enum] = ACTIONS(5013),
    [anon_sym_class] = ACTIONS(5013),
    [anon_sym_struct] = ACTIONS(5013),
    [anon_sym_union] = ACTIONS(5013),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5013),
    [anon_sym_decltype] = ACTIONS(5013),
    [sym_virtual] = ACTIONS(5013),
    [anon_sym_explicit] = ACTIONS(5013),
    [anon_sym_typename] = ACTIONS(5013),
    [anon_sym_template] = ACTIONS(5013),
    [anon_sym_operator] = ACTIONS(5013),
    [anon_sym_friend] = ACTIONS(5013),
    [anon_sym_public] = ACTIONS(5013),
    [anon_sym_private] = ACTIONS(5013),
    [anon_sym_protected] = ACTIONS(5013),
    [anon_sym_using] = ACTIONS(5013),
    [anon_sym_static_assert] = ACTIONS(5013),
    [anon_sym_precise] = ACTIONS(5013),
    [anon_sym_shared] = ACTIONS(5013),
    [anon_sym_groupshared] = ACTIONS(5013),
    [anon_sym_uniform] = ACTIONS(5013),
    [anon_sym_row_major] = ACTIONS(5013),
    [anon_sym_column_major] = ACTIONS(5013),
    [anon_sym_globallycoherent] = ACTIONS(5013),
    [anon_sym_centroid] = ACTIONS(5013),
    [anon_sym_noperspective] = ACTIONS(5013),
    [anon_sym_nointerpolation] = ACTIONS(5013),
    [anon_sym_sample] = ACTIONS(5013),
    [anon_sym_linear] = ACTIONS(5013),
    [anon_sym_snorm] = ACTIONS(5013),
    [anon_sym_unorm] = ACTIONS(5013),
    [anon_sym_point] = ACTIONS(5013),
    [anon_sym_line] = ACTIONS(5013),
    [anon_sym_triangleadj] = ACTIONS(5013),
    [anon_sym_lineadj] = ACTIONS(5013),
    [anon_sym_triangle] = ACTIONS(5013),
  },
  [2158] = {
    [sym_identifier] = ACTIONS(5013),
    [aux_sym_preproc_def_token1] = ACTIONS(5013),
    [aux_sym_preproc_if_token1] = ACTIONS(5013),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5013),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5013),
    [sym_preproc_directive] = ACTIONS(5013),
    [anon_sym_LPAREN2] = ACTIONS(5015),
    [anon_sym_TILDE] = ACTIONS(5015),
    [anon_sym_STAR] = ACTIONS(5015),
    [anon_sym_AMP_AMP] = ACTIONS(5015),
    [anon_sym_AMP] = ACTIONS(5013),
    [anon_sym___extension__] = ACTIONS(5013),
    [anon_sym_typedef] = ACTIONS(5013),
    [anon_sym_in] = ACTIONS(5013),
    [anon_sym_out] = ACTIONS(5013),
    [anon_sym_inout] = ACTIONS(5013),
    [anon_sym_extern] = ACTIONS(5013),
    [anon_sym___attribute__] = ACTIONS(5013),
    [anon_sym_COLON_COLON] = ACTIONS(5015),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5015),
    [anon_sym___declspec] = ACTIONS(5013),
    [anon_sym___based] = ACTIONS(5013),
    [anon_sym_RBRACE] = ACTIONS(5015),
    [anon_sym_signed] = ACTIONS(5013),
    [anon_sym_unsigned] = ACTIONS(5013),
    [anon_sym_long] = ACTIONS(5013),
    [anon_sym_short] = ACTIONS(5013),
    [anon_sym_LBRACK] = ACTIONS(5013),
    [anon_sym_static] = ACTIONS(5013),
    [anon_sym_register] = ACTIONS(5013),
    [anon_sym_inline] = ACTIONS(5013),
    [anon_sym___inline] = ACTIONS(5013),
    [anon_sym___inline__] = ACTIONS(5013),
    [anon_sym___forceinline] = ACTIONS(5013),
    [anon_sym_thread_local] = ACTIONS(5013),
    [anon_sym___thread] = ACTIONS(5013),
    [anon_sym_const] = ACTIONS(5013),
    [anon_sym_constexpr] = ACTIONS(5013),
    [anon_sym_volatile] = ACTIONS(5013),
    [anon_sym_restrict] = ACTIONS(5013),
    [anon_sym___restrict__] = ACTIONS(5013),
    [anon_sym__Atomic] = ACTIONS(5013),
    [anon_sym__Noreturn] = ACTIONS(5013),
    [anon_sym_noreturn] = ACTIONS(5013),
    [anon_sym_mutable] = ACTIONS(5013),
    [anon_sym_constinit] = ACTIONS(5013),
    [anon_sym_consteval] = ACTIONS(5013),
    [anon_sym_alignas] = ACTIONS(5013),
    [anon_sym__Alignas] = ACTIONS(5013),
    [sym_primitive_type] = ACTIONS(5013),
    [anon_sym_enum] = ACTIONS(5013),
    [anon_sym_class] = ACTIONS(5013),
    [anon_sym_struct] = ACTIONS(5013),
    [anon_sym_union] = ACTIONS(5013),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5013),
    [anon_sym_decltype] = ACTIONS(5013),
    [sym_virtual] = ACTIONS(5013),
    [anon_sym_explicit] = ACTIONS(5013),
    [anon_sym_typename] = ACTIONS(5013),
    [anon_sym_template] = ACTIONS(5013),
    [anon_sym_operator] = ACTIONS(5013),
    [anon_sym_friend] = ACTIONS(5013),
    [anon_sym_public] = ACTIONS(5013),
    [anon_sym_private] = ACTIONS(5013),
    [anon_sym_protected] = ACTIONS(5013),
    [anon_sym_using] = ACTIONS(5013),
    [anon_sym_static_assert] = ACTIONS(5013),
    [anon_sym_precise] = ACTIONS(5013),
    [anon_sym_shared] = ACTIONS(5013),
    [anon_sym_groupshared] = ACTIONS(5013),
    [anon_sym_uniform] = ACTIONS(5013),
    [anon_sym_row_major] = ACTIONS(5013),
    [anon_sym_column_major] = ACTIONS(5013),
    [anon_sym_globallycoherent] = ACTIONS(5013),
    [anon_sym_centroid] = ACTIONS(5013),
    [anon_sym_noperspective] = ACTIONS(5013),
    [anon_sym_nointerpolation] = ACTIONS(5013),
    [anon_sym_sample] = ACTIONS(5013),
    [anon_sym_linear] = ACTIONS(5013),
    [anon_sym_snorm] = ACTIONS(5013),
    [anon_sym_unorm] = ACTIONS(5013),
    [anon_sym_point] = ACTIONS(5013),
    [anon_sym_line] = ACTIONS(5013),
    [anon_sym_triangleadj] = ACTIONS(5013),
    [anon_sym_lineadj] = ACTIONS(5013),
    [anon_sym_triangle] = ACTIONS(5013),
  },
  [2159] = {
    [sym_identifier] = ACTIONS(2324),
    [aux_sym_preproc_def_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token1] = ACTIONS(2324),
    [aux_sym_preproc_if_token2] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2324),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2324),
    [sym_preproc_directive] = ACTIONS(2324),
    [anon_sym_LPAREN2] = ACTIONS(2326),
    [anon_sym_TILDE] = ACTIONS(2326),
    [anon_sym_STAR] = ACTIONS(2326),
    [anon_sym_AMP_AMP] = ACTIONS(2326),
    [anon_sym_AMP] = ACTIONS(2324),
    [anon_sym___extension__] = ACTIONS(2324),
    [anon_sym_typedef] = ACTIONS(2324),
    [anon_sym_in] = ACTIONS(2324),
    [anon_sym_out] = ACTIONS(2324),
    [anon_sym_inout] = ACTIONS(2324),
    [anon_sym_extern] = ACTIONS(2324),
    [anon_sym___attribute__] = ACTIONS(2324),
    [anon_sym_COLON_COLON] = ACTIONS(2326),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2326),
    [anon_sym___declspec] = ACTIONS(2324),
    [anon_sym___based] = ACTIONS(2324),
    [anon_sym_signed] = ACTIONS(2324),
    [anon_sym_unsigned] = ACTIONS(2324),
    [anon_sym_long] = ACTIONS(2324),
    [anon_sym_short] = ACTIONS(2324),
    [anon_sym_LBRACK] = ACTIONS(2324),
    [anon_sym_static] = ACTIONS(2324),
    [anon_sym_register] = ACTIONS(2324),
    [anon_sym_inline] = ACTIONS(2324),
    [anon_sym___inline] = ACTIONS(2324),
    [anon_sym___inline__] = ACTIONS(2324),
    [anon_sym___forceinline] = ACTIONS(2324),
    [anon_sym_thread_local] = ACTIONS(2324),
    [anon_sym___thread] = ACTIONS(2324),
    [anon_sym_const] = ACTIONS(2324),
    [anon_sym_constexpr] = ACTIONS(2324),
    [anon_sym_volatile] = ACTIONS(2324),
    [anon_sym_restrict] = ACTIONS(2324),
    [anon_sym___restrict__] = ACTIONS(2324),
    [anon_sym__Atomic] = ACTIONS(2324),
    [anon_sym__Noreturn] = ACTIONS(2324),
    [anon_sym_noreturn] = ACTIONS(2324),
    [anon_sym_mutable] = ACTIONS(2324),
    [anon_sym_constinit] = ACTIONS(2324),
    [anon_sym_consteval] = ACTIONS(2324),
    [anon_sym_alignas] = ACTIONS(2324),
    [anon_sym__Alignas] = ACTIONS(2324),
    [sym_primitive_type] = ACTIONS(2324),
    [anon_sym_enum] = ACTIONS(2324),
    [anon_sym_class] = ACTIONS(2324),
    [anon_sym_struct] = ACTIONS(2324),
    [anon_sym_union] = ACTIONS(2324),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2324),
    [anon_sym_decltype] = ACTIONS(2324),
    [sym_virtual] = ACTIONS(2324),
    [anon_sym_explicit] = ACTIONS(2324),
    [anon_sym_typename] = ACTIONS(2324),
    [anon_sym_template] = ACTIONS(2324),
    [anon_sym_operator] = ACTIONS(2324),
    [anon_sym_friend] = ACTIONS(2324),
    [anon_sym_public] = ACTIONS(2324),
    [anon_sym_private] = ACTIONS(2324),
    [anon_sym_protected] = ACTIONS(2324),
    [anon_sym_using] = ACTIONS(2324),
    [anon_sym_static_assert] = ACTIONS(2324),
    [anon_sym_precise] = ACTIONS(2324),
    [anon_sym_shared] = ACTIONS(2324),
    [anon_sym_groupshared] = ACTIONS(2324),
    [anon_sym_uniform] = ACTIONS(2324),
    [anon_sym_row_major] = ACTIONS(2324),
    [anon_sym_column_major] = ACTIONS(2324),
    [anon_sym_globallycoherent] = ACTIONS(2324),
    [anon_sym_centroid] = ACTIONS(2324),
    [anon_sym_noperspective] = ACTIONS(2324),
    [anon_sym_nointerpolation] = ACTIONS(2324),
    [anon_sym_sample] = ACTIONS(2324),
    [anon_sym_linear] = ACTIONS(2324),
    [anon_sym_snorm] = ACTIONS(2324),
    [anon_sym_unorm] = ACTIONS(2324),
    [anon_sym_point] = ACTIONS(2324),
    [anon_sym_line] = ACTIONS(2324),
    [anon_sym_triangleadj] = ACTIONS(2324),
    [anon_sym_lineadj] = ACTIONS(2324),
    [anon_sym_triangle] = ACTIONS(2324),
  },
  [2160] = {
    [sym_identifier] = ACTIONS(5061),
    [aux_sym_preproc_def_token1] = ACTIONS(5061),
    [aux_sym_preproc_if_token1] = ACTIONS(5061),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5061),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5061),
    [sym_preproc_directive] = ACTIONS(5061),
    [anon_sym_LPAREN2] = ACTIONS(5063),
    [anon_sym_TILDE] = ACTIONS(5063),
    [anon_sym_STAR] = ACTIONS(5063),
    [anon_sym_AMP_AMP] = ACTIONS(5063),
    [anon_sym_AMP] = ACTIONS(5061),
    [anon_sym___extension__] = ACTIONS(5061),
    [anon_sym_typedef] = ACTIONS(5061),
    [anon_sym_in] = ACTIONS(5061),
    [anon_sym_out] = ACTIONS(5061),
    [anon_sym_inout] = ACTIONS(5061),
    [anon_sym_extern] = ACTIONS(5061),
    [anon_sym___attribute__] = ACTIONS(5061),
    [anon_sym_COLON_COLON] = ACTIONS(5063),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5063),
    [anon_sym___declspec] = ACTIONS(5061),
    [anon_sym___based] = ACTIONS(5061),
    [anon_sym_RBRACE] = ACTIONS(5063),
    [anon_sym_signed] = ACTIONS(5061),
    [anon_sym_unsigned] = ACTIONS(5061),
    [anon_sym_long] = ACTIONS(5061),
    [anon_sym_short] = ACTIONS(5061),
    [anon_sym_LBRACK] = ACTIONS(5061),
    [anon_sym_static] = ACTIONS(5061),
    [anon_sym_register] = ACTIONS(5061),
    [anon_sym_inline] = ACTIONS(5061),
    [anon_sym___inline] = ACTIONS(5061),
    [anon_sym___inline__] = ACTIONS(5061),
    [anon_sym___forceinline] = ACTIONS(5061),
    [anon_sym_thread_local] = ACTIONS(5061),
    [anon_sym___thread] = ACTIONS(5061),
    [anon_sym_const] = ACTIONS(5061),
    [anon_sym_constexpr] = ACTIONS(5061),
    [anon_sym_volatile] = ACTIONS(5061),
    [anon_sym_restrict] = ACTIONS(5061),
    [anon_sym___restrict__] = ACTIONS(5061),
    [anon_sym__Atomic] = ACTIONS(5061),
    [anon_sym__Noreturn] = ACTIONS(5061),
    [anon_sym_noreturn] = ACTIONS(5061),
    [anon_sym_mutable] = ACTIONS(5061),
    [anon_sym_constinit] = ACTIONS(5061),
    [anon_sym_consteval] = ACTIONS(5061),
    [anon_sym_alignas] = ACTIONS(5061),
    [anon_sym__Alignas] = ACTIONS(5061),
    [sym_primitive_type] = ACTIONS(5061),
    [anon_sym_enum] = ACTIONS(5061),
    [anon_sym_class] = ACTIONS(5061),
    [anon_sym_struct] = ACTIONS(5061),
    [anon_sym_union] = ACTIONS(5061),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5061),
    [anon_sym_decltype] = ACTIONS(5061),
    [sym_virtual] = ACTIONS(5061),
    [anon_sym_explicit] = ACTIONS(5061),
    [anon_sym_typename] = ACTIONS(5061),
    [anon_sym_template] = ACTIONS(5061),
    [anon_sym_operator] = ACTIONS(5061),
    [anon_sym_friend] = ACTIONS(5061),
    [anon_sym_public] = ACTIONS(5061),
    [anon_sym_private] = ACTIONS(5061),
    [anon_sym_protected] = ACTIONS(5061),
    [anon_sym_using] = ACTIONS(5061),
    [anon_sym_static_assert] = ACTIONS(5061),
    [anon_sym_precise] = ACTIONS(5061),
    [anon_sym_shared] = ACTIONS(5061),
    [anon_sym_groupshared] = ACTIONS(5061),
    [anon_sym_uniform] = ACTIONS(5061),
    [anon_sym_row_major] = ACTIONS(5061),
    [anon_sym_column_major] = ACTIONS(5061),
    [anon_sym_globallycoherent] = ACTIONS(5061),
    [anon_sym_centroid] = ACTIONS(5061),
    [anon_sym_noperspective] = ACTIONS(5061),
    [anon_sym_nointerpolation] = ACTIONS(5061),
    [anon_sym_sample] = ACTIONS(5061),
    [anon_sym_linear] = ACTIONS(5061),
    [anon_sym_snorm] = ACTIONS(5061),
    [anon_sym_unorm] = ACTIONS(5061),
    [anon_sym_point] = ACTIONS(5061),
    [anon_sym_line] = ACTIONS(5061),
    [anon_sym_triangleadj] = ACTIONS(5061),
    [anon_sym_lineadj] = ACTIONS(5061),
    [anon_sym_triangle] = ACTIONS(5061),
  },
  [2161] = {
    [sym_identifier] = ACTIONS(2565),
    [aux_sym_preproc_def_token1] = ACTIONS(2565),
    [aux_sym_preproc_if_token1] = ACTIONS(2565),
    [aux_sym_preproc_if_token2] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2565),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2565),
    [sym_preproc_directive] = ACTIONS(2565),
    [anon_sym_LPAREN2] = ACTIONS(2567),
    [anon_sym_TILDE] = ACTIONS(2567),
    [anon_sym_STAR] = ACTIONS(2567),
    [anon_sym_AMP_AMP] = ACTIONS(2567),
    [anon_sym_AMP] = ACTIONS(2565),
    [anon_sym___extension__] = ACTIONS(2565),
    [anon_sym_typedef] = ACTIONS(2565),
    [anon_sym_in] = ACTIONS(2565),
    [anon_sym_out] = ACTIONS(2565),
    [anon_sym_inout] = ACTIONS(2565),
    [anon_sym_extern] = ACTIONS(2565),
    [anon_sym___attribute__] = ACTIONS(2565),
    [anon_sym_COLON_COLON] = ACTIONS(2567),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2567),
    [anon_sym___declspec] = ACTIONS(2565),
    [anon_sym___based] = ACTIONS(2565),
    [anon_sym_signed] = ACTIONS(2565),
    [anon_sym_unsigned] = ACTIONS(2565),
    [anon_sym_long] = ACTIONS(2565),
    [anon_sym_short] = ACTIONS(2565),
    [anon_sym_LBRACK] = ACTIONS(2565),
    [anon_sym_static] = ACTIONS(2565),
    [anon_sym_register] = ACTIONS(2565),
    [anon_sym_inline] = ACTIONS(2565),
    [anon_sym___inline] = ACTIONS(2565),
    [anon_sym___inline__] = ACTIONS(2565),
    [anon_sym___forceinline] = ACTIONS(2565),
    [anon_sym_thread_local] = ACTIONS(2565),
    [anon_sym___thread] = ACTIONS(2565),
    [anon_sym_const] = ACTIONS(2565),
    [anon_sym_constexpr] = ACTIONS(2565),
    [anon_sym_volatile] = ACTIONS(2565),
    [anon_sym_restrict] = ACTIONS(2565),
    [anon_sym___restrict__] = ACTIONS(2565),
    [anon_sym__Atomic] = ACTIONS(2565),
    [anon_sym__Noreturn] = ACTIONS(2565),
    [anon_sym_noreturn] = ACTIONS(2565),
    [anon_sym_mutable] = ACTIONS(2565),
    [anon_sym_constinit] = ACTIONS(2565),
    [anon_sym_consteval] = ACTIONS(2565),
    [anon_sym_alignas] = ACTIONS(2565),
    [anon_sym__Alignas] = ACTIONS(2565),
    [sym_primitive_type] = ACTIONS(2565),
    [anon_sym_enum] = ACTIONS(2565),
    [anon_sym_class] = ACTIONS(2565),
    [anon_sym_struct] = ACTIONS(2565),
    [anon_sym_union] = ACTIONS(2565),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2565),
    [anon_sym_decltype] = ACTIONS(2565),
    [sym_virtual] = ACTIONS(2565),
    [anon_sym_explicit] = ACTIONS(2565),
    [anon_sym_typename] = ACTIONS(2565),
    [anon_sym_template] = ACTIONS(2565),
    [anon_sym_operator] = ACTIONS(2565),
    [anon_sym_friend] = ACTIONS(2565),
    [anon_sym_public] = ACTIONS(2565),
    [anon_sym_private] = ACTIONS(2565),
    [anon_sym_protected] = ACTIONS(2565),
    [anon_sym_using] = ACTIONS(2565),
    [anon_sym_static_assert] = ACTIONS(2565),
    [anon_sym_precise] = ACTIONS(2565),
    [anon_sym_shared] = ACTIONS(2565),
    [anon_sym_groupshared] = ACTIONS(2565),
    [anon_sym_uniform] = ACTIONS(2565),
    [anon_sym_row_major] = ACTIONS(2565),
    [anon_sym_column_major] = ACTIONS(2565),
    [anon_sym_globallycoherent] = ACTIONS(2565),
    [anon_sym_centroid] = ACTIONS(2565),
    [anon_sym_noperspective] = ACTIONS(2565),
    [anon_sym_nointerpolation] = ACTIONS(2565),
    [anon_sym_sample] = ACTIONS(2565),
    [anon_sym_linear] = ACTIONS(2565),
    [anon_sym_snorm] = ACTIONS(2565),
    [anon_sym_unorm] = ACTIONS(2565),
    [anon_sym_point] = ACTIONS(2565),
    [anon_sym_line] = ACTIONS(2565),
    [anon_sym_triangleadj] = ACTIONS(2565),
    [anon_sym_lineadj] = ACTIONS(2565),
    [anon_sym_triangle] = ACTIONS(2565),
  },
  [2162] = {
    [sym_identifier] = ACTIONS(2573),
    [aux_sym_preproc_def_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token1] = ACTIONS(2573),
    [aux_sym_preproc_if_token2] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2573),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2573),
    [sym_preproc_directive] = ACTIONS(2573),
    [anon_sym_LPAREN2] = ACTIONS(2575),
    [anon_sym_TILDE] = ACTIONS(2575),
    [anon_sym_STAR] = ACTIONS(2575),
    [anon_sym_AMP_AMP] = ACTIONS(2575),
    [anon_sym_AMP] = ACTIONS(2573),
    [anon_sym___extension__] = ACTIONS(2573),
    [anon_sym_typedef] = ACTIONS(2573),
    [anon_sym_in] = ACTIONS(2573),
    [anon_sym_out] = ACTIONS(2573),
    [anon_sym_inout] = ACTIONS(2573),
    [anon_sym_extern] = ACTIONS(2573),
    [anon_sym___attribute__] = ACTIONS(2573),
    [anon_sym_COLON_COLON] = ACTIONS(2575),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2575),
    [anon_sym___declspec] = ACTIONS(2573),
    [anon_sym___based] = ACTIONS(2573),
    [anon_sym_signed] = ACTIONS(2573),
    [anon_sym_unsigned] = ACTIONS(2573),
    [anon_sym_long] = ACTIONS(2573),
    [anon_sym_short] = ACTIONS(2573),
    [anon_sym_LBRACK] = ACTIONS(2573),
    [anon_sym_static] = ACTIONS(2573),
    [anon_sym_register] = ACTIONS(2573),
    [anon_sym_inline] = ACTIONS(2573),
    [anon_sym___inline] = ACTIONS(2573),
    [anon_sym___inline__] = ACTIONS(2573),
    [anon_sym___forceinline] = ACTIONS(2573),
    [anon_sym_thread_local] = ACTIONS(2573),
    [anon_sym___thread] = ACTIONS(2573),
    [anon_sym_const] = ACTIONS(2573),
    [anon_sym_constexpr] = ACTIONS(2573),
    [anon_sym_volatile] = ACTIONS(2573),
    [anon_sym_restrict] = ACTIONS(2573),
    [anon_sym___restrict__] = ACTIONS(2573),
    [anon_sym__Atomic] = ACTIONS(2573),
    [anon_sym__Noreturn] = ACTIONS(2573),
    [anon_sym_noreturn] = ACTIONS(2573),
    [anon_sym_mutable] = ACTIONS(2573),
    [anon_sym_constinit] = ACTIONS(2573),
    [anon_sym_consteval] = ACTIONS(2573),
    [anon_sym_alignas] = ACTIONS(2573),
    [anon_sym__Alignas] = ACTIONS(2573),
    [sym_primitive_type] = ACTIONS(2573),
    [anon_sym_enum] = ACTIONS(2573),
    [anon_sym_class] = ACTIONS(2573),
    [anon_sym_struct] = ACTIONS(2573),
    [anon_sym_union] = ACTIONS(2573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2573),
    [anon_sym_decltype] = ACTIONS(2573),
    [sym_virtual] = ACTIONS(2573),
    [anon_sym_explicit] = ACTIONS(2573),
    [anon_sym_typename] = ACTIONS(2573),
    [anon_sym_template] = ACTIONS(2573),
    [anon_sym_operator] = ACTIONS(2573),
    [anon_sym_friend] = ACTIONS(2573),
    [anon_sym_public] = ACTIONS(2573),
    [anon_sym_private] = ACTIONS(2573),
    [anon_sym_protected] = ACTIONS(2573),
    [anon_sym_using] = ACTIONS(2573),
    [anon_sym_static_assert] = ACTIONS(2573),
    [anon_sym_precise] = ACTIONS(2573),
    [anon_sym_shared] = ACTIONS(2573),
    [anon_sym_groupshared] = ACTIONS(2573),
    [anon_sym_uniform] = ACTIONS(2573),
    [anon_sym_row_major] = ACTIONS(2573),
    [anon_sym_column_major] = ACTIONS(2573),
    [anon_sym_globallycoherent] = ACTIONS(2573),
    [anon_sym_centroid] = ACTIONS(2573),
    [anon_sym_noperspective] = ACTIONS(2573),
    [anon_sym_nointerpolation] = ACTIONS(2573),
    [anon_sym_sample] = ACTIONS(2573),
    [anon_sym_linear] = ACTIONS(2573),
    [anon_sym_snorm] = ACTIONS(2573),
    [anon_sym_unorm] = ACTIONS(2573),
    [anon_sym_point] = ACTIONS(2573),
    [anon_sym_line] = ACTIONS(2573),
    [anon_sym_triangleadj] = ACTIONS(2573),
    [anon_sym_lineadj] = ACTIONS(2573),
    [anon_sym_triangle] = ACTIONS(2573),
  },
  [2163] = {
    [sym_identifier] = ACTIONS(5057),
    [aux_sym_preproc_def_token1] = ACTIONS(5057),
    [aux_sym_preproc_if_token1] = ACTIONS(5057),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5057),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5057),
    [sym_preproc_directive] = ACTIONS(5057),
    [anon_sym_LPAREN2] = ACTIONS(5059),
    [anon_sym_TILDE] = ACTIONS(5059),
    [anon_sym_STAR] = ACTIONS(5059),
    [anon_sym_AMP_AMP] = ACTIONS(5059),
    [anon_sym_AMP] = ACTIONS(5057),
    [anon_sym___extension__] = ACTIONS(5057),
    [anon_sym_typedef] = ACTIONS(5057),
    [anon_sym_in] = ACTIONS(5057),
    [anon_sym_out] = ACTIONS(5057),
    [anon_sym_inout] = ACTIONS(5057),
    [anon_sym_extern] = ACTIONS(5057),
    [anon_sym___attribute__] = ACTIONS(5057),
    [anon_sym_COLON_COLON] = ACTIONS(5059),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5059),
    [anon_sym___declspec] = ACTIONS(5057),
    [anon_sym___based] = ACTIONS(5057),
    [anon_sym_RBRACE] = ACTIONS(5059),
    [anon_sym_signed] = ACTIONS(5057),
    [anon_sym_unsigned] = ACTIONS(5057),
    [anon_sym_long] = ACTIONS(5057),
    [anon_sym_short] = ACTIONS(5057),
    [anon_sym_LBRACK] = ACTIONS(5057),
    [anon_sym_static] = ACTIONS(5057),
    [anon_sym_register] = ACTIONS(5057),
    [anon_sym_inline] = ACTIONS(5057),
    [anon_sym___inline] = ACTIONS(5057),
    [anon_sym___inline__] = ACTIONS(5057),
    [anon_sym___forceinline] = ACTIONS(5057),
    [anon_sym_thread_local] = ACTIONS(5057),
    [anon_sym___thread] = ACTIONS(5057),
    [anon_sym_const] = ACTIONS(5057),
    [anon_sym_constexpr] = ACTIONS(5057),
    [anon_sym_volatile] = ACTIONS(5057),
    [anon_sym_restrict] = ACTIONS(5057),
    [anon_sym___restrict__] = ACTIONS(5057),
    [anon_sym__Atomic] = ACTIONS(5057),
    [anon_sym__Noreturn] = ACTIONS(5057),
    [anon_sym_noreturn] = ACTIONS(5057),
    [anon_sym_mutable] = ACTIONS(5057),
    [anon_sym_constinit] = ACTIONS(5057),
    [anon_sym_consteval] = ACTIONS(5057),
    [anon_sym_alignas] = ACTIONS(5057),
    [anon_sym__Alignas] = ACTIONS(5057),
    [sym_primitive_type] = ACTIONS(5057),
    [anon_sym_enum] = ACTIONS(5057),
    [anon_sym_class] = ACTIONS(5057),
    [anon_sym_struct] = ACTIONS(5057),
    [anon_sym_union] = ACTIONS(5057),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5057),
    [anon_sym_decltype] = ACTIONS(5057),
    [sym_virtual] = ACTIONS(5057),
    [anon_sym_explicit] = ACTIONS(5057),
    [anon_sym_typename] = ACTIONS(5057),
    [anon_sym_template] = ACTIONS(5057),
    [anon_sym_operator] = ACTIONS(5057),
    [anon_sym_friend] = ACTIONS(5057),
    [anon_sym_public] = ACTIONS(5057),
    [anon_sym_private] = ACTIONS(5057),
    [anon_sym_protected] = ACTIONS(5057),
    [anon_sym_using] = ACTIONS(5057),
    [anon_sym_static_assert] = ACTIONS(5057),
    [anon_sym_precise] = ACTIONS(5057),
    [anon_sym_shared] = ACTIONS(5057),
    [anon_sym_groupshared] = ACTIONS(5057),
    [anon_sym_uniform] = ACTIONS(5057),
    [anon_sym_row_major] = ACTIONS(5057),
    [anon_sym_column_major] = ACTIONS(5057),
    [anon_sym_globallycoherent] = ACTIONS(5057),
    [anon_sym_centroid] = ACTIONS(5057),
    [anon_sym_noperspective] = ACTIONS(5057),
    [anon_sym_nointerpolation] = ACTIONS(5057),
    [anon_sym_sample] = ACTIONS(5057),
    [anon_sym_linear] = ACTIONS(5057),
    [anon_sym_snorm] = ACTIONS(5057),
    [anon_sym_unorm] = ACTIONS(5057),
    [anon_sym_point] = ACTIONS(5057),
    [anon_sym_line] = ACTIONS(5057),
    [anon_sym_triangleadj] = ACTIONS(5057),
    [anon_sym_lineadj] = ACTIONS(5057),
    [anon_sym_triangle] = ACTIONS(5057),
  },
  [2164] = {
    [sym_identifier] = ACTIONS(5049),
    [aux_sym_preproc_def_token1] = ACTIONS(5049),
    [aux_sym_preproc_if_token1] = ACTIONS(5049),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5049),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5049),
    [sym_preproc_directive] = ACTIONS(5049),
    [anon_sym_LPAREN2] = ACTIONS(5051),
    [anon_sym_TILDE] = ACTIONS(5051),
    [anon_sym_STAR] = ACTIONS(5051),
    [anon_sym_AMP_AMP] = ACTIONS(5051),
    [anon_sym_AMP] = ACTIONS(5049),
    [anon_sym___extension__] = ACTIONS(5049),
    [anon_sym_typedef] = ACTIONS(5049),
    [anon_sym_in] = ACTIONS(5049),
    [anon_sym_out] = ACTIONS(5049),
    [anon_sym_inout] = ACTIONS(5049),
    [anon_sym_extern] = ACTIONS(5049),
    [anon_sym___attribute__] = ACTIONS(5049),
    [anon_sym_COLON_COLON] = ACTIONS(5051),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5051),
    [anon_sym___declspec] = ACTIONS(5049),
    [anon_sym___based] = ACTIONS(5049),
    [anon_sym_RBRACE] = ACTIONS(5051),
    [anon_sym_signed] = ACTIONS(5049),
    [anon_sym_unsigned] = ACTIONS(5049),
    [anon_sym_long] = ACTIONS(5049),
    [anon_sym_short] = ACTIONS(5049),
    [anon_sym_LBRACK] = ACTIONS(5049),
    [anon_sym_static] = ACTIONS(5049),
    [anon_sym_register] = ACTIONS(5049),
    [anon_sym_inline] = ACTIONS(5049),
    [anon_sym___inline] = ACTIONS(5049),
    [anon_sym___inline__] = ACTIONS(5049),
    [anon_sym___forceinline] = ACTIONS(5049),
    [anon_sym_thread_local] = ACTIONS(5049),
    [anon_sym___thread] = ACTIONS(5049),
    [anon_sym_const] = ACTIONS(5049),
    [anon_sym_constexpr] = ACTIONS(5049),
    [anon_sym_volatile] = ACTIONS(5049),
    [anon_sym_restrict] = ACTIONS(5049),
    [anon_sym___restrict__] = ACTIONS(5049),
    [anon_sym__Atomic] = ACTIONS(5049),
    [anon_sym__Noreturn] = ACTIONS(5049),
    [anon_sym_noreturn] = ACTIONS(5049),
    [anon_sym_mutable] = ACTIONS(5049),
    [anon_sym_constinit] = ACTIONS(5049),
    [anon_sym_consteval] = ACTIONS(5049),
    [anon_sym_alignas] = ACTIONS(5049),
    [anon_sym__Alignas] = ACTIONS(5049),
    [sym_primitive_type] = ACTIONS(5049),
    [anon_sym_enum] = ACTIONS(5049),
    [anon_sym_class] = ACTIONS(5049),
    [anon_sym_struct] = ACTIONS(5049),
    [anon_sym_union] = ACTIONS(5049),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5049),
    [anon_sym_decltype] = ACTIONS(5049),
    [sym_virtual] = ACTIONS(5049),
    [anon_sym_explicit] = ACTIONS(5049),
    [anon_sym_typename] = ACTIONS(5049),
    [anon_sym_template] = ACTIONS(5049),
    [anon_sym_operator] = ACTIONS(5049),
    [anon_sym_friend] = ACTIONS(5049),
    [anon_sym_public] = ACTIONS(5049),
    [anon_sym_private] = ACTIONS(5049),
    [anon_sym_protected] = ACTIONS(5049),
    [anon_sym_using] = ACTIONS(5049),
    [anon_sym_static_assert] = ACTIONS(5049),
    [anon_sym_precise] = ACTIONS(5049),
    [anon_sym_shared] = ACTIONS(5049),
    [anon_sym_groupshared] = ACTIONS(5049),
    [anon_sym_uniform] = ACTIONS(5049),
    [anon_sym_row_major] = ACTIONS(5049),
    [anon_sym_column_major] = ACTIONS(5049),
    [anon_sym_globallycoherent] = ACTIONS(5049),
    [anon_sym_centroid] = ACTIONS(5049),
    [anon_sym_noperspective] = ACTIONS(5049),
    [anon_sym_nointerpolation] = ACTIONS(5049),
    [anon_sym_sample] = ACTIONS(5049),
    [anon_sym_linear] = ACTIONS(5049),
    [anon_sym_snorm] = ACTIONS(5049),
    [anon_sym_unorm] = ACTIONS(5049),
    [anon_sym_point] = ACTIONS(5049),
    [anon_sym_line] = ACTIONS(5049),
    [anon_sym_triangleadj] = ACTIONS(5049),
    [anon_sym_lineadj] = ACTIONS(5049),
    [anon_sym_triangle] = ACTIONS(5049),
  },
  [2165] = {
    [sym_identifier] = ACTIONS(2420),
    [aux_sym_preproc_def_token1] = ACTIONS(2420),
    [aux_sym_preproc_if_token1] = ACTIONS(2420),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2420),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2420),
    [sym_preproc_directive] = ACTIONS(2420),
    [anon_sym_LPAREN2] = ACTIONS(2422),
    [anon_sym_TILDE] = ACTIONS(2422),
    [anon_sym_STAR] = ACTIONS(2422),
    [anon_sym_AMP_AMP] = ACTIONS(2422),
    [anon_sym_AMP] = ACTIONS(2420),
    [anon_sym___extension__] = ACTIONS(2420),
    [anon_sym_typedef] = ACTIONS(2420),
    [anon_sym_in] = ACTIONS(2420),
    [anon_sym_out] = ACTIONS(2420),
    [anon_sym_inout] = ACTIONS(2420),
    [anon_sym_extern] = ACTIONS(2420),
    [anon_sym___attribute__] = ACTIONS(2420),
    [anon_sym_COLON_COLON] = ACTIONS(2422),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2422),
    [anon_sym___declspec] = ACTIONS(2420),
    [anon_sym___based] = ACTIONS(2420),
    [anon_sym_RBRACE] = ACTIONS(2422),
    [anon_sym_signed] = ACTIONS(2420),
    [anon_sym_unsigned] = ACTIONS(2420),
    [anon_sym_long] = ACTIONS(2420),
    [anon_sym_short] = ACTIONS(2420),
    [anon_sym_LBRACK] = ACTIONS(2420),
    [anon_sym_static] = ACTIONS(2420),
    [anon_sym_register] = ACTIONS(2420),
    [anon_sym_inline] = ACTIONS(2420),
    [anon_sym___inline] = ACTIONS(2420),
    [anon_sym___inline__] = ACTIONS(2420),
    [anon_sym___forceinline] = ACTIONS(2420),
    [anon_sym_thread_local] = ACTIONS(2420),
    [anon_sym___thread] = ACTIONS(2420),
    [anon_sym_const] = ACTIONS(2420),
    [anon_sym_constexpr] = ACTIONS(2420),
    [anon_sym_volatile] = ACTIONS(2420),
    [anon_sym_restrict] = ACTIONS(2420),
    [anon_sym___restrict__] = ACTIONS(2420),
    [anon_sym__Atomic] = ACTIONS(2420),
    [anon_sym__Noreturn] = ACTIONS(2420),
    [anon_sym_noreturn] = ACTIONS(2420),
    [anon_sym_mutable] = ACTIONS(2420),
    [anon_sym_constinit] = ACTIONS(2420),
    [anon_sym_consteval] = ACTIONS(2420),
    [anon_sym_alignas] = ACTIONS(2420),
    [anon_sym__Alignas] = ACTIONS(2420),
    [sym_primitive_type] = ACTIONS(2420),
    [anon_sym_enum] = ACTIONS(2420),
    [anon_sym_class] = ACTIONS(2420),
    [anon_sym_struct] = ACTIONS(2420),
    [anon_sym_union] = ACTIONS(2420),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2420),
    [anon_sym_decltype] = ACTIONS(2420),
    [sym_virtual] = ACTIONS(2420),
    [anon_sym_explicit] = ACTIONS(2420),
    [anon_sym_typename] = ACTIONS(2420),
    [anon_sym_template] = ACTIONS(2420),
    [anon_sym_operator] = ACTIONS(2420),
    [anon_sym_friend] = ACTIONS(2420),
    [anon_sym_public] = ACTIONS(2420),
    [anon_sym_private] = ACTIONS(2420),
    [anon_sym_protected] = ACTIONS(2420),
    [anon_sym_using] = ACTIONS(2420),
    [anon_sym_static_assert] = ACTIONS(2420),
    [anon_sym_precise] = ACTIONS(2420),
    [anon_sym_shared] = ACTIONS(2420),
    [anon_sym_groupshared] = ACTIONS(2420),
    [anon_sym_uniform] = ACTIONS(2420),
    [anon_sym_row_major] = ACTIONS(2420),
    [anon_sym_column_major] = ACTIONS(2420),
    [anon_sym_globallycoherent] = ACTIONS(2420),
    [anon_sym_centroid] = ACTIONS(2420),
    [anon_sym_noperspective] = ACTIONS(2420),
    [anon_sym_nointerpolation] = ACTIONS(2420),
    [anon_sym_sample] = ACTIONS(2420),
    [anon_sym_linear] = ACTIONS(2420),
    [anon_sym_snorm] = ACTIONS(2420),
    [anon_sym_unorm] = ACTIONS(2420),
    [anon_sym_point] = ACTIONS(2420),
    [anon_sym_line] = ACTIONS(2420),
    [anon_sym_triangleadj] = ACTIONS(2420),
    [anon_sym_lineadj] = ACTIONS(2420),
    [anon_sym_triangle] = ACTIONS(2420),
  },
  [2166] = {
    [sym_identifier] = ACTIONS(2454),
    [aux_sym_preproc_def_token1] = ACTIONS(2454),
    [aux_sym_preproc_if_token1] = ACTIONS(2454),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2454),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2454),
    [sym_preproc_directive] = ACTIONS(2454),
    [anon_sym_LPAREN2] = ACTIONS(2456),
    [anon_sym_TILDE] = ACTIONS(2456),
    [anon_sym_STAR] = ACTIONS(2456),
    [anon_sym_AMP_AMP] = ACTIONS(2456),
    [anon_sym_AMP] = ACTIONS(2454),
    [anon_sym___extension__] = ACTIONS(2454),
    [anon_sym_typedef] = ACTIONS(2454),
    [anon_sym_in] = ACTIONS(2454),
    [anon_sym_out] = ACTIONS(2454),
    [anon_sym_inout] = ACTIONS(2454),
    [anon_sym_extern] = ACTIONS(2454),
    [anon_sym___attribute__] = ACTIONS(2454),
    [anon_sym_COLON_COLON] = ACTIONS(2456),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2456),
    [anon_sym___declspec] = ACTIONS(2454),
    [anon_sym___based] = ACTIONS(2454),
    [anon_sym_RBRACE] = ACTIONS(2456),
    [anon_sym_signed] = ACTIONS(2454),
    [anon_sym_unsigned] = ACTIONS(2454),
    [anon_sym_long] = ACTIONS(2454),
    [anon_sym_short] = ACTIONS(2454),
    [anon_sym_LBRACK] = ACTIONS(2454),
    [anon_sym_static] = ACTIONS(2454),
    [anon_sym_register] = ACTIONS(2454),
    [anon_sym_inline] = ACTIONS(2454),
    [anon_sym___inline] = ACTIONS(2454),
    [anon_sym___inline__] = ACTIONS(2454),
    [anon_sym___forceinline] = ACTIONS(2454),
    [anon_sym_thread_local] = ACTIONS(2454),
    [anon_sym___thread] = ACTIONS(2454),
    [anon_sym_const] = ACTIONS(2454),
    [anon_sym_constexpr] = ACTIONS(2454),
    [anon_sym_volatile] = ACTIONS(2454),
    [anon_sym_restrict] = ACTIONS(2454),
    [anon_sym___restrict__] = ACTIONS(2454),
    [anon_sym__Atomic] = ACTIONS(2454),
    [anon_sym__Noreturn] = ACTIONS(2454),
    [anon_sym_noreturn] = ACTIONS(2454),
    [anon_sym_mutable] = ACTIONS(2454),
    [anon_sym_constinit] = ACTIONS(2454),
    [anon_sym_consteval] = ACTIONS(2454),
    [anon_sym_alignas] = ACTIONS(2454),
    [anon_sym__Alignas] = ACTIONS(2454),
    [sym_primitive_type] = ACTIONS(2454),
    [anon_sym_enum] = ACTIONS(2454),
    [anon_sym_class] = ACTIONS(2454),
    [anon_sym_struct] = ACTIONS(2454),
    [anon_sym_union] = ACTIONS(2454),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2454),
    [anon_sym_decltype] = ACTIONS(2454),
    [sym_virtual] = ACTIONS(2454),
    [anon_sym_explicit] = ACTIONS(2454),
    [anon_sym_typename] = ACTIONS(2454),
    [anon_sym_template] = ACTIONS(2454),
    [anon_sym_operator] = ACTIONS(2454),
    [anon_sym_friend] = ACTIONS(2454),
    [anon_sym_public] = ACTIONS(2454),
    [anon_sym_private] = ACTIONS(2454),
    [anon_sym_protected] = ACTIONS(2454),
    [anon_sym_using] = ACTIONS(2454),
    [anon_sym_static_assert] = ACTIONS(2454),
    [anon_sym_precise] = ACTIONS(2454),
    [anon_sym_shared] = ACTIONS(2454),
    [anon_sym_groupshared] = ACTIONS(2454),
    [anon_sym_uniform] = ACTIONS(2454),
    [anon_sym_row_major] = ACTIONS(2454),
    [anon_sym_column_major] = ACTIONS(2454),
    [anon_sym_globallycoherent] = ACTIONS(2454),
    [anon_sym_centroid] = ACTIONS(2454),
    [anon_sym_noperspective] = ACTIONS(2454),
    [anon_sym_nointerpolation] = ACTIONS(2454),
    [anon_sym_sample] = ACTIONS(2454),
    [anon_sym_linear] = ACTIONS(2454),
    [anon_sym_snorm] = ACTIONS(2454),
    [anon_sym_unorm] = ACTIONS(2454),
    [anon_sym_point] = ACTIONS(2454),
    [anon_sym_line] = ACTIONS(2454),
    [anon_sym_triangleadj] = ACTIONS(2454),
    [anon_sym_lineadj] = ACTIONS(2454),
    [anon_sym_triangle] = ACTIONS(2454),
  },
  [2167] = {
    [sym_identifier] = ACTIONS(2204),
    [aux_sym_preproc_def_token1] = ACTIONS(2204),
    [aux_sym_preproc_if_token1] = ACTIONS(2204),
    [aux_sym_preproc_if_token2] = ACTIONS(2204),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2204),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2204),
    [sym_preproc_directive] = ACTIONS(2204),
    [anon_sym_LPAREN2] = ACTIONS(2206),
    [anon_sym_TILDE] = ACTIONS(2206),
    [anon_sym_STAR] = ACTIONS(2206),
    [anon_sym_AMP_AMP] = ACTIONS(2206),
    [anon_sym_AMP] = ACTIONS(2204),
    [anon_sym___extension__] = ACTIONS(2204),
    [anon_sym_typedef] = ACTIONS(2204),
    [anon_sym_in] = ACTIONS(2204),
    [anon_sym_out] = ACTIONS(2204),
    [anon_sym_inout] = ACTIONS(2204),
    [anon_sym_extern] = ACTIONS(2204),
    [anon_sym___attribute__] = ACTIONS(2204),
    [anon_sym_COLON_COLON] = ACTIONS(2206),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2206),
    [anon_sym___declspec] = ACTIONS(2204),
    [anon_sym___based] = ACTIONS(2204),
    [anon_sym_signed] = ACTIONS(2204),
    [anon_sym_unsigned] = ACTIONS(2204),
    [anon_sym_long] = ACTIONS(2204),
    [anon_sym_short] = ACTIONS(2204),
    [anon_sym_LBRACK] = ACTIONS(2204),
    [anon_sym_static] = ACTIONS(2204),
    [anon_sym_register] = ACTIONS(2204),
    [anon_sym_inline] = ACTIONS(2204),
    [anon_sym___inline] = ACTIONS(2204),
    [anon_sym___inline__] = ACTIONS(2204),
    [anon_sym___forceinline] = ACTIONS(2204),
    [anon_sym_thread_local] = ACTIONS(2204),
    [anon_sym___thread] = ACTIONS(2204),
    [anon_sym_const] = ACTIONS(2204),
    [anon_sym_constexpr] = ACTIONS(2204),
    [anon_sym_volatile] = ACTIONS(2204),
    [anon_sym_restrict] = ACTIONS(2204),
    [anon_sym___restrict__] = ACTIONS(2204),
    [anon_sym__Atomic] = ACTIONS(2204),
    [anon_sym__Noreturn] = ACTIONS(2204),
    [anon_sym_noreturn] = ACTIONS(2204),
    [anon_sym_mutable] = ACTIONS(2204),
    [anon_sym_constinit] = ACTIONS(2204),
    [anon_sym_consteval] = ACTIONS(2204),
    [anon_sym_alignas] = ACTIONS(2204),
    [anon_sym__Alignas] = ACTIONS(2204),
    [sym_primitive_type] = ACTIONS(2204),
    [anon_sym_enum] = ACTIONS(2204),
    [anon_sym_class] = ACTIONS(2204),
    [anon_sym_struct] = ACTIONS(2204),
    [anon_sym_union] = ACTIONS(2204),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2204),
    [anon_sym_decltype] = ACTIONS(2204),
    [sym_virtual] = ACTIONS(2204),
    [anon_sym_explicit] = ACTIONS(2204),
    [anon_sym_typename] = ACTIONS(2204),
    [anon_sym_template] = ACTIONS(2204),
    [anon_sym_operator] = ACTIONS(2204),
    [anon_sym_friend] = ACTIONS(2204),
    [anon_sym_public] = ACTIONS(2204),
    [anon_sym_private] = ACTIONS(2204),
    [anon_sym_protected] = ACTIONS(2204),
    [anon_sym_using] = ACTIONS(2204),
    [anon_sym_static_assert] = ACTIONS(2204),
    [anon_sym_precise] = ACTIONS(2204),
    [anon_sym_shared] = ACTIONS(2204),
    [anon_sym_groupshared] = ACTIONS(2204),
    [anon_sym_uniform] = ACTIONS(2204),
    [anon_sym_row_major] = ACTIONS(2204),
    [anon_sym_column_major] = ACTIONS(2204),
    [anon_sym_globallycoherent] = ACTIONS(2204),
    [anon_sym_centroid] = ACTIONS(2204),
    [anon_sym_noperspective] = ACTIONS(2204),
    [anon_sym_nointerpolation] = ACTIONS(2204),
    [anon_sym_sample] = ACTIONS(2204),
    [anon_sym_linear] = ACTIONS(2204),
    [anon_sym_snorm] = ACTIONS(2204),
    [anon_sym_unorm] = ACTIONS(2204),
    [anon_sym_point] = ACTIONS(2204),
    [anon_sym_line] = ACTIONS(2204),
    [anon_sym_triangleadj] = ACTIONS(2204),
    [anon_sym_lineadj] = ACTIONS(2204),
    [anon_sym_triangle] = ACTIONS(2204),
  },
  [2168] = {
    [sym_identifier] = ACTIONS(5005),
    [aux_sym_preproc_def_token1] = ACTIONS(5005),
    [aux_sym_preproc_if_token1] = ACTIONS(5005),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5005),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5005),
    [sym_preproc_directive] = ACTIONS(5005),
    [anon_sym_LPAREN2] = ACTIONS(5007),
    [anon_sym_TILDE] = ACTIONS(5007),
    [anon_sym_STAR] = ACTIONS(5007),
    [anon_sym_AMP_AMP] = ACTIONS(5007),
    [anon_sym_AMP] = ACTIONS(5005),
    [anon_sym___extension__] = ACTIONS(5005),
    [anon_sym_typedef] = ACTIONS(5005),
    [anon_sym_in] = ACTIONS(5005),
    [anon_sym_out] = ACTIONS(5005),
    [anon_sym_inout] = ACTIONS(5005),
    [anon_sym_extern] = ACTIONS(5005),
    [anon_sym___attribute__] = ACTIONS(5005),
    [anon_sym_COLON_COLON] = ACTIONS(5007),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5007),
    [anon_sym___declspec] = ACTIONS(5005),
    [anon_sym___based] = ACTIONS(5005),
    [anon_sym_RBRACE] = ACTIONS(5007),
    [anon_sym_signed] = ACTIONS(5005),
    [anon_sym_unsigned] = ACTIONS(5005),
    [anon_sym_long] = ACTIONS(5005),
    [anon_sym_short] = ACTIONS(5005),
    [anon_sym_LBRACK] = ACTIONS(5005),
    [anon_sym_static] = ACTIONS(5005),
    [anon_sym_register] = ACTIONS(5005),
    [anon_sym_inline] = ACTIONS(5005),
    [anon_sym___inline] = ACTIONS(5005),
    [anon_sym___inline__] = ACTIONS(5005),
    [anon_sym___forceinline] = ACTIONS(5005),
    [anon_sym_thread_local] = ACTIONS(5005),
    [anon_sym___thread] = ACTIONS(5005),
    [anon_sym_const] = ACTIONS(5005),
    [anon_sym_constexpr] = ACTIONS(5005),
    [anon_sym_volatile] = ACTIONS(5005),
    [anon_sym_restrict] = ACTIONS(5005),
    [anon_sym___restrict__] = ACTIONS(5005),
    [anon_sym__Atomic] = ACTIONS(5005),
    [anon_sym__Noreturn] = ACTIONS(5005),
    [anon_sym_noreturn] = ACTIONS(5005),
    [anon_sym_mutable] = ACTIONS(5005),
    [anon_sym_constinit] = ACTIONS(5005),
    [anon_sym_consteval] = ACTIONS(5005),
    [anon_sym_alignas] = ACTIONS(5005),
    [anon_sym__Alignas] = ACTIONS(5005),
    [sym_primitive_type] = ACTIONS(5005),
    [anon_sym_enum] = ACTIONS(5005),
    [anon_sym_class] = ACTIONS(5005),
    [anon_sym_struct] = ACTIONS(5005),
    [anon_sym_union] = ACTIONS(5005),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5005),
    [anon_sym_decltype] = ACTIONS(5005),
    [sym_virtual] = ACTIONS(5005),
    [anon_sym_explicit] = ACTIONS(5005),
    [anon_sym_typename] = ACTIONS(5005),
    [anon_sym_template] = ACTIONS(5005),
    [anon_sym_operator] = ACTIONS(5005),
    [anon_sym_friend] = ACTIONS(5005),
    [anon_sym_public] = ACTIONS(5005),
    [anon_sym_private] = ACTIONS(5005),
    [anon_sym_protected] = ACTIONS(5005),
    [anon_sym_using] = ACTIONS(5005),
    [anon_sym_static_assert] = ACTIONS(5005),
    [anon_sym_precise] = ACTIONS(5005),
    [anon_sym_shared] = ACTIONS(5005),
    [anon_sym_groupshared] = ACTIONS(5005),
    [anon_sym_uniform] = ACTIONS(5005),
    [anon_sym_row_major] = ACTIONS(5005),
    [anon_sym_column_major] = ACTIONS(5005),
    [anon_sym_globallycoherent] = ACTIONS(5005),
    [anon_sym_centroid] = ACTIONS(5005),
    [anon_sym_noperspective] = ACTIONS(5005),
    [anon_sym_nointerpolation] = ACTIONS(5005),
    [anon_sym_sample] = ACTIONS(5005),
    [anon_sym_linear] = ACTIONS(5005),
    [anon_sym_snorm] = ACTIONS(5005),
    [anon_sym_unorm] = ACTIONS(5005),
    [anon_sym_point] = ACTIONS(5005),
    [anon_sym_line] = ACTIONS(5005),
    [anon_sym_triangleadj] = ACTIONS(5005),
    [anon_sym_lineadj] = ACTIONS(5005),
    [anon_sym_triangle] = ACTIONS(5005),
  },
  [2169] = {
    [sym_identifier] = ACTIONS(5101),
    [aux_sym_preproc_def_token1] = ACTIONS(5101),
    [aux_sym_preproc_if_token1] = ACTIONS(5101),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5101),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5101),
    [sym_preproc_directive] = ACTIONS(5101),
    [anon_sym_LPAREN2] = ACTIONS(5103),
    [anon_sym_TILDE] = ACTIONS(5103),
    [anon_sym_STAR] = ACTIONS(5103),
    [anon_sym_AMP_AMP] = ACTIONS(5103),
    [anon_sym_AMP] = ACTIONS(5101),
    [anon_sym___extension__] = ACTIONS(5101),
    [anon_sym_typedef] = ACTIONS(5101),
    [anon_sym_in] = ACTIONS(5101),
    [anon_sym_out] = ACTIONS(5101),
    [anon_sym_inout] = ACTIONS(5101),
    [anon_sym_extern] = ACTIONS(5101),
    [anon_sym___attribute__] = ACTIONS(5101),
    [anon_sym_COLON_COLON] = ACTIONS(5103),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5103),
    [anon_sym___declspec] = ACTIONS(5101),
    [anon_sym___based] = ACTIONS(5101),
    [anon_sym_RBRACE] = ACTIONS(5103),
    [anon_sym_signed] = ACTIONS(5101),
    [anon_sym_unsigned] = ACTIONS(5101),
    [anon_sym_long] = ACTIONS(5101),
    [anon_sym_short] = ACTIONS(5101),
    [anon_sym_LBRACK] = ACTIONS(5101),
    [anon_sym_static] = ACTIONS(5101),
    [anon_sym_register] = ACTIONS(5101),
    [anon_sym_inline] = ACTIONS(5101),
    [anon_sym___inline] = ACTIONS(5101),
    [anon_sym___inline__] = ACTIONS(5101),
    [anon_sym___forceinline] = ACTIONS(5101),
    [anon_sym_thread_local] = ACTIONS(5101),
    [anon_sym___thread] = ACTIONS(5101),
    [anon_sym_const] = ACTIONS(5101),
    [anon_sym_constexpr] = ACTIONS(5101),
    [anon_sym_volatile] = ACTIONS(5101),
    [anon_sym_restrict] = ACTIONS(5101),
    [anon_sym___restrict__] = ACTIONS(5101),
    [anon_sym__Atomic] = ACTIONS(5101),
    [anon_sym__Noreturn] = ACTIONS(5101),
    [anon_sym_noreturn] = ACTIONS(5101),
    [anon_sym_mutable] = ACTIONS(5101),
    [anon_sym_constinit] = ACTIONS(5101),
    [anon_sym_consteval] = ACTIONS(5101),
    [anon_sym_alignas] = ACTIONS(5101),
    [anon_sym__Alignas] = ACTIONS(5101),
    [sym_primitive_type] = ACTIONS(5101),
    [anon_sym_enum] = ACTIONS(5101),
    [anon_sym_class] = ACTIONS(5101),
    [anon_sym_struct] = ACTIONS(5101),
    [anon_sym_union] = ACTIONS(5101),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5101),
    [anon_sym_decltype] = ACTIONS(5101),
    [sym_virtual] = ACTIONS(5101),
    [anon_sym_explicit] = ACTIONS(5101),
    [anon_sym_typename] = ACTIONS(5101),
    [anon_sym_template] = ACTIONS(5101),
    [anon_sym_operator] = ACTIONS(5101),
    [anon_sym_friend] = ACTIONS(5101),
    [anon_sym_public] = ACTIONS(5101),
    [anon_sym_private] = ACTIONS(5101),
    [anon_sym_protected] = ACTIONS(5101),
    [anon_sym_using] = ACTIONS(5101),
    [anon_sym_static_assert] = ACTIONS(5101),
    [anon_sym_precise] = ACTIONS(5101),
    [anon_sym_shared] = ACTIONS(5101),
    [anon_sym_groupshared] = ACTIONS(5101),
    [anon_sym_uniform] = ACTIONS(5101),
    [anon_sym_row_major] = ACTIONS(5101),
    [anon_sym_column_major] = ACTIONS(5101),
    [anon_sym_globallycoherent] = ACTIONS(5101),
    [anon_sym_centroid] = ACTIONS(5101),
    [anon_sym_noperspective] = ACTIONS(5101),
    [anon_sym_nointerpolation] = ACTIONS(5101),
    [anon_sym_sample] = ACTIONS(5101),
    [anon_sym_linear] = ACTIONS(5101),
    [anon_sym_snorm] = ACTIONS(5101),
    [anon_sym_unorm] = ACTIONS(5101),
    [anon_sym_point] = ACTIONS(5101),
    [anon_sym_line] = ACTIONS(5101),
    [anon_sym_triangleadj] = ACTIONS(5101),
    [anon_sym_lineadj] = ACTIONS(5101),
    [anon_sym_triangle] = ACTIONS(5101),
  },
  [2170] = {
    [sym_identifier] = ACTIONS(2428),
    [aux_sym_preproc_def_token1] = ACTIONS(2428),
    [aux_sym_preproc_if_token1] = ACTIONS(2428),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2428),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2428),
    [sym_preproc_directive] = ACTIONS(2428),
    [anon_sym_LPAREN2] = ACTIONS(2430),
    [anon_sym_TILDE] = ACTIONS(2430),
    [anon_sym_STAR] = ACTIONS(2430),
    [anon_sym_AMP_AMP] = ACTIONS(2430),
    [anon_sym_AMP] = ACTIONS(2428),
    [anon_sym___extension__] = ACTIONS(2428),
    [anon_sym_typedef] = ACTIONS(2428),
    [anon_sym_in] = ACTIONS(2428),
    [anon_sym_out] = ACTIONS(2428),
    [anon_sym_inout] = ACTIONS(2428),
    [anon_sym_extern] = ACTIONS(2428),
    [anon_sym___attribute__] = ACTIONS(2428),
    [anon_sym_COLON_COLON] = ACTIONS(2430),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2430),
    [anon_sym___declspec] = ACTIONS(2428),
    [anon_sym___based] = ACTIONS(2428),
    [anon_sym_RBRACE] = ACTIONS(2430),
    [anon_sym_signed] = ACTIONS(2428),
    [anon_sym_unsigned] = ACTIONS(2428),
    [anon_sym_long] = ACTIONS(2428),
    [anon_sym_short] = ACTIONS(2428),
    [anon_sym_LBRACK] = ACTIONS(2428),
    [anon_sym_static] = ACTIONS(2428),
    [anon_sym_register] = ACTIONS(2428),
    [anon_sym_inline] = ACTIONS(2428),
    [anon_sym___inline] = ACTIONS(2428),
    [anon_sym___inline__] = ACTIONS(2428),
    [anon_sym___forceinline] = ACTIONS(2428),
    [anon_sym_thread_local] = ACTIONS(2428),
    [anon_sym___thread] = ACTIONS(2428),
    [anon_sym_const] = ACTIONS(2428),
    [anon_sym_constexpr] = ACTIONS(2428),
    [anon_sym_volatile] = ACTIONS(2428),
    [anon_sym_restrict] = ACTIONS(2428),
    [anon_sym___restrict__] = ACTIONS(2428),
    [anon_sym__Atomic] = ACTIONS(2428),
    [anon_sym__Noreturn] = ACTIONS(2428),
    [anon_sym_noreturn] = ACTIONS(2428),
    [anon_sym_mutable] = ACTIONS(2428),
    [anon_sym_constinit] = ACTIONS(2428),
    [anon_sym_consteval] = ACTIONS(2428),
    [anon_sym_alignas] = ACTIONS(2428),
    [anon_sym__Alignas] = ACTIONS(2428),
    [sym_primitive_type] = ACTIONS(2428),
    [anon_sym_enum] = ACTIONS(2428),
    [anon_sym_class] = ACTIONS(2428),
    [anon_sym_struct] = ACTIONS(2428),
    [anon_sym_union] = ACTIONS(2428),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2428),
    [anon_sym_decltype] = ACTIONS(2428),
    [sym_virtual] = ACTIONS(2428),
    [anon_sym_explicit] = ACTIONS(2428),
    [anon_sym_typename] = ACTIONS(2428),
    [anon_sym_template] = ACTIONS(2428),
    [anon_sym_operator] = ACTIONS(2428),
    [anon_sym_friend] = ACTIONS(2428),
    [anon_sym_public] = ACTIONS(2428),
    [anon_sym_private] = ACTIONS(2428),
    [anon_sym_protected] = ACTIONS(2428),
    [anon_sym_using] = ACTIONS(2428),
    [anon_sym_static_assert] = ACTIONS(2428),
    [anon_sym_precise] = ACTIONS(2428),
    [anon_sym_shared] = ACTIONS(2428),
    [anon_sym_groupshared] = ACTIONS(2428),
    [anon_sym_uniform] = ACTIONS(2428),
    [anon_sym_row_major] = ACTIONS(2428),
    [anon_sym_column_major] = ACTIONS(2428),
    [anon_sym_globallycoherent] = ACTIONS(2428),
    [anon_sym_centroid] = ACTIONS(2428),
    [anon_sym_noperspective] = ACTIONS(2428),
    [anon_sym_nointerpolation] = ACTIONS(2428),
    [anon_sym_sample] = ACTIONS(2428),
    [anon_sym_linear] = ACTIONS(2428),
    [anon_sym_snorm] = ACTIONS(2428),
    [anon_sym_unorm] = ACTIONS(2428),
    [anon_sym_point] = ACTIONS(2428),
    [anon_sym_line] = ACTIONS(2428),
    [anon_sym_triangleadj] = ACTIONS(2428),
    [anon_sym_lineadj] = ACTIONS(2428),
    [anon_sym_triangle] = ACTIONS(2428),
  },
  [2171] = {
    [sym_identifier] = ACTIONS(2248),
    [aux_sym_preproc_def_token1] = ACTIONS(2248),
    [aux_sym_preproc_if_token1] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2248),
    [sym_preproc_directive] = ACTIONS(2248),
    [anon_sym_LPAREN2] = ACTIONS(2250),
    [anon_sym_TILDE] = ACTIONS(2250),
    [anon_sym_STAR] = ACTIONS(2250),
    [anon_sym_AMP_AMP] = ACTIONS(2250),
    [anon_sym_AMP] = ACTIONS(2248),
    [anon_sym___extension__] = ACTIONS(2248),
    [anon_sym_typedef] = ACTIONS(2248),
    [anon_sym_in] = ACTIONS(2248),
    [anon_sym_out] = ACTIONS(2248),
    [anon_sym_inout] = ACTIONS(2248),
    [anon_sym_extern] = ACTIONS(2248),
    [anon_sym___attribute__] = ACTIONS(2248),
    [anon_sym_COLON_COLON] = ACTIONS(2250),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2250),
    [anon_sym___declspec] = ACTIONS(2248),
    [anon_sym___based] = ACTIONS(2248),
    [anon_sym_RBRACE] = ACTIONS(2250),
    [anon_sym_signed] = ACTIONS(2248),
    [anon_sym_unsigned] = ACTIONS(2248),
    [anon_sym_long] = ACTIONS(2248),
    [anon_sym_short] = ACTIONS(2248),
    [anon_sym_LBRACK] = ACTIONS(2248),
    [anon_sym_static] = ACTIONS(2248),
    [anon_sym_register] = ACTIONS(2248),
    [anon_sym_inline] = ACTIONS(2248),
    [anon_sym___inline] = ACTIONS(2248),
    [anon_sym___inline__] = ACTIONS(2248),
    [anon_sym___forceinline] = ACTIONS(2248),
    [anon_sym_thread_local] = ACTIONS(2248),
    [anon_sym___thread] = ACTIONS(2248),
    [anon_sym_const] = ACTIONS(2248),
    [anon_sym_constexpr] = ACTIONS(2248),
    [anon_sym_volatile] = ACTIONS(2248),
    [anon_sym_restrict] = ACTIONS(2248),
    [anon_sym___restrict__] = ACTIONS(2248),
    [anon_sym__Atomic] = ACTIONS(2248),
    [anon_sym__Noreturn] = ACTIONS(2248),
    [anon_sym_noreturn] = ACTIONS(2248),
    [anon_sym_mutable] = ACTIONS(2248),
    [anon_sym_constinit] = ACTIONS(2248),
    [anon_sym_consteval] = ACTIONS(2248),
    [anon_sym_alignas] = ACTIONS(2248),
    [anon_sym__Alignas] = ACTIONS(2248),
    [sym_primitive_type] = ACTIONS(2248),
    [anon_sym_enum] = ACTIONS(2248),
    [anon_sym_class] = ACTIONS(2248),
    [anon_sym_struct] = ACTIONS(2248),
    [anon_sym_union] = ACTIONS(2248),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2248),
    [anon_sym_decltype] = ACTIONS(2248),
    [sym_virtual] = ACTIONS(2248),
    [anon_sym_explicit] = ACTIONS(2248),
    [anon_sym_typename] = ACTIONS(2248),
    [anon_sym_template] = ACTIONS(2248),
    [anon_sym_operator] = ACTIONS(2248),
    [anon_sym_friend] = ACTIONS(2248),
    [anon_sym_public] = ACTIONS(2248),
    [anon_sym_private] = ACTIONS(2248),
    [anon_sym_protected] = ACTIONS(2248),
    [anon_sym_using] = ACTIONS(2248),
    [anon_sym_static_assert] = ACTIONS(2248),
    [anon_sym_precise] = ACTIONS(2248),
    [anon_sym_shared] = ACTIONS(2248),
    [anon_sym_groupshared] = ACTIONS(2248),
    [anon_sym_uniform] = ACTIONS(2248),
    [anon_sym_row_major] = ACTIONS(2248),
    [anon_sym_column_major] = ACTIONS(2248),
    [anon_sym_globallycoherent] = ACTIONS(2248),
    [anon_sym_centroid] = ACTIONS(2248),
    [anon_sym_noperspective] = ACTIONS(2248),
    [anon_sym_nointerpolation] = ACTIONS(2248),
    [anon_sym_sample] = ACTIONS(2248),
    [anon_sym_linear] = ACTIONS(2248),
    [anon_sym_snorm] = ACTIONS(2248),
    [anon_sym_unorm] = ACTIONS(2248),
    [anon_sym_point] = ACTIONS(2248),
    [anon_sym_line] = ACTIONS(2248),
    [anon_sym_triangleadj] = ACTIONS(2248),
    [anon_sym_lineadj] = ACTIONS(2248),
    [anon_sym_triangle] = ACTIONS(2248),
  },
  [2172] = {
    [sym_identifier] = ACTIONS(2432),
    [aux_sym_preproc_def_token1] = ACTIONS(2432),
    [aux_sym_preproc_if_token1] = ACTIONS(2432),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2432),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2432),
    [sym_preproc_directive] = ACTIONS(2432),
    [anon_sym_LPAREN2] = ACTIONS(2434),
    [anon_sym_TILDE] = ACTIONS(2434),
    [anon_sym_STAR] = ACTIONS(2434),
    [anon_sym_AMP_AMP] = ACTIONS(2434),
    [anon_sym_AMP] = ACTIONS(2432),
    [anon_sym___extension__] = ACTIONS(2432),
    [anon_sym_typedef] = ACTIONS(2432),
    [anon_sym_in] = ACTIONS(2432),
    [anon_sym_out] = ACTIONS(2432),
    [anon_sym_inout] = ACTIONS(2432),
    [anon_sym_extern] = ACTIONS(2432),
    [anon_sym___attribute__] = ACTIONS(2432),
    [anon_sym_COLON_COLON] = ACTIONS(2434),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2434),
    [anon_sym___declspec] = ACTIONS(2432),
    [anon_sym___based] = ACTIONS(2432),
    [anon_sym_RBRACE] = ACTIONS(2434),
    [anon_sym_signed] = ACTIONS(2432),
    [anon_sym_unsigned] = ACTIONS(2432),
    [anon_sym_long] = ACTIONS(2432),
    [anon_sym_short] = ACTIONS(2432),
    [anon_sym_LBRACK] = ACTIONS(2432),
    [anon_sym_static] = ACTIONS(2432),
    [anon_sym_register] = ACTIONS(2432),
    [anon_sym_inline] = ACTIONS(2432),
    [anon_sym___inline] = ACTIONS(2432),
    [anon_sym___inline__] = ACTIONS(2432),
    [anon_sym___forceinline] = ACTIONS(2432),
    [anon_sym_thread_local] = ACTIONS(2432),
    [anon_sym___thread] = ACTIONS(2432),
    [anon_sym_const] = ACTIONS(2432),
    [anon_sym_constexpr] = ACTIONS(2432),
    [anon_sym_volatile] = ACTIONS(2432),
    [anon_sym_restrict] = ACTIONS(2432),
    [anon_sym___restrict__] = ACTIONS(2432),
    [anon_sym__Atomic] = ACTIONS(2432),
    [anon_sym__Noreturn] = ACTIONS(2432),
    [anon_sym_noreturn] = ACTIONS(2432),
    [anon_sym_mutable] = ACTIONS(2432),
    [anon_sym_constinit] = ACTIONS(2432),
    [anon_sym_consteval] = ACTIONS(2432),
    [anon_sym_alignas] = ACTIONS(2432),
    [anon_sym__Alignas] = ACTIONS(2432),
    [sym_primitive_type] = ACTIONS(2432),
    [anon_sym_enum] = ACTIONS(2432),
    [anon_sym_class] = ACTIONS(2432),
    [anon_sym_struct] = ACTIONS(2432),
    [anon_sym_union] = ACTIONS(2432),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2432),
    [anon_sym_decltype] = ACTIONS(2432),
    [sym_virtual] = ACTIONS(2432),
    [anon_sym_explicit] = ACTIONS(2432),
    [anon_sym_typename] = ACTIONS(2432),
    [anon_sym_template] = ACTIONS(2432),
    [anon_sym_operator] = ACTIONS(2432),
    [anon_sym_friend] = ACTIONS(2432),
    [anon_sym_public] = ACTIONS(2432),
    [anon_sym_private] = ACTIONS(2432),
    [anon_sym_protected] = ACTIONS(2432),
    [anon_sym_using] = ACTIONS(2432),
    [anon_sym_static_assert] = ACTIONS(2432),
    [anon_sym_precise] = ACTIONS(2432),
    [anon_sym_shared] = ACTIONS(2432),
    [anon_sym_groupshared] = ACTIONS(2432),
    [anon_sym_uniform] = ACTIONS(2432),
    [anon_sym_row_major] = ACTIONS(2432),
    [anon_sym_column_major] = ACTIONS(2432),
    [anon_sym_globallycoherent] = ACTIONS(2432),
    [anon_sym_centroid] = ACTIONS(2432),
    [anon_sym_noperspective] = ACTIONS(2432),
    [anon_sym_nointerpolation] = ACTIONS(2432),
    [anon_sym_sample] = ACTIONS(2432),
    [anon_sym_linear] = ACTIONS(2432),
    [anon_sym_snorm] = ACTIONS(2432),
    [anon_sym_unorm] = ACTIONS(2432),
    [anon_sym_point] = ACTIONS(2432),
    [anon_sym_line] = ACTIONS(2432),
    [anon_sym_triangleadj] = ACTIONS(2432),
    [anon_sym_lineadj] = ACTIONS(2432),
    [anon_sym_triangle] = ACTIONS(2432),
  },
  [2173] = {
    [sym_identifier] = ACTIONS(5037),
    [aux_sym_preproc_def_token1] = ACTIONS(5037),
    [aux_sym_preproc_if_token1] = ACTIONS(5037),
    [aux_sym_preproc_if_token2] = ACTIONS(5037),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5037),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5037),
    [sym_preproc_directive] = ACTIONS(5037),
    [anon_sym_LPAREN2] = ACTIONS(5039),
    [anon_sym_TILDE] = ACTIONS(5039),
    [anon_sym_STAR] = ACTIONS(5039),
    [anon_sym_AMP_AMP] = ACTIONS(5039),
    [anon_sym_AMP] = ACTIONS(5037),
    [anon_sym___extension__] = ACTIONS(5037),
    [anon_sym_typedef] = ACTIONS(5037),
    [anon_sym_in] = ACTIONS(5037),
    [anon_sym_out] = ACTIONS(5037),
    [anon_sym_inout] = ACTIONS(5037),
    [anon_sym_extern] = ACTIONS(5037),
    [anon_sym___attribute__] = ACTIONS(5037),
    [anon_sym_COLON_COLON] = ACTIONS(5039),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5039),
    [anon_sym___declspec] = ACTIONS(5037),
    [anon_sym___based] = ACTIONS(5037),
    [anon_sym_signed] = ACTIONS(5037),
    [anon_sym_unsigned] = ACTIONS(5037),
    [anon_sym_long] = ACTIONS(5037),
    [anon_sym_short] = ACTIONS(5037),
    [anon_sym_LBRACK] = ACTIONS(5037),
    [anon_sym_static] = ACTIONS(5037),
    [anon_sym_register] = ACTIONS(5037),
    [anon_sym_inline] = ACTIONS(5037),
    [anon_sym___inline] = ACTIONS(5037),
    [anon_sym___inline__] = ACTIONS(5037),
    [anon_sym___forceinline] = ACTIONS(5037),
    [anon_sym_thread_local] = ACTIONS(5037),
    [anon_sym___thread] = ACTIONS(5037),
    [anon_sym_const] = ACTIONS(5037),
    [anon_sym_constexpr] = ACTIONS(5037),
    [anon_sym_volatile] = ACTIONS(5037),
    [anon_sym_restrict] = ACTIONS(5037),
    [anon_sym___restrict__] = ACTIONS(5037),
    [anon_sym__Atomic] = ACTIONS(5037),
    [anon_sym__Noreturn] = ACTIONS(5037),
    [anon_sym_noreturn] = ACTIONS(5037),
    [anon_sym_mutable] = ACTIONS(5037),
    [anon_sym_constinit] = ACTIONS(5037),
    [anon_sym_consteval] = ACTIONS(5037),
    [anon_sym_alignas] = ACTIONS(5037),
    [anon_sym__Alignas] = ACTIONS(5037),
    [sym_primitive_type] = ACTIONS(5037),
    [anon_sym_enum] = ACTIONS(5037),
    [anon_sym_class] = ACTIONS(5037),
    [anon_sym_struct] = ACTIONS(5037),
    [anon_sym_union] = ACTIONS(5037),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5037),
    [anon_sym_decltype] = ACTIONS(5037),
    [sym_virtual] = ACTIONS(5037),
    [anon_sym_explicit] = ACTIONS(5037),
    [anon_sym_typename] = ACTIONS(5037),
    [anon_sym_template] = ACTIONS(5037),
    [anon_sym_operator] = ACTIONS(5037),
    [anon_sym_friend] = ACTIONS(5037),
    [anon_sym_public] = ACTIONS(5037),
    [anon_sym_private] = ACTIONS(5037),
    [anon_sym_protected] = ACTIONS(5037),
    [anon_sym_using] = ACTIONS(5037),
    [anon_sym_static_assert] = ACTIONS(5037),
    [anon_sym_precise] = ACTIONS(5037),
    [anon_sym_shared] = ACTIONS(5037),
    [anon_sym_groupshared] = ACTIONS(5037),
    [anon_sym_uniform] = ACTIONS(5037),
    [anon_sym_row_major] = ACTIONS(5037),
    [anon_sym_column_major] = ACTIONS(5037),
    [anon_sym_globallycoherent] = ACTIONS(5037),
    [anon_sym_centroid] = ACTIONS(5037),
    [anon_sym_noperspective] = ACTIONS(5037),
    [anon_sym_nointerpolation] = ACTIONS(5037),
    [anon_sym_sample] = ACTIONS(5037),
    [anon_sym_linear] = ACTIONS(5037),
    [anon_sym_snorm] = ACTIONS(5037),
    [anon_sym_unorm] = ACTIONS(5037),
    [anon_sym_point] = ACTIONS(5037),
    [anon_sym_line] = ACTIONS(5037),
    [anon_sym_triangleadj] = ACTIONS(5037),
    [anon_sym_lineadj] = ACTIONS(5037),
    [anon_sym_triangle] = ACTIONS(5037),
  },
  [2174] = {
    [sym_identifier] = ACTIONS(2490),
    [aux_sym_preproc_def_token1] = ACTIONS(2490),
    [aux_sym_preproc_if_token1] = ACTIONS(2490),
    [aux_sym_preproc_if_token2] = ACTIONS(2490),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2490),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2490),
    [sym_preproc_directive] = ACTIONS(2490),
    [anon_sym_LPAREN2] = ACTIONS(2492),
    [anon_sym_TILDE] = ACTIONS(2492),
    [anon_sym_STAR] = ACTIONS(2492),
    [anon_sym_AMP_AMP] = ACTIONS(2492),
    [anon_sym_AMP] = ACTIONS(2490),
    [anon_sym___extension__] = ACTIONS(2490),
    [anon_sym_typedef] = ACTIONS(2490),
    [anon_sym_in] = ACTIONS(2490),
    [anon_sym_out] = ACTIONS(2490),
    [anon_sym_inout] = ACTIONS(2490),
    [anon_sym_extern] = ACTIONS(2490),
    [anon_sym___attribute__] = ACTIONS(2490),
    [anon_sym_COLON_COLON] = ACTIONS(2492),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2492),
    [anon_sym___declspec] = ACTIONS(2490),
    [anon_sym___based] = ACTIONS(2490),
    [anon_sym_signed] = ACTIONS(2490),
    [anon_sym_unsigned] = ACTIONS(2490),
    [anon_sym_long] = ACTIONS(2490),
    [anon_sym_short] = ACTIONS(2490),
    [anon_sym_LBRACK] = ACTIONS(2490),
    [anon_sym_static] = ACTIONS(2490),
    [anon_sym_register] = ACTIONS(2490),
    [anon_sym_inline] = ACTIONS(2490),
    [anon_sym___inline] = ACTIONS(2490),
    [anon_sym___inline__] = ACTIONS(2490),
    [anon_sym___forceinline] = ACTIONS(2490),
    [anon_sym_thread_local] = ACTIONS(2490),
    [anon_sym___thread] = ACTIONS(2490),
    [anon_sym_const] = ACTIONS(2490),
    [anon_sym_constexpr] = ACTIONS(2490),
    [anon_sym_volatile] = ACTIONS(2490),
    [anon_sym_restrict] = ACTIONS(2490),
    [anon_sym___restrict__] = ACTIONS(2490),
    [anon_sym__Atomic] = ACTIONS(2490),
    [anon_sym__Noreturn] = ACTIONS(2490),
    [anon_sym_noreturn] = ACTIONS(2490),
    [anon_sym_mutable] = ACTIONS(2490),
    [anon_sym_constinit] = ACTIONS(2490),
    [anon_sym_consteval] = ACTIONS(2490),
    [anon_sym_alignas] = ACTIONS(2490),
    [anon_sym__Alignas] = ACTIONS(2490),
    [sym_primitive_type] = ACTIONS(2490),
    [anon_sym_enum] = ACTIONS(2490),
    [anon_sym_class] = ACTIONS(2490),
    [anon_sym_struct] = ACTIONS(2490),
    [anon_sym_union] = ACTIONS(2490),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2490),
    [anon_sym_decltype] = ACTIONS(2490),
    [sym_virtual] = ACTIONS(2490),
    [anon_sym_explicit] = ACTIONS(2490),
    [anon_sym_typename] = ACTIONS(2490),
    [anon_sym_template] = ACTIONS(2490),
    [anon_sym_operator] = ACTIONS(2490),
    [anon_sym_friend] = ACTIONS(2490),
    [anon_sym_public] = ACTIONS(2490),
    [anon_sym_private] = ACTIONS(2490),
    [anon_sym_protected] = ACTIONS(2490),
    [anon_sym_using] = ACTIONS(2490),
    [anon_sym_static_assert] = ACTIONS(2490),
    [anon_sym_precise] = ACTIONS(2490),
    [anon_sym_shared] = ACTIONS(2490),
    [anon_sym_groupshared] = ACTIONS(2490),
    [anon_sym_uniform] = ACTIONS(2490),
    [anon_sym_row_major] = ACTIONS(2490),
    [anon_sym_column_major] = ACTIONS(2490),
    [anon_sym_globallycoherent] = ACTIONS(2490),
    [anon_sym_centroid] = ACTIONS(2490),
    [anon_sym_noperspective] = ACTIONS(2490),
    [anon_sym_nointerpolation] = ACTIONS(2490),
    [anon_sym_sample] = ACTIONS(2490),
    [anon_sym_linear] = ACTIONS(2490),
    [anon_sym_snorm] = ACTIONS(2490),
    [anon_sym_unorm] = ACTIONS(2490),
    [anon_sym_point] = ACTIONS(2490),
    [anon_sym_line] = ACTIONS(2490),
    [anon_sym_triangleadj] = ACTIONS(2490),
    [anon_sym_lineadj] = ACTIONS(2490),
    [anon_sym_triangle] = ACTIONS(2490),
  },
  [2175] = {
    [sym_identifier] = ACTIONS(5017),
    [aux_sym_preproc_def_token1] = ACTIONS(5017),
    [aux_sym_preproc_if_token1] = ACTIONS(5017),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5017),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5017),
    [sym_preproc_directive] = ACTIONS(5017),
    [anon_sym_LPAREN2] = ACTIONS(5019),
    [anon_sym_TILDE] = ACTIONS(5019),
    [anon_sym_STAR] = ACTIONS(5019),
    [anon_sym_AMP_AMP] = ACTIONS(5019),
    [anon_sym_AMP] = ACTIONS(5017),
    [anon_sym___extension__] = ACTIONS(5017),
    [anon_sym_typedef] = ACTIONS(5017),
    [anon_sym_in] = ACTIONS(5017),
    [anon_sym_out] = ACTIONS(5017),
    [anon_sym_inout] = ACTIONS(5017),
    [anon_sym_extern] = ACTIONS(5017),
    [anon_sym___attribute__] = ACTIONS(5017),
    [anon_sym_COLON_COLON] = ACTIONS(5019),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5019),
    [anon_sym___declspec] = ACTIONS(5017),
    [anon_sym___based] = ACTIONS(5017),
    [anon_sym_RBRACE] = ACTIONS(5019),
    [anon_sym_signed] = ACTIONS(5017),
    [anon_sym_unsigned] = ACTIONS(5017),
    [anon_sym_long] = ACTIONS(5017),
    [anon_sym_short] = ACTIONS(5017),
    [anon_sym_LBRACK] = ACTIONS(5017),
    [anon_sym_static] = ACTIONS(5017),
    [anon_sym_register] = ACTIONS(5017),
    [anon_sym_inline] = ACTIONS(5017),
    [anon_sym___inline] = ACTIONS(5017),
    [anon_sym___inline__] = ACTIONS(5017),
    [anon_sym___forceinline] = ACTIONS(5017),
    [anon_sym_thread_local] = ACTIONS(5017),
    [anon_sym___thread] = ACTIONS(5017),
    [anon_sym_const] = ACTIONS(5017),
    [anon_sym_constexpr] = ACTIONS(5017),
    [anon_sym_volatile] = ACTIONS(5017),
    [anon_sym_restrict] = ACTIONS(5017),
    [anon_sym___restrict__] = ACTIONS(5017),
    [anon_sym__Atomic] = ACTIONS(5017),
    [anon_sym__Noreturn] = ACTIONS(5017),
    [anon_sym_noreturn] = ACTIONS(5017),
    [anon_sym_mutable] = ACTIONS(5017),
    [anon_sym_constinit] = ACTIONS(5017),
    [anon_sym_consteval] = ACTIONS(5017),
    [anon_sym_alignas] = ACTIONS(5017),
    [anon_sym__Alignas] = ACTIONS(5017),
    [sym_primitive_type] = ACTIONS(5017),
    [anon_sym_enum] = ACTIONS(5017),
    [anon_sym_class] = ACTIONS(5017),
    [anon_sym_struct] = ACTIONS(5017),
    [anon_sym_union] = ACTIONS(5017),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5017),
    [anon_sym_decltype] = ACTIONS(5017),
    [sym_virtual] = ACTIONS(5017),
    [anon_sym_explicit] = ACTIONS(5017),
    [anon_sym_typename] = ACTIONS(5017),
    [anon_sym_template] = ACTIONS(5017),
    [anon_sym_operator] = ACTIONS(5017),
    [anon_sym_friend] = ACTIONS(5017),
    [anon_sym_public] = ACTIONS(5017),
    [anon_sym_private] = ACTIONS(5017),
    [anon_sym_protected] = ACTIONS(5017),
    [anon_sym_using] = ACTIONS(5017),
    [anon_sym_static_assert] = ACTIONS(5017),
    [anon_sym_precise] = ACTIONS(5017),
    [anon_sym_shared] = ACTIONS(5017),
    [anon_sym_groupshared] = ACTIONS(5017),
    [anon_sym_uniform] = ACTIONS(5017),
    [anon_sym_row_major] = ACTIONS(5017),
    [anon_sym_column_major] = ACTIONS(5017),
    [anon_sym_globallycoherent] = ACTIONS(5017),
    [anon_sym_centroid] = ACTIONS(5017),
    [anon_sym_noperspective] = ACTIONS(5017),
    [anon_sym_nointerpolation] = ACTIONS(5017),
    [anon_sym_sample] = ACTIONS(5017),
    [anon_sym_linear] = ACTIONS(5017),
    [anon_sym_snorm] = ACTIONS(5017),
    [anon_sym_unorm] = ACTIONS(5017),
    [anon_sym_point] = ACTIONS(5017),
    [anon_sym_line] = ACTIONS(5017),
    [anon_sym_triangleadj] = ACTIONS(5017),
    [anon_sym_lineadj] = ACTIONS(5017),
    [anon_sym_triangle] = ACTIONS(5017),
  },
  [2176] = {
    [sym_identifier] = ACTIONS(5005),
    [aux_sym_preproc_def_token1] = ACTIONS(5005),
    [aux_sym_preproc_if_token1] = ACTIONS(5005),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5005),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5005),
    [sym_preproc_directive] = ACTIONS(5005),
    [anon_sym_LPAREN2] = ACTIONS(5007),
    [anon_sym_TILDE] = ACTIONS(5007),
    [anon_sym_STAR] = ACTIONS(5007),
    [anon_sym_AMP_AMP] = ACTIONS(5007),
    [anon_sym_AMP] = ACTIONS(5005),
    [anon_sym___extension__] = ACTIONS(5005),
    [anon_sym_typedef] = ACTIONS(5005),
    [anon_sym_in] = ACTIONS(5005),
    [anon_sym_out] = ACTIONS(5005),
    [anon_sym_inout] = ACTIONS(5005),
    [anon_sym_extern] = ACTIONS(5005),
    [anon_sym___attribute__] = ACTIONS(5005),
    [anon_sym_COLON_COLON] = ACTIONS(5007),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5007),
    [anon_sym___declspec] = ACTIONS(5005),
    [anon_sym___based] = ACTIONS(5005),
    [anon_sym_RBRACE] = ACTIONS(5007),
    [anon_sym_signed] = ACTIONS(5005),
    [anon_sym_unsigned] = ACTIONS(5005),
    [anon_sym_long] = ACTIONS(5005),
    [anon_sym_short] = ACTIONS(5005),
    [anon_sym_LBRACK] = ACTIONS(5005),
    [anon_sym_static] = ACTIONS(5005),
    [anon_sym_register] = ACTIONS(5005),
    [anon_sym_inline] = ACTIONS(5005),
    [anon_sym___inline] = ACTIONS(5005),
    [anon_sym___inline__] = ACTIONS(5005),
    [anon_sym___forceinline] = ACTIONS(5005),
    [anon_sym_thread_local] = ACTIONS(5005),
    [anon_sym___thread] = ACTIONS(5005),
    [anon_sym_const] = ACTIONS(5005),
    [anon_sym_constexpr] = ACTIONS(5005),
    [anon_sym_volatile] = ACTIONS(5005),
    [anon_sym_restrict] = ACTIONS(5005),
    [anon_sym___restrict__] = ACTIONS(5005),
    [anon_sym__Atomic] = ACTIONS(5005),
    [anon_sym__Noreturn] = ACTIONS(5005),
    [anon_sym_noreturn] = ACTIONS(5005),
    [anon_sym_mutable] = ACTIONS(5005),
    [anon_sym_constinit] = ACTIONS(5005),
    [anon_sym_consteval] = ACTIONS(5005),
    [anon_sym_alignas] = ACTIONS(5005),
    [anon_sym__Alignas] = ACTIONS(5005),
    [sym_primitive_type] = ACTIONS(5005),
    [anon_sym_enum] = ACTIONS(5005),
    [anon_sym_class] = ACTIONS(5005),
    [anon_sym_struct] = ACTIONS(5005),
    [anon_sym_union] = ACTIONS(5005),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5005),
    [anon_sym_decltype] = ACTIONS(5005),
    [sym_virtual] = ACTIONS(5005),
    [anon_sym_explicit] = ACTIONS(5005),
    [anon_sym_typename] = ACTIONS(5005),
    [anon_sym_template] = ACTIONS(5005),
    [anon_sym_operator] = ACTIONS(5005),
    [anon_sym_friend] = ACTIONS(5005),
    [anon_sym_public] = ACTIONS(5005),
    [anon_sym_private] = ACTIONS(5005),
    [anon_sym_protected] = ACTIONS(5005),
    [anon_sym_using] = ACTIONS(5005),
    [anon_sym_static_assert] = ACTIONS(5005),
    [anon_sym_precise] = ACTIONS(5005),
    [anon_sym_shared] = ACTIONS(5005),
    [anon_sym_groupshared] = ACTIONS(5005),
    [anon_sym_uniform] = ACTIONS(5005),
    [anon_sym_row_major] = ACTIONS(5005),
    [anon_sym_column_major] = ACTIONS(5005),
    [anon_sym_globallycoherent] = ACTIONS(5005),
    [anon_sym_centroid] = ACTIONS(5005),
    [anon_sym_noperspective] = ACTIONS(5005),
    [anon_sym_nointerpolation] = ACTIONS(5005),
    [anon_sym_sample] = ACTIONS(5005),
    [anon_sym_linear] = ACTIONS(5005),
    [anon_sym_snorm] = ACTIONS(5005),
    [anon_sym_unorm] = ACTIONS(5005),
    [anon_sym_point] = ACTIONS(5005),
    [anon_sym_line] = ACTIONS(5005),
    [anon_sym_triangleadj] = ACTIONS(5005),
    [anon_sym_lineadj] = ACTIONS(5005),
    [anon_sym_triangle] = ACTIONS(5005),
  },
  [2177] = {
    [sym_identifier] = ACTIONS(5017),
    [aux_sym_preproc_def_token1] = ACTIONS(5017),
    [aux_sym_preproc_if_token1] = ACTIONS(5017),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5017),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5017),
    [sym_preproc_directive] = ACTIONS(5017),
    [anon_sym_LPAREN2] = ACTIONS(5019),
    [anon_sym_TILDE] = ACTIONS(5019),
    [anon_sym_STAR] = ACTIONS(5019),
    [anon_sym_AMP_AMP] = ACTIONS(5019),
    [anon_sym_AMP] = ACTIONS(5017),
    [anon_sym___extension__] = ACTIONS(5017),
    [anon_sym_typedef] = ACTIONS(5017),
    [anon_sym_in] = ACTIONS(5017),
    [anon_sym_out] = ACTIONS(5017),
    [anon_sym_inout] = ACTIONS(5017),
    [anon_sym_extern] = ACTIONS(5017),
    [anon_sym___attribute__] = ACTIONS(5017),
    [anon_sym_COLON_COLON] = ACTIONS(5019),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5019),
    [anon_sym___declspec] = ACTIONS(5017),
    [anon_sym___based] = ACTIONS(5017),
    [anon_sym_RBRACE] = ACTIONS(5019),
    [anon_sym_signed] = ACTIONS(5017),
    [anon_sym_unsigned] = ACTIONS(5017),
    [anon_sym_long] = ACTIONS(5017),
    [anon_sym_short] = ACTIONS(5017),
    [anon_sym_LBRACK] = ACTIONS(5017),
    [anon_sym_static] = ACTIONS(5017),
    [anon_sym_register] = ACTIONS(5017),
    [anon_sym_inline] = ACTIONS(5017),
    [anon_sym___inline] = ACTIONS(5017),
    [anon_sym___inline__] = ACTIONS(5017),
    [anon_sym___forceinline] = ACTIONS(5017),
    [anon_sym_thread_local] = ACTIONS(5017),
    [anon_sym___thread] = ACTIONS(5017),
    [anon_sym_const] = ACTIONS(5017),
    [anon_sym_constexpr] = ACTIONS(5017),
    [anon_sym_volatile] = ACTIONS(5017),
    [anon_sym_restrict] = ACTIONS(5017),
    [anon_sym___restrict__] = ACTIONS(5017),
    [anon_sym__Atomic] = ACTIONS(5017),
    [anon_sym__Noreturn] = ACTIONS(5017),
    [anon_sym_noreturn] = ACTIONS(5017),
    [anon_sym_mutable] = ACTIONS(5017),
    [anon_sym_constinit] = ACTIONS(5017),
    [anon_sym_consteval] = ACTIONS(5017),
    [anon_sym_alignas] = ACTIONS(5017),
    [anon_sym__Alignas] = ACTIONS(5017),
    [sym_primitive_type] = ACTIONS(5017),
    [anon_sym_enum] = ACTIONS(5017),
    [anon_sym_class] = ACTIONS(5017),
    [anon_sym_struct] = ACTIONS(5017),
    [anon_sym_union] = ACTIONS(5017),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5017),
    [anon_sym_decltype] = ACTIONS(5017),
    [sym_virtual] = ACTIONS(5017),
    [anon_sym_explicit] = ACTIONS(5017),
    [anon_sym_typename] = ACTIONS(5017),
    [anon_sym_template] = ACTIONS(5017),
    [anon_sym_operator] = ACTIONS(5017),
    [anon_sym_friend] = ACTIONS(5017),
    [anon_sym_public] = ACTIONS(5017),
    [anon_sym_private] = ACTIONS(5017),
    [anon_sym_protected] = ACTIONS(5017),
    [anon_sym_using] = ACTIONS(5017),
    [anon_sym_static_assert] = ACTIONS(5017),
    [anon_sym_precise] = ACTIONS(5017),
    [anon_sym_shared] = ACTIONS(5017),
    [anon_sym_groupshared] = ACTIONS(5017),
    [anon_sym_uniform] = ACTIONS(5017),
    [anon_sym_row_major] = ACTIONS(5017),
    [anon_sym_column_major] = ACTIONS(5017),
    [anon_sym_globallycoherent] = ACTIONS(5017),
    [anon_sym_centroid] = ACTIONS(5017),
    [anon_sym_noperspective] = ACTIONS(5017),
    [anon_sym_nointerpolation] = ACTIONS(5017),
    [anon_sym_sample] = ACTIONS(5017),
    [anon_sym_linear] = ACTIONS(5017),
    [anon_sym_snorm] = ACTIONS(5017),
    [anon_sym_unorm] = ACTIONS(5017),
    [anon_sym_point] = ACTIONS(5017),
    [anon_sym_line] = ACTIONS(5017),
    [anon_sym_triangleadj] = ACTIONS(5017),
    [anon_sym_lineadj] = ACTIONS(5017),
    [anon_sym_triangle] = ACTIONS(5017),
  },
  [2178] = {
    [sym_identifier] = ACTIONS(2502),
    [aux_sym_preproc_def_token1] = ACTIONS(2502),
    [aux_sym_preproc_if_token1] = ACTIONS(2502),
    [aux_sym_preproc_if_token2] = ACTIONS(2502),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2502),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2502),
    [sym_preproc_directive] = ACTIONS(2502),
    [anon_sym_LPAREN2] = ACTIONS(2504),
    [anon_sym_TILDE] = ACTIONS(2504),
    [anon_sym_STAR] = ACTIONS(2504),
    [anon_sym_AMP_AMP] = ACTIONS(2504),
    [anon_sym_AMP] = ACTIONS(2502),
    [anon_sym___extension__] = ACTIONS(2502),
    [anon_sym_typedef] = ACTIONS(2502),
    [anon_sym_in] = ACTIONS(2502),
    [anon_sym_out] = ACTIONS(2502),
    [anon_sym_inout] = ACTIONS(2502),
    [anon_sym_extern] = ACTIONS(2502),
    [anon_sym___attribute__] = ACTIONS(2502),
    [anon_sym_COLON_COLON] = ACTIONS(2504),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2504),
    [anon_sym___declspec] = ACTIONS(2502),
    [anon_sym___based] = ACTIONS(2502),
    [anon_sym_signed] = ACTIONS(2502),
    [anon_sym_unsigned] = ACTIONS(2502),
    [anon_sym_long] = ACTIONS(2502),
    [anon_sym_short] = ACTIONS(2502),
    [anon_sym_LBRACK] = ACTIONS(2502),
    [anon_sym_static] = ACTIONS(2502),
    [anon_sym_register] = ACTIONS(2502),
    [anon_sym_inline] = ACTIONS(2502),
    [anon_sym___inline] = ACTIONS(2502),
    [anon_sym___inline__] = ACTIONS(2502),
    [anon_sym___forceinline] = ACTIONS(2502),
    [anon_sym_thread_local] = ACTIONS(2502),
    [anon_sym___thread] = ACTIONS(2502),
    [anon_sym_const] = ACTIONS(2502),
    [anon_sym_constexpr] = ACTIONS(2502),
    [anon_sym_volatile] = ACTIONS(2502),
    [anon_sym_restrict] = ACTIONS(2502),
    [anon_sym___restrict__] = ACTIONS(2502),
    [anon_sym__Atomic] = ACTIONS(2502),
    [anon_sym__Noreturn] = ACTIONS(2502),
    [anon_sym_noreturn] = ACTIONS(2502),
    [anon_sym_mutable] = ACTIONS(2502),
    [anon_sym_constinit] = ACTIONS(2502),
    [anon_sym_consteval] = ACTIONS(2502),
    [anon_sym_alignas] = ACTIONS(2502),
    [anon_sym__Alignas] = ACTIONS(2502),
    [sym_primitive_type] = ACTIONS(2502),
    [anon_sym_enum] = ACTIONS(2502),
    [anon_sym_class] = ACTIONS(2502),
    [anon_sym_struct] = ACTIONS(2502),
    [anon_sym_union] = ACTIONS(2502),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2502),
    [anon_sym_decltype] = ACTIONS(2502),
    [sym_virtual] = ACTIONS(2502),
    [anon_sym_explicit] = ACTIONS(2502),
    [anon_sym_typename] = ACTIONS(2502),
    [anon_sym_template] = ACTIONS(2502),
    [anon_sym_operator] = ACTIONS(2502),
    [anon_sym_friend] = ACTIONS(2502),
    [anon_sym_public] = ACTIONS(2502),
    [anon_sym_private] = ACTIONS(2502),
    [anon_sym_protected] = ACTIONS(2502),
    [anon_sym_using] = ACTIONS(2502),
    [anon_sym_static_assert] = ACTIONS(2502),
    [anon_sym_precise] = ACTIONS(2502),
    [anon_sym_shared] = ACTIONS(2502),
    [anon_sym_groupshared] = ACTIONS(2502),
    [anon_sym_uniform] = ACTIONS(2502),
    [anon_sym_row_major] = ACTIONS(2502),
    [anon_sym_column_major] = ACTIONS(2502),
    [anon_sym_globallycoherent] = ACTIONS(2502),
    [anon_sym_centroid] = ACTIONS(2502),
    [anon_sym_noperspective] = ACTIONS(2502),
    [anon_sym_nointerpolation] = ACTIONS(2502),
    [anon_sym_sample] = ACTIONS(2502),
    [anon_sym_linear] = ACTIONS(2502),
    [anon_sym_snorm] = ACTIONS(2502),
    [anon_sym_unorm] = ACTIONS(2502),
    [anon_sym_point] = ACTIONS(2502),
    [anon_sym_line] = ACTIONS(2502),
    [anon_sym_triangleadj] = ACTIONS(2502),
    [anon_sym_lineadj] = ACTIONS(2502),
    [anon_sym_triangle] = ACTIONS(2502),
  },
  [2179] = {
    [sym_identifier] = ACTIONS(2536),
    [aux_sym_preproc_def_token1] = ACTIONS(2536),
    [aux_sym_preproc_if_token1] = ACTIONS(2536),
    [aux_sym_preproc_if_token2] = ACTIONS(2536),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2536),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2536),
    [sym_preproc_directive] = ACTIONS(2536),
    [anon_sym_LPAREN2] = ACTIONS(2538),
    [anon_sym_TILDE] = ACTIONS(2538),
    [anon_sym_STAR] = ACTIONS(2538),
    [anon_sym_AMP_AMP] = ACTIONS(2538),
    [anon_sym_AMP] = ACTIONS(2536),
    [anon_sym___extension__] = ACTIONS(2536),
    [anon_sym_typedef] = ACTIONS(2536),
    [anon_sym_in] = ACTIONS(2536),
    [anon_sym_out] = ACTIONS(2536),
    [anon_sym_inout] = ACTIONS(2536),
    [anon_sym_extern] = ACTIONS(2536),
    [anon_sym___attribute__] = ACTIONS(2536),
    [anon_sym_COLON_COLON] = ACTIONS(2538),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2538),
    [anon_sym___declspec] = ACTIONS(2536),
    [anon_sym___based] = ACTIONS(2536),
    [anon_sym_signed] = ACTIONS(2536),
    [anon_sym_unsigned] = ACTIONS(2536),
    [anon_sym_long] = ACTIONS(2536),
    [anon_sym_short] = ACTIONS(2536),
    [anon_sym_LBRACK] = ACTIONS(2536),
    [anon_sym_static] = ACTIONS(2536),
    [anon_sym_register] = ACTIONS(2536),
    [anon_sym_inline] = ACTIONS(2536),
    [anon_sym___inline] = ACTIONS(2536),
    [anon_sym___inline__] = ACTIONS(2536),
    [anon_sym___forceinline] = ACTIONS(2536),
    [anon_sym_thread_local] = ACTIONS(2536),
    [anon_sym___thread] = ACTIONS(2536),
    [anon_sym_const] = ACTIONS(2536),
    [anon_sym_constexpr] = ACTIONS(2536),
    [anon_sym_volatile] = ACTIONS(2536),
    [anon_sym_restrict] = ACTIONS(2536),
    [anon_sym___restrict__] = ACTIONS(2536),
    [anon_sym__Atomic] = ACTIONS(2536),
    [anon_sym__Noreturn] = ACTIONS(2536),
    [anon_sym_noreturn] = ACTIONS(2536),
    [anon_sym_mutable] = ACTIONS(2536),
    [anon_sym_constinit] = ACTIONS(2536),
    [anon_sym_consteval] = ACTIONS(2536),
    [anon_sym_alignas] = ACTIONS(2536),
    [anon_sym__Alignas] = ACTIONS(2536),
    [sym_primitive_type] = ACTIONS(2536),
    [anon_sym_enum] = ACTIONS(2536),
    [anon_sym_class] = ACTIONS(2536),
    [anon_sym_struct] = ACTIONS(2536),
    [anon_sym_union] = ACTIONS(2536),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2536),
    [anon_sym_decltype] = ACTIONS(2536),
    [sym_virtual] = ACTIONS(2536),
    [anon_sym_explicit] = ACTIONS(2536),
    [anon_sym_typename] = ACTIONS(2536),
    [anon_sym_template] = ACTIONS(2536),
    [anon_sym_operator] = ACTIONS(2536),
    [anon_sym_friend] = ACTIONS(2536),
    [anon_sym_public] = ACTIONS(2536),
    [anon_sym_private] = ACTIONS(2536),
    [anon_sym_protected] = ACTIONS(2536),
    [anon_sym_using] = ACTIONS(2536),
    [anon_sym_static_assert] = ACTIONS(2536),
    [anon_sym_precise] = ACTIONS(2536),
    [anon_sym_shared] = ACTIONS(2536),
    [anon_sym_groupshared] = ACTIONS(2536),
    [anon_sym_uniform] = ACTIONS(2536),
    [anon_sym_row_major] = ACTIONS(2536),
    [anon_sym_column_major] = ACTIONS(2536),
    [anon_sym_globallycoherent] = ACTIONS(2536),
    [anon_sym_centroid] = ACTIONS(2536),
    [anon_sym_noperspective] = ACTIONS(2536),
    [anon_sym_nointerpolation] = ACTIONS(2536),
    [anon_sym_sample] = ACTIONS(2536),
    [anon_sym_linear] = ACTIONS(2536),
    [anon_sym_snorm] = ACTIONS(2536),
    [anon_sym_unorm] = ACTIONS(2536),
    [anon_sym_point] = ACTIONS(2536),
    [anon_sym_line] = ACTIONS(2536),
    [anon_sym_triangleadj] = ACTIONS(2536),
    [anon_sym_lineadj] = ACTIONS(2536),
    [anon_sym_triangle] = ACTIONS(2536),
  },
  [2180] = {
    [sym_identifier] = ACTIONS(5021),
    [aux_sym_preproc_def_token1] = ACTIONS(5021),
    [aux_sym_preproc_if_token1] = ACTIONS(5021),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5021),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5021),
    [sym_preproc_directive] = ACTIONS(5021),
    [anon_sym_LPAREN2] = ACTIONS(5023),
    [anon_sym_TILDE] = ACTIONS(5023),
    [anon_sym_STAR] = ACTIONS(5023),
    [anon_sym_AMP_AMP] = ACTIONS(5023),
    [anon_sym_AMP] = ACTIONS(5021),
    [anon_sym___extension__] = ACTIONS(5021),
    [anon_sym_typedef] = ACTIONS(5021),
    [anon_sym_in] = ACTIONS(5021),
    [anon_sym_out] = ACTIONS(5021),
    [anon_sym_inout] = ACTIONS(5021),
    [anon_sym_extern] = ACTIONS(5021),
    [anon_sym___attribute__] = ACTIONS(5021),
    [anon_sym_COLON_COLON] = ACTIONS(5023),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5023),
    [anon_sym___declspec] = ACTIONS(5021),
    [anon_sym___based] = ACTIONS(5021),
    [anon_sym_RBRACE] = ACTIONS(5023),
    [anon_sym_signed] = ACTIONS(5021),
    [anon_sym_unsigned] = ACTIONS(5021),
    [anon_sym_long] = ACTIONS(5021),
    [anon_sym_short] = ACTIONS(5021),
    [anon_sym_LBRACK] = ACTIONS(5021),
    [anon_sym_static] = ACTIONS(5021),
    [anon_sym_register] = ACTIONS(5021),
    [anon_sym_inline] = ACTIONS(5021),
    [anon_sym___inline] = ACTIONS(5021),
    [anon_sym___inline__] = ACTIONS(5021),
    [anon_sym___forceinline] = ACTIONS(5021),
    [anon_sym_thread_local] = ACTIONS(5021),
    [anon_sym___thread] = ACTIONS(5021),
    [anon_sym_const] = ACTIONS(5021),
    [anon_sym_constexpr] = ACTIONS(5021),
    [anon_sym_volatile] = ACTIONS(5021),
    [anon_sym_restrict] = ACTIONS(5021),
    [anon_sym___restrict__] = ACTIONS(5021),
    [anon_sym__Atomic] = ACTIONS(5021),
    [anon_sym__Noreturn] = ACTIONS(5021),
    [anon_sym_noreturn] = ACTIONS(5021),
    [anon_sym_mutable] = ACTIONS(5021),
    [anon_sym_constinit] = ACTIONS(5021),
    [anon_sym_consteval] = ACTIONS(5021),
    [anon_sym_alignas] = ACTIONS(5021),
    [anon_sym__Alignas] = ACTIONS(5021),
    [sym_primitive_type] = ACTIONS(5021),
    [anon_sym_enum] = ACTIONS(5021),
    [anon_sym_class] = ACTIONS(5021),
    [anon_sym_struct] = ACTIONS(5021),
    [anon_sym_union] = ACTIONS(5021),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5021),
    [anon_sym_decltype] = ACTIONS(5021),
    [sym_virtual] = ACTIONS(5021),
    [anon_sym_explicit] = ACTIONS(5021),
    [anon_sym_typename] = ACTIONS(5021),
    [anon_sym_template] = ACTIONS(5021),
    [anon_sym_operator] = ACTIONS(5021),
    [anon_sym_friend] = ACTIONS(5021),
    [anon_sym_public] = ACTIONS(5021),
    [anon_sym_private] = ACTIONS(5021),
    [anon_sym_protected] = ACTIONS(5021),
    [anon_sym_using] = ACTIONS(5021),
    [anon_sym_static_assert] = ACTIONS(5021),
    [anon_sym_precise] = ACTIONS(5021),
    [anon_sym_shared] = ACTIONS(5021),
    [anon_sym_groupshared] = ACTIONS(5021),
    [anon_sym_uniform] = ACTIONS(5021),
    [anon_sym_row_major] = ACTIONS(5021),
    [anon_sym_column_major] = ACTIONS(5021),
    [anon_sym_globallycoherent] = ACTIONS(5021),
    [anon_sym_centroid] = ACTIONS(5021),
    [anon_sym_noperspective] = ACTIONS(5021),
    [anon_sym_nointerpolation] = ACTIONS(5021),
    [anon_sym_sample] = ACTIONS(5021),
    [anon_sym_linear] = ACTIONS(5021),
    [anon_sym_snorm] = ACTIONS(5021),
    [anon_sym_unorm] = ACTIONS(5021),
    [anon_sym_point] = ACTIONS(5021),
    [anon_sym_line] = ACTIONS(5021),
    [anon_sym_triangleadj] = ACTIONS(5021),
    [anon_sym_lineadj] = ACTIONS(5021),
    [anon_sym_triangle] = ACTIONS(5021),
  },
  [2181] = {
    [sym_identifier] = ACTIONS(2494),
    [aux_sym_preproc_def_token1] = ACTIONS(2494),
    [aux_sym_preproc_if_token1] = ACTIONS(2494),
    [aux_sym_preproc_if_token2] = ACTIONS(2494),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2494),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2494),
    [sym_preproc_directive] = ACTIONS(2494),
    [anon_sym_LPAREN2] = ACTIONS(2496),
    [anon_sym_TILDE] = ACTIONS(2496),
    [anon_sym_STAR] = ACTIONS(2496),
    [anon_sym_AMP_AMP] = ACTIONS(2496),
    [anon_sym_AMP] = ACTIONS(2494),
    [anon_sym___extension__] = ACTIONS(2494),
    [anon_sym_typedef] = ACTIONS(2494),
    [anon_sym_in] = ACTIONS(2494),
    [anon_sym_out] = ACTIONS(2494),
    [anon_sym_inout] = ACTIONS(2494),
    [anon_sym_extern] = ACTIONS(2494),
    [anon_sym___attribute__] = ACTIONS(2494),
    [anon_sym_COLON_COLON] = ACTIONS(2496),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2496),
    [anon_sym___declspec] = ACTIONS(2494),
    [anon_sym___based] = ACTIONS(2494),
    [anon_sym_signed] = ACTIONS(2494),
    [anon_sym_unsigned] = ACTIONS(2494),
    [anon_sym_long] = ACTIONS(2494),
    [anon_sym_short] = ACTIONS(2494),
    [anon_sym_LBRACK] = ACTIONS(2494),
    [anon_sym_static] = ACTIONS(2494),
    [anon_sym_register] = ACTIONS(2494),
    [anon_sym_inline] = ACTIONS(2494),
    [anon_sym___inline] = ACTIONS(2494),
    [anon_sym___inline__] = ACTIONS(2494),
    [anon_sym___forceinline] = ACTIONS(2494),
    [anon_sym_thread_local] = ACTIONS(2494),
    [anon_sym___thread] = ACTIONS(2494),
    [anon_sym_const] = ACTIONS(2494),
    [anon_sym_constexpr] = ACTIONS(2494),
    [anon_sym_volatile] = ACTIONS(2494),
    [anon_sym_restrict] = ACTIONS(2494),
    [anon_sym___restrict__] = ACTIONS(2494),
    [anon_sym__Atomic] = ACTIONS(2494),
    [anon_sym__Noreturn] = ACTIONS(2494),
    [anon_sym_noreturn] = ACTIONS(2494),
    [anon_sym_mutable] = ACTIONS(2494),
    [anon_sym_constinit] = ACTIONS(2494),
    [anon_sym_consteval] = ACTIONS(2494),
    [anon_sym_alignas] = ACTIONS(2494),
    [anon_sym__Alignas] = ACTIONS(2494),
    [sym_primitive_type] = ACTIONS(2494),
    [anon_sym_enum] = ACTIONS(2494),
    [anon_sym_class] = ACTIONS(2494),
    [anon_sym_struct] = ACTIONS(2494),
    [anon_sym_union] = ACTIONS(2494),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2494),
    [anon_sym_decltype] = ACTIONS(2494),
    [sym_virtual] = ACTIONS(2494),
    [anon_sym_explicit] = ACTIONS(2494),
    [anon_sym_typename] = ACTIONS(2494),
    [anon_sym_template] = ACTIONS(2494),
    [anon_sym_operator] = ACTIONS(2494),
    [anon_sym_friend] = ACTIONS(2494),
    [anon_sym_public] = ACTIONS(2494),
    [anon_sym_private] = ACTIONS(2494),
    [anon_sym_protected] = ACTIONS(2494),
    [anon_sym_using] = ACTIONS(2494),
    [anon_sym_static_assert] = ACTIONS(2494),
    [anon_sym_precise] = ACTIONS(2494),
    [anon_sym_shared] = ACTIONS(2494),
    [anon_sym_groupshared] = ACTIONS(2494),
    [anon_sym_uniform] = ACTIONS(2494),
    [anon_sym_row_major] = ACTIONS(2494),
    [anon_sym_column_major] = ACTIONS(2494),
    [anon_sym_globallycoherent] = ACTIONS(2494),
    [anon_sym_centroid] = ACTIONS(2494),
    [anon_sym_noperspective] = ACTIONS(2494),
    [anon_sym_nointerpolation] = ACTIONS(2494),
    [anon_sym_sample] = ACTIONS(2494),
    [anon_sym_linear] = ACTIONS(2494),
    [anon_sym_snorm] = ACTIONS(2494),
    [anon_sym_unorm] = ACTIONS(2494),
    [anon_sym_point] = ACTIONS(2494),
    [anon_sym_line] = ACTIONS(2494),
    [anon_sym_triangleadj] = ACTIONS(2494),
    [anon_sym_lineadj] = ACTIONS(2494),
    [anon_sym_triangle] = ACTIONS(2494),
  },
  [2182] = {
    [sym_identifier] = ACTIONS(2248),
    [aux_sym_preproc_def_token1] = ACTIONS(2248),
    [aux_sym_preproc_if_token1] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2248),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2248),
    [sym_preproc_directive] = ACTIONS(2248),
    [anon_sym_LPAREN2] = ACTIONS(2250),
    [anon_sym_TILDE] = ACTIONS(2250),
    [anon_sym_STAR] = ACTIONS(2250),
    [anon_sym_AMP_AMP] = ACTIONS(2250),
    [anon_sym_AMP] = ACTIONS(2248),
    [anon_sym___extension__] = ACTIONS(2248),
    [anon_sym_typedef] = ACTIONS(2248),
    [anon_sym_in] = ACTIONS(2248),
    [anon_sym_out] = ACTIONS(2248),
    [anon_sym_inout] = ACTIONS(2248),
    [anon_sym_extern] = ACTIONS(2248),
    [anon_sym___attribute__] = ACTIONS(2248),
    [anon_sym_COLON_COLON] = ACTIONS(2250),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2250),
    [anon_sym___declspec] = ACTIONS(2248),
    [anon_sym___based] = ACTIONS(2248),
    [anon_sym_RBRACE] = ACTIONS(2250),
    [anon_sym_signed] = ACTIONS(2248),
    [anon_sym_unsigned] = ACTIONS(2248),
    [anon_sym_long] = ACTIONS(2248),
    [anon_sym_short] = ACTIONS(2248),
    [anon_sym_LBRACK] = ACTIONS(2248),
    [anon_sym_static] = ACTIONS(2248),
    [anon_sym_register] = ACTIONS(2248),
    [anon_sym_inline] = ACTIONS(2248),
    [anon_sym___inline] = ACTIONS(2248),
    [anon_sym___inline__] = ACTIONS(2248),
    [anon_sym___forceinline] = ACTIONS(2248),
    [anon_sym_thread_local] = ACTIONS(2248),
    [anon_sym___thread] = ACTIONS(2248),
    [anon_sym_const] = ACTIONS(2248),
    [anon_sym_constexpr] = ACTIONS(2248),
    [anon_sym_volatile] = ACTIONS(2248),
    [anon_sym_restrict] = ACTIONS(2248),
    [anon_sym___restrict__] = ACTIONS(2248),
    [anon_sym__Atomic] = ACTIONS(2248),
    [anon_sym__Noreturn] = ACTIONS(2248),
    [anon_sym_noreturn] = ACTIONS(2248),
    [anon_sym_mutable] = ACTIONS(2248),
    [anon_sym_constinit] = ACTIONS(2248),
    [anon_sym_consteval] = ACTIONS(2248),
    [anon_sym_alignas] = ACTIONS(2248),
    [anon_sym__Alignas] = ACTIONS(2248),
    [sym_primitive_type] = ACTIONS(2248),
    [anon_sym_enum] = ACTIONS(2248),
    [anon_sym_class] = ACTIONS(2248),
    [anon_sym_struct] = ACTIONS(2248),
    [anon_sym_union] = ACTIONS(2248),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2248),
    [anon_sym_decltype] = ACTIONS(2248),
    [sym_virtual] = ACTIONS(2248),
    [anon_sym_explicit] = ACTIONS(2248),
    [anon_sym_typename] = ACTIONS(2248),
    [anon_sym_template] = ACTIONS(2248),
    [anon_sym_operator] = ACTIONS(2248),
    [anon_sym_friend] = ACTIONS(2248),
    [anon_sym_public] = ACTIONS(2248),
    [anon_sym_private] = ACTIONS(2248),
    [anon_sym_protected] = ACTIONS(2248),
    [anon_sym_using] = ACTIONS(2248),
    [anon_sym_static_assert] = ACTIONS(2248),
    [anon_sym_precise] = ACTIONS(2248),
    [anon_sym_shared] = ACTIONS(2248),
    [anon_sym_groupshared] = ACTIONS(2248),
    [anon_sym_uniform] = ACTIONS(2248),
    [anon_sym_row_major] = ACTIONS(2248),
    [anon_sym_column_major] = ACTIONS(2248),
    [anon_sym_globallycoherent] = ACTIONS(2248),
    [anon_sym_centroid] = ACTIONS(2248),
    [anon_sym_noperspective] = ACTIONS(2248),
    [anon_sym_nointerpolation] = ACTIONS(2248),
    [anon_sym_sample] = ACTIONS(2248),
    [anon_sym_linear] = ACTIONS(2248),
    [anon_sym_snorm] = ACTIONS(2248),
    [anon_sym_unorm] = ACTIONS(2248),
    [anon_sym_point] = ACTIONS(2248),
    [anon_sym_line] = ACTIONS(2248),
    [anon_sym_triangleadj] = ACTIONS(2248),
    [anon_sym_lineadj] = ACTIONS(2248),
    [anon_sym_triangle] = ACTIONS(2248),
  },
  [2183] = {
    [sym_identifier] = ACTIONS(2440),
    [aux_sym_preproc_def_token1] = ACTIONS(2440),
    [aux_sym_preproc_if_token1] = ACTIONS(2440),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2440),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2440),
    [sym_preproc_directive] = ACTIONS(2440),
    [anon_sym_LPAREN2] = ACTIONS(2442),
    [anon_sym_TILDE] = ACTIONS(2442),
    [anon_sym_STAR] = ACTIONS(2442),
    [anon_sym_AMP_AMP] = ACTIONS(2442),
    [anon_sym_AMP] = ACTIONS(2440),
    [anon_sym___extension__] = ACTIONS(2440),
    [anon_sym_typedef] = ACTIONS(2440),
    [anon_sym_in] = ACTIONS(2440),
    [anon_sym_out] = ACTIONS(2440),
    [anon_sym_inout] = ACTIONS(2440),
    [anon_sym_extern] = ACTIONS(2440),
    [anon_sym___attribute__] = ACTIONS(2440),
    [anon_sym_COLON_COLON] = ACTIONS(2442),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2442),
    [anon_sym___declspec] = ACTIONS(2440),
    [anon_sym___based] = ACTIONS(2440),
    [anon_sym_RBRACE] = ACTIONS(2442),
    [anon_sym_signed] = ACTIONS(2440),
    [anon_sym_unsigned] = ACTIONS(2440),
    [anon_sym_long] = ACTIONS(2440),
    [anon_sym_short] = ACTIONS(2440),
    [anon_sym_LBRACK] = ACTIONS(2440),
    [anon_sym_static] = ACTIONS(2440),
    [anon_sym_register] = ACTIONS(2440),
    [anon_sym_inline] = ACTIONS(2440),
    [anon_sym___inline] = ACTIONS(2440),
    [anon_sym___inline__] = ACTIONS(2440),
    [anon_sym___forceinline] = ACTIONS(2440),
    [anon_sym_thread_local] = ACTIONS(2440),
    [anon_sym___thread] = ACTIONS(2440),
    [anon_sym_const] = ACTIONS(2440),
    [anon_sym_constexpr] = ACTIONS(2440),
    [anon_sym_volatile] = ACTIONS(2440),
    [anon_sym_restrict] = ACTIONS(2440),
    [anon_sym___restrict__] = ACTIONS(2440),
    [anon_sym__Atomic] = ACTIONS(2440),
    [anon_sym__Noreturn] = ACTIONS(2440),
    [anon_sym_noreturn] = ACTIONS(2440),
    [anon_sym_mutable] = ACTIONS(2440),
    [anon_sym_constinit] = ACTIONS(2440),
    [anon_sym_consteval] = ACTIONS(2440),
    [anon_sym_alignas] = ACTIONS(2440),
    [anon_sym__Alignas] = ACTIONS(2440),
    [sym_primitive_type] = ACTIONS(2440),
    [anon_sym_enum] = ACTIONS(2440),
    [anon_sym_class] = ACTIONS(2440),
    [anon_sym_struct] = ACTIONS(2440),
    [anon_sym_union] = ACTIONS(2440),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2440),
    [anon_sym_decltype] = ACTIONS(2440),
    [sym_virtual] = ACTIONS(2440),
    [anon_sym_explicit] = ACTIONS(2440),
    [anon_sym_typename] = ACTIONS(2440),
    [anon_sym_template] = ACTIONS(2440),
    [anon_sym_operator] = ACTIONS(2440),
    [anon_sym_friend] = ACTIONS(2440),
    [anon_sym_public] = ACTIONS(2440),
    [anon_sym_private] = ACTIONS(2440),
    [anon_sym_protected] = ACTIONS(2440),
    [anon_sym_using] = ACTIONS(2440),
    [anon_sym_static_assert] = ACTIONS(2440),
    [anon_sym_precise] = ACTIONS(2440),
    [anon_sym_shared] = ACTIONS(2440),
    [anon_sym_groupshared] = ACTIONS(2440),
    [anon_sym_uniform] = ACTIONS(2440),
    [anon_sym_row_major] = ACTIONS(2440),
    [anon_sym_column_major] = ACTIONS(2440),
    [anon_sym_globallycoherent] = ACTIONS(2440),
    [anon_sym_centroid] = ACTIONS(2440),
    [anon_sym_noperspective] = ACTIONS(2440),
    [anon_sym_nointerpolation] = ACTIONS(2440),
    [anon_sym_sample] = ACTIONS(2440),
    [anon_sym_linear] = ACTIONS(2440),
    [anon_sym_snorm] = ACTIONS(2440),
    [anon_sym_unorm] = ACTIONS(2440),
    [anon_sym_point] = ACTIONS(2440),
    [anon_sym_line] = ACTIONS(2440),
    [anon_sym_triangleadj] = ACTIONS(2440),
    [anon_sym_lineadj] = ACTIONS(2440),
    [anon_sym_triangle] = ACTIONS(2440),
  },
  [2184] = {
    [sym_identifier] = ACTIONS(2444),
    [aux_sym_preproc_def_token1] = ACTIONS(2444),
    [aux_sym_preproc_if_token1] = ACTIONS(2444),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2444),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2444),
    [sym_preproc_directive] = ACTIONS(2444),
    [anon_sym_LPAREN2] = ACTIONS(2446),
    [anon_sym_TILDE] = ACTIONS(2446),
    [anon_sym_STAR] = ACTIONS(2446),
    [anon_sym_AMP_AMP] = ACTIONS(2446),
    [anon_sym_AMP] = ACTIONS(2444),
    [anon_sym___extension__] = ACTIONS(2444),
    [anon_sym_typedef] = ACTIONS(2444),
    [anon_sym_in] = ACTIONS(2444),
    [anon_sym_out] = ACTIONS(2444),
    [anon_sym_inout] = ACTIONS(2444),
    [anon_sym_extern] = ACTIONS(2444),
    [anon_sym___attribute__] = ACTIONS(2444),
    [anon_sym_COLON_COLON] = ACTIONS(2446),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2446),
    [anon_sym___declspec] = ACTIONS(2444),
    [anon_sym___based] = ACTIONS(2444),
    [anon_sym_RBRACE] = ACTIONS(2446),
    [anon_sym_signed] = ACTIONS(2444),
    [anon_sym_unsigned] = ACTIONS(2444),
    [anon_sym_long] = ACTIONS(2444),
    [anon_sym_short] = ACTIONS(2444),
    [anon_sym_LBRACK] = ACTIONS(2444),
    [anon_sym_static] = ACTIONS(2444),
    [anon_sym_register] = ACTIONS(2444),
    [anon_sym_inline] = ACTIONS(2444),
    [anon_sym___inline] = ACTIONS(2444),
    [anon_sym___inline__] = ACTIONS(2444),
    [anon_sym___forceinline] = ACTIONS(2444),
    [anon_sym_thread_local] = ACTIONS(2444),
    [anon_sym___thread] = ACTIONS(2444),
    [anon_sym_const] = ACTIONS(2444),
    [anon_sym_constexpr] = ACTIONS(2444),
    [anon_sym_volatile] = ACTIONS(2444),
    [anon_sym_restrict] = ACTIONS(2444),
    [anon_sym___restrict__] = ACTIONS(2444),
    [anon_sym__Atomic] = ACTIONS(2444),
    [anon_sym__Noreturn] = ACTIONS(2444),
    [anon_sym_noreturn] = ACTIONS(2444),
    [anon_sym_mutable] = ACTIONS(2444),
    [anon_sym_constinit] = ACTIONS(2444),
    [anon_sym_consteval] = ACTIONS(2444),
    [anon_sym_alignas] = ACTIONS(2444),
    [anon_sym__Alignas] = ACTIONS(2444),
    [sym_primitive_type] = ACTIONS(2444),
    [anon_sym_enum] = ACTIONS(2444),
    [anon_sym_class] = ACTIONS(2444),
    [anon_sym_struct] = ACTIONS(2444),
    [anon_sym_union] = ACTIONS(2444),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2444),
    [anon_sym_decltype] = ACTIONS(2444),
    [sym_virtual] = ACTIONS(2444),
    [anon_sym_explicit] = ACTIONS(2444),
    [anon_sym_typename] = ACTIONS(2444),
    [anon_sym_template] = ACTIONS(2444),
    [anon_sym_operator] = ACTIONS(2444),
    [anon_sym_friend] = ACTIONS(2444),
    [anon_sym_public] = ACTIONS(2444),
    [anon_sym_private] = ACTIONS(2444),
    [anon_sym_protected] = ACTIONS(2444),
    [anon_sym_using] = ACTIONS(2444),
    [anon_sym_static_assert] = ACTIONS(2444),
    [anon_sym_precise] = ACTIONS(2444),
    [anon_sym_shared] = ACTIONS(2444),
    [anon_sym_groupshared] = ACTIONS(2444),
    [anon_sym_uniform] = ACTIONS(2444),
    [anon_sym_row_major] = ACTIONS(2444),
    [anon_sym_column_major] = ACTIONS(2444),
    [anon_sym_globallycoherent] = ACTIONS(2444),
    [anon_sym_centroid] = ACTIONS(2444),
    [anon_sym_noperspective] = ACTIONS(2444),
    [anon_sym_nointerpolation] = ACTIONS(2444),
    [anon_sym_sample] = ACTIONS(2444),
    [anon_sym_linear] = ACTIONS(2444),
    [anon_sym_snorm] = ACTIONS(2444),
    [anon_sym_unorm] = ACTIONS(2444),
    [anon_sym_point] = ACTIONS(2444),
    [anon_sym_line] = ACTIONS(2444),
    [anon_sym_triangleadj] = ACTIONS(2444),
    [anon_sym_lineadj] = ACTIONS(2444),
    [anon_sym_triangle] = ACTIONS(2444),
  },
  [2185] = {
    [sym_identifier] = ACTIONS(5041),
    [aux_sym_preproc_def_token1] = ACTIONS(5041),
    [aux_sym_preproc_if_token1] = ACTIONS(5041),
    [aux_sym_preproc_if_token2] = ACTIONS(5041),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(5041),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(5041),
    [sym_preproc_directive] = ACTIONS(5041),
    [anon_sym_LPAREN2] = ACTIONS(5043),
    [anon_sym_TILDE] = ACTIONS(5043),
    [anon_sym_STAR] = ACTIONS(5043),
    [anon_sym_AMP_AMP] = ACTIONS(5043),
    [anon_sym_AMP] = ACTIONS(5041),
    [anon_sym___extension__] = ACTIONS(5041),
    [anon_sym_typedef] = ACTIONS(5041),
    [anon_sym_in] = ACTIONS(5041),
    [anon_sym_out] = ACTIONS(5041),
    [anon_sym_inout] = ACTIONS(5041),
    [anon_sym_extern] = ACTIONS(5041),
    [anon_sym___attribute__] = ACTIONS(5041),
    [anon_sym_COLON_COLON] = ACTIONS(5043),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5043),
    [anon_sym___declspec] = ACTIONS(5041),
    [anon_sym___based] = ACTIONS(5041),
    [anon_sym_signed] = ACTIONS(5041),
    [anon_sym_unsigned] = ACTIONS(5041),
    [anon_sym_long] = ACTIONS(5041),
    [anon_sym_short] = ACTIONS(5041),
    [anon_sym_LBRACK] = ACTIONS(5041),
    [anon_sym_static] = ACTIONS(5041),
    [anon_sym_register] = ACTIONS(5041),
    [anon_sym_inline] = ACTIONS(5041),
    [anon_sym___inline] = ACTIONS(5041),
    [anon_sym___inline__] = ACTIONS(5041),
    [anon_sym___forceinline] = ACTIONS(5041),
    [anon_sym_thread_local] = ACTIONS(5041),
    [anon_sym___thread] = ACTIONS(5041),
    [anon_sym_const] = ACTIONS(5041),
    [anon_sym_constexpr] = ACTIONS(5041),
    [anon_sym_volatile] = ACTIONS(5041),
    [anon_sym_restrict] = ACTIONS(5041),
    [anon_sym___restrict__] = ACTIONS(5041),
    [anon_sym__Atomic] = ACTIONS(5041),
    [anon_sym__Noreturn] = ACTIONS(5041),
    [anon_sym_noreturn] = ACTIONS(5041),
    [anon_sym_mutable] = ACTIONS(5041),
    [anon_sym_constinit] = ACTIONS(5041),
    [anon_sym_consteval] = ACTIONS(5041),
    [anon_sym_alignas] = ACTIONS(5041),
    [anon_sym__Alignas] = ACTIONS(5041),
    [sym_primitive_type] = ACTIONS(5041),
    [anon_sym_enum] = ACTIONS(5041),
    [anon_sym_class] = ACTIONS(5041),
    [anon_sym_struct] = ACTIONS(5041),
    [anon_sym_union] = ACTIONS(5041),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5041),
    [anon_sym_decltype] = ACTIONS(5041),
    [sym_virtual] = ACTIONS(5041),
    [anon_sym_explicit] = ACTIONS(5041),
    [anon_sym_typename] = ACTIONS(5041),
    [anon_sym_template] = ACTIONS(5041),
    [anon_sym_operator] = ACTIONS(5041),
    [anon_sym_friend] = ACTIONS(5041),
    [anon_sym_public] = ACTIONS(5041),
    [anon_sym_private] = ACTIONS(5041),
    [anon_sym_protected] = ACTIONS(5041),
    [anon_sym_using] = ACTIONS(5041),
    [anon_sym_static_assert] = ACTIONS(5041),
    [anon_sym_precise] = ACTIONS(5041),
    [anon_sym_shared] = ACTIONS(5041),
    [anon_sym_groupshared] = ACTIONS(5041),
    [anon_sym_uniform] = ACTIONS(5041),
    [anon_sym_row_major] = ACTIONS(5041),
    [anon_sym_column_major] = ACTIONS(5041),
    [anon_sym_globallycoherent] = ACTIONS(5041),
    [anon_sym_centroid] = ACTIONS(5041),
    [anon_sym_noperspective] = ACTIONS(5041),
    [anon_sym_nointerpolation] = ACTIONS(5041),
    [anon_sym_sample] = ACTIONS(5041),
    [anon_sym_linear] = ACTIONS(5041),
    [anon_sym_snorm] = ACTIONS(5041),
    [anon_sym_unorm] = ACTIONS(5041),
    [anon_sym_point] = ACTIONS(5041),
    [anon_sym_line] = ACTIONS(5041),
    [anon_sym_triangleadj] = ACTIONS(5041),
    [anon_sym_lineadj] = ACTIONS(5041),
    [anon_sym_triangle] = ACTIONS(5041),
  },
  [2186] = {
    [sym_identifier] = ACTIONS(2532),
    [aux_sym_preproc_def_token1] = ACTIONS(2532),
    [aux_sym_preproc_if_token1] = ACTIONS(2532),
    [aux_sym_preproc_if_token2] = ACTIONS(2532),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2532),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2532),
    [sym_preproc_directive] = ACTIONS(2532),
    [anon_sym_LPAREN2] = ACTIONS(2534),
    [anon_sym_TILDE] = ACTIONS(2534),
    [anon_sym_STAR] = ACTIONS(2534),
    [anon_sym_AMP_AMP] = ACTIONS(2534),
    [anon_sym_AMP] = ACTIONS(2532),
    [anon_sym___extension__] = ACTIONS(2532),
    [anon_sym_typedef] = ACTIONS(2532),
    [anon_sym_in] = ACTIONS(2532),
    [anon_sym_out] = ACTIONS(2532),
    [anon_sym_inout] = ACTIONS(2532),
    [anon_sym_extern] = ACTIONS(2532),
    [anon_sym___attribute__] = ACTIONS(2532),
    [anon_sym_COLON_COLON] = ACTIONS(2534),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2534),
    [anon_sym___declspec] = ACTIONS(2532),
    [anon_sym___based] = ACTIONS(2532),
    [anon_sym_signed] = ACTIONS(2532),
    [anon_sym_unsigned] = ACTIONS(2532),
    [anon_sym_long] = ACTIONS(2532),
    [anon_sym_short] = ACTIONS(2532),
    [anon_sym_LBRACK] = ACTIONS(2532),
    [anon_sym_static] = ACTIONS(2532),
    [anon_sym_register] = ACTIONS(2532),
    [anon_sym_inline] = ACTIONS(2532),
    [anon_sym___inline] = ACTIONS(2532),
    [anon_sym___inline__] = ACTIONS(2532),
    [anon_sym___forceinline] = ACTIONS(2532),
    [anon_sym_thread_local] = ACTIONS(2532),
    [anon_sym___thread] = ACTIONS(2532),
    [anon_sym_const] = ACTIONS(2532),
    [anon_sym_constexpr] = ACTIONS(2532),
    [anon_sym_volatile] = ACTIONS(2532),
    [anon_sym_restrict] = ACTIONS(2532),
    [anon_sym___restrict__] = ACTIONS(2532),
    [anon_sym__Atomic] = ACTIONS(2532),
    [anon_sym__Noreturn] = ACTIONS(2532),
    [anon_sym_noreturn] = ACTIONS(2532),
    [anon_sym_mutable] = ACTIONS(2532),
    [anon_sym_constinit] = ACTIONS(2532),
    [anon_sym_consteval] = ACTIONS(2532),
    [anon_sym_alignas] = ACTIONS(2532),
    [anon_sym__Alignas] = ACTIONS(2532),
    [sym_primitive_type] = ACTIONS(2532),
    [anon_sym_enum] = ACTIONS(2532),
    [anon_sym_class] = ACTIONS(2532),
    [anon_sym_struct] = ACTIONS(2532),
    [anon_sym_union] = ACTIONS(2532),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2532),
    [anon_sym_decltype] = ACTIONS(2532),
    [sym_virtual] = ACTIONS(2532),
    [anon_sym_explicit] = ACTIONS(2532),
    [anon_sym_typename] = ACTIONS(2532),
    [anon_sym_template] = ACTIONS(2532),
    [anon_sym_operator] = ACTIONS(2532),
    [anon_sym_friend] = ACTIONS(2532),
    [anon_sym_public] = ACTIONS(2532),
    [anon_sym_private] = ACTIONS(2532),
    [anon_sym_protected] = ACTIONS(2532),
    [anon_sym_using] = ACTIONS(2532),
    [anon_sym_static_assert] = ACTIONS(2532),
    [anon_sym_precise] = ACTIONS(2532),
    [anon_sym_shared] = ACTIONS(2532),
    [anon_sym_groupshared] = ACTIONS(2532),
    [anon_sym_uniform] = ACTIONS(2532),
    [anon_sym_row_major] = ACTIONS(2532),
    [anon_sym_column_major] = ACTIONS(2532),
    [anon_sym_globallycoherent] = ACTIONS(2532),
    [anon_sym_centroid] = ACTIONS(2532),
    [anon_sym_noperspective] = ACTIONS(2532),
    [anon_sym_nointerpolation] = ACTIONS(2532),
    [anon_sym_sample] = ACTIONS(2532),
    [anon_sym_linear] = ACTIONS(2532),
    [anon_sym_snorm] = ACTIONS(2532),
    [anon_sym_unorm] = ACTIONS(2532),
    [anon_sym_point] = ACTIONS(2532),
    [anon_sym_line] = ACTIONS(2532),
    [anon_sym_triangleadj] = ACTIONS(2532),
    [anon_sym_lineadj] = ACTIONS(2532),
    [anon_sym_triangle] = ACTIONS(2532),
  },
  [2187] = {
    [sym_identifier] = ACTIONS(2118),
    [aux_sym_preproc_def_token1] = ACTIONS(2118),
    [aux_sym_preproc_if_token1] = ACTIONS(2118),
    [aux_sym_preproc_if_token2] = ACTIONS(2118),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2118),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2118),
    [sym_preproc_directive] = ACTIONS(2118),
    [anon_sym_LPAREN2] = ACTIONS(2120),
    [anon_sym_TILDE] = ACTIONS(2120),
    [anon_sym_STAR] = ACTIONS(2120),
    [anon_sym_AMP_AMP] = ACTIONS(2120),
    [anon_sym_AMP] = ACTIONS(2118),
    [anon_sym___extension__] = ACTIONS(2118),
    [anon_sym_typedef] = ACTIONS(2118),
    [anon_sym_in] = ACTIONS(2118),
    [anon_sym_out] = ACTIONS(2118),
    [anon_sym_inout] = ACTIONS(2118),
    [anon_sym_extern] = ACTIONS(2118),
    [anon_sym___attribute__] = ACTIONS(2118),
    [anon_sym_COLON_COLON] = ACTIONS(2120),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2120),
    [anon_sym___declspec] = ACTIONS(2118),
    [anon_sym___based] = ACTIONS(2118),
    [anon_sym_signed] = ACTIONS(2118),
    [anon_sym_unsigned] = ACTIONS(2118),
    [anon_sym_long] = ACTIONS(2118),
    [anon_sym_short] = ACTIONS(2118),
    [anon_sym_LBRACK] = ACTIONS(2118),
    [anon_sym_static] = ACTIONS(2118),
    [anon_sym_register] = ACTIONS(2118),
    [anon_sym_inline] = ACTIONS(2118),
    [anon_sym___inline] = ACTIONS(2118),
    [anon_sym___inline__] = ACTIONS(2118),
    [anon_sym___forceinline] = ACTIONS(2118),
    [anon_sym_thread_local] = ACTIONS(2118),
    [anon_sym___thread] = ACTIONS(2118),
    [anon_sym_const] = ACTIONS(2118),
    [anon_sym_constexpr] = ACTIONS(2118),
    [anon_sym_volatile] = ACTIONS(2118),
    [anon_sym_restrict] = ACTIONS(2118),
    [anon_sym___restrict__] = ACTIONS(2118),
    [anon_sym__Atomic] = ACTIONS(2118),
    [anon_sym__Noreturn] = ACTIONS(2118),
    [anon_sym_noreturn] = ACTIONS(2118),
    [anon_sym_mutable] = ACTIONS(2118),
    [anon_sym_constinit] = ACTIONS(2118),
    [anon_sym_consteval] = ACTIONS(2118),
    [anon_sym_alignas] = ACTIONS(2118),
    [anon_sym__Alignas] = ACTIONS(2118),
    [sym_primitive_type] = ACTIONS(2118),
    [anon_sym_enum] = ACTIONS(2118),
    [anon_sym_class] = ACTIONS(2118),
    [anon_sym_struct] = ACTIONS(2118),
    [anon_sym_union] = ACTIONS(2118),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2118),
    [anon_sym_decltype] = ACTIONS(2118),
    [sym_virtual] = ACTIONS(2118),
    [anon_sym_explicit] = ACTIONS(2118),
    [anon_sym_typename] = ACTIONS(2118),
    [anon_sym_template] = ACTIONS(2118),
    [anon_sym_operator] = ACTIONS(2118),
    [anon_sym_friend] = ACTIONS(2118),
    [anon_sym_public] = ACTIONS(2118),
    [anon_sym_private] = ACTIONS(2118),
    [anon_sym_protected] = ACTIONS(2118),
    [anon_sym_using] = ACTIONS(2118),
    [anon_sym_static_assert] = ACTIONS(2118),
    [anon_sym_precise] = ACTIONS(2118),
    [anon_sym_shared] = ACTIONS(2118),
    [anon_sym_groupshared] = ACTIONS(2118),
    [anon_sym_uniform] = ACTIONS(2118),
    [anon_sym_row_major] = ACTIONS(2118),
    [anon_sym_column_major] = ACTIONS(2118),
    [anon_sym_globallycoherent] = ACTIONS(2118),
    [anon_sym_centroid] = ACTIONS(2118),
    [anon_sym_noperspective] = ACTIONS(2118),
    [anon_sym_nointerpolation] = ACTIONS(2118),
    [anon_sym_sample] = ACTIONS(2118),
    [anon_sym_linear] = ACTIONS(2118),
    [anon_sym_snorm] = ACTIONS(2118),
    [anon_sym_unorm] = ACTIONS(2118),
    [anon_sym_point] = ACTIONS(2118),
    [anon_sym_line] = ACTIONS(2118),
    [anon_sym_triangleadj] = ACTIONS(2118),
    [anon_sym_lineadj] = ACTIONS(2118),
    [anon_sym_triangle] = ACTIONS(2118),
  },
  [2188] = {
    [sym_identifier] = ACTIONS(2448),
    [aux_sym_preproc_def_token1] = ACTIONS(2448),
    [aux_sym_preproc_if_token1] = ACTIONS(2448),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2448),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2448),
    [sym_preproc_directive] = ACTIONS(2448),
    [anon_sym_LPAREN2] = ACTIONS(2450),
    [anon_sym_TILDE] = ACTIONS(2450),
    [anon_sym_STAR] = ACTIONS(2450),
    [anon_sym_AMP_AMP] = ACTIONS(2450),
    [anon_sym_AMP] = ACTIONS(2448),
    [anon_sym___extension__] = ACTIONS(2448),
    [anon_sym_typedef] = ACTIONS(2448),
    [anon_sym_in] = ACTIONS(2448),
    [anon_sym_out] = ACTIONS(2448),
    [anon_sym_inout] = ACTIONS(2448),
    [anon_sym_extern] = ACTIONS(2448),
    [anon_sym___attribute__] = ACTIONS(2448),
    [anon_sym_COLON_COLON] = ACTIONS(2450),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2450),
    [anon_sym___declspec] = ACTIONS(2448),
    [anon_sym___based] = ACTIONS(2448),
    [anon_sym_RBRACE] = ACTIONS(2450),
    [anon_sym_signed] = ACTIONS(2448),
    [anon_sym_unsigned] = ACTIONS(2448),
    [anon_sym_long] = ACTIONS(2448),
    [anon_sym_short] = ACTIONS(2448),
    [anon_sym_LBRACK] = ACTIONS(2448),
    [anon_sym_static] = ACTIONS(2448),
    [anon_sym_register] = ACTIONS(2448),
    [anon_sym_inline] = ACTIONS(2448),
    [anon_sym___inline] = ACTIONS(2448),
    [anon_sym___inline__] = ACTIONS(2448),
    [anon_sym___forceinline] = ACTIONS(2448),
    [anon_sym_thread_local] = ACTIONS(2448),
    [anon_sym___thread] = ACTIONS(2448),
    [anon_sym_const] = ACTIONS(2448),
    [anon_sym_constexpr] = ACTIONS(2448),
    [anon_sym_volatile] = ACTIONS(2448),
    [anon_sym_restrict] = ACTIONS(2448),
    [anon_sym___restrict__] = ACTIONS(2448),
    [anon_sym__Atomic] = ACTIONS(2448),
    [anon_sym__Noreturn] = ACTIONS(2448),
    [anon_sym_noreturn] = ACTIONS(2448),
    [anon_sym_mutable] = ACTIONS(2448),
    [anon_sym_constinit] = ACTIONS(2448),
    [anon_sym_consteval] = ACTIONS(2448),
    [anon_sym_alignas] = ACTIONS(2448),
    [anon_sym__Alignas] = ACTIONS(2448),
    [sym_primitive_type] = ACTIONS(2448),
    [anon_sym_enum] = ACTIONS(2448),
    [anon_sym_class] = ACTIONS(2448),
    [anon_sym_struct] = ACTIONS(2448),
    [anon_sym_union] = ACTIONS(2448),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2448),
    [anon_sym_decltype] = ACTIONS(2448),
    [sym_virtual] = ACTIONS(2448),
    [anon_sym_explicit] = ACTIONS(2448),
    [anon_sym_typename] = ACTIONS(2448),
    [anon_sym_template] = ACTIONS(2448),
    [anon_sym_operator] = ACTIONS(2448),
    [anon_sym_friend] = ACTIONS(2448),
    [anon_sym_public] = ACTIONS(2448),
    [anon_sym_private] = ACTIONS(2448),
    [anon_sym_protected] = ACTIONS(2448),
    [anon_sym_using] = ACTIONS(2448),
    [anon_sym_static_assert] = ACTIONS(2448),
    [anon_sym_precise] = ACTIONS(2448),
    [anon_sym_shared] = ACTIONS(2448),
    [anon_sym_groupshared] = ACTIONS(2448),
    [anon_sym_uniform] = ACTIONS(2448),
    [anon_sym_row_major] = ACTIONS(2448),
    [anon_sym_column_major] = ACTIONS(2448),
    [anon_sym_globallycoherent] = ACTIONS(2448),
    [anon_sym_centroid] = ACTIONS(2448),
    [anon_sym_noperspective] = ACTIONS(2448),
    [anon_sym_nointerpolation] = ACTIONS(2448),
    [anon_sym_sample] = ACTIONS(2448),
    [anon_sym_linear] = ACTIONS(2448),
    [anon_sym_snorm] = ACTIONS(2448),
    [anon_sym_unorm] = ACTIONS(2448),
    [anon_sym_point] = ACTIONS(2448),
    [anon_sym_line] = ACTIONS(2448),
    [anon_sym_triangleadj] = ACTIONS(2448),
    [anon_sym_lineadj] = ACTIONS(2448),
    [anon_sym_triangle] = ACTIONS(2448),
  },
  [2189] = {
    [sym_identifier] = ACTIONS(2264),
    [aux_sym_preproc_def_token1] = ACTIONS(2264),
    [aux_sym_preproc_if_token1] = ACTIONS(2264),
    [aux_sym_preproc_if_token2] = ACTIONS(2264),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2264),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2264),
    [sym_preproc_directive] = ACTIONS(2264),
    [anon_sym_LPAREN2] = ACTIONS(2266),
    [anon_sym_TILDE] = ACTIONS(2266),
    [anon_sym_STAR] = ACTIONS(2266),
    [anon_sym_AMP_AMP] = ACTIONS(2266),
    [anon_sym_AMP] = ACTIONS(2264),
    [anon_sym___extension__] = ACTIONS(2264),
    [anon_sym_typedef] = ACTIONS(2264),
    [anon_sym_in] = ACTIONS(2264),
    [anon_sym_out] = ACTIONS(2264),
    [anon_sym_inout] = ACTIONS(2264),
    [anon_sym_extern] = ACTIONS(2264),
    [anon_sym___attribute__] = ACTIONS(2264),
    [anon_sym_COLON_COLON] = ACTIONS(2266),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2266),
    [anon_sym___declspec] = ACTIONS(2264),
    [anon_sym___based] = ACTIONS(2264),
    [anon_sym_signed] = ACTIONS(2264),
    [anon_sym_unsigned] = ACTIONS(2264),
    [anon_sym_long] = ACTIONS(2264),
    [anon_sym_short] = ACTIONS(2264),
    [anon_sym_LBRACK] = ACTIONS(2264),
    [anon_sym_static] = ACTIONS(2264),
    [anon_sym_register] = ACTIONS(2264),
    [anon_sym_inline] = ACTIONS(2264),
    [anon_sym___inline] = ACTIONS(2264),
    [anon_sym___inline__] = ACTIONS(2264),
    [anon_sym___forceinline] = ACTIONS(2264),
    [anon_sym_thread_local] = ACTIONS(2264),
    [anon_sym___thread] = ACTIONS(2264),
    [anon_sym_const] = ACTIONS(2264),
    [anon_sym_constexpr] = ACTIONS(2264),
    [anon_sym_volatile] = ACTIONS(2264),
    [anon_sym_restrict] = ACTIONS(2264),
    [anon_sym___restrict__] = ACTIONS(2264),
    [anon_sym__Atomic] = ACTIONS(2264),
    [anon_sym__Noreturn] = ACTIONS(2264),
    [anon_sym_noreturn] = ACTIONS(2264),
    [anon_sym_mutable] = ACTIONS(2264),
    [anon_sym_constinit] = ACTIONS(2264),
    [anon_sym_consteval] = ACTIONS(2264),
    [anon_sym_alignas] = ACTIONS(2264),
    [anon_sym__Alignas] = ACTIONS(2264),
    [sym_primitive_type] = ACTIONS(2264),
    [anon_sym_enum] = ACTIONS(2264),
    [anon_sym_class] = ACTIONS(2264),
    [anon_sym_struct] = ACTIONS(2264),
    [anon_sym_union] = ACTIONS(2264),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2264),
    [anon_sym_decltype] = ACTIONS(2264),
    [sym_virtual] = ACTIONS(2264),
    [anon_sym_explicit] = ACTIONS(2264),
    [anon_sym_typename] = ACTIONS(2264),
    [anon_sym_template] = ACTIONS(2264),
    [anon_sym_operator] = ACTIONS(2264),
    [anon_sym_friend] = ACTIONS(2264),
    [anon_sym_public] = ACTIONS(2264),
    [anon_sym_private] = ACTIONS(2264),
    [anon_sym_protected] = ACTIONS(2264),
    [anon_sym_using] = ACTIONS(2264),
    [anon_sym_static_assert] = ACTIONS(2264),
    [anon_sym_precise] = ACTIONS(2264),
    [anon_sym_shared] = ACTIONS(2264),
    [anon_sym_groupshared] = ACTIONS(2264),
    [anon_sym_uniform] = ACTIONS(2264),
    [anon_sym_row_major] = ACTIONS(2264),
    [anon_sym_column_major] = ACTIONS(2264),
    [anon_sym_globallycoherent] = ACTIONS(2264),
    [anon_sym_centroid] = ACTIONS(2264),
    [anon_sym_noperspective] = ACTIONS(2264),
    [anon_sym_nointerpolation] = ACTIONS(2264),
    [anon_sym_sample] = ACTIONS(2264),
    [anon_sym_linear] = ACTIONS(2264),
    [anon_sym_snorm] = ACTIONS(2264),
    [anon_sym_unorm] = ACTIONS(2264),
    [anon_sym_point] = ACTIONS(2264),
    [anon_sym_line] = ACTIONS(2264),
    [anon_sym_triangleadj] = ACTIONS(2264),
    [anon_sym_lineadj] = ACTIONS(2264),
    [anon_sym_triangle] = ACTIONS(2264),
  },
  [2190] = {
    [sym_identifier] = ACTIONS(2308),
    [aux_sym_preproc_def_token1] = ACTIONS(2308),
    [aux_sym_preproc_if_token1] = ACTIONS(2308),
    [aux_sym_preproc_if_token2] = ACTIONS(2308),
    [aux_sym_preproc_ifdef_token1] = ACTIONS(2308),
    [aux_sym_preproc_ifdef_token2] = ACTIONS(2308),
    [sym_preproc_directive] = ACTIONS(2308),
    [anon_sym_LPAREN2] = ACTIONS(2310),
    [anon_sym_TILDE] = ACTIONS(2310),
    [anon_sym_STAR] = ACTIONS(2310),
    [anon_sym_AMP_AMP] = ACTIONS(2310),
    [anon_sym_AMP] = ACTIONS(2308),
    [anon_sym___extension__] = ACTIONS(2308),
    [anon_sym_typedef] = ACTIONS(2308),
    [anon_sym_in] = ACTIONS(2308),
    [anon_sym_out] = ACTIONS(2308),
    [anon_sym_inout] = ACTIONS(2308),
    [anon_sym_extern] = ACTIONS(2308),
    [anon_sym___attribute__] = ACTIONS(2308),
    [anon_sym_COLON_COLON] = ACTIONS(2310),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2310),
    [anon_sym___declspec] = ACTIONS(2308),
    [anon_sym___based] = ACTIONS(2308),
    [anon_sym_signed] = ACTIONS(2308),
    [anon_sym_unsigned] = ACTIONS(2308),
    [anon_sym_long] = ACTIONS(2308),
    [anon_sym_short] = ACTIONS(2308),
    [anon_sym_LBRACK] = ACTIONS(2308),
    [anon_sym_static] = ACTIONS(2308),
    [anon_sym_register] = ACTIONS(2308),
    [anon_sym_inline] = ACTIONS(2308),
    [anon_sym___inline] = ACTIONS(2308),
    [anon_sym___inline__] = ACTIONS(2308),
    [anon_sym___forceinline] = ACTIONS(2308),
    [anon_sym_thread_local] = ACTIONS(2308),
    [anon_sym___thread] = ACTIONS(2308),
    [anon_sym_const] = ACTIONS(2308),
    [anon_sym_constexpr] = ACTIONS(2308),
    [anon_sym_volatile] = ACTIONS(2308),
    [anon_sym_restrict] = ACTIONS(2308),
    [anon_sym___restrict__] = ACTIONS(2308),
    [anon_sym__Atomic] = ACTIONS(2308),
    [anon_sym__Noreturn] = ACTIONS(2308),
    [anon_sym_noreturn] = ACTIONS(2308),
    [anon_sym_mutable] = ACTIONS(2308),
    [anon_sym_constinit] = ACTIONS(2308),
    [anon_sym_consteval] = ACTIONS(2308),
    [anon_sym_alignas] = ACTIONS(2308),
    [anon_sym__Alignas] = ACTIONS(2308),
    [sym_primitive_type] = ACTIONS(2308),
    [anon_sym_enum] = ACTIONS(2308),
    [anon_sym_class] = ACTIONS(2308),
    [anon_sym_struct] = ACTIONS(2308),
    [anon_sym_union] = ACTIONS(2308),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2308),
    [anon_sym_decltype] = ACTIONS(2308),
    [sym_virtual] = ACTIONS(2308),
    [anon_sym_explicit] = ACTIONS(2308),
    [anon_sym_typename] = ACTIONS(2308),
    [anon_sym_template] = ACTIONS(2308),
    [anon_sym_operator] = ACTIONS(2308),
    [anon_sym_friend] = ACTIONS(2308),
    [anon_sym_public] = ACTIONS(2308),
    [anon_sym_private] = ACTIONS(2308),
    [anon_sym_protected] = ACTIONS(2308),
    [anon_sym_using] = ACTIONS(2308),
    [anon_sym_static_assert] = ACTIONS(2308),
    [anon_sym_precise] = ACTIONS(2308),
    [anon_sym_shared] = ACTIONS(2308),
    [anon_sym_groupshared] = ACTIONS(2308),
    [anon_sym_uniform] = ACTIONS(2308),
    [anon_sym_row_major] = ACTIONS(2308),
    [anon_sym_column_major] = ACTIONS(2308),
    [anon_sym_globallycoherent] = ACTIONS(2308),
    [anon_sym_centroid] = ACTIONS(2308),
    [anon_sym_noperspective] = ACTIONS(2308),
    [anon_sym_nointerpolation] = ACTIONS(2308),
    [anon_sym_sample] = ACTIONS(2308),
    [anon_sym_linear] = ACTIONS(2308),
    [anon_sym_snorm] = ACTIONS(2308),
    [anon_sym_unorm] = ACTIONS(2308),
    [anon_sym_point] = ACTIONS(2308),
    [anon_sym_line] = ACTIONS(2308),
    [anon_sym_triangleadj] = ACTIONS(2308),
    [anon_sym_lineadj] = ACTIONS(2308),
    [anon_sym_triangle] = ACTIONS(2308),
  },
  [2191] = {
    [sym_identifier] = ACTIONS(1887),
    [anon_sym_LPAREN2] = ACTIONS(1889),
    [anon_sym_TILDE] = ACTIONS(1889),
    [anon_sym_STAR] = ACTIONS(1889),
    [anon_sym_PIPE_PIPE] = ACTIONS(1889),
    [anon_sym_AMP_AMP] = ACTIONS(1889),
    [anon_sym_AMP] = ACTIONS(1887),
    [anon_sym___extension__] = ACTIONS(1887),
    [anon_sym_in] = ACTIONS(1887),
    [anon_sym_out] = ACTIONS(1887),
    [anon_sym_inout] = ACTIONS(1887),
    [anon_sym_extern] = ACTIONS(1887),
    [anon_sym___attribute__] = ACTIONS(1887),
    [anon_sym_COLON_COLON] = ACTIONS(1889),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1889),
    [anon_sym___declspec] = ACTIONS(1887),
    [anon_sym___based] = ACTIONS(1887),
    [anon_sym___cdecl] = ACTIONS(1887),
    [anon_sym___clrcall] = ACTIONS(1887),
    [anon_sym___stdcall] = ACTIONS(1887),
    [anon_sym___fastcall] = ACTIONS(1887),
    [anon_sym___thiscall] = ACTIONS(1887),
    [anon_sym___vectorcall] = ACTIONS(1887),
    [anon_sym_signed] = ACTIONS(1887),
    [anon_sym_unsigned] = ACTIONS(1887),
    [anon_sym_long] = ACTIONS(1887),
    [anon_sym_short] = ACTIONS(1887),
    [anon_sym_LBRACK] = ACTIONS(1887),
    [anon_sym_static] = ACTIONS(1887),
    [anon_sym_register] = ACTIONS(1887),
    [anon_sym_inline] = ACTIONS(1887),
    [anon_sym___inline] = ACTIONS(1887),
    [anon_sym___inline__] = ACTIONS(1887),
    [anon_sym___forceinline] = ACTIONS(1887),
    [anon_sym_thread_local] = ACTIONS(1887),
    [anon_sym___thread] = ACTIONS(1887),
    [anon_sym_const] = ACTIONS(1887),
    [anon_sym_constexpr] = ACTIONS(1887),
    [anon_sym_volatile] = ACTIONS(1887),
    [anon_sym_restrict] = ACTIONS(1887),
    [anon_sym___restrict__] = ACTIONS(1887),
    [anon_sym__Atomic] = ACTIONS(1887),
    [anon_sym__Noreturn] = ACTIONS(1887),
    [anon_sym_noreturn] = ACTIONS(1887),
    [anon_sym_mutable] = ACTIONS(1887),
    [anon_sym_constinit] = ACTIONS(1887),
    [anon_sym_consteval] = ACTIONS(1887),
    [anon_sym_alignas] = ACTIONS(1887),
    [anon_sym__Alignas] = ACTIONS(1887),
    [sym_primitive_type] = ACTIONS(1887),
    [anon_sym_enum] = ACTIONS(1887),
    [anon_sym_class] = ACTIONS(1887),
    [anon_sym_struct] = ACTIONS(1887),
    [anon_sym_union] = ACTIONS(1887),
    [anon_sym_or] = ACTIONS(1887),
    [anon_sym_and] = ACTIONS(1887),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1887),
    [anon_sym_decltype] = ACTIONS(1887),
    [sym_virtual] = ACTIONS(1887),
    [anon_sym_explicit] = ACTIONS(1887),
    [anon_sym_typename] = ACTIONS(1887),
    [anon_sym_template] = ACTIONS(1887),
    [anon_sym_operator] = ACTIONS(1887),
    [anon_sym_friend] = ACTIONS(1887),
    [anon_sym_using] = ACTIONS(1887),
    [anon_sym_concept] = ACTIONS(1887),
    [anon_sym_precise] = ACTIONS(1887),
    [anon_sym_shared] = ACTIONS(1887),
    [anon_sym_groupshared] = ACTIONS(1887),
    [anon_sym_uniform] = ACTIONS(1887),
    [anon_sym_row_major] = ACTIONS(1887),
    [anon_sym_column_major] = ACTIONS(1887),
    [anon_sym_globallycoherent] = ACTIONS(1887),
    [anon_sym_centroid] = ACTIONS(1887),
    [anon_sym_noperspective] = ACTIONS(1887),
    [anon_sym_nointerpolation] = ACTIONS(1887),
    [anon_sym_sample] = ACTIONS(1887),
    [anon_sym_linear] = ACTIONS(1887),
    [anon_sym_snorm] = ACTIONS(1887),
    [anon_sym_unorm] = ACTIONS(1887),
    [anon_sym_point] = ACTIONS(1887),
    [anon_sym_line] = ACTIONS(1887),
    [anon_sym_triangleadj] = ACTIONS(1887),
    [anon_sym_lineadj] = ACTIONS(1887),
    [anon_sym_triangle] = ACTIONS(1887),
  },
  [2192] = {
    [sym_identifier] = ACTIONS(1925),
    [anon_sym_LPAREN2] = ACTIONS(1927),
    [anon_sym_TILDE] = ACTIONS(1927),
    [anon_sym_STAR] = ACTIONS(1927),
    [anon_sym_PIPE_PIPE] = ACTIONS(1927),
    [anon_sym_AMP_AMP] = ACTIONS(1927),
    [anon_sym_AMP] = ACTIONS(1925),
    [anon_sym___extension__] = ACTIONS(1925),
    [anon_sym_in] = ACTIONS(1925),
    [anon_sym_out] = ACTIONS(1925),
    [anon_sym_inout] = ACTIONS(1925),
    [anon_sym_extern] = ACTIONS(1925),
    [anon_sym___attribute__] = ACTIONS(1925),
    [anon_sym_COLON_COLON] = ACTIONS(1927),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1927),
    [anon_sym___declspec] = ACTIONS(1925),
    [anon_sym___based] = ACTIONS(1925),
    [anon_sym___cdecl] = ACTIONS(1925),
    [anon_sym___clrcall] = ACTIONS(1925),
    [anon_sym___stdcall] = ACTIONS(1925),
    [anon_sym___fastcall] = ACTIONS(1925),
    [anon_sym___thiscall] = ACTIONS(1925),
    [anon_sym___vectorcall] = ACTIONS(1925),
    [anon_sym_signed] = ACTIONS(1925),
    [anon_sym_unsigned] = ACTIONS(1925),
    [anon_sym_long] = ACTIONS(1925),
    [anon_sym_short] = ACTIONS(1925),
    [anon_sym_LBRACK] = ACTIONS(1925),
    [anon_sym_static] = ACTIONS(1925),
    [anon_sym_register] = ACTIONS(1925),
    [anon_sym_inline] = ACTIONS(1925),
    [anon_sym___inline] = ACTIONS(1925),
    [anon_sym___inline__] = ACTIONS(1925),
    [anon_sym___forceinline] = ACTIONS(1925),
    [anon_sym_thread_local] = ACTIONS(1925),
    [anon_sym___thread] = ACTIONS(1925),
    [anon_sym_const] = ACTIONS(1925),
    [anon_sym_constexpr] = ACTIONS(1925),
    [anon_sym_volatile] = ACTIONS(1925),
    [anon_sym_restrict] = ACTIONS(1925),
    [anon_sym___restrict__] = ACTIONS(1925),
    [anon_sym__Atomic] = ACTIONS(1925),
    [anon_sym__Noreturn] = ACTIONS(1925),
    [anon_sym_noreturn] = ACTIONS(1925),
    [anon_sym_mutable] = ACTIONS(1925),
    [anon_sym_constinit] = ACTIONS(1925),
    [anon_sym_consteval] = ACTIONS(1925),
    [anon_sym_alignas] = ACTIONS(1925),
    [anon_sym__Alignas] = ACTIONS(1925),
    [sym_primitive_type] = ACTIONS(1925),
    [anon_sym_enum] = ACTIONS(1925),
    [anon_sym_class] = ACTIONS(1925),
    [anon_sym_struct] = ACTIONS(1925),
    [anon_sym_union] = ACTIONS(1925),
    [anon_sym_or] = ACTIONS(1925),
    [anon_sym_and] = ACTIONS(1925),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1925),
    [anon_sym_decltype] = ACTIONS(1925),
    [sym_virtual] = ACTIONS(1925),
    [anon_sym_explicit] = ACTIONS(1925),
    [anon_sym_typename] = ACTIONS(1925),
    [anon_sym_template] = ACTIONS(1925),
    [anon_sym_operator] = ACTIONS(1925),
    [anon_sym_friend] = ACTIONS(1925),
    [anon_sym_using] = ACTIONS(1925),
    [anon_sym_concept] = ACTIONS(1925),
    [anon_sym_precise] = ACTIONS(1925),
    [anon_sym_shared] = ACTIONS(1925),
    [anon_sym_groupshared] = ACTIONS(1925),
    [anon_sym_uniform] = ACTIONS(1925),
    [anon_sym_row_major] = ACTIONS(1925),
    [anon_sym_column_major] = ACTIONS(1925),
    [anon_sym_globallycoherent] = ACTIONS(1925),
    [anon_sym_centroid] = ACTIONS(1925),
    [anon_sym_noperspective] = ACTIONS(1925),
    [anon_sym_nointerpolation] = ACTIONS(1925),
    [anon_sym_sample] = ACTIONS(1925),
    [anon_sym_linear] = ACTIONS(1925),
    [anon_sym_snorm] = ACTIONS(1925),
    [anon_sym_unorm] = ACTIONS(1925),
    [anon_sym_point] = ACTIONS(1925),
    [anon_sym_line] = ACTIONS(1925),
    [anon_sym_triangleadj] = ACTIONS(1925),
    [anon_sym_lineadj] = ACTIONS(1925),
    [anon_sym_triangle] = ACTIONS(1925),
  },
  [2193] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1971),
    [anon_sym_COMMA] = ACTIONS(1971),
    [anon_sym_RPAREN] = ACTIONS(1971),
    [anon_sym_LPAREN2] = ACTIONS(1971),
    [anon_sym_TILDE] = ACTIONS(1971),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_PIPE_PIPE] = ACTIONS(1971),
    [anon_sym_AMP_AMP] = ACTIONS(1971),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_COLON] = ACTIONS(1969),
    [anon_sym_SEMI] = ACTIONS(1971),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym_in] = ACTIONS(1969),
    [anon_sym_out] = ACTIONS(1969),
    [anon_sym_inout] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1971),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym___cdecl] = ACTIONS(1969),
    [anon_sym___clrcall] = ACTIONS(1969),
    [anon_sym___stdcall] = ACTIONS(1969),
    [anon_sym___fastcall] = ACTIONS(1969),
    [anon_sym___thiscall] = ACTIONS(1969),
    [anon_sym___vectorcall] = ACTIONS(1969),
    [anon_sym_LBRACE] = ACTIONS(1971),
    [anon_sym_LBRACK] = ACTIONS(1969),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_EQ] = ACTIONS(1971),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [anon_sym_else] = ACTIONS(1969),
    [anon_sym_while] = ACTIONS(1969),
    [anon_sym_or] = ACTIONS(1969),
    [anon_sym_and] = ACTIONS(1969),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_final] = ACTIONS(1969),
    [anon_sym_override] = ACTIONS(1969),
    [sym_virtual] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1969),
    [anon_sym_GT2] = ACTIONS(1971),
    [anon_sym_operator] = ACTIONS(1969),
    [anon_sym_try] = ACTIONS(1969),
    [anon_sym_requires] = ACTIONS(1969),
    [anon_sym_precise] = ACTIONS(1969),
    [anon_sym_shared] = ACTIONS(1969),
    [anon_sym_groupshared] = ACTIONS(1969),
    [anon_sym_uniform] = ACTIONS(1969),
    [anon_sym_row_major] = ACTIONS(1969),
    [anon_sym_column_major] = ACTIONS(1969),
    [anon_sym_globallycoherent] = ACTIONS(1969),
    [anon_sym_centroid] = ACTIONS(1969),
    [anon_sym_noperspective] = ACTIONS(1969),
    [anon_sym_nointerpolation] = ACTIONS(1969),
    [anon_sym_sample] = ACTIONS(1969),
    [anon_sym_linear] = ACTIONS(1969),
    [anon_sym_snorm] = ACTIONS(1969),
    [anon_sym_unorm] = ACTIONS(1969),
    [anon_sym_point] = ACTIONS(1969),
    [anon_sym_line] = ACTIONS(1969),
    [anon_sym_triangleadj] = ACTIONS(1969),
    [anon_sym_lineadj] = ACTIONS(1969),
    [anon_sym_triangle] = ACTIONS(1969),
  },
  [2194] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_LPAREN2] = ACTIONS(1971),
    [anon_sym_TILDE] = ACTIONS(1971),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_PIPE_PIPE] = ACTIONS(1971),
    [anon_sym_AMP_AMP] = ACTIONS(1971),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym_in] = ACTIONS(1969),
    [anon_sym_out] = ACTIONS(1969),
    [anon_sym_inout] = ACTIONS(1969),
    [anon_sym_extern] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1971),
    [anon_sym___declspec] = ACTIONS(1969),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym___cdecl] = ACTIONS(1969),
    [anon_sym___clrcall] = ACTIONS(1969),
    [anon_sym___stdcall] = ACTIONS(1969),
    [anon_sym___fastcall] = ACTIONS(1969),
    [anon_sym___thiscall] = ACTIONS(1969),
    [anon_sym___vectorcall] = ACTIONS(1969),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1969),
    [anon_sym_static] = ACTIONS(1969),
    [anon_sym_register] = ACTIONS(1969),
    [anon_sym_inline] = ACTIONS(1969),
    [anon_sym___inline] = ACTIONS(1969),
    [anon_sym___inline__] = ACTIONS(1969),
    [anon_sym___forceinline] = ACTIONS(1969),
    [anon_sym_thread_local] = ACTIONS(1969),
    [anon_sym___thread] = ACTIONS(1969),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_enum] = ACTIONS(1969),
    [anon_sym_class] = ACTIONS(1969),
    [anon_sym_struct] = ACTIONS(1969),
    [anon_sym_union] = ACTIONS(1969),
    [anon_sym_or] = ACTIONS(1969),
    [anon_sym_and] = ACTIONS(1969),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [sym_virtual] = ACTIONS(1969),
    [anon_sym_explicit] = ACTIONS(1969),
    [anon_sym_typename] = ACTIONS(1969),
    [anon_sym_template] = ACTIONS(1969),
    [anon_sym_operator] = ACTIONS(1969),
    [anon_sym_friend] = ACTIONS(1969),
    [anon_sym_using] = ACTIONS(1969),
    [anon_sym_concept] = ACTIONS(1969),
    [anon_sym_precise] = ACTIONS(1969),
    [anon_sym_shared] = ACTIONS(1969),
    [anon_sym_groupshared] = ACTIONS(1969),
    [anon_sym_uniform] = ACTIONS(1969),
    [anon_sym_row_major] = ACTIONS(1969),
    [anon_sym_column_major] = ACTIONS(1969),
    [anon_sym_globallycoherent] = ACTIONS(1969),
    [anon_sym_centroid] = ACTIONS(1969),
    [anon_sym_noperspective] = ACTIONS(1969),
    [anon_sym_nointerpolation] = ACTIONS(1969),
    [anon_sym_sample] = ACTIONS(1969),
    [anon_sym_linear] = ACTIONS(1969),
    [anon_sym_snorm] = ACTIONS(1969),
    [anon_sym_unorm] = ACTIONS(1969),
    [anon_sym_point] = ACTIONS(1969),
    [anon_sym_line] = ACTIONS(1969),
    [anon_sym_triangleadj] = ACTIONS(1969),
    [anon_sym_lineadj] = ACTIONS(1969),
    [anon_sym_triangle] = ACTIONS(1969),
  },
  [2195] = {
    [sym_identifier] = ACTIONS(1949),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1951),
    [anon_sym_COMMA] = ACTIONS(1951),
    [anon_sym_RPAREN] = ACTIONS(1951),
    [anon_sym_LPAREN2] = ACTIONS(1951),
    [anon_sym_TILDE] = ACTIONS(1951),
    [anon_sym_STAR] = ACTIONS(1951),
    [anon_sym_PIPE_PIPE] = ACTIONS(1951),
    [anon_sym_AMP_AMP] = ACTIONS(1951),
    [anon_sym_AMP] = ACTIONS(1949),
    [anon_sym_COLON] = ACTIONS(1949),
    [anon_sym_SEMI] = ACTIONS(1951),
    [anon_sym___extension__] = ACTIONS(1949),
    [anon_sym_in] = ACTIONS(1949),
    [anon_sym_out] = ACTIONS(1949),
    [anon_sym_inout] = ACTIONS(1949),
    [anon_sym_extern] = ACTIONS(1949),
    [anon_sym___attribute__] = ACTIONS(1949),
    [anon_sym_COLON_COLON] = ACTIONS(1951),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1951),
    [anon_sym___declspec] = ACTIONS(1949),
    [anon_sym___based] = ACTIONS(1949),
    [anon_sym___cdecl] = ACTIONS(1949),
    [anon_sym___clrcall] = ACTIONS(1949),
    [anon_sym___stdcall] = ACTIONS(1949),
    [anon_sym___fastcall] = ACTIONS(1949),
    [anon_sym___thiscall] = ACTIONS(1949),
    [anon_sym___vectorcall] = ACTIONS(1949),
    [anon_sym_LBRACE] = ACTIONS(1951),
    [anon_sym_LBRACK] = ACTIONS(1949),
    [anon_sym_static] = ACTIONS(1949),
    [anon_sym_EQ] = ACTIONS(1951),
    [anon_sym_register] = ACTIONS(1949),
    [anon_sym_inline] = ACTIONS(1949),
    [anon_sym___inline] = ACTIONS(1949),
    [anon_sym___inline__] = ACTIONS(1949),
    [anon_sym___forceinline] = ACTIONS(1949),
    [anon_sym_thread_local] = ACTIONS(1949),
    [anon_sym___thread] = ACTIONS(1949),
    [anon_sym_const] = ACTIONS(1949),
    [anon_sym_constexpr] = ACTIONS(1949),
    [anon_sym_volatile] = ACTIONS(1949),
    [anon_sym_restrict] = ACTIONS(1949),
    [anon_sym___restrict__] = ACTIONS(1949),
    [anon_sym__Atomic] = ACTIONS(1949),
    [anon_sym__Noreturn] = ACTIONS(1949),
    [anon_sym_noreturn] = ACTIONS(1949),
    [anon_sym_mutable] = ACTIONS(1949),
    [anon_sym_constinit] = ACTIONS(1949),
    [anon_sym_consteval] = ACTIONS(1949),
    [anon_sym_alignas] = ACTIONS(1949),
    [anon_sym__Alignas] = ACTIONS(1949),
    [anon_sym_else] = ACTIONS(1949),
    [anon_sym_while] = ACTIONS(1949),
    [anon_sym_or] = ACTIONS(1949),
    [anon_sym_and] = ACTIONS(1949),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1949),
    [anon_sym_decltype] = ACTIONS(1949),
    [anon_sym_final] = ACTIONS(1949),
    [anon_sym_override] = ACTIONS(1949),
    [sym_virtual] = ACTIONS(1949),
    [anon_sym_template] = ACTIONS(1949),
    [anon_sym_GT2] = ACTIONS(1951),
    [anon_sym_operator] = ACTIONS(1949),
    [anon_sym_try] = ACTIONS(1949),
    [anon_sym_requires] = ACTIONS(1949),
    [anon_sym_precise] = ACTIONS(1949),
    [anon_sym_shared] = ACTIONS(1949),
    [anon_sym_groupshared] = ACTIONS(1949),
    [anon_sym_uniform] = ACTIONS(1949),
    [anon_sym_row_major] = ACTIONS(1949),
    [anon_sym_column_major] = ACTIONS(1949),
    [anon_sym_globallycoherent] = ACTIONS(1949),
    [anon_sym_centroid] = ACTIONS(1949),
    [anon_sym_noperspective] = ACTIONS(1949),
    [anon_sym_nointerpolation] = ACTIONS(1949),
    [anon_sym_sample] = ACTIONS(1949),
    [anon_sym_linear] = ACTIONS(1949),
    [anon_sym_snorm] = ACTIONS(1949),
    [anon_sym_unorm] = ACTIONS(1949),
    [anon_sym_point] = ACTIONS(1949),
    [anon_sym_line] = ACTIONS(1949),
    [anon_sym_triangleadj] = ACTIONS(1949),
    [anon_sym_lineadj] = ACTIONS(1949),
    [anon_sym_triangle] = ACTIONS(1949),
  },
  [2196] = {
    [sym__declaration_modifiers] = STATE(2224),
    [sym_attribute_specifier] = STATE(2224),
    [sym_attribute_declaration] = STATE(2224),
    [sym_ms_declspec_modifier] = STATE(2224),
    [sym_storage_class_specifier] = STATE(2224),
    [sym_type_qualifier] = STATE(2224),
    [sym_alignas_qualifier] = STATE(2331),
    [sym_decltype_auto] = STATE(2274),
    [sym_qualifiers] = STATE(2224),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2224),
    [sym_identifier] = ACTIONS(5214),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5216),
    [anon_sym_COMMA] = ACTIONS(5216),
    [anon_sym_RPAREN] = ACTIONS(5216),
    [anon_sym_LPAREN2] = ACTIONS(5216),
    [anon_sym_TILDE] = ACTIONS(5216),
    [anon_sym_STAR] = ACTIONS(5216),
    [anon_sym_AMP_AMP] = ACTIONS(5216),
    [anon_sym_AMP] = ACTIONS(5214),
    [anon_sym_COLON] = ACTIONS(5214),
    [anon_sym_SEMI] = ACTIONS(5216),
    [anon_sym___extension__] = ACTIONS(4981),
    [anon_sym_in] = ACTIONS(5218),
    [anon_sym_out] = ACTIONS(5218),
    [anon_sym_inout] = ACTIONS(5218),
    [anon_sym_extern] = ACTIONS(4985),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5216),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4991),
    [anon_sym___declspec] = ACTIONS(4993),
    [anon_sym___based] = ACTIONS(5214),
    [anon_sym___cdecl] = ACTIONS(5214),
    [anon_sym___clrcall] = ACTIONS(5214),
    [anon_sym___stdcall] = ACTIONS(5214),
    [anon_sym___fastcall] = ACTIONS(5214),
    [anon_sym___thiscall] = ACTIONS(5214),
    [anon_sym___vectorcall] = ACTIONS(5214),
    [anon_sym_LBRACK] = ACTIONS(5214),
    [anon_sym_static] = ACTIONS(4985),
    [anon_sym_EQ] = ACTIONS(5216),
    [anon_sym_register] = ACTIONS(4985),
    [anon_sym_inline] = ACTIONS(4985),
    [anon_sym___inline] = ACTIONS(4985),
    [anon_sym___inline__] = ACTIONS(4985),
    [anon_sym___forceinline] = ACTIONS(4985),
    [anon_sym_thread_local] = ACTIONS(4985),
    [anon_sym___thread] = ACTIONS(4985),
    [anon_sym_const] = ACTIONS(4981),
    [anon_sym_constexpr] = ACTIONS(4981),
    [anon_sym_volatile] = ACTIONS(4981),
    [anon_sym_restrict] = ACTIONS(4981),
    [anon_sym___restrict__] = ACTIONS(4981),
    [anon_sym__Atomic] = ACTIONS(4981),
    [anon_sym__Noreturn] = ACTIONS(4981),
    [anon_sym_noreturn] = ACTIONS(4981),
    [anon_sym_mutable] = ACTIONS(4981),
    [anon_sym_constinit] = ACTIONS(4981),
    [anon_sym_consteval] = ACTIONS(4981),
    [anon_sym_alignas] = ACTIONS(4995),
    [anon_sym__Alignas] = ACTIONS(4995),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5220),
    [anon_sym_decltype] = ACTIONS(5222),
    [sym_virtual] = ACTIONS(5218),
    [anon_sym_template] = ACTIONS(5214),
    [anon_sym_GT2] = ACTIONS(5216),
    [anon_sym_operator] = ACTIONS(5214),
    [anon_sym_precise] = ACTIONS(4997),
    [anon_sym_shared] = ACTIONS(4997),
    [anon_sym_groupshared] = ACTIONS(4997),
    [anon_sym_uniform] = ACTIONS(4997),
    [anon_sym_row_major] = ACTIONS(4997),
    [anon_sym_column_major] = ACTIONS(4997),
    [anon_sym_globallycoherent] = ACTIONS(4997),
    [anon_sym_centroid] = ACTIONS(4997),
    [anon_sym_noperspective] = ACTIONS(4997),
    [anon_sym_nointerpolation] = ACTIONS(4997),
    [anon_sym_sample] = ACTIONS(4997),
    [anon_sym_linear] = ACTIONS(4997),
    [anon_sym_snorm] = ACTIONS(4997),
    [anon_sym_unorm] = ACTIONS(4997),
    [anon_sym_point] = ACTIONS(4997),
    [anon_sym_line] = ACTIONS(4997),
    [anon_sym_triangleadj] = ACTIONS(4997),
    [anon_sym_lineadj] = ACTIONS(4997),
    [anon_sym_triangle] = ACTIONS(4997),
  },
  [2197] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2197),
    [sym_identifier] = ACTIONS(5224),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5226),
    [anon_sym_COMMA] = ACTIONS(5226),
    [anon_sym_RPAREN] = ACTIONS(5226),
    [anon_sym_LPAREN2] = ACTIONS(5226),
    [anon_sym_TILDE] = ACTIONS(5226),
    [anon_sym_STAR] = ACTIONS(5226),
    [anon_sym_AMP_AMP] = ACTIONS(5226),
    [anon_sym_AMP] = ACTIONS(5224),
    [anon_sym_COLON] = ACTIONS(5224),
    [anon_sym_SEMI] = ACTIONS(5226),
    [anon_sym___extension__] = ACTIONS(5224),
    [anon_sym_in] = ACTIONS(5224),
    [anon_sym_out] = ACTIONS(5224),
    [anon_sym_inout] = ACTIONS(5224),
    [anon_sym_extern] = ACTIONS(5224),
    [anon_sym___attribute__] = ACTIONS(5224),
    [anon_sym_COLON_COLON] = ACTIONS(5226),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5226),
    [anon_sym___declspec] = ACTIONS(5224),
    [anon_sym___based] = ACTIONS(5224),
    [anon_sym___cdecl] = ACTIONS(5224),
    [anon_sym___clrcall] = ACTIONS(5224),
    [anon_sym___stdcall] = ACTIONS(5224),
    [anon_sym___fastcall] = ACTIONS(5224),
    [anon_sym___thiscall] = ACTIONS(5224),
    [anon_sym___vectorcall] = ACTIONS(5224),
    [anon_sym_LBRACE] = ACTIONS(5226),
    [anon_sym_signed] = ACTIONS(5228),
    [anon_sym_unsigned] = ACTIONS(5228),
    [anon_sym_long] = ACTIONS(5228),
    [anon_sym_short] = ACTIONS(5228),
    [anon_sym_LBRACK] = ACTIONS(5224),
    [anon_sym_static] = ACTIONS(5224),
    [anon_sym_EQ] = ACTIONS(5226),
    [anon_sym_register] = ACTIONS(5224),
    [anon_sym_inline] = ACTIONS(5224),
    [anon_sym___inline] = ACTIONS(5224),
    [anon_sym___inline__] = ACTIONS(5224),
    [anon_sym___forceinline] = ACTIONS(5224),
    [anon_sym_thread_local] = ACTIONS(5224),
    [anon_sym___thread] = ACTIONS(5224),
    [anon_sym_const] = ACTIONS(5224),
    [anon_sym_constexpr] = ACTIONS(5224),
    [anon_sym_volatile] = ACTIONS(5224),
    [anon_sym_restrict] = ACTIONS(5224),
    [anon_sym___restrict__] = ACTIONS(5224),
    [anon_sym__Atomic] = ACTIONS(5224),
    [anon_sym__Noreturn] = ACTIONS(5224),
    [anon_sym_noreturn] = ACTIONS(5224),
    [anon_sym_mutable] = ACTIONS(5224),
    [anon_sym_constinit] = ACTIONS(5224),
    [anon_sym_consteval] = ACTIONS(5224),
    [anon_sym_alignas] = ACTIONS(5224),
    [anon_sym__Alignas] = ACTIONS(5224),
    [sym_primitive_type] = ACTIONS(5224),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5224),
    [anon_sym_decltype] = ACTIONS(5224),
    [anon_sym_final] = ACTIONS(5224),
    [anon_sym_override] = ACTIONS(5224),
    [sym_virtual] = ACTIONS(5224),
    [anon_sym_template] = ACTIONS(5224),
    [anon_sym_GT2] = ACTIONS(5226),
    [anon_sym_operator] = ACTIONS(5224),
    [anon_sym_requires] = ACTIONS(5224),
    [anon_sym_precise] = ACTIONS(5224),
    [anon_sym_shared] = ACTIONS(5224),
    [anon_sym_groupshared] = ACTIONS(5224),
    [anon_sym_uniform] = ACTIONS(5224),
    [anon_sym_row_major] = ACTIONS(5224),
    [anon_sym_column_major] = ACTIONS(5224),
    [anon_sym_globallycoherent] = ACTIONS(5224),
    [anon_sym_centroid] = ACTIONS(5224),
    [anon_sym_noperspective] = ACTIONS(5224),
    [anon_sym_nointerpolation] = ACTIONS(5224),
    [anon_sym_sample] = ACTIONS(5224),
    [anon_sym_linear] = ACTIONS(5224),
    [anon_sym_snorm] = ACTIONS(5224),
    [anon_sym_unorm] = ACTIONS(5224),
    [anon_sym_point] = ACTIONS(5224),
    [anon_sym_line] = ACTIONS(5224),
    [anon_sym_triangleadj] = ACTIONS(5224),
    [anon_sym_lineadj] = ACTIONS(5224),
    [anon_sym_triangle] = ACTIONS(5224),
  },
  [2198] = {
    [sym_identifier] = ACTIONS(1953),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_TILDE] = ACTIONS(1955),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_PIPE_PIPE] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym_in] = ACTIONS(1953),
    [anon_sym_out] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1953),
    [anon_sym_extern] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1955),
    [anon_sym___declspec] = ACTIONS(1953),
    [anon_sym___based] = ACTIONS(1953),
    [anon_sym___cdecl] = ACTIONS(1953),
    [anon_sym___clrcall] = ACTIONS(1953),
    [anon_sym___stdcall] = ACTIONS(1953),
    [anon_sym___fastcall] = ACTIONS(1953),
    [anon_sym___thiscall] = ACTIONS(1953),
    [anon_sym___vectorcall] = ACTIONS(1953),
    [anon_sym_signed] = ACTIONS(1953),
    [anon_sym_unsigned] = ACTIONS(1953),
    [anon_sym_long] = ACTIONS(1953),
    [anon_sym_short] = ACTIONS(1953),
    [anon_sym_LBRACK] = ACTIONS(1953),
    [anon_sym_static] = ACTIONS(1953),
    [anon_sym_register] = ACTIONS(1953),
    [anon_sym_inline] = ACTIONS(1953),
    [anon_sym___inline] = ACTIONS(1953),
    [anon_sym___inline__] = ACTIONS(1953),
    [anon_sym___forceinline] = ACTIONS(1953),
    [anon_sym_thread_local] = ACTIONS(1953),
    [anon_sym___thread] = ACTIONS(1953),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [sym_primitive_type] = ACTIONS(1953),
    [anon_sym_enum] = ACTIONS(1953),
    [anon_sym_class] = ACTIONS(1953),
    [anon_sym_struct] = ACTIONS(1953),
    [anon_sym_union] = ACTIONS(1953),
    [anon_sym_or] = ACTIONS(1953),
    [anon_sym_and] = ACTIONS(1953),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [sym_virtual] = ACTIONS(1953),
    [anon_sym_explicit] = ACTIONS(1953),
    [anon_sym_typename] = ACTIONS(1953),
    [anon_sym_template] = ACTIONS(1953),
    [anon_sym_operator] = ACTIONS(1953),
    [anon_sym_friend] = ACTIONS(1953),
    [anon_sym_using] = ACTIONS(1953),
    [anon_sym_concept] = ACTIONS(1953),
    [anon_sym_precise] = ACTIONS(1953),
    [anon_sym_shared] = ACTIONS(1953),
    [anon_sym_groupshared] = ACTIONS(1953),
    [anon_sym_uniform] = ACTIONS(1953),
    [anon_sym_row_major] = ACTIONS(1953),
    [anon_sym_column_major] = ACTIONS(1953),
    [anon_sym_globallycoherent] = ACTIONS(1953),
    [anon_sym_centroid] = ACTIONS(1953),
    [anon_sym_noperspective] = ACTIONS(1953),
    [anon_sym_nointerpolation] = ACTIONS(1953),
    [anon_sym_sample] = ACTIONS(1953),
    [anon_sym_linear] = ACTIONS(1953),
    [anon_sym_snorm] = ACTIONS(1953),
    [anon_sym_unorm] = ACTIONS(1953),
    [anon_sym_point] = ACTIONS(1953),
    [anon_sym_line] = ACTIONS(1953),
    [anon_sym_triangleadj] = ACTIONS(1953),
    [anon_sym_lineadj] = ACTIONS(1953),
    [anon_sym_triangle] = ACTIONS(1953),
  },
  [2199] = {
    [sym_identifier] = ACTIONS(1953),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1955),
    [anon_sym_COMMA] = ACTIONS(1955),
    [anon_sym_RPAREN] = ACTIONS(1955),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_TILDE] = ACTIONS(1955),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_PIPE_PIPE] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym_COLON] = ACTIONS(1953),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym_in] = ACTIONS(1953),
    [anon_sym_out] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1953),
    [anon_sym_extern] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1955),
    [anon_sym___declspec] = ACTIONS(1953),
    [anon_sym___based] = ACTIONS(1953),
    [anon_sym___cdecl] = ACTIONS(1953),
    [anon_sym___clrcall] = ACTIONS(1953),
    [anon_sym___stdcall] = ACTIONS(1953),
    [anon_sym___fastcall] = ACTIONS(1953),
    [anon_sym___thiscall] = ACTIONS(1953),
    [anon_sym___vectorcall] = ACTIONS(1953),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_LBRACK] = ACTIONS(1953),
    [anon_sym_static] = ACTIONS(1953),
    [anon_sym_EQ] = ACTIONS(1955),
    [anon_sym_register] = ACTIONS(1953),
    [anon_sym_inline] = ACTIONS(1953),
    [anon_sym___inline] = ACTIONS(1953),
    [anon_sym___inline__] = ACTIONS(1953),
    [anon_sym___forceinline] = ACTIONS(1953),
    [anon_sym_thread_local] = ACTIONS(1953),
    [anon_sym___thread] = ACTIONS(1953),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [anon_sym_else] = ACTIONS(1953),
    [anon_sym_while] = ACTIONS(1953),
    [anon_sym_or] = ACTIONS(1953),
    [anon_sym_and] = ACTIONS(1953),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
    [sym_virtual] = ACTIONS(1953),
    [anon_sym_template] = ACTIONS(1953),
    [anon_sym_GT2] = ACTIONS(1955),
    [anon_sym_operator] = ACTIONS(1953),
    [anon_sym_try] = ACTIONS(1953),
    [anon_sym_requires] = ACTIONS(1953),
    [anon_sym_precise] = ACTIONS(1953),
    [anon_sym_shared] = ACTIONS(1953),
    [anon_sym_groupshared] = ACTIONS(1953),
    [anon_sym_uniform] = ACTIONS(1953),
    [anon_sym_row_major] = ACTIONS(1953),
    [anon_sym_column_major] = ACTIONS(1953),
    [anon_sym_globallycoherent] = ACTIONS(1953),
    [anon_sym_centroid] = ACTIONS(1953),
    [anon_sym_noperspective] = ACTIONS(1953),
    [anon_sym_nointerpolation] = ACTIONS(1953),
    [anon_sym_sample] = ACTIONS(1953),
    [anon_sym_linear] = ACTIONS(1953),
    [anon_sym_snorm] = ACTIONS(1953),
    [anon_sym_unorm] = ACTIONS(1953),
    [anon_sym_point] = ACTIONS(1953),
    [anon_sym_line] = ACTIONS(1953),
    [anon_sym_triangleadj] = ACTIONS(1953),
    [anon_sym_lineadj] = ACTIONS(1953),
    [anon_sym_triangle] = ACTIONS(1953),
  },
  [2200] = {
    [sym_identifier] = ACTIONS(5231),
    [anon_sym_LPAREN2] = ACTIONS(5233),
    [anon_sym_TILDE] = ACTIONS(5233),
    [anon_sym_STAR] = ACTIONS(5233),
    [anon_sym_PIPE_PIPE] = ACTIONS(5235),
    [anon_sym_AMP_AMP] = ACTIONS(5237),
    [anon_sym_AMP] = ACTIONS(5231),
    [anon_sym___extension__] = ACTIONS(5231),
    [anon_sym_in] = ACTIONS(5231),
    [anon_sym_out] = ACTIONS(5231),
    [anon_sym_inout] = ACTIONS(5231),
    [anon_sym_extern] = ACTIONS(5231),
    [anon_sym___attribute__] = ACTIONS(5231),
    [anon_sym_COLON_COLON] = ACTIONS(5233),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5233),
    [anon_sym___declspec] = ACTIONS(5231),
    [anon_sym___based] = ACTIONS(5231),
    [anon_sym___cdecl] = ACTIONS(5231),
    [anon_sym___clrcall] = ACTIONS(5231),
    [anon_sym___stdcall] = ACTIONS(5231),
    [anon_sym___fastcall] = ACTIONS(5231),
    [anon_sym___thiscall] = ACTIONS(5231),
    [anon_sym___vectorcall] = ACTIONS(5231),
    [anon_sym_signed] = ACTIONS(5231),
    [anon_sym_unsigned] = ACTIONS(5231),
    [anon_sym_long] = ACTIONS(5231),
    [anon_sym_short] = ACTIONS(5231),
    [anon_sym_LBRACK] = ACTIONS(5231),
    [anon_sym_static] = ACTIONS(5231),
    [anon_sym_register] = ACTIONS(5231),
    [anon_sym_inline] = ACTIONS(5231),
    [anon_sym___inline] = ACTIONS(5231),
    [anon_sym___inline__] = ACTIONS(5231),
    [anon_sym___forceinline] = ACTIONS(5231),
    [anon_sym_thread_local] = ACTIONS(5231),
    [anon_sym___thread] = ACTIONS(5231),
    [anon_sym_const] = ACTIONS(5231),
    [anon_sym_constexpr] = ACTIONS(5231),
    [anon_sym_volatile] = ACTIONS(5231),
    [anon_sym_restrict] = ACTIONS(5231),
    [anon_sym___restrict__] = ACTIONS(5231),
    [anon_sym__Atomic] = ACTIONS(5231),
    [anon_sym__Noreturn] = ACTIONS(5231),
    [anon_sym_noreturn] = ACTIONS(5231),
    [anon_sym_mutable] = ACTIONS(5231),
    [anon_sym_constinit] = ACTIONS(5231),
    [anon_sym_consteval] = ACTIONS(5231),
    [anon_sym_alignas] = ACTIONS(5231),
    [anon_sym__Alignas] = ACTIONS(5231),
    [sym_primitive_type] = ACTIONS(5231),
    [anon_sym_enum] = ACTIONS(5231),
    [anon_sym_class] = ACTIONS(5231),
    [anon_sym_struct] = ACTIONS(5231),
    [anon_sym_union] = ACTIONS(5231),
    [anon_sym_or] = ACTIONS(5239),
    [anon_sym_and] = ACTIONS(5241),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5231),
    [anon_sym_decltype] = ACTIONS(5231),
    [sym_virtual] = ACTIONS(5231),
    [anon_sym_explicit] = ACTIONS(5231),
    [anon_sym_typename] = ACTIONS(5231),
    [anon_sym_template] = ACTIONS(5231),
    [anon_sym_operator] = ACTIONS(5231),
    [anon_sym_friend] = ACTIONS(5231),
    [anon_sym_using] = ACTIONS(5231),
    [anon_sym_concept] = ACTIONS(5231),
    [anon_sym_precise] = ACTIONS(5231),
    [anon_sym_shared] = ACTIONS(5231),
    [anon_sym_groupshared] = ACTIONS(5231),
    [anon_sym_uniform] = ACTIONS(5231),
    [anon_sym_row_major] = ACTIONS(5231),
    [anon_sym_column_major] = ACTIONS(5231),
    [anon_sym_globallycoherent] = ACTIONS(5231),
    [anon_sym_centroid] = ACTIONS(5231),
    [anon_sym_noperspective] = ACTIONS(5231),
    [anon_sym_nointerpolation] = ACTIONS(5231),
    [anon_sym_sample] = ACTIONS(5231),
    [anon_sym_linear] = ACTIONS(5231),
    [anon_sym_snorm] = ACTIONS(5231),
    [anon_sym_unorm] = ACTIONS(5231),
    [anon_sym_point] = ACTIONS(5231),
    [anon_sym_line] = ACTIONS(5231),
    [anon_sym_triangleadj] = ACTIONS(5231),
    [anon_sym_lineadj] = ACTIONS(5231),
    [anon_sym_triangle] = ACTIONS(5231),
  },
  [2201] = {
    [sym_identifier] = ACTIONS(1903),
    [anon_sym_LPAREN2] = ACTIONS(1905),
    [anon_sym_TILDE] = ACTIONS(1905),
    [anon_sym_STAR] = ACTIONS(1905),
    [anon_sym_PIPE_PIPE] = ACTIONS(1905),
    [anon_sym_AMP_AMP] = ACTIONS(1905),
    [anon_sym_AMP] = ACTIONS(1903),
    [anon_sym___extension__] = ACTIONS(1903),
    [anon_sym_in] = ACTIONS(1903),
    [anon_sym_out] = ACTIONS(1903),
    [anon_sym_inout] = ACTIONS(1903),
    [anon_sym_extern] = ACTIONS(1903),
    [anon_sym___attribute__] = ACTIONS(1903),
    [anon_sym_COLON_COLON] = ACTIONS(1905),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1905),
    [anon_sym___declspec] = ACTIONS(1903),
    [anon_sym___based] = ACTIONS(1903),
    [anon_sym___cdecl] = ACTIONS(1903),
    [anon_sym___clrcall] = ACTIONS(1903),
    [anon_sym___stdcall] = ACTIONS(1903),
    [anon_sym___fastcall] = ACTIONS(1903),
    [anon_sym___thiscall] = ACTIONS(1903),
    [anon_sym___vectorcall] = ACTIONS(1903),
    [anon_sym_signed] = ACTIONS(1903),
    [anon_sym_unsigned] = ACTIONS(1903),
    [anon_sym_long] = ACTIONS(1903),
    [anon_sym_short] = ACTIONS(1903),
    [anon_sym_LBRACK] = ACTIONS(1903),
    [anon_sym_static] = ACTIONS(1903),
    [anon_sym_register] = ACTIONS(1903),
    [anon_sym_inline] = ACTIONS(1903),
    [anon_sym___inline] = ACTIONS(1903),
    [anon_sym___inline__] = ACTIONS(1903),
    [anon_sym___forceinline] = ACTIONS(1903),
    [anon_sym_thread_local] = ACTIONS(1903),
    [anon_sym___thread] = ACTIONS(1903),
    [anon_sym_const] = ACTIONS(1903),
    [anon_sym_constexpr] = ACTIONS(1903),
    [anon_sym_volatile] = ACTIONS(1903),
    [anon_sym_restrict] = ACTIONS(1903),
    [anon_sym___restrict__] = ACTIONS(1903),
    [anon_sym__Atomic] = ACTIONS(1903),
    [anon_sym__Noreturn] = ACTIONS(1903),
    [anon_sym_noreturn] = ACTIONS(1903),
    [anon_sym_mutable] = ACTIONS(1903),
    [anon_sym_constinit] = ACTIONS(1903),
    [anon_sym_consteval] = ACTIONS(1903),
    [anon_sym_alignas] = ACTIONS(1903),
    [anon_sym__Alignas] = ACTIONS(1903),
    [sym_primitive_type] = ACTIONS(1903),
    [anon_sym_enum] = ACTIONS(1903),
    [anon_sym_class] = ACTIONS(1903),
    [anon_sym_struct] = ACTIONS(1903),
    [anon_sym_union] = ACTIONS(1903),
    [anon_sym_or] = ACTIONS(1903),
    [anon_sym_and] = ACTIONS(1903),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1903),
    [anon_sym_decltype] = ACTIONS(1903),
    [sym_virtual] = ACTIONS(1903),
    [anon_sym_explicit] = ACTIONS(1903),
    [anon_sym_typename] = ACTIONS(1903),
    [anon_sym_template] = ACTIONS(1903),
    [anon_sym_operator] = ACTIONS(1903),
    [anon_sym_friend] = ACTIONS(1903),
    [anon_sym_using] = ACTIONS(1903),
    [anon_sym_concept] = ACTIONS(1903),
    [anon_sym_precise] = ACTIONS(1903),
    [anon_sym_shared] = ACTIONS(1903),
    [anon_sym_groupshared] = ACTIONS(1903),
    [anon_sym_uniform] = ACTIONS(1903),
    [anon_sym_row_major] = ACTIONS(1903),
    [anon_sym_column_major] = ACTIONS(1903),
    [anon_sym_globallycoherent] = ACTIONS(1903),
    [anon_sym_centroid] = ACTIONS(1903),
    [anon_sym_noperspective] = ACTIONS(1903),
    [anon_sym_nointerpolation] = ACTIONS(1903),
    [anon_sym_sample] = ACTIONS(1903),
    [anon_sym_linear] = ACTIONS(1903),
    [anon_sym_snorm] = ACTIONS(1903),
    [anon_sym_unorm] = ACTIONS(1903),
    [anon_sym_point] = ACTIONS(1903),
    [anon_sym_line] = ACTIONS(1903),
    [anon_sym_triangleadj] = ACTIONS(1903),
    [anon_sym_lineadj] = ACTIONS(1903),
    [anon_sym_triangle] = ACTIONS(1903),
  },
  [2202] = {
    [sym_identifier] = ACTIONS(1917),
    [anon_sym_LPAREN2] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_STAR] = ACTIONS(1919),
    [anon_sym_PIPE_PIPE] = ACTIONS(1919),
    [anon_sym_AMP_AMP] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1917),
    [anon_sym___extension__] = ACTIONS(1917),
    [anon_sym_in] = ACTIONS(1917),
    [anon_sym_out] = ACTIONS(1917),
    [anon_sym_inout] = ACTIONS(1917),
    [anon_sym_extern] = ACTIONS(1917),
    [anon_sym___attribute__] = ACTIONS(1917),
    [anon_sym_COLON_COLON] = ACTIONS(1919),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1919),
    [anon_sym___declspec] = ACTIONS(1917),
    [anon_sym___based] = ACTIONS(1917),
    [anon_sym___cdecl] = ACTIONS(1917),
    [anon_sym___clrcall] = ACTIONS(1917),
    [anon_sym___stdcall] = ACTIONS(1917),
    [anon_sym___fastcall] = ACTIONS(1917),
    [anon_sym___thiscall] = ACTIONS(1917),
    [anon_sym___vectorcall] = ACTIONS(1917),
    [anon_sym_signed] = ACTIONS(1917),
    [anon_sym_unsigned] = ACTIONS(1917),
    [anon_sym_long] = ACTIONS(1917),
    [anon_sym_short] = ACTIONS(1917),
    [anon_sym_LBRACK] = ACTIONS(1917),
    [anon_sym_static] = ACTIONS(1917),
    [anon_sym_register] = ACTIONS(1917),
    [anon_sym_inline] = ACTIONS(1917),
    [anon_sym___inline] = ACTIONS(1917),
    [anon_sym___inline__] = ACTIONS(1917),
    [anon_sym___forceinline] = ACTIONS(1917),
    [anon_sym_thread_local] = ACTIONS(1917),
    [anon_sym___thread] = ACTIONS(1917),
    [anon_sym_const] = ACTIONS(1917),
    [anon_sym_constexpr] = ACTIONS(1917),
    [anon_sym_volatile] = ACTIONS(1917),
    [anon_sym_restrict] = ACTIONS(1917),
    [anon_sym___restrict__] = ACTIONS(1917),
    [anon_sym__Atomic] = ACTIONS(1917),
    [anon_sym__Noreturn] = ACTIONS(1917),
    [anon_sym_noreturn] = ACTIONS(1917),
    [anon_sym_mutable] = ACTIONS(1917),
    [anon_sym_constinit] = ACTIONS(1917),
    [anon_sym_consteval] = ACTIONS(1917),
    [anon_sym_alignas] = ACTIONS(1917),
    [anon_sym__Alignas] = ACTIONS(1917),
    [sym_primitive_type] = ACTIONS(1917),
    [anon_sym_enum] = ACTIONS(1917),
    [anon_sym_class] = ACTIONS(1917),
    [anon_sym_struct] = ACTIONS(1917),
    [anon_sym_union] = ACTIONS(1917),
    [anon_sym_or] = ACTIONS(1917),
    [anon_sym_and] = ACTIONS(1917),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1917),
    [anon_sym_decltype] = ACTIONS(1917),
    [sym_virtual] = ACTIONS(1917),
    [anon_sym_explicit] = ACTIONS(1917),
    [anon_sym_typename] = ACTIONS(1917),
    [anon_sym_template] = ACTIONS(1917),
    [anon_sym_operator] = ACTIONS(1917),
    [anon_sym_friend] = ACTIONS(1917),
    [anon_sym_using] = ACTIONS(1917),
    [anon_sym_concept] = ACTIONS(1917),
    [anon_sym_precise] = ACTIONS(1917),
    [anon_sym_shared] = ACTIONS(1917),
    [anon_sym_groupshared] = ACTIONS(1917),
    [anon_sym_uniform] = ACTIONS(1917),
    [anon_sym_row_major] = ACTIONS(1917),
    [anon_sym_column_major] = ACTIONS(1917),
    [anon_sym_globallycoherent] = ACTIONS(1917),
    [anon_sym_centroid] = ACTIONS(1917),
    [anon_sym_noperspective] = ACTIONS(1917),
    [anon_sym_nointerpolation] = ACTIONS(1917),
    [anon_sym_sample] = ACTIONS(1917),
    [anon_sym_linear] = ACTIONS(1917),
    [anon_sym_snorm] = ACTIONS(1917),
    [anon_sym_unorm] = ACTIONS(1917),
    [anon_sym_point] = ACTIONS(1917),
    [anon_sym_line] = ACTIONS(1917),
    [anon_sym_triangleadj] = ACTIONS(1917),
    [anon_sym_lineadj] = ACTIONS(1917),
    [anon_sym_triangle] = ACTIONS(1917),
  },
  [2203] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(3250),
    [sym_raw_string_literal] = STATE(2868),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2520),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_RPAREN] = ACTIONS(3837),
    [anon_sym_LPAREN2] = ACTIONS(3837),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3834),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3837),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3834),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5243),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym___extension__] = ACTIONS(3830),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_signed] = ACTIONS(5190),
    [anon_sym_unsigned] = ACTIONS(5190),
    [anon_sym_long] = ACTIONS(5190),
    [anon_sym_short] = ACTIONS(5190),
    [anon_sym_LBRACK] = ACTIONS(3837),
    [anon_sym_EQ] = ACTIONS(3854),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3830),
    [anon_sym_volatile] = ACTIONS(3830),
    [anon_sym_restrict] = ACTIONS(3830),
    [anon_sym___restrict__] = ACTIONS(3830),
    [anon_sym__Atomic] = ACTIONS(3830),
    [anon_sym__Noreturn] = ACTIONS(3830),
    [anon_sym_noreturn] = ACTIONS(3830),
    [anon_sym_mutable] = ACTIONS(3830),
    [anon_sym_constinit] = ACTIONS(3830),
    [anon_sym_consteval] = ACTIONS(3830),
    [anon_sym_alignas] = ACTIONS(3830),
    [anon_sym__Alignas] = ACTIONS(3830),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3856),
    [anon_sym_SLASH_EQ] = ACTIONS(3856),
    [anon_sym_PERCENT_EQ] = ACTIONS(3856),
    [anon_sym_PLUS_EQ] = ACTIONS(3856),
    [anon_sym_DASH_EQ] = ACTIONS(3856),
    [anon_sym_LT_LT_EQ] = ACTIONS(3856),
    [anon_sym_GT_GT_EQ] = ACTIONS(3856),
    [anon_sym_AMP_EQ] = ACTIONS(3856),
    [anon_sym_CARET_EQ] = ACTIONS(3856),
    [anon_sym_PIPE_EQ] = ACTIONS(3856),
    [anon_sym_and_eq] = ACTIONS(3856),
    [anon_sym_or_eq] = ACTIONS(3856),
    [anon_sym_xor_eq] = ACTIONS(3856),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3830),
    [anon_sym_decltype] = ACTIONS(3830),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
  },
  [2204] = {
    [sym__declaration_modifiers] = STATE(2218),
    [sym_attribute_specifier] = STATE(2218),
    [sym_attribute_declaration] = STATE(2218),
    [sym_ms_declspec_modifier] = STATE(2218),
    [sym_storage_class_specifier] = STATE(2218),
    [sym_type_qualifier] = STATE(2218),
    [sym_alignas_qualifier] = STATE(2331),
    [sym_decltype_auto] = STATE(2274),
    [sym_qualifiers] = STATE(2218),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2218),
    [sym_identifier] = ACTIONS(5246),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5248),
    [anon_sym_COMMA] = ACTIONS(5248),
    [anon_sym_RPAREN] = ACTIONS(5248),
    [anon_sym_LPAREN2] = ACTIONS(5248),
    [anon_sym_TILDE] = ACTIONS(5248),
    [anon_sym_STAR] = ACTIONS(5248),
    [anon_sym_AMP_AMP] = ACTIONS(5248),
    [anon_sym_AMP] = ACTIONS(5246),
    [anon_sym_COLON] = ACTIONS(5246),
    [anon_sym_SEMI] = ACTIONS(5248),
    [anon_sym___extension__] = ACTIONS(4981),
    [anon_sym_in] = ACTIONS(5250),
    [anon_sym_out] = ACTIONS(5250),
    [anon_sym_inout] = ACTIONS(5250),
    [anon_sym_extern] = ACTIONS(4985),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5248),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4991),
    [anon_sym___declspec] = ACTIONS(4993),
    [anon_sym___based] = ACTIONS(5246),
    [anon_sym___cdecl] = ACTIONS(5246),
    [anon_sym___clrcall] = ACTIONS(5246),
    [anon_sym___stdcall] = ACTIONS(5246),
    [anon_sym___fastcall] = ACTIONS(5246),
    [anon_sym___thiscall] = ACTIONS(5246),
    [anon_sym___vectorcall] = ACTIONS(5246),
    [anon_sym_LBRACK] = ACTIONS(5246),
    [anon_sym_static] = ACTIONS(4985),
    [anon_sym_EQ] = ACTIONS(5248),
    [anon_sym_register] = ACTIONS(4985),
    [anon_sym_inline] = ACTIONS(4985),
    [anon_sym___inline] = ACTIONS(4985),
    [anon_sym___inline__] = ACTIONS(4985),
    [anon_sym___forceinline] = ACTIONS(4985),
    [anon_sym_thread_local] = ACTIONS(4985),
    [anon_sym___thread] = ACTIONS(4985),
    [anon_sym_const] = ACTIONS(4981),
    [anon_sym_constexpr] = ACTIONS(4981),
    [anon_sym_volatile] = ACTIONS(4981),
    [anon_sym_restrict] = ACTIONS(4981),
    [anon_sym___restrict__] = ACTIONS(4981),
    [anon_sym__Atomic] = ACTIONS(4981),
    [anon_sym__Noreturn] = ACTIONS(4981),
    [anon_sym_noreturn] = ACTIONS(4981),
    [anon_sym_mutable] = ACTIONS(4981),
    [anon_sym_constinit] = ACTIONS(4981),
    [anon_sym_consteval] = ACTIONS(4981),
    [anon_sym_alignas] = ACTIONS(4995),
    [anon_sym__Alignas] = ACTIONS(4995),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5220),
    [anon_sym_decltype] = ACTIONS(5222),
    [sym_virtual] = ACTIONS(5250),
    [anon_sym_template] = ACTIONS(5246),
    [anon_sym_GT2] = ACTIONS(5248),
    [anon_sym_operator] = ACTIONS(5246),
    [anon_sym_precise] = ACTIONS(4997),
    [anon_sym_shared] = ACTIONS(4997),
    [anon_sym_groupshared] = ACTIONS(4997),
    [anon_sym_uniform] = ACTIONS(4997),
    [anon_sym_row_major] = ACTIONS(4997),
    [anon_sym_column_major] = ACTIONS(4997),
    [anon_sym_globallycoherent] = ACTIONS(4997),
    [anon_sym_centroid] = ACTIONS(4997),
    [anon_sym_noperspective] = ACTIONS(4997),
    [anon_sym_nointerpolation] = ACTIONS(4997),
    [anon_sym_sample] = ACTIONS(4997),
    [anon_sym_linear] = ACTIONS(4997),
    [anon_sym_snorm] = ACTIONS(4997),
    [anon_sym_unorm] = ACTIONS(4997),
    [anon_sym_point] = ACTIONS(4997),
    [anon_sym_line] = ACTIONS(4997),
    [anon_sym_triangleadj] = ACTIONS(4997),
    [anon_sym_lineadj] = ACTIONS(4997),
    [anon_sym_triangle] = ACTIONS(4997),
  },
  [2205] = {
    [sym_identifier] = ACTIONS(1953),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1955),
    [anon_sym_COMMA] = ACTIONS(1955),
    [anon_sym_RPAREN] = ACTIONS(1955),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_TILDE] = ACTIONS(1955),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_PIPE_PIPE] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym_COLON] = ACTIONS(1953),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym_in] = ACTIONS(1953),
    [anon_sym_out] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1953),
    [anon_sym_extern] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1955),
    [anon_sym___declspec] = ACTIONS(1953),
    [anon_sym___based] = ACTIONS(1953),
    [anon_sym___cdecl] = ACTIONS(1953),
    [anon_sym___clrcall] = ACTIONS(1953),
    [anon_sym___stdcall] = ACTIONS(1953),
    [anon_sym___fastcall] = ACTIONS(1953),
    [anon_sym___thiscall] = ACTIONS(1953),
    [anon_sym___vectorcall] = ACTIONS(1953),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_LBRACK] = ACTIONS(1953),
    [anon_sym_static] = ACTIONS(1953),
    [anon_sym_EQ] = ACTIONS(1955),
    [anon_sym_register] = ACTIONS(1953),
    [anon_sym_inline] = ACTIONS(1953),
    [anon_sym___inline] = ACTIONS(1953),
    [anon_sym___inline__] = ACTIONS(1953),
    [anon_sym___forceinline] = ACTIONS(1953),
    [anon_sym_thread_local] = ACTIONS(1953),
    [anon_sym___thread] = ACTIONS(1953),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [anon_sym_else] = ACTIONS(1953),
    [anon_sym_while] = ACTIONS(1953),
    [anon_sym_or] = ACTIONS(1953),
    [anon_sym_and] = ACTIONS(1953),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
    [sym_virtual] = ACTIONS(1953),
    [anon_sym_template] = ACTIONS(1953),
    [anon_sym_GT2] = ACTIONS(1955),
    [anon_sym_operator] = ACTIONS(1953),
    [anon_sym_try] = ACTIONS(1953),
    [anon_sym_requires] = ACTIONS(1953),
    [anon_sym_precise] = ACTIONS(1953),
    [anon_sym_shared] = ACTIONS(1953),
    [anon_sym_groupshared] = ACTIONS(1953),
    [anon_sym_uniform] = ACTIONS(1953),
    [anon_sym_row_major] = ACTIONS(1953),
    [anon_sym_column_major] = ACTIONS(1953),
    [anon_sym_globallycoherent] = ACTIONS(1953),
    [anon_sym_centroid] = ACTIONS(1953),
    [anon_sym_noperspective] = ACTIONS(1953),
    [anon_sym_nointerpolation] = ACTIONS(1953),
    [anon_sym_sample] = ACTIONS(1953),
    [anon_sym_linear] = ACTIONS(1953),
    [anon_sym_snorm] = ACTIONS(1953),
    [anon_sym_unorm] = ACTIONS(1953),
    [anon_sym_point] = ACTIONS(1953),
    [anon_sym_line] = ACTIONS(1953),
    [anon_sym_triangleadj] = ACTIONS(1953),
    [anon_sym_lineadj] = ACTIONS(1953),
    [anon_sym_triangle] = ACTIONS(1953),
  },
  [2206] = {
    [sym_identifier] = ACTIONS(1953),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_TILDE] = ACTIONS(1955),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_PIPE_PIPE] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym_in] = ACTIONS(1953),
    [anon_sym_out] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1953),
    [anon_sym_extern] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1955),
    [anon_sym___declspec] = ACTIONS(1953),
    [anon_sym___based] = ACTIONS(1953),
    [anon_sym___cdecl] = ACTIONS(1953),
    [anon_sym___clrcall] = ACTIONS(1953),
    [anon_sym___stdcall] = ACTIONS(1953),
    [anon_sym___fastcall] = ACTIONS(1953),
    [anon_sym___thiscall] = ACTIONS(1953),
    [anon_sym___vectorcall] = ACTIONS(1953),
    [anon_sym_signed] = ACTIONS(1953),
    [anon_sym_unsigned] = ACTIONS(1953),
    [anon_sym_long] = ACTIONS(1953),
    [anon_sym_short] = ACTIONS(1953),
    [anon_sym_LBRACK] = ACTIONS(1953),
    [anon_sym_static] = ACTIONS(1953),
    [anon_sym_register] = ACTIONS(1953),
    [anon_sym_inline] = ACTIONS(1953),
    [anon_sym___inline] = ACTIONS(1953),
    [anon_sym___inline__] = ACTIONS(1953),
    [anon_sym___forceinline] = ACTIONS(1953),
    [anon_sym_thread_local] = ACTIONS(1953),
    [anon_sym___thread] = ACTIONS(1953),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [sym_primitive_type] = ACTIONS(1953),
    [anon_sym_enum] = ACTIONS(1953),
    [anon_sym_class] = ACTIONS(1953),
    [anon_sym_struct] = ACTIONS(1953),
    [anon_sym_union] = ACTIONS(1953),
    [anon_sym_or] = ACTIONS(1953),
    [anon_sym_and] = ACTIONS(1953),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [sym_virtual] = ACTIONS(1953),
    [anon_sym_explicit] = ACTIONS(1953),
    [anon_sym_typename] = ACTIONS(1953),
    [anon_sym_template] = ACTIONS(1953),
    [anon_sym_operator] = ACTIONS(1953),
    [anon_sym_friend] = ACTIONS(1953),
    [anon_sym_using] = ACTIONS(1953),
    [anon_sym_concept] = ACTIONS(1953),
    [anon_sym_precise] = ACTIONS(1953),
    [anon_sym_shared] = ACTIONS(1953),
    [anon_sym_groupshared] = ACTIONS(1953),
    [anon_sym_uniform] = ACTIONS(1953),
    [anon_sym_row_major] = ACTIONS(1953),
    [anon_sym_column_major] = ACTIONS(1953),
    [anon_sym_globallycoherent] = ACTIONS(1953),
    [anon_sym_centroid] = ACTIONS(1953),
    [anon_sym_noperspective] = ACTIONS(1953),
    [anon_sym_nointerpolation] = ACTIONS(1953),
    [anon_sym_sample] = ACTIONS(1953),
    [anon_sym_linear] = ACTIONS(1953),
    [anon_sym_snorm] = ACTIONS(1953),
    [anon_sym_unorm] = ACTIONS(1953),
    [anon_sym_point] = ACTIONS(1953),
    [anon_sym_line] = ACTIONS(1953),
    [anon_sym_triangleadj] = ACTIONS(1953),
    [anon_sym_lineadj] = ACTIONS(1953),
    [anon_sym_triangle] = ACTIONS(1953),
  },
  [2207] = {
    [sym_identifier] = ACTIONS(1931),
    [anon_sym_LPAREN2] = ACTIONS(1929),
    [anon_sym_TILDE] = ACTIONS(1929),
    [anon_sym_STAR] = ACTIONS(1929),
    [anon_sym_PIPE_PIPE] = ACTIONS(1929),
    [anon_sym_AMP_AMP] = ACTIONS(1929),
    [anon_sym_AMP] = ACTIONS(1931),
    [anon_sym___extension__] = ACTIONS(1931),
    [anon_sym_in] = ACTIONS(1931),
    [anon_sym_out] = ACTIONS(1931),
    [anon_sym_inout] = ACTIONS(1931),
    [anon_sym_extern] = ACTIONS(1931),
    [anon_sym___attribute__] = ACTIONS(1931),
    [anon_sym_COLON_COLON] = ACTIONS(1929),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1929),
    [anon_sym___declspec] = ACTIONS(1931),
    [anon_sym___based] = ACTIONS(1931),
    [anon_sym___cdecl] = ACTIONS(1931),
    [anon_sym___clrcall] = ACTIONS(1931),
    [anon_sym___stdcall] = ACTIONS(1931),
    [anon_sym___fastcall] = ACTIONS(1931),
    [anon_sym___thiscall] = ACTIONS(1931),
    [anon_sym___vectorcall] = ACTIONS(1931),
    [anon_sym_signed] = ACTIONS(1931),
    [anon_sym_unsigned] = ACTIONS(1931),
    [anon_sym_long] = ACTIONS(1931),
    [anon_sym_short] = ACTIONS(1931),
    [anon_sym_LBRACK] = ACTIONS(1931),
    [anon_sym_static] = ACTIONS(1931),
    [anon_sym_register] = ACTIONS(1931),
    [anon_sym_inline] = ACTIONS(1931),
    [anon_sym___inline] = ACTIONS(1931),
    [anon_sym___inline__] = ACTIONS(1931),
    [anon_sym___forceinline] = ACTIONS(1931),
    [anon_sym_thread_local] = ACTIONS(1931),
    [anon_sym___thread] = ACTIONS(1931),
    [anon_sym_const] = ACTIONS(1931),
    [anon_sym_constexpr] = ACTIONS(1931),
    [anon_sym_volatile] = ACTIONS(1931),
    [anon_sym_restrict] = ACTIONS(1931),
    [anon_sym___restrict__] = ACTIONS(1931),
    [anon_sym__Atomic] = ACTIONS(1931),
    [anon_sym__Noreturn] = ACTIONS(1931),
    [anon_sym_noreturn] = ACTIONS(1931),
    [anon_sym_mutable] = ACTIONS(1931),
    [anon_sym_constinit] = ACTIONS(1931),
    [anon_sym_consteval] = ACTIONS(1931),
    [anon_sym_alignas] = ACTIONS(1931),
    [anon_sym__Alignas] = ACTIONS(1931),
    [sym_primitive_type] = ACTIONS(1931),
    [anon_sym_enum] = ACTIONS(1931),
    [anon_sym_class] = ACTIONS(1931),
    [anon_sym_struct] = ACTIONS(1931),
    [anon_sym_union] = ACTIONS(1931),
    [anon_sym_or] = ACTIONS(1931),
    [anon_sym_and] = ACTIONS(1931),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1931),
    [anon_sym_decltype] = ACTIONS(1931),
    [sym_virtual] = ACTIONS(1931),
    [anon_sym_explicit] = ACTIONS(1931),
    [anon_sym_typename] = ACTIONS(1931),
    [anon_sym_template] = ACTIONS(1931),
    [anon_sym_operator] = ACTIONS(1931),
    [anon_sym_friend] = ACTIONS(1931),
    [anon_sym_using] = ACTIONS(1931),
    [anon_sym_concept] = ACTIONS(1931),
    [anon_sym_precise] = ACTIONS(1931),
    [anon_sym_shared] = ACTIONS(1931),
    [anon_sym_groupshared] = ACTIONS(1931),
    [anon_sym_uniform] = ACTIONS(1931),
    [anon_sym_row_major] = ACTIONS(1931),
    [anon_sym_column_major] = ACTIONS(1931),
    [anon_sym_globallycoherent] = ACTIONS(1931),
    [anon_sym_centroid] = ACTIONS(1931),
    [anon_sym_noperspective] = ACTIONS(1931),
    [anon_sym_nointerpolation] = ACTIONS(1931),
    [anon_sym_sample] = ACTIONS(1931),
    [anon_sym_linear] = ACTIONS(1931),
    [anon_sym_snorm] = ACTIONS(1931),
    [anon_sym_unorm] = ACTIONS(1931),
    [anon_sym_point] = ACTIONS(1931),
    [anon_sym_line] = ACTIONS(1931),
    [anon_sym_triangleadj] = ACTIONS(1931),
    [anon_sym_lineadj] = ACTIONS(1931),
    [anon_sym_triangle] = ACTIONS(1931),
  },
  [2208] = {
    [sym_identifier] = ACTIONS(1899),
    [anon_sym_LPAREN2] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_STAR] = ACTIONS(1901),
    [anon_sym_PIPE_PIPE] = ACTIONS(1901),
    [anon_sym_AMP_AMP] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1899),
    [anon_sym___extension__] = ACTIONS(1899),
    [anon_sym_in] = ACTIONS(1899),
    [anon_sym_out] = ACTIONS(1899),
    [anon_sym_inout] = ACTIONS(1899),
    [anon_sym_extern] = ACTIONS(1899),
    [anon_sym___attribute__] = ACTIONS(1899),
    [anon_sym_COLON_COLON] = ACTIONS(1901),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1901),
    [anon_sym___declspec] = ACTIONS(1899),
    [anon_sym___based] = ACTIONS(1899),
    [anon_sym___cdecl] = ACTIONS(1899),
    [anon_sym___clrcall] = ACTIONS(1899),
    [anon_sym___stdcall] = ACTIONS(1899),
    [anon_sym___fastcall] = ACTIONS(1899),
    [anon_sym___thiscall] = ACTIONS(1899),
    [anon_sym___vectorcall] = ACTIONS(1899),
    [anon_sym_signed] = ACTIONS(1899),
    [anon_sym_unsigned] = ACTIONS(1899),
    [anon_sym_long] = ACTIONS(1899),
    [anon_sym_short] = ACTIONS(1899),
    [anon_sym_LBRACK] = ACTIONS(1899),
    [anon_sym_static] = ACTIONS(1899),
    [anon_sym_register] = ACTIONS(1899),
    [anon_sym_inline] = ACTIONS(1899),
    [anon_sym___inline] = ACTIONS(1899),
    [anon_sym___inline__] = ACTIONS(1899),
    [anon_sym___forceinline] = ACTIONS(1899),
    [anon_sym_thread_local] = ACTIONS(1899),
    [anon_sym___thread] = ACTIONS(1899),
    [anon_sym_const] = ACTIONS(1899),
    [anon_sym_constexpr] = ACTIONS(1899),
    [anon_sym_volatile] = ACTIONS(1899),
    [anon_sym_restrict] = ACTIONS(1899),
    [anon_sym___restrict__] = ACTIONS(1899),
    [anon_sym__Atomic] = ACTIONS(1899),
    [anon_sym__Noreturn] = ACTIONS(1899),
    [anon_sym_noreturn] = ACTIONS(1899),
    [anon_sym_mutable] = ACTIONS(1899),
    [anon_sym_constinit] = ACTIONS(1899),
    [anon_sym_consteval] = ACTIONS(1899),
    [anon_sym_alignas] = ACTIONS(1899),
    [anon_sym__Alignas] = ACTIONS(1899),
    [sym_primitive_type] = ACTIONS(1899),
    [anon_sym_enum] = ACTIONS(1899),
    [anon_sym_class] = ACTIONS(1899),
    [anon_sym_struct] = ACTIONS(1899),
    [anon_sym_union] = ACTIONS(1899),
    [anon_sym_or] = ACTIONS(1899),
    [anon_sym_and] = ACTIONS(1899),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1899),
    [anon_sym_decltype] = ACTIONS(1899),
    [sym_virtual] = ACTIONS(1899),
    [anon_sym_explicit] = ACTIONS(1899),
    [anon_sym_typename] = ACTIONS(1899),
    [anon_sym_template] = ACTIONS(1899),
    [anon_sym_operator] = ACTIONS(1899),
    [anon_sym_friend] = ACTIONS(1899),
    [anon_sym_using] = ACTIONS(1899),
    [anon_sym_concept] = ACTIONS(1899),
    [anon_sym_precise] = ACTIONS(1899),
    [anon_sym_shared] = ACTIONS(1899),
    [anon_sym_groupshared] = ACTIONS(1899),
    [anon_sym_uniform] = ACTIONS(1899),
    [anon_sym_row_major] = ACTIONS(1899),
    [anon_sym_column_major] = ACTIONS(1899),
    [anon_sym_globallycoherent] = ACTIONS(1899),
    [anon_sym_centroid] = ACTIONS(1899),
    [anon_sym_noperspective] = ACTIONS(1899),
    [anon_sym_nointerpolation] = ACTIONS(1899),
    [anon_sym_sample] = ACTIONS(1899),
    [anon_sym_linear] = ACTIONS(1899),
    [anon_sym_snorm] = ACTIONS(1899),
    [anon_sym_unorm] = ACTIONS(1899),
    [anon_sym_point] = ACTIONS(1899),
    [anon_sym_line] = ACTIONS(1899),
    [anon_sym_triangleadj] = ACTIONS(1899),
    [anon_sym_lineadj] = ACTIONS(1899),
    [anon_sym_triangle] = ACTIONS(1899),
  },
  [2209] = {
    [sym_identifier] = ACTIONS(1949),
    [anon_sym_LPAREN2] = ACTIONS(1951),
    [anon_sym_TILDE] = ACTIONS(1951),
    [anon_sym_STAR] = ACTIONS(1951),
    [anon_sym_PIPE_PIPE] = ACTIONS(1951),
    [anon_sym_AMP_AMP] = ACTIONS(1951),
    [anon_sym_AMP] = ACTIONS(1949),
    [anon_sym___extension__] = ACTIONS(1949),
    [anon_sym_in] = ACTIONS(1949),
    [anon_sym_out] = ACTIONS(1949),
    [anon_sym_inout] = ACTIONS(1949),
    [anon_sym_extern] = ACTIONS(1949),
    [anon_sym___attribute__] = ACTIONS(1949),
    [anon_sym_COLON_COLON] = ACTIONS(1951),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1951),
    [anon_sym___declspec] = ACTIONS(1949),
    [anon_sym___based] = ACTIONS(1949),
    [anon_sym___cdecl] = ACTIONS(1949),
    [anon_sym___clrcall] = ACTIONS(1949),
    [anon_sym___stdcall] = ACTIONS(1949),
    [anon_sym___fastcall] = ACTIONS(1949),
    [anon_sym___thiscall] = ACTIONS(1949),
    [anon_sym___vectorcall] = ACTIONS(1949),
    [anon_sym_signed] = ACTIONS(1949),
    [anon_sym_unsigned] = ACTIONS(1949),
    [anon_sym_long] = ACTIONS(1949),
    [anon_sym_short] = ACTIONS(1949),
    [anon_sym_LBRACK] = ACTIONS(1949),
    [anon_sym_static] = ACTIONS(1949),
    [anon_sym_register] = ACTIONS(1949),
    [anon_sym_inline] = ACTIONS(1949),
    [anon_sym___inline] = ACTIONS(1949),
    [anon_sym___inline__] = ACTIONS(1949),
    [anon_sym___forceinline] = ACTIONS(1949),
    [anon_sym_thread_local] = ACTIONS(1949),
    [anon_sym___thread] = ACTIONS(1949),
    [anon_sym_const] = ACTIONS(1949),
    [anon_sym_constexpr] = ACTIONS(1949),
    [anon_sym_volatile] = ACTIONS(1949),
    [anon_sym_restrict] = ACTIONS(1949),
    [anon_sym___restrict__] = ACTIONS(1949),
    [anon_sym__Atomic] = ACTIONS(1949),
    [anon_sym__Noreturn] = ACTIONS(1949),
    [anon_sym_noreturn] = ACTIONS(1949),
    [anon_sym_mutable] = ACTIONS(1949),
    [anon_sym_constinit] = ACTIONS(1949),
    [anon_sym_consteval] = ACTIONS(1949),
    [anon_sym_alignas] = ACTIONS(1949),
    [anon_sym__Alignas] = ACTIONS(1949),
    [sym_primitive_type] = ACTIONS(1949),
    [anon_sym_enum] = ACTIONS(1949),
    [anon_sym_class] = ACTIONS(1949),
    [anon_sym_struct] = ACTIONS(1949),
    [anon_sym_union] = ACTIONS(1949),
    [anon_sym_or] = ACTIONS(1949),
    [anon_sym_and] = ACTIONS(1949),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1949),
    [anon_sym_decltype] = ACTIONS(1949),
    [sym_virtual] = ACTIONS(1949),
    [anon_sym_explicit] = ACTIONS(1949),
    [anon_sym_typename] = ACTIONS(1949),
    [anon_sym_template] = ACTIONS(1949),
    [anon_sym_operator] = ACTIONS(1949),
    [anon_sym_friend] = ACTIONS(1949),
    [anon_sym_using] = ACTIONS(1949),
    [anon_sym_concept] = ACTIONS(1949),
    [anon_sym_precise] = ACTIONS(1949),
    [anon_sym_shared] = ACTIONS(1949),
    [anon_sym_groupshared] = ACTIONS(1949),
    [anon_sym_uniform] = ACTIONS(1949),
    [anon_sym_row_major] = ACTIONS(1949),
    [anon_sym_column_major] = ACTIONS(1949),
    [anon_sym_globallycoherent] = ACTIONS(1949),
    [anon_sym_centroid] = ACTIONS(1949),
    [anon_sym_noperspective] = ACTIONS(1949),
    [anon_sym_nointerpolation] = ACTIONS(1949),
    [anon_sym_sample] = ACTIONS(1949),
    [anon_sym_linear] = ACTIONS(1949),
    [anon_sym_snorm] = ACTIONS(1949),
    [anon_sym_unorm] = ACTIONS(1949),
    [anon_sym_point] = ACTIONS(1949),
    [anon_sym_line] = ACTIONS(1949),
    [anon_sym_triangleadj] = ACTIONS(1949),
    [anon_sym_lineadj] = ACTIONS(1949),
    [anon_sym_triangle] = ACTIONS(1949),
  },
  [2210] = {
    [sym_identifier] = ACTIONS(1891),
    [anon_sym_LPAREN2] = ACTIONS(1893),
    [anon_sym_TILDE] = ACTIONS(1893),
    [anon_sym_STAR] = ACTIONS(1893),
    [anon_sym_PIPE_PIPE] = ACTIONS(1893),
    [anon_sym_AMP_AMP] = ACTIONS(1893),
    [anon_sym_AMP] = ACTIONS(1891),
    [anon_sym___extension__] = ACTIONS(1891),
    [anon_sym_in] = ACTIONS(1891),
    [anon_sym_out] = ACTIONS(1891),
    [anon_sym_inout] = ACTIONS(1891),
    [anon_sym_extern] = ACTIONS(1891),
    [anon_sym___attribute__] = ACTIONS(1891),
    [anon_sym_COLON_COLON] = ACTIONS(1893),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1893),
    [anon_sym___declspec] = ACTIONS(1891),
    [anon_sym___based] = ACTIONS(1891),
    [anon_sym___cdecl] = ACTIONS(1891),
    [anon_sym___clrcall] = ACTIONS(1891),
    [anon_sym___stdcall] = ACTIONS(1891),
    [anon_sym___fastcall] = ACTIONS(1891),
    [anon_sym___thiscall] = ACTIONS(1891),
    [anon_sym___vectorcall] = ACTIONS(1891),
    [anon_sym_signed] = ACTIONS(1891),
    [anon_sym_unsigned] = ACTIONS(1891),
    [anon_sym_long] = ACTIONS(1891),
    [anon_sym_short] = ACTIONS(1891),
    [anon_sym_LBRACK] = ACTIONS(1891),
    [anon_sym_static] = ACTIONS(1891),
    [anon_sym_register] = ACTIONS(1891),
    [anon_sym_inline] = ACTIONS(1891),
    [anon_sym___inline] = ACTIONS(1891),
    [anon_sym___inline__] = ACTIONS(1891),
    [anon_sym___forceinline] = ACTIONS(1891),
    [anon_sym_thread_local] = ACTIONS(1891),
    [anon_sym___thread] = ACTIONS(1891),
    [anon_sym_const] = ACTIONS(1891),
    [anon_sym_constexpr] = ACTIONS(1891),
    [anon_sym_volatile] = ACTIONS(1891),
    [anon_sym_restrict] = ACTIONS(1891),
    [anon_sym___restrict__] = ACTIONS(1891),
    [anon_sym__Atomic] = ACTIONS(1891),
    [anon_sym__Noreturn] = ACTIONS(1891),
    [anon_sym_noreturn] = ACTIONS(1891),
    [anon_sym_mutable] = ACTIONS(1891),
    [anon_sym_constinit] = ACTIONS(1891),
    [anon_sym_consteval] = ACTIONS(1891),
    [anon_sym_alignas] = ACTIONS(1891),
    [anon_sym__Alignas] = ACTIONS(1891),
    [sym_primitive_type] = ACTIONS(1891),
    [anon_sym_enum] = ACTIONS(1891),
    [anon_sym_class] = ACTIONS(1891),
    [anon_sym_struct] = ACTIONS(1891),
    [anon_sym_union] = ACTIONS(1891),
    [anon_sym_or] = ACTIONS(1891),
    [anon_sym_and] = ACTIONS(1891),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1891),
    [anon_sym_decltype] = ACTIONS(1891),
    [sym_virtual] = ACTIONS(1891),
    [anon_sym_explicit] = ACTIONS(1891),
    [anon_sym_typename] = ACTIONS(1891),
    [anon_sym_template] = ACTIONS(1891),
    [anon_sym_operator] = ACTIONS(1891),
    [anon_sym_friend] = ACTIONS(1891),
    [anon_sym_using] = ACTIONS(1891),
    [anon_sym_concept] = ACTIONS(1891),
    [anon_sym_precise] = ACTIONS(1891),
    [anon_sym_shared] = ACTIONS(1891),
    [anon_sym_groupshared] = ACTIONS(1891),
    [anon_sym_uniform] = ACTIONS(1891),
    [anon_sym_row_major] = ACTIONS(1891),
    [anon_sym_column_major] = ACTIONS(1891),
    [anon_sym_globallycoherent] = ACTIONS(1891),
    [anon_sym_centroid] = ACTIONS(1891),
    [anon_sym_noperspective] = ACTIONS(1891),
    [anon_sym_nointerpolation] = ACTIONS(1891),
    [anon_sym_sample] = ACTIONS(1891),
    [anon_sym_linear] = ACTIONS(1891),
    [anon_sym_snorm] = ACTIONS(1891),
    [anon_sym_unorm] = ACTIONS(1891),
    [anon_sym_point] = ACTIONS(1891),
    [anon_sym_line] = ACTIONS(1891),
    [anon_sym_triangleadj] = ACTIONS(1891),
    [anon_sym_lineadj] = ACTIONS(1891),
    [anon_sym_triangle] = ACTIONS(1891),
  },
  [2211] = {
    [sym_identifier] = ACTIONS(1895),
    [anon_sym_LPAREN2] = ACTIONS(1897),
    [anon_sym_TILDE] = ACTIONS(1897),
    [anon_sym_STAR] = ACTIONS(1897),
    [anon_sym_PIPE_PIPE] = ACTIONS(1897),
    [anon_sym_AMP_AMP] = ACTIONS(1897),
    [anon_sym_AMP] = ACTIONS(1895),
    [anon_sym___extension__] = ACTIONS(1895),
    [anon_sym_in] = ACTIONS(1895),
    [anon_sym_out] = ACTIONS(1895),
    [anon_sym_inout] = ACTIONS(1895),
    [anon_sym_extern] = ACTIONS(1895),
    [anon_sym___attribute__] = ACTIONS(1895),
    [anon_sym_COLON_COLON] = ACTIONS(1897),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1897),
    [anon_sym___declspec] = ACTIONS(1895),
    [anon_sym___based] = ACTIONS(1895),
    [anon_sym___cdecl] = ACTIONS(1895),
    [anon_sym___clrcall] = ACTIONS(1895),
    [anon_sym___stdcall] = ACTIONS(1895),
    [anon_sym___fastcall] = ACTIONS(1895),
    [anon_sym___thiscall] = ACTIONS(1895),
    [anon_sym___vectorcall] = ACTIONS(1895),
    [anon_sym_signed] = ACTIONS(1895),
    [anon_sym_unsigned] = ACTIONS(1895),
    [anon_sym_long] = ACTIONS(1895),
    [anon_sym_short] = ACTIONS(1895),
    [anon_sym_LBRACK] = ACTIONS(1895),
    [anon_sym_static] = ACTIONS(1895),
    [anon_sym_register] = ACTIONS(1895),
    [anon_sym_inline] = ACTIONS(1895),
    [anon_sym___inline] = ACTIONS(1895),
    [anon_sym___inline__] = ACTIONS(1895),
    [anon_sym___forceinline] = ACTIONS(1895),
    [anon_sym_thread_local] = ACTIONS(1895),
    [anon_sym___thread] = ACTIONS(1895),
    [anon_sym_const] = ACTIONS(1895),
    [anon_sym_constexpr] = ACTIONS(1895),
    [anon_sym_volatile] = ACTIONS(1895),
    [anon_sym_restrict] = ACTIONS(1895),
    [anon_sym___restrict__] = ACTIONS(1895),
    [anon_sym__Atomic] = ACTIONS(1895),
    [anon_sym__Noreturn] = ACTIONS(1895),
    [anon_sym_noreturn] = ACTIONS(1895),
    [anon_sym_mutable] = ACTIONS(1895),
    [anon_sym_constinit] = ACTIONS(1895),
    [anon_sym_consteval] = ACTIONS(1895),
    [anon_sym_alignas] = ACTIONS(1895),
    [anon_sym__Alignas] = ACTIONS(1895),
    [sym_primitive_type] = ACTIONS(1895),
    [anon_sym_enum] = ACTIONS(1895),
    [anon_sym_class] = ACTIONS(1895),
    [anon_sym_struct] = ACTIONS(1895),
    [anon_sym_union] = ACTIONS(1895),
    [anon_sym_or] = ACTIONS(1895),
    [anon_sym_and] = ACTIONS(1895),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1895),
    [anon_sym_decltype] = ACTIONS(1895),
    [sym_virtual] = ACTIONS(1895),
    [anon_sym_explicit] = ACTIONS(1895),
    [anon_sym_typename] = ACTIONS(1895),
    [anon_sym_template] = ACTIONS(1895),
    [anon_sym_operator] = ACTIONS(1895),
    [anon_sym_friend] = ACTIONS(1895),
    [anon_sym_using] = ACTIONS(1895),
    [anon_sym_concept] = ACTIONS(1895),
    [anon_sym_precise] = ACTIONS(1895),
    [anon_sym_shared] = ACTIONS(1895),
    [anon_sym_groupshared] = ACTIONS(1895),
    [anon_sym_uniform] = ACTIONS(1895),
    [anon_sym_row_major] = ACTIONS(1895),
    [anon_sym_column_major] = ACTIONS(1895),
    [anon_sym_globallycoherent] = ACTIONS(1895),
    [anon_sym_centroid] = ACTIONS(1895),
    [anon_sym_noperspective] = ACTIONS(1895),
    [anon_sym_nointerpolation] = ACTIONS(1895),
    [anon_sym_sample] = ACTIONS(1895),
    [anon_sym_linear] = ACTIONS(1895),
    [anon_sym_snorm] = ACTIONS(1895),
    [anon_sym_unorm] = ACTIONS(1895),
    [anon_sym_point] = ACTIONS(1895),
    [anon_sym_line] = ACTIONS(1895),
    [anon_sym_triangleadj] = ACTIONS(1895),
    [anon_sym_lineadj] = ACTIONS(1895),
    [anon_sym_triangle] = ACTIONS(1895),
  },
  [2212] = {
    [sym_identifier] = ACTIONS(1959),
    [anon_sym_LPAREN2] = ACTIONS(1961),
    [anon_sym_TILDE] = ACTIONS(1961),
    [anon_sym_STAR] = ACTIONS(1961),
    [anon_sym_PIPE_PIPE] = ACTIONS(1961),
    [anon_sym_AMP_AMP] = ACTIONS(1961),
    [anon_sym_AMP] = ACTIONS(1959),
    [anon_sym___extension__] = ACTIONS(1959),
    [anon_sym_in] = ACTIONS(1959),
    [anon_sym_out] = ACTIONS(1959),
    [anon_sym_inout] = ACTIONS(1959),
    [anon_sym_extern] = ACTIONS(1959),
    [anon_sym___attribute__] = ACTIONS(1959),
    [anon_sym_COLON_COLON] = ACTIONS(1961),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1961),
    [anon_sym___declspec] = ACTIONS(1959),
    [anon_sym___based] = ACTIONS(1959),
    [anon_sym___cdecl] = ACTIONS(1959),
    [anon_sym___clrcall] = ACTIONS(1959),
    [anon_sym___stdcall] = ACTIONS(1959),
    [anon_sym___fastcall] = ACTIONS(1959),
    [anon_sym___thiscall] = ACTIONS(1959),
    [anon_sym___vectorcall] = ACTIONS(1959),
    [anon_sym_signed] = ACTIONS(1959),
    [anon_sym_unsigned] = ACTIONS(1959),
    [anon_sym_long] = ACTIONS(1959),
    [anon_sym_short] = ACTIONS(1959),
    [anon_sym_LBRACK] = ACTIONS(1959),
    [anon_sym_static] = ACTIONS(1959),
    [anon_sym_register] = ACTIONS(1959),
    [anon_sym_inline] = ACTIONS(1959),
    [anon_sym___inline] = ACTIONS(1959),
    [anon_sym___inline__] = ACTIONS(1959),
    [anon_sym___forceinline] = ACTIONS(1959),
    [anon_sym_thread_local] = ACTIONS(1959),
    [anon_sym___thread] = ACTIONS(1959),
    [anon_sym_const] = ACTIONS(1959),
    [anon_sym_constexpr] = ACTIONS(1959),
    [anon_sym_volatile] = ACTIONS(1959),
    [anon_sym_restrict] = ACTIONS(1959),
    [anon_sym___restrict__] = ACTIONS(1959),
    [anon_sym__Atomic] = ACTIONS(1959),
    [anon_sym__Noreturn] = ACTIONS(1959),
    [anon_sym_noreturn] = ACTIONS(1959),
    [anon_sym_mutable] = ACTIONS(1959),
    [anon_sym_constinit] = ACTIONS(1959),
    [anon_sym_consteval] = ACTIONS(1959),
    [anon_sym_alignas] = ACTIONS(1959),
    [anon_sym__Alignas] = ACTIONS(1959),
    [sym_primitive_type] = ACTIONS(1959),
    [anon_sym_enum] = ACTIONS(1959),
    [anon_sym_class] = ACTIONS(1959),
    [anon_sym_struct] = ACTIONS(1959),
    [anon_sym_union] = ACTIONS(1959),
    [anon_sym_or] = ACTIONS(1959),
    [anon_sym_and] = ACTIONS(1959),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1959),
    [anon_sym_decltype] = ACTIONS(1959),
    [sym_virtual] = ACTIONS(1959),
    [anon_sym_explicit] = ACTIONS(1959),
    [anon_sym_typename] = ACTIONS(1959),
    [anon_sym_template] = ACTIONS(1959),
    [anon_sym_operator] = ACTIONS(1959),
    [anon_sym_friend] = ACTIONS(1959),
    [anon_sym_using] = ACTIONS(1959),
    [anon_sym_concept] = ACTIONS(1959),
    [anon_sym_precise] = ACTIONS(1959),
    [anon_sym_shared] = ACTIONS(1959),
    [anon_sym_groupshared] = ACTIONS(1959),
    [anon_sym_uniform] = ACTIONS(1959),
    [anon_sym_row_major] = ACTIONS(1959),
    [anon_sym_column_major] = ACTIONS(1959),
    [anon_sym_globallycoherent] = ACTIONS(1959),
    [anon_sym_centroid] = ACTIONS(1959),
    [anon_sym_noperspective] = ACTIONS(1959),
    [anon_sym_nointerpolation] = ACTIONS(1959),
    [anon_sym_sample] = ACTIONS(1959),
    [anon_sym_linear] = ACTIONS(1959),
    [anon_sym_snorm] = ACTIONS(1959),
    [anon_sym_unorm] = ACTIONS(1959),
    [anon_sym_point] = ACTIONS(1959),
    [anon_sym_line] = ACTIONS(1959),
    [anon_sym_triangleadj] = ACTIONS(1959),
    [anon_sym_lineadj] = ACTIONS(1959),
    [anon_sym_triangle] = ACTIONS(1959),
  },
  [2213] = {
    [sym_identifier] = ACTIONS(5252),
    [anon_sym_LPAREN2] = ACTIONS(5254),
    [anon_sym_TILDE] = ACTIONS(5254),
    [anon_sym_STAR] = ACTIONS(5254),
    [anon_sym_PIPE_PIPE] = ACTIONS(5254),
    [anon_sym_AMP_AMP] = ACTIONS(5237),
    [anon_sym_AMP] = ACTIONS(5252),
    [anon_sym___extension__] = ACTIONS(5252),
    [anon_sym_in] = ACTIONS(5252),
    [anon_sym_out] = ACTIONS(5252),
    [anon_sym_inout] = ACTIONS(5252),
    [anon_sym_extern] = ACTIONS(5252),
    [anon_sym___attribute__] = ACTIONS(5252),
    [anon_sym_COLON_COLON] = ACTIONS(5254),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5254),
    [anon_sym___declspec] = ACTIONS(5252),
    [anon_sym___based] = ACTIONS(5252),
    [anon_sym___cdecl] = ACTIONS(5252),
    [anon_sym___clrcall] = ACTIONS(5252),
    [anon_sym___stdcall] = ACTIONS(5252),
    [anon_sym___fastcall] = ACTIONS(5252),
    [anon_sym___thiscall] = ACTIONS(5252),
    [anon_sym___vectorcall] = ACTIONS(5252),
    [anon_sym_signed] = ACTIONS(5252),
    [anon_sym_unsigned] = ACTIONS(5252),
    [anon_sym_long] = ACTIONS(5252),
    [anon_sym_short] = ACTIONS(5252),
    [anon_sym_LBRACK] = ACTIONS(5252),
    [anon_sym_static] = ACTIONS(5252),
    [anon_sym_register] = ACTIONS(5252),
    [anon_sym_inline] = ACTIONS(5252),
    [anon_sym___inline] = ACTIONS(5252),
    [anon_sym___inline__] = ACTIONS(5252),
    [anon_sym___forceinline] = ACTIONS(5252),
    [anon_sym_thread_local] = ACTIONS(5252),
    [anon_sym___thread] = ACTIONS(5252),
    [anon_sym_const] = ACTIONS(5252),
    [anon_sym_constexpr] = ACTIONS(5252),
    [anon_sym_volatile] = ACTIONS(5252),
    [anon_sym_restrict] = ACTIONS(5252),
    [anon_sym___restrict__] = ACTIONS(5252),
    [anon_sym__Atomic] = ACTIONS(5252),
    [anon_sym__Noreturn] = ACTIONS(5252),
    [anon_sym_noreturn] = ACTIONS(5252),
    [anon_sym_mutable] = ACTIONS(5252),
    [anon_sym_constinit] = ACTIONS(5252),
    [anon_sym_consteval] = ACTIONS(5252),
    [anon_sym_alignas] = ACTIONS(5252),
    [anon_sym__Alignas] = ACTIONS(5252),
    [sym_primitive_type] = ACTIONS(5252),
    [anon_sym_enum] = ACTIONS(5252),
    [anon_sym_class] = ACTIONS(5252),
    [anon_sym_struct] = ACTIONS(5252),
    [anon_sym_union] = ACTIONS(5252),
    [anon_sym_or] = ACTIONS(5252),
    [anon_sym_and] = ACTIONS(5241),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5252),
    [anon_sym_decltype] = ACTIONS(5252),
    [sym_virtual] = ACTIONS(5252),
    [anon_sym_explicit] = ACTIONS(5252),
    [anon_sym_typename] = ACTIONS(5252),
    [anon_sym_template] = ACTIONS(5252),
    [anon_sym_operator] = ACTIONS(5252),
    [anon_sym_friend] = ACTIONS(5252),
    [anon_sym_using] = ACTIONS(5252),
    [anon_sym_concept] = ACTIONS(5252),
    [anon_sym_precise] = ACTIONS(5252),
    [anon_sym_shared] = ACTIONS(5252),
    [anon_sym_groupshared] = ACTIONS(5252),
    [anon_sym_uniform] = ACTIONS(5252),
    [anon_sym_row_major] = ACTIONS(5252),
    [anon_sym_column_major] = ACTIONS(5252),
    [anon_sym_globallycoherent] = ACTIONS(5252),
    [anon_sym_centroid] = ACTIONS(5252),
    [anon_sym_noperspective] = ACTIONS(5252),
    [anon_sym_nointerpolation] = ACTIONS(5252),
    [anon_sym_sample] = ACTIONS(5252),
    [anon_sym_linear] = ACTIONS(5252),
    [anon_sym_snorm] = ACTIONS(5252),
    [anon_sym_unorm] = ACTIONS(5252),
    [anon_sym_point] = ACTIONS(5252),
    [anon_sym_line] = ACTIONS(5252),
    [anon_sym_triangleadj] = ACTIONS(5252),
    [anon_sym_lineadj] = ACTIONS(5252),
    [anon_sym_triangle] = ACTIONS(5252),
  },
  [2214] = {
    [sym_identifier] = ACTIONS(1947),
    [anon_sym_LPAREN2] = ACTIONS(1945),
    [anon_sym_TILDE] = ACTIONS(1945),
    [anon_sym_STAR] = ACTIONS(1945),
    [anon_sym_PIPE_PIPE] = ACTIONS(1945),
    [anon_sym_AMP_AMP] = ACTIONS(1945),
    [anon_sym_AMP] = ACTIONS(1947),
    [anon_sym___extension__] = ACTIONS(1947),
    [anon_sym_in] = ACTIONS(1947),
    [anon_sym_out] = ACTIONS(1947),
    [anon_sym_inout] = ACTIONS(1947),
    [anon_sym_extern] = ACTIONS(1947),
    [anon_sym___attribute__] = ACTIONS(1947),
    [anon_sym_COLON_COLON] = ACTIONS(1945),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1945),
    [anon_sym___declspec] = ACTIONS(1947),
    [anon_sym___based] = ACTIONS(1947),
    [anon_sym___cdecl] = ACTIONS(1947),
    [anon_sym___clrcall] = ACTIONS(1947),
    [anon_sym___stdcall] = ACTIONS(1947),
    [anon_sym___fastcall] = ACTIONS(1947),
    [anon_sym___thiscall] = ACTIONS(1947),
    [anon_sym___vectorcall] = ACTIONS(1947),
    [anon_sym_signed] = ACTIONS(1947),
    [anon_sym_unsigned] = ACTIONS(1947),
    [anon_sym_long] = ACTIONS(1947),
    [anon_sym_short] = ACTIONS(1947),
    [anon_sym_LBRACK] = ACTIONS(1947),
    [anon_sym_static] = ACTIONS(1947),
    [anon_sym_register] = ACTIONS(1947),
    [anon_sym_inline] = ACTIONS(1947),
    [anon_sym___inline] = ACTIONS(1947),
    [anon_sym___inline__] = ACTIONS(1947),
    [anon_sym___forceinline] = ACTIONS(1947),
    [anon_sym_thread_local] = ACTIONS(1947),
    [anon_sym___thread] = ACTIONS(1947),
    [anon_sym_const] = ACTIONS(1947),
    [anon_sym_constexpr] = ACTIONS(1947),
    [anon_sym_volatile] = ACTIONS(1947),
    [anon_sym_restrict] = ACTIONS(1947),
    [anon_sym___restrict__] = ACTIONS(1947),
    [anon_sym__Atomic] = ACTIONS(1947),
    [anon_sym__Noreturn] = ACTIONS(1947),
    [anon_sym_noreturn] = ACTIONS(1947),
    [anon_sym_mutable] = ACTIONS(1947),
    [anon_sym_constinit] = ACTIONS(1947),
    [anon_sym_consteval] = ACTIONS(1947),
    [anon_sym_alignas] = ACTIONS(1947),
    [anon_sym__Alignas] = ACTIONS(1947),
    [sym_primitive_type] = ACTIONS(1947),
    [anon_sym_enum] = ACTIONS(1947),
    [anon_sym_class] = ACTIONS(1947),
    [anon_sym_struct] = ACTIONS(1947),
    [anon_sym_union] = ACTIONS(1947),
    [anon_sym_or] = ACTIONS(1947),
    [anon_sym_and] = ACTIONS(1947),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1947),
    [anon_sym_decltype] = ACTIONS(1947),
    [sym_virtual] = ACTIONS(1947),
    [anon_sym_explicit] = ACTIONS(1947),
    [anon_sym_typename] = ACTIONS(1947),
    [anon_sym_template] = ACTIONS(1947),
    [anon_sym_operator] = ACTIONS(1947),
    [anon_sym_friend] = ACTIONS(1947),
    [anon_sym_using] = ACTIONS(1947),
    [anon_sym_concept] = ACTIONS(1947),
    [anon_sym_precise] = ACTIONS(1947),
    [anon_sym_shared] = ACTIONS(1947),
    [anon_sym_groupshared] = ACTIONS(1947),
    [anon_sym_uniform] = ACTIONS(1947),
    [anon_sym_row_major] = ACTIONS(1947),
    [anon_sym_column_major] = ACTIONS(1947),
    [anon_sym_globallycoherent] = ACTIONS(1947),
    [anon_sym_centroid] = ACTIONS(1947),
    [anon_sym_noperspective] = ACTIONS(1947),
    [anon_sym_nointerpolation] = ACTIONS(1947),
    [anon_sym_sample] = ACTIONS(1947),
    [anon_sym_linear] = ACTIONS(1947),
    [anon_sym_snorm] = ACTIONS(1947),
    [anon_sym_unorm] = ACTIONS(1947),
    [anon_sym_point] = ACTIONS(1947),
    [anon_sym_line] = ACTIONS(1947),
    [anon_sym_triangleadj] = ACTIONS(1947),
    [anon_sym_lineadj] = ACTIONS(1947),
    [anon_sym_triangle] = ACTIONS(1947),
  },
  [2215] = {
    [sym_identifier] = ACTIONS(1953),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_TILDE] = ACTIONS(1955),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_PIPE_PIPE] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym_in] = ACTIONS(1953),
    [anon_sym_out] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1953),
    [anon_sym_extern] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1955),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1955),
    [anon_sym___declspec] = ACTIONS(1953),
    [anon_sym___based] = ACTIONS(1953),
    [anon_sym___cdecl] = ACTIONS(1953),
    [anon_sym___clrcall] = ACTIONS(1953),
    [anon_sym___stdcall] = ACTIONS(1953),
    [anon_sym___fastcall] = ACTIONS(1953),
    [anon_sym___thiscall] = ACTIONS(1953),
    [anon_sym___vectorcall] = ACTIONS(1953),
    [anon_sym_signed] = ACTIONS(1953),
    [anon_sym_unsigned] = ACTIONS(1953),
    [anon_sym_long] = ACTIONS(1953),
    [anon_sym_short] = ACTIONS(1953),
    [anon_sym_LBRACK] = ACTIONS(1953),
    [anon_sym_static] = ACTIONS(1953),
    [anon_sym_register] = ACTIONS(1953),
    [anon_sym_inline] = ACTIONS(1953),
    [anon_sym___inline] = ACTIONS(1953),
    [anon_sym___inline__] = ACTIONS(1953),
    [anon_sym___forceinline] = ACTIONS(1953),
    [anon_sym_thread_local] = ACTIONS(1953),
    [anon_sym___thread] = ACTIONS(1953),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [sym_primitive_type] = ACTIONS(1953),
    [anon_sym_enum] = ACTIONS(1953),
    [anon_sym_class] = ACTIONS(1953),
    [anon_sym_struct] = ACTIONS(1953),
    [anon_sym_union] = ACTIONS(1953),
    [anon_sym_or] = ACTIONS(1953),
    [anon_sym_and] = ACTIONS(1953),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [sym_virtual] = ACTIONS(1953),
    [anon_sym_explicit] = ACTIONS(1953),
    [anon_sym_typename] = ACTIONS(1953),
    [anon_sym_template] = ACTIONS(1953),
    [anon_sym_operator] = ACTIONS(1953),
    [anon_sym_friend] = ACTIONS(1953),
    [anon_sym_using] = ACTIONS(1953),
    [anon_sym_concept] = ACTIONS(1953),
    [anon_sym_precise] = ACTIONS(1953),
    [anon_sym_shared] = ACTIONS(1953),
    [anon_sym_groupshared] = ACTIONS(1953),
    [anon_sym_uniform] = ACTIONS(1953),
    [anon_sym_row_major] = ACTIONS(1953),
    [anon_sym_column_major] = ACTIONS(1953),
    [anon_sym_globallycoherent] = ACTIONS(1953),
    [anon_sym_centroid] = ACTIONS(1953),
    [anon_sym_noperspective] = ACTIONS(1953),
    [anon_sym_nointerpolation] = ACTIONS(1953),
    [anon_sym_sample] = ACTIONS(1953),
    [anon_sym_linear] = ACTIONS(1953),
    [anon_sym_snorm] = ACTIONS(1953),
    [anon_sym_unorm] = ACTIONS(1953),
    [anon_sym_point] = ACTIONS(1953),
    [anon_sym_line] = ACTIONS(1953),
    [anon_sym_triangleadj] = ACTIONS(1953),
    [anon_sym_lineadj] = ACTIONS(1953),
    [anon_sym_triangle] = ACTIONS(1953),
  },
  [2216] = {
    [sym_identifier] = ACTIONS(3631),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3633),
    [anon_sym_COMMA] = ACTIONS(3633),
    [anon_sym_RPAREN] = ACTIONS(3633),
    [anon_sym_LPAREN2] = ACTIONS(3633),
    [anon_sym_TILDE] = ACTIONS(3633),
    [anon_sym_STAR] = ACTIONS(3633),
    [anon_sym_AMP_AMP] = ACTIONS(3633),
    [anon_sym_AMP] = ACTIONS(3631),
    [anon_sym_COLON] = ACTIONS(3631),
    [anon_sym_SEMI] = ACTIONS(3633),
    [anon_sym___extension__] = ACTIONS(3631),
    [anon_sym_in] = ACTIONS(3631),
    [anon_sym_out] = ACTIONS(3631),
    [anon_sym_inout] = ACTIONS(3631),
    [anon_sym_extern] = ACTIONS(3631),
    [anon_sym___attribute__] = ACTIONS(3631),
    [anon_sym_COLON_COLON] = ACTIONS(3633),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3633),
    [anon_sym___declspec] = ACTIONS(3631),
    [anon_sym___based] = ACTIONS(3631),
    [anon_sym___cdecl] = ACTIONS(3631),
    [anon_sym___clrcall] = ACTIONS(3631),
    [anon_sym___stdcall] = ACTIONS(3631),
    [anon_sym___fastcall] = ACTIONS(3631),
    [anon_sym___thiscall] = ACTIONS(3631),
    [anon_sym___vectorcall] = ACTIONS(3631),
    [anon_sym_LBRACE] = ACTIONS(3633),
    [anon_sym_LBRACK] = ACTIONS(3631),
    [anon_sym_static] = ACTIONS(3631),
    [anon_sym_EQ] = ACTIONS(3633),
    [anon_sym_register] = ACTIONS(3631),
    [anon_sym_inline] = ACTIONS(3631),
    [anon_sym___inline] = ACTIONS(3631),
    [anon_sym___inline__] = ACTIONS(3631),
    [anon_sym___forceinline] = ACTIONS(3631),
    [anon_sym_thread_local] = ACTIONS(3631),
    [anon_sym___thread] = ACTIONS(3631),
    [anon_sym_const] = ACTIONS(3631),
    [anon_sym_constexpr] = ACTIONS(3631),
    [anon_sym_volatile] = ACTIONS(3631),
    [anon_sym_restrict] = ACTIONS(3631),
    [anon_sym___restrict__] = ACTIONS(3631),
    [anon_sym__Atomic] = ACTIONS(3631),
    [anon_sym__Noreturn] = ACTIONS(3631),
    [anon_sym_noreturn] = ACTIONS(3631),
    [anon_sym_mutable] = ACTIONS(3631),
    [anon_sym_constinit] = ACTIONS(3631),
    [anon_sym_consteval] = ACTIONS(3631),
    [anon_sym_alignas] = ACTIONS(3631),
    [anon_sym__Alignas] = ACTIONS(3631),
    [anon_sym_DASH_GT] = ACTIONS(3633),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(3631),
    [anon_sym_final] = ACTIONS(3631),
    [anon_sym_override] = ACTIONS(3631),
    [sym_virtual] = ACTIONS(3631),
    [anon_sym_explicit] = ACTIONS(3631),
    [anon_sym_template] = ACTIONS(3631),
    [anon_sym_GT2] = ACTIONS(3633),
    [anon_sym_operator] = ACTIONS(3631),
    [anon_sym_try] = ACTIONS(3631),
    [anon_sym_public] = ACTIONS(3631),
    [anon_sym_private] = ACTIONS(3631),
    [anon_sym_protected] = ACTIONS(3631),
    [anon_sym_requires] = ACTIONS(3631),
    [anon_sym_precise] = ACTIONS(3631),
    [anon_sym_shared] = ACTIONS(3631),
    [anon_sym_groupshared] = ACTIONS(3631),
    [anon_sym_uniform] = ACTIONS(3631),
    [anon_sym_row_major] = ACTIONS(3631),
    [anon_sym_column_major] = ACTIONS(3631),
    [anon_sym_globallycoherent] = ACTIONS(3631),
    [anon_sym_centroid] = ACTIONS(3631),
    [anon_sym_noperspective] = ACTIONS(3631),
    [anon_sym_nointerpolation] = ACTIONS(3631),
    [anon_sym_sample] = ACTIONS(3631),
    [anon_sym_linear] = ACTIONS(3631),
    [anon_sym_snorm] = ACTIONS(3631),
    [anon_sym_unorm] = ACTIONS(3631),
    [anon_sym_point] = ACTIONS(3631),
    [anon_sym_line] = ACTIONS(3631),
    [anon_sym_triangleadj] = ACTIONS(3631),
    [anon_sym_lineadj] = ACTIONS(3631),
    [anon_sym_triangle] = ACTIONS(3631),
  },
  [2217] = {
    [sym_identifier] = ACTIONS(3657),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3659),
    [anon_sym_COMMA] = ACTIONS(3659),
    [anon_sym_RPAREN] = ACTIONS(3659),
    [anon_sym_LPAREN2] = ACTIONS(3659),
    [anon_sym_TILDE] = ACTIONS(3659),
    [anon_sym_STAR] = ACTIONS(3659),
    [anon_sym_AMP_AMP] = ACTIONS(3659),
    [anon_sym_AMP] = ACTIONS(3657),
    [anon_sym_COLON] = ACTIONS(3657),
    [anon_sym_SEMI] = ACTIONS(3659),
    [anon_sym___extension__] = ACTIONS(3657),
    [anon_sym_in] = ACTIONS(3657),
    [anon_sym_out] = ACTIONS(3657),
    [anon_sym_inout] = ACTIONS(3657),
    [anon_sym_extern] = ACTIONS(3657),
    [anon_sym___attribute__] = ACTIONS(3657),
    [anon_sym_COLON_COLON] = ACTIONS(3659),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3659),
    [anon_sym___declspec] = ACTIONS(3657),
    [anon_sym___based] = ACTIONS(3657),
    [anon_sym___cdecl] = ACTIONS(3657),
    [anon_sym___clrcall] = ACTIONS(3657),
    [anon_sym___stdcall] = ACTIONS(3657),
    [anon_sym___fastcall] = ACTIONS(3657),
    [anon_sym___thiscall] = ACTIONS(3657),
    [anon_sym___vectorcall] = ACTIONS(3657),
    [anon_sym_LBRACE] = ACTIONS(3659),
    [anon_sym_LBRACK] = ACTIONS(3657),
    [anon_sym_static] = ACTIONS(3657),
    [anon_sym_EQ] = ACTIONS(3659),
    [anon_sym_register] = ACTIONS(3657),
    [anon_sym_inline] = ACTIONS(3657),
    [anon_sym___inline] = ACTIONS(3657),
    [anon_sym___inline__] = ACTIONS(3657),
    [anon_sym___forceinline] = ACTIONS(3657),
    [anon_sym_thread_local] = ACTIONS(3657),
    [anon_sym___thread] = ACTIONS(3657),
    [anon_sym_const] = ACTIONS(3657),
    [anon_sym_constexpr] = ACTIONS(3657),
    [anon_sym_volatile] = ACTIONS(3657),
    [anon_sym_restrict] = ACTIONS(3657),
    [anon_sym___restrict__] = ACTIONS(3657),
    [anon_sym__Atomic] = ACTIONS(3657),
    [anon_sym__Noreturn] = ACTIONS(3657),
    [anon_sym_noreturn] = ACTIONS(3657),
    [anon_sym_mutable] = ACTIONS(3657),
    [anon_sym_constinit] = ACTIONS(3657),
    [anon_sym_consteval] = ACTIONS(3657),
    [anon_sym_alignas] = ACTIONS(3657),
    [anon_sym__Alignas] = ACTIONS(3657),
    [anon_sym_DASH_GT] = ACTIONS(3659),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(3657),
    [anon_sym_final] = ACTIONS(3657),
    [anon_sym_override] = ACTIONS(3657),
    [sym_virtual] = ACTIONS(3657),
    [anon_sym_explicit] = ACTIONS(3657),
    [anon_sym_template] = ACTIONS(3657),
    [anon_sym_GT2] = ACTIONS(3659),
    [anon_sym_operator] = ACTIONS(3657),
    [anon_sym_try] = ACTIONS(3657),
    [anon_sym_public] = ACTIONS(3657),
    [anon_sym_private] = ACTIONS(3657),
    [anon_sym_protected] = ACTIONS(3657),
    [anon_sym_requires] = ACTIONS(3657),
    [anon_sym_precise] = ACTIONS(3657),
    [anon_sym_shared] = ACTIONS(3657),
    [anon_sym_groupshared] = ACTIONS(3657),
    [anon_sym_uniform] = ACTIONS(3657),
    [anon_sym_row_major] = ACTIONS(3657),
    [anon_sym_column_major] = ACTIONS(3657),
    [anon_sym_globallycoherent] = ACTIONS(3657),
    [anon_sym_centroid] = ACTIONS(3657),
    [anon_sym_noperspective] = ACTIONS(3657),
    [anon_sym_nointerpolation] = ACTIONS(3657),
    [anon_sym_sample] = ACTIONS(3657),
    [anon_sym_linear] = ACTIONS(3657),
    [anon_sym_snorm] = ACTIONS(3657),
    [anon_sym_unorm] = ACTIONS(3657),
    [anon_sym_point] = ACTIONS(3657),
    [anon_sym_line] = ACTIONS(3657),
    [anon_sym_triangleadj] = ACTIONS(3657),
    [anon_sym_lineadj] = ACTIONS(3657),
    [anon_sym_triangle] = ACTIONS(3657),
  },
  [2218] = {
    [sym__declaration_modifiers] = STATE(2220),
    [sym_attribute_specifier] = STATE(2220),
    [sym_attribute_declaration] = STATE(2220),
    [sym_ms_declspec_modifier] = STATE(2220),
    [sym_storage_class_specifier] = STATE(2220),
    [sym_type_qualifier] = STATE(2220),
    [sym_alignas_qualifier] = STATE(2331),
    [sym_qualifiers] = STATE(2220),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2220),
    [sym_identifier] = ACTIONS(5256),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5258),
    [anon_sym_COMMA] = ACTIONS(5258),
    [anon_sym_RPAREN] = ACTIONS(5258),
    [anon_sym_LPAREN2] = ACTIONS(5258),
    [anon_sym_TILDE] = ACTIONS(5258),
    [anon_sym_STAR] = ACTIONS(5258),
    [anon_sym_AMP_AMP] = ACTIONS(5258),
    [anon_sym_AMP] = ACTIONS(5256),
    [anon_sym_COLON] = ACTIONS(5256),
    [anon_sym_SEMI] = ACTIONS(5258),
    [anon_sym___extension__] = ACTIONS(4981),
    [anon_sym_in] = ACTIONS(5260),
    [anon_sym_out] = ACTIONS(5260),
    [anon_sym_inout] = ACTIONS(5260),
    [anon_sym_extern] = ACTIONS(4985),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5258),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4991),
    [anon_sym___declspec] = ACTIONS(4993),
    [anon_sym___based] = ACTIONS(5256),
    [anon_sym___cdecl] = ACTIONS(5256),
    [anon_sym___clrcall] = ACTIONS(5256),
    [anon_sym___stdcall] = ACTIONS(5256),
    [anon_sym___fastcall] = ACTIONS(5256),
    [anon_sym___thiscall] = ACTIONS(5256),
    [anon_sym___vectorcall] = ACTIONS(5256),
    [anon_sym_LBRACK] = ACTIONS(5256),
    [anon_sym_static] = ACTIONS(4985),
    [anon_sym_EQ] = ACTIONS(5258),
    [anon_sym_register] = ACTIONS(4985),
    [anon_sym_inline] = ACTIONS(4985),
    [anon_sym___inline] = ACTIONS(4985),
    [anon_sym___inline__] = ACTIONS(4985),
    [anon_sym___forceinline] = ACTIONS(4985),
    [anon_sym_thread_local] = ACTIONS(4985),
    [anon_sym___thread] = ACTIONS(4985),
    [anon_sym_const] = ACTIONS(4981),
    [anon_sym_constexpr] = ACTIONS(4981),
    [anon_sym_volatile] = ACTIONS(4981),
    [anon_sym_restrict] = ACTIONS(4981),
    [anon_sym___restrict__] = ACTIONS(4981),
    [anon_sym__Atomic] = ACTIONS(4981),
    [anon_sym__Noreturn] = ACTIONS(4981),
    [anon_sym_noreturn] = ACTIONS(4981),
    [anon_sym_mutable] = ACTIONS(4981),
    [anon_sym_constinit] = ACTIONS(4981),
    [anon_sym_consteval] = ACTIONS(4981),
    [anon_sym_alignas] = ACTIONS(4995),
    [anon_sym__Alignas] = ACTIONS(4995),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(5256),
    [sym_virtual] = ACTIONS(5260),
    [anon_sym_template] = ACTIONS(5256),
    [anon_sym_GT2] = ACTIONS(5258),
    [anon_sym_operator] = ACTIONS(5256),
    [anon_sym_precise] = ACTIONS(4997),
    [anon_sym_shared] = ACTIONS(4997),
    [anon_sym_groupshared] = ACTIONS(4997),
    [anon_sym_uniform] = ACTIONS(4997),
    [anon_sym_row_major] = ACTIONS(4997),
    [anon_sym_column_major] = ACTIONS(4997),
    [anon_sym_globallycoherent] = ACTIONS(4997),
    [anon_sym_centroid] = ACTIONS(4997),
    [anon_sym_noperspective] = ACTIONS(4997),
    [anon_sym_nointerpolation] = ACTIONS(4997),
    [anon_sym_sample] = ACTIONS(4997),
    [anon_sym_linear] = ACTIONS(4997),
    [anon_sym_snorm] = ACTIONS(4997),
    [anon_sym_unorm] = ACTIONS(4997),
    [anon_sym_point] = ACTIONS(4997),
    [anon_sym_line] = ACTIONS(4997),
    [anon_sym_triangleadj] = ACTIONS(4997),
    [anon_sym_lineadj] = ACTIONS(4997),
    [anon_sym_triangle] = ACTIONS(4997),
  },
  [2219] = {
    [sym_identifier] = ACTIONS(5262),
    [anon_sym_LPAREN2] = ACTIONS(5264),
    [anon_sym_TILDE] = ACTIONS(5264),
    [anon_sym_STAR] = ACTIONS(5264),
    [anon_sym_AMP_AMP] = ACTIONS(5264),
    [anon_sym_AMP] = ACTIONS(5262),
    [anon_sym___extension__] = ACTIONS(5262),
    [anon_sym_in] = ACTIONS(5262),
    [anon_sym_out] = ACTIONS(5262),
    [anon_sym_inout] = ACTIONS(5262),
    [anon_sym_extern] = ACTIONS(5262),
    [anon_sym___attribute__] = ACTIONS(5262),
    [anon_sym_COLON_COLON] = ACTIONS(5264),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5264),
    [anon_sym___declspec] = ACTIONS(5262),
    [anon_sym___based] = ACTIONS(5262),
    [anon_sym___cdecl] = ACTIONS(5262),
    [anon_sym___clrcall] = ACTIONS(5262),
    [anon_sym___stdcall] = ACTIONS(5262),
    [anon_sym___fastcall] = ACTIONS(5262),
    [anon_sym___thiscall] = ACTIONS(5262),
    [anon_sym___vectorcall] = ACTIONS(5262),
    [anon_sym_signed] = ACTIONS(5262),
    [anon_sym_unsigned] = ACTIONS(5262),
    [anon_sym_long] = ACTIONS(5262),
    [anon_sym_short] = ACTIONS(5262),
    [anon_sym_LBRACK] = ACTIONS(5262),
    [anon_sym_static] = ACTIONS(5262),
    [anon_sym_register] = ACTIONS(5262),
    [anon_sym_inline] = ACTIONS(5262),
    [anon_sym___inline] = ACTIONS(5262),
    [anon_sym___inline__] = ACTIONS(5262),
    [anon_sym___forceinline] = ACTIONS(5262),
    [anon_sym_thread_local] = ACTIONS(5262),
    [anon_sym___thread] = ACTIONS(5262),
    [anon_sym_const] = ACTIONS(5262),
    [anon_sym_constexpr] = ACTIONS(5262),
    [anon_sym_volatile] = ACTIONS(5262),
    [anon_sym_restrict] = ACTIONS(5262),
    [anon_sym___restrict__] = ACTIONS(5262),
    [anon_sym__Atomic] = ACTIONS(5262),
    [anon_sym__Noreturn] = ACTIONS(5262),
    [anon_sym_noreturn] = ACTIONS(5262),
    [anon_sym_mutable] = ACTIONS(5262),
    [anon_sym_constinit] = ACTIONS(5262),
    [anon_sym_consteval] = ACTIONS(5262),
    [anon_sym_alignas] = ACTIONS(5262),
    [anon_sym__Alignas] = ACTIONS(5262),
    [sym_primitive_type] = ACTIONS(5262),
    [anon_sym_enum] = ACTIONS(5262),
    [anon_sym_class] = ACTIONS(5262),
    [anon_sym_struct] = ACTIONS(5262),
    [anon_sym_union] = ACTIONS(5262),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5262),
    [anon_sym_decltype] = ACTIONS(5262),
    [sym_virtual] = ACTIONS(5262),
    [anon_sym_explicit] = ACTIONS(5262),
    [anon_sym_typename] = ACTIONS(5262),
    [anon_sym_template] = ACTIONS(5262),
    [anon_sym_operator] = ACTIONS(5262),
    [anon_sym_friend] = ACTIONS(5262),
    [anon_sym_using] = ACTIONS(5262),
    [anon_sym_concept] = ACTIONS(5262),
    [anon_sym_requires] = ACTIONS(5262),
    [anon_sym_precise] = ACTIONS(5262),
    [anon_sym_shared] = ACTIONS(5262),
    [anon_sym_groupshared] = ACTIONS(5262),
    [anon_sym_uniform] = ACTIONS(5262),
    [anon_sym_row_major] = ACTIONS(5262),
    [anon_sym_column_major] = ACTIONS(5262),
    [anon_sym_globallycoherent] = ACTIONS(5262),
    [anon_sym_centroid] = ACTIONS(5262),
    [anon_sym_noperspective] = ACTIONS(5262),
    [anon_sym_nointerpolation] = ACTIONS(5262),
    [anon_sym_sample] = ACTIONS(5262),
    [anon_sym_linear] = ACTIONS(5262),
    [anon_sym_snorm] = ACTIONS(5262),
    [anon_sym_unorm] = ACTIONS(5262),
    [anon_sym_point] = ACTIONS(5262),
    [anon_sym_line] = ACTIONS(5262),
    [anon_sym_triangleadj] = ACTIONS(5262),
    [anon_sym_lineadj] = ACTIONS(5262),
    [anon_sym_triangle] = ACTIONS(5262),
  },
  [2220] = {
    [sym__declaration_modifiers] = STATE(2220),
    [sym_attribute_specifier] = STATE(2220),
    [sym_attribute_declaration] = STATE(2220),
    [sym_ms_declspec_modifier] = STATE(2220),
    [sym_storage_class_specifier] = STATE(2220),
    [sym_type_qualifier] = STATE(2220),
    [sym_alignas_qualifier] = STATE(2331),
    [sym_qualifiers] = STATE(2220),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2220),
    [sym_identifier] = ACTIONS(5266),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5268),
    [anon_sym_COMMA] = ACTIONS(5268),
    [anon_sym_RPAREN] = ACTIONS(5268),
    [anon_sym_LPAREN2] = ACTIONS(5268),
    [anon_sym_TILDE] = ACTIONS(5268),
    [anon_sym_STAR] = ACTIONS(5268),
    [anon_sym_AMP_AMP] = ACTIONS(5268),
    [anon_sym_AMP] = ACTIONS(5266),
    [anon_sym_COLON] = ACTIONS(5266),
    [anon_sym_SEMI] = ACTIONS(5268),
    [anon_sym___extension__] = ACTIONS(5270),
    [anon_sym_in] = ACTIONS(5273),
    [anon_sym_out] = ACTIONS(5273),
    [anon_sym_inout] = ACTIONS(5273),
    [anon_sym_extern] = ACTIONS(5276),
    [anon_sym___attribute__] = ACTIONS(5279),
    [anon_sym_COLON_COLON] = ACTIONS(5268),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5282),
    [anon_sym___declspec] = ACTIONS(5285),
    [anon_sym___based] = ACTIONS(5266),
    [anon_sym___cdecl] = ACTIONS(5266),
    [anon_sym___clrcall] = ACTIONS(5266),
    [anon_sym___stdcall] = ACTIONS(5266),
    [anon_sym___fastcall] = ACTIONS(5266),
    [anon_sym___thiscall] = ACTIONS(5266),
    [anon_sym___vectorcall] = ACTIONS(5266),
    [anon_sym_LBRACK] = ACTIONS(5266),
    [anon_sym_static] = ACTIONS(5276),
    [anon_sym_EQ] = ACTIONS(5268),
    [anon_sym_register] = ACTIONS(5276),
    [anon_sym_inline] = ACTIONS(5276),
    [anon_sym___inline] = ACTIONS(5276),
    [anon_sym___inline__] = ACTIONS(5276),
    [anon_sym___forceinline] = ACTIONS(5276),
    [anon_sym_thread_local] = ACTIONS(5276),
    [anon_sym___thread] = ACTIONS(5276),
    [anon_sym_const] = ACTIONS(5270),
    [anon_sym_constexpr] = ACTIONS(5270),
    [anon_sym_volatile] = ACTIONS(5270),
    [anon_sym_restrict] = ACTIONS(5270),
    [anon_sym___restrict__] = ACTIONS(5270),
    [anon_sym__Atomic] = ACTIONS(5270),
    [anon_sym__Noreturn] = ACTIONS(5270),
    [anon_sym_noreturn] = ACTIONS(5270),
    [anon_sym_mutable] = ACTIONS(5270),
    [anon_sym_constinit] = ACTIONS(5270),
    [anon_sym_consteval] = ACTIONS(5270),
    [anon_sym_alignas] = ACTIONS(5288),
    [anon_sym__Alignas] = ACTIONS(5288),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(5266),
    [sym_virtual] = ACTIONS(5273),
    [anon_sym_template] = ACTIONS(5266),
    [anon_sym_GT2] = ACTIONS(5268),
    [anon_sym_operator] = ACTIONS(5266),
    [anon_sym_precise] = ACTIONS(5291),
    [anon_sym_shared] = ACTIONS(5291),
    [anon_sym_groupshared] = ACTIONS(5291),
    [anon_sym_uniform] = ACTIONS(5291),
    [anon_sym_row_major] = ACTIONS(5291),
    [anon_sym_column_major] = ACTIONS(5291),
    [anon_sym_globallycoherent] = ACTIONS(5291),
    [anon_sym_centroid] = ACTIONS(5291),
    [anon_sym_noperspective] = ACTIONS(5291),
    [anon_sym_nointerpolation] = ACTIONS(5291),
    [anon_sym_sample] = ACTIONS(5291),
    [anon_sym_linear] = ACTIONS(5291),
    [anon_sym_snorm] = ACTIONS(5291),
    [anon_sym_unorm] = ACTIONS(5291),
    [anon_sym_point] = ACTIONS(5291),
    [anon_sym_line] = ACTIONS(5291),
    [anon_sym_triangleadj] = ACTIONS(5291),
    [anon_sym_lineadj] = ACTIONS(5291),
    [anon_sym_triangle] = ACTIONS(5291),
  },
  [2221] = {
    [sym_identifier] = ACTIONS(1959),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1961),
    [anon_sym_COMMA] = ACTIONS(1961),
    [anon_sym_RPAREN] = ACTIONS(1961),
    [anon_sym_LPAREN2] = ACTIONS(1961),
    [anon_sym_TILDE] = ACTIONS(1961),
    [anon_sym_STAR] = ACTIONS(1961),
    [anon_sym_PIPE_PIPE] = ACTIONS(1961),
    [anon_sym_AMP_AMP] = ACTIONS(1961),
    [anon_sym_AMP] = ACTIONS(1959),
    [anon_sym_COLON] = ACTIONS(1959),
    [anon_sym_SEMI] = ACTIONS(1961),
    [anon_sym___extension__] = ACTIONS(1959),
    [anon_sym_in] = ACTIONS(1959),
    [anon_sym_out] = ACTIONS(1959),
    [anon_sym_inout] = ACTIONS(1959),
    [anon_sym_extern] = ACTIONS(1959),
    [anon_sym___attribute__] = ACTIONS(1959),
    [anon_sym_COLON_COLON] = ACTIONS(1961),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1961),
    [anon_sym___declspec] = ACTIONS(1959),
    [anon_sym___based] = ACTIONS(1959),
    [anon_sym___cdecl] = ACTIONS(1959),
    [anon_sym___clrcall] = ACTIONS(1959),
    [anon_sym___stdcall] = ACTIONS(1959),
    [anon_sym___fastcall] = ACTIONS(1959),
    [anon_sym___thiscall] = ACTIONS(1959),
    [anon_sym___vectorcall] = ACTIONS(1959),
    [anon_sym_LBRACE] = ACTIONS(1961),
    [anon_sym_LBRACK] = ACTIONS(1959),
    [anon_sym_static] = ACTIONS(1959),
    [anon_sym_EQ] = ACTIONS(1961),
    [anon_sym_register] = ACTIONS(1959),
    [anon_sym_inline] = ACTIONS(1959),
    [anon_sym___inline] = ACTIONS(1959),
    [anon_sym___inline__] = ACTIONS(1959),
    [anon_sym___forceinline] = ACTIONS(1959),
    [anon_sym_thread_local] = ACTIONS(1959),
    [anon_sym___thread] = ACTIONS(1959),
    [anon_sym_const] = ACTIONS(1959),
    [anon_sym_constexpr] = ACTIONS(1959),
    [anon_sym_volatile] = ACTIONS(1959),
    [anon_sym_restrict] = ACTIONS(1959),
    [anon_sym___restrict__] = ACTIONS(1959),
    [anon_sym__Atomic] = ACTIONS(1959),
    [anon_sym__Noreturn] = ACTIONS(1959),
    [anon_sym_noreturn] = ACTIONS(1959),
    [anon_sym_mutable] = ACTIONS(1959),
    [anon_sym_constinit] = ACTIONS(1959),
    [anon_sym_consteval] = ACTIONS(1959),
    [anon_sym_alignas] = ACTIONS(1959),
    [anon_sym__Alignas] = ACTIONS(1959),
    [anon_sym_or] = ACTIONS(1959),
    [anon_sym_and] = ACTIONS(1959),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1959),
    [anon_sym_decltype] = ACTIONS(1959),
    [anon_sym_final] = ACTIONS(1959),
    [anon_sym_override] = ACTIONS(1959),
    [sym_virtual] = ACTIONS(1959),
    [anon_sym_template] = ACTIONS(1959),
    [anon_sym_GT2] = ACTIONS(1961),
    [anon_sym_operator] = ACTIONS(1959),
    [anon_sym_try] = ACTIONS(1959),
    [anon_sym_requires] = ACTIONS(1959),
    [anon_sym_precise] = ACTIONS(1959),
    [anon_sym_shared] = ACTIONS(1959),
    [anon_sym_groupshared] = ACTIONS(1959),
    [anon_sym_uniform] = ACTIONS(1959),
    [anon_sym_row_major] = ACTIONS(1959),
    [anon_sym_column_major] = ACTIONS(1959),
    [anon_sym_globallycoherent] = ACTIONS(1959),
    [anon_sym_centroid] = ACTIONS(1959),
    [anon_sym_noperspective] = ACTIONS(1959),
    [anon_sym_nointerpolation] = ACTIONS(1959),
    [anon_sym_sample] = ACTIONS(1959),
    [anon_sym_linear] = ACTIONS(1959),
    [anon_sym_snorm] = ACTIONS(1959),
    [anon_sym_unorm] = ACTIONS(1959),
    [anon_sym_point] = ACTIONS(1959),
    [anon_sym_line] = ACTIONS(1959),
    [anon_sym_triangleadj] = ACTIONS(1959),
    [anon_sym_lineadj] = ACTIONS(1959),
    [anon_sym_triangle] = ACTIONS(1959),
  },
  [2222] = {
    [sym_template_argument_list] = STATE(2390),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2233),
    [sym_identifier] = ACTIONS(5294),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5296),
    [anon_sym_COMMA] = ACTIONS(5296),
    [anon_sym_RPAREN] = ACTIONS(5296),
    [anon_sym_LPAREN2] = ACTIONS(5296),
    [anon_sym_TILDE] = ACTIONS(5296),
    [anon_sym_STAR] = ACTIONS(5296),
    [anon_sym_AMP_AMP] = ACTIONS(5296),
    [anon_sym_AMP] = ACTIONS(5294),
    [anon_sym_LT] = ACTIONS(5298),
    [anon_sym_COLON] = ACTIONS(5294),
    [anon_sym_SEMI] = ACTIONS(5296),
    [anon_sym___extension__] = ACTIONS(5294),
    [anon_sym_in] = ACTIONS(5294),
    [anon_sym_out] = ACTIONS(5294),
    [anon_sym_inout] = ACTIONS(5294),
    [anon_sym_extern] = ACTIONS(5294),
    [anon_sym___attribute__] = ACTIONS(5294),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5296),
    [anon_sym___declspec] = ACTIONS(5294),
    [anon_sym___based] = ACTIONS(5294),
    [anon_sym___cdecl] = ACTIONS(5294),
    [anon_sym___clrcall] = ACTIONS(5294),
    [anon_sym___stdcall] = ACTIONS(5294),
    [anon_sym___fastcall] = ACTIONS(5294),
    [anon_sym___thiscall] = ACTIONS(5294),
    [anon_sym___vectorcall] = ACTIONS(5294),
    [anon_sym_LBRACE] = ACTIONS(5296),
    [anon_sym_signed] = ACTIONS(3848),
    [anon_sym_unsigned] = ACTIONS(3848),
    [anon_sym_long] = ACTIONS(3848),
    [anon_sym_short] = ACTIONS(3848),
    [anon_sym_LBRACK] = ACTIONS(5294),
    [anon_sym_static] = ACTIONS(5294),
    [anon_sym_EQ] = ACTIONS(5296),
    [anon_sym_register] = ACTIONS(5294),
    [anon_sym_inline] = ACTIONS(5294),
    [anon_sym___inline] = ACTIONS(5294),
    [anon_sym___inline__] = ACTIONS(5294),
    [anon_sym___forceinline] = ACTIONS(5294),
    [anon_sym_thread_local] = ACTIONS(5294),
    [anon_sym___thread] = ACTIONS(5294),
    [anon_sym_const] = ACTIONS(5294),
    [anon_sym_constexpr] = ACTIONS(5294),
    [anon_sym_volatile] = ACTIONS(5294),
    [anon_sym_restrict] = ACTIONS(5294),
    [anon_sym___restrict__] = ACTIONS(5294),
    [anon_sym__Atomic] = ACTIONS(5294),
    [anon_sym__Noreturn] = ACTIONS(5294),
    [anon_sym_noreturn] = ACTIONS(5294),
    [anon_sym_mutable] = ACTIONS(5294),
    [anon_sym_constinit] = ACTIONS(5294),
    [anon_sym_consteval] = ACTIONS(5294),
    [anon_sym_alignas] = ACTIONS(5294),
    [anon_sym__Alignas] = ACTIONS(5294),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5294),
    [anon_sym_decltype] = ACTIONS(5294),
    [sym_virtual] = ACTIONS(5294),
    [anon_sym_template] = ACTIONS(5294),
    [anon_sym_GT2] = ACTIONS(5296),
    [anon_sym_operator] = ACTIONS(5294),
    [anon_sym_precise] = ACTIONS(5294),
    [anon_sym_shared] = ACTIONS(5294),
    [anon_sym_groupshared] = ACTIONS(5294),
    [anon_sym_uniform] = ACTIONS(5294),
    [anon_sym_row_major] = ACTIONS(5294),
    [anon_sym_column_major] = ACTIONS(5294),
    [anon_sym_globallycoherent] = ACTIONS(5294),
    [anon_sym_centroid] = ACTIONS(5294),
    [anon_sym_noperspective] = ACTIONS(5294),
    [anon_sym_nointerpolation] = ACTIONS(5294),
    [anon_sym_sample] = ACTIONS(5294),
    [anon_sym_linear] = ACTIONS(5294),
    [anon_sym_snorm] = ACTIONS(5294),
    [anon_sym_unorm] = ACTIONS(5294),
    [anon_sym_point] = ACTIONS(5294),
    [anon_sym_line] = ACTIONS(5294),
    [anon_sym_triangleadj] = ACTIONS(5294),
    [anon_sym_lineadj] = ACTIONS(5294),
    [anon_sym_triangle] = ACTIONS(5294),
  },
  [2223] = {
    [sym_identifier] = ACTIONS(5300),
    [anon_sym_LPAREN2] = ACTIONS(5302),
    [anon_sym_TILDE] = ACTIONS(5302),
    [anon_sym_STAR] = ACTIONS(5302),
    [anon_sym_AMP_AMP] = ACTIONS(5302),
    [anon_sym_AMP] = ACTIONS(5300),
    [anon_sym___extension__] = ACTIONS(5300),
    [anon_sym_in] = ACTIONS(5300),
    [anon_sym_out] = ACTIONS(5300),
    [anon_sym_inout] = ACTIONS(5300),
    [anon_sym_extern] = ACTIONS(5300),
    [anon_sym___attribute__] = ACTIONS(5300),
    [anon_sym_COLON_COLON] = ACTIONS(5302),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5302),
    [anon_sym___declspec] = ACTIONS(5300),
    [anon_sym___based] = ACTIONS(5300),
    [anon_sym___cdecl] = ACTIONS(5300),
    [anon_sym___clrcall] = ACTIONS(5300),
    [anon_sym___stdcall] = ACTIONS(5300),
    [anon_sym___fastcall] = ACTIONS(5300),
    [anon_sym___thiscall] = ACTIONS(5300),
    [anon_sym___vectorcall] = ACTIONS(5300),
    [anon_sym_signed] = ACTIONS(5300),
    [anon_sym_unsigned] = ACTIONS(5300),
    [anon_sym_long] = ACTIONS(5300),
    [anon_sym_short] = ACTIONS(5300),
    [anon_sym_LBRACK] = ACTIONS(5300),
    [anon_sym_static] = ACTIONS(5300),
    [anon_sym_register] = ACTIONS(5300),
    [anon_sym_inline] = ACTIONS(5300),
    [anon_sym___inline] = ACTIONS(5300),
    [anon_sym___inline__] = ACTIONS(5300),
    [anon_sym___forceinline] = ACTIONS(5300),
    [anon_sym_thread_local] = ACTIONS(5300),
    [anon_sym___thread] = ACTIONS(5300),
    [anon_sym_const] = ACTIONS(5300),
    [anon_sym_constexpr] = ACTIONS(5300),
    [anon_sym_volatile] = ACTIONS(5300),
    [anon_sym_restrict] = ACTIONS(5300),
    [anon_sym___restrict__] = ACTIONS(5300),
    [anon_sym__Atomic] = ACTIONS(5300),
    [anon_sym__Noreturn] = ACTIONS(5300),
    [anon_sym_noreturn] = ACTIONS(5300),
    [anon_sym_mutable] = ACTIONS(5300),
    [anon_sym_constinit] = ACTIONS(5300),
    [anon_sym_consteval] = ACTIONS(5300),
    [anon_sym_alignas] = ACTIONS(5300),
    [anon_sym__Alignas] = ACTIONS(5300),
    [sym_primitive_type] = ACTIONS(5300),
    [anon_sym_enum] = ACTIONS(5300),
    [anon_sym_class] = ACTIONS(5300),
    [anon_sym_struct] = ACTIONS(5300),
    [anon_sym_union] = ACTIONS(5300),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5300),
    [anon_sym_decltype] = ACTIONS(5300),
    [sym_virtual] = ACTIONS(5300),
    [anon_sym_explicit] = ACTIONS(5300),
    [anon_sym_typename] = ACTIONS(5300),
    [anon_sym_template] = ACTIONS(5300),
    [anon_sym_operator] = ACTIONS(5300),
    [anon_sym_friend] = ACTIONS(5300),
    [anon_sym_using] = ACTIONS(5300),
    [anon_sym_concept] = ACTIONS(5300),
    [anon_sym_requires] = ACTIONS(5300),
    [anon_sym_precise] = ACTIONS(5300),
    [anon_sym_shared] = ACTIONS(5300),
    [anon_sym_groupshared] = ACTIONS(5300),
    [anon_sym_uniform] = ACTIONS(5300),
    [anon_sym_row_major] = ACTIONS(5300),
    [anon_sym_column_major] = ACTIONS(5300),
    [anon_sym_globallycoherent] = ACTIONS(5300),
    [anon_sym_centroid] = ACTIONS(5300),
    [anon_sym_noperspective] = ACTIONS(5300),
    [anon_sym_nointerpolation] = ACTIONS(5300),
    [anon_sym_sample] = ACTIONS(5300),
    [anon_sym_linear] = ACTIONS(5300),
    [anon_sym_snorm] = ACTIONS(5300),
    [anon_sym_unorm] = ACTIONS(5300),
    [anon_sym_point] = ACTIONS(5300),
    [anon_sym_line] = ACTIONS(5300),
    [anon_sym_triangleadj] = ACTIONS(5300),
    [anon_sym_lineadj] = ACTIONS(5300),
    [anon_sym_triangle] = ACTIONS(5300),
  },
  [2224] = {
    [sym__declaration_modifiers] = STATE(2220),
    [sym_attribute_specifier] = STATE(2220),
    [sym_attribute_declaration] = STATE(2220),
    [sym_ms_declspec_modifier] = STATE(2220),
    [sym_storage_class_specifier] = STATE(2220),
    [sym_type_qualifier] = STATE(2220),
    [sym_alignas_qualifier] = STATE(2331),
    [sym_qualifiers] = STATE(2220),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2220),
    [sym_identifier] = ACTIONS(5304),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5306),
    [anon_sym_COMMA] = ACTIONS(5306),
    [anon_sym_RPAREN] = ACTIONS(5306),
    [anon_sym_LPAREN2] = ACTIONS(5306),
    [anon_sym_TILDE] = ACTIONS(5306),
    [anon_sym_STAR] = ACTIONS(5306),
    [anon_sym_AMP_AMP] = ACTIONS(5306),
    [anon_sym_AMP] = ACTIONS(5304),
    [anon_sym_COLON] = ACTIONS(5304),
    [anon_sym_SEMI] = ACTIONS(5306),
    [anon_sym___extension__] = ACTIONS(4981),
    [anon_sym_in] = ACTIONS(5260),
    [anon_sym_out] = ACTIONS(5260),
    [anon_sym_inout] = ACTIONS(5260),
    [anon_sym_extern] = ACTIONS(4985),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5306),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4991),
    [anon_sym___declspec] = ACTIONS(4993),
    [anon_sym___based] = ACTIONS(5304),
    [anon_sym___cdecl] = ACTIONS(5304),
    [anon_sym___clrcall] = ACTIONS(5304),
    [anon_sym___stdcall] = ACTIONS(5304),
    [anon_sym___fastcall] = ACTIONS(5304),
    [anon_sym___thiscall] = ACTIONS(5304),
    [anon_sym___vectorcall] = ACTIONS(5304),
    [anon_sym_LBRACK] = ACTIONS(5304),
    [anon_sym_static] = ACTIONS(4985),
    [anon_sym_EQ] = ACTIONS(5306),
    [anon_sym_register] = ACTIONS(4985),
    [anon_sym_inline] = ACTIONS(4985),
    [anon_sym___inline] = ACTIONS(4985),
    [anon_sym___inline__] = ACTIONS(4985),
    [anon_sym___forceinline] = ACTIONS(4985),
    [anon_sym_thread_local] = ACTIONS(4985),
    [anon_sym___thread] = ACTIONS(4985),
    [anon_sym_const] = ACTIONS(4981),
    [anon_sym_constexpr] = ACTIONS(4981),
    [anon_sym_volatile] = ACTIONS(4981),
    [anon_sym_restrict] = ACTIONS(4981),
    [anon_sym___restrict__] = ACTIONS(4981),
    [anon_sym__Atomic] = ACTIONS(4981),
    [anon_sym__Noreturn] = ACTIONS(4981),
    [anon_sym_noreturn] = ACTIONS(4981),
    [anon_sym_mutable] = ACTIONS(4981),
    [anon_sym_constinit] = ACTIONS(4981),
    [anon_sym_consteval] = ACTIONS(4981),
    [anon_sym_alignas] = ACTIONS(4995),
    [anon_sym__Alignas] = ACTIONS(4995),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(5304),
    [sym_virtual] = ACTIONS(5260),
    [anon_sym_template] = ACTIONS(5304),
    [anon_sym_GT2] = ACTIONS(5306),
    [anon_sym_operator] = ACTIONS(5304),
    [anon_sym_precise] = ACTIONS(4997),
    [anon_sym_shared] = ACTIONS(4997),
    [anon_sym_groupshared] = ACTIONS(4997),
    [anon_sym_uniform] = ACTIONS(4997),
    [anon_sym_row_major] = ACTIONS(4997),
    [anon_sym_column_major] = ACTIONS(4997),
    [anon_sym_globallycoherent] = ACTIONS(4997),
    [anon_sym_centroid] = ACTIONS(4997),
    [anon_sym_noperspective] = ACTIONS(4997),
    [anon_sym_nointerpolation] = ACTIONS(4997),
    [anon_sym_sample] = ACTIONS(4997),
    [anon_sym_linear] = ACTIONS(4997),
    [anon_sym_snorm] = ACTIONS(4997),
    [anon_sym_unorm] = ACTIONS(4997),
    [anon_sym_point] = ACTIONS(4997),
    [anon_sym_line] = ACTIONS(4997),
    [anon_sym_triangleadj] = ACTIONS(4997),
    [anon_sym_lineadj] = ACTIONS(4997),
    [anon_sym_triangle] = ACTIONS(4997),
  },
  [2225] = {
    [sym_identifier] = ACTIONS(5308),
    [anon_sym_LPAREN2] = ACTIONS(5310),
    [anon_sym_TILDE] = ACTIONS(5310),
    [anon_sym_STAR] = ACTIONS(5310),
    [anon_sym_AMP_AMP] = ACTIONS(5310),
    [anon_sym_AMP] = ACTIONS(5308),
    [anon_sym___extension__] = ACTIONS(5308),
    [anon_sym_in] = ACTIONS(5308),
    [anon_sym_out] = ACTIONS(5308),
    [anon_sym_inout] = ACTIONS(5308),
    [anon_sym_extern] = ACTIONS(5308),
    [anon_sym___attribute__] = ACTIONS(5308),
    [anon_sym_COLON_COLON] = ACTIONS(5310),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5310),
    [anon_sym___declspec] = ACTIONS(5308),
    [anon_sym___based] = ACTIONS(5308),
    [anon_sym___cdecl] = ACTIONS(5308),
    [anon_sym___clrcall] = ACTIONS(5308),
    [anon_sym___stdcall] = ACTIONS(5308),
    [anon_sym___fastcall] = ACTIONS(5308),
    [anon_sym___thiscall] = ACTIONS(5308),
    [anon_sym___vectorcall] = ACTIONS(5308),
    [anon_sym_signed] = ACTIONS(5308),
    [anon_sym_unsigned] = ACTIONS(5308),
    [anon_sym_long] = ACTIONS(5308),
    [anon_sym_short] = ACTIONS(5308),
    [anon_sym_LBRACK] = ACTIONS(5308),
    [anon_sym_static] = ACTIONS(5308),
    [anon_sym_register] = ACTIONS(5308),
    [anon_sym_inline] = ACTIONS(5308),
    [anon_sym___inline] = ACTIONS(5308),
    [anon_sym___inline__] = ACTIONS(5308),
    [anon_sym___forceinline] = ACTIONS(5308),
    [anon_sym_thread_local] = ACTIONS(5308),
    [anon_sym___thread] = ACTIONS(5308),
    [anon_sym_const] = ACTIONS(5308),
    [anon_sym_constexpr] = ACTIONS(5308),
    [anon_sym_volatile] = ACTIONS(5308),
    [anon_sym_restrict] = ACTIONS(5308),
    [anon_sym___restrict__] = ACTIONS(5308),
    [anon_sym__Atomic] = ACTIONS(5308),
    [anon_sym__Noreturn] = ACTIONS(5308),
    [anon_sym_noreturn] = ACTIONS(5308),
    [anon_sym_mutable] = ACTIONS(5308),
    [anon_sym_constinit] = ACTIONS(5308),
    [anon_sym_consteval] = ACTIONS(5308),
    [anon_sym_alignas] = ACTIONS(5308),
    [anon_sym__Alignas] = ACTIONS(5308),
    [sym_primitive_type] = ACTIONS(5308),
    [anon_sym_enum] = ACTIONS(5308),
    [anon_sym_class] = ACTIONS(5308),
    [anon_sym_struct] = ACTIONS(5308),
    [anon_sym_union] = ACTIONS(5308),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5308),
    [anon_sym_decltype] = ACTIONS(5308),
    [sym_virtual] = ACTIONS(5308),
    [anon_sym_explicit] = ACTIONS(5308),
    [anon_sym_typename] = ACTIONS(5308),
    [anon_sym_template] = ACTIONS(5308),
    [anon_sym_operator] = ACTIONS(5308),
    [anon_sym_friend] = ACTIONS(5308),
    [anon_sym_using] = ACTIONS(5308),
    [anon_sym_concept] = ACTIONS(5308),
    [anon_sym_requires] = ACTIONS(5308),
    [anon_sym_precise] = ACTIONS(5308),
    [anon_sym_shared] = ACTIONS(5308),
    [anon_sym_groupshared] = ACTIONS(5308),
    [anon_sym_uniform] = ACTIONS(5308),
    [anon_sym_row_major] = ACTIONS(5308),
    [anon_sym_column_major] = ACTIONS(5308),
    [anon_sym_globallycoherent] = ACTIONS(5308),
    [anon_sym_centroid] = ACTIONS(5308),
    [anon_sym_noperspective] = ACTIONS(5308),
    [anon_sym_nointerpolation] = ACTIONS(5308),
    [anon_sym_sample] = ACTIONS(5308),
    [anon_sym_linear] = ACTIONS(5308),
    [anon_sym_snorm] = ACTIONS(5308),
    [anon_sym_unorm] = ACTIONS(5308),
    [anon_sym_point] = ACTIONS(5308),
    [anon_sym_line] = ACTIONS(5308),
    [anon_sym_triangleadj] = ACTIONS(5308),
    [anon_sym_lineadj] = ACTIONS(5308),
    [anon_sym_triangle] = ACTIONS(5308),
  },
  [2226] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2197),
    [sym_identifier] = ACTIONS(5312),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5315),
    [anon_sym_COMMA] = ACTIONS(5315),
    [anon_sym_RPAREN] = ACTIONS(5315),
    [anon_sym_LPAREN2] = ACTIONS(5315),
    [anon_sym_TILDE] = ACTIONS(5315),
    [anon_sym_STAR] = ACTIONS(5315),
    [anon_sym_AMP_AMP] = ACTIONS(5315),
    [anon_sym_AMP] = ACTIONS(5312),
    [anon_sym_COLON] = ACTIONS(5312),
    [anon_sym_SEMI] = ACTIONS(5315),
    [anon_sym___extension__] = ACTIONS(5312),
    [anon_sym_in] = ACTIONS(5312),
    [anon_sym_out] = ACTIONS(5312),
    [anon_sym_inout] = ACTIONS(5312),
    [anon_sym_extern] = ACTIONS(5312),
    [anon_sym___attribute__] = ACTIONS(5312),
    [anon_sym_COLON_COLON] = ACTIONS(5315),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5315),
    [anon_sym___declspec] = ACTIONS(5312),
    [anon_sym___based] = ACTIONS(5312),
    [anon_sym___cdecl] = ACTIONS(5312),
    [anon_sym___clrcall] = ACTIONS(5312),
    [anon_sym___stdcall] = ACTIONS(5312),
    [anon_sym___fastcall] = ACTIONS(5312),
    [anon_sym___thiscall] = ACTIONS(5312),
    [anon_sym___vectorcall] = ACTIONS(5312),
    [anon_sym_LBRACE] = ACTIONS(5315),
    [anon_sym_signed] = ACTIONS(5228),
    [anon_sym_unsigned] = ACTIONS(5228),
    [anon_sym_long] = ACTIONS(5228),
    [anon_sym_short] = ACTIONS(5228),
    [anon_sym_LBRACK] = ACTIONS(5312),
    [anon_sym_static] = ACTIONS(5312),
    [anon_sym_EQ] = ACTIONS(5315),
    [anon_sym_register] = ACTIONS(5312),
    [anon_sym_inline] = ACTIONS(5312),
    [anon_sym___inline] = ACTIONS(5312),
    [anon_sym___inline__] = ACTIONS(5312),
    [anon_sym___forceinline] = ACTIONS(5312),
    [anon_sym_thread_local] = ACTIONS(5312),
    [anon_sym___thread] = ACTIONS(5312),
    [anon_sym_const] = ACTIONS(5312),
    [anon_sym_constexpr] = ACTIONS(5312),
    [anon_sym_volatile] = ACTIONS(5312),
    [anon_sym_restrict] = ACTIONS(5312),
    [anon_sym___restrict__] = ACTIONS(5312),
    [anon_sym__Atomic] = ACTIONS(5312),
    [anon_sym__Noreturn] = ACTIONS(5312),
    [anon_sym_noreturn] = ACTIONS(5312),
    [anon_sym_mutable] = ACTIONS(5312),
    [anon_sym_constinit] = ACTIONS(5312),
    [anon_sym_consteval] = ACTIONS(5312),
    [anon_sym_alignas] = ACTIONS(5312),
    [anon_sym__Alignas] = ACTIONS(5312),
    [sym_primitive_type] = ACTIONS(5224),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5312),
    [anon_sym_decltype] = ACTIONS(5312),
    [sym_virtual] = ACTIONS(5312),
    [anon_sym_template] = ACTIONS(5312),
    [anon_sym_GT2] = ACTIONS(5315),
    [anon_sym_operator] = ACTIONS(5312),
    [anon_sym_precise] = ACTIONS(5312),
    [anon_sym_shared] = ACTIONS(5312),
    [anon_sym_groupshared] = ACTIONS(5312),
    [anon_sym_uniform] = ACTIONS(5312),
    [anon_sym_row_major] = ACTIONS(5312),
    [anon_sym_column_major] = ACTIONS(5312),
    [anon_sym_globallycoherent] = ACTIONS(5312),
    [anon_sym_centroid] = ACTIONS(5312),
    [anon_sym_noperspective] = ACTIONS(5312),
    [anon_sym_nointerpolation] = ACTIONS(5312),
    [anon_sym_sample] = ACTIONS(5312),
    [anon_sym_linear] = ACTIONS(5312),
    [anon_sym_snorm] = ACTIONS(5312),
    [anon_sym_unorm] = ACTIONS(5312),
    [anon_sym_point] = ACTIONS(5312),
    [anon_sym_line] = ACTIONS(5312),
    [anon_sym_triangleadj] = ACTIONS(5312),
    [anon_sym_lineadj] = ACTIONS(5312),
    [anon_sym_triangle] = ACTIONS(5312),
  },
  [2227] = {
    [sym_argument_list] = STATE(2805),
    [sym_initializer_list] = STATE(4005),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2240),
    [sym_identifier] = ACTIONS(5318),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5320),
    [anon_sym_COMMA] = ACTIONS(5320),
    [anon_sym_RPAREN] = ACTIONS(5320),
    [anon_sym_LPAREN2] = ACTIONS(5322),
    [anon_sym_TILDE] = ACTIONS(5320),
    [anon_sym_STAR] = ACTIONS(5320),
    [anon_sym_AMP_AMP] = ACTIONS(5320),
    [anon_sym_AMP] = ACTIONS(5318),
    [anon_sym_COLON] = ACTIONS(5318),
    [anon_sym_SEMI] = ACTIONS(5320),
    [anon_sym___extension__] = ACTIONS(5318),
    [anon_sym_in] = ACTIONS(5318),
    [anon_sym_out] = ACTIONS(5318),
    [anon_sym_inout] = ACTIONS(5318),
    [anon_sym_extern] = ACTIONS(5318),
    [anon_sym___attribute__] = ACTIONS(5318),
    [anon_sym_COLON_COLON] = ACTIONS(5320),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5320),
    [anon_sym___declspec] = ACTIONS(5318),
    [anon_sym___based] = ACTIONS(5318),
    [anon_sym___cdecl] = ACTIONS(5318),
    [anon_sym___clrcall] = ACTIONS(5318),
    [anon_sym___stdcall] = ACTIONS(5318),
    [anon_sym___fastcall] = ACTIONS(5318),
    [anon_sym___thiscall] = ACTIONS(5318),
    [anon_sym___vectorcall] = ACTIONS(5318),
    [anon_sym_LBRACE] = ACTIONS(3952),
    [anon_sym_signed] = ACTIONS(5325),
    [anon_sym_unsigned] = ACTIONS(5325),
    [anon_sym_long] = ACTIONS(5325),
    [anon_sym_short] = ACTIONS(5325),
    [anon_sym_LBRACK] = ACTIONS(5318),
    [anon_sym_static] = ACTIONS(5318),
    [anon_sym_EQ] = ACTIONS(5320),
    [anon_sym_register] = ACTIONS(5318),
    [anon_sym_inline] = ACTIONS(5318),
    [anon_sym___inline] = ACTIONS(5318),
    [anon_sym___inline__] = ACTIONS(5318),
    [anon_sym___forceinline] = ACTIONS(5318),
    [anon_sym_thread_local] = ACTIONS(5318),
    [anon_sym___thread] = ACTIONS(5318),
    [anon_sym_const] = ACTIONS(5318),
    [anon_sym_constexpr] = ACTIONS(5318),
    [anon_sym_volatile] = ACTIONS(5318),
    [anon_sym_restrict] = ACTIONS(5318),
    [anon_sym___restrict__] = ACTIONS(5318),
    [anon_sym__Atomic] = ACTIONS(5318),
    [anon_sym__Noreturn] = ACTIONS(5318),
    [anon_sym_noreturn] = ACTIONS(5318),
    [anon_sym_mutable] = ACTIONS(5318),
    [anon_sym_constinit] = ACTIONS(5318),
    [anon_sym_consteval] = ACTIONS(5318),
    [anon_sym_alignas] = ACTIONS(5318),
    [anon_sym__Alignas] = ACTIONS(5318),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5318),
    [anon_sym_decltype] = ACTIONS(5318),
    [sym_virtual] = ACTIONS(5318),
    [anon_sym_template] = ACTIONS(5318),
    [anon_sym_operator] = ACTIONS(5318),
    [anon_sym_precise] = ACTIONS(5318),
    [anon_sym_shared] = ACTIONS(5318),
    [anon_sym_groupshared] = ACTIONS(5318),
    [anon_sym_uniform] = ACTIONS(5318),
    [anon_sym_row_major] = ACTIONS(5318),
    [anon_sym_column_major] = ACTIONS(5318),
    [anon_sym_globallycoherent] = ACTIONS(5318),
    [anon_sym_centroid] = ACTIONS(5318),
    [anon_sym_noperspective] = ACTIONS(5318),
    [anon_sym_nointerpolation] = ACTIONS(5318),
    [anon_sym_sample] = ACTIONS(5318),
    [anon_sym_linear] = ACTIONS(5318),
    [anon_sym_snorm] = ACTIONS(5318),
    [anon_sym_unorm] = ACTIONS(5318),
    [anon_sym_point] = ACTIONS(5318),
    [anon_sym_line] = ACTIONS(5318),
    [anon_sym_triangleadj] = ACTIONS(5318),
    [anon_sym_lineadj] = ACTIONS(5318),
    [anon_sym_triangle] = ACTIONS(5318),
  },
  [2228] = {
    [sym_identifier] = ACTIONS(1953),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1955),
    [anon_sym_COMMA] = ACTIONS(1955),
    [anon_sym_RPAREN] = ACTIONS(1955),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_TILDE] = ACTIONS(1955),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_PIPE_PIPE] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym_COLON] = ACTIONS(1953),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym_in] = ACTIONS(1953),
    [anon_sym_out] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1953),
    [anon_sym_extern] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1955),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1955),
    [anon_sym___declspec] = ACTIONS(1953),
    [anon_sym___based] = ACTIONS(1953),
    [anon_sym___cdecl] = ACTIONS(1953),
    [anon_sym___clrcall] = ACTIONS(1953),
    [anon_sym___stdcall] = ACTIONS(1953),
    [anon_sym___fastcall] = ACTIONS(1953),
    [anon_sym___thiscall] = ACTIONS(1953),
    [anon_sym___vectorcall] = ACTIONS(1953),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_LBRACK] = ACTIONS(1953),
    [anon_sym_static] = ACTIONS(1953),
    [anon_sym_EQ] = ACTIONS(1955),
    [anon_sym_register] = ACTIONS(1953),
    [anon_sym_inline] = ACTIONS(1953),
    [anon_sym___inline] = ACTIONS(1953),
    [anon_sym___inline__] = ACTIONS(1953),
    [anon_sym___forceinline] = ACTIONS(1953),
    [anon_sym_thread_local] = ACTIONS(1953),
    [anon_sym___thread] = ACTIONS(1953),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [anon_sym_or] = ACTIONS(1953),
    [anon_sym_and] = ACTIONS(1953),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
    [sym_virtual] = ACTIONS(1953),
    [anon_sym_template] = ACTIONS(1953),
    [anon_sym_GT2] = ACTIONS(1955),
    [anon_sym_operator] = ACTIONS(1953),
    [anon_sym_requires] = ACTIONS(1953),
    [anon_sym_precise] = ACTIONS(1953),
    [anon_sym_shared] = ACTIONS(1953),
    [anon_sym_groupshared] = ACTIONS(1953),
    [anon_sym_uniform] = ACTIONS(1953),
    [anon_sym_row_major] = ACTIONS(1953),
    [anon_sym_column_major] = ACTIONS(1953),
    [anon_sym_globallycoherent] = ACTIONS(1953),
    [anon_sym_centroid] = ACTIONS(1953),
    [anon_sym_noperspective] = ACTIONS(1953),
    [anon_sym_nointerpolation] = ACTIONS(1953),
    [anon_sym_sample] = ACTIONS(1953),
    [anon_sym_linear] = ACTIONS(1953),
    [anon_sym_snorm] = ACTIONS(1953),
    [anon_sym_unorm] = ACTIONS(1953),
    [anon_sym_point] = ACTIONS(1953),
    [anon_sym_line] = ACTIONS(1953),
    [anon_sym_triangleadj] = ACTIONS(1953),
    [anon_sym_lineadj] = ACTIONS(1953),
    [anon_sym_triangle] = ACTIONS(1953),
  },
  [2229] = {
    [sym_attribute_specifier] = STATE(2286),
    [sym_field_declaration_list] = STATE(2320),
    [sym_virtual_specifier] = STATE(6832),
    [sym_base_class_clause] = STATE(7803),
    [sym_identifier] = ACTIONS(5327),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5329),
    [anon_sym_COMMA] = ACTIONS(5329),
    [anon_sym_RPAREN] = ACTIONS(5329),
    [anon_sym_LPAREN2] = ACTIONS(5329),
    [anon_sym_TILDE] = ACTIONS(5329),
    [anon_sym_STAR] = ACTIONS(5329),
    [anon_sym_AMP_AMP] = ACTIONS(5329),
    [anon_sym_AMP] = ACTIONS(5327),
    [anon_sym_COLON] = ACTIONS(1911),
    [anon_sym_SEMI] = ACTIONS(5329),
    [anon_sym___extension__] = ACTIONS(5327),
    [anon_sym_in] = ACTIONS(5327),
    [anon_sym_out] = ACTIONS(5327),
    [anon_sym_inout] = ACTIONS(5327),
    [anon_sym_extern] = ACTIONS(5327),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5329),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5329),
    [anon_sym___declspec] = ACTIONS(5327),
    [anon_sym___based] = ACTIONS(5327),
    [anon_sym___cdecl] = ACTIONS(5327),
    [anon_sym___clrcall] = ACTIONS(5327),
    [anon_sym___stdcall] = ACTIONS(5327),
    [anon_sym___fastcall] = ACTIONS(5327),
    [anon_sym___thiscall] = ACTIONS(5327),
    [anon_sym___vectorcall] = ACTIONS(5327),
    [anon_sym_LBRACE] = ACTIONS(5331),
    [anon_sym_LBRACK] = ACTIONS(5327),
    [anon_sym_static] = ACTIONS(5327),
    [anon_sym_EQ] = ACTIONS(5329),
    [anon_sym_register] = ACTIONS(5327),
    [anon_sym_inline] = ACTIONS(5327),
    [anon_sym___inline] = ACTIONS(5327),
    [anon_sym___inline__] = ACTIONS(5327),
    [anon_sym___forceinline] = ACTIONS(5327),
    [anon_sym_thread_local] = ACTIONS(5327),
    [anon_sym___thread] = ACTIONS(5327),
    [anon_sym_const] = ACTIONS(5327),
    [anon_sym_constexpr] = ACTIONS(5327),
    [anon_sym_volatile] = ACTIONS(5327),
    [anon_sym_restrict] = ACTIONS(5327),
    [anon_sym___restrict__] = ACTIONS(5327),
    [anon_sym__Atomic] = ACTIONS(5327),
    [anon_sym__Noreturn] = ACTIONS(5327),
    [anon_sym_noreturn] = ACTIONS(5327),
    [anon_sym_mutable] = ACTIONS(5327),
    [anon_sym_constinit] = ACTIONS(5327),
    [anon_sym_consteval] = ACTIONS(5327),
    [anon_sym_alignas] = ACTIONS(5327),
    [anon_sym__Alignas] = ACTIONS(5327),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5327),
    [anon_sym_decltype] = ACTIONS(5327),
    [anon_sym_final] = ACTIONS(1915),
    [anon_sym_override] = ACTIONS(1915),
    [sym_virtual] = ACTIONS(5327),
    [anon_sym_template] = ACTIONS(5327),
    [anon_sym_GT2] = ACTIONS(5329),
    [anon_sym_operator] = ACTIONS(5327),
    [anon_sym_precise] = ACTIONS(5327),
    [anon_sym_shared] = ACTIONS(5327),
    [anon_sym_groupshared] = ACTIONS(5327),
    [anon_sym_uniform] = ACTIONS(5327),
    [anon_sym_row_major] = ACTIONS(5327),
    [anon_sym_column_major] = ACTIONS(5327),
    [anon_sym_globallycoherent] = ACTIONS(5327),
    [anon_sym_centroid] = ACTIONS(5327),
    [anon_sym_noperspective] = ACTIONS(5327),
    [anon_sym_nointerpolation] = ACTIONS(5327),
    [anon_sym_sample] = ACTIONS(5327),
    [anon_sym_linear] = ACTIONS(5327),
    [anon_sym_snorm] = ACTIONS(5327),
    [anon_sym_unorm] = ACTIONS(5327),
    [anon_sym_point] = ACTIONS(5327),
    [anon_sym_line] = ACTIONS(5327),
    [anon_sym_triangleadj] = ACTIONS(5327),
    [anon_sym_lineadj] = ACTIONS(5327),
    [anon_sym_triangle] = ACTIONS(5327),
  },
  [2230] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2226),
    [sym_identifier] = ACTIONS(5333),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5336),
    [anon_sym_COMMA] = ACTIONS(5336),
    [anon_sym_RPAREN] = ACTIONS(5336),
    [anon_sym_LPAREN2] = ACTIONS(5336),
    [anon_sym_TILDE] = ACTIONS(5336),
    [anon_sym_STAR] = ACTIONS(5336),
    [anon_sym_AMP_AMP] = ACTIONS(5336),
    [anon_sym_AMP] = ACTIONS(5338),
    [anon_sym_COLON] = ACTIONS(5338),
    [anon_sym_SEMI] = ACTIONS(5336),
    [anon_sym___extension__] = ACTIONS(5338),
    [anon_sym_in] = ACTIONS(5338),
    [anon_sym_out] = ACTIONS(5338),
    [anon_sym_inout] = ACTIONS(5338),
    [anon_sym_extern] = ACTIONS(5338),
    [anon_sym___attribute__] = ACTIONS(5338),
    [anon_sym_COLON_COLON] = ACTIONS(5336),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5336),
    [anon_sym___declspec] = ACTIONS(5338),
    [anon_sym___based] = ACTIONS(5338),
    [anon_sym___cdecl] = ACTIONS(5338),
    [anon_sym___clrcall] = ACTIONS(5338),
    [anon_sym___stdcall] = ACTIONS(5338),
    [anon_sym___fastcall] = ACTIONS(5338),
    [anon_sym___thiscall] = ACTIONS(5338),
    [anon_sym___vectorcall] = ACTIONS(5338),
    [anon_sym_LBRACE] = ACTIONS(5336),
    [anon_sym_signed] = ACTIONS(5340),
    [anon_sym_unsigned] = ACTIONS(5340),
    [anon_sym_long] = ACTIONS(5340),
    [anon_sym_short] = ACTIONS(5340),
    [anon_sym_LBRACK] = ACTIONS(5338),
    [anon_sym_static] = ACTIONS(5338),
    [anon_sym_EQ] = ACTIONS(5336),
    [anon_sym_register] = ACTIONS(5338),
    [anon_sym_inline] = ACTIONS(5338),
    [anon_sym___inline] = ACTIONS(5338),
    [anon_sym___inline__] = ACTIONS(5338),
    [anon_sym___forceinline] = ACTIONS(5338),
    [anon_sym_thread_local] = ACTIONS(5338),
    [anon_sym___thread] = ACTIONS(5338),
    [anon_sym_const] = ACTIONS(5338),
    [anon_sym_constexpr] = ACTIONS(5338),
    [anon_sym_volatile] = ACTIONS(5338),
    [anon_sym_restrict] = ACTIONS(5338),
    [anon_sym___restrict__] = ACTIONS(5338),
    [anon_sym__Atomic] = ACTIONS(5338),
    [anon_sym__Noreturn] = ACTIONS(5338),
    [anon_sym_noreturn] = ACTIONS(5338),
    [anon_sym_mutable] = ACTIONS(5338),
    [anon_sym_constinit] = ACTIONS(5338),
    [anon_sym_consteval] = ACTIONS(5338),
    [anon_sym_alignas] = ACTIONS(5338),
    [anon_sym__Alignas] = ACTIONS(5338),
    [sym_primitive_type] = ACTIONS(5342),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5338),
    [anon_sym_decltype] = ACTIONS(5338),
    [sym_virtual] = ACTIONS(5338),
    [anon_sym_template] = ACTIONS(5338),
    [anon_sym_GT2] = ACTIONS(5336),
    [anon_sym_operator] = ACTIONS(5338),
    [anon_sym_precise] = ACTIONS(5338),
    [anon_sym_shared] = ACTIONS(5338),
    [anon_sym_groupshared] = ACTIONS(5338),
    [anon_sym_uniform] = ACTIONS(5338),
    [anon_sym_row_major] = ACTIONS(5338),
    [anon_sym_column_major] = ACTIONS(5338),
    [anon_sym_globallycoherent] = ACTIONS(5338),
    [anon_sym_centroid] = ACTIONS(5338),
    [anon_sym_noperspective] = ACTIONS(5338),
    [anon_sym_nointerpolation] = ACTIONS(5338),
    [anon_sym_sample] = ACTIONS(5338),
    [anon_sym_linear] = ACTIONS(5338),
    [anon_sym_snorm] = ACTIONS(5338),
    [anon_sym_unorm] = ACTIONS(5338),
    [anon_sym_point] = ACTIONS(5338),
    [anon_sym_line] = ACTIONS(5338),
    [anon_sym_triangleadj] = ACTIONS(5338),
    [anon_sym_lineadj] = ACTIONS(5338),
    [anon_sym_triangle] = ACTIONS(5338),
  },
  [2231] = {
    [sym_identifier] = ACTIONS(1895),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1897),
    [anon_sym_COMMA] = ACTIONS(1897),
    [anon_sym_RPAREN] = ACTIONS(1897),
    [aux_sym_preproc_if_token2] = ACTIONS(1897),
    [aux_sym_preproc_else_token1] = ACTIONS(1897),
    [aux_sym_preproc_elif_token1] = ACTIONS(1895),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1897),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1897),
    [anon_sym_LPAREN2] = ACTIONS(1897),
    [anon_sym_DASH] = ACTIONS(1895),
    [anon_sym_PLUS] = ACTIONS(1895),
    [anon_sym_STAR] = ACTIONS(1895),
    [anon_sym_SLASH] = ACTIONS(1895),
    [anon_sym_PERCENT] = ACTIONS(1895),
    [anon_sym_PIPE_PIPE] = ACTIONS(1897),
    [anon_sym_AMP_AMP] = ACTIONS(1897),
    [anon_sym_PIPE] = ACTIONS(1895),
    [anon_sym_CARET] = ACTIONS(1895),
    [anon_sym_AMP] = ACTIONS(1895),
    [anon_sym_EQ_EQ] = ACTIONS(1897),
    [anon_sym_BANG_EQ] = ACTIONS(1897),
    [anon_sym_GT] = ACTIONS(1895),
    [anon_sym_GT_EQ] = ACTIONS(1897),
    [anon_sym_LT_EQ] = ACTIONS(1895),
    [anon_sym_LT] = ACTIONS(1895),
    [anon_sym_LT_LT] = ACTIONS(1895),
    [anon_sym_GT_GT] = ACTIONS(1895),
    [anon_sym_COLON] = ACTIONS(1895),
    [anon_sym_SEMI] = ACTIONS(1897),
    [anon_sym___extension__] = ACTIONS(1895),
    [anon_sym___attribute__] = ACTIONS(1895),
    [anon_sym_COLON_COLON] = ACTIONS(1897),
    [anon_sym_LBRACE] = ACTIONS(1897),
    [anon_sym_RBRACE] = ACTIONS(1897),
    [anon_sym_LBRACK] = ACTIONS(1897),
    [anon_sym_RBRACK] = ACTIONS(1897),
    [anon_sym_EQ] = ACTIONS(1895),
    [anon_sym_const] = ACTIONS(1895),
    [anon_sym_constexpr] = ACTIONS(1895),
    [anon_sym_volatile] = ACTIONS(1895),
    [anon_sym_restrict] = ACTIONS(1895),
    [anon_sym___restrict__] = ACTIONS(1895),
    [anon_sym__Atomic] = ACTIONS(1895),
    [anon_sym__Noreturn] = ACTIONS(1895),
    [anon_sym_noreturn] = ACTIONS(1895),
    [anon_sym_mutable] = ACTIONS(1895),
    [anon_sym_constinit] = ACTIONS(1895),
    [anon_sym_consteval] = ACTIONS(1895),
    [anon_sym_alignas] = ACTIONS(1895),
    [anon_sym__Alignas] = ACTIONS(1895),
    [anon_sym_QMARK] = ACTIONS(1897),
    [anon_sym_STAR_EQ] = ACTIONS(1897),
    [anon_sym_SLASH_EQ] = ACTIONS(1897),
    [anon_sym_PERCENT_EQ] = ACTIONS(1897),
    [anon_sym_PLUS_EQ] = ACTIONS(1897),
    [anon_sym_DASH_EQ] = ACTIONS(1897),
    [anon_sym_LT_LT_EQ] = ACTIONS(1897),
    [anon_sym_GT_GT_EQ] = ACTIONS(1897),
    [anon_sym_AMP_EQ] = ACTIONS(1897),
    [anon_sym_CARET_EQ] = ACTIONS(1897),
    [anon_sym_PIPE_EQ] = ACTIONS(1897),
    [anon_sym_and_eq] = ACTIONS(1895),
    [anon_sym_or_eq] = ACTIONS(1895),
    [anon_sym_xor_eq] = ACTIONS(1895),
    [anon_sym_LT_EQ_GT] = ACTIONS(1897),
    [anon_sym_or] = ACTIONS(1895),
    [anon_sym_and] = ACTIONS(1895),
    [anon_sym_bitor] = ACTIONS(1895),
    [anon_sym_xor] = ACTIONS(1895),
    [anon_sym_bitand] = ACTIONS(1895),
    [anon_sym_not_eq] = ACTIONS(1895),
    [anon_sym_DASH_DASH] = ACTIONS(1897),
    [anon_sym_PLUS_PLUS] = ACTIONS(1897),
    [anon_sym_DOT] = ACTIONS(1895),
    [anon_sym_DOT_STAR] = ACTIONS(1897),
    [anon_sym_DASH_GT] = ACTIONS(1897),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1895),
    [anon_sym_decltype] = ACTIONS(1895),
    [anon_sym_final] = ACTIONS(1895),
    [anon_sym_override] = ACTIONS(1895),
  },
  [2232] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2232),
    [sym_identifier] = ACTIONS(5224),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5226),
    [anon_sym_COMMA] = ACTIONS(5226),
    [anon_sym_RPAREN] = ACTIONS(5226),
    [anon_sym_LPAREN2] = ACTIONS(5226),
    [anon_sym_TILDE] = ACTIONS(5226),
    [anon_sym_STAR] = ACTIONS(5226),
    [anon_sym_AMP_AMP] = ACTIONS(5226),
    [anon_sym_AMP] = ACTIONS(5224),
    [anon_sym_COLON] = ACTIONS(5224),
    [anon_sym_SEMI] = ACTIONS(5226),
    [anon_sym___extension__] = ACTIONS(5224),
    [anon_sym_in] = ACTIONS(5224),
    [anon_sym_out] = ACTIONS(5224),
    [anon_sym_inout] = ACTIONS(5224),
    [anon_sym_extern] = ACTIONS(5224),
    [anon_sym___attribute__] = ACTIONS(5224),
    [anon_sym_COLON_COLON] = ACTIONS(5226),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5226),
    [anon_sym___declspec] = ACTIONS(5224),
    [anon_sym___based] = ACTIONS(5224),
    [anon_sym___cdecl] = ACTIONS(5224),
    [anon_sym___clrcall] = ACTIONS(5224),
    [anon_sym___stdcall] = ACTIONS(5224),
    [anon_sym___fastcall] = ACTIONS(5224),
    [anon_sym___thiscall] = ACTIONS(5224),
    [anon_sym___vectorcall] = ACTIONS(5224),
    [anon_sym_LBRACE] = ACTIONS(5226),
    [anon_sym_signed] = ACTIONS(5344),
    [anon_sym_unsigned] = ACTIONS(5344),
    [anon_sym_long] = ACTIONS(5344),
    [anon_sym_short] = ACTIONS(5344),
    [anon_sym_LBRACK] = ACTIONS(5224),
    [anon_sym_static] = ACTIONS(5224),
    [anon_sym_EQ] = ACTIONS(5226),
    [anon_sym_register] = ACTIONS(5224),
    [anon_sym_inline] = ACTIONS(5224),
    [anon_sym___inline] = ACTIONS(5224),
    [anon_sym___inline__] = ACTIONS(5224),
    [anon_sym___forceinline] = ACTIONS(5224),
    [anon_sym_thread_local] = ACTIONS(5224),
    [anon_sym___thread] = ACTIONS(5224),
    [anon_sym_const] = ACTIONS(5224),
    [anon_sym_constexpr] = ACTIONS(5224),
    [anon_sym_volatile] = ACTIONS(5224),
    [anon_sym_restrict] = ACTIONS(5224),
    [anon_sym___restrict__] = ACTIONS(5224),
    [anon_sym__Atomic] = ACTIONS(5224),
    [anon_sym__Noreturn] = ACTIONS(5224),
    [anon_sym_noreturn] = ACTIONS(5224),
    [anon_sym_mutable] = ACTIONS(5224),
    [anon_sym_constinit] = ACTIONS(5224),
    [anon_sym_consteval] = ACTIONS(5224),
    [anon_sym_alignas] = ACTIONS(5224),
    [anon_sym__Alignas] = ACTIONS(5224),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5224),
    [anon_sym_decltype] = ACTIONS(5224),
    [sym_virtual] = ACTIONS(5224),
    [anon_sym_template] = ACTIONS(5224),
    [anon_sym_GT2] = ACTIONS(5226),
    [anon_sym_operator] = ACTIONS(5224),
    [anon_sym_precise] = ACTIONS(5224),
    [anon_sym_shared] = ACTIONS(5224),
    [anon_sym_groupshared] = ACTIONS(5224),
    [anon_sym_uniform] = ACTIONS(5224),
    [anon_sym_row_major] = ACTIONS(5224),
    [anon_sym_column_major] = ACTIONS(5224),
    [anon_sym_globallycoherent] = ACTIONS(5224),
    [anon_sym_centroid] = ACTIONS(5224),
    [anon_sym_noperspective] = ACTIONS(5224),
    [anon_sym_nointerpolation] = ACTIONS(5224),
    [anon_sym_sample] = ACTIONS(5224),
    [anon_sym_linear] = ACTIONS(5224),
    [anon_sym_snorm] = ACTIONS(5224),
    [anon_sym_unorm] = ACTIONS(5224),
    [anon_sym_point] = ACTIONS(5224),
    [anon_sym_line] = ACTIONS(5224),
    [anon_sym_triangleadj] = ACTIONS(5224),
    [anon_sym_lineadj] = ACTIONS(5224),
    [anon_sym_triangle] = ACTIONS(5224),
  },
  [2233] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2232),
    [sym_identifier] = ACTIONS(5347),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5349),
    [anon_sym_COMMA] = ACTIONS(5349),
    [anon_sym_RPAREN] = ACTIONS(5349),
    [anon_sym_LPAREN2] = ACTIONS(5349),
    [anon_sym_TILDE] = ACTIONS(5349),
    [anon_sym_STAR] = ACTIONS(5349),
    [anon_sym_AMP_AMP] = ACTIONS(5349),
    [anon_sym_AMP] = ACTIONS(5347),
    [anon_sym_COLON] = ACTIONS(5347),
    [anon_sym_SEMI] = ACTIONS(5349),
    [anon_sym___extension__] = ACTIONS(5347),
    [anon_sym_in] = ACTIONS(5347),
    [anon_sym_out] = ACTIONS(5347),
    [anon_sym_inout] = ACTIONS(5347),
    [anon_sym_extern] = ACTIONS(5347),
    [anon_sym___attribute__] = ACTIONS(5347),
    [anon_sym_COLON_COLON] = ACTIONS(5349),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5349),
    [anon_sym___declspec] = ACTIONS(5347),
    [anon_sym___based] = ACTIONS(5347),
    [anon_sym___cdecl] = ACTIONS(5347),
    [anon_sym___clrcall] = ACTIONS(5347),
    [anon_sym___stdcall] = ACTIONS(5347),
    [anon_sym___fastcall] = ACTIONS(5347),
    [anon_sym___thiscall] = ACTIONS(5347),
    [anon_sym___vectorcall] = ACTIONS(5347),
    [anon_sym_LBRACE] = ACTIONS(5349),
    [anon_sym_signed] = ACTIONS(5351),
    [anon_sym_unsigned] = ACTIONS(5351),
    [anon_sym_long] = ACTIONS(5351),
    [anon_sym_short] = ACTIONS(5351),
    [anon_sym_LBRACK] = ACTIONS(5347),
    [anon_sym_static] = ACTIONS(5347),
    [anon_sym_EQ] = ACTIONS(5349),
    [anon_sym_register] = ACTIONS(5347),
    [anon_sym_inline] = ACTIONS(5347),
    [anon_sym___inline] = ACTIONS(5347),
    [anon_sym___inline__] = ACTIONS(5347),
    [anon_sym___forceinline] = ACTIONS(5347),
    [anon_sym_thread_local] = ACTIONS(5347),
    [anon_sym___thread] = ACTIONS(5347),
    [anon_sym_const] = ACTIONS(5347),
    [anon_sym_constexpr] = ACTIONS(5347),
    [anon_sym_volatile] = ACTIONS(5347),
    [anon_sym_restrict] = ACTIONS(5347),
    [anon_sym___restrict__] = ACTIONS(5347),
    [anon_sym__Atomic] = ACTIONS(5347),
    [anon_sym__Noreturn] = ACTIONS(5347),
    [anon_sym_noreturn] = ACTIONS(5347),
    [anon_sym_mutable] = ACTIONS(5347),
    [anon_sym_constinit] = ACTIONS(5347),
    [anon_sym_consteval] = ACTIONS(5347),
    [anon_sym_alignas] = ACTIONS(5347),
    [anon_sym__Alignas] = ACTIONS(5347),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5347),
    [anon_sym_decltype] = ACTIONS(5347),
    [sym_virtual] = ACTIONS(5347),
    [anon_sym_template] = ACTIONS(5347),
    [anon_sym_GT2] = ACTIONS(5349),
    [anon_sym_operator] = ACTIONS(5347),
    [anon_sym_precise] = ACTIONS(5347),
    [anon_sym_shared] = ACTIONS(5347),
    [anon_sym_groupshared] = ACTIONS(5347),
    [anon_sym_uniform] = ACTIONS(5347),
    [anon_sym_row_major] = ACTIONS(5347),
    [anon_sym_column_major] = ACTIONS(5347),
    [anon_sym_globallycoherent] = ACTIONS(5347),
    [anon_sym_centroid] = ACTIONS(5347),
    [anon_sym_noperspective] = ACTIONS(5347),
    [anon_sym_nointerpolation] = ACTIONS(5347),
    [anon_sym_sample] = ACTIONS(5347),
    [anon_sym_linear] = ACTIONS(5347),
    [anon_sym_snorm] = ACTIONS(5347),
    [anon_sym_unorm] = ACTIONS(5347),
    [anon_sym_point] = ACTIONS(5347),
    [anon_sym_line] = ACTIONS(5347),
    [anon_sym_triangleadj] = ACTIONS(5347),
    [anon_sym_lineadj] = ACTIONS(5347),
    [anon_sym_triangle] = ACTIONS(5347),
  },
  [2234] = {
    [sym_template_argument_list] = STATE(2221),
    [sym_identifier] = ACTIONS(1941),
    [anon_sym_RPAREN] = ACTIONS(1943),
    [anon_sym_LPAREN2] = ACTIONS(1943),
    [anon_sym_TILDE] = ACTIONS(1943),
    [anon_sym_STAR] = ACTIONS(1943),
    [anon_sym_PIPE_PIPE] = ACTIONS(1943),
    [anon_sym_AMP_AMP] = ACTIONS(1943),
    [anon_sym_AMP] = ACTIONS(1941),
    [anon_sym_LT] = ACTIONS(5298),
    [anon_sym_COLON] = ACTIONS(1941),
    [anon_sym_SEMI] = ACTIONS(1943),
    [anon_sym___extension__] = ACTIONS(1941),
    [anon_sym_in] = ACTIONS(1941),
    [anon_sym_out] = ACTIONS(1941),
    [anon_sym_inout] = ACTIONS(1941),
    [anon_sym_extern] = ACTIONS(1941),
    [anon_sym___attribute__] = ACTIONS(1941),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1943),
    [anon_sym___declspec] = ACTIONS(1941),
    [anon_sym___based] = ACTIONS(1941),
    [anon_sym___cdecl] = ACTIONS(1941),
    [anon_sym___clrcall] = ACTIONS(1941),
    [anon_sym___stdcall] = ACTIONS(1941),
    [anon_sym___fastcall] = ACTIONS(1941),
    [anon_sym___thiscall] = ACTIONS(1941),
    [anon_sym___vectorcall] = ACTIONS(1941),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_LBRACK] = ACTIONS(1941),
    [anon_sym_static] = ACTIONS(1941),
    [anon_sym_register] = ACTIONS(1941),
    [anon_sym_inline] = ACTIONS(1941),
    [anon_sym___inline] = ACTIONS(1941),
    [anon_sym___inline__] = ACTIONS(1941),
    [anon_sym___forceinline] = ACTIONS(1941),
    [anon_sym_thread_local] = ACTIONS(1941),
    [anon_sym___thread] = ACTIONS(1941),
    [anon_sym_const] = ACTIONS(1941),
    [anon_sym_constexpr] = ACTIONS(1941),
    [anon_sym_volatile] = ACTIONS(1941),
    [anon_sym_restrict] = ACTIONS(1941),
    [anon_sym___restrict__] = ACTIONS(1941),
    [anon_sym__Atomic] = ACTIONS(1941),
    [anon_sym__Noreturn] = ACTIONS(1941),
    [anon_sym_noreturn] = ACTIONS(1941),
    [anon_sym_mutable] = ACTIONS(1941),
    [anon_sym_constinit] = ACTIONS(1941),
    [anon_sym_consteval] = ACTIONS(1941),
    [anon_sym_alignas] = ACTIONS(1941),
    [anon_sym__Alignas] = ACTIONS(1941),
    [anon_sym_or] = ACTIONS(1941),
    [anon_sym_and] = ACTIONS(1941),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1941),
    [anon_sym_decltype] = ACTIONS(1941),
    [anon_sym_final] = ACTIONS(1941),
    [anon_sym_override] = ACTIONS(1941),
    [sym_virtual] = ACTIONS(1941),
    [anon_sym_template] = ACTIONS(1941),
    [anon_sym_operator] = ACTIONS(1941),
    [anon_sym_try] = ACTIONS(1941),
    [anon_sym_requires] = ACTIONS(1941),
    [anon_sym_precise] = ACTIONS(1941),
    [anon_sym_shared] = ACTIONS(1941),
    [anon_sym_groupshared] = ACTIONS(1941),
    [anon_sym_uniform] = ACTIONS(1941),
    [anon_sym_row_major] = ACTIONS(1941),
    [anon_sym_column_major] = ACTIONS(1941),
    [anon_sym_globallycoherent] = ACTIONS(1941),
    [anon_sym_centroid] = ACTIONS(1941),
    [anon_sym_noperspective] = ACTIONS(1941),
    [anon_sym_nointerpolation] = ACTIONS(1941),
    [anon_sym_sample] = ACTIONS(1941),
    [anon_sym_linear] = ACTIONS(1941),
    [anon_sym_snorm] = ACTIONS(1941),
    [anon_sym_unorm] = ACTIONS(1941),
    [anon_sym_point] = ACTIONS(1941),
    [anon_sym_line] = ACTIONS(1941),
    [anon_sym_triangleadj] = ACTIONS(1941),
    [anon_sym_lineadj] = ACTIONS(1941),
    [anon_sym_triangle] = ACTIONS(1941),
  },
  [2235] = {
    [sym_identifier] = ACTIONS(1903),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1905),
    [anon_sym_COMMA] = ACTIONS(1905),
    [anon_sym_RPAREN] = ACTIONS(1905),
    [aux_sym_preproc_if_token2] = ACTIONS(1905),
    [aux_sym_preproc_else_token1] = ACTIONS(1905),
    [aux_sym_preproc_elif_token1] = ACTIONS(1903),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1905),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1905),
    [anon_sym_LPAREN2] = ACTIONS(1905),
    [anon_sym_DASH] = ACTIONS(1903),
    [anon_sym_PLUS] = ACTIONS(1903),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_SLASH] = ACTIONS(1903),
    [anon_sym_PERCENT] = ACTIONS(1903),
    [anon_sym_PIPE_PIPE] = ACTIONS(1905),
    [anon_sym_AMP_AMP] = ACTIONS(1905),
    [anon_sym_PIPE] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1903),
    [anon_sym_AMP] = ACTIONS(1903),
    [anon_sym_EQ_EQ] = ACTIONS(1905),
    [anon_sym_BANG_EQ] = ACTIONS(1905),
    [anon_sym_GT] = ACTIONS(1903),
    [anon_sym_GT_EQ] = ACTIONS(1905),
    [anon_sym_LT_EQ] = ACTIONS(1903),
    [anon_sym_LT] = ACTIONS(1903),
    [anon_sym_LT_LT] = ACTIONS(1903),
    [anon_sym_GT_GT] = ACTIONS(1903),
    [anon_sym_COLON] = ACTIONS(1903),
    [anon_sym_SEMI] = ACTIONS(1905),
    [anon_sym___extension__] = ACTIONS(1903),
    [anon_sym___attribute__] = ACTIONS(1903),
    [anon_sym_COLON_COLON] = ACTIONS(1905),
    [anon_sym_LBRACE] = ACTIONS(1905),
    [anon_sym_RBRACE] = ACTIONS(1905),
    [anon_sym_LBRACK] = ACTIONS(1905),
    [anon_sym_RBRACK] = ACTIONS(1905),
    [anon_sym_EQ] = ACTIONS(1903),
    [anon_sym_const] = ACTIONS(1903),
    [anon_sym_constexpr] = ACTIONS(1903),
    [anon_sym_volatile] = ACTIONS(1903),
    [anon_sym_restrict] = ACTIONS(1903),
    [anon_sym___restrict__] = ACTIONS(1903),
    [anon_sym__Atomic] = ACTIONS(1903),
    [anon_sym__Noreturn] = ACTIONS(1903),
    [anon_sym_noreturn] = ACTIONS(1903),
    [anon_sym_mutable] = ACTIONS(1903),
    [anon_sym_constinit] = ACTIONS(1903),
    [anon_sym_consteval] = ACTIONS(1903),
    [anon_sym_alignas] = ACTIONS(1903),
    [anon_sym__Alignas] = ACTIONS(1903),
    [anon_sym_QMARK] = ACTIONS(1905),
    [anon_sym_STAR_EQ] = ACTIONS(1905),
    [anon_sym_SLASH_EQ] = ACTIONS(1905),
    [anon_sym_PERCENT_EQ] = ACTIONS(1905),
    [anon_sym_PLUS_EQ] = ACTIONS(1905),
    [anon_sym_DASH_EQ] = ACTIONS(1905),
    [anon_sym_LT_LT_EQ] = ACTIONS(1905),
    [anon_sym_GT_GT_EQ] = ACTIONS(1905),
    [anon_sym_AMP_EQ] = ACTIONS(1905),
    [anon_sym_CARET_EQ] = ACTIONS(1905),
    [anon_sym_PIPE_EQ] = ACTIONS(1905),
    [anon_sym_and_eq] = ACTIONS(1903),
    [anon_sym_or_eq] = ACTIONS(1903),
    [anon_sym_xor_eq] = ACTIONS(1903),
    [anon_sym_LT_EQ_GT] = ACTIONS(1905),
    [anon_sym_or] = ACTIONS(1903),
    [anon_sym_and] = ACTIONS(1903),
    [anon_sym_bitor] = ACTIONS(1903),
    [anon_sym_xor] = ACTIONS(1903),
    [anon_sym_bitand] = ACTIONS(1903),
    [anon_sym_not_eq] = ACTIONS(1903),
    [anon_sym_DASH_DASH] = ACTIONS(1905),
    [anon_sym_PLUS_PLUS] = ACTIONS(1905),
    [anon_sym_DOT] = ACTIONS(1903),
    [anon_sym_DOT_STAR] = ACTIONS(1905),
    [anon_sym_DASH_GT] = ACTIONS(1905),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1903),
    [anon_sym_decltype] = ACTIONS(1903),
    [anon_sym_final] = ACTIONS(1903),
    [anon_sym_override] = ACTIONS(1903),
  },
  [2236] = {
    [sym_identifier] = ACTIONS(1917),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1919),
    [anon_sym_COMMA] = ACTIONS(1919),
    [anon_sym_RPAREN] = ACTIONS(1919),
    [aux_sym_preproc_if_token2] = ACTIONS(1919),
    [aux_sym_preproc_else_token1] = ACTIONS(1919),
    [aux_sym_preproc_elif_token1] = ACTIONS(1917),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1919),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1919),
    [anon_sym_LPAREN2] = ACTIONS(1919),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1917),
    [anon_sym_SLASH] = ACTIONS(1917),
    [anon_sym_PERCENT] = ACTIONS(1917),
    [anon_sym_PIPE_PIPE] = ACTIONS(1919),
    [anon_sym_AMP_AMP] = ACTIONS(1919),
    [anon_sym_PIPE] = ACTIONS(1917),
    [anon_sym_CARET] = ACTIONS(1917),
    [anon_sym_AMP] = ACTIONS(1917),
    [anon_sym_EQ_EQ] = ACTIONS(1919),
    [anon_sym_BANG_EQ] = ACTIONS(1919),
    [anon_sym_GT] = ACTIONS(1917),
    [anon_sym_GT_EQ] = ACTIONS(1919),
    [anon_sym_LT_EQ] = ACTIONS(1917),
    [anon_sym_LT] = ACTIONS(1917),
    [anon_sym_LT_LT] = ACTIONS(1917),
    [anon_sym_GT_GT] = ACTIONS(1917),
    [anon_sym_COLON] = ACTIONS(1917),
    [anon_sym_SEMI] = ACTIONS(1919),
    [anon_sym___extension__] = ACTIONS(1917),
    [anon_sym___attribute__] = ACTIONS(1917),
    [anon_sym_COLON_COLON] = ACTIONS(1919),
    [anon_sym_LBRACE] = ACTIONS(1919),
    [anon_sym_RBRACE] = ACTIONS(1919),
    [anon_sym_LBRACK] = ACTIONS(1919),
    [anon_sym_RBRACK] = ACTIONS(1919),
    [anon_sym_EQ] = ACTIONS(1917),
    [anon_sym_const] = ACTIONS(1917),
    [anon_sym_constexpr] = ACTIONS(1917),
    [anon_sym_volatile] = ACTIONS(1917),
    [anon_sym_restrict] = ACTIONS(1917),
    [anon_sym___restrict__] = ACTIONS(1917),
    [anon_sym__Atomic] = ACTIONS(1917),
    [anon_sym__Noreturn] = ACTIONS(1917),
    [anon_sym_noreturn] = ACTIONS(1917),
    [anon_sym_mutable] = ACTIONS(1917),
    [anon_sym_constinit] = ACTIONS(1917),
    [anon_sym_consteval] = ACTIONS(1917),
    [anon_sym_alignas] = ACTIONS(1917),
    [anon_sym__Alignas] = ACTIONS(1917),
    [anon_sym_QMARK] = ACTIONS(1919),
    [anon_sym_STAR_EQ] = ACTIONS(1919),
    [anon_sym_SLASH_EQ] = ACTIONS(1919),
    [anon_sym_PERCENT_EQ] = ACTIONS(1919),
    [anon_sym_PLUS_EQ] = ACTIONS(1919),
    [anon_sym_DASH_EQ] = ACTIONS(1919),
    [anon_sym_LT_LT_EQ] = ACTIONS(1919),
    [anon_sym_GT_GT_EQ] = ACTIONS(1919),
    [anon_sym_AMP_EQ] = ACTIONS(1919),
    [anon_sym_CARET_EQ] = ACTIONS(1919),
    [anon_sym_PIPE_EQ] = ACTIONS(1919),
    [anon_sym_and_eq] = ACTIONS(1917),
    [anon_sym_or_eq] = ACTIONS(1917),
    [anon_sym_xor_eq] = ACTIONS(1917),
    [anon_sym_LT_EQ_GT] = ACTIONS(1919),
    [anon_sym_or] = ACTIONS(1917),
    [anon_sym_and] = ACTIONS(1917),
    [anon_sym_bitor] = ACTIONS(1917),
    [anon_sym_xor] = ACTIONS(1917),
    [anon_sym_bitand] = ACTIONS(1917),
    [anon_sym_not_eq] = ACTIONS(1917),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DOT] = ACTIONS(1917),
    [anon_sym_DOT_STAR] = ACTIONS(1919),
    [anon_sym_DASH_GT] = ACTIONS(1919),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1917),
    [anon_sym_decltype] = ACTIONS(1917),
    [anon_sym_final] = ACTIONS(1917),
    [anon_sym_override] = ACTIONS(1917),
  },
  [2237] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2240),
    [sym_identifier] = ACTIONS(5353),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5355),
    [anon_sym_COMMA] = ACTIONS(5355),
    [anon_sym_RPAREN] = ACTIONS(5355),
    [anon_sym_LPAREN2] = ACTIONS(5355),
    [anon_sym_TILDE] = ACTIONS(5355),
    [anon_sym_STAR] = ACTIONS(5355),
    [anon_sym_AMP_AMP] = ACTIONS(5355),
    [anon_sym_AMP] = ACTIONS(5353),
    [anon_sym_COLON] = ACTIONS(5353),
    [anon_sym_SEMI] = ACTIONS(5355),
    [anon_sym___extension__] = ACTIONS(5353),
    [anon_sym_in] = ACTIONS(5353),
    [anon_sym_out] = ACTIONS(5353),
    [anon_sym_inout] = ACTIONS(5353),
    [anon_sym_extern] = ACTIONS(5353),
    [anon_sym___attribute__] = ACTIONS(5353),
    [anon_sym_COLON_COLON] = ACTIONS(5355),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5355),
    [anon_sym___declspec] = ACTIONS(5353),
    [anon_sym___based] = ACTIONS(5353),
    [anon_sym___cdecl] = ACTIONS(5353),
    [anon_sym___clrcall] = ACTIONS(5353),
    [anon_sym___stdcall] = ACTIONS(5353),
    [anon_sym___fastcall] = ACTIONS(5353),
    [anon_sym___thiscall] = ACTIONS(5353),
    [anon_sym___vectorcall] = ACTIONS(5353),
    [anon_sym_LBRACE] = ACTIONS(5355),
    [anon_sym_signed] = ACTIONS(5325),
    [anon_sym_unsigned] = ACTIONS(5325),
    [anon_sym_long] = ACTIONS(5325),
    [anon_sym_short] = ACTIONS(5325),
    [anon_sym_LBRACK] = ACTIONS(5353),
    [anon_sym_static] = ACTIONS(5353),
    [anon_sym_EQ] = ACTIONS(5355),
    [anon_sym_register] = ACTIONS(5353),
    [anon_sym_inline] = ACTIONS(5353),
    [anon_sym___inline] = ACTIONS(5353),
    [anon_sym___inline__] = ACTIONS(5353),
    [anon_sym___forceinline] = ACTIONS(5353),
    [anon_sym_thread_local] = ACTIONS(5353),
    [anon_sym___thread] = ACTIONS(5353),
    [anon_sym_const] = ACTIONS(5353),
    [anon_sym_constexpr] = ACTIONS(5353),
    [anon_sym_volatile] = ACTIONS(5353),
    [anon_sym_restrict] = ACTIONS(5353),
    [anon_sym___restrict__] = ACTIONS(5353),
    [anon_sym__Atomic] = ACTIONS(5353),
    [anon_sym__Noreturn] = ACTIONS(5353),
    [anon_sym_noreturn] = ACTIONS(5353),
    [anon_sym_mutable] = ACTIONS(5353),
    [anon_sym_constinit] = ACTIONS(5353),
    [anon_sym_consteval] = ACTIONS(5353),
    [anon_sym_alignas] = ACTIONS(5353),
    [anon_sym__Alignas] = ACTIONS(5353),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5353),
    [anon_sym_decltype] = ACTIONS(5353),
    [sym_virtual] = ACTIONS(5353),
    [anon_sym_template] = ACTIONS(5353),
    [anon_sym_GT2] = ACTIONS(5355),
    [anon_sym_operator] = ACTIONS(5353),
    [anon_sym_precise] = ACTIONS(5353),
    [anon_sym_shared] = ACTIONS(5353),
    [anon_sym_groupshared] = ACTIONS(5353),
    [anon_sym_uniform] = ACTIONS(5353),
    [anon_sym_row_major] = ACTIONS(5353),
    [anon_sym_column_major] = ACTIONS(5353),
    [anon_sym_globallycoherent] = ACTIONS(5353),
    [anon_sym_centroid] = ACTIONS(5353),
    [anon_sym_noperspective] = ACTIONS(5353),
    [anon_sym_nointerpolation] = ACTIONS(5353),
    [anon_sym_sample] = ACTIONS(5353),
    [anon_sym_linear] = ACTIONS(5353),
    [anon_sym_snorm] = ACTIONS(5353),
    [anon_sym_unorm] = ACTIONS(5353),
    [anon_sym_point] = ACTIONS(5353),
    [anon_sym_line] = ACTIONS(5353),
    [anon_sym_triangleadj] = ACTIONS(5353),
    [anon_sym_lineadj] = ACTIONS(5353),
    [anon_sym_triangle] = ACTIONS(5353),
  },
  [2238] = {
    [sym_identifier] = ACTIONS(5357),
    [anon_sym_LPAREN2] = ACTIONS(5359),
    [anon_sym_STAR] = ACTIONS(5359),
    [anon_sym_AMP_AMP] = ACTIONS(5359),
    [anon_sym_AMP] = ACTIONS(5361),
    [anon_sym_LT] = ACTIONS(5359),
    [anon_sym___extension__] = ACTIONS(5357),
    [anon_sym_in] = ACTIONS(5357),
    [anon_sym_out] = ACTIONS(5357),
    [anon_sym_inout] = ACTIONS(5357),
    [anon_sym_extern] = ACTIONS(5357),
    [anon_sym___attribute__] = ACTIONS(5357),
    [anon_sym_COLON_COLON] = ACTIONS(5363),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5363),
    [anon_sym___declspec] = ACTIONS(5357),
    [anon_sym___cdecl] = ACTIONS(5357),
    [anon_sym___clrcall] = ACTIONS(5357),
    [anon_sym___stdcall] = ACTIONS(5357),
    [anon_sym___fastcall] = ACTIONS(5357),
    [anon_sym___thiscall] = ACTIONS(5357),
    [anon_sym___vectorcall] = ACTIONS(5357),
    [anon_sym_LBRACE] = ACTIONS(5359),
    [anon_sym_signed] = ACTIONS(5357),
    [anon_sym_unsigned] = ACTIONS(5357),
    [anon_sym_long] = ACTIONS(5357),
    [anon_sym_short] = ACTIONS(5357),
    [anon_sym_LBRACK] = ACTIONS(5361),
    [anon_sym_static] = ACTIONS(5357),
    [anon_sym_EQ] = ACTIONS(5365),
    [anon_sym_register] = ACTIONS(5357),
    [anon_sym_inline] = ACTIONS(5357),
    [anon_sym___inline] = ACTIONS(5357),
    [anon_sym___inline__] = ACTIONS(5357),
    [anon_sym___forceinline] = ACTIONS(5357),
    [anon_sym_thread_local] = ACTIONS(5357),
    [anon_sym___thread] = ACTIONS(5357),
    [anon_sym_const] = ACTIONS(5357),
    [anon_sym_constexpr] = ACTIONS(5357),
    [anon_sym_volatile] = ACTIONS(5357),
    [anon_sym_restrict] = ACTIONS(5357),
    [anon_sym___restrict__] = ACTIONS(5357),
    [anon_sym__Atomic] = ACTIONS(5357),
    [anon_sym__Noreturn] = ACTIONS(5357),
    [anon_sym_noreturn] = ACTIONS(5357),
    [anon_sym_mutable] = ACTIONS(5357),
    [anon_sym_constinit] = ACTIONS(5357),
    [anon_sym_consteval] = ACTIONS(5357),
    [anon_sym_alignas] = ACTIONS(5357),
    [anon_sym__Alignas] = ACTIONS(5357),
    [sym_primitive_type] = ACTIONS(5357),
    [anon_sym_enum] = ACTIONS(5357),
    [anon_sym_class] = ACTIONS(5357),
    [anon_sym_struct] = ACTIONS(5357),
    [anon_sym_union] = ACTIONS(5357),
    [anon_sym_if] = ACTIONS(5357),
    [anon_sym_for] = ACTIONS(5357),
    [anon_sym_DOT] = ACTIONS(5365),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5357),
    [anon_sym_decltype] = ACTIONS(5357),
    [sym_virtual] = ACTIONS(5357),
    [anon_sym_typename] = ACTIONS(5357),
    [anon_sym_template] = ACTIONS(5357),
    [anon_sym_precise] = ACTIONS(5357),
    [anon_sym_shared] = ACTIONS(5357),
    [anon_sym_groupshared] = ACTIONS(5357),
    [anon_sym_uniform] = ACTIONS(5357),
    [anon_sym_row_major] = ACTIONS(5357),
    [anon_sym_column_major] = ACTIONS(5357),
    [anon_sym_globallycoherent] = ACTIONS(5357),
    [anon_sym_centroid] = ACTIONS(5357),
    [anon_sym_noperspective] = ACTIONS(5357),
    [anon_sym_nointerpolation] = ACTIONS(5357),
    [anon_sym_sample] = ACTIONS(5357),
    [anon_sym_linear] = ACTIONS(5357),
    [anon_sym_snorm] = ACTIONS(5357),
    [anon_sym_unorm] = ACTIONS(5357),
    [anon_sym_point] = ACTIONS(5357),
    [anon_sym_line] = ACTIONS(5357),
    [anon_sym_triangleadj] = ACTIONS(5357),
    [anon_sym_lineadj] = ACTIONS(5357),
    [anon_sym_triangle] = ACTIONS(5357),
  },
  [2239] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2247),
    [sym_identifier] = ACTIONS(5367),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5369),
    [anon_sym_COMMA] = ACTIONS(5369),
    [anon_sym_RPAREN] = ACTIONS(5369),
    [anon_sym_LPAREN2] = ACTIONS(5369),
    [anon_sym_TILDE] = ACTIONS(5369),
    [anon_sym_STAR] = ACTIONS(5369),
    [anon_sym_AMP_AMP] = ACTIONS(5369),
    [anon_sym_AMP] = ACTIONS(5367),
    [anon_sym_COLON] = ACTIONS(5367),
    [anon_sym_SEMI] = ACTIONS(5369),
    [anon_sym___extension__] = ACTIONS(5367),
    [anon_sym_in] = ACTIONS(5367),
    [anon_sym_out] = ACTIONS(5367),
    [anon_sym_inout] = ACTIONS(5367),
    [anon_sym_extern] = ACTIONS(5367),
    [anon_sym___attribute__] = ACTIONS(5367),
    [anon_sym_COLON_COLON] = ACTIONS(5369),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5369),
    [anon_sym___declspec] = ACTIONS(5367),
    [anon_sym___based] = ACTIONS(5367),
    [anon_sym___cdecl] = ACTIONS(5367),
    [anon_sym___clrcall] = ACTIONS(5367),
    [anon_sym___stdcall] = ACTIONS(5367),
    [anon_sym___fastcall] = ACTIONS(5367),
    [anon_sym___thiscall] = ACTIONS(5367),
    [anon_sym___vectorcall] = ACTIONS(5367),
    [anon_sym_LBRACE] = ACTIONS(5369),
    [anon_sym_signed] = ACTIONS(5371),
    [anon_sym_unsigned] = ACTIONS(5371),
    [anon_sym_long] = ACTIONS(5371),
    [anon_sym_short] = ACTIONS(5371),
    [anon_sym_LBRACK] = ACTIONS(5367),
    [anon_sym_static] = ACTIONS(5367),
    [anon_sym_EQ] = ACTIONS(5369),
    [anon_sym_register] = ACTIONS(5367),
    [anon_sym_inline] = ACTIONS(5367),
    [anon_sym___inline] = ACTIONS(5367),
    [anon_sym___inline__] = ACTIONS(5367),
    [anon_sym___forceinline] = ACTIONS(5367),
    [anon_sym_thread_local] = ACTIONS(5367),
    [anon_sym___thread] = ACTIONS(5367),
    [anon_sym_const] = ACTIONS(5367),
    [anon_sym_constexpr] = ACTIONS(5367),
    [anon_sym_volatile] = ACTIONS(5367),
    [anon_sym_restrict] = ACTIONS(5367),
    [anon_sym___restrict__] = ACTIONS(5367),
    [anon_sym__Atomic] = ACTIONS(5367),
    [anon_sym__Noreturn] = ACTIONS(5367),
    [anon_sym_noreturn] = ACTIONS(5367),
    [anon_sym_mutable] = ACTIONS(5367),
    [anon_sym_constinit] = ACTIONS(5367),
    [anon_sym_consteval] = ACTIONS(5367),
    [anon_sym_alignas] = ACTIONS(5367),
    [anon_sym__Alignas] = ACTIONS(5367),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5367),
    [anon_sym_decltype] = ACTIONS(5367),
    [sym_virtual] = ACTIONS(5367),
    [anon_sym_template] = ACTIONS(5367),
    [anon_sym_GT2] = ACTIONS(5369),
    [anon_sym_operator] = ACTIONS(5367),
    [anon_sym_precise] = ACTIONS(5367),
    [anon_sym_shared] = ACTIONS(5367),
    [anon_sym_groupshared] = ACTIONS(5367),
    [anon_sym_uniform] = ACTIONS(5367),
    [anon_sym_row_major] = ACTIONS(5367),
    [anon_sym_column_major] = ACTIONS(5367),
    [anon_sym_globallycoherent] = ACTIONS(5367),
    [anon_sym_centroid] = ACTIONS(5367),
    [anon_sym_noperspective] = ACTIONS(5367),
    [anon_sym_nointerpolation] = ACTIONS(5367),
    [anon_sym_sample] = ACTIONS(5367),
    [anon_sym_linear] = ACTIONS(5367),
    [anon_sym_snorm] = ACTIONS(5367),
    [anon_sym_unorm] = ACTIONS(5367),
    [anon_sym_point] = ACTIONS(5367),
    [anon_sym_line] = ACTIONS(5367),
    [anon_sym_triangleadj] = ACTIONS(5367),
    [anon_sym_lineadj] = ACTIONS(5367),
    [anon_sym_triangle] = ACTIONS(5367),
  },
  [2240] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2232),
    [sym_identifier] = ACTIONS(5373),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5375),
    [anon_sym_COMMA] = ACTIONS(5375),
    [anon_sym_RPAREN] = ACTIONS(5375),
    [anon_sym_LPAREN2] = ACTIONS(5375),
    [anon_sym_TILDE] = ACTIONS(5375),
    [anon_sym_STAR] = ACTIONS(5375),
    [anon_sym_AMP_AMP] = ACTIONS(5375),
    [anon_sym_AMP] = ACTIONS(5373),
    [anon_sym_COLON] = ACTIONS(5373),
    [anon_sym_SEMI] = ACTIONS(5375),
    [anon_sym___extension__] = ACTIONS(5373),
    [anon_sym_in] = ACTIONS(5373),
    [anon_sym_out] = ACTIONS(5373),
    [anon_sym_inout] = ACTIONS(5373),
    [anon_sym_extern] = ACTIONS(5373),
    [anon_sym___attribute__] = ACTIONS(5373),
    [anon_sym_COLON_COLON] = ACTIONS(5375),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5375),
    [anon_sym___declspec] = ACTIONS(5373),
    [anon_sym___based] = ACTIONS(5373),
    [anon_sym___cdecl] = ACTIONS(5373),
    [anon_sym___clrcall] = ACTIONS(5373),
    [anon_sym___stdcall] = ACTIONS(5373),
    [anon_sym___fastcall] = ACTIONS(5373),
    [anon_sym___thiscall] = ACTIONS(5373),
    [anon_sym___vectorcall] = ACTIONS(5373),
    [anon_sym_LBRACE] = ACTIONS(5375),
    [anon_sym_signed] = ACTIONS(5351),
    [anon_sym_unsigned] = ACTIONS(5351),
    [anon_sym_long] = ACTIONS(5351),
    [anon_sym_short] = ACTIONS(5351),
    [anon_sym_LBRACK] = ACTIONS(5373),
    [anon_sym_static] = ACTIONS(5373),
    [anon_sym_EQ] = ACTIONS(5375),
    [anon_sym_register] = ACTIONS(5373),
    [anon_sym_inline] = ACTIONS(5373),
    [anon_sym___inline] = ACTIONS(5373),
    [anon_sym___inline__] = ACTIONS(5373),
    [anon_sym___forceinline] = ACTIONS(5373),
    [anon_sym_thread_local] = ACTIONS(5373),
    [anon_sym___thread] = ACTIONS(5373),
    [anon_sym_const] = ACTIONS(5373),
    [anon_sym_constexpr] = ACTIONS(5373),
    [anon_sym_volatile] = ACTIONS(5373),
    [anon_sym_restrict] = ACTIONS(5373),
    [anon_sym___restrict__] = ACTIONS(5373),
    [anon_sym__Atomic] = ACTIONS(5373),
    [anon_sym__Noreturn] = ACTIONS(5373),
    [anon_sym_noreturn] = ACTIONS(5373),
    [anon_sym_mutable] = ACTIONS(5373),
    [anon_sym_constinit] = ACTIONS(5373),
    [anon_sym_consteval] = ACTIONS(5373),
    [anon_sym_alignas] = ACTIONS(5373),
    [anon_sym__Alignas] = ACTIONS(5373),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5373),
    [anon_sym_decltype] = ACTIONS(5373),
    [sym_virtual] = ACTIONS(5373),
    [anon_sym_template] = ACTIONS(5373),
    [anon_sym_GT2] = ACTIONS(5375),
    [anon_sym_operator] = ACTIONS(5373),
    [anon_sym_precise] = ACTIONS(5373),
    [anon_sym_shared] = ACTIONS(5373),
    [anon_sym_groupshared] = ACTIONS(5373),
    [anon_sym_uniform] = ACTIONS(5373),
    [anon_sym_row_major] = ACTIONS(5373),
    [anon_sym_column_major] = ACTIONS(5373),
    [anon_sym_globallycoherent] = ACTIONS(5373),
    [anon_sym_centroid] = ACTIONS(5373),
    [anon_sym_noperspective] = ACTIONS(5373),
    [anon_sym_nointerpolation] = ACTIONS(5373),
    [anon_sym_sample] = ACTIONS(5373),
    [anon_sym_linear] = ACTIONS(5373),
    [anon_sym_snorm] = ACTIONS(5373),
    [anon_sym_unorm] = ACTIONS(5373),
    [anon_sym_point] = ACTIONS(5373),
    [anon_sym_line] = ACTIONS(5373),
    [anon_sym_triangleadj] = ACTIONS(5373),
    [anon_sym_lineadj] = ACTIONS(5373),
    [anon_sym_triangle] = ACTIONS(5373),
  },
  [2241] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2232),
    [sym_identifier] = ACTIONS(5377),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5379),
    [anon_sym_COMMA] = ACTIONS(5379),
    [anon_sym_RPAREN] = ACTIONS(5379),
    [anon_sym_LPAREN2] = ACTIONS(5379),
    [anon_sym_TILDE] = ACTIONS(5379),
    [anon_sym_STAR] = ACTIONS(5379),
    [anon_sym_AMP_AMP] = ACTIONS(5379),
    [anon_sym_AMP] = ACTIONS(5377),
    [anon_sym_COLON] = ACTIONS(5377),
    [anon_sym_SEMI] = ACTIONS(5379),
    [anon_sym___extension__] = ACTIONS(5377),
    [anon_sym_in] = ACTIONS(5377),
    [anon_sym_out] = ACTIONS(5377),
    [anon_sym_inout] = ACTIONS(5377),
    [anon_sym_extern] = ACTIONS(5377),
    [anon_sym___attribute__] = ACTIONS(5377),
    [anon_sym_COLON_COLON] = ACTIONS(5379),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5379),
    [anon_sym___declspec] = ACTIONS(5377),
    [anon_sym___based] = ACTIONS(5377),
    [anon_sym___cdecl] = ACTIONS(5377),
    [anon_sym___clrcall] = ACTIONS(5377),
    [anon_sym___stdcall] = ACTIONS(5377),
    [anon_sym___fastcall] = ACTIONS(5377),
    [anon_sym___thiscall] = ACTIONS(5377),
    [anon_sym___vectorcall] = ACTIONS(5377),
    [anon_sym_LBRACE] = ACTIONS(5379),
    [anon_sym_signed] = ACTIONS(5351),
    [anon_sym_unsigned] = ACTIONS(5351),
    [anon_sym_long] = ACTIONS(5351),
    [anon_sym_short] = ACTIONS(5351),
    [anon_sym_LBRACK] = ACTIONS(5377),
    [anon_sym_static] = ACTIONS(5377),
    [anon_sym_EQ] = ACTIONS(5379),
    [anon_sym_register] = ACTIONS(5377),
    [anon_sym_inline] = ACTIONS(5377),
    [anon_sym___inline] = ACTIONS(5377),
    [anon_sym___inline__] = ACTIONS(5377),
    [anon_sym___forceinline] = ACTIONS(5377),
    [anon_sym_thread_local] = ACTIONS(5377),
    [anon_sym___thread] = ACTIONS(5377),
    [anon_sym_const] = ACTIONS(5377),
    [anon_sym_constexpr] = ACTIONS(5377),
    [anon_sym_volatile] = ACTIONS(5377),
    [anon_sym_restrict] = ACTIONS(5377),
    [anon_sym___restrict__] = ACTIONS(5377),
    [anon_sym__Atomic] = ACTIONS(5377),
    [anon_sym__Noreturn] = ACTIONS(5377),
    [anon_sym_noreturn] = ACTIONS(5377),
    [anon_sym_mutable] = ACTIONS(5377),
    [anon_sym_constinit] = ACTIONS(5377),
    [anon_sym_consteval] = ACTIONS(5377),
    [anon_sym_alignas] = ACTIONS(5377),
    [anon_sym__Alignas] = ACTIONS(5377),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5377),
    [anon_sym_decltype] = ACTIONS(5377),
    [sym_virtual] = ACTIONS(5377),
    [anon_sym_template] = ACTIONS(5377),
    [anon_sym_GT2] = ACTIONS(5379),
    [anon_sym_operator] = ACTIONS(5377),
    [anon_sym_precise] = ACTIONS(5377),
    [anon_sym_shared] = ACTIONS(5377),
    [anon_sym_groupshared] = ACTIONS(5377),
    [anon_sym_uniform] = ACTIONS(5377),
    [anon_sym_row_major] = ACTIONS(5377),
    [anon_sym_column_major] = ACTIONS(5377),
    [anon_sym_globallycoherent] = ACTIONS(5377),
    [anon_sym_centroid] = ACTIONS(5377),
    [anon_sym_noperspective] = ACTIONS(5377),
    [anon_sym_nointerpolation] = ACTIONS(5377),
    [anon_sym_sample] = ACTIONS(5377),
    [anon_sym_linear] = ACTIONS(5377),
    [anon_sym_snorm] = ACTIONS(5377),
    [anon_sym_unorm] = ACTIONS(5377),
    [anon_sym_point] = ACTIONS(5377),
    [anon_sym_line] = ACTIONS(5377),
    [anon_sym_triangleadj] = ACTIONS(5377),
    [anon_sym_lineadj] = ACTIONS(5377),
    [anon_sym_triangle] = ACTIONS(5377),
  },
  [2242] = {
    [sym_template_argument_list] = STATE(2221),
    [sym_identifier] = ACTIONS(1933),
    [anon_sym_RPAREN] = ACTIONS(1935),
    [anon_sym_LPAREN2] = ACTIONS(1935),
    [anon_sym_TILDE] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1935),
    [anon_sym_PIPE_PIPE] = ACTIONS(1935),
    [anon_sym_AMP_AMP] = ACTIONS(1935),
    [anon_sym_AMP] = ACTIONS(1933),
    [anon_sym_LT] = ACTIONS(5298),
    [anon_sym_COLON] = ACTIONS(1933),
    [anon_sym_SEMI] = ACTIONS(1935),
    [anon_sym___extension__] = ACTIONS(1933),
    [anon_sym_in] = ACTIONS(1933),
    [anon_sym_out] = ACTIONS(1933),
    [anon_sym_inout] = ACTIONS(1933),
    [anon_sym_extern] = ACTIONS(1933),
    [anon_sym___attribute__] = ACTIONS(1933),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1935),
    [anon_sym___declspec] = ACTIONS(1933),
    [anon_sym___based] = ACTIONS(1933),
    [anon_sym___cdecl] = ACTIONS(1933),
    [anon_sym___clrcall] = ACTIONS(1933),
    [anon_sym___stdcall] = ACTIONS(1933),
    [anon_sym___fastcall] = ACTIONS(1933),
    [anon_sym___thiscall] = ACTIONS(1933),
    [anon_sym___vectorcall] = ACTIONS(1933),
    [anon_sym_LBRACE] = ACTIONS(1935),
    [anon_sym_LBRACK] = ACTIONS(1933),
    [anon_sym_static] = ACTIONS(1933),
    [anon_sym_register] = ACTIONS(1933),
    [anon_sym_inline] = ACTIONS(1933),
    [anon_sym___inline] = ACTIONS(1933),
    [anon_sym___inline__] = ACTIONS(1933),
    [anon_sym___forceinline] = ACTIONS(1933),
    [anon_sym_thread_local] = ACTIONS(1933),
    [anon_sym___thread] = ACTIONS(1933),
    [anon_sym_const] = ACTIONS(1933),
    [anon_sym_constexpr] = ACTIONS(1933),
    [anon_sym_volatile] = ACTIONS(1933),
    [anon_sym_restrict] = ACTIONS(1933),
    [anon_sym___restrict__] = ACTIONS(1933),
    [anon_sym__Atomic] = ACTIONS(1933),
    [anon_sym__Noreturn] = ACTIONS(1933),
    [anon_sym_noreturn] = ACTIONS(1933),
    [anon_sym_mutable] = ACTIONS(1933),
    [anon_sym_constinit] = ACTIONS(1933),
    [anon_sym_consteval] = ACTIONS(1933),
    [anon_sym_alignas] = ACTIONS(1933),
    [anon_sym__Alignas] = ACTIONS(1933),
    [anon_sym_or] = ACTIONS(1933),
    [anon_sym_and] = ACTIONS(1933),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1933),
    [anon_sym_decltype] = ACTIONS(1933),
    [anon_sym_final] = ACTIONS(1933),
    [anon_sym_override] = ACTIONS(1933),
    [sym_virtual] = ACTIONS(1933),
    [anon_sym_template] = ACTIONS(1933),
    [anon_sym_operator] = ACTIONS(1933),
    [anon_sym_try] = ACTIONS(1933),
    [anon_sym_requires] = ACTIONS(1933),
    [anon_sym_precise] = ACTIONS(1933),
    [anon_sym_shared] = ACTIONS(1933),
    [anon_sym_groupshared] = ACTIONS(1933),
    [anon_sym_uniform] = ACTIONS(1933),
    [anon_sym_row_major] = ACTIONS(1933),
    [anon_sym_column_major] = ACTIONS(1933),
    [anon_sym_globallycoherent] = ACTIONS(1933),
    [anon_sym_centroid] = ACTIONS(1933),
    [anon_sym_noperspective] = ACTIONS(1933),
    [anon_sym_nointerpolation] = ACTIONS(1933),
    [anon_sym_sample] = ACTIONS(1933),
    [anon_sym_linear] = ACTIONS(1933),
    [anon_sym_snorm] = ACTIONS(1933),
    [anon_sym_unorm] = ACTIONS(1933),
    [anon_sym_point] = ACTIONS(1933),
    [anon_sym_line] = ACTIONS(1933),
    [anon_sym_triangleadj] = ACTIONS(1933),
    [anon_sym_lineadj] = ACTIONS(1933),
    [anon_sym_triangle] = ACTIONS(1933),
  },
  [2243] = {
    [sym_identifier] = ACTIONS(1887),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1889),
    [anon_sym_COMMA] = ACTIONS(1889),
    [anon_sym_RPAREN] = ACTIONS(1889),
    [aux_sym_preproc_if_token2] = ACTIONS(1889),
    [aux_sym_preproc_else_token1] = ACTIONS(1889),
    [aux_sym_preproc_elif_token1] = ACTIONS(1887),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1889),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1889),
    [anon_sym_LPAREN2] = ACTIONS(1889),
    [anon_sym_DASH] = ACTIONS(1887),
    [anon_sym_PLUS] = ACTIONS(1887),
    [anon_sym_STAR] = ACTIONS(1887),
    [anon_sym_SLASH] = ACTIONS(1887),
    [anon_sym_PERCENT] = ACTIONS(1887),
    [anon_sym_PIPE_PIPE] = ACTIONS(1889),
    [anon_sym_AMP_AMP] = ACTIONS(1889),
    [anon_sym_PIPE] = ACTIONS(1887),
    [anon_sym_CARET] = ACTIONS(1887),
    [anon_sym_AMP] = ACTIONS(1887),
    [anon_sym_EQ_EQ] = ACTIONS(1889),
    [anon_sym_BANG_EQ] = ACTIONS(1889),
    [anon_sym_GT] = ACTIONS(1887),
    [anon_sym_GT_EQ] = ACTIONS(1889),
    [anon_sym_LT_EQ] = ACTIONS(1887),
    [anon_sym_LT] = ACTIONS(1887),
    [anon_sym_LT_LT] = ACTIONS(1887),
    [anon_sym_GT_GT] = ACTIONS(1887),
    [anon_sym_COLON] = ACTIONS(1887),
    [anon_sym_SEMI] = ACTIONS(1889),
    [anon_sym___extension__] = ACTIONS(1887),
    [anon_sym___attribute__] = ACTIONS(1887),
    [anon_sym_COLON_COLON] = ACTIONS(1889),
    [anon_sym_LBRACE] = ACTIONS(1889),
    [anon_sym_RBRACE] = ACTIONS(1889),
    [anon_sym_LBRACK] = ACTIONS(1889),
    [anon_sym_RBRACK] = ACTIONS(1889),
    [anon_sym_EQ] = ACTIONS(1887),
    [anon_sym_const] = ACTIONS(1887),
    [anon_sym_constexpr] = ACTIONS(1887),
    [anon_sym_volatile] = ACTIONS(1887),
    [anon_sym_restrict] = ACTIONS(1887),
    [anon_sym___restrict__] = ACTIONS(1887),
    [anon_sym__Atomic] = ACTIONS(1887),
    [anon_sym__Noreturn] = ACTIONS(1887),
    [anon_sym_noreturn] = ACTIONS(1887),
    [anon_sym_mutable] = ACTIONS(1887),
    [anon_sym_constinit] = ACTIONS(1887),
    [anon_sym_consteval] = ACTIONS(1887),
    [anon_sym_alignas] = ACTIONS(1887),
    [anon_sym__Alignas] = ACTIONS(1887),
    [anon_sym_QMARK] = ACTIONS(1889),
    [anon_sym_STAR_EQ] = ACTIONS(1889),
    [anon_sym_SLASH_EQ] = ACTIONS(1889),
    [anon_sym_PERCENT_EQ] = ACTIONS(1889),
    [anon_sym_PLUS_EQ] = ACTIONS(1889),
    [anon_sym_DASH_EQ] = ACTIONS(1889),
    [anon_sym_LT_LT_EQ] = ACTIONS(1889),
    [anon_sym_GT_GT_EQ] = ACTIONS(1889),
    [anon_sym_AMP_EQ] = ACTIONS(1889),
    [anon_sym_CARET_EQ] = ACTIONS(1889),
    [anon_sym_PIPE_EQ] = ACTIONS(1889),
    [anon_sym_and_eq] = ACTIONS(1887),
    [anon_sym_or_eq] = ACTIONS(1887),
    [anon_sym_xor_eq] = ACTIONS(1887),
    [anon_sym_LT_EQ_GT] = ACTIONS(1889),
    [anon_sym_or] = ACTIONS(1887),
    [anon_sym_and] = ACTIONS(1887),
    [anon_sym_bitor] = ACTIONS(1887),
    [anon_sym_xor] = ACTIONS(1887),
    [anon_sym_bitand] = ACTIONS(1887),
    [anon_sym_not_eq] = ACTIONS(1887),
    [anon_sym_DASH_DASH] = ACTIONS(1889),
    [anon_sym_PLUS_PLUS] = ACTIONS(1889),
    [anon_sym_DOT] = ACTIONS(1887),
    [anon_sym_DOT_STAR] = ACTIONS(1889),
    [anon_sym_DASH_GT] = ACTIONS(1889),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1887),
    [anon_sym_decltype] = ACTIONS(1887),
    [anon_sym_final] = ACTIONS(1887),
    [anon_sym_override] = ACTIONS(1887),
  },
  [2244] = {
    [sym_identifier] = ACTIONS(1899),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1901),
    [anon_sym_COMMA] = ACTIONS(1901),
    [anon_sym_RPAREN] = ACTIONS(1901),
    [aux_sym_preproc_if_token2] = ACTIONS(1901),
    [aux_sym_preproc_else_token1] = ACTIONS(1901),
    [aux_sym_preproc_elif_token1] = ACTIONS(1899),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1901),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1901),
    [anon_sym_LPAREN2] = ACTIONS(1901),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1899),
    [anon_sym_SLASH] = ACTIONS(1899),
    [anon_sym_PERCENT] = ACTIONS(1899),
    [anon_sym_PIPE_PIPE] = ACTIONS(1901),
    [anon_sym_AMP_AMP] = ACTIONS(1901),
    [anon_sym_PIPE] = ACTIONS(1899),
    [anon_sym_CARET] = ACTIONS(1899),
    [anon_sym_AMP] = ACTIONS(1899),
    [anon_sym_EQ_EQ] = ACTIONS(1901),
    [anon_sym_BANG_EQ] = ACTIONS(1901),
    [anon_sym_GT] = ACTIONS(1899),
    [anon_sym_GT_EQ] = ACTIONS(1901),
    [anon_sym_LT_EQ] = ACTIONS(1899),
    [anon_sym_LT] = ACTIONS(1899),
    [anon_sym_LT_LT] = ACTIONS(1899),
    [anon_sym_GT_GT] = ACTIONS(1899),
    [anon_sym_COLON] = ACTIONS(1899),
    [anon_sym_SEMI] = ACTIONS(1901),
    [anon_sym___extension__] = ACTIONS(1899),
    [anon_sym___attribute__] = ACTIONS(1899),
    [anon_sym_COLON_COLON] = ACTIONS(1901),
    [anon_sym_LBRACE] = ACTIONS(1901),
    [anon_sym_RBRACE] = ACTIONS(1901),
    [anon_sym_LBRACK] = ACTIONS(1901),
    [anon_sym_RBRACK] = ACTIONS(1901),
    [anon_sym_EQ] = ACTIONS(1899),
    [anon_sym_const] = ACTIONS(1899),
    [anon_sym_constexpr] = ACTIONS(1899),
    [anon_sym_volatile] = ACTIONS(1899),
    [anon_sym_restrict] = ACTIONS(1899),
    [anon_sym___restrict__] = ACTIONS(1899),
    [anon_sym__Atomic] = ACTIONS(1899),
    [anon_sym__Noreturn] = ACTIONS(1899),
    [anon_sym_noreturn] = ACTIONS(1899),
    [anon_sym_mutable] = ACTIONS(1899),
    [anon_sym_constinit] = ACTIONS(1899),
    [anon_sym_consteval] = ACTIONS(1899),
    [anon_sym_alignas] = ACTIONS(1899),
    [anon_sym__Alignas] = ACTIONS(1899),
    [anon_sym_QMARK] = ACTIONS(1901),
    [anon_sym_STAR_EQ] = ACTIONS(1901),
    [anon_sym_SLASH_EQ] = ACTIONS(1901),
    [anon_sym_PERCENT_EQ] = ACTIONS(1901),
    [anon_sym_PLUS_EQ] = ACTIONS(1901),
    [anon_sym_DASH_EQ] = ACTIONS(1901),
    [anon_sym_LT_LT_EQ] = ACTIONS(1901),
    [anon_sym_GT_GT_EQ] = ACTIONS(1901),
    [anon_sym_AMP_EQ] = ACTIONS(1901),
    [anon_sym_CARET_EQ] = ACTIONS(1901),
    [anon_sym_PIPE_EQ] = ACTIONS(1901),
    [anon_sym_and_eq] = ACTIONS(1899),
    [anon_sym_or_eq] = ACTIONS(1899),
    [anon_sym_xor_eq] = ACTIONS(1899),
    [anon_sym_LT_EQ_GT] = ACTIONS(1901),
    [anon_sym_or] = ACTIONS(1899),
    [anon_sym_and] = ACTIONS(1899),
    [anon_sym_bitor] = ACTIONS(1899),
    [anon_sym_xor] = ACTIONS(1899),
    [anon_sym_bitand] = ACTIONS(1899),
    [anon_sym_not_eq] = ACTIONS(1899),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DOT] = ACTIONS(1899),
    [anon_sym_DOT_STAR] = ACTIONS(1901),
    [anon_sym_DASH_GT] = ACTIONS(1901),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1899),
    [anon_sym_decltype] = ACTIONS(1899),
    [anon_sym_final] = ACTIONS(1899),
    [anon_sym_override] = ACTIONS(1899),
  },
  [2245] = {
    [sym_identifier] = ACTIONS(1925),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1927),
    [anon_sym_COMMA] = ACTIONS(1927),
    [anon_sym_RPAREN] = ACTIONS(1927),
    [aux_sym_preproc_if_token2] = ACTIONS(1927),
    [aux_sym_preproc_else_token1] = ACTIONS(1927),
    [aux_sym_preproc_elif_token1] = ACTIONS(1925),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1927),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1927),
    [anon_sym_LPAREN2] = ACTIONS(1927),
    [anon_sym_DASH] = ACTIONS(1925),
    [anon_sym_PLUS] = ACTIONS(1925),
    [anon_sym_STAR] = ACTIONS(1925),
    [anon_sym_SLASH] = ACTIONS(1925),
    [anon_sym_PERCENT] = ACTIONS(1925),
    [anon_sym_PIPE_PIPE] = ACTIONS(1927),
    [anon_sym_AMP_AMP] = ACTIONS(1927),
    [anon_sym_PIPE] = ACTIONS(1925),
    [anon_sym_CARET] = ACTIONS(1925),
    [anon_sym_AMP] = ACTIONS(1925),
    [anon_sym_EQ_EQ] = ACTIONS(1927),
    [anon_sym_BANG_EQ] = ACTIONS(1927),
    [anon_sym_GT] = ACTIONS(1925),
    [anon_sym_GT_EQ] = ACTIONS(1927),
    [anon_sym_LT_EQ] = ACTIONS(1925),
    [anon_sym_LT] = ACTIONS(1925),
    [anon_sym_LT_LT] = ACTIONS(1925),
    [anon_sym_GT_GT] = ACTIONS(1925),
    [anon_sym_COLON] = ACTIONS(1925),
    [anon_sym_SEMI] = ACTIONS(1927),
    [anon_sym___extension__] = ACTIONS(1925),
    [anon_sym___attribute__] = ACTIONS(1925),
    [anon_sym_COLON_COLON] = ACTIONS(1927),
    [anon_sym_LBRACE] = ACTIONS(1927),
    [anon_sym_RBRACE] = ACTIONS(1927),
    [anon_sym_LBRACK] = ACTIONS(1927),
    [anon_sym_RBRACK] = ACTIONS(1927),
    [anon_sym_EQ] = ACTIONS(1925),
    [anon_sym_const] = ACTIONS(1925),
    [anon_sym_constexpr] = ACTIONS(1925),
    [anon_sym_volatile] = ACTIONS(1925),
    [anon_sym_restrict] = ACTIONS(1925),
    [anon_sym___restrict__] = ACTIONS(1925),
    [anon_sym__Atomic] = ACTIONS(1925),
    [anon_sym__Noreturn] = ACTIONS(1925),
    [anon_sym_noreturn] = ACTIONS(1925),
    [anon_sym_mutable] = ACTIONS(1925),
    [anon_sym_constinit] = ACTIONS(1925),
    [anon_sym_consteval] = ACTIONS(1925),
    [anon_sym_alignas] = ACTIONS(1925),
    [anon_sym__Alignas] = ACTIONS(1925),
    [anon_sym_QMARK] = ACTIONS(1927),
    [anon_sym_STAR_EQ] = ACTIONS(1927),
    [anon_sym_SLASH_EQ] = ACTIONS(1927),
    [anon_sym_PERCENT_EQ] = ACTIONS(1927),
    [anon_sym_PLUS_EQ] = ACTIONS(1927),
    [anon_sym_DASH_EQ] = ACTIONS(1927),
    [anon_sym_LT_LT_EQ] = ACTIONS(1927),
    [anon_sym_GT_GT_EQ] = ACTIONS(1927),
    [anon_sym_AMP_EQ] = ACTIONS(1927),
    [anon_sym_CARET_EQ] = ACTIONS(1927),
    [anon_sym_PIPE_EQ] = ACTIONS(1927),
    [anon_sym_and_eq] = ACTIONS(1925),
    [anon_sym_or_eq] = ACTIONS(1925),
    [anon_sym_xor_eq] = ACTIONS(1925),
    [anon_sym_LT_EQ_GT] = ACTIONS(1927),
    [anon_sym_or] = ACTIONS(1925),
    [anon_sym_and] = ACTIONS(1925),
    [anon_sym_bitor] = ACTIONS(1925),
    [anon_sym_xor] = ACTIONS(1925),
    [anon_sym_bitand] = ACTIONS(1925),
    [anon_sym_not_eq] = ACTIONS(1925),
    [anon_sym_DASH_DASH] = ACTIONS(1927),
    [anon_sym_PLUS_PLUS] = ACTIONS(1927),
    [anon_sym_DOT] = ACTIONS(1925),
    [anon_sym_DOT_STAR] = ACTIONS(1927),
    [anon_sym_DASH_GT] = ACTIONS(1927),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1925),
    [anon_sym_decltype] = ACTIONS(1925),
    [anon_sym_final] = ACTIONS(1925),
    [anon_sym_override] = ACTIONS(1925),
  },
  [2246] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2241),
    [sym_identifier] = ACTIONS(5381),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5383),
    [anon_sym_COMMA] = ACTIONS(5383),
    [anon_sym_RPAREN] = ACTIONS(5383),
    [anon_sym_LPAREN2] = ACTIONS(5383),
    [anon_sym_TILDE] = ACTIONS(5383),
    [anon_sym_STAR] = ACTIONS(5383),
    [anon_sym_AMP_AMP] = ACTIONS(5383),
    [anon_sym_AMP] = ACTIONS(5381),
    [anon_sym_COLON] = ACTIONS(5381),
    [anon_sym_SEMI] = ACTIONS(5383),
    [anon_sym___extension__] = ACTIONS(5381),
    [anon_sym_in] = ACTIONS(5381),
    [anon_sym_out] = ACTIONS(5381),
    [anon_sym_inout] = ACTIONS(5381),
    [anon_sym_extern] = ACTIONS(5381),
    [anon_sym___attribute__] = ACTIONS(5381),
    [anon_sym_COLON_COLON] = ACTIONS(5383),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5383),
    [anon_sym___declspec] = ACTIONS(5381),
    [anon_sym___based] = ACTIONS(5381),
    [anon_sym___cdecl] = ACTIONS(5381),
    [anon_sym___clrcall] = ACTIONS(5381),
    [anon_sym___stdcall] = ACTIONS(5381),
    [anon_sym___fastcall] = ACTIONS(5381),
    [anon_sym___thiscall] = ACTIONS(5381),
    [anon_sym___vectorcall] = ACTIONS(5381),
    [anon_sym_LBRACE] = ACTIONS(5383),
    [anon_sym_signed] = ACTIONS(5385),
    [anon_sym_unsigned] = ACTIONS(5385),
    [anon_sym_long] = ACTIONS(5385),
    [anon_sym_short] = ACTIONS(5385),
    [anon_sym_LBRACK] = ACTIONS(5381),
    [anon_sym_static] = ACTIONS(5381),
    [anon_sym_EQ] = ACTIONS(5383),
    [anon_sym_register] = ACTIONS(5381),
    [anon_sym_inline] = ACTIONS(5381),
    [anon_sym___inline] = ACTIONS(5381),
    [anon_sym___inline__] = ACTIONS(5381),
    [anon_sym___forceinline] = ACTIONS(5381),
    [anon_sym_thread_local] = ACTIONS(5381),
    [anon_sym___thread] = ACTIONS(5381),
    [anon_sym_const] = ACTIONS(5381),
    [anon_sym_constexpr] = ACTIONS(5381),
    [anon_sym_volatile] = ACTIONS(5381),
    [anon_sym_restrict] = ACTIONS(5381),
    [anon_sym___restrict__] = ACTIONS(5381),
    [anon_sym__Atomic] = ACTIONS(5381),
    [anon_sym__Noreturn] = ACTIONS(5381),
    [anon_sym_noreturn] = ACTIONS(5381),
    [anon_sym_mutable] = ACTIONS(5381),
    [anon_sym_constinit] = ACTIONS(5381),
    [anon_sym_consteval] = ACTIONS(5381),
    [anon_sym_alignas] = ACTIONS(5381),
    [anon_sym__Alignas] = ACTIONS(5381),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5381),
    [anon_sym_decltype] = ACTIONS(5381),
    [sym_virtual] = ACTIONS(5381),
    [anon_sym_template] = ACTIONS(5381),
    [anon_sym_GT2] = ACTIONS(5383),
    [anon_sym_operator] = ACTIONS(5381),
    [anon_sym_precise] = ACTIONS(5381),
    [anon_sym_shared] = ACTIONS(5381),
    [anon_sym_groupshared] = ACTIONS(5381),
    [anon_sym_uniform] = ACTIONS(5381),
    [anon_sym_row_major] = ACTIONS(5381),
    [anon_sym_column_major] = ACTIONS(5381),
    [anon_sym_globallycoherent] = ACTIONS(5381),
    [anon_sym_centroid] = ACTIONS(5381),
    [anon_sym_noperspective] = ACTIONS(5381),
    [anon_sym_nointerpolation] = ACTIONS(5381),
    [anon_sym_sample] = ACTIONS(5381),
    [anon_sym_linear] = ACTIONS(5381),
    [anon_sym_snorm] = ACTIONS(5381),
    [anon_sym_unorm] = ACTIONS(5381),
    [anon_sym_point] = ACTIONS(5381),
    [anon_sym_line] = ACTIONS(5381),
    [anon_sym_triangleadj] = ACTIONS(5381),
    [anon_sym_lineadj] = ACTIONS(5381),
    [anon_sym_triangle] = ACTIONS(5381),
  },
  [2247] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2232),
    [sym_identifier] = ACTIONS(5387),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5389),
    [anon_sym_COMMA] = ACTIONS(5389),
    [anon_sym_RPAREN] = ACTIONS(5389),
    [anon_sym_LPAREN2] = ACTIONS(5389),
    [anon_sym_TILDE] = ACTIONS(5389),
    [anon_sym_STAR] = ACTIONS(5389),
    [anon_sym_AMP_AMP] = ACTIONS(5389),
    [anon_sym_AMP] = ACTIONS(5387),
    [anon_sym_COLON] = ACTIONS(5387),
    [anon_sym_SEMI] = ACTIONS(5389),
    [anon_sym___extension__] = ACTIONS(5387),
    [anon_sym_in] = ACTIONS(5387),
    [anon_sym_out] = ACTIONS(5387),
    [anon_sym_inout] = ACTIONS(5387),
    [anon_sym_extern] = ACTIONS(5387),
    [anon_sym___attribute__] = ACTIONS(5387),
    [anon_sym_COLON_COLON] = ACTIONS(5389),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5389),
    [anon_sym___declspec] = ACTIONS(5387),
    [anon_sym___based] = ACTIONS(5387),
    [anon_sym___cdecl] = ACTIONS(5387),
    [anon_sym___clrcall] = ACTIONS(5387),
    [anon_sym___stdcall] = ACTIONS(5387),
    [anon_sym___fastcall] = ACTIONS(5387),
    [anon_sym___thiscall] = ACTIONS(5387),
    [anon_sym___vectorcall] = ACTIONS(5387),
    [anon_sym_LBRACE] = ACTIONS(5389),
    [anon_sym_signed] = ACTIONS(5351),
    [anon_sym_unsigned] = ACTIONS(5351),
    [anon_sym_long] = ACTIONS(5351),
    [anon_sym_short] = ACTIONS(5351),
    [anon_sym_LBRACK] = ACTIONS(5387),
    [anon_sym_static] = ACTIONS(5387),
    [anon_sym_EQ] = ACTIONS(5389),
    [anon_sym_register] = ACTIONS(5387),
    [anon_sym_inline] = ACTIONS(5387),
    [anon_sym___inline] = ACTIONS(5387),
    [anon_sym___inline__] = ACTIONS(5387),
    [anon_sym___forceinline] = ACTIONS(5387),
    [anon_sym_thread_local] = ACTIONS(5387),
    [anon_sym___thread] = ACTIONS(5387),
    [anon_sym_const] = ACTIONS(5387),
    [anon_sym_constexpr] = ACTIONS(5387),
    [anon_sym_volatile] = ACTIONS(5387),
    [anon_sym_restrict] = ACTIONS(5387),
    [anon_sym___restrict__] = ACTIONS(5387),
    [anon_sym__Atomic] = ACTIONS(5387),
    [anon_sym__Noreturn] = ACTIONS(5387),
    [anon_sym_noreturn] = ACTIONS(5387),
    [anon_sym_mutable] = ACTIONS(5387),
    [anon_sym_constinit] = ACTIONS(5387),
    [anon_sym_consteval] = ACTIONS(5387),
    [anon_sym_alignas] = ACTIONS(5387),
    [anon_sym__Alignas] = ACTIONS(5387),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5387),
    [anon_sym_decltype] = ACTIONS(5387),
    [sym_virtual] = ACTIONS(5387),
    [anon_sym_template] = ACTIONS(5387),
    [anon_sym_GT2] = ACTIONS(5389),
    [anon_sym_operator] = ACTIONS(5387),
    [anon_sym_precise] = ACTIONS(5387),
    [anon_sym_shared] = ACTIONS(5387),
    [anon_sym_groupshared] = ACTIONS(5387),
    [anon_sym_uniform] = ACTIONS(5387),
    [anon_sym_row_major] = ACTIONS(5387),
    [anon_sym_column_major] = ACTIONS(5387),
    [anon_sym_globallycoherent] = ACTIONS(5387),
    [anon_sym_centroid] = ACTIONS(5387),
    [anon_sym_noperspective] = ACTIONS(5387),
    [anon_sym_nointerpolation] = ACTIONS(5387),
    [anon_sym_sample] = ACTIONS(5387),
    [anon_sym_linear] = ACTIONS(5387),
    [anon_sym_snorm] = ACTIONS(5387),
    [anon_sym_unorm] = ACTIONS(5387),
    [anon_sym_point] = ACTIONS(5387),
    [anon_sym_line] = ACTIONS(5387),
    [anon_sym_triangleadj] = ACTIONS(5387),
    [anon_sym_lineadj] = ACTIONS(5387),
    [anon_sym_triangle] = ACTIONS(5387),
  },
  [2248] = {
    [sym_identifier] = ACTIONS(1891),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1893),
    [anon_sym_COMMA] = ACTIONS(1893),
    [anon_sym_RPAREN] = ACTIONS(1893),
    [aux_sym_preproc_if_token2] = ACTIONS(1893),
    [aux_sym_preproc_else_token1] = ACTIONS(1893),
    [aux_sym_preproc_elif_token1] = ACTIONS(1891),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1893),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1893),
    [anon_sym_LPAREN2] = ACTIONS(1893),
    [anon_sym_DASH] = ACTIONS(1891),
    [anon_sym_PLUS] = ACTIONS(1891),
    [anon_sym_STAR] = ACTIONS(1891),
    [anon_sym_SLASH] = ACTIONS(1891),
    [anon_sym_PERCENT] = ACTIONS(1891),
    [anon_sym_PIPE_PIPE] = ACTIONS(1893),
    [anon_sym_AMP_AMP] = ACTIONS(1893),
    [anon_sym_PIPE] = ACTIONS(1891),
    [anon_sym_CARET] = ACTIONS(1891),
    [anon_sym_AMP] = ACTIONS(1891),
    [anon_sym_EQ_EQ] = ACTIONS(1893),
    [anon_sym_BANG_EQ] = ACTIONS(1893),
    [anon_sym_GT] = ACTIONS(1891),
    [anon_sym_GT_EQ] = ACTIONS(1893),
    [anon_sym_LT_EQ] = ACTIONS(1891),
    [anon_sym_LT] = ACTIONS(1891),
    [anon_sym_LT_LT] = ACTIONS(1891),
    [anon_sym_GT_GT] = ACTIONS(1891),
    [anon_sym_COLON] = ACTIONS(1891),
    [anon_sym_SEMI] = ACTIONS(1893),
    [anon_sym___extension__] = ACTIONS(1891),
    [anon_sym___attribute__] = ACTIONS(1891),
    [anon_sym_COLON_COLON] = ACTIONS(1893),
    [anon_sym_LBRACE] = ACTIONS(1893),
    [anon_sym_RBRACE] = ACTIONS(1893),
    [anon_sym_LBRACK] = ACTIONS(1893),
    [anon_sym_RBRACK] = ACTIONS(1893),
    [anon_sym_EQ] = ACTIONS(1891),
    [anon_sym_const] = ACTIONS(1891),
    [anon_sym_constexpr] = ACTIONS(1891),
    [anon_sym_volatile] = ACTIONS(1891),
    [anon_sym_restrict] = ACTIONS(1891),
    [anon_sym___restrict__] = ACTIONS(1891),
    [anon_sym__Atomic] = ACTIONS(1891),
    [anon_sym__Noreturn] = ACTIONS(1891),
    [anon_sym_noreturn] = ACTIONS(1891),
    [anon_sym_mutable] = ACTIONS(1891),
    [anon_sym_constinit] = ACTIONS(1891),
    [anon_sym_consteval] = ACTIONS(1891),
    [anon_sym_alignas] = ACTIONS(1891),
    [anon_sym__Alignas] = ACTIONS(1891),
    [anon_sym_QMARK] = ACTIONS(1893),
    [anon_sym_STAR_EQ] = ACTIONS(1893),
    [anon_sym_SLASH_EQ] = ACTIONS(1893),
    [anon_sym_PERCENT_EQ] = ACTIONS(1893),
    [anon_sym_PLUS_EQ] = ACTIONS(1893),
    [anon_sym_DASH_EQ] = ACTIONS(1893),
    [anon_sym_LT_LT_EQ] = ACTIONS(1893),
    [anon_sym_GT_GT_EQ] = ACTIONS(1893),
    [anon_sym_AMP_EQ] = ACTIONS(1893),
    [anon_sym_CARET_EQ] = ACTIONS(1893),
    [anon_sym_PIPE_EQ] = ACTIONS(1893),
    [anon_sym_and_eq] = ACTIONS(1891),
    [anon_sym_or_eq] = ACTIONS(1891),
    [anon_sym_xor_eq] = ACTIONS(1891),
    [anon_sym_LT_EQ_GT] = ACTIONS(1893),
    [anon_sym_or] = ACTIONS(1891),
    [anon_sym_and] = ACTIONS(1891),
    [anon_sym_bitor] = ACTIONS(1891),
    [anon_sym_xor] = ACTIONS(1891),
    [anon_sym_bitand] = ACTIONS(1891),
    [anon_sym_not_eq] = ACTIONS(1891),
    [anon_sym_DASH_DASH] = ACTIONS(1893),
    [anon_sym_PLUS_PLUS] = ACTIONS(1893),
    [anon_sym_DOT] = ACTIONS(1891),
    [anon_sym_DOT_STAR] = ACTIONS(1893),
    [anon_sym_DASH_GT] = ACTIONS(1893),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1891),
    [anon_sym_decltype] = ACTIONS(1891),
    [anon_sym_final] = ACTIONS(1891),
    [anon_sym_override] = ACTIONS(1891),
  },
  [2249] = {
    [sym_identifier] = ACTIONS(5391),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5393),
    [anon_sym_COMMA] = ACTIONS(5393),
    [anon_sym_RPAREN] = ACTIONS(5393),
    [anon_sym_LPAREN2] = ACTIONS(5393),
    [anon_sym_TILDE] = ACTIONS(5393),
    [anon_sym_STAR] = ACTIONS(5393),
    [anon_sym_AMP_AMP] = ACTIONS(5393),
    [anon_sym_AMP] = ACTIONS(5391),
    [anon_sym_COLON] = ACTIONS(5391),
    [anon_sym_SEMI] = ACTIONS(5393),
    [anon_sym___extension__] = ACTIONS(5391),
    [anon_sym_in] = ACTIONS(5391),
    [anon_sym_out] = ACTIONS(5391),
    [anon_sym_inout] = ACTIONS(5391),
    [anon_sym_extern] = ACTIONS(5391),
    [anon_sym___attribute__] = ACTIONS(5391),
    [anon_sym_COLON_COLON] = ACTIONS(5393),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5393),
    [anon_sym___declspec] = ACTIONS(5391),
    [anon_sym___based] = ACTIONS(5391),
    [anon_sym___cdecl] = ACTIONS(5391),
    [anon_sym___clrcall] = ACTIONS(5391),
    [anon_sym___stdcall] = ACTIONS(5391),
    [anon_sym___fastcall] = ACTIONS(5391),
    [anon_sym___thiscall] = ACTIONS(5391),
    [anon_sym___vectorcall] = ACTIONS(5391),
    [anon_sym_LBRACE] = ACTIONS(5393),
    [anon_sym_LBRACK] = ACTIONS(5391),
    [anon_sym_static] = ACTIONS(5391),
    [anon_sym_EQ] = ACTIONS(5393),
    [anon_sym_register] = ACTIONS(5391),
    [anon_sym_inline] = ACTIONS(5391),
    [anon_sym___inline] = ACTIONS(5391),
    [anon_sym___inline__] = ACTIONS(5391),
    [anon_sym___forceinline] = ACTIONS(5391),
    [anon_sym_thread_local] = ACTIONS(5391),
    [anon_sym___thread] = ACTIONS(5391),
    [anon_sym_const] = ACTIONS(5391),
    [anon_sym_constexpr] = ACTIONS(5391),
    [anon_sym_volatile] = ACTIONS(5391),
    [anon_sym_restrict] = ACTIONS(5391),
    [anon_sym___restrict__] = ACTIONS(5391),
    [anon_sym__Atomic] = ACTIONS(5391),
    [anon_sym__Noreturn] = ACTIONS(5391),
    [anon_sym_noreturn] = ACTIONS(5391),
    [anon_sym_mutable] = ACTIONS(5391),
    [anon_sym_constinit] = ACTIONS(5391),
    [anon_sym_consteval] = ACTIONS(5391),
    [anon_sym_alignas] = ACTIONS(5391),
    [anon_sym__Alignas] = ACTIONS(5391),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5391),
    [anon_sym_decltype] = ACTIONS(5391),
    [anon_sym_final] = ACTIONS(5391),
    [anon_sym_override] = ACTIONS(5391),
    [sym_virtual] = ACTIONS(5391),
    [anon_sym_template] = ACTIONS(5391),
    [anon_sym_GT2] = ACTIONS(5393),
    [anon_sym_operator] = ACTIONS(5391),
    [anon_sym_try] = ACTIONS(5391),
    [anon_sym_requires] = ACTIONS(5391),
    [anon_sym_precise] = ACTIONS(5391),
    [anon_sym_shared] = ACTIONS(5391),
    [anon_sym_groupshared] = ACTIONS(5391),
    [anon_sym_uniform] = ACTIONS(5391),
    [anon_sym_row_major] = ACTIONS(5391),
    [anon_sym_column_major] = ACTIONS(5391),
    [anon_sym_globallycoherent] = ACTIONS(5391),
    [anon_sym_centroid] = ACTIONS(5391),
    [anon_sym_noperspective] = ACTIONS(5391),
    [anon_sym_nointerpolation] = ACTIONS(5391),
    [anon_sym_sample] = ACTIONS(5391),
    [anon_sym_linear] = ACTIONS(5391),
    [anon_sym_snorm] = ACTIONS(5391),
    [anon_sym_unorm] = ACTIONS(5391),
    [anon_sym_point] = ACTIONS(5391),
    [anon_sym_line] = ACTIONS(5391),
    [anon_sym_triangleadj] = ACTIONS(5391),
    [anon_sym_lineadj] = ACTIONS(5391),
    [anon_sym_triangle] = ACTIONS(5391),
  },
  [2250] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2240),
    [sym_identifier] = ACTIONS(5318),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5320),
    [anon_sym_COMMA] = ACTIONS(5320),
    [anon_sym_RPAREN] = ACTIONS(5320),
    [anon_sym_LPAREN2] = ACTIONS(5320),
    [anon_sym_TILDE] = ACTIONS(5320),
    [anon_sym_STAR] = ACTIONS(5320),
    [anon_sym_AMP_AMP] = ACTIONS(5320),
    [anon_sym_AMP] = ACTIONS(5318),
    [anon_sym_COLON] = ACTIONS(5318),
    [anon_sym_SEMI] = ACTIONS(5320),
    [anon_sym___extension__] = ACTIONS(5318),
    [anon_sym_in] = ACTIONS(5318),
    [anon_sym_out] = ACTIONS(5318),
    [anon_sym_inout] = ACTIONS(5318),
    [anon_sym_extern] = ACTIONS(5318),
    [anon_sym___attribute__] = ACTIONS(5318),
    [anon_sym_COLON_COLON] = ACTIONS(5320),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5320),
    [anon_sym___declspec] = ACTIONS(5318),
    [anon_sym___based] = ACTIONS(5318),
    [anon_sym___cdecl] = ACTIONS(5318),
    [anon_sym___clrcall] = ACTIONS(5318),
    [anon_sym___stdcall] = ACTIONS(5318),
    [anon_sym___fastcall] = ACTIONS(5318),
    [anon_sym___thiscall] = ACTIONS(5318),
    [anon_sym___vectorcall] = ACTIONS(5318),
    [anon_sym_signed] = ACTIONS(5325),
    [anon_sym_unsigned] = ACTIONS(5325),
    [anon_sym_long] = ACTIONS(5325),
    [anon_sym_short] = ACTIONS(5325),
    [anon_sym_LBRACK] = ACTIONS(5318),
    [anon_sym_static] = ACTIONS(5318),
    [anon_sym_EQ] = ACTIONS(5320),
    [anon_sym_register] = ACTIONS(5318),
    [anon_sym_inline] = ACTIONS(5318),
    [anon_sym___inline] = ACTIONS(5318),
    [anon_sym___inline__] = ACTIONS(5318),
    [anon_sym___forceinline] = ACTIONS(5318),
    [anon_sym_thread_local] = ACTIONS(5318),
    [anon_sym___thread] = ACTIONS(5318),
    [anon_sym_const] = ACTIONS(5318),
    [anon_sym_constexpr] = ACTIONS(5318),
    [anon_sym_volatile] = ACTIONS(5318),
    [anon_sym_restrict] = ACTIONS(5318),
    [anon_sym___restrict__] = ACTIONS(5318),
    [anon_sym__Atomic] = ACTIONS(5318),
    [anon_sym__Noreturn] = ACTIONS(5318),
    [anon_sym_noreturn] = ACTIONS(5318),
    [anon_sym_mutable] = ACTIONS(5318),
    [anon_sym_constinit] = ACTIONS(5318),
    [anon_sym_consteval] = ACTIONS(5318),
    [anon_sym_alignas] = ACTIONS(5318),
    [anon_sym__Alignas] = ACTIONS(5318),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5318),
    [anon_sym_decltype] = ACTIONS(5318),
    [sym_virtual] = ACTIONS(5318),
    [anon_sym_template] = ACTIONS(5318),
    [anon_sym_GT2] = ACTIONS(5320),
    [anon_sym_operator] = ACTIONS(5318),
    [anon_sym_precise] = ACTIONS(5318),
    [anon_sym_shared] = ACTIONS(5318),
    [anon_sym_groupshared] = ACTIONS(5318),
    [anon_sym_uniform] = ACTIONS(5318),
    [anon_sym_row_major] = ACTIONS(5318),
    [anon_sym_column_major] = ACTIONS(5318),
    [anon_sym_globallycoherent] = ACTIONS(5318),
    [anon_sym_centroid] = ACTIONS(5318),
    [anon_sym_noperspective] = ACTIONS(5318),
    [anon_sym_nointerpolation] = ACTIONS(5318),
    [anon_sym_sample] = ACTIONS(5318),
    [anon_sym_linear] = ACTIONS(5318),
    [anon_sym_snorm] = ACTIONS(5318),
    [anon_sym_unorm] = ACTIONS(5318),
    [anon_sym_point] = ACTIONS(5318),
    [anon_sym_line] = ACTIONS(5318),
    [anon_sym_triangleadj] = ACTIONS(5318),
    [anon_sym_lineadj] = ACTIONS(5318),
    [anon_sym_triangle] = ACTIONS(5318),
  },
  [2251] = {
    [sym_identifier] = ACTIONS(2142),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2144),
    [anon_sym_COMMA] = ACTIONS(2144),
    [anon_sym_RPAREN] = ACTIONS(2144),
    [anon_sym_LPAREN2] = ACTIONS(2144),
    [anon_sym_TILDE] = ACTIONS(2144),
    [anon_sym_STAR] = ACTIONS(2144),
    [anon_sym_AMP_AMP] = ACTIONS(2144),
    [anon_sym_AMP] = ACTIONS(2142),
    [anon_sym_COLON] = ACTIONS(2142),
    [anon_sym_SEMI] = ACTIONS(2144),
    [anon_sym___extension__] = ACTIONS(2142),
    [anon_sym_in] = ACTIONS(2142),
    [anon_sym_out] = ACTIONS(2142),
    [anon_sym_inout] = ACTIONS(2142),
    [anon_sym_extern] = ACTIONS(2142),
    [anon_sym___attribute__] = ACTIONS(2142),
    [anon_sym_COLON_COLON] = ACTIONS(2144),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2144),
    [anon_sym___declspec] = ACTIONS(2142),
    [anon_sym___based] = ACTIONS(2142),
    [anon_sym___cdecl] = ACTIONS(2142),
    [anon_sym___clrcall] = ACTIONS(2142),
    [anon_sym___stdcall] = ACTIONS(2142),
    [anon_sym___fastcall] = ACTIONS(2142),
    [anon_sym___thiscall] = ACTIONS(2142),
    [anon_sym___vectorcall] = ACTIONS(2142),
    [anon_sym_LBRACK] = ACTIONS(2142),
    [anon_sym_static] = ACTIONS(2142),
    [anon_sym_EQ] = ACTIONS(2144),
    [anon_sym_register] = ACTIONS(2142),
    [anon_sym_inline] = ACTIONS(2142),
    [anon_sym___inline] = ACTIONS(2142),
    [anon_sym___inline__] = ACTIONS(2142),
    [anon_sym___forceinline] = ACTIONS(2142),
    [anon_sym_thread_local] = ACTIONS(2142),
    [anon_sym___thread] = ACTIONS(2142),
    [anon_sym_const] = ACTIONS(2142),
    [anon_sym_constexpr] = ACTIONS(2142),
    [anon_sym_volatile] = ACTIONS(2142),
    [anon_sym_restrict] = ACTIONS(2142),
    [anon_sym___restrict__] = ACTIONS(2142),
    [anon_sym__Atomic] = ACTIONS(2142),
    [anon_sym__Noreturn] = ACTIONS(2142),
    [anon_sym_noreturn] = ACTIONS(2142),
    [anon_sym_mutable] = ACTIONS(2142),
    [anon_sym_constinit] = ACTIONS(2142),
    [anon_sym_consteval] = ACTIONS(2142),
    [anon_sym_alignas] = ACTIONS(2142),
    [anon_sym__Alignas] = ACTIONS(2142),
    [anon_sym_else] = ACTIONS(2142),
    [anon_sym_while] = ACTIONS(2142),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2142),
    [anon_sym_decltype] = ACTIONS(2142),
    [anon_sym_final] = ACTIONS(2142),
    [anon_sym_override] = ACTIONS(2142),
    [sym_virtual] = ACTIONS(2142),
    [anon_sym_template] = ACTIONS(2142),
    [anon_sym_GT2] = ACTIONS(2144),
    [anon_sym_operator] = ACTIONS(2142),
    [anon_sym_requires] = ACTIONS(2142),
    [anon_sym_precise] = ACTIONS(2142),
    [anon_sym_shared] = ACTIONS(2142),
    [anon_sym_groupshared] = ACTIONS(2142),
    [anon_sym_uniform] = ACTIONS(2142),
    [anon_sym_row_major] = ACTIONS(2142),
    [anon_sym_column_major] = ACTIONS(2142),
    [anon_sym_globallycoherent] = ACTIONS(2142),
    [anon_sym_centroid] = ACTIONS(2142),
    [anon_sym_noperspective] = ACTIONS(2142),
    [anon_sym_nointerpolation] = ACTIONS(2142),
    [anon_sym_sample] = ACTIONS(2142),
    [anon_sym_linear] = ACTIONS(2142),
    [anon_sym_snorm] = ACTIONS(2142),
    [anon_sym_unorm] = ACTIONS(2142),
    [anon_sym_point] = ACTIONS(2142),
    [anon_sym_line] = ACTIONS(2142),
    [anon_sym_triangleadj] = ACTIONS(2142),
    [anon_sym_lineadj] = ACTIONS(2142),
    [anon_sym_triangle] = ACTIONS(2142),
  },
  [2252] = {
    [sym_identifier] = ACTIONS(5318),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5320),
    [anon_sym_COMMA] = ACTIONS(5320),
    [anon_sym_RPAREN] = ACTIONS(5320),
    [anon_sym_LPAREN2] = ACTIONS(5320),
    [anon_sym_TILDE] = ACTIONS(5320),
    [anon_sym_STAR] = ACTIONS(5320),
    [anon_sym_AMP_AMP] = ACTIONS(5320),
    [anon_sym_AMP] = ACTIONS(5318),
    [anon_sym_COLON] = ACTIONS(5318),
    [anon_sym_SEMI] = ACTIONS(5320),
    [anon_sym___extension__] = ACTIONS(5318),
    [anon_sym_in] = ACTIONS(5318),
    [anon_sym_out] = ACTIONS(5318),
    [anon_sym_inout] = ACTIONS(5318),
    [anon_sym_extern] = ACTIONS(5318),
    [anon_sym___attribute__] = ACTIONS(5318),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5320),
    [anon_sym___declspec] = ACTIONS(5318),
    [anon_sym___based] = ACTIONS(5318),
    [anon_sym___cdecl] = ACTIONS(5318),
    [anon_sym___clrcall] = ACTIONS(5318),
    [anon_sym___stdcall] = ACTIONS(5318),
    [anon_sym___fastcall] = ACTIONS(5318),
    [anon_sym___thiscall] = ACTIONS(5318),
    [anon_sym___vectorcall] = ACTIONS(5318),
    [anon_sym_LBRACE] = ACTIONS(5320),
    [anon_sym_LBRACK] = ACTIONS(5318),
    [anon_sym_static] = ACTIONS(5318),
    [anon_sym_EQ] = ACTIONS(5320),
    [anon_sym_register] = ACTIONS(5318),
    [anon_sym_inline] = ACTIONS(5318),
    [anon_sym___inline] = ACTIONS(5318),
    [anon_sym___inline__] = ACTIONS(5318),
    [anon_sym___forceinline] = ACTIONS(5318),
    [anon_sym_thread_local] = ACTIONS(5318),
    [anon_sym___thread] = ACTIONS(5318),
    [anon_sym_const] = ACTIONS(5318),
    [anon_sym_constexpr] = ACTIONS(5318),
    [anon_sym_volatile] = ACTIONS(5318),
    [anon_sym_restrict] = ACTIONS(5318),
    [anon_sym___restrict__] = ACTIONS(5318),
    [anon_sym__Atomic] = ACTIONS(5318),
    [anon_sym__Noreturn] = ACTIONS(5318),
    [anon_sym_noreturn] = ACTIONS(5318),
    [anon_sym_mutable] = ACTIONS(5318),
    [anon_sym_constinit] = ACTIONS(5318),
    [anon_sym_consteval] = ACTIONS(5318),
    [anon_sym_alignas] = ACTIONS(5318),
    [anon_sym__Alignas] = ACTIONS(5318),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5318),
    [anon_sym_decltype] = ACTIONS(5318),
    [anon_sym_final] = ACTIONS(5318),
    [anon_sym_override] = ACTIONS(5318),
    [sym_virtual] = ACTIONS(5318),
    [anon_sym_template] = ACTIONS(5318),
    [anon_sym_GT2] = ACTIONS(5320),
    [anon_sym_operator] = ACTIONS(5318),
    [anon_sym_try] = ACTIONS(5318),
    [anon_sym_requires] = ACTIONS(5318),
    [anon_sym_precise] = ACTIONS(5318),
    [anon_sym_shared] = ACTIONS(5318),
    [anon_sym_groupshared] = ACTIONS(5318),
    [anon_sym_uniform] = ACTIONS(5318),
    [anon_sym_row_major] = ACTIONS(5318),
    [anon_sym_column_major] = ACTIONS(5318),
    [anon_sym_globallycoherent] = ACTIONS(5318),
    [anon_sym_centroid] = ACTIONS(5318),
    [anon_sym_noperspective] = ACTIONS(5318),
    [anon_sym_nointerpolation] = ACTIONS(5318),
    [anon_sym_sample] = ACTIONS(5318),
    [anon_sym_linear] = ACTIONS(5318),
    [anon_sym_snorm] = ACTIONS(5318),
    [anon_sym_unorm] = ACTIONS(5318),
    [anon_sym_point] = ACTIONS(5318),
    [anon_sym_line] = ACTIONS(5318),
    [anon_sym_triangleadj] = ACTIONS(5318),
    [anon_sym_lineadj] = ACTIONS(5318),
    [anon_sym_triangle] = ACTIONS(5318),
  },
  [2253] = {
    [sym_identifier] = ACTIONS(2260),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2262),
    [anon_sym_COMMA] = ACTIONS(2262),
    [anon_sym_RPAREN] = ACTIONS(2262),
    [anon_sym_LPAREN2] = ACTIONS(2262),
    [anon_sym_TILDE] = ACTIONS(2262),
    [anon_sym_STAR] = ACTIONS(2262),
    [anon_sym_AMP_AMP] = ACTIONS(2262),
    [anon_sym_AMP] = ACTIONS(2260),
    [anon_sym_COLON] = ACTIONS(2260),
    [anon_sym_SEMI] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(2260),
    [anon_sym_in] = ACTIONS(2260),
    [anon_sym_out] = ACTIONS(2260),
    [anon_sym_inout] = ACTIONS(2260),
    [anon_sym_extern] = ACTIONS(2260),
    [anon_sym___attribute__] = ACTIONS(2260),
    [anon_sym_COLON_COLON] = ACTIONS(2262),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2262),
    [anon_sym___declspec] = ACTIONS(2260),
    [anon_sym___based] = ACTIONS(2260),
    [anon_sym___cdecl] = ACTIONS(2260),
    [anon_sym___clrcall] = ACTIONS(2260),
    [anon_sym___stdcall] = ACTIONS(2260),
    [anon_sym___fastcall] = ACTIONS(2260),
    [anon_sym___thiscall] = ACTIONS(2260),
    [anon_sym___vectorcall] = ACTIONS(2260),
    [anon_sym_LBRACK] = ACTIONS(2260),
    [anon_sym_static] = ACTIONS(2260),
    [anon_sym_EQ] = ACTIONS(2262),
    [anon_sym_register] = ACTIONS(2260),
    [anon_sym_inline] = ACTIONS(2260),
    [anon_sym___inline] = ACTIONS(2260),
    [anon_sym___inline__] = ACTIONS(2260),
    [anon_sym___forceinline] = ACTIONS(2260),
    [anon_sym_thread_local] = ACTIONS(2260),
    [anon_sym___thread] = ACTIONS(2260),
    [anon_sym_const] = ACTIONS(2260),
    [anon_sym_constexpr] = ACTIONS(2260),
    [anon_sym_volatile] = ACTIONS(2260),
    [anon_sym_restrict] = ACTIONS(2260),
    [anon_sym___restrict__] = ACTIONS(2260),
    [anon_sym__Atomic] = ACTIONS(2260),
    [anon_sym__Noreturn] = ACTIONS(2260),
    [anon_sym_noreturn] = ACTIONS(2260),
    [anon_sym_mutable] = ACTIONS(2260),
    [anon_sym_constinit] = ACTIONS(2260),
    [anon_sym_consteval] = ACTIONS(2260),
    [anon_sym_alignas] = ACTIONS(2260),
    [anon_sym__Alignas] = ACTIONS(2260),
    [anon_sym_else] = ACTIONS(2260),
    [anon_sym_while] = ACTIONS(2260),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2260),
    [anon_sym_decltype] = ACTIONS(2260),
    [anon_sym_final] = ACTIONS(2260),
    [anon_sym_override] = ACTIONS(2260),
    [sym_virtual] = ACTIONS(2260),
    [anon_sym_template] = ACTIONS(2260),
    [anon_sym_GT2] = ACTIONS(2262),
    [anon_sym_operator] = ACTIONS(2260),
    [anon_sym_requires] = ACTIONS(2260),
    [anon_sym_precise] = ACTIONS(2260),
    [anon_sym_shared] = ACTIONS(2260),
    [anon_sym_groupshared] = ACTIONS(2260),
    [anon_sym_uniform] = ACTIONS(2260),
    [anon_sym_row_major] = ACTIONS(2260),
    [anon_sym_column_major] = ACTIONS(2260),
    [anon_sym_globallycoherent] = ACTIONS(2260),
    [anon_sym_centroid] = ACTIONS(2260),
    [anon_sym_noperspective] = ACTIONS(2260),
    [anon_sym_nointerpolation] = ACTIONS(2260),
    [anon_sym_sample] = ACTIONS(2260),
    [anon_sym_linear] = ACTIONS(2260),
    [anon_sym_snorm] = ACTIONS(2260),
    [anon_sym_unorm] = ACTIONS(2260),
    [anon_sym_point] = ACTIONS(2260),
    [anon_sym_line] = ACTIONS(2260),
    [anon_sym_triangleadj] = ACTIONS(2260),
    [anon_sym_lineadj] = ACTIONS(2260),
    [anon_sym_triangle] = ACTIONS(2260),
  },
  [2254] = {
    [sym__declaration_modifiers] = STATE(2224),
    [sym_attribute_specifier] = STATE(2224),
    [sym_attribute_declaration] = STATE(2224),
    [sym_ms_declspec_modifier] = STATE(2224),
    [sym_storage_class_specifier] = STATE(2224),
    [sym_type_qualifier] = STATE(2224),
    [sym_alignas_qualifier] = STATE(2331),
    [sym_decltype_auto] = STATE(2274),
    [sym_qualifiers] = STATE(2224),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2224),
    [sym_identifier] = ACTIONS(5214),
    [anon_sym_LPAREN2] = ACTIONS(5216),
    [anon_sym_TILDE] = ACTIONS(5216),
    [anon_sym_STAR] = ACTIONS(5216),
    [anon_sym_AMP_AMP] = ACTIONS(5216),
    [anon_sym_AMP] = ACTIONS(5214),
    [anon_sym_SEMI] = ACTIONS(5395),
    [anon_sym___extension__] = ACTIONS(4981),
    [anon_sym_in] = ACTIONS(5218),
    [anon_sym_out] = ACTIONS(5218),
    [anon_sym_inout] = ACTIONS(5218),
    [anon_sym_extern] = ACTIONS(4985),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5216),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4991),
    [anon_sym___declspec] = ACTIONS(4993),
    [anon_sym___based] = ACTIONS(5214),
    [anon_sym___cdecl] = ACTIONS(5214),
    [anon_sym___clrcall] = ACTIONS(5214),
    [anon_sym___stdcall] = ACTIONS(5214),
    [anon_sym___fastcall] = ACTIONS(5214),
    [anon_sym___thiscall] = ACTIONS(5214),
    [anon_sym___vectorcall] = ACTIONS(5214),
    [anon_sym_LBRACK] = ACTIONS(5214),
    [anon_sym_static] = ACTIONS(4985),
    [anon_sym_register] = ACTIONS(4985),
    [anon_sym_inline] = ACTIONS(4985),
    [anon_sym___inline] = ACTIONS(4985),
    [anon_sym___inline__] = ACTIONS(4985),
    [anon_sym___forceinline] = ACTIONS(4985),
    [anon_sym_thread_local] = ACTIONS(4985),
    [anon_sym___thread] = ACTIONS(4985),
    [anon_sym_const] = ACTIONS(4981),
    [anon_sym_constexpr] = ACTIONS(4981),
    [anon_sym_volatile] = ACTIONS(4981),
    [anon_sym_restrict] = ACTIONS(4981),
    [anon_sym___restrict__] = ACTIONS(4981),
    [anon_sym__Atomic] = ACTIONS(4981),
    [anon_sym__Noreturn] = ACTIONS(4981),
    [anon_sym_noreturn] = ACTIONS(4981),
    [anon_sym_mutable] = ACTIONS(4981),
    [anon_sym_constinit] = ACTIONS(4981),
    [anon_sym_consteval] = ACTIONS(4981),
    [anon_sym_alignas] = ACTIONS(4995),
    [anon_sym__Alignas] = ACTIONS(4995),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5220),
    [anon_sym_decltype] = ACTIONS(5222),
    [sym_virtual] = ACTIONS(5218),
    [anon_sym_template] = ACTIONS(5214),
    [anon_sym_operator] = ACTIONS(5214),
    [anon_sym_precise] = ACTIONS(4997),
    [anon_sym_shared] = ACTIONS(4997),
    [anon_sym_groupshared] = ACTIONS(4997),
    [anon_sym_uniform] = ACTIONS(4997),
    [anon_sym_row_major] = ACTIONS(4997),
    [anon_sym_column_major] = ACTIONS(4997),
    [anon_sym_globallycoherent] = ACTIONS(4997),
    [anon_sym_centroid] = ACTIONS(4997),
    [anon_sym_noperspective] = ACTIONS(4997),
    [anon_sym_nointerpolation] = ACTIONS(4997),
    [anon_sym_sample] = ACTIONS(4997),
    [anon_sym_linear] = ACTIONS(4997),
    [anon_sym_snorm] = ACTIONS(4997),
    [anon_sym_unorm] = ACTIONS(4997),
    [anon_sym_point] = ACTIONS(4997),
    [anon_sym_line] = ACTIONS(4997),
    [anon_sym_triangleadj] = ACTIONS(4997),
    [anon_sym_lineadj] = ACTIONS(4997),
    [anon_sym_triangle] = ACTIONS(4997),
  },
  [2255] = {
    [sym_string_literal] = STATE(1186),
    [sym_identifier] = ACTIONS(5397),
    [anon_sym_LPAREN2] = ACTIONS(5399),
    [anon_sym_TILDE] = ACTIONS(5399),
    [anon_sym_STAR] = ACTIONS(5399),
    [anon_sym_AMP_AMP] = ACTIONS(5399),
    [anon_sym_AMP] = ACTIONS(5397),
    [anon_sym___extension__] = ACTIONS(5397),
    [anon_sym_in] = ACTIONS(5397),
    [anon_sym_out] = ACTIONS(5397),
    [anon_sym_inout] = ACTIONS(5397),
    [anon_sym_extern] = ACTIONS(5397),
    [anon_sym___attribute__] = ACTIONS(5397),
    [anon_sym_COLON_COLON] = ACTIONS(5399),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5399),
    [anon_sym___declspec] = ACTIONS(5397),
    [anon_sym___based] = ACTIONS(5397),
    [anon_sym_signed] = ACTIONS(5397),
    [anon_sym_unsigned] = ACTIONS(5397),
    [anon_sym_long] = ACTIONS(5397),
    [anon_sym_short] = ACTIONS(5397),
    [anon_sym_LBRACK] = ACTIONS(5397),
    [anon_sym_static] = ACTIONS(5397),
    [anon_sym_register] = ACTIONS(5397),
    [anon_sym_inline] = ACTIONS(5397),
    [anon_sym___inline] = ACTIONS(5397),
    [anon_sym___inline__] = ACTIONS(5397),
    [anon_sym___forceinline] = ACTIONS(5397),
    [anon_sym_thread_local] = ACTIONS(5397),
    [anon_sym___thread] = ACTIONS(5397),
    [anon_sym_const] = ACTIONS(5397),
    [anon_sym_constexpr] = ACTIONS(5397),
    [anon_sym_volatile] = ACTIONS(5397),
    [anon_sym_restrict] = ACTIONS(5397),
    [anon_sym___restrict__] = ACTIONS(5397),
    [anon_sym__Atomic] = ACTIONS(5397),
    [anon_sym__Noreturn] = ACTIONS(5397),
    [anon_sym_noreturn] = ACTIONS(5397),
    [anon_sym_mutable] = ACTIONS(5397),
    [anon_sym_constinit] = ACTIONS(5397),
    [anon_sym_consteval] = ACTIONS(5397),
    [anon_sym_alignas] = ACTIONS(5397),
    [anon_sym__Alignas] = ACTIONS(5397),
    [sym_primitive_type] = ACTIONS(5397),
    [anon_sym_enum] = ACTIONS(5397),
    [anon_sym_class] = ACTIONS(5397),
    [anon_sym_struct] = ACTIONS(5397),
    [anon_sym_union] = ACTIONS(5397),
    [anon_sym_L_DQUOTE] = ACTIONS(5401),
    [anon_sym_u_DQUOTE] = ACTIONS(5401),
    [anon_sym_U_DQUOTE] = ACTIONS(5401),
    [anon_sym_u8_DQUOTE] = ACTIONS(5401),
    [anon_sym_DQUOTE] = ACTIONS(5401),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5397),
    [anon_sym_decltype] = ACTIONS(5397),
    [sym_virtual] = ACTIONS(5397),
    [anon_sym_explicit] = ACTIONS(5397),
    [anon_sym_typename] = ACTIONS(5397),
    [anon_sym_template] = ACTIONS(5397),
    [anon_sym_operator] = ACTIONS(5397),
    [anon_sym_precise] = ACTIONS(5397),
    [anon_sym_shared] = ACTIONS(5397),
    [anon_sym_groupshared] = ACTIONS(5397),
    [anon_sym_uniform] = ACTIONS(5397),
    [anon_sym_row_major] = ACTIONS(5397),
    [anon_sym_column_major] = ACTIONS(5397),
    [anon_sym_globallycoherent] = ACTIONS(5397),
    [anon_sym_centroid] = ACTIONS(5397),
    [anon_sym_noperspective] = ACTIONS(5397),
    [anon_sym_nointerpolation] = ACTIONS(5397),
    [anon_sym_sample] = ACTIONS(5397),
    [anon_sym_linear] = ACTIONS(5397),
    [anon_sym_snorm] = ACTIONS(5397),
    [anon_sym_unorm] = ACTIONS(5397),
    [anon_sym_point] = ACTIONS(5397),
    [anon_sym_line] = ACTIONS(5397),
    [anon_sym_triangleadj] = ACTIONS(5397),
    [anon_sym_lineadj] = ACTIONS(5397),
    [anon_sym_triangle] = ACTIONS(5397),
  },
  [2256] = {
    [sym__declaration_modifiers] = STATE(2224),
    [sym_attribute_specifier] = STATE(2224),
    [sym_attribute_declaration] = STATE(2224),
    [sym_ms_declspec_modifier] = STATE(2224),
    [sym_storage_class_specifier] = STATE(2224),
    [sym_type_qualifier] = STATE(2224),
    [sym_alignas_qualifier] = STATE(2331),
    [sym_decltype_auto] = STATE(2274),
    [sym_qualifiers] = STATE(2224),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2224),
    [sym_identifier] = ACTIONS(5214),
    [anon_sym_LPAREN2] = ACTIONS(5216),
    [anon_sym_TILDE] = ACTIONS(5216),
    [anon_sym_STAR] = ACTIONS(5216),
    [anon_sym_AMP_AMP] = ACTIONS(5216),
    [anon_sym_AMP] = ACTIONS(5214),
    [anon_sym_SEMI] = ACTIONS(5403),
    [anon_sym___extension__] = ACTIONS(4981),
    [anon_sym_in] = ACTIONS(5218),
    [anon_sym_out] = ACTIONS(5218),
    [anon_sym_inout] = ACTIONS(5218),
    [anon_sym_extern] = ACTIONS(4985),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5216),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4991),
    [anon_sym___declspec] = ACTIONS(4993),
    [anon_sym___based] = ACTIONS(5214),
    [anon_sym___cdecl] = ACTIONS(5214),
    [anon_sym___clrcall] = ACTIONS(5214),
    [anon_sym___stdcall] = ACTIONS(5214),
    [anon_sym___fastcall] = ACTIONS(5214),
    [anon_sym___thiscall] = ACTIONS(5214),
    [anon_sym___vectorcall] = ACTIONS(5214),
    [anon_sym_LBRACK] = ACTIONS(5214),
    [anon_sym_static] = ACTIONS(4985),
    [anon_sym_register] = ACTIONS(4985),
    [anon_sym_inline] = ACTIONS(4985),
    [anon_sym___inline] = ACTIONS(4985),
    [anon_sym___inline__] = ACTIONS(4985),
    [anon_sym___forceinline] = ACTIONS(4985),
    [anon_sym_thread_local] = ACTIONS(4985),
    [anon_sym___thread] = ACTIONS(4985),
    [anon_sym_const] = ACTIONS(4981),
    [anon_sym_constexpr] = ACTIONS(4981),
    [anon_sym_volatile] = ACTIONS(4981),
    [anon_sym_restrict] = ACTIONS(4981),
    [anon_sym___restrict__] = ACTIONS(4981),
    [anon_sym__Atomic] = ACTIONS(4981),
    [anon_sym__Noreturn] = ACTIONS(4981),
    [anon_sym_noreturn] = ACTIONS(4981),
    [anon_sym_mutable] = ACTIONS(4981),
    [anon_sym_constinit] = ACTIONS(4981),
    [anon_sym_consteval] = ACTIONS(4981),
    [anon_sym_alignas] = ACTIONS(4995),
    [anon_sym__Alignas] = ACTIONS(4995),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5220),
    [anon_sym_decltype] = ACTIONS(5222),
    [sym_virtual] = ACTIONS(5218),
    [anon_sym_template] = ACTIONS(5214),
    [anon_sym_operator] = ACTIONS(5214),
    [anon_sym_precise] = ACTIONS(4997),
    [anon_sym_shared] = ACTIONS(4997),
    [anon_sym_groupshared] = ACTIONS(4997),
    [anon_sym_uniform] = ACTIONS(4997),
    [anon_sym_row_major] = ACTIONS(4997),
    [anon_sym_column_major] = ACTIONS(4997),
    [anon_sym_globallycoherent] = ACTIONS(4997),
    [anon_sym_centroid] = ACTIONS(4997),
    [anon_sym_noperspective] = ACTIONS(4997),
    [anon_sym_nointerpolation] = ACTIONS(4997),
    [anon_sym_sample] = ACTIONS(4997),
    [anon_sym_linear] = ACTIONS(4997),
    [anon_sym_snorm] = ACTIONS(4997),
    [anon_sym_unorm] = ACTIONS(4997),
    [anon_sym_point] = ACTIONS(4997),
    [anon_sym_line] = ACTIONS(4997),
    [anon_sym_triangleadj] = ACTIONS(4997),
    [anon_sym_lineadj] = ACTIONS(4997),
    [anon_sym_triangle] = ACTIONS(4997),
  },
  [2257] = {
    [sym__declaration_modifiers] = STATE(2224),
    [sym_attribute_specifier] = STATE(2224),
    [sym_attribute_declaration] = STATE(2224),
    [sym_ms_declspec_modifier] = STATE(2224),
    [sym_storage_class_specifier] = STATE(2224),
    [sym_type_qualifier] = STATE(2224),
    [sym_alignas_qualifier] = STATE(2331),
    [sym_decltype_auto] = STATE(2274),
    [sym_qualifiers] = STATE(2224),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2224),
    [sym_identifier] = ACTIONS(5214),
    [anon_sym_LPAREN2] = ACTIONS(5216),
    [anon_sym_TILDE] = ACTIONS(5216),
    [anon_sym_STAR] = ACTIONS(5216),
    [anon_sym_AMP_AMP] = ACTIONS(5216),
    [anon_sym_AMP] = ACTIONS(5214),
    [anon_sym_SEMI] = ACTIONS(5405),
    [anon_sym___extension__] = ACTIONS(4981),
    [anon_sym_in] = ACTIONS(5218),
    [anon_sym_out] = ACTIONS(5218),
    [anon_sym_inout] = ACTIONS(5218),
    [anon_sym_extern] = ACTIONS(4985),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5216),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4991),
    [anon_sym___declspec] = ACTIONS(4993),
    [anon_sym___based] = ACTIONS(5214),
    [anon_sym___cdecl] = ACTIONS(5214),
    [anon_sym___clrcall] = ACTIONS(5214),
    [anon_sym___stdcall] = ACTIONS(5214),
    [anon_sym___fastcall] = ACTIONS(5214),
    [anon_sym___thiscall] = ACTIONS(5214),
    [anon_sym___vectorcall] = ACTIONS(5214),
    [anon_sym_LBRACK] = ACTIONS(5214),
    [anon_sym_static] = ACTIONS(4985),
    [anon_sym_register] = ACTIONS(4985),
    [anon_sym_inline] = ACTIONS(4985),
    [anon_sym___inline] = ACTIONS(4985),
    [anon_sym___inline__] = ACTIONS(4985),
    [anon_sym___forceinline] = ACTIONS(4985),
    [anon_sym_thread_local] = ACTIONS(4985),
    [anon_sym___thread] = ACTIONS(4985),
    [anon_sym_const] = ACTIONS(4981),
    [anon_sym_constexpr] = ACTIONS(4981),
    [anon_sym_volatile] = ACTIONS(4981),
    [anon_sym_restrict] = ACTIONS(4981),
    [anon_sym___restrict__] = ACTIONS(4981),
    [anon_sym__Atomic] = ACTIONS(4981),
    [anon_sym__Noreturn] = ACTIONS(4981),
    [anon_sym_noreturn] = ACTIONS(4981),
    [anon_sym_mutable] = ACTIONS(4981),
    [anon_sym_constinit] = ACTIONS(4981),
    [anon_sym_consteval] = ACTIONS(4981),
    [anon_sym_alignas] = ACTIONS(4995),
    [anon_sym__Alignas] = ACTIONS(4995),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5220),
    [anon_sym_decltype] = ACTIONS(5222),
    [sym_virtual] = ACTIONS(5218),
    [anon_sym_template] = ACTIONS(5214),
    [anon_sym_operator] = ACTIONS(5214),
    [anon_sym_precise] = ACTIONS(4997),
    [anon_sym_shared] = ACTIONS(4997),
    [anon_sym_groupshared] = ACTIONS(4997),
    [anon_sym_uniform] = ACTIONS(4997),
    [anon_sym_row_major] = ACTIONS(4997),
    [anon_sym_column_major] = ACTIONS(4997),
    [anon_sym_globallycoherent] = ACTIONS(4997),
    [anon_sym_centroid] = ACTIONS(4997),
    [anon_sym_noperspective] = ACTIONS(4997),
    [anon_sym_nointerpolation] = ACTIONS(4997),
    [anon_sym_sample] = ACTIONS(4997),
    [anon_sym_linear] = ACTIONS(4997),
    [anon_sym_snorm] = ACTIONS(4997),
    [anon_sym_unorm] = ACTIONS(4997),
    [anon_sym_point] = ACTIONS(4997),
    [anon_sym_line] = ACTIONS(4997),
    [anon_sym_triangleadj] = ACTIONS(4997),
    [anon_sym_lineadj] = ACTIONS(4997),
    [anon_sym_triangle] = ACTIONS(4997),
  },
  [2258] = {
    [sym__declaration_modifiers] = STATE(2224),
    [sym_attribute_specifier] = STATE(2224),
    [sym_attribute_declaration] = STATE(2224),
    [sym_ms_declspec_modifier] = STATE(2224),
    [sym_storage_class_specifier] = STATE(2224),
    [sym_type_qualifier] = STATE(2224),
    [sym_alignas_qualifier] = STATE(2331),
    [sym_decltype_auto] = STATE(2274),
    [sym_qualifiers] = STATE(2224),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2224),
    [sym_identifier] = ACTIONS(5214),
    [anon_sym_LPAREN2] = ACTIONS(5216),
    [anon_sym_TILDE] = ACTIONS(5216),
    [anon_sym_STAR] = ACTIONS(5216),
    [anon_sym_AMP_AMP] = ACTIONS(5216),
    [anon_sym_AMP] = ACTIONS(5214),
    [anon_sym_SEMI] = ACTIONS(5407),
    [anon_sym___extension__] = ACTIONS(4981),
    [anon_sym_in] = ACTIONS(5218),
    [anon_sym_out] = ACTIONS(5218),
    [anon_sym_inout] = ACTIONS(5218),
    [anon_sym_extern] = ACTIONS(4985),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5216),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4991),
    [anon_sym___declspec] = ACTIONS(4993),
    [anon_sym___based] = ACTIONS(5214),
    [anon_sym___cdecl] = ACTIONS(5214),
    [anon_sym___clrcall] = ACTIONS(5214),
    [anon_sym___stdcall] = ACTIONS(5214),
    [anon_sym___fastcall] = ACTIONS(5214),
    [anon_sym___thiscall] = ACTIONS(5214),
    [anon_sym___vectorcall] = ACTIONS(5214),
    [anon_sym_LBRACK] = ACTIONS(5214),
    [anon_sym_static] = ACTIONS(4985),
    [anon_sym_register] = ACTIONS(4985),
    [anon_sym_inline] = ACTIONS(4985),
    [anon_sym___inline] = ACTIONS(4985),
    [anon_sym___inline__] = ACTIONS(4985),
    [anon_sym___forceinline] = ACTIONS(4985),
    [anon_sym_thread_local] = ACTIONS(4985),
    [anon_sym___thread] = ACTIONS(4985),
    [anon_sym_const] = ACTIONS(4981),
    [anon_sym_constexpr] = ACTIONS(4981),
    [anon_sym_volatile] = ACTIONS(4981),
    [anon_sym_restrict] = ACTIONS(4981),
    [anon_sym___restrict__] = ACTIONS(4981),
    [anon_sym__Atomic] = ACTIONS(4981),
    [anon_sym__Noreturn] = ACTIONS(4981),
    [anon_sym_noreturn] = ACTIONS(4981),
    [anon_sym_mutable] = ACTIONS(4981),
    [anon_sym_constinit] = ACTIONS(4981),
    [anon_sym_consteval] = ACTIONS(4981),
    [anon_sym_alignas] = ACTIONS(4995),
    [anon_sym__Alignas] = ACTIONS(4995),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5220),
    [anon_sym_decltype] = ACTIONS(5222),
    [sym_virtual] = ACTIONS(5218),
    [anon_sym_template] = ACTIONS(5214),
    [anon_sym_operator] = ACTIONS(5214),
    [anon_sym_precise] = ACTIONS(4997),
    [anon_sym_shared] = ACTIONS(4997),
    [anon_sym_groupshared] = ACTIONS(4997),
    [anon_sym_uniform] = ACTIONS(4997),
    [anon_sym_row_major] = ACTIONS(4997),
    [anon_sym_column_major] = ACTIONS(4997),
    [anon_sym_globallycoherent] = ACTIONS(4997),
    [anon_sym_centroid] = ACTIONS(4997),
    [anon_sym_noperspective] = ACTIONS(4997),
    [anon_sym_nointerpolation] = ACTIONS(4997),
    [anon_sym_sample] = ACTIONS(4997),
    [anon_sym_linear] = ACTIONS(4997),
    [anon_sym_snorm] = ACTIONS(4997),
    [anon_sym_unorm] = ACTIONS(4997),
    [anon_sym_point] = ACTIONS(4997),
    [anon_sym_line] = ACTIONS(4997),
    [anon_sym_triangleadj] = ACTIONS(4997),
    [anon_sym_lineadj] = ACTIONS(4997),
    [anon_sym_triangle] = ACTIONS(4997),
  },
  [2259] = {
    [sym__declaration_modifiers] = STATE(2224),
    [sym_attribute_specifier] = STATE(2224),
    [sym_attribute_declaration] = STATE(2224),
    [sym_ms_declspec_modifier] = STATE(2224),
    [sym_storage_class_specifier] = STATE(2224),
    [sym_type_qualifier] = STATE(2224),
    [sym_alignas_qualifier] = STATE(2331),
    [sym_decltype_auto] = STATE(2274),
    [sym_qualifiers] = STATE(2224),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2224),
    [sym_identifier] = ACTIONS(5214),
    [anon_sym_LPAREN2] = ACTIONS(5216),
    [anon_sym_TILDE] = ACTIONS(5216),
    [anon_sym_STAR] = ACTIONS(5216),
    [anon_sym_AMP_AMP] = ACTIONS(5216),
    [anon_sym_AMP] = ACTIONS(5214),
    [anon_sym_SEMI] = ACTIONS(5409),
    [anon_sym___extension__] = ACTIONS(4981),
    [anon_sym_in] = ACTIONS(5218),
    [anon_sym_out] = ACTIONS(5218),
    [anon_sym_inout] = ACTIONS(5218),
    [anon_sym_extern] = ACTIONS(4985),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5216),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4991),
    [anon_sym___declspec] = ACTIONS(4993),
    [anon_sym___based] = ACTIONS(5214),
    [anon_sym___cdecl] = ACTIONS(5214),
    [anon_sym___clrcall] = ACTIONS(5214),
    [anon_sym___stdcall] = ACTIONS(5214),
    [anon_sym___fastcall] = ACTIONS(5214),
    [anon_sym___thiscall] = ACTIONS(5214),
    [anon_sym___vectorcall] = ACTIONS(5214),
    [anon_sym_LBRACK] = ACTIONS(5214),
    [anon_sym_static] = ACTIONS(4985),
    [anon_sym_register] = ACTIONS(4985),
    [anon_sym_inline] = ACTIONS(4985),
    [anon_sym___inline] = ACTIONS(4985),
    [anon_sym___inline__] = ACTIONS(4985),
    [anon_sym___forceinline] = ACTIONS(4985),
    [anon_sym_thread_local] = ACTIONS(4985),
    [anon_sym___thread] = ACTIONS(4985),
    [anon_sym_const] = ACTIONS(4981),
    [anon_sym_constexpr] = ACTIONS(4981),
    [anon_sym_volatile] = ACTIONS(4981),
    [anon_sym_restrict] = ACTIONS(4981),
    [anon_sym___restrict__] = ACTIONS(4981),
    [anon_sym__Atomic] = ACTIONS(4981),
    [anon_sym__Noreturn] = ACTIONS(4981),
    [anon_sym_noreturn] = ACTIONS(4981),
    [anon_sym_mutable] = ACTIONS(4981),
    [anon_sym_constinit] = ACTIONS(4981),
    [anon_sym_consteval] = ACTIONS(4981),
    [anon_sym_alignas] = ACTIONS(4995),
    [anon_sym__Alignas] = ACTIONS(4995),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5220),
    [anon_sym_decltype] = ACTIONS(5222),
    [sym_virtual] = ACTIONS(5218),
    [anon_sym_template] = ACTIONS(5214),
    [anon_sym_operator] = ACTIONS(5214),
    [anon_sym_precise] = ACTIONS(4997),
    [anon_sym_shared] = ACTIONS(4997),
    [anon_sym_groupshared] = ACTIONS(4997),
    [anon_sym_uniform] = ACTIONS(4997),
    [anon_sym_row_major] = ACTIONS(4997),
    [anon_sym_column_major] = ACTIONS(4997),
    [anon_sym_globallycoherent] = ACTIONS(4997),
    [anon_sym_centroid] = ACTIONS(4997),
    [anon_sym_noperspective] = ACTIONS(4997),
    [anon_sym_nointerpolation] = ACTIONS(4997),
    [anon_sym_sample] = ACTIONS(4997),
    [anon_sym_linear] = ACTIONS(4997),
    [anon_sym_snorm] = ACTIONS(4997),
    [anon_sym_unorm] = ACTIONS(4997),
    [anon_sym_point] = ACTIONS(4997),
    [anon_sym_line] = ACTIONS(4997),
    [anon_sym_triangleadj] = ACTIONS(4997),
    [anon_sym_lineadj] = ACTIONS(4997),
    [anon_sym_triangle] = ACTIONS(4997),
  },
  [2260] = {
    [sym_string_literal] = STATE(1187),
    [sym_identifier] = ACTIONS(5397),
    [anon_sym_LPAREN2] = ACTIONS(5399),
    [anon_sym_TILDE] = ACTIONS(5399),
    [anon_sym_STAR] = ACTIONS(5399),
    [anon_sym_AMP_AMP] = ACTIONS(5399),
    [anon_sym_AMP] = ACTIONS(5397),
    [anon_sym___extension__] = ACTIONS(5397),
    [anon_sym_in] = ACTIONS(5397),
    [anon_sym_out] = ACTIONS(5397),
    [anon_sym_inout] = ACTIONS(5397),
    [anon_sym_extern] = ACTIONS(5397),
    [anon_sym___attribute__] = ACTIONS(5397),
    [anon_sym_COLON_COLON] = ACTIONS(5399),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5399),
    [anon_sym___declspec] = ACTIONS(5397),
    [anon_sym___based] = ACTIONS(5397),
    [anon_sym_signed] = ACTIONS(5397),
    [anon_sym_unsigned] = ACTIONS(5397),
    [anon_sym_long] = ACTIONS(5397),
    [anon_sym_short] = ACTIONS(5397),
    [anon_sym_LBRACK] = ACTIONS(5397),
    [anon_sym_static] = ACTIONS(5397),
    [anon_sym_register] = ACTIONS(5397),
    [anon_sym_inline] = ACTIONS(5397),
    [anon_sym___inline] = ACTIONS(5397),
    [anon_sym___inline__] = ACTIONS(5397),
    [anon_sym___forceinline] = ACTIONS(5397),
    [anon_sym_thread_local] = ACTIONS(5397),
    [anon_sym___thread] = ACTIONS(5397),
    [anon_sym_const] = ACTIONS(5397),
    [anon_sym_constexpr] = ACTIONS(5397),
    [anon_sym_volatile] = ACTIONS(5397),
    [anon_sym_restrict] = ACTIONS(5397),
    [anon_sym___restrict__] = ACTIONS(5397),
    [anon_sym__Atomic] = ACTIONS(5397),
    [anon_sym__Noreturn] = ACTIONS(5397),
    [anon_sym_noreturn] = ACTIONS(5397),
    [anon_sym_mutable] = ACTIONS(5397),
    [anon_sym_constinit] = ACTIONS(5397),
    [anon_sym_consteval] = ACTIONS(5397),
    [anon_sym_alignas] = ACTIONS(5397),
    [anon_sym__Alignas] = ACTIONS(5397),
    [sym_primitive_type] = ACTIONS(5397),
    [anon_sym_enum] = ACTIONS(5397),
    [anon_sym_class] = ACTIONS(5397),
    [anon_sym_struct] = ACTIONS(5397),
    [anon_sym_union] = ACTIONS(5397),
    [anon_sym_L_DQUOTE] = ACTIONS(5401),
    [anon_sym_u_DQUOTE] = ACTIONS(5401),
    [anon_sym_U_DQUOTE] = ACTIONS(5401),
    [anon_sym_u8_DQUOTE] = ACTIONS(5401),
    [anon_sym_DQUOTE] = ACTIONS(5401),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5397),
    [anon_sym_decltype] = ACTIONS(5397),
    [sym_virtual] = ACTIONS(5397),
    [anon_sym_explicit] = ACTIONS(5397),
    [anon_sym_typename] = ACTIONS(5397),
    [anon_sym_template] = ACTIONS(5397),
    [anon_sym_operator] = ACTIONS(5397),
    [anon_sym_precise] = ACTIONS(5397),
    [anon_sym_shared] = ACTIONS(5397),
    [anon_sym_groupshared] = ACTIONS(5397),
    [anon_sym_uniform] = ACTIONS(5397),
    [anon_sym_row_major] = ACTIONS(5397),
    [anon_sym_column_major] = ACTIONS(5397),
    [anon_sym_globallycoherent] = ACTIONS(5397),
    [anon_sym_centroid] = ACTIONS(5397),
    [anon_sym_noperspective] = ACTIONS(5397),
    [anon_sym_nointerpolation] = ACTIONS(5397),
    [anon_sym_sample] = ACTIONS(5397),
    [anon_sym_linear] = ACTIONS(5397),
    [anon_sym_snorm] = ACTIONS(5397),
    [anon_sym_unorm] = ACTIONS(5397),
    [anon_sym_point] = ACTIONS(5397),
    [anon_sym_line] = ACTIONS(5397),
    [anon_sym_triangleadj] = ACTIONS(5397),
    [anon_sym_lineadj] = ACTIONS(5397),
    [anon_sym_triangle] = ACTIONS(5397),
  },
  [2261] = {
    [sym_string_literal] = STATE(1184),
    [sym_identifier] = ACTIONS(5397),
    [anon_sym_LPAREN2] = ACTIONS(5399),
    [anon_sym_TILDE] = ACTIONS(5399),
    [anon_sym_STAR] = ACTIONS(5399),
    [anon_sym_AMP_AMP] = ACTIONS(5399),
    [anon_sym_AMP] = ACTIONS(5397),
    [anon_sym___extension__] = ACTIONS(5397),
    [anon_sym_in] = ACTIONS(5397),
    [anon_sym_out] = ACTIONS(5397),
    [anon_sym_inout] = ACTIONS(5397),
    [anon_sym_extern] = ACTIONS(5397),
    [anon_sym___attribute__] = ACTIONS(5397),
    [anon_sym_COLON_COLON] = ACTIONS(5399),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5399),
    [anon_sym___declspec] = ACTIONS(5397),
    [anon_sym___based] = ACTIONS(5397),
    [anon_sym_signed] = ACTIONS(5397),
    [anon_sym_unsigned] = ACTIONS(5397),
    [anon_sym_long] = ACTIONS(5397),
    [anon_sym_short] = ACTIONS(5397),
    [anon_sym_LBRACK] = ACTIONS(5397),
    [anon_sym_static] = ACTIONS(5397),
    [anon_sym_register] = ACTIONS(5397),
    [anon_sym_inline] = ACTIONS(5397),
    [anon_sym___inline] = ACTIONS(5397),
    [anon_sym___inline__] = ACTIONS(5397),
    [anon_sym___forceinline] = ACTIONS(5397),
    [anon_sym_thread_local] = ACTIONS(5397),
    [anon_sym___thread] = ACTIONS(5397),
    [anon_sym_const] = ACTIONS(5397),
    [anon_sym_constexpr] = ACTIONS(5397),
    [anon_sym_volatile] = ACTIONS(5397),
    [anon_sym_restrict] = ACTIONS(5397),
    [anon_sym___restrict__] = ACTIONS(5397),
    [anon_sym__Atomic] = ACTIONS(5397),
    [anon_sym__Noreturn] = ACTIONS(5397),
    [anon_sym_noreturn] = ACTIONS(5397),
    [anon_sym_mutable] = ACTIONS(5397),
    [anon_sym_constinit] = ACTIONS(5397),
    [anon_sym_consteval] = ACTIONS(5397),
    [anon_sym_alignas] = ACTIONS(5397),
    [anon_sym__Alignas] = ACTIONS(5397),
    [sym_primitive_type] = ACTIONS(5397),
    [anon_sym_enum] = ACTIONS(5397),
    [anon_sym_class] = ACTIONS(5397),
    [anon_sym_struct] = ACTIONS(5397),
    [anon_sym_union] = ACTIONS(5397),
    [anon_sym_L_DQUOTE] = ACTIONS(5401),
    [anon_sym_u_DQUOTE] = ACTIONS(5401),
    [anon_sym_U_DQUOTE] = ACTIONS(5401),
    [anon_sym_u8_DQUOTE] = ACTIONS(5401),
    [anon_sym_DQUOTE] = ACTIONS(5401),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5397),
    [anon_sym_decltype] = ACTIONS(5397),
    [sym_virtual] = ACTIONS(5397),
    [anon_sym_explicit] = ACTIONS(5397),
    [anon_sym_typename] = ACTIONS(5397),
    [anon_sym_template] = ACTIONS(5397),
    [anon_sym_operator] = ACTIONS(5397),
    [anon_sym_precise] = ACTIONS(5397),
    [anon_sym_shared] = ACTIONS(5397),
    [anon_sym_groupshared] = ACTIONS(5397),
    [anon_sym_uniform] = ACTIONS(5397),
    [anon_sym_row_major] = ACTIONS(5397),
    [anon_sym_column_major] = ACTIONS(5397),
    [anon_sym_globallycoherent] = ACTIONS(5397),
    [anon_sym_centroid] = ACTIONS(5397),
    [anon_sym_noperspective] = ACTIONS(5397),
    [anon_sym_nointerpolation] = ACTIONS(5397),
    [anon_sym_sample] = ACTIONS(5397),
    [anon_sym_linear] = ACTIONS(5397),
    [anon_sym_snorm] = ACTIONS(5397),
    [anon_sym_unorm] = ACTIONS(5397),
    [anon_sym_point] = ACTIONS(5397),
    [anon_sym_line] = ACTIONS(5397),
    [anon_sym_triangleadj] = ACTIONS(5397),
    [anon_sym_lineadj] = ACTIONS(5397),
    [anon_sym_triangle] = ACTIONS(5397),
  },
  [2262] = {
    [sym_identifier] = ACTIONS(5353),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5355),
    [anon_sym_COMMA] = ACTIONS(5355),
    [anon_sym_RPAREN] = ACTIONS(5355),
    [anon_sym_LPAREN2] = ACTIONS(5355),
    [anon_sym_TILDE] = ACTIONS(5355),
    [anon_sym_STAR] = ACTIONS(5355),
    [anon_sym_AMP_AMP] = ACTIONS(5355),
    [anon_sym_AMP] = ACTIONS(5353),
    [anon_sym_COLON] = ACTIONS(5353),
    [anon_sym_SEMI] = ACTIONS(5355),
    [anon_sym___extension__] = ACTIONS(5353),
    [anon_sym_in] = ACTIONS(5353),
    [anon_sym_out] = ACTIONS(5353),
    [anon_sym_inout] = ACTIONS(5353),
    [anon_sym_extern] = ACTIONS(5353),
    [anon_sym___attribute__] = ACTIONS(5353),
    [anon_sym_COLON_COLON] = ACTIONS(5355),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5355),
    [anon_sym___declspec] = ACTIONS(5353),
    [anon_sym___based] = ACTIONS(5353),
    [anon_sym___cdecl] = ACTIONS(5353),
    [anon_sym___clrcall] = ACTIONS(5353),
    [anon_sym___stdcall] = ACTIONS(5353),
    [anon_sym___fastcall] = ACTIONS(5353),
    [anon_sym___thiscall] = ACTIONS(5353),
    [anon_sym___vectorcall] = ACTIONS(5353),
    [anon_sym_LBRACE] = ACTIONS(5355),
    [anon_sym_LBRACK] = ACTIONS(5353),
    [anon_sym_static] = ACTIONS(5353),
    [anon_sym_EQ] = ACTIONS(5355),
    [anon_sym_register] = ACTIONS(5353),
    [anon_sym_inline] = ACTIONS(5353),
    [anon_sym___inline] = ACTIONS(5353),
    [anon_sym___inline__] = ACTIONS(5353),
    [anon_sym___forceinline] = ACTIONS(5353),
    [anon_sym_thread_local] = ACTIONS(5353),
    [anon_sym___thread] = ACTIONS(5353),
    [anon_sym_const] = ACTIONS(5353),
    [anon_sym_constexpr] = ACTIONS(5353),
    [anon_sym_volatile] = ACTIONS(5353),
    [anon_sym_restrict] = ACTIONS(5353),
    [anon_sym___restrict__] = ACTIONS(5353),
    [anon_sym__Atomic] = ACTIONS(5353),
    [anon_sym__Noreturn] = ACTIONS(5353),
    [anon_sym_noreturn] = ACTIONS(5353),
    [anon_sym_mutable] = ACTIONS(5353),
    [anon_sym_constinit] = ACTIONS(5353),
    [anon_sym_consteval] = ACTIONS(5353),
    [anon_sym_alignas] = ACTIONS(5353),
    [anon_sym__Alignas] = ACTIONS(5353),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5353),
    [anon_sym_decltype] = ACTIONS(5353),
    [anon_sym_final] = ACTIONS(5353),
    [anon_sym_override] = ACTIONS(5353),
    [sym_virtual] = ACTIONS(5353),
    [anon_sym_template] = ACTIONS(5353),
    [anon_sym_GT2] = ACTIONS(5355),
    [anon_sym_operator] = ACTIONS(5353),
    [anon_sym_requires] = ACTIONS(5353),
    [anon_sym_precise] = ACTIONS(5353),
    [anon_sym_shared] = ACTIONS(5353),
    [anon_sym_groupshared] = ACTIONS(5353),
    [anon_sym_uniform] = ACTIONS(5353),
    [anon_sym_row_major] = ACTIONS(5353),
    [anon_sym_column_major] = ACTIONS(5353),
    [anon_sym_globallycoherent] = ACTIONS(5353),
    [anon_sym_centroid] = ACTIONS(5353),
    [anon_sym_noperspective] = ACTIONS(5353),
    [anon_sym_nointerpolation] = ACTIONS(5353),
    [anon_sym_sample] = ACTIONS(5353),
    [anon_sym_linear] = ACTIONS(5353),
    [anon_sym_snorm] = ACTIONS(5353),
    [anon_sym_unorm] = ACTIONS(5353),
    [anon_sym_point] = ACTIONS(5353),
    [anon_sym_line] = ACTIONS(5353),
    [anon_sym_triangleadj] = ACTIONS(5353),
    [anon_sym_lineadj] = ACTIONS(5353),
    [anon_sym_triangle] = ACTIONS(5353),
  },
  [2263] = {
    [sym__declaration_modifiers] = STATE(2224),
    [sym_attribute_specifier] = STATE(2224),
    [sym_attribute_declaration] = STATE(2224),
    [sym_ms_declspec_modifier] = STATE(2224),
    [sym_storage_class_specifier] = STATE(2224),
    [sym_type_qualifier] = STATE(2224),
    [sym_alignas_qualifier] = STATE(2331),
    [sym_decltype_auto] = STATE(2274),
    [sym_qualifiers] = STATE(2224),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2224),
    [sym_identifier] = ACTIONS(5214),
    [anon_sym_LPAREN2] = ACTIONS(5216),
    [anon_sym_TILDE] = ACTIONS(5216),
    [anon_sym_STAR] = ACTIONS(5216),
    [anon_sym_AMP_AMP] = ACTIONS(5216),
    [anon_sym_AMP] = ACTIONS(5214),
    [anon_sym_SEMI] = ACTIONS(5411),
    [anon_sym___extension__] = ACTIONS(4981),
    [anon_sym_in] = ACTIONS(5218),
    [anon_sym_out] = ACTIONS(5218),
    [anon_sym_inout] = ACTIONS(5218),
    [anon_sym_extern] = ACTIONS(4985),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5216),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4991),
    [anon_sym___declspec] = ACTIONS(4993),
    [anon_sym___based] = ACTIONS(5214),
    [anon_sym___cdecl] = ACTIONS(5214),
    [anon_sym___clrcall] = ACTIONS(5214),
    [anon_sym___stdcall] = ACTIONS(5214),
    [anon_sym___fastcall] = ACTIONS(5214),
    [anon_sym___thiscall] = ACTIONS(5214),
    [anon_sym___vectorcall] = ACTIONS(5214),
    [anon_sym_LBRACK] = ACTIONS(5214),
    [anon_sym_static] = ACTIONS(4985),
    [anon_sym_register] = ACTIONS(4985),
    [anon_sym_inline] = ACTIONS(4985),
    [anon_sym___inline] = ACTIONS(4985),
    [anon_sym___inline__] = ACTIONS(4985),
    [anon_sym___forceinline] = ACTIONS(4985),
    [anon_sym_thread_local] = ACTIONS(4985),
    [anon_sym___thread] = ACTIONS(4985),
    [anon_sym_const] = ACTIONS(4981),
    [anon_sym_constexpr] = ACTIONS(4981),
    [anon_sym_volatile] = ACTIONS(4981),
    [anon_sym_restrict] = ACTIONS(4981),
    [anon_sym___restrict__] = ACTIONS(4981),
    [anon_sym__Atomic] = ACTIONS(4981),
    [anon_sym__Noreturn] = ACTIONS(4981),
    [anon_sym_noreturn] = ACTIONS(4981),
    [anon_sym_mutable] = ACTIONS(4981),
    [anon_sym_constinit] = ACTIONS(4981),
    [anon_sym_consteval] = ACTIONS(4981),
    [anon_sym_alignas] = ACTIONS(4995),
    [anon_sym__Alignas] = ACTIONS(4995),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5220),
    [anon_sym_decltype] = ACTIONS(5222),
    [sym_virtual] = ACTIONS(5218),
    [anon_sym_template] = ACTIONS(5214),
    [anon_sym_operator] = ACTIONS(5214),
    [anon_sym_precise] = ACTIONS(4997),
    [anon_sym_shared] = ACTIONS(4997),
    [anon_sym_groupshared] = ACTIONS(4997),
    [anon_sym_uniform] = ACTIONS(4997),
    [anon_sym_row_major] = ACTIONS(4997),
    [anon_sym_column_major] = ACTIONS(4997),
    [anon_sym_globallycoherent] = ACTIONS(4997),
    [anon_sym_centroid] = ACTIONS(4997),
    [anon_sym_noperspective] = ACTIONS(4997),
    [anon_sym_nointerpolation] = ACTIONS(4997),
    [anon_sym_sample] = ACTIONS(4997),
    [anon_sym_linear] = ACTIONS(4997),
    [anon_sym_snorm] = ACTIONS(4997),
    [anon_sym_unorm] = ACTIONS(4997),
    [anon_sym_point] = ACTIONS(4997),
    [anon_sym_line] = ACTIONS(4997),
    [anon_sym_triangleadj] = ACTIONS(4997),
    [anon_sym_lineadj] = ACTIONS(4997),
    [anon_sym_triangle] = ACTIONS(4997),
  },
  [2264] = {
    [sym_decltype_auto] = STATE(2274),
    [sym_identifier] = ACTIONS(5413),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5415),
    [anon_sym_COMMA] = ACTIONS(5415),
    [anon_sym_RPAREN] = ACTIONS(5415),
    [anon_sym_LPAREN2] = ACTIONS(5415),
    [anon_sym_TILDE] = ACTIONS(5415),
    [anon_sym_STAR] = ACTIONS(5415),
    [anon_sym_AMP_AMP] = ACTIONS(5415),
    [anon_sym_AMP] = ACTIONS(5413),
    [anon_sym_COLON] = ACTIONS(5413),
    [anon_sym_SEMI] = ACTIONS(5415),
    [anon_sym___extension__] = ACTIONS(5413),
    [anon_sym_in] = ACTIONS(5413),
    [anon_sym_out] = ACTIONS(5413),
    [anon_sym_inout] = ACTIONS(5413),
    [anon_sym_extern] = ACTIONS(5413),
    [anon_sym___attribute__] = ACTIONS(5413),
    [anon_sym_COLON_COLON] = ACTIONS(5415),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5415),
    [anon_sym___declspec] = ACTIONS(5413),
    [anon_sym___based] = ACTIONS(5413),
    [anon_sym___cdecl] = ACTIONS(5413),
    [anon_sym___clrcall] = ACTIONS(5413),
    [anon_sym___stdcall] = ACTIONS(5413),
    [anon_sym___fastcall] = ACTIONS(5413),
    [anon_sym___thiscall] = ACTIONS(5413),
    [anon_sym___vectorcall] = ACTIONS(5413),
    [anon_sym_LBRACK] = ACTIONS(5413),
    [anon_sym_static] = ACTIONS(5413),
    [anon_sym_EQ] = ACTIONS(5415),
    [anon_sym_register] = ACTIONS(5413),
    [anon_sym_inline] = ACTIONS(5413),
    [anon_sym___inline] = ACTIONS(5413),
    [anon_sym___inline__] = ACTIONS(5413),
    [anon_sym___forceinline] = ACTIONS(5413),
    [anon_sym_thread_local] = ACTIONS(5413),
    [anon_sym___thread] = ACTIONS(5413),
    [anon_sym_const] = ACTIONS(5413),
    [anon_sym_constexpr] = ACTIONS(5413),
    [anon_sym_volatile] = ACTIONS(5413),
    [anon_sym_restrict] = ACTIONS(5413),
    [anon_sym___restrict__] = ACTIONS(5413),
    [anon_sym__Atomic] = ACTIONS(5413),
    [anon_sym__Noreturn] = ACTIONS(5413),
    [anon_sym_noreturn] = ACTIONS(5413),
    [anon_sym_mutable] = ACTIONS(5413),
    [anon_sym_constinit] = ACTIONS(5413),
    [anon_sym_consteval] = ACTIONS(5413),
    [anon_sym_alignas] = ACTIONS(5413),
    [anon_sym__Alignas] = ACTIONS(5413),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5220),
    [anon_sym_decltype] = ACTIONS(5222),
    [anon_sym_final] = ACTIONS(5413),
    [anon_sym_override] = ACTIONS(5413),
    [sym_virtual] = ACTIONS(5413),
    [anon_sym_template] = ACTIONS(5413),
    [anon_sym_GT2] = ACTIONS(5415),
    [anon_sym_operator] = ACTIONS(5413),
    [anon_sym_requires] = ACTIONS(5413),
    [anon_sym_precise] = ACTIONS(5413),
    [anon_sym_shared] = ACTIONS(5413),
    [anon_sym_groupshared] = ACTIONS(5413),
    [anon_sym_uniform] = ACTIONS(5413),
    [anon_sym_row_major] = ACTIONS(5413),
    [anon_sym_column_major] = ACTIONS(5413),
    [anon_sym_globallycoherent] = ACTIONS(5413),
    [anon_sym_centroid] = ACTIONS(5413),
    [anon_sym_noperspective] = ACTIONS(5413),
    [anon_sym_nointerpolation] = ACTIONS(5413),
    [anon_sym_sample] = ACTIONS(5413),
    [anon_sym_linear] = ACTIONS(5413),
    [anon_sym_snorm] = ACTIONS(5413),
    [anon_sym_unorm] = ACTIONS(5413),
    [anon_sym_point] = ACTIONS(5413),
    [anon_sym_line] = ACTIONS(5413),
    [anon_sym_triangleadj] = ACTIONS(5413),
    [anon_sym_lineadj] = ACTIONS(5413),
    [anon_sym_triangle] = ACTIONS(5413),
  },
  [2265] = {
    [sym__declaration_modifiers] = STATE(2224),
    [sym_attribute_specifier] = STATE(2224),
    [sym_attribute_declaration] = STATE(2224),
    [sym_ms_declspec_modifier] = STATE(2224),
    [sym_storage_class_specifier] = STATE(2224),
    [sym_type_qualifier] = STATE(2224),
    [sym_alignas_qualifier] = STATE(2331),
    [sym_decltype_auto] = STATE(2274),
    [sym_qualifiers] = STATE(2224),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2224),
    [sym_identifier] = ACTIONS(5214),
    [anon_sym_LPAREN2] = ACTIONS(5216),
    [anon_sym_TILDE] = ACTIONS(5216),
    [anon_sym_STAR] = ACTIONS(5216),
    [anon_sym_AMP_AMP] = ACTIONS(5216),
    [anon_sym_AMP] = ACTIONS(5214),
    [anon_sym_SEMI] = ACTIONS(5417),
    [anon_sym___extension__] = ACTIONS(4981),
    [anon_sym_in] = ACTIONS(5218),
    [anon_sym_out] = ACTIONS(5218),
    [anon_sym_inout] = ACTIONS(5218),
    [anon_sym_extern] = ACTIONS(4985),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5216),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4991),
    [anon_sym___declspec] = ACTIONS(4993),
    [anon_sym___based] = ACTIONS(5214),
    [anon_sym___cdecl] = ACTIONS(5214),
    [anon_sym___clrcall] = ACTIONS(5214),
    [anon_sym___stdcall] = ACTIONS(5214),
    [anon_sym___fastcall] = ACTIONS(5214),
    [anon_sym___thiscall] = ACTIONS(5214),
    [anon_sym___vectorcall] = ACTIONS(5214),
    [anon_sym_LBRACK] = ACTIONS(5214),
    [anon_sym_static] = ACTIONS(4985),
    [anon_sym_register] = ACTIONS(4985),
    [anon_sym_inline] = ACTIONS(4985),
    [anon_sym___inline] = ACTIONS(4985),
    [anon_sym___inline__] = ACTIONS(4985),
    [anon_sym___forceinline] = ACTIONS(4985),
    [anon_sym_thread_local] = ACTIONS(4985),
    [anon_sym___thread] = ACTIONS(4985),
    [anon_sym_const] = ACTIONS(4981),
    [anon_sym_constexpr] = ACTIONS(4981),
    [anon_sym_volatile] = ACTIONS(4981),
    [anon_sym_restrict] = ACTIONS(4981),
    [anon_sym___restrict__] = ACTIONS(4981),
    [anon_sym__Atomic] = ACTIONS(4981),
    [anon_sym__Noreturn] = ACTIONS(4981),
    [anon_sym_noreturn] = ACTIONS(4981),
    [anon_sym_mutable] = ACTIONS(4981),
    [anon_sym_constinit] = ACTIONS(4981),
    [anon_sym_consteval] = ACTIONS(4981),
    [anon_sym_alignas] = ACTIONS(4995),
    [anon_sym__Alignas] = ACTIONS(4995),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5220),
    [anon_sym_decltype] = ACTIONS(5222),
    [sym_virtual] = ACTIONS(5218),
    [anon_sym_template] = ACTIONS(5214),
    [anon_sym_operator] = ACTIONS(5214),
    [anon_sym_precise] = ACTIONS(4997),
    [anon_sym_shared] = ACTIONS(4997),
    [anon_sym_groupshared] = ACTIONS(4997),
    [anon_sym_uniform] = ACTIONS(4997),
    [anon_sym_row_major] = ACTIONS(4997),
    [anon_sym_column_major] = ACTIONS(4997),
    [anon_sym_globallycoherent] = ACTIONS(4997),
    [anon_sym_centroid] = ACTIONS(4997),
    [anon_sym_noperspective] = ACTIONS(4997),
    [anon_sym_nointerpolation] = ACTIONS(4997),
    [anon_sym_sample] = ACTIONS(4997),
    [anon_sym_linear] = ACTIONS(4997),
    [anon_sym_snorm] = ACTIONS(4997),
    [anon_sym_unorm] = ACTIONS(4997),
    [anon_sym_point] = ACTIONS(4997),
    [anon_sym_line] = ACTIONS(4997),
    [anon_sym_triangleadj] = ACTIONS(4997),
    [anon_sym_lineadj] = ACTIONS(4997),
    [anon_sym_triangle] = ACTIONS(4997),
  },
  [2266] = {
    [sym_string_literal] = STATE(1183),
    [sym_identifier] = ACTIONS(5397),
    [anon_sym_LPAREN2] = ACTIONS(5399),
    [anon_sym_TILDE] = ACTIONS(5399),
    [anon_sym_STAR] = ACTIONS(5399),
    [anon_sym_AMP_AMP] = ACTIONS(5399),
    [anon_sym_AMP] = ACTIONS(5397),
    [anon_sym___extension__] = ACTIONS(5397),
    [anon_sym_in] = ACTIONS(5397),
    [anon_sym_out] = ACTIONS(5397),
    [anon_sym_inout] = ACTIONS(5397),
    [anon_sym_extern] = ACTIONS(5397),
    [anon_sym___attribute__] = ACTIONS(5397),
    [anon_sym_COLON_COLON] = ACTIONS(5399),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5399),
    [anon_sym___declspec] = ACTIONS(5397),
    [anon_sym___based] = ACTIONS(5397),
    [anon_sym_signed] = ACTIONS(5397),
    [anon_sym_unsigned] = ACTIONS(5397),
    [anon_sym_long] = ACTIONS(5397),
    [anon_sym_short] = ACTIONS(5397),
    [anon_sym_LBRACK] = ACTIONS(5397),
    [anon_sym_static] = ACTIONS(5397),
    [anon_sym_register] = ACTIONS(5397),
    [anon_sym_inline] = ACTIONS(5397),
    [anon_sym___inline] = ACTIONS(5397),
    [anon_sym___inline__] = ACTIONS(5397),
    [anon_sym___forceinline] = ACTIONS(5397),
    [anon_sym_thread_local] = ACTIONS(5397),
    [anon_sym___thread] = ACTIONS(5397),
    [anon_sym_const] = ACTIONS(5397),
    [anon_sym_constexpr] = ACTIONS(5397),
    [anon_sym_volatile] = ACTIONS(5397),
    [anon_sym_restrict] = ACTIONS(5397),
    [anon_sym___restrict__] = ACTIONS(5397),
    [anon_sym__Atomic] = ACTIONS(5397),
    [anon_sym__Noreturn] = ACTIONS(5397),
    [anon_sym_noreturn] = ACTIONS(5397),
    [anon_sym_mutable] = ACTIONS(5397),
    [anon_sym_constinit] = ACTIONS(5397),
    [anon_sym_consteval] = ACTIONS(5397),
    [anon_sym_alignas] = ACTIONS(5397),
    [anon_sym__Alignas] = ACTIONS(5397),
    [sym_primitive_type] = ACTIONS(5397),
    [anon_sym_enum] = ACTIONS(5397),
    [anon_sym_class] = ACTIONS(5397),
    [anon_sym_struct] = ACTIONS(5397),
    [anon_sym_union] = ACTIONS(5397),
    [anon_sym_L_DQUOTE] = ACTIONS(5401),
    [anon_sym_u_DQUOTE] = ACTIONS(5401),
    [anon_sym_U_DQUOTE] = ACTIONS(5401),
    [anon_sym_u8_DQUOTE] = ACTIONS(5401),
    [anon_sym_DQUOTE] = ACTIONS(5401),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5397),
    [anon_sym_decltype] = ACTIONS(5397),
    [sym_virtual] = ACTIONS(5397),
    [anon_sym_explicit] = ACTIONS(5397),
    [anon_sym_typename] = ACTIONS(5397),
    [anon_sym_template] = ACTIONS(5397),
    [anon_sym_operator] = ACTIONS(5397),
    [anon_sym_precise] = ACTIONS(5397),
    [anon_sym_shared] = ACTIONS(5397),
    [anon_sym_groupshared] = ACTIONS(5397),
    [anon_sym_uniform] = ACTIONS(5397),
    [anon_sym_row_major] = ACTIONS(5397),
    [anon_sym_column_major] = ACTIONS(5397),
    [anon_sym_globallycoherent] = ACTIONS(5397),
    [anon_sym_centroid] = ACTIONS(5397),
    [anon_sym_noperspective] = ACTIONS(5397),
    [anon_sym_nointerpolation] = ACTIONS(5397),
    [anon_sym_sample] = ACTIONS(5397),
    [anon_sym_linear] = ACTIONS(5397),
    [anon_sym_snorm] = ACTIONS(5397),
    [anon_sym_unorm] = ACTIONS(5397),
    [anon_sym_point] = ACTIONS(5397),
    [anon_sym_line] = ACTIONS(5397),
    [anon_sym_triangleadj] = ACTIONS(5397),
    [anon_sym_lineadj] = ACTIONS(5397),
    [anon_sym_triangle] = ACTIONS(5397),
  },
  [2267] = {
    [sym_identifier] = ACTIONS(5357),
    [anon_sym_LPAREN2] = ACTIONS(5359),
    [anon_sym_STAR] = ACTIONS(5359),
    [anon_sym_AMP_AMP] = ACTIONS(5359),
    [anon_sym_AMP] = ACTIONS(5361),
    [anon_sym_LT] = ACTIONS(5359),
    [anon_sym___extension__] = ACTIONS(5357),
    [anon_sym_in] = ACTIONS(5357),
    [anon_sym_out] = ACTIONS(5357),
    [anon_sym_inout] = ACTIONS(5357),
    [anon_sym_extern] = ACTIONS(5357),
    [anon_sym___attribute__] = ACTIONS(5357),
    [anon_sym_COLON_COLON] = ACTIONS(5363),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5363),
    [anon_sym___declspec] = ACTIONS(5357),
    [anon_sym___cdecl] = ACTIONS(5357),
    [anon_sym___clrcall] = ACTIONS(5357),
    [anon_sym___stdcall] = ACTIONS(5357),
    [anon_sym___fastcall] = ACTIONS(5357),
    [anon_sym___thiscall] = ACTIONS(5357),
    [anon_sym___vectorcall] = ACTIONS(5357),
    [anon_sym_LBRACE] = ACTIONS(5359),
    [anon_sym_signed] = ACTIONS(5357),
    [anon_sym_unsigned] = ACTIONS(5357),
    [anon_sym_long] = ACTIONS(5357),
    [anon_sym_short] = ACTIONS(5357),
    [anon_sym_LBRACK] = ACTIONS(5361),
    [anon_sym_static] = ACTIONS(5357),
    [anon_sym_register] = ACTIONS(5357),
    [anon_sym_inline] = ACTIONS(5357),
    [anon_sym___inline] = ACTIONS(5357),
    [anon_sym___inline__] = ACTIONS(5357),
    [anon_sym___forceinline] = ACTIONS(5357),
    [anon_sym_thread_local] = ACTIONS(5357),
    [anon_sym___thread] = ACTIONS(5357),
    [anon_sym_const] = ACTIONS(5357),
    [anon_sym_constexpr] = ACTIONS(5357),
    [anon_sym_volatile] = ACTIONS(5357),
    [anon_sym_restrict] = ACTIONS(5357),
    [anon_sym___restrict__] = ACTIONS(5357),
    [anon_sym__Atomic] = ACTIONS(5357),
    [anon_sym__Noreturn] = ACTIONS(5357),
    [anon_sym_noreturn] = ACTIONS(5357),
    [anon_sym_mutable] = ACTIONS(5357),
    [anon_sym_constinit] = ACTIONS(5357),
    [anon_sym_consteval] = ACTIONS(5357),
    [anon_sym_alignas] = ACTIONS(5357),
    [anon_sym__Alignas] = ACTIONS(5357),
    [sym_primitive_type] = ACTIONS(5357),
    [anon_sym_enum] = ACTIONS(5357),
    [anon_sym_class] = ACTIONS(5357),
    [anon_sym_struct] = ACTIONS(5357),
    [anon_sym_union] = ACTIONS(5357),
    [anon_sym_if] = ACTIONS(5357),
    [anon_sym_for] = ACTIONS(5357),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5357),
    [anon_sym_decltype] = ACTIONS(5357),
    [sym_virtual] = ACTIONS(5357),
    [anon_sym_typename] = ACTIONS(5357),
    [anon_sym_template] = ACTIONS(5357),
    [anon_sym_precise] = ACTIONS(5357),
    [anon_sym_shared] = ACTIONS(5357),
    [anon_sym_groupshared] = ACTIONS(5357),
    [anon_sym_uniform] = ACTIONS(5357),
    [anon_sym_row_major] = ACTIONS(5357),
    [anon_sym_column_major] = ACTIONS(5357),
    [anon_sym_globallycoherent] = ACTIONS(5357),
    [anon_sym_centroid] = ACTIONS(5357),
    [anon_sym_noperspective] = ACTIONS(5357),
    [anon_sym_nointerpolation] = ACTIONS(5357),
    [anon_sym_sample] = ACTIONS(5357),
    [anon_sym_linear] = ACTIONS(5357),
    [anon_sym_snorm] = ACTIONS(5357),
    [anon_sym_unorm] = ACTIONS(5357),
    [anon_sym_point] = ACTIONS(5357),
    [anon_sym_line] = ACTIONS(5357),
    [anon_sym_triangleadj] = ACTIONS(5357),
    [anon_sym_lineadj] = ACTIONS(5357),
    [anon_sym_triangle] = ACTIONS(5357),
  },
  [2268] = {
    [sym_identifier] = ACTIONS(5133),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5135),
    [anon_sym_COMMA] = ACTIONS(5135),
    [anon_sym_RPAREN] = ACTIONS(5135),
    [anon_sym_LPAREN2] = ACTIONS(5135),
    [anon_sym_TILDE] = ACTIONS(5135),
    [anon_sym_STAR] = ACTIONS(5135),
    [anon_sym_AMP_AMP] = ACTIONS(5135),
    [anon_sym_AMP] = ACTIONS(5133),
    [anon_sym_COLON] = ACTIONS(5133),
    [anon_sym_SEMI] = ACTIONS(5135),
    [anon_sym___extension__] = ACTIONS(5133),
    [anon_sym_in] = ACTIONS(5133),
    [anon_sym_out] = ACTIONS(5133),
    [anon_sym_inout] = ACTIONS(5133),
    [anon_sym_extern] = ACTIONS(5133),
    [anon_sym___attribute__] = ACTIONS(5133),
    [anon_sym_COLON_COLON] = ACTIONS(5135),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5135),
    [anon_sym___declspec] = ACTIONS(5133),
    [anon_sym___based] = ACTIONS(5133),
    [anon_sym___cdecl] = ACTIONS(5133),
    [anon_sym___clrcall] = ACTIONS(5133),
    [anon_sym___stdcall] = ACTIONS(5133),
    [anon_sym___fastcall] = ACTIONS(5133),
    [anon_sym___thiscall] = ACTIONS(5133),
    [anon_sym___vectorcall] = ACTIONS(5133),
    [anon_sym_LBRACE] = ACTIONS(5135),
    [anon_sym_LBRACK] = ACTIONS(5133),
    [anon_sym_static] = ACTIONS(5133),
    [anon_sym_EQ] = ACTIONS(5135),
    [anon_sym_register] = ACTIONS(5133),
    [anon_sym_inline] = ACTIONS(5133),
    [anon_sym___inline] = ACTIONS(5133),
    [anon_sym___inline__] = ACTIONS(5133),
    [anon_sym___forceinline] = ACTIONS(5133),
    [anon_sym_thread_local] = ACTIONS(5133),
    [anon_sym___thread] = ACTIONS(5133),
    [anon_sym_const] = ACTIONS(5133),
    [anon_sym_constexpr] = ACTIONS(5133),
    [anon_sym_volatile] = ACTIONS(5133),
    [anon_sym_restrict] = ACTIONS(5133),
    [anon_sym___restrict__] = ACTIONS(5133),
    [anon_sym__Atomic] = ACTIONS(5133),
    [anon_sym__Noreturn] = ACTIONS(5133),
    [anon_sym_noreturn] = ACTIONS(5133),
    [anon_sym_mutable] = ACTIONS(5133),
    [anon_sym_constinit] = ACTIONS(5133),
    [anon_sym_consteval] = ACTIONS(5133),
    [anon_sym_alignas] = ACTIONS(5133),
    [anon_sym__Alignas] = ACTIONS(5133),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5133),
    [anon_sym_decltype] = ACTIONS(5133),
    [anon_sym_final] = ACTIONS(5133),
    [anon_sym_override] = ACTIONS(5133),
    [sym_virtual] = ACTIONS(5133),
    [anon_sym_explicit] = ACTIONS(5133),
    [anon_sym_template] = ACTIONS(5133),
    [anon_sym_GT2] = ACTIONS(5135),
    [anon_sym_operator] = ACTIONS(5133),
    [anon_sym_precise] = ACTIONS(5133),
    [anon_sym_shared] = ACTIONS(5133),
    [anon_sym_groupshared] = ACTIONS(5133),
    [anon_sym_uniform] = ACTIONS(5133),
    [anon_sym_row_major] = ACTIONS(5133),
    [anon_sym_column_major] = ACTIONS(5133),
    [anon_sym_globallycoherent] = ACTIONS(5133),
    [anon_sym_centroid] = ACTIONS(5133),
    [anon_sym_noperspective] = ACTIONS(5133),
    [anon_sym_nointerpolation] = ACTIONS(5133),
    [anon_sym_sample] = ACTIONS(5133),
    [anon_sym_linear] = ACTIONS(5133),
    [anon_sym_snorm] = ACTIONS(5133),
    [anon_sym_unorm] = ACTIONS(5133),
    [anon_sym_point] = ACTIONS(5133),
    [anon_sym_line] = ACTIONS(5133),
    [anon_sym_triangleadj] = ACTIONS(5133),
    [anon_sym_lineadj] = ACTIONS(5133),
    [anon_sym_triangle] = ACTIONS(5133),
  },
  [2269] = {
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5421),
    [anon_sym_COMMA] = ACTIONS(5421),
    [anon_sym_RPAREN] = ACTIONS(5421),
    [anon_sym_LPAREN2] = ACTIONS(5421),
    [anon_sym_TILDE] = ACTIONS(5421),
    [anon_sym_STAR] = ACTIONS(5421),
    [anon_sym_AMP_AMP] = ACTIONS(5421),
    [anon_sym_AMP] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(5419),
    [anon_sym_SEMI] = ACTIONS(5421),
    [anon_sym___extension__] = ACTIONS(5419),
    [anon_sym_in] = ACTIONS(5419),
    [anon_sym_out] = ACTIONS(5419),
    [anon_sym_inout] = ACTIONS(5419),
    [anon_sym_extern] = ACTIONS(5419),
    [anon_sym___attribute__] = ACTIONS(5419),
    [anon_sym_COLON_COLON] = ACTIONS(5421),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5421),
    [anon_sym___declspec] = ACTIONS(5419),
    [anon_sym___based] = ACTIONS(5419),
    [anon_sym___cdecl] = ACTIONS(5419),
    [anon_sym___clrcall] = ACTIONS(5419),
    [anon_sym___stdcall] = ACTIONS(5419),
    [anon_sym___fastcall] = ACTIONS(5419),
    [anon_sym___thiscall] = ACTIONS(5419),
    [anon_sym___vectorcall] = ACTIONS(5419),
    [anon_sym_LBRACK] = ACTIONS(5419),
    [anon_sym_static] = ACTIONS(5419),
    [anon_sym_EQ] = ACTIONS(5421),
    [anon_sym_register] = ACTIONS(5419),
    [anon_sym_inline] = ACTIONS(5419),
    [anon_sym___inline] = ACTIONS(5419),
    [anon_sym___inline__] = ACTIONS(5419),
    [anon_sym___forceinline] = ACTIONS(5419),
    [anon_sym_thread_local] = ACTIONS(5419),
    [anon_sym___thread] = ACTIONS(5419),
    [anon_sym_const] = ACTIONS(5419),
    [anon_sym_constexpr] = ACTIONS(5419),
    [anon_sym_volatile] = ACTIONS(5419),
    [anon_sym_restrict] = ACTIONS(5419),
    [anon_sym___restrict__] = ACTIONS(5419),
    [anon_sym__Atomic] = ACTIONS(5419),
    [anon_sym__Noreturn] = ACTIONS(5419),
    [anon_sym_noreturn] = ACTIONS(5419),
    [anon_sym_mutable] = ACTIONS(5419),
    [anon_sym_constinit] = ACTIONS(5419),
    [anon_sym_consteval] = ACTIONS(5419),
    [anon_sym_alignas] = ACTIONS(5419),
    [anon_sym__Alignas] = ACTIONS(5419),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5419),
    [anon_sym_decltype] = ACTIONS(5419),
    [anon_sym_final] = ACTIONS(5419),
    [anon_sym_override] = ACTIONS(5419),
    [sym_virtual] = ACTIONS(5419),
    [anon_sym_template] = ACTIONS(5419),
    [anon_sym_GT2] = ACTIONS(5421),
    [anon_sym_operator] = ACTIONS(5419),
    [anon_sym_requires] = ACTIONS(5419),
    [anon_sym_precise] = ACTIONS(5419),
    [anon_sym_shared] = ACTIONS(5419),
    [anon_sym_groupshared] = ACTIONS(5419),
    [anon_sym_uniform] = ACTIONS(5419),
    [anon_sym_row_major] = ACTIONS(5419),
    [anon_sym_column_major] = ACTIONS(5419),
    [anon_sym_globallycoherent] = ACTIONS(5419),
    [anon_sym_centroid] = ACTIONS(5419),
    [anon_sym_noperspective] = ACTIONS(5419),
    [anon_sym_nointerpolation] = ACTIONS(5419),
    [anon_sym_sample] = ACTIONS(5419),
    [anon_sym_linear] = ACTIONS(5419),
    [anon_sym_snorm] = ACTIONS(5419),
    [anon_sym_unorm] = ACTIONS(5419),
    [anon_sym_point] = ACTIONS(5419),
    [anon_sym_line] = ACTIONS(5419),
    [anon_sym_triangleadj] = ACTIONS(5419),
    [anon_sym_lineadj] = ACTIONS(5419),
    [anon_sym_triangle] = ACTIONS(5419),
  },
  [2270] = {
    [sym_identifier] = ACTIONS(5423),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5425),
    [anon_sym_COMMA] = ACTIONS(5425),
    [anon_sym_RPAREN] = ACTIONS(5425),
    [anon_sym_LPAREN2] = ACTIONS(5425),
    [anon_sym_TILDE] = ACTIONS(5425),
    [anon_sym_STAR] = ACTIONS(5425),
    [anon_sym_AMP_AMP] = ACTIONS(5425),
    [anon_sym_AMP] = ACTIONS(5423),
    [anon_sym_COLON] = ACTIONS(5423),
    [anon_sym_SEMI] = ACTIONS(5425),
    [anon_sym___extension__] = ACTIONS(5423),
    [anon_sym_in] = ACTIONS(5423),
    [anon_sym_out] = ACTIONS(5423),
    [anon_sym_inout] = ACTIONS(5423),
    [anon_sym_extern] = ACTIONS(5423),
    [anon_sym___attribute__] = ACTIONS(5423),
    [anon_sym_COLON_COLON] = ACTIONS(5425),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5425),
    [anon_sym___declspec] = ACTIONS(5423),
    [anon_sym___based] = ACTIONS(5423),
    [anon_sym___cdecl] = ACTIONS(5423),
    [anon_sym___clrcall] = ACTIONS(5423),
    [anon_sym___stdcall] = ACTIONS(5423),
    [anon_sym___fastcall] = ACTIONS(5423),
    [anon_sym___thiscall] = ACTIONS(5423),
    [anon_sym___vectorcall] = ACTIONS(5423),
    [anon_sym_LBRACK] = ACTIONS(5423),
    [anon_sym_static] = ACTIONS(5423),
    [anon_sym_EQ] = ACTIONS(5425),
    [anon_sym_register] = ACTIONS(5423),
    [anon_sym_inline] = ACTIONS(5423),
    [anon_sym___inline] = ACTIONS(5423),
    [anon_sym___inline__] = ACTIONS(5423),
    [anon_sym___forceinline] = ACTIONS(5423),
    [anon_sym_thread_local] = ACTIONS(5423),
    [anon_sym___thread] = ACTIONS(5423),
    [anon_sym_const] = ACTIONS(5423),
    [anon_sym_constexpr] = ACTIONS(5423),
    [anon_sym_volatile] = ACTIONS(5423),
    [anon_sym_restrict] = ACTIONS(5423),
    [anon_sym___restrict__] = ACTIONS(5423),
    [anon_sym__Atomic] = ACTIONS(5423),
    [anon_sym__Noreturn] = ACTIONS(5423),
    [anon_sym_noreturn] = ACTIONS(5423),
    [anon_sym_mutable] = ACTIONS(5423),
    [anon_sym_constinit] = ACTIONS(5423),
    [anon_sym_consteval] = ACTIONS(5423),
    [anon_sym_alignas] = ACTIONS(5423),
    [anon_sym__Alignas] = ACTIONS(5423),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5423),
    [anon_sym_decltype] = ACTIONS(5423),
    [anon_sym_final] = ACTIONS(5423),
    [anon_sym_override] = ACTIONS(5423),
    [sym_virtual] = ACTIONS(5423),
    [anon_sym_template] = ACTIONS(5423),
    [anon_sym_GT2] = ACTIONS(5425),
    [anon_sym_operator] = ACTIONS(5423),
    [anon_sym_requires] = ACTIONS(5423),
    [anon_sym_precise] = ACTIONS(5423),
    [anon_sym_shared] = ACTIONS(5423),
    [anon_sym_groupshared] = ACTIONS(5423),
    [anon_sym_uniform] = ACTIONS(5423),
    [anon_sym_row_major] = ACTIONS(5423),
    [anon_sym_column_major] = ACTIONS(5423),
    [anon_sym_globallycoherent] = ACTIONS(5423),
    [anon_sym_centroid] = ACTIONS(5423),
    [anon_sym_noperspective] = ACTIONS(5423),
    [anon_sym_nointerpolation] = ACTIONS(5423),
    [anon_sym_sample] = ACTIONS(5423),
    [anon_sym_linear] = ACTIONS(5423),
    [anon_sym_snorm] = ACTIONS(5423),
    [anon_sym_unorm] = ACTIONS(5423),
    [anon_sym_point] = ACTIONS(5423),
    [anon_sym_line] = ACTIONS(5423),
    [anon_sym_triangleadj] = ACTIONS(5423),
    [anon_sym_lineadj] = ACTIONS(5423),
    [anon_sym_triangle] = ACTIONS(5423),
  },
  [2271] = {
    [sym_identifier] = ACTIONS(5427),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5429),
    [anon_sym_COMMA] = ACTIONS(5429),
    [anon_sym_RPAREN] = ACTIONS(5429),
    [anon_sym_LPAREN2] = ACTIONS(5429),
    [anon_sym_TILDE] = ACTIONS(5429),
    [anon_sym_STAR] = ACTIONS(5429),
    [anon_sym_AMP_AMP] = ACTIONS(5429),
    [anon_sym_AMP] = ACTIONS(5427),
    [anon_sym_COLON] = ACTIONS(5427),
    [anon_sym_SEMI] = ACTIONS(5429),
    [anon_sym___extension__] = ACTIONS(5427),
    [anon_sym_in] = ACTIONS(5427),
    [anon_sym_out] = ACTIONS(5427),
    [anon_sym_inout] = ACTIONS(5427),
    [anon_sym_extern] = ACTIONS(5427),
    [anon_sym___attribute__] = ACTIONS(5427),
    [anon_sym_COLON_COLON] = ACTIONS(5429),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5429),
    [anon_sym___declspec] = ACTIONS(5427),
    [anon_sym___based] = ACTIONS(5427),
    [anon_sym___cdecl] = ACTIONS(5427),
    [anon_sym___clrcall] = ACTIONS(5427),
    [anon_sym___stdcall] = ACTIONS(5427),
    [anon_sym___fastcall] = ACTIONS(5427),
    [anon_sym___thiscall] = ACTIONS(5427),
    [anon_sym___vectorcall] = ACTIONS(5427),
    [anon_sym_LBRACK] = ACTIONS(5427),
    [anon_sym_static] = ACTIONS(5427),
    [anon_sym_EQ] = ACTIONS(5429),
    [anon_sym_register] = ACTIONS(5427),
    [anon_sym_inline] = ACTIONS(5427),
    [anon_sym___inline] = ACTIONS(5427),
    [anon_sym___inline__] = ACTIONS(5427),
    [anon_sym___forceinline] = ACTIONS(5427),
    [anon_sym_thread_local] = ACTIONS(5427),
    [anon_sym___thread] = ACTIONS(5427),
    [anon_sym_const] = ACTIONS(5427),
    [anon_sym_constexpr] = ACTIONS(5427),
    [anon_sym_volatile] = ACTIONS(5427),
    [anon_sym_restrict] = ACTIONS(5427),
    [anon_sym___restrict__] = ACTIONS(5427),
    [anon_sym__Atomic] = ACTIONS(5427),
    [anon_sym__Noreturn] = ACTIONS(5427),
    [anon_sym_noreturn] = ACTIONS(5427),
    [anon_sym_mutable] = ACTIONS(5427),
    [anon_sym_constinit] = ACTIONS(5427),
    [anon_sym_consteval] = ACTIONS(5427),
    [anon_sym_alignas] = ACTIONS(5427),
    [anon_sym__Alignas] = ACTIONS(5427),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5427),
    [anon_sym_decltype] = ACTIONS(5427),
    [anon_sym_final] = ACTIONS(5427),
    [anon_sym_override] = ACTIONS(5427),
    [sym_virtual] = ACTIONS(5427),
    [anon_sym_template] = ACTIONS(5427),
    [anon_sym_GT2] = ACTIONS(5429),
    [anon_sym_operator] = ACTIONS(5427),
    [anon_sym_requires] = ACTIONS(5427),
    [anon_sym_precise] = ACTIONS(5427),
    [anon_sym_shared] = ACTIONS(5427),
    [anon_sym_groupshared] = ACTIONS(5427),
    [anon_sym_uniform] = ACTIONS(5427),
    [anon_sym_row_major] = ACTIONS(5427),
    [anon_sym_column_major] = ACTIONS(5427),
    [anon_sym_globallycoherent] = ACTIONS(5427),
    [anon_sym_centroid] = ACTIONS(5427),
    [anon_sym_noperspective] = ACTIONS(5427),
    [anon_sym_nointerpolation] = ACTIONS(5427),
    [anon_sym_sample] = ACTIONS(5427),
    [anon_sym_linear] = ACTIONS(5427),
    [anon_sym_snorm] = ACTIONS(5427),
    [anon_sym_unorm] = ACTIONS(5427),
    [anon_sym_point] = ACTIONS(5427),
    [anon_sym_line] = ACTIONS(5427),
    [anon_sym_triangleadj] = ACTIONS(5427),
    [anon_sym_lineadj] = ACTIONS(5427),
    [anon_sym_triangle] = ACTIONS(5427),
  },
  [2272] = {
    [sym_identifier] = ACTIONS(5431),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5433),
    [anon_sym_COMMA] = ACTIONS(5433),
    [anon_sym_RPAREN] = ACTIONS(5433),
    [anon_sym_LPAREN2] = ACTIONS(5433),
    [anon_sym_TILDE] = ACTIONS(5433),
    [anon_sym_STAR] = ACTIONS(5433),
    [anon_sym_AMP_AMP] = ACTIONS(5433),
    [anon_sym_AMP] = ACTIONS(5431),
    [anon_sym_COLON] = ACTIONS(5431),
    [anon_sym_SEMI] = ACTIONS(5433),
    [anon_sym___extension__] = ACTIONS(5431),
    [anon_sym_in] = ACTIONS(5431),
    [anon_sym_out] = ACTIONS(5431),
    [anon_sym_inout] = ACTIONS(5431),
    [anon_sym_extern] = ACTIONS(5431),
    [anon_sym___attribute__] = ACTIONS(5431),
    [anon_sym_COLON_COLON] = ACTIONS(5433),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5433),
    [anon_sym___declspec] = ACTIONS(5431),
    [anon_sym___based] = ACTIONS(5431),
    [anon_sym___cdecl] = ACTIONS(5431),
    [anon_sym___clrcall] = ACTIONS(5431),
    [anon_sym___stdcall] = ACTIONS(5431),
    [anon_sym___fastcall] = ACTIONS(5431),
    [anon_sym___thiscall] = ACTIONS(5431),
    [anon_sym___vectorcall] = ACTIONS(5431),
    [anon_sym_LBRACK] = ACTIONS(5431),
    [anon_sym_static] = ACTIONS(5431),
    [anon_sym_EQ] = ACTIONS(5433),
    [anon_sym_register] = ACTIONS(5431),
    [anon_sym_inline] = ACTIONS(5431),
    [anon_sym___inline] = ACTIONS(5431),
    [anon_sym___inline__] = ACTIONS(5431),
    [anon_sym___forceinline] = ACTIONS(5431),
    [anon_sym_thread_local] = ACTIONS(5431),
    [anon_sym___thread] = ACTIONS(5431),
    [anon_sym_const] = ACTIONS(5431),
    [anon_sym_constexpr] = ACTIONS(5431),
    [anon_sym_volatile] = ACTIONS(5431),
    [anon_sym_restrict] = ACTIONS(5431),
    [anon_sym___restrict__] = ACTIONS(5431),
    [anon_sym__Atomic] = ACTIONS(5431),
    [anon_sym__Noreturn] = ACTIONS(5431),
    [anon_sym_noreturn] = ACTIONS(5431),
    [anon_sym_mutable] = ACTIONS(5431),
    [anon_sym_constinit] = ACTIONS(5431),
    [anon_sym_consteval] = ACTIONS(5431),
    [anon_sym_alignas] = ACTIONS(5431),
    [anon_sym__Alignas] = ACTIONS(5431),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5431),
    [anon_sym_decltype] = ACTIONS(5431),
    [anon_sym_final] = ACTIONS(5431),
    [anon_sym_override] = ACTIONS(5431),
    [sym_virtual] = ACTIONS(5431),
    [anon_sym_template] = ACTIONS(5431),
    [anon_sym_GT2] = ACTIONS(5433),
    [anon_sym_operator] = ACTIONS(5431),
    [anon_sym_requires] = ACTIONS(5431),
    [anon_sym_precise] = ACTIONS(5431),
    [anon_sym_shared] = ACTIONS(5431),
    [anon_sym_groupshared] = ACTIONS(5431),
    [anon_sym_uniform] = ACTIONS(5431),
    [anon_sym_row_major] = ACTIONS(5431),
    [anon_sym_column_major] = ACTIONS(5431),
    [anon_sym_globallycoherent] = ACTIONS(5431),
    [anon_sym_centroid] = ACTIONS(5431),
    [anon_sym_noperspective] = ACTIONS(5431),
    [anon_sym_nointerpolation] = ACTIONS(5431),
    [anon_sym_sample] = ACTIONS(5431),
    [anon_sym_linear] = ACTIONS(5431),
    [anon_sym_snorm] = ACTIONS(5431),
    [anon_sym_unorm] = ACTIONS(5431),
    [anon_sym_point] = ACTIONS(5431),
    [anon_sym_line] = ACTIONS(5431),
    [anon_sym_triangleadj] = ACTIONS(5431),
    [anon_sym_lineadj] = ACTIONS(5431),
    [anon_sym_triangle] = ACTIONS(5431),
  },
  [2273] = {
    [sym_identifier] = ACTIONS(5435),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5437),
    [anon_sym_COMMA] = ACTIONS(5437),
    [anon_sym_RPAREN] = ACTIONS(5437),
    [anon_sym_LPAREN2] = ACTIONS(5437),
    [anon_sym_TILDE] = ACTIONS(5437),
    [anon_sym_STAR] = ACTIONS(5437),
    [anon_sym_AMP_AMP] = ACTIONS(5437),
    [anon_sym_AMP] = ACTIONS(5435),
    [anon_sym_COLON] = ACTIONS(5435),
    [anon_sym_SEMI] = ACTIONS(5437),
    [anon_sym___extension__] = ACTIONS(5435),
    [anon_sym_in] = ACTIONS(5435),
    [anon_sym_out] = ACTIONS(5435),
    [anon_sym_inout] = ACTIONS(5435),
    [anon_sym_extern] = ACTIONS(5435),
    [anon_sym___attribute__] = ACTIONS(5435),
    [anon_sym_COLON_COLON] = ACTIONS(5437),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5437),
    [anon_sym___declspec] = ACTIONS(5435),
    [anon_sym___based] = ACTIONS(5435),
    [anon_sym___cdecl] = ACTIONS(5435),
    [anon_sym___clrcall] = ACTIONS(5435),
    [anon_sym___stdcall] = ACTIONS(5435),
    [anon_sym___fastcall] = ACTIONS(5435),
    [anon_sym___thiscall] = ACTIONS(5435),
    [anon_sym___vectorcall] = ACTIONS(5435),
    [anon_sym_LBRACE] = ACTIONS(5437),
    [anon_sym_LBRACK] = ACTIONS(5435),
    [anon_sym_static] = ACTIONS(5435),
    [anon_sym_EQ] = ACTIONS(5437),
    [anon_sym_register] = ACTIONS(5435),
    [anon_sym_inline] = ACTIONS(5435),
    [anon_sym___inline] = ACTIONS(5435),
    [anon_sym___inline__] = ACTIONS(5435),
    [anon_sym___forceinline] = ACTIONS(5435),
    [anon_sym_thread_local] = ACTIONS(5435),
    [anon_sym___thread] = ACTIONS(5435),
    [anon_sym_const] = ACTIONS(5435),
    [anon_sym_constexpr] = ACTIONS(5435),
    [anon_sym_volatile] = ACTIONS(5435),
    [anon_sym_restrict] = ACTIONS(5435),
    [anon_sym___restrict__] = ACTIONS(5435),
    [anon_sym__Atomic] = ACTIONS(5435),
    [anon_sym__Noreturn] = ACTIONS(5435),
    [anon_sym_noreturn] = ACTIONS(5435),
    [anon_sym_mutable] = ACTIONS(5435),
    [anon_sym_constinit] = ACTIONS(5435),
    [anon_sym_consteval] = ACTIONS(5435),
    [anon_sym_alignas] = ACTIONS(5435),
    [anon_sym__Alignas] = ACTIONS(5435),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(5435),
    [anon_sym_final] = ACTIONS(5435),
    [anon_sym_override] = ACTIONS(5435),
    [sym_virtual] = ACTIONS(5435),
    [anon_sym_explicit] = ACTIONS(5435),
    [anon_sym_template] = ACTIONS(5435),
    [anon_sym_GT2] = ACTIONS(5437),
    [anon_sym_operator] = ACTIONS(5435),
    [anon_sym_precise] = ACTIONS(5435),
    [anon_sym_shared] = ACTIONS(5435),
    [anon_sym_groupshared] = ACTIONS(5435),
    [anon_sym_uniform] = ACTIONS(5435),
    [anon_sym_row_major] = ACTIONS(5435),
    [anon_sym_column_major] = ACTIONS(5435),
    [anon_sym_globallycoherent] = ACTIONS(5435),
    [anon_sym_centroid] = ACTIONS(5435),
    [anon_sym_noperspective] = ACTIONS(5435),
    [anon_sym_nointerpolation] = ACTIONS(5435),
    [anon_sym_sample] = ACTIONS(5435),
    [anon_sym_linear] = ACTIONS(5435),
    [anon_sym_snorm] = ACTIONS(5435),
    [anon_sym_unorm] = ACTIONS(5435),
    [anon_sym_point] = ACTIONS(5435),
    [anon_sym_line] = ACTIONS(5435),
    [anon_sym_triangleadj] = ACTIONS(5435),
    [anon_sym_lineadj] = ACTIONS(5435),
    [anon_sym_triangle] = ACTIONS(5435),
  },
  [2274] = {
    [sym_identifier] = ACTIONS(5439),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5441),
    [anon_sym_COMMA] = ACTIONS(5441),
    [anon_sym_RPAREN] = ACTIONS(5441),
    [anon_sym_LPAREN2] = ACTIONS(5441),
    [anon_sym_TILDE] = ACTIONS(5441),
    [anon_sym_STAR] = ACTIONS(5441),
    [anon_sym_AMP_AMP] = ACTIONS(5441),
    [anon_sym_AMP] = ACTIONS(5439),
    [anon_sym_COLON] = ACTIONS(5439),
    [anon_sym_SEMI] = ACTIONS(5441),
    [anon_sym___extension__] = ACTIONS(5439),
    [anon_sym_in] = ACTIONS(5439),
    [anon_sym_out] = ACTIONS(5439),
    [anon_sym_inout] = ACTIONS(5439),
    [anon_sym_extern] = ACTIONS(5439),
    [anon_sym___attribute__] = ACTIONS(5439),
    [anon_sym_COLON_COLON] = ACTIONS(5441),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5441),
    [anon_sym___declspec] = ACTIONS(5439),
    [anon_sym___based] = ACTIONS(5439),
    [anon_sym___cdecl] = ACTIONS(5439),
    [anon_sym___clrcall] = ACTIONS(5439),
    [anon_sym___stdcall] = ACTIONS(5439),
    [anon_sym___fastcall] = ACTIONS(5439),
    [anon_sym___thiscall] = ACTIONS(5439),
    [anon_sym___vectorcall] = ACTIONS(5439),
    [anon_sym_LBRACK] = ACTIONS(5439),
    [anon_sym_static] = ACTIONS(5439),
    [anon_sym_EQ] = ACTIONS(5441),
    [anon_sym_register] = ACTIONS(5439),
    [anon_sym_inline] = ACTIONS(5439),
    [anon_sym___inline] = ACTIONS(5439),
    [anon_sym___inline__] = ACTIONS(5439),
    [anon_sym___forceinline] = ACTIONS(5439),
    [anon_sym_thread_local] = ACTIONS(5439),
    [anon_sym___thread] = ACTIONS(5439),
    [anon_sym_const] = ACTIONS(5439),
    [anon_sym_constexpr] = ACTIONS(5439),
    [anon_sym_volatile] = ACTIONS(5439),
    [anon_sym_restrict] = ACTIONS(5439),
    [anon_sym___restrict__] = ACTIONS(5439),
    [anon_sym__Atomic] = ACTIONS(5439),
    [anon_sym__Noreturn] = ACTIONS(5439),
    [anon_sym_noreturn] = ACTIONS(5439),
    [anon_sym_mutable] = ACTIONS(5439),
    [anon_sym_constinit] = ACTIONS(5439),
    [anon_sym_consteval] = ACTIONS(5439),
    [anon_sym_alignas] = ACTIONS(5439),
    [anon_sym__Alignas] = ACTIONS(5439),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5439),
    [anon_sym_decltype] = ACTIONS(5439),
    [anon_sym_final] = ACTIONS(5439),
    [anon_sym_override] = ACTIONS(5439),
    [sym_virtual] = ACTIONS(5439),
    [anon_sym_template] = ACTIONS(5439),
    [anon_sym_GT2] = ACTIONS(5441),
    [anon_sym_operator] = ACTIONS(5439),
    [anon_sym_requires] = ACTIONS(5439),
    [anon_sym_precise] = ACTIONS(5439),
    [anon_sym_shared] = ACTIONS(5439),
    [anon_sym_groupshared] = ACTIONS(5439),
    [anon_sym_uniform] = ACTIONS(5439),
    [anon_sym_row_major] = ACTIONS(5439),
    [anon_sym_column_major] = ACTIONS(5439),
    [anon_sym_globallycoherent] = ACTIONS(5439),
    [anon_sym_centroid] = ACTIONS(5439),
    [anon_sym_noperspective] = ACTIONS(5439),
    [anon_sym_nointerpolation] = ACTIONS(5439),
    [anon_sym_sample] = ACTIONS(5439),
    [anon_sym_linear] = ACTIONS(5439),
    [anon_sym_snorm] = ACTIONS(5439),
    [anon_sym_unorm] = ACTIONS(5439),
    [anon_sym_point] = ACTIONS(5439),
    [anon_sym_line] = ACTIONS(5439),
    [anon_sym_triangleadj] = ACTIONS(5439),
    [anon_sym_lineadj] = ACTIONS(5439),
    [anon_sym_triangle] = ACTIONS(5439),
  },
  [2275] = {
    [sym_identifier] = ACTIONS(5443),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5445),
    [anon_sym_COMMA] = ACTIONS(5445),
    [anon_sym_RPAREN] = ACTIONS(5445),
    [anon_sym_LPAREN2] = ACTIONS(5445),
    [anon_sym_TILDE] = ACTIONS(5445),
    [anon_sym_STAR] = ACTIONS(5445),
    [anon_sym_AMP_AMP] = ACTIONS(5445),
    [anon_sym_AMP] = ACTIONS(5443),
    [anon_sym_COLON] = ACTIONS(5443),
    [anon_sym_SEMI] = ACTIONS(5445),
    [anon_sym___extension__] = ACTIONS(5443),
    [anon_sym_in] = ACTIONS(5443),
    [anon_sym_out] = ACTIONS(5443),
    [anon_sym_inout] = ACTIONS(5443),
    [anon_sym_extern] = ACTIONS(5443),
    [anon_sym___attribute__] = ACTIONS(5443),
    [anon_sym_COLON_COLON] = ACTIONS(5445),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5445),
    [anon_sym___declspec] = ACTIONS(5443),
    [anon_sym___based] = ACTIONS(5443),
    [anon_sym___cdecl] = ACTIONS(5443),
    [anon_sym___clrcall] = ACTIONS(5443),
    [anon_sym___stdcall] = ACTIONS(5443),
    [anon_sym___fastcall] = ACTIONS(5443),
    [anon_sym___thiscall] = ACTIONS(5443),
    [anon_sym___vectorcall] = ACTIONS(5443),
    [anon_sym_LBRACK] = ACTIONS(5443),
    [anon_sym_static] = ACTIONS(5443),
    [anon_sym_EQ] = ACTIONS(5445),
    [anon_sym_register] = ACTIONS(5443),
    [anon_sym_inline] = ACTIONS(5443),
    [anon_sym___inline] = ACTIONS(5443),
    [anon_sym___inline__] = ACTIONS(5443),
    [anon_sym___forceinline] = ACTIONS(5443),
    [anon_sym_thread_local] = ACTIONS(5443),
    [anon_sym___thread] = ACTIONS(5443),
    [anon_sym_const] = ACTIONS(5443),
    [anon_sym_constexpr] = ACTIONS(5443),
    [anon_sym_volatile] = ACTIONS(5443),
    [anon_sym_restrict] = ACTIONS(5443),
    [anon_sym___restrict__] = ACTIONS(5443),
    [anon_sym__Atomic] = ACTIONS(5443),
    [anon_sym__Noreturn] = ACTIONS(5443),
    [anon_sym_noreturn] = ACTIONS(5443),
    [anon_sym_mutable] = ACTIONS(5443),
    [anon_sym_constinit] = ACTIONS(5443),
    [anon_sym_consteval] = ACTIONS(5443),
    [anon_sym_alignas] = ACTIONS(5443),
    [anon_sym__Alignas] = ACTIONS(5443),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5443),
    [anon_sym_decltype] = ACTIONS(5443),
    [anon_sym_final] = ACTIONS(5443),
    [anon_sym_override] = ACTIONS(5443),
    [sym_virtual] = ACTIONS(5443),
    [anon_sym_template] = ACTIONS(5443),
    [anon_sym_GT2] = ACTIONS(5445),
    [anon_sym_operator] = ACTIONS(5443),
    [anon_sym_requires] = ACTIONS(5443),
    [anon_sym_precise] = ACTIONS(5443),
    [anon_sym_shared] = ACTIONS(5443),
    [anon_sym_groupshared] = ACTIONS(5443),
    [anon_sym_uniform] = ACTIONS(5443),
    [anon_sym_row_major] = ACTIONS(5443),
    [anon_sym_column_major] = ACTIONS(5443),
    [anon_sym_globallycoherent] = ACTIONS(5443),
    [anon_sym_centroid] = ACTIONS(5443),
    [anon_sym_noperspective] = ACTIONS(5443),
    [anon_sym_nointerpolation] = ACTIONS(5443),
    [anon_sym_sample] = ACTIONS(5443),
    [anon_sym_linear] = ACTIONS(5443),
    [anon_sym_snorm] = ACTIONS(5443),
    [anon_sym_unorm] = ACTIONS(5443),
    [anon_sym_point] = ACTIONS(5443),
    [anon_sym_line] = ACTIONS(5443),
    [anon_sym_triangleadj] = ACTIONS(5443),
    [anon_sym_lineadj] = ACTIONS(5443),
    [anon_sym_triangle] = ACTIONS(5443),
  },
  [2276] = {
    [sym_identifier] = ACTIONS(5447),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5449),
    [anon_sym_COMMA] = ACTIONS(5449),
    [anon_sym_RPAREN] = ACTIONS(5449),
    [anon_sym_LPAREN2] = ACTIONS(5449),
    [anon_sym_TILDE] = ACTIONS(5449),
    [anon_sym_STAR] = ACTIONS(5449),
    [anon_sym_AMP_AMP] = ACTIONS(5449),
    [anon_sym_AMP] = ACTIONS(5447),
    [anon_sym_COLON] = ACTIONS(5447),
    [anon_sym_SEMI] = ACTIONS(5449),
    [anon_sym___extension__] = ACTIONS(5447),
    [anon_sym_in] = ACTIONS(5447),
    [anon_sym_out] = ACTIONS(5447),
    [anon_sym_inout] = ACTIONS(5447),
    [anon_sym_extern] = ACTIONS(5447),
    [anon_sym___attribute__] = ACTIONS(5447),
    [anon_sym_COLON_COLON] = ACTIONS(5449),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5449),
    [anon_sym___declspec] = ACTIONS(5447),
    [anon_sym___based] = ACTIONS(5447),
    [anon_sym___cdecl] = ACTIONS(5447),
    [anon_sym___clrcall] = ACTIONS(5447),
    [anon_sym___stdcall] = ACTIONS(5447),
    [anon_sym___fastcall] = ACTIONS(5447),
    [anon_sym___thiscall] = ACTIONS(5447),
    [anon_sym___vectorcall] = ACTIONS(5447),
    [anon_sym_LBRACK] = ACTIONS(5447),
    [anon_sym_static] = ACTIONS(5447),
    [anon_sym_EQ] = ACTIONS(5449),
    [anon_sym_register] = ACTIONS(5447),
    [anon_sym_inline] = ACTIONS(5447),
    [anon_sym___inline] = ACTIONS(5447),
    [anon_sym___inline__] = ACTIONS(5447),
    [anon_sym___forceinline] = ACTIONS(5447),
    [anon_sym_thread_local] = ACTIONS(5447),
    [anon_sym___thread] = ACTIONS(5447),
    [anon_sym_const] = ACTIONS(5447),
    [anon_sym_constexpr] = ACTIONS(5447),
    [anon_sym_volatile] = ACTIONS(5447),
    [anon_sym_restrict] = ACTIONS(5447),
    [anon_sym___restrict__] = ACTIONS(5447),
    [anon_sym__Atomic] = ACTIONS(5447),
    [anon_sym__Noreturn] = ACTIONS(5447),
    [anon_sym_noreturn] = ACTIONS(5447),
    [anon_sym_mutable] = ACTIONS(5447),
    [anon_sym_constinit] = ACTIONS(5447),
    [anon_sym_consteval] = ACTIONS(5447),
    [anon_sym_alignas] = ACTIONS(5447),
    [anon_sym__Alignas] = ACTIONS(5447),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5447),
    [anon_sym_decltype] = ACTIONS(5447),
    [anon_sym_final] = ACTIONS(5447),
    [anon_sym_override] = ACTIONS(5447),
    [sym_virtual] = ACTIONS(5447),
    [anon_sym_template] = ACTIONS(5447),
    [anon_sym_GT2] = ACTIONS(5449),
    [anon_sym_operator] = ACTIONS(5447),
    [anon_sym_requires] = ACTIONS(5447),
    [anon_sym_precise] = ACTIONS(5447),
    [anon_sym_shared] = ACTIONS(5447),
    [anon_sym_groupshared] = ACTIONS(5447),
    [anon_sym_uniform] = ACTIONS(5447),
    [anon_sym_row_major] = ACTIONS(5447),
    [anon_sym_column_major] = ACTIONS(5447),
    [anon_sym_globallycoherent] = ACTIONS(5447),
    [anon_sym_centroid] = ACTIONS(5447),
    [anon_sym_noperspective] = ACTIONS(5447),
    [anon_sym_nointerpolation] = ACTIONS(5447),
    [anon_sym_sample] = ACTIONS(5447),
    [anon_sym_linear] = ACTIONS(5447),
    [anon_sym_snorm] = ACTIONS(5447),
    [anon_sym_unorm] = ACTIONS(5447),
    [anon_sym_point] = ACTIONS(5447),
    [anon_sym_line] = ACTIONS(5447),
    [anon_sym_triangleadj] = ACTIONS(5447),
    [anon_sym_lineadj] = ACTIONS(5447),
    [anon_sym_triangle] = ACTIONS(5447),
  },
  [2277] = {
    [sym_identifier] = ACTIONS(5318),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5320),
    [anon_sym_COMMA] = ACTIONS(5320),
    [anon_sym_RPAREN] = ACTIONS(5320),
    [anon_sym_LPAREN2] = ACTIONS(5320),
    [anon_sym_TILDE] = ACTIONS(5320),
    [anon_sym_STAR] = ACTIONS(5320),
    [anon_sym_AMP_AMP] = ACTIONS(5320),
    [anon_sym_AMP] = ACTIONS(5318),
    [anon_sym_COLON] = ACTIONS(5318),
    [anon_sym_SEMI] = ACTIONS(5320),
    [anon_sym___extension__] = ACTIONS(5318),
    [anon_sym_in] = ACTIONS(5318),
    [anon_sym_out] = ACTIONS(5318),
    [anon_sym_inout] = ACTIONS(5318),
    [anon_sym_extern] = ACTIONS(5318),
    [anon_sym___attribute__] = ACTIONS(5318),
    [anon_sym_COLON_COLON] = ACTIONS(5320),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5320),
    [anon_sym___declspec] = ACTIONS(5318),
    [anon_sym___based] = ACTIONS(5318),
    [anon_sym___cdecl] = ACTIONS(5318),
    [anon_sym___clrcall] = ACTIONS(5318),
    [anon_sym___stdcall] = ACTIONS(5318),
    [anon_sym___fastcall] = ACTIONS(5318),
    [anon_sym___thiscall] = ACTIONS(5318),
    [anon_sym___vectorcall] = ACTIONS(5318),
    [anon_sym_LBRACK] = ACTIONS(5318),
    [anon_sym_static] = ACTIONS(5318),
    [anon_sym_EQ] = ACTIONS(5320),
    [anon_sym_register] = ACTIONS(5318),
    [anon_sym_inline] = ACTIONS(5318),
    [anon_sym___inline] = ACTIONS(5318),
    [anon_sym___inline__] = ACTIONS(5318),
    [anon_sym___forceinline] = ACTIONS(5318),
    [anon_sym_thread_local] = ACTIONS(5318),
    [anon_sym___thread] = ACTIONS(5318),
    [anon_sym_const] = ACTIONS(5318),
    [anon_sym_constexpr] = ACTIONS(5318),
    [anon_sym_volatile] = ACTIONS(5318),
    [anon_sym_restrict] = ACTIONS(5318),
    [anon_sym___restrict__] = ACTIONS(5318),
    [anon_sym__Atomic] = ACTIONS(5318),
    [anon_sym__Noreturn] = ACTIONS(5318),
    [anon_sym_noreturn] = ACTIONS(5318),
    [anon_sym_mutable] = ACTIONS(5318),
    [anon_sym_constinit] = ACTIONS(5318),
    [anon_sym_consteval] = ACTIONS(5318),
    [anon_sym_alignas] = ACTIONS(5318),
    [anon_sym__Alignas] = ACTIONS(5318),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5318),
    [anon_sym_decltype] = ACTIONS(5318),
    [anon_sym_final] = ACTIONS(5318),
    [anon_sym_override] = ACTIONS(5318),
    [sym_virtual] = ACTIONS(5318),
    [anon_sym_template] = ACTIONS(5318),
    [anon_sym_GT2] = ACTIONS(5320),
    [anon_sym_operator] = ACTIONS(5318),
    [anon_sym_requires] = ACTIONS(5318),
    [anon_sym_precise] = ACTIONS(5318),
    [anon_sym_shared] = ACTIONS(5318),
    [anon_sym_groupshared] = ACTIONS(5318),
    [anon_sym_uniform] = ACTIONS(5318),
    [anon_sym_row_major] = ACTIONS(5318),
    [anon_sym_column_major] = ACTIONS(5318),
    [anon_sym_globallycoherent] = ACTIONS(5318),
    [anon_sym_centroid] = ACTIONS(5318),
    [anon_sym_noperspective] = ACTIONS(5318),
    [anon_sym_nointerpolation] = ACTIONS(5318),
    [anon_sym_sample] = ACTIONS(5318),
    [anon_sym_linear] = ACTIONS(5318),
    [anon_sym_snorm] = ACTIONS(5318),
    [anon_sym_unorm] = ACTIONS(5318),
    [anon_sym_point] = ACTIONS(5318),
    [anon_sym_line] = ACTIONS(5318),
    [anon_sym_triangleadj] = ACTIONS(5318),
    [anon_sym_lineadj] = ACTIONS(5318),
    [anon_sym_triangle] = ACTIONS(5318),
  },
  [2278] = {
    [sym_identifier] = ACTIONS(5451),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5453),
    [anon_sym_COMMA] = ACTIONS(5453),
    [anon_sym_RPAREN] = ACTIONS(5453),
    [anon_sym_LPAREN2] = ACTIONS(5453),
    [anon_sym_TILDE] = ACTIONS(5453),
    [anon_sym_STAR] = ACTIONS(5453),
    [anon_sym_AMP_AMP] = ACTIONS(5453),
    [anon_sym_AMP] = ACTIONS(5451),
    [anon_sym_COLON] = ACTIONS(5451),
    [anon_sym_SEMI] = ACTIONS(5453),
    [anon_sym___extension__] = ACTIONS(5451),
    [anon_sym_in] = ACTIONS(5451),
    [anon_sym_out] = ACTIONS(5451),
    [anon_sym_inout] = ACTIONS(5451),
    [anon_sym_extern] = ACTIONS(5451),
    [anon_sym___attribute__] = ACTIONS(5451),
    [anon_sym_COLON_COLON] = ACTIONS(5453),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5453),
    [anon_sym___declspec] = ACTIONS(5451),
    [anon_sym___based] = ACTIONS(5451),
    [anon_sym___cdecl] = ACTIONS(5451),
    [anon_sym___clrcall] = ACTIONS(5451),
    [anon_sym___stdcall] = ACTIONS(5451),
    [anon_sym___fastcall] = ACTIONS(5451),
    [anon_sym___thiscall] = ACTIONS(5451),
    [anon_sym___vectorcall] = ACTIONS(5451),
    [anon_sym_LBRACK] = ACTIONS(5451),
    [anon_sym_static] = ACTIONS(5451),
    [anon_sym_EQ] = ACTIONS(5453),
    [anon_sym_register] = ACTIONS(5451),
    [anon_sym_inline] = ACTIONS(5451),
    [anon_sym___inline] = ACTIONS(5451),
    [anon_sym___inline__] = ACTIONS(5451),
    [anon_sym___forceinline] = ACTIONS(5451),
    [anon_sym_thread_local] = ACTIONS(5451),
    [anon_sym___thread] = ACTIONS(5451),
    [anon_sym_const] = ACTIONS(5451),
    [anon_sym_constexpr] = ACTIONS(5451),
    [anon_sym_volatile] = ACTIONS(5451),
    [anon_sym_restrict] = ACTIONS(5451),
    [anon_sym___restrict__] = ACTIONS(5451),
    [anon_sym__Atomic] = ACTIONS(5451),
    [anon_sym__Noreturn] = ACTIONS(5451),
    [anon_sym_noreturn] = ACTIONS(5451),
    [anon_sym_mutable] = ACTIONS(5451),
    [anon_sym_constinit] = ACTIONS(5451),
    [anon_sym_consteval] = ACTIONS(5451),
    [anon_sym_alignas] = ACTIONS(5451),
    [anon_sym__Alignas] = ACTIONS(5451),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5451),
    [anon_sym_decltype] = ACTIONS(5451),
    [anon_sym_final] = ACTIONS(5451),
    [anon_sym_override] = ACTIONS(5451),
    [sym_virtual] = ACTIONS(5451),
    [anon_sym_template] = ACTIONS(5451),
    [anon_sym_GT2] = ACTIONS(5453),
    [anon_sym_operator] = ACTIONS(5451),
    [anon_sym_requires] = ACTIONS(5451),
    [anon_sym_precise] = ACTIONS(5451),
    [anon_sym_shared] = ACTIONS(5451),
    [anon_sym_groupshared] = ACTIONS(5451),
    [anon_sym_uniform] = ACTIONS(5451),
    [anon_sym_row_major] = ACTIONS(5451),
    [anon_sym_column_major] = ACTIONS(5451),
    [anon_sym_globallycoherent] = ACTIONS(5451),
    [anon_sym_centroid] = ACTIONS(5451),
    [anon_sym_noperspective] = ACTIONS(5451),
    [anon_sym_nointerpolation] = ACTIONS(5451),
    [anon_sym_sample] = ACTIONS(5451),
    [anon_sym_linear] = ACTIONS(5451),
    [anon_sym_snorm] = ACTIONS(5451),
    [anon_sym_unorm] = ACTIONS(5451),
    [anon_sym_point] = ACTIONS(5451),
    [anon_sym_line] = ACTIONS(5451),
    [anon_sym_triangleadj] = ACTIONS(5451),
    [anon_sym_lineadj] = ACTIONS(5451),
    [anon_sym_triangle] = ACTIONS(5451),
  },
  [2279] = {
    [sym_identifier] = ACTIONS(5318),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5320),
    [anon_sym_COMMA] = ACTIONS(5320),
    [anon_sym_RPAREN] = ACTIONS(5320),
    [anon_sym_LPAREN2] = ACTIONS(5320),
    [anon_sym_TILDE] = ACTIONS(5320),
    [anon_sym_STAR] = ACTIONS(5320),
    [anon_sym_AMP_AMP] = ACTIONS(5320),
    [anon_sym_AMP] = ACTIONS(5318),
    [anon_sym_COLON] = ACTIONS(5318),
    [anon_sym_SEMI] = ACTIONS(5320),
    [anon_sym___extension__] = ACTIONS(5318),
    [anon_sym_in] = ACTIONS(5318),
    [anon_sym_out] = ACTIONS(5318),
    [anon_sym_inout] = ACTIONS(5318),
    [anon_sym_extern] = ACTIONS(5318),
    [anon_sym___attribute__] = ACTIONS(5318),
    [anon_sym_COLON_COLON] = ACTIONS(5320),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5320),
    [anon_sym___declspec] = ACTIONS(5318),
    [anon_sym___based] = ACTIONS(5318),
    [anon_sym___cdecl] = ACTIONS(5318),
    [anon_sym___clrcall] = ACTIONS(5318),
    [anon_sym___stdcall] = ACTIONS(5318),
    [anon_sym___fastcall] = ACTIONS(5318),
    [anon_sym___thiscall] = ACTIONS(5318),
    [anon_sym___vectorcall] = ACTIONS(5318),
    [anon_sym_LBRACK] = ACTIONS(5318),
    [anon_sym_static] = ACTIONS(5318),
    [anon_sym_EQ] = ACTIONS(5320),
    [anon_sym_register] = ACTIONS(5318),
    [anon_sym_inline] = ACTIONS(5318),
    [anon_sym___inline] = ACTIONS(5318),
    [anon_sym___inline__] = ACTIONS(5318),
    [anon_sym___forceinline] = ACTIONS(5318),
    [anon_sym_thread_local] = ACTIONS(5318),
    [anon_sym___thread] = ACTIONS(5318),
    [anon_sym_const] = ACTIONS(5318),
    [anon_sym_constexpr] = ACTIONS(5318),
    [anon_sym_volatile] = ACTIONS(5318),
    [anon_sym_restrict] = ACTIONS(5318),
    [anon_sym___restrict__] = ACTIONS(5318),
    [anon_sym__Atomic] = ACTIONS(5318),
    [anon_sym__Noreturn] = ACTIONS(5318),
    [anon_sym_noreturn] = ACTIONS(5318),
    [anon_sym_mutable] = ACTIONS(5318),
    [anon_sym_constinit] = ACTIONS(5318),
    [anon_sym_consteval] = ACTIONS(5318),
    [anon_sym_alignas] = ACTIONS(5318),
    [anon_sym__Alignas] = ACTIONS(5318),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5318),
    [anon_sym_decltype] = ACTIONS(5318),
    [anon_sym_final] = ACTIONS(5318),
    [anon_sym_override] = ACTIONS(5318),
    [sym_virtual] = ACTIONS(5318),
    [anon_sym_template] = ACTIONS(5318),
    [anon_sym_GT2] = ACTIONS(5320),
    [anon_sym_operator] = ACTIONS(5318),
    [anon_sym_requires] = ACTIONS(5318),
    [anon_sym_precise] = ACTIONS(5318),
    [anon_sym_shared] = ACTIONS(5318),
    [anon_sym_groupshared] = ACTIONS(5318),
    [anon_sym_uniform] = ACTIONS(5318),
    [anon_sym_row_major] = ACTIONS(5318),
    [anon_sym_column_major] = ACTIONS(5318),
    [anon_sym_globallycoherent] = ACTIONS(5318),
    [anon_sym_centroid] = ACTIONS(5318),
    [anon_sym_noperspective] = ACTIONS(5318),
    [anon_sym_nointerpolation] = ACTIONS(5318),
    [anon_sym_sample] = ACTIONS(5318),
    [anon_sym_linear] = ACTIONS(5318),
    [anon_sym_snorm] = ACTIONS(5318),
    [anon_sym_unorm] = ACTIONS(5318),
    [anon_sym_point] = ACTIONS(5318),
    [anon_sym_line] = ACTIONS(5318),
    [anon_sym_triangleadj] = ACTIONS(5318),
    [anon_sym_lineadj] = ACTIONS(5318),
    [anon_sym_triangle] = ACTIONS(5318),
  },
  [2280] = {
    [sym_identifier] = ACTIONS(5455),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5457),
    [anon_sym_COMMA] = ACTIONS(5457),
    [anon_sym_RPAREN] = ACTIONS(5457),
    [anon_sym_LPAREN2] = ACTIONS(5457),
    [anon_sym_TILDE] = ACTIONS(5457),
    [anon_sym_STAR] = ACTIONS(5457),
    [anon_sym_AMP_AMP] = ACTIONS(5457),
    [anon_sym_AMP] = ACTIONS(5455),
    [anon_sym_COLON] = ACTIONS(5455),
    [anon_sym_SEMI] = ACTIONS(5457),
    [anon_sym___extension__] = ACTIONS(5455),
    [anon_sym_in] = ACTIONS(5455),
    [anon_sym_out] = ACTIONS(5455),
    [anon_sym_inout] = ACTIONS(5455),
    [anon_sym_extern] = ACTIONS(5455),
    [anon_sym___attribute__] = ACTIONS(5455),
    [anon_sym_COLON_COLON] = ACTIONS(5457),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5457),
    [anon_sym___declspec] = ACTIONS(5455),
    [anon_sym___based] = ACTIONS(5455),
    [anon_sym___cdecl] = ACTIONS(5455),
    [anon_sym___clrcall] = ACTIONS(5455),
    [anon_sym___stdcall] = ACTIONS(5455),
    [anon_sym___fastcall] = ACTIONS(5455),
    [anon_sym___thiscall] = ACTIONS(5455),
    [anon_sym___vectorcall] = ACTIONS(5455),
    [anon_sym_LBRACK] = ACTIONS(5455),
    [anon_sym_static] = ACTIONS(5455),
    [anon_sym_EQ] = ACTIONS(5457),
    [anon_sym_register] = ACTIONS(5455),
    [anon_sym_inline] = ACTIONS(5455),
    [anon_sym___inline] = ACTIONS(5455),
    [anon_sym___inline__] = ACTIONS(5455),
    [anon_sym___forceinline] = ACTIONS(5455),
    [anon_sym_thread_local] = ACTIONS(5455),
    [anon_sym___thread] = ACTIONS(5455),
    [anon_sym_const] = ACTIONS(5455),
    [anon_sym_constexpr] = ACTIONS(5455),
    [anon_sym_volatile] = ACTIONS(5455),
    [anon_sym_restrict] = ACTIONS(5455),
    [anon_sym___restrict__] = ACTIONS(5455),
    [anon_sym__Atomic] = ACTIONS(5455),
    [anon_sym__Noreturn] = ACTIONS(5455),
    [anon_sym_noreturn] = ACTIONS(5455),
    [anon_sym_mutable] = ACTIONS(5455),
    [anon_sym_constinit] = ACTIONS(5455),
    [anon_sym_consteval] = ACTIONS(5455),
    [anon_sym_alignas] = ACTIONS(5455),
    [anon_sym__Alignas] = ACTIONS(5455),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5455),
    [anon_sym_decltype] = ACTIONS(5455),
    [anon_sym_final] = ACTIONS(5455),
    [anon_sym_override] = ACTIONS(5455),
    [sym_virtual] = ACTIONS(5455),
    [anon_sym_template] = ACTIONS(5455),
    [anon_sym_GT2] = ACTIONS(5457),
    [anon_sym_operator] = ACTIONS(5455),
    [anon_sym_requires] = ACTIONS(5455),
    [anon_sym_precise] = ACTIONS(5455),
    [anon_sym_shared] = ACTIONS(5455),
    [anon_sym_groupshared] = ACTIONS(5455),
    [anon_sym_uniform] = ACTIONS(5455),
    [anon_sym_row_major] = ACTIONS(5455),
    [anon_sym_column_major] = ACTIONS(5455),
    [anon_sym_globallycoherent] = ACTIONS(5455),
    [anon_sym_centroid] = ACTIONS(5455),
    [anon_sym_noperspective] = ACTIONS(5455),
    [anon_sym_nointerpolation] = ACTIONS(5455),
    [anon_sym_sample] = ACTIONS(5455),
    [anon_sym_linear] = ACTIONS(5455),
    [anon_sym_snorm] = ACTIONS(5455),
    [anon_sym_unorm] = ACTIONS(5455),
    [anon_sym_point] = ACTIONS(5455),
    [anon_sym_line] = ACTIONS(5455),
    [anon_sym_triangleadj] = ACTIONS(5455),
    [anon_sym_lineadj] = ACTIONS(5455),
    [anon_sym_triangle] = ACTIONS(5455),
  },
  [2281] = {
    [sym_identifier] = ACTIONS(5459),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5461),
    [anon_sym_COMMA] = ACTIONS(5461),
    [anon_sym_RPAREN] = ACTIONS(5461),
    [anon_sym_LPAREN2] = ACTIONS(5461),
    [anon_sym_TILDE] = ACTIONS(5461),
    [anon_sym_STAR] = ACTIONS(5461),
    [anon_sym_AMP_AMP] = ACTIONS(5461),
    [anon_sym_AMP] = ACTIONS(5459),
    [anon_sym_COLON] = ACTIONS(5459),
    [anon_sym_SEMI] = ACTIONS(5461),
    [anon_sym___extension__] = ACTIONS(5459),
    [anon_sym_in] = ACTIONS(5459),
    [anon_sym_out] = ACTIONS(5459),
    [anon_sym_inout] = ACTIONS(5459),
    [anon_sym_extern] = ACTIONS(5459),
    [anon_sym___attribute__] = ACTIONS(5459),
    [anon_sym_COLON_COLON] = ACTIONS(5461),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5461),
    [anon_sym___declspec] = ACTIONS(5459),
    [anon_sym___based] = ACTIONS(5459),
    [anon_sym___cdecl] = ACTIONS(5459),
    [anon_sym___clrcall] = ACTIONS(5459),
    [anon_sym___stdcall] = ACTIONS(5459),
    [anon_sym___fastcall] = ACTIONS(5459),
    [anon_sym___thiscall] = ACTIONS(5459),
    [anon_sym___vectorcall] = ACTIONS(5459),
    [anon_sym_LBRACK] = ACTIONS(5459),
    [anon_sym_static] = ACTIONS(5459),
    [anon_sym_EQ] = ACTIONS(5461),
    [anon_sym_register] = ACTIONS(5459),
    [anon_sym_inline] = ACTIONS(5459),
    [anon_sym___inline] = ACTIONS(5459),
    [anon_sym___inline__] = ACTIONS(5459),
    [anon_sym___forceinline] = ACTIONS(5459),
    [anon_sym_thread_local] = ACTIONS(5459),
    [anon_sym___thread] = ACTIONS(5459),
    [anon_sym_const] = ACTIONS(5459),
    [anon_sym_constexpr] = ACTIONS(5459),
    [anon_sym_volatile] = ACTIONS(5459),
    [anon_sym_restrict] = ACTIONS(5459),
    [anon_sym___restrict__] = ACTIONS(5459),
    [anon_sym__Atomic] = ACTIONS(5459),
    [anon_sym__Noreturn] = ACTIONS(5459),
    [anon_sym_noreturn] = ACTIONS(5459),
    [anon_sym_mutable] = ACTIONS(5459),
    [anon_sym_constinit] = ACTIONS(5459),
    [anon_sym_consteval] = ACTIONS(5459),
    [anon_sym_alignas] = ACTIONS(5459),
    [anon_sym__Alignas] = ACTIONS(5459),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5459),
    [anon_sym_decltype] = ACTIONS(5459),
    [anon_sym_final] = ACTIONS(5459),
    [anon_sym_override] = ACTIONS(5459),
    [sym_virtual] = ACTIONS(5459),
    [anon_sym_template] = ACTIONS(5459),
    [anon_sym_GT2] = ACTIONS(5461),
    [anon_sym_operator] = ACTIONS(5459),
    [anon_sym_requires] = ACTIONS(5459),
    [anon_sym_precise] = ACTIONS(5459),
    [anon_sym_shared] = ACTIONS(5459),
    [anon_sym_groupshared] = ACTIONS(5459),
    [anon_sym_uniform] = ACTIONS(5459),
    [anon_sym_row_major] = ACTIONS(5459),
    [anon_sym_column_major] = ACTIONS(5459),
    [anon_sym_globallycoherent] = ACTIONS(5459),
    [anon_sym_centroid] = ACTIONS(5459),
    [anon_sym_noperspective] = ACTIONS(5459),
    [anon_sym_nointerpolation] = ACTIONS(5459),
    [anon_sym_sample] = ACTIONS(5459),
    [anon_sym_linear] = ACTIONS(5459),
    [anon_sym_snorm] = ACTIONS(5459),
    [anon_sym_unorm] = ACTIONS(5459),
    [anon_sym_point] = ACTIONS(5459),
    [anon_sym_line] = ACTIONS(5459),
    [anon_sym_triangleadj] = ACTIONS(5459),
    [anon_sym_lineadj] = ACTIONS(5459),
    [anon_sym_triangle] = ACTIONS(5459),
  },
  [2282] = {
    [sym_identifier] = ACTIONS(5463),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5465),
    [anon_sym_COMMA] = ACTIONS(5465),
    [anon_sym_RPAREN] = ACTIONS(5465),
    [anon_sym_LPAREN2] = ACTIONS(5465),
    [anon_sym_TILDE] = ACTIONS(5465),
    [anon_sym_STAR] = ACTIONS(5465),
    [anon_sym_AMP_AMP] = ACTIONS(5465),
    [anon_sym_AMP] = ACTIONS(5463),
    [anon_sym_COLON] = ACTIONS(5463),
    [anon_sym_SEMI] = ACTIONS(5465),
    [anon_sym___extension__] = ACTIONS(5463),
    [anon_sym_in] = ACTIONS(5463),
    [anon_sym_out] = ACTIONS(5463),
    [anon_sym_inout] = ACTIONS(5463),
    [anon_sym_extern] = ACTIONS(5463),
    [anon_sym___attribute__] = ACTIONS(5463),
    [anon_sym_COLON_COLON] = ACTIONS(5465),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5465),
    [anon_sym___declspec] = ACTIONS(5463),
    [anon_sym___based] = ACTIONS(5463),
    [anon_sym___cdecl] = ACTIONS(5463),
    [anon_sym___clrcall] = ACTIONS(5463),
    [anon_sym___stdcall] = ACTIONS(5463),
    [anon_sym___fastcall] = ACTIONS(5463),
    [anon_sym___thiscall] = ACTIONS(5463),
    [anon_sym___vectorcall] = ACTIONS(5463),
    [anon_sym_LBRACK] = ACTIONS(5463),
    [anon_sym_static] = ACTIONS(5463),
    [anon_sym_EQ] = ACTIONS(5465),
    [anon_sym_register] = ACTIONS(5463),
    [anon_sym_inline] = ACTIONS(5463),
    [anon_sym___inline] = ACTIONS(5463),
    [anon_sym___inline__] = ACTIONS(5463),
    [anon_sym___forceinline] = ACTIONS(5463),
    [anon_sym_thread_local] = ACTIONS(5463),
    [anon_sym___thread] = ACTIONS(5463),
    [anon_sym_const] = ACTIONS(5463),
    [anon_sym_constexpr] = ACTIONS(5463),
    [anon_sym_volatile] = ACTIONS(5463),
    [anon_sym_restrict] = ACTIONS(5463),
    [anon_sym___restrict__] = ACTIONS(5463),
    [anon_sym__Atomic] = ACTIONS(5463),
    [anon_sym__Noreturn] = ACTIONS(5463),
    [anon_sym_noreturn] = ACTIONS(5463),
    [anon_sym_mutable] = ACTIONS(5463),
    [anon_sym_constinit] = ACTIONS(5463),
    [anon_sym_consteval] = ACTIONS(5463),
    [anon_sym_alignas] = ACTIONS(5463),
    [anon_sym__Alignas] = ACTIONS(5463),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5463),
    [anon_sym_decltype] = ACTIONS(5463),
    [anon_sym_final] = ACTIONS(5463),
    [anon_sym_override] = ACTIONS(5463),
    [sym_virtual] = ACTIONS(5463),
    [anon_sym_template] = ACTIONS(5463),
    [anon_sym_GT2] = ACTIONS(5465),
    [anon_sym_operator] = ACTIONS(5463),
    [anon_sym_requires] = ACTIONS(5463),
    [anon_sym_precise] = ACTIONS(5463),
    [anon_sym_shared] = ACTIONS(5463),
    [anon_sym_groupshared] = ACTIONS(5463),
    [anon_sym_uniform] = ACTIONS(5463),
    [anon_sym_row_major] = ACTIONS(5463),
    [anon_sym_column_major] = ACTIONS(5463),
    [anon_sym_globallycoherent] = ACTIONS(5463),
    [anon_sym_centroid] = ACTIONS(5463),
    [anon_sym_noperspective] = ACTIONS(5463),
    [anon_sym_nointerpolation] = ACTIONS(5463),
    [anon_sym_sample] = ACTIONS(5463),
    [anon_sym_linear] = ACTIONS(5463),
    [anon_sym_snorm] = ACTIONS(5463),
    [anon_sym_unorm] = ACTIONS(5463),
    [anon_sym_point] = ACTIONS(5463),
    [anon_sym_line] = ACTIONS(5463),
    [anon_sym_triangleadj] = ACTIONS(5463),
    [anon_sym_lineadj] = ACTIONS(5463),
    [anon_sym_triangle] = ACTIONS(5463),
  },
  [2283] = {
    [sym_identifier] = ACTIONS(5467),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5469),
    [anon_sym_COMMA] = ACTIONS(5469),
    [anon_sym_RPAREN] = ACTIONS(5469),
    [anon_sym_LPAREN2] = ACTIONS(5469),
    [anon_sym_TILDE] = ACTIONS(5469),
    [anon_sym_STAR] = ACTIONS(5469),
    [anon_sym_AMP_AMP] = ACTIONS(5469),
    [anon_sym_AMP] = ACTIONS(5467),
    [anon_sym_COLON] = ACTIONS(5467),
    [anon_sym_SEMI] = ACTIONS(5469),
    [anon_sym___extension__] = ACTIONS(5467),
    [anon_sym_in] = ACTIONS(5467),
    [anon_sym_out] = ACTIONS(5467),
    [anon_sym_inout] = ACTIONS(5467),
    [anon_sym_extern] = ACTIONS(5467),
    [anon_sym___attribute__] = ACTIONS(5467),
    [anon_sym_COLON_COLON] = ACTIONS(5469),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5469),
    [anon_sym___declspec] = ACTIONS(5467),
    [anon_sym___based] = ACTIONS(5467),
    [anon_sym___cdecl] = ACTIONS(5467),
    [anon_sym___clrcall] = ACTIONS(5467),
    [anon_sym___stdcall] = ACTIONS(5467),
    [anon_sym___fastcall] = ACTIONS(5467),
    [anon_sym___thiscall] = ACTIONS(5467),
    [anon_sym___vectorcall] = ACTIONS(5467),
    [anon_sym_LBRACK] = ACTIONS(5467),
    [anon_sym_static] = ACTIONS(5467),
    [anon_sym_EQ] = ACTIONS(5469),
    [anon_sym_register] = ACTIONS(5467),
    [anon_sym_inline] = ACTIONS(5467),
    [anon_sym___inline] = ACTIONS(5467),
    [anon_sym___inline__] = ACTIONS(5467),
    [anon_sym___forceinline] = ACTIONS(5467),
    [anon_sym_thread_local] = ACTIONS(5467),
    [anon_sym___thread] = ACTIONS(5467),
    [anon_sym_const] = ACTIONS(5467),
    [anon_sym_constexpr] = ACTIONS(5467),
    [anon_sym_volatile] = ACTIONS(5467),
    [anon_sym_restrict] = ACTIONS(5467),
    [anon_sym___restrict__] = ACTIONS(5467),
    [anon_sym__Atomic] = ACTIONS(5467),
    [anon_sym__Noreturn] = ACTIONS(5467),
    [anon_sym_noreturn] = ACTIONS(5467),
    [anon_sym_mutable] = ACTIONS(5467),
    [anon_sym_constinit] = ACTIONS(5467),
    [anon_sym_consteval] = ACTIONS(5467),
    [anon_sym_alignas] = ACTIONS(5467),
    [anon_sym__Alignas] = ACTIONS(5467),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5467),
    [anon_sym_decltype] = ACTIONS(5467),
    [anon_sym_final] = ACTIONS(5467),
    [anon_sym_override] = ACTIONS(5467),
    [sym_virtual] = ACTIONS(5467),
    [anon_sym_template] = ACTIONS(5467),
    [anon_sym_GT2] = ACTIONS(5469),
    [anon_sym_operator] = ACTIONS(5467),
    [anon_sym_requires] = ACTIONS(5467),
    [anon_sym_precise] = ACTIONS(5467),
    [anon_sym_shared] = ACTIONS(5467),
    [anon_sym_groupshared] = ACTIONS(5467),
    [anon_sym_uniform] = ACTIONS(5467),
    [anon_sym_row_major] = ACTIONS(5467),
    [anon_sym_column_major] = ACTIONS(5467),
    [anon_sym_globallycoherent] = ACTIONS(5467),
    [anon_sym_centroid] = ACTIONS(5467),
    [anon_sym_noperspective] = ACTIONS(5467),
    [anon_sym_nointerpolation] = ACTIONS(5467),
    [anon_sym_sample] = ACTIONS(5467),
    [anon_sym_linear] = ACTIONS(5467),
    [anon_sym_snorm] = ACTIONS(5467),
    [anon_sym_unorm] = ACTIONS(5467),
    [anon_sym_point] = ACTIONS(5467),
    [anon_sym_line] = ACTIONS(5467),
    [anon_sym_triangleadj] = ACTIONS(5467),
    [anon_sym_lineadj] = ACTIONS(5467),
    [anon_sym_triangle] = ACTIONS(5467),
  },
  [2284] = {
    [sym_identifier] = ACTIONS(5471),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5473),
    [anon_sym_COMMA] = ACTIONS(5473),
    [anon_sym_RPAREN] = ACTIONS(5473),
    [anon_sym_LPAREN2] = ACTIONS(5473),
    [anon_sym_TILDE] = ACTIONS(5473),
    [anon_sym_STAR] = ACTIONS(5473),
    [anon_sym_AMP_AMP] = ACTIONS(5473),
    [anon_sym_AMP] = ACTIONS(5471),
    [anon_sym_COLON] = ACTIONS(5471),
    [anon_sym_SEMI] = ACTIONS(5473),
    [anon_sym___extension__] = ACTIONS(5471),
    [anon_sym_in] = ACTIONS(5471),
    [anon_sym_out] = ACTIONS(5471),
    [anon_sym_inout] = ACTIONS(5471),
    [anon_sym_extern] = ACTIONS(5471),
    [anon_sym___attribute__] = ACTIONS(5471),
    [anon_sym_COLON_COLON] = ACTIONS(5473),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5473),
    [anon_sym___declspec] = ACTIONS(5471),
    [anon_sym___based] = ACTIONS(5471),
    [anon_sym___cdecl] = ACTIONS(5471),
    [anon_sym___clrcall] = ACTIONS(5471),
    [anon_sym___stdcall] = ACTIONS(5471),
    [anon_sym___fastcall] = ACTIONS(5471),
    [anon_sym___thiscall] = ACTIONS(5471),
    [anon_sym___vectorcall] = ACTIONS(5471),
    [anon_sym_LBRACK] = ACTIONS(5471),
    [anon_sym_static] = ACTIONS(5471),
    [anon_sym_EQ] = ACTIONS(5473),
    [anon_sym_register] = ACTIONS(5471),
    [anon_sym_inline] = ACTIONS(5471),
    [anon_sym___inline] = ACTIONS(5471),
    [anon_sym___inline__] = ACTIONS(5471),
    [anon_sym___forceinline] = ACTIONS(5471),
    [anon_sym_thread_local] = ACTIONS(5471),
    [anon_sym___thread] = ACTIONS(5471),
    [anon_sym_const] = ACTIONS(5471),
    [anon_sym_constexpr] = ACTIONS(5471),
    [anon_sym_volatile] = ACTIONS(5471),
    [anon_sym_restrict] = ACTIONS(5471),
    [anon_sym___restrict__] = ACTIONS(5471),
    [anon_sym__Atomic] = ACTIONS(5471),
    [anon_sym__Noreturn] = ACTIONS(5471),
    [anon_sym_noreturn] = ACTIONS(5471),
    [anon_sym_mutable] = ACTIONS(5471),
    [anon_sym_constinit] = ACTIONS(5471),
    [anon_sym_consteval] = ACTIONS(5471),
    [anon_sym_alignas] = ACTIONS(5471),
    [anon_sym__Alignas] = ACTIONS(5471),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5471),
    [anon_sym_decltype] = ACTIONS(5471),
    [anon_sym_final] = ACTIONS(5471),
    [anon_sym_override] = ACTIONS(5471),
    [sym_virtual] = ACTIONS(5471),
    [anon_sym_template] = ACTIONS(5471),
    [anon_sym_GT2] = ACTIONS(5473),
    [anon_sym_operator] = ACTIONS(5471),
    [anon_sym_requires] = ACTIONS(5471),
    [anon_sym_precise] = ACTIONS(5471),
    [anon_sym_shared] = ACTIONS(5471),
    [anon_sym_groupshared] = ACTIONS(5471),
    [anon_sym_uniform] = ACTIONS(5471),
    [anon_sym_row_major] = ACTIONS(5471),
    [anon_sym_column_major] = ACTIONS(5471),
    [anon_sym_globallycoherent] = ACTIONS(5471),
    [anon_sym_centroid] = ACTIONS(5471),
    [anon_sym_noperspective] = ACTIONS(5471),
    [anon_sym_nointerpolation] = ACTIONS(5471),
    [anon_sym_sample] = ACTIONS(5471),
    [anon_sym_linear] = ACTIONS(5471),
    [anon_sym_snorm] = ACTIONS(5471),
    [anon_sym_unorm] = ACTIONS(5471),
    [anon_sym_point] = ACTIONS(5471),
    [anon_sym_line] = ACTIONS(5471),
    [anon_sym_triangleadj] = ACTIONS(5471),
    [anon_sym_lineadj] = ACTIONS(5471),
    [anon_sym_triangle] = ACTIONS(5471),
  },
  [2285] = {
    [sym_identifier] = ACTIONS(5475),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5477),
    [anon_sym_COMMA] = ACTIONS(5477),
    [anon_sym_RPAREN] = ACTIONS(5477),
    [anon_sym_LPAREN2] = ACTIONS(5477),
    [anon_sym_TILDE] = ACTIONS(5477),
    [anon_sym_STAR] = ACTIONS(5477),
    [anon_sym_AMP_AMP] = ACTIONS(5477),
    [anon_sym_AMP] = ACTIONS(5475),
    [anon_sym_COLON] = ACTIONS(5475),
    [anon_sym_SEMI] = ACTIONS(5477),
    [anon_sym___extension__] = ACTIONS(5475),
    [anon_sym_in] = ACTIONS(5475),
    [anon_sym_out] = ACTIONS(5475),
    [anon_sym_inout] = ACTIONS(5475),
    [anon_sym_extern] = ACTIONS(5475),
    [anon_sym___attribute__] = ACTIONS(5475),
    [anon_sym_COLON_COLON] = ACTIONS(5477),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5477),
    [anon_sym___declspec] = ACTIONS(5475),
    [anon_sym___based] = ACTIONS(5475),
    [anon_sym___cdecl] = ACTIONS(5475),
    [anon_sym___clrcall] = ACTIONS(5475),
    [anon_sym___stdcall] = ACTIONS(5475),
    [anon_sym___fastcall] = ACTIONS(5475),
    [anon_sym___thiscall] = ACTIONS(5475),
    [anon_sym___vectorcall] = ACTIONS(5475),
    [anon_sym_LBRACK] = ACTIONS(5475),
    [anon_sym_static] = ACTIONS(5475),
    [anon_sym_EQ] = ACTIONS(5477),
    [anon_sym_register] = ACTIONS(5475),
    [anon_sym_inline] = ACTIONS(5475),
    [anon_sym___inline] = ACTIONS(5475),
    [anon_sym___inline__] = ACTIONS(5475),
    [anon_sym___forceinline] = ACTIONS(5475),
    [anon_sym_thread_local] = ACTIONS(5475),
    [anon_sym___thread] = ACTIONS(5475),
    [anon_sym_const] = ACTIONS(5475),
    [anon_sym_constexpr] = ACTIONS(5475),
    [anon_sym_volatile] = ACTIONS(5475),
    [anon_sym_restrict] = ACTIONS(5475),
    [anon_sym___restrict__] = ACTIONS(5475),
    [anon_sym__Atomic] = ACTIONS(5475),
    [anon_sym__Noreturn] = ACTIONS(5475),
    [anon_sym_noreturn] = ACTIONS(5475),
    [anon_sym_mutable] = ACTIONS(5475),
    [anon_sym_constinit] = ACTIONS(5475),
    [anon_sym_consteval] = ACTIONS(5475),
    [anon_sym_alignas] = ACTIONS(5475),
    [anon_sym__Alignas] = ACTIONS(5475),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5475),
    [anon_sym_decltype] = ACTIONS(5475),
    [anon_sym_final] = ACTIONS(5475),
    [anon_sym_override] = ACTIONS(5475),
    [sym_virtual] = ACTIONS(5475),
    [anon_sym_template] = ACTIONS(5475),
    [anon_sym_GT2] = ACTIONS(5477),
    [anon_sym_operator] = ACTIONS(5475),
    [anon_sym_requires] = ACTIONS(5475),
    [anon_sym_precise] = ACTIONS(5475),
    [anon_sym_shared] = ACTIONS(5475),
    [anon_sym_groupshared] = ACTIONS(5475),
    [anon_sym_uniform] = ACTIONS(5475),
    [anon_sym_row_major] = ACTIONS(5475),
    [anon_sym_column_major] = ACTIONS(5475),
    [anon_sym_globallycoherent] = ACTIONS(5475),
    [anon_sym_centroid] = ACTIONS(5475),
    [anon_sym_noperspective] = ACTIONS(5475),
    [anon_sym_nointerpolation] = ACTIONS(5475),
    [anon_sym_sample] = ACTIONS(5475),
    [anon_sym_linear] = ACTIONS(5475),
    [anon_sym_snorm] = ACTIONS(5475),
    [anon_sym_unorm] = ACTIONS(5475),
    [anon_sym_point] = ACTIONS(5475),
    [anon_sym_line] = ACTIONS(5475),
    [anon_sym_triangleadj] = ACTIONS(5475),
    [anon_sym_lineadj] = ACTIONS(5475),
    [anon_sym_triangle] = ACTIONS(5475),
  },
  [2286] = {
    [sym_identifier] = ACTIONS(5479),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5481),
    [anon_sym_COMMA] = ACTIONS(5481),
    [anon_sym_RPAREN] = ACTIONS(5481),
    [anon_sym_LPAREN2] = ACTIONS(5481),
    [anon_sym_TILDE] = ACTIONS(5481),
    [anon_sym_STAR] = ACTIONS(5481),
    [anon_sym_AMP_AMP] = ACTIONS(5481),
    [anon_sym_AMP] = ACTIONS(5479),
    [anon_sym_COLON] = ACTIONS(5479),
    [anon_sym_SEMI] = ACTIONS(5481),
    [anon_sym___extension__] = ACTIONS(5479),
    [anon_sym_in] = ACTIONS(5479),
    [anon_sym_out] = ACTIONS(5479),
    [anon_sym_inout] = ACTIONS(5479),
    [anon_sym_extern] = ACTIONS(5479),
    [anon_sym___attribute__] = ACTIONS(5479),
    [anon_sym_COLON_COLON] = ACTIONS(5481),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5481),
    [anon_sym___declspec] = ACTIONS(5479),
    [anon_sym___based] = ACTIONS(5479),
    [anon_sym___cdecl] = ACTIONS(5479),
    [anon_sym___clrcall] = ACTIONS(5479),
    [anon_sym___stdcall] = ACTIONS(5479),
    [anon_sym___fastcall] = ACTIONS(5479),
    [anon_sym___thiscall] = ACTIONS(5479),
    [anon_sym___vectorcall] = ACTIONS(5479),
    [anon_sym_LBRACK] = ACTIONS(5479),
    [anon_sym_static] = ACTIONS(5479),
    [anon_sym_EQ] = ACTIONS(5481),
    [anon_sym_register] = ACTIONS(5479),
    [anon_sym_inline] = ACTIONS(5479),
    [anon_sym___inline] = ACTIONS(5479),
    [anon_sym___inline__] = ACTIONS(5479),
    [anon_sym___forceinline] = ACTIONS(5479),
    [anon_sym_thread_local] = ACTIONS(5479),
    [anon_sym___thread] = ACTIONS(5479),
    [anon_sym_const] = ACTIONS(5479),
    [anon_sym_constexpr] = ACTIONS(5479),
    [anon_sym_volatile] = ACTIONS(5479),
    [anon_sym_restrict] = ACTIONS(5479),
    [anon_sym___restrict__] = ACTIONS(5479),
    [anon_sym__Atomic] = ACTIONS(5479),
    [anon_sym__Noreturn] = ACTIONS(5479),
    [anon_sym_noreturn] = ACTIONS(5479),
    [anon_sym_mutable] = ACTIONS(5479),
    [anon_sym_constinit] = ACTIONS(5479),
    [anon_sym_consteval] = ACTIONS(5479),
    [anon_sym_alignas] = ACTIONS(5479),
    [anon_sym__Alignas] = ACTIONS(5479),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5479),
    [anon_sym_decltype] = ACTIONS(5479),
    [anon_sym_final] = ACTIONS(5479),
    [anon_sym_override] = ACTIONS(5479),
    [sym_virtual] = ACTIONS(5479),
    [anon_sym_template] = ACTIONS(5479),
    [anon_sym_GT2] = ACTIONS(5481),
    [anon_sym_operator] = ACTIONS(5479),
    [anon_sym_requires] = ACTIONS(5479),
    [anon_sym_precise] = ACTIONS(5479),
    [anon_sym_shared] = ACTIONS(5479),
    [anon_sym_groupshared] = ACTIONS(5479),
    [anon_sym_uniform] = ACTIONS(5479),
    [anon_sym_row_major] = ACTIONS(5479),
    [anon_sym_column_major] = ACTIONS(5479),
    [anon_sym_globallycoherent] = ACTIONS(5479),
    [anon_sym_centroid] = ACTIONS(5479),
    [anon_sym_noperspective] = ACTIONS(5479),
    [anon_sym_nointerpolation] = ACTIONS(5479),
    [anon_sym_sample] = ACTIONS(5479),
    [anon_sym_linear] = ACTIONS(5479),
    [anon_sym_snorm] = ACTIONS(5479),
    [anon_sym_unorm] = ACTIONS(5479),
    [anon_sym_point] = ACTIONS(5479),
    [anon_sym_line] = ACTIONS(5479),
    [anon_sym_triangleadj] = ACTIONS(5479),
    [anon_sym_lineadj] = ACTIONS(5479),
    [anon_sym_triangle] = ACTIONS(5479),
  },
  [2287] = {
    [sym_identifier] = ACTIONS(5483),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5485),
    [anon_sym_COMMA] = ACTIONS(5485),
    [anon_sym_RPAREN] = ACTIONS(5485),
    [anon_sym_LPAREN2] = ACTIONS(5485),
    [anon_sym_TILDE] = ACTIONS(5485),
    [anon_sym_STAR] = ACTIONS(5485),
    [anon_sym_AMP_AMP] = ACTIONS(5485),
    [anon_sym_AMP] = ACTIONS(5483),
    [anon_sym_COLON] = ACTIONS(5483),
    [anon_sym_SEMI] = ACTIONS(5485),
    [anon_sym___extension__] = ACTIONS(5483),
    [anon_sym_in] = ACTIONS(5483),
    [anon_sym_out] = ACTIONS(5483),
    [anon_sym_inout] = ACTIONS(5483),
    [anon_sym_extern] = ACTIONS(5483),
    [anon_sym___attribute__] = ACTIONS(5483),
    [anon_sym_COLON_COLON] = ACTIONS(5485),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5485),
    [anon_sym___declspec] = ACTIONS(5483),
    [anon_sym___based] = ACTIONS(5483),
    [anon_sym___cdecl] = ACTIONS(5483),
    [anon_sym___clrcall] = ACTIONS(5483),
    [anon_sym___stdcall] = ACTIONS(5483),
    [anon_sym___fastcall] = ACTIONS(5483),
    [anon_sym___thiscall] = ACTIONS(5483),
    [anon_sym___vectorcall] = ACTIONS(5483),
    [anon_sym_LBRACK] = ACTIONS(5483),
    [anon_sym_static] = ACTIONS(5483),
    [anon_sym_EQ] = ACTIONS(5485),
    [anon_sym_register] = ACTIONS(5483),
    [anon_sym_inline] = ACTIONS(5483),
    [anon_sym___inline] = ACTIONS(5483),
    [anon_sym___inline__] = ACTIONS(5483),
    [anon_sym___forceinline] = ACTIONS(5483),
    [anon_sym_thread_local] = ACTIONS(5483),
    [anon_sym___thread] = ACTIONS(5483),
    [anon_sym_const] = ACTIONS(5483),
    [anon_sym_constexpr] = ACTIONS(5483),
    [anon_sym_volatile] = ACTIONS(5483),
    [anon_sym_restrict] = ACTIONS(5483),
    [anon_sym___restrict__] = ACTIONS(5483),
    [anon_sym__Atomic] = ACTIONS(5483),
    [anon_sym__Noreturn] = ACTIONS(5483),
    [anon_sym_noreturn] = ACTIONS(5483),
    [anon_sym_mutable] = ACTIONS(5483),
    [anon_sym_constinit] = ACTIONS(5483),
    [anon_sym_consteval] = ACTIONS(5483),
    [anon_sym_alignas] = ACTIONS(5483),
    [anon_sym__Alignas] = ACTIONS(5483),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5483),
    [anon_sym_decltype] = ACTIONS(5483),
    [anon_sym_final] = ACTIONS(5483),
    [anon_sym_override] = ACTIONS(5483),
    [sym_virtual] = ACTIONS(5483),
    [anon_sym_template] = ACTIONS(5483),
    [anon_sym_GT2] = ACTIONS(5485),
    [anon_sym_operator] = ACTIONS(5483),
    [anon_sym_requires] = ACTIONS(5483),
    [anon_sym_precise] = ACTIONS(5483),
    [anon_sym_shared] = ACTIONS(5483),
    [anon_sym_groupshared] = ACTIONS(5483),
    [anon_sym_uniform] = ACTIONS(5483),
    [anon_sym_row_major] = ACTIONS(5483),
    [anon_sym_column_major] = ACTIONS(5483),
    [anon_sym_globallycoherent] = ACTIONS(5483),
    [anon_sym_centroid] = ACTIONS(5483),
    [anon_sym_noperspective] = ACTIONS(5483),
    [anon_sym_nointerpolation] = ACTIONS(5483),
    [anon_sym_sample] = ACTIONS(5483),
    [anon_sym_linear] = ACTIONS(5483),
    [anon_sym_snorm] = ACTIONS(5483),
    [anon_sym_unorm] = ACTIONS(5483),
    [anon_sym_point] = ACTIONS(5483),
    [anon_sym_line] = ACTIONS(5483),
    [anon_sym_triangleadj] = ACTIONS(5483),
    [anon_sym_lineadj] = ACTIONS(5483),
    [anon_sym_triangle] = ACTIONS(5483),
  },
  [2288] = {
    [sym_identifier] = ACTIONS(5467),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5469),
    [anon_sym_COMMA] = ACTIONS(5469),
    [anon_sym_RPAREN] = ACTIONS(5469),
    [anon_sym_LPAREN2] = ACTIONS(5469),
    [anon_sym_TILDE] = ACTIONS(5469),
    [anon_sym_STAR] = ACTIONS(5469),
    [anon_sym_AMP_AMP] = ACTIONS(5469),
    [anon_sym_AMP] = ACTIONS(5467),
    [anon_sym_COLON] = ACTIONS(5467),
    [anon_sym_SEMI] = ACTIONS(5469),
    [anon_sym___extension__] = ACTIONS(5467),
    [anon_sym_in] = ACTIONS(5467),
    [anon_sym_out] = ACTIONS(5467),
    [anon_sym_inout] = ACTIONS(5467),
    [anon_sym_extern] = ACTIONS(5467),
    [anon_sym___attribute__] = ACTIONS(5467),
    [anon_sym_COLON_COLON] = ACTIONS(5469),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5469),
    [anon_sym___declspec] = ACTIONS(5467),
    [anon_sym___based] = ACTIONS(5467),
    [anon_sym___cdecl] = ACTIONS(5467),
    [anon_sym___clrcall] = ACTIONS(5467),
    [anon_sym___stdcall] = ACTIONS(5467),
    [anon_sym___fastcall] = ACTIONS(5467),
    [anon_sym___thiscall] = ACTIONS(5467),
    [anon_sym___vectorcall] = ACTIONS(5467),
    [anon_sym_LBRACK] = ACTIONS(5467),
    [anon_sym_static] = ACTIONS(5467),
    [anon_sym_EQ] = ACTIONS(5469),
    [anon_sym_register] = ACTIONS(5467),
    [anon_sym_inline] = ACTIONS(5467),
    [anon_sym___inline] = ACTIONS(5467),
    [anon_sym___inline__] = ACTIONS(5467),
    [anon_sym___forceinline] = ACTIONS(5467),
    [anon_sym_thread_local] = ACTIONS(5467),
    [anon_sym___thread] = ACTIONS(5467),
    [anon_sym_const] = ACTIONS(5467),
    [anon_sym_constexpr] = ACTIONS(5467),
    [anon_sym_volatile] = ACTIONS(5467),
    [anon_sym_restrict] = ACTIONS(5467),
    [anon_sym___restrict__] = ACTIONS(5467),
    [anon_sym__Atomic] = ACTIONS(5467),
    [anon_sym__Noreturn] = ACTIONS(5467),
    [anon_sym_noreturn] = ACTIONS(5467),
    [anon_sym_mutable] = ACTIONS(5467),
    [anon_sym_constinit] = ACTIONS(5467),
    [anon_sym_consteval] = ACTIONS(5467),
    [anon_sym_alignas] = ACTIONS(5467),
    [anon_sym__Alignas] = ACTIONS(5467),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5467),
    [anon_sym_decltype] = ACTIONS(5467),
    [anon_sym_final] = ACTIONS(5467),
    [anon_sym_override] = ACTIONS(5467),
    [sym_virtual] = ACTIONS(5467),
    [anon_sym_template] = ACTIONS(5467),
    [anon_sym_GT2] = ACTIONS(5469),
    [anon_sym_operator] = ACTIONS(5467),
    [anon_sym_requires] = ACTIONS(5467),
    [anon_sym_precise] = ACTIONS(5467),
    [anon_sym_shared] = ACTIONS(5467),
    [anon_sym_groupshared] = ACTIONS(5467),
    [anon_sym_uniform] = ACTIONS(5467),
    [anon_sym_row_major] = ACTIONS(5467),
    [anon_sym_column_major] = ACTIONS(5467),
    [anon_sym_globallycoherent] = ACTIONS(5467),
    [anon_sym_centroid] = ACTIONS(5467),
    [anon_sym_noperspective] = ACTIONS(5467),
    [anon_sym_nointerpolation] = ACTIONS(5467),
    [anon_sym_sample] = ACTIONS(5467),
    [anon_sym_linear] = ACTIONS(5467),
    [anon_sym_snorm] = ACTIONS(5467),
    [anon_sym_unorm] = ACTIONS(5467),
    [anon_sym_point] = ACTIONS(5467),
    [anon_sym_line] = ACTIONS(5467),
    [anon_sym_triangleadj] = ACTIONS(5467),
    [anon_sym_lineadj] = ACTIONS(5467),
    [anon_sym_triangle] = ACTIONS(5467),
  },
  [2289] = {
    [sym_identifier] = ACTIONS(5487),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5489),
    [anon_sym_COMMA] = ACTIONS(5489),
    [anon_sym_RPAREN] = ACTIONS(5489),
    [anon_sym_LPAREN2] = ACTIONS(5489),
    [anon_sym_TILDE] = ACTIONS(5489),
    [anon_sym_STAR] = ACTIONS(5489),
    [anon_sym_AMP_AMP] = ACTIONS(5489),
    [anon_sym_AMP] = ACTIONS(5487),
    [anon_sym_COLON] = ACTIONS(5487),
    [anon_sym_SEMI] = ACTIONS(5489),
    [anon_sym___extension__] = ACTIONS(5487),
    [anon_sym_in] = ACTIONS(5487),
    [anon_sym_out] = ACTIONS(5487),
    [anon_sym_inout] = ACTIONS(5487),
    [anon_sym_extern] = ACTIONS(5487),
    [anon_sym___attribute__] = ACTIONS(5487),
    [anon_sym_COLON_COLON] = ACTIONS(5489),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5489),
    [anon_sym___declspec] = ACTIONS(5487),
    [anon_sym___based] = ACTIONS(5487),
    [anon_sym___cdecl] = ACTIONS(5487),
    [anon_sym___clrcall] = ACTIONS(5487),
    [anon_sym___stdcall] = ACTIONS(5487),
    [anon_sym___fastcall] = ACTIONS(5487),
    [anon_sym___thiscall] = ACTIONS(5487),
    [anon_sym___vectorcall] = ACTIONS(5487),
    [anon_sym_LBRACK] = ACTIONS(5487),
    [anon_sym_static] = ACTIONS(5487),
    [anon_sym_EQ] = ACTIONS(5489),
    [anon_sym_register] = ACTIONS(5487),
    [anon_sym_inline] = ACTIONS(5487),
    [anon_sym___inline] = ACTIONS(5487),
    [anon_sym___inline__] = ACTIONS(5487),
    [anon_sym___forceinline] = ACTIONS(5487),
    [anon_sym_thread_local] = ACTIONS(5487),
    [anon_sym___thread] = ACTIONS(5487),
    [anon_sym_const] = ACTIONS(5487),
    [anon_sym_constexpr] = ACTIONS(5487),
    [anon_sym_volatile] = ACTIONS(5487),
    [anon_sym_restrict] = ACTIONS(5487),
    [anon_sym___restrict__] = ACTIONS(5487),
    [anon_sym__Atomic] = ACTIONS(5487),
    [anon_sym__Noreturn] = ACTIONS(5487),
    [anon_sym_noreturn] = ACTIONS(5487),
    [anon_sym_mutable] = ACTIONS(5487),
    [anon_sym_constinit] = ACTIONS(5487),
    [anon_sym_consteval] = ACTIONS(5487),
    [anon_sym_alignas] = ACTIONS(5487),
    [anon_sym__Alignas] = ACTIONS(5487),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5487),
    [anon_sym_decltype] = ACTIONS(5487),
    [anon_sym_final] = ACTIONS(5487),
    [anon_sym_override] = ACTIONS(5487),
    [sym_virtual] = ACTIONS(5487),
    [anon_sym_template] = ACTIONS(5487),
    [anon_sym_GT2] = ACTIONS(5489),
    [anon_sym_operator] = ACTIONS(5487),
    [anon_sym_requires] = ACTIONS(5487),
    [anon_sym_precise] = ACTIONS(5487),
    [anon_sym_shared] = ACTIONS(5487),
    [anon_sym_groupshared] = ACTIONS(5487),
    [anon_sym_uniform] = ACTIONS(5487),
    [anon_sym_row_major] = ACTIONS(5487),
    [anon_sym_column_major] = ACTIONS(5487),
    [anon_sym_globallycoherent] = ACTIONS(5487),
    [anon_sym_centroid] = ACTIONS(5487),
    [anon_sym_noperspective] = ACTIONS(5487),
    [anon_sym_nointerpolation] = ACTIONS(5487),
    [anon_sym_sample] = ACTIONS(5487),
    [anon_sym_linear] = ACTIONS(5487),
    [anon_sym_snorm] = ACTIONS(5487),
    [anon_sym_unorm] = ACTIONS(5487),
    [anon_sym_point] = ACTIONS(5487),
    [anon_sym_line] = ACTIONS(5487),
    [anon_sym_triangleadj] = ACTIONS(5487),
    [anon_sym_lineadj] = ACTIONS(5487),
    [anon_sym_triangle] = ACTIONS(5487),
  },
  [2290] = {
    [sym_identifier] = ACTIONS(5491),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5493),
    [anon_sym_COMMA] = ACTIONS(5493),
    [anon_sym_RPAREN] = ACTIONS(5493),
    [anon_sym_LPAREN2] = ACTIONS(5493),
    [anon_sym_TILDE] = ACTIONS(5493),
    [anon_sym_STAR] = ACTIONS(5493),
    [anon_sym_AMP_AMP] = ACTIONS(5493),
    [anon_sym_AMP] = ACTIONS(5491),
    [anon_sym_COLON] = ACTIONS(5491),
    [anon_sym_SEMI] = ACTIONS(5493),
    [anon_sym___extension__] = ACTIONS(5491),
    [anon_sym_in] = ACTIONS(5491),
    [anon_sym_out] = ACTIONS(5491),
    [anon_sym_inout] = ACTIONS(5491),
    [anon_sym_extern] = ACTIONS(5491),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym_COLON_COLON] = ACTIONS(5493),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5493),
    [anon_sym___declspec] = ACTIONS(5491),
    [anon_sym___based] = ACTIONS(5491),
    [anon_sym___cdecl] = ACTIONS(5491),
    [anon_sym___clrcall] = ACTIONS(5491),
    [anon_sym___stdcall] = ACTIONS(5491),
    [anon_sym___fastcall] = ACTIONS(5491),
    [anon_sym___thiscall] = ACTIONS(5491),
    [anon_sym___vectorcall] = ACTIONS(5491),
    [anon_sym_LBRACK] = ACTIONS(5491),
    [anon_sym_static] = ACTIONS(5491),
    [anon_sym_EQ] = ACTIONS(5493),
    [anon_sym_register] = ACTIONS(5491),
    [anon_sym_inline] = ACTIONS(5491),
    [anon_sym___inline] = ACTIONS(5491),
    [anon_sym___inline__] = ACTIONS(5491),
    [anon_sym___forceinline] = ACTIONS(5491),
    [anon_sym_thread_local] = ACTIONS(5491),
    [anon_sym___thread] = ACTIONS(5491),
    [anon_sym_const] = ACTIONS(5491),
    [anon_sym_constexpr] = ACTIONS(5491),
    [anon_sym_volatile] = ACTIONS(5491),
    [anon_sym_restrict] = ACTIONS(5491),
    [anon_sym___restrict__] = ACTIONS(5491),
    [anon_sym__Atomic] = ACTIONS(5491),
    [anon_sym__Noreturn] = ACTIONS(5491),
    [anon_sym_noreturn] = ACTIONS(5491),
    [anon_sym_mutable] = ACTIONS(5491),
    [anon_sym_constinit] = ACTIONS(5491),
    [anon_sym_consteval] = ACTIONS(5491),
    [anon_sym_alignas] = ACTIONS(5491),
    [anon_sym__Alignas] = ACTIONS(5491),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5491),
    [anon_sym_decltype] = ACTIONS(5491),
    [anon_sym_final] = ACTIONS(5491),
    [anon_sym_override] = ACTIONS(5491),
    [sym_virtual] = ACTIONS(5491),
    [anon_sym_template] = ACTIONS(5491),
    [anon_sym_GT2] = ACTIONS(5493),
    [anon_sym_operator] = ACTIONS(5491),
    [anon_sym_requires] = ACTIONS(5491),
    [anon_sym_precise] = ACTIONS(5491),
    [anon_sym_shared] = ACTIONS(5491),
    [anon_sym_groupshared] = ACTIONS(5491),
    [anon_sym_uniform] = ACTIONS(5491),
    [anon_sym_row_major] = ACTIONS(5491),
    [anon_sym_column_major] = ACTIONS(5491),
    [anon_sym_globallycoherent] = ACTIONS(5491),
    [anon_sym_centroid] = ACTIONS(5491),
    [anon_sym_noperspective] = ACTIONS(5491),
    [anon_sym_nointerpolation] = ACTIONS(5491),
    [anon_sym_sample] = ACTIONS(5491),
    [anon_sym_linear] = ACTIONS(5491),
    [anon_sym_snorm] = ACTIONS(5491),
    [anon_sym_unorm] = ACTIONS(5491),
    [anon_sym_point] = ACTIONS(5491),
    [anon_sym_line] = ACTIONS(5491),
    [anon_sym_triangleadj] = ACTIONS(5491),
    [anon_sym_lineadj] = ACTIONS(5491),
    [anon_sym_triangle] = ACTIONS(5491),
  },
  [2291] = {
    [sym_identifier] = ACTIONS(5153),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5155),
    [anon_sym_COMMA] = ACTIONS(5155),
    [anon_sym_RPAREN] = ACTIONS(5155),
    [anon_sym_LPAREN2] = ACTIONS(5155),
    [anon_sym_TILDE] = ACTIONS(5155),
    [anon_sym_STAR] = ACTIONS(5155),
    [anon_sym_AMP_AMP] = ACTIONS(5155),
    [anon_sym_AMP] = ACTIONS(5153),
    [anon_sym_COLON] = ACTIONS(5153),
    [anon_sym_SEMI] = ACTIONS(5155),
    [anon_sym___extension__] = ACTIONS(5153),
    [anon_sym_in] = ACTIONS(5153),
    [anon_sym_out] = ACTIONS(5153),
    [anon_sym_inout] = ACTIONS(5153),
    [anon_sym_extern] = ACTIONS(5153),
    [anon_sym___attribute__] = ACTIONS(5153),
    [anon_sym_COLON_COLON] = ACTIONS(5155),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5155),
    [anon_sym___declspec] = ACTIONS(5153),
    [anon_sym___based] = ACTIONS(5153),
    [anon_sym___cdecl] = ACTIONS(5153),
    [anon_sym___clrcall] = ACTIONS(5153),
    [anon_sym___stdcall] = ACTIONS(5153),
    [anon_sym___fastcall] = ACTIONS(5153),
    [anon_sym___thiscall] = ACTIONS(5153),
    [anon_sym___vectorcall] = ACTIONS(5153),
    [anon_sym_LBRACE] = ACTIONS(5155),
    [anon_sym_LBRACK] = ACTIONS(5153),
    [anon_sym_static] = ACTIONS(5153),
    [anon_sym_EQ] = ACTIONS(5155),
    [anon_sym_register] = ACTIONS(5153),
    [anon_sym_inline] = ACTIONS(5153),
    [anon_sym___inline] = ACTIONS(5153),
    [anon_sym___inline__] = ACTIONS(5153),
    [anon_sym___forceinline] = ACTIONS(5153),
    [anon_sym_thread_local] = ACTIONS(5153),
    [anon_sym___thread] = ACTIONS(5153),
    [anon_sym_const] = ACTIONS(5153),
    [anon_sym_constexpr] = ACTIONS(5153),
    [anon_sym_volatile] = ACTIONS(5153),
    [anon_sym_restrict] = ACTIONS(5153),
    [anon_sym___restrict__] = ACTIONS(5153),
    [anon_sym__Atomic] = ACTIONS(5153),
    [anon_sym__Noreturn] = ACTIONS(5153),
    [anon_sym_noreturn] = ACTIONS(5153),
    [anon_sym_mutable] = ACTIONS(5153),
    [anon_sym_constinit] = ACTIONS(5153),
    [anon_sym_consteval] = ACTIONS(5153),
    [anon_sym_alignas] = ACTIONS(5153),
    [anon_sym__Alignas] = ACTIONS(5153),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(5153),
    [anon_sym_final] = ACTIONS(5153),
    [anon_sym_override] = ACTIONS(5153),
    [sym_virtual] = ACTIONS(5153),
    [anon_sym_explicit] = ACTIONS(5153),
    [anon_sym_template] = ACTIONS(5153),
    [anon_sym_GT2] = ACTIONS(5155),
    [anon_sym_operator] = ACTIONS(5153),
    [anon_sym_precise] = ACTIONS(5153),
    [anon_sym_shared] = ACTIONS(5153),
    [anon_sym_groupshared] = ACTIONS(5153),
    [anon_sym_uniform] = ACTIONS(5153),
    [anon_sym_row_major] = ACTIONS(5153),
    [anon_sym_column_major] = ACTIONS(5153),
    [anon_sym_globallycoherent] = ACTIONS(5153),
    [anon_sym_centroid] = ACTIONS(5153),
    [anon_sym_noperspective] = ACTIONS(5153),
    [anon_sym_nointerpolation] = ACTIONS(5153),
    [anon_sym_sample] = ACTIONS(5153),
    [anon_sym_linear] = ACTIONS(5153),
    [anon_sym_snorm] = ACTIONS(5153),
    [anon_sym_unorm] = ACTIONS(5153),
    [anon_sym_point] = ACTIONS(5153),
    [anon_sym_line] = ACTIONS(5153),
    [anon_sym_triangleadj] = ACTIONS(5153),
    [anon_sym_lineadj] = ACTIONS(5153),
    [anon_sym_triangle] = ACTIONS(5153),
  },
  [2292] = {
    [sym_identifier] = ACTIONS(5495),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5497),
    [anon_sym_COMMA] = ACTIONS(5497),
    [anon_sym_RPAREN] = ACTIONS(5497),
    [anon_sym_LPAREN2] = ACTIONS(5497),
    [anon_sym_TILDE] = ACTIONS(5497),
    [anon_sym_STAR] = ACTIONS(5497),
    [anon_sym_AMP_AMP] = ACTIONS(5497),
    [anon_sym_AMP] = ACTIONS(5495),
    [anon_sym_COLON] = ACTIONS(5495),
    [anon_sym_SEMI] = ACTIONS(5497),
    [anon_sym___extension__] = ACTIONS(5495),
    [anon_sym_in] = ACTIONS(5495),
    [anon_sym_out] = ACTIONS(5495),
    [anon_sym_inout] = ACTIONS(5495),
    [anon_sym_extern] = ACTIONS(5495),
    [anon_sym___attribute__] = ACTIONS(5495),
    [anon_sym_COLON_COLON] = ACTIONS(5497),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5497),
    [anon_sym___declspec] = ACTIONS(5495),
    [anon_sym___based] = ACTIONS(5495),
    [anon_sym___cdecl] = ACTIONS(5495),
    [anon_sym___clrcall] = ACTIONS(5495),
    [anon_sym___stdcall] = ACTIONS(5495),
    [anon_sym___fastcall] = ACTIONS(5495),
    [anon_sym___thiscall] = ACTIONS(5495),
    [anon_sym___vectorcall] = ACTIONS(5495),
    [anon_sym_LBRACK] = ACTIONS(5495),
    [anon_sym_static] = ACTIONS(5495),
    [anon_sym_EQ] = ACTIONS(5497),
    [anon_sym_register] = ACTIONS(5495),
    [anon_sym_inline] = ACTIONS(5495),
    [anon_sym___inline] = ACTIONS(5495),
    [anon_sym___inline__] = ACTIONS(5495),
    [anon_sym___forceinline] = ACTIONS(5495),
    [anon_sym_thread_local] = ACTIONS(5495),
    [anon_sym___thread] = ACTIONS(5495),
    [anon_sym_const] = ACTIONS(5495),
    [anon_sym_constexpr] = ACTIONS(5495),
    [anon_sym_volatile] = ACTIONS(5495),
    [anon_sym_restrict] = ACTIONS(5495),
    [anon_sym___restrict__] = ACTIONS(5495),
    [anon_sym__Atomic] = ACTIONS(5495),
    [anon_sym__Noreturn] = ACTIONS(5495),
    [anon_sym_noreturn] = ACTIONS(5495),
    [anon_sym_mutable] = ACTIONS(5495),
    [anon_sym_constinit] = ACTIONS(5495),
    [anon_sym_consteval] = ACTIONS(5495),
    [anon_sym_alignas] = ACTIONS(5495),
    [anon_sym__Alignas] = ACTIONS(5495),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5495),
    [anon_sym_decltype] = ACTIONS(5495),
    [anon_sym_final] = ACTIONS(5495),
    [anon_sym_override] = ACTIONS(5495),
    [sym_virtual] = ACTIONS(5495),
    [anon_sym_template] = ACTIONS(5495),
    [anon_sym_GT2] = ACTIONS(5497),
    [anon_sym_operator] = ACTIONS(5495),
    [anon_sym_requires] = ACTIONS(5495),
    [anon_sym_precise] = ACTIONS(5495),
    [anon_sym_shared] = ACTIONS(5495),
    [anon_sym_groupshared] = ACTIONS(5495),
    [anon_sym_uniform] = ACTIONS(5495),
    [anon_sym_row_major] = ACTIONS(5495),
    [anon_sym_column_major] = ACTIONS(5495),
    [anon_sym_globallycoherent] = ACTIONS(5495),
    [anon_sym_centroid] = ACTIONS(5495),
    [anon_sym_noperspective] = ACTIONS(5495),
    [anon_sym_nointerpolation] = ACTIONS(5495),
    [anon_sym_sample] = ACTIONS(5495),
    [anon_sym_linear] = ACTIONS(5495),
    [anon_sym_snorm] = ACTIONS(5495),
    [anon_sym_unorm] = ACTIONS(5495),
    [anon_sym_point] = ACTIONS(5495),
    [anon_sym_line] = ACTIONS(5495),
    [anon_sym_triangleadj] = ACTIONS(5495),
    [anon_sym_lineadj] = ACTIONS(5495),
    [anon_sym_triangle] = ACTIONS(5495),
  },
  [2293] = {
    [sym_identifier] = ACTIONS(5499),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5501),
    [anon_sym_COMMA] = ACTIONS(5501),
    [anon_sym_RPAREN] = ACTIONS(5501),
    [anon_sym_LPAREN2] = ACTIONS(5501),
    [anon_sym_TILDE] = ACTIONS(5501),
    [anon_sym_STAR] = ACTIONS(5501),
    [anon_sym_AMP_AMP] = ACTIONS(5501),
    [anon_sym_AMP] = ACTIONS(5499),
    [anon_sym_COLON] = ACTIONS(5499),
    [anon_sym_SEMI] = ACTIONS(5501),
    [anon_sym___extension__] = ACTIONS(5499),
    [anon_sym_in] = ACTIONS(5499),
    [anon_sym_out] = ACTIONS(5499),
    [anon_sym_inout] = ACTIONS(5499),
    [anon_sym_extern] = ACTIONS(5499),
    [anon_sym___attribute__] = ACTIONS(5499),
    [anon_sym_COLON_COLON] = ACTIONS(5501),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5501),
    [anon_sym___declspec] = ACTIONS(5499),
    [anon_sym___based] = ACTIONS(5499),
    [anon_sym___cdecl] = ACTIONS(5499),
    [anon_sym___clrcall] = ACTIONS(5499),
    [anon_sym___stdcall] = ACTIONS(5499),
    [anon_sym___fastcall] = ACTIONS(5499),
    [anon_sym___thiscall] = ACTIONS(5499),
    [anon_sym___vectorcall] = ACTIONS(5499),
    [anon_sym_LBRACK] = ACTIONS(5499),
    [anon_sym_static] = ACTIONS(5499),
    [anon_sym_EQ] = ACTIONS(5501),
    [anon_sym_register] = ACTIONS(5499),
    [anon_sym_inline] = ACTIONS(5499),
    [anon_sym___inline] = ACTIONS(5499),
    [anon_sym___inline__] = ACTIONS(5499),
    [anon_sym___forceinline] = ACTIONS(5499),
    [anon_sym_thread_local] = ACTIONS(5499),
    [anon_sym___thread] = ACTIONS(5499),
    [anon_sym_const] = ACTIONS(5499),
    [anon_sym_constexpr] = ACTIONS(5499),
    [anon_sym_volatile] = ACTIONS(5499),
    [anon_sym_restrict] = ACTIONS(5499),
    [anon_sym___restrict__] = ACTIONS(5499),
    [anon_sym__Atomic] = ACTIONS(5499),
    [anon_sym__Noreturn] = ACTIONS(5499),
    [anon_sym_noreturn] = ACTIONS(5499),
    [anon_sym_mutable] = ACTIONS(5499),
    [anon_sym_constinit] = ACTIONS(5499),
    [anon_sym_consteval] = ACTIONS(5499),
    [anon_sym_alignas] = ACTIONS(5499),
    [anon_sym__Alignas] = ACTIONS(5499),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5499),
    [anon_sym_decltype] = ACTIONS(5499),
    [anon_sym_final] = ACTIONS(5499),
    [anon_sym_override] = ACTIONS(5499),
    [sym_virtual] = ACTIONS(5499),
    [anon_sym_template] = ACTIONS(5499),
    [anon_sym_GT2] = ACTIONS(5501),
    [anon_sym_operator] = ACTIONS(5499),
    [anon_sym_requires] = ACTIONS(5499),
    [anon_sym_precise] = ACTIONS(5499),
    [anon_sym_shared] = ACTIONS(5499),
    [anon_sym_groupshared] = ACTIONS(5499),
    [anon_sym_uniform] = ACTIONS(5499),
    [anon_sym_row_major] = ACTIONS(5499),
    [anon_sym_column_major] = ACTIONS(5499),
    [anon_sym_globallycoherent] = ACTIONS(5499),
    [anon_sym_centroid] = ACTIONS(5499),
    [anon_sym_noperspective] = ACTIONS(5499),
    [anon_sym_nointerpolation] = ACTIONS(5499),
    [anon_sym_sample] = ACTIONS(5499),
    [anon_sym_linear] = ACTIONS(5499),
    [anon_sym_snorm] = ACTIONS(5499),
    [anon_sym_unorm] = ACTIONS(5499),
    [anon_sym_point] = ACTIONS(5499),
    [anon_sym_line] = ACTIONS(5499),
    [anon_sym_triangleadj] = ACTIONS(5499),
    [anon_sym_lineadj] = ACTIONS(5499),
    [anon_sym_triangle] = ACTIONS(5499),
  },
  [2294] = {
    [sym_identifier] = ACTIONS(5467),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5469),
    [anon_sym_COMMA] = ACTIONS(5469),
    [anon_sym_RPAREN] = ACTIONS(5469),
    [anon_sym_LPAREN2] = ACTIONS(5469),
    [anon_sym_TILDE] = ACTIONS(5469),
    [anon_sym_STAR] = ACTIONS(5469),
    [anon_sym_AMP_AMP] = ACTIONS(5469),
    [anon_sym_AMP] = ACTIONS(5467),
    [anon_sym_COLON] = ACTIONS(5467),
    [anon_sym_SEMI] = ACTIONS(5469),
    [anon_sym___extension__] = ACTIONS(5467),
    [anon_sym_in] = ACTIONS(5467),
    [anon_sym_out] = ACTIONS(5467),
    [anon_sym_inout] = ACTIONS(5467),
    [anon_sym_extern] = ACTIONS(5467),
    [anon_sym___attribute__] = ACTIONS(5467),
    [anon_sym_COLON_COLON] = ACTIONS(5469),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5469),
    [anon_sym___declspec] = ACTIONS(5467),
    [anon_sym___based] = ACTIONS(5467),
    [anon_sym___cdecl] = ACTIONS(5467),
    [anon_sym___clrcall] = ACTIONS(5467),
    [anon_sym___stdcall] = ACTIONS(5467),
    [anon_sym___fastcall] = ACTIONS(5467),
    [anon_sym___thiscall] = ACTIONS(5467),
    [anon_sym___vectorcall] = ACTIONS(5467),
    [anon_sym_LBRACK] = ACTIONS(5467),
    [anon_sym_static] = ACTIONS(5467),
    [anon_sym_EQ] = ACTIONS(5469),
    [anon_sym_register] = ACTIONS(5467),
    [anon_sym_inline] = ACTIONS(5467),
    [anon_sym___inline] = ACTIONS(5467),
    [anon_sym___inline__] = ACTIONS(5467),
    [anon_sym___forceinline] = ACTIONS(5467),
    [anon_sym_thread_local] = ACTIONS(5467),
    [anon_sym___thread] = ACTIONS(5467),
    [anon_sym_const] = ACTIONS(5467),
    [anon_sym_constexpr] = ACTIONS(5467),
    [anon_sym_volatile] = ACTIONS(5467),
    [anon_sym_restrict] = ACTIONS(5467),
    [anon_sym___restrict__] = ACTIONS(5467),
    [anon_sym__Atomic] = ACTIONS(5467),
    [anon_sym__Noreturn] = ACTIONS(5467),
    [anon_sym_noreturn] = ACTIONS(5467),
    [anon_sym_mutable] = ACTIONS(5467),
    [anon_sym_constinit] = ACTIONS(5467),
    [anon_sym_consteval] = ACTIONS(5467),
    [anon_sym_alignas] = ACTIONS(5467),
    [anon_sym__Alignas] = ACTIONS(5467),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5467),
    [anon_sym_decltype] = ACTIONS(5467),
    [anon_sym_final] = ACTIONS(5467),
    [anon_sym_override] = ACTIONS(5467),
    [sym_virtual] = ACTIONS(5467),
    [anon_sym_template] = ACTIONS(5467),
    [anon_sym_GT2] = ACTIONS(5469),
    [anon_sym_operator] = ACTIONS(5467),
    [anon_sym_requires] = ACTIONS(5467),
    [anon_sym_precise] = ACTIONS(5467),
    [anon_sym_shared] = ACTIONS(5467),
    [anon_sym_groupshared] = ACTIONS(5467),
    [anon_sym_uniform] = ACTIONS(5467),
    [anon_sym_row_major] = ACTIONS(5467),
    [anon_sym_column_major] = ACTIONS(5467),
    [anon_sym_globallycoherent] = ACTIONS(5467),
    [anon_sym_centroid] = ACTIONS(5467),
    [anon_sym_noperspective] = ACTIONS(5467),
    [anon_sym_nointerpolation] = ACTIONS(5467),
    [anon_sym_sample] = ACTIONS(5467),
    [anon_sym_linear] = ACTIONS(5467),
    [anon_sym_snorm] = ACTIONS(5467),
    [anon_sym_unorm] = ACTIONS(5467),
    [anon_sym_point] = ACTIONS(5467),
    [anon_sym_line] = ACTIONS(5467),
    [anon_sym_triangleadj] = ACTIONS(5467),
    [anon_sym_lineadj] = ACTIONS(5467),
    [anon_sym_triangle] = ACTIONS(5467),
  },
  [2295] = {
    [sym_identifier] = ACTIONS(5503),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5505),
    [anon_sym_COMMA] = ACTIONS(5505),
    [anon_sym_RPAREN] = ACTIONS(5505),
    [anon_sym_LPAREN2] = ACTIONS(5505),
    [anon_sym_TILDE] = ACTIONS(5505),
    [anon_sym_STAR] = ACTIONS(5505),
    [anon_sym_AMP_AMP] = ACTIONS(5505),
    [anon_sym_AMP] = ACTIONS(5503),
    [anon_sym_COLON] = ACTIONS(5503),
    [anon_sym_SEMI] = ACTIONS(5505),
    [anon_sym___extension__] = ACTIONS(5503),
    [anon_sym_in] = ACTIONS(5503),
    [anon_sym_out] = ACTIONS(5503),
    [anon_sym_inout] = ACTIONS(5503),
    [anon_sym_extern] = ACTIONS(5503),
    [anon_sym___attribute__] = ACTIONS(5503),
    [anon_sym_COLON_COLON] = ACTIONS(5505),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5505),
    [anon_sym___declspec] = ACTIONS(5503),
    [anon_sym___based] = ACTIONS(5503),
    [anon_sym___cdecl] = ACTIONS(5503),
    [anon_sym___clrcall] = ACTIONS(5503),
    [anon_sym___stdcall] = ACTIONS(5503),
    [anon_sym___fastcall] = ACTIONS(5503),
    [anon_sym___thiscall] = ACTIONS(5503),
    [anon_sym___vectorcall] = ACTIONS(5503),
    [anon_sym_LBRACK] = ACTIONS(5503),
    [anon_sym_static] = ACTIONS(5503),
    [anon_sym_EQ] = ACTIONS(5505),
    [anon_sym_register] = ACTIONS(5503),
    [anon_sym_inline] = ACTIONS(5503),
    [anon_sym___inline] = ACTIONS(5503),
    [anon_sym___inline__] = ACTIONS(5503),
    [anon_sym___forceinline] = ACTIONS(5503),
    [anon_sym_thread_local] = ACTIONS(5503),
    [anon_sym___thread] = ACTIONS(5503),
    [anon_sym_const] = ACTIONS(5503),
    [anon_sym_constexpr] = ACTIONS(5503),
    [anon_sym_volatile] = ACTIONS(5503),
    [anon_sym_restrict] = ACTIONS(5503),
    [anon_sym___restrict__] = ACTIONS(5503),
    [anon_sym__Atomic] = ACTIONS(5503),
    [anon_sym__Noreturn] = ACTIONS(5503),
    [anon_sym_noreturn] = ACTIONS(5503),
    [anon_sym_mutable] = ACTIONS(5503),
    [anon_sym_constinit] = ACTIONS(5503),
    [anon_sym_consteval] = ACTIONS(5503),
    [anon_sym_alignas] = ACTIONS(5503),
    [anon_sym__Alignas] = ACTIONS(5503),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5503),
    [anon_sym_decltype] = ACTIONS(5503),
    [anon_sym_final] = ACTIONS(5503),
    [anon_sym_override] = ACTIONS(5503),
    [sym_virtual] = ACTIONS(5503),
    [anon_sym_template] = ACTIONS(5503),
    [anon_sym_GT2] = ACTIONS(5505),
    [anon_sym_operator] = ACTIONS(5503),
    [anon_sym_requires] = ACTIONS(5503),
    [anon_sym_precise] = ACTIONS(5503),
    [anon_sym_shared] = ACTIONS(5503),
    [anon_sym_groupshared] = ACTIONS(5503),
    [anon_sym_uniform] = ACTIONS(5503),
    [anon_sym_row_major] = ACTIONS(5503),
    [anon_sym_column_major] = ACTIONS(5503),
    [anon_sym_globallycoherent] = ACTIONS(5503),
    [anon_sym_centroid] = ACTIONS(5503),
    [anon_sym_noperspective] = ACTIONS(5503),
    [anon_sym_nointerpolation] = ACTIONS(5503),
    [anon_sym_sample] = ACTIONS(5503),
    [anon_sym_linear] = ACTIONS(5503),
    [anon_sym_snorm] = ACTIONS(5503),
    [anon_sym_unorm] = ACTIONS(5503),
    [anon_sym_point] = ACTIONS(5503),
    [anon_sym_line] = ACTIONS(5503),
    [anon_sym_triangleadj] = ACTIONS(5503),
    [anon_sym_lineadj] = ACTIONS(5503),
    [anon_sym_triangle] = ACTIONS(5503),
  },
  [2296] = {
    [sym_identifier] = ACTIONS(5507),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5509),
    [anon_sym_COMMA] = ACTIONS(5509),
    [anon_sym_RPAREN] = ACTIONS(5509),
    [anon_sym_LPAREN2] = ACTIONS(5509),
    [anon_sym_TILDE] = ACTIONS(5509),
    [anon_sym_STAR] = ACTIONS(5509),
    [anon_sym_AMP_AMP] = ACTIONS(5509),
    [anon_sym_AMP] = ACTIONS(5507),
    [anon_sym_COLON] = ACTIONS(5507),
    [anon_sym_SEMI] = ACTIONS(5509),
    [anon_sym___extension__] = ACTIONS(5507),
    [anon_sym_in] = ACTIONS(5507),
    [anon_sym_out] = ACTIONS(5507),
    [anon_sym_inout] = ACTIONS(5507),
    [anon_sym_extern] = ACTIONS(5507),
    [anon_sym___attribute__] = ACTIONS(5507),
    [anon_sym_COLON_COLON] = ACTIONS(5509),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5509),
    [anon_sym___declspec] = ACTIONS(5507),
    [anon_sym___based] = ACTIONS(5507),
    [anon_sym___cdecl] = ACTIONS(5507),
    [anon_sym___clrcall] = ACTIONS(5507),
    [anon_sym___stdcall] = ACTIONS(5507),
    [anon_sym___fastcall] = ACTIONS(5507),
    [anon_sym___thiscall] = ACTIONS(5507),
    [anon_sym___vectorcall] = ACTIONS(5507),
    [anon_sym_LBRACK] = ACTIONS(5507),
    [anon_sym_static] = ACTIONS(5507),
    [anon_sym_EQ] = ACTIONS(5509),
    [anon_sym_register] = ACTIONS(5507),
    [anon_sym_inline] = ACTIONS(5507),
    [anon_sym___inline] = ACTIONS(5507),
    [anon_sym___inline__] = ACTIONS(5507),
    [anon_sym___forceinline] = ACTIONS(5507),
    [anon_sym_thread_local] = ACTIONS(5507),
    [anon_sym___thread] = ACTIONS(5507),
    [anon_sym_const] = ACTIONS(5507),
    [anon_sym_constexpr] = ACTIONS(5507),
    [anon_sym_volatile] = ACTIONS(5507),
    [anon_sym_restrict] = ACTIONS(5507),
    [anon_sym___restrict__] = ACTIONS(5507),
    [anon_sym__Atomic] = ACTIONS(5507),
    [anon_sym__Noreturn] = ACTIONS(5507),
    [anon_sym_noreturn] = ACTIONS(5507),
    [anon_sym_mutable] = ACTIONS(5507),
    [anon_sym_constinit] = ACTIONS(5507),
    [anon_sym_consteval] = ACTIONS(5507),
    [anon_sym_alignas] = ACTIONS(5507),
    [anon_sym__Alignas] = ACTIONS(5507),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5507),
    [anon_sym_decltype] = ACTIONS(5507),
    [anon_sym_final] = ACTIONS(5507),
    [anon_sym_override] = ACTIONS(5507),
    [sym_virtual] = ACTIONS(5507),
    [anon_sym_template] = ACTIONS(5507),
    [anon_sym_GT2] = ACTIONS(5509),
    [anon_sym_operator] = ACTIONS(5507),
    [anon_sym_requires] = ACTIONS(5507),
    [anon_sym_precise] = ACTIONS(5507),
    [anon_sym_shared] = ACTIONS(5507),
    [anon_sym_groupshared] = ACTIONS(5507),
    [anon_sym_uniform] = ACTIONS(5507),
    [anon_sym_row_major] = ACTIONS(5507),
    [anon_sym_column_major] = ACTIONS(5507),
    [anon_sym_globallycoherent] = ACTIONS(5507),
    [anon_sym_centroid] = ACTIONS(5507),
    [anon_sym_noperspective] = ACTIONS(5507),
    [anon_sym_nointerpolation] = ACTIONS(5507),
    [anon_sym_sample] = ACTIONS(5507),
    [anon_sym_linear] = ACTIONS(5507),
    [anon_sym_snorm] = ACTIONS(5507),
    [anon_sym_unorm] = ACTIONS(5507),
    [anon_sym_point] = ACTIONS(5507),
    [anon_sym_line] = ACTIONS(5507),
    [anon_sym_triangleadj] = ACTIONS(5507),
    [anon_sym_lineadj] = ACTIONS(5507),
    [anon_sym_triangle] = ACTIONS(5507),
  },
  [2297] = {
    [sym_identifier] = ACTIONS(5511),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5513),
    [anon_sym_COMMA] = ACTIONS(5513),
    [anon_sym_RPAREN] = ACTIONS(5513),
    [anon_sym_LPAREN2] = ACTIONS(5513),
    [anon_sym_TILDE] = ACTIONS(5513),
    [anon_sym_STAR] = ACTIONS(5513),
    [anon_sym_AMP_AMP] = ACTIONS(5513),
    [anon_sym_AMP] = ACTIONS(5511),
    [anon_sym_COLON] = ACTIONS(5511),
    [anon_sym_SEMI] = ACTIONS(5513),
    [anon_sym___extension__] = ACTIONS(5511),
    [anon_sym_in] = ACTIONS(5511),
    [anon_sym_out] = ACTIONS(5511),
    [anon_sym_inout] = ACTIONS(5511),
    [anon_sym_extern] = ACTIONS(5511),
    [anon_sym___attribute__] = ACTIONS(5511),
    [anon_sym_COLON_COLON] = ACTIONS(5513),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5513),
    [anon_sym___declspec] = ACTIONS(5511),
    [anon_sym___based] = ACTIONS(5511),
    [anon_sym___cdecl] = ACTIONS(5511),
    [anon_sym___clrcall] = ACTIONS(5511),
    [anon_sym___stdcall] = ACTIONS(5511),
    [anon_sym___fastcall] = ACTIONS(5511),
    [anon_sym___thiscall] = ACTIONS(5511),
    [anon_sym___vectorcall] = ACTIONS(5511),
    [anon_sym_LBRACK] = ACTIONS(5511),
    [anon_sym_static] = ACTIONS(5511),
    [anon_sym_EQ] = ACTIONS(5513),
    [anon_sym_register] = ACTIONS(5511),
    [anon_sym_inline] = ACTIONS(5511),
    [anon_sym___inline] = ACTIONS(5511),
    [anon_sym___inline__] = ACTIONS(5511),
    [anon_sym___forceinline] = ACTIONS(5511),
    [anon_sym_thread_local] = ACTIONS(5511),
    [anon_sym___thread] = ACTIONS(5511),
    [anon_sym_const] = ACTIONS(5511),
    [anon_sym_constexpr] = ACTIONS(5511),
    [anon_sym_volatile] = ACTIONS(5511),
    [anon_sym_restrict] = ACTIONS(5511),
    [anon_sym___restrict__] = ACTIONS(5511),
    [anon_sym__Atomic] = ACTIONS(5511),
    [anon_sym__Noreturn] = ACTIONS(5511),
    [anon_sym_noreturn] = ACTIONS(5511),
    [anon_sym_mutable] = ACTIONS(5511),
    [anon_sym_constinit] = ACTIONS(5511),
    [anon_sym_consteval] = ACTIONS(5511),
    [anon_sym_alignas] = ACTIONS(5511),
    [anon_sym__Alignas] = ACTIONS(5511),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5511),
    [anon_sym_decltype] = ACTIONS(5511),
    [anon_sym_final] = ACTIONS(5511),
    [anon_sym_override] = ACTIONS(5511),
    [sym_virtual] = ACTIONS(5511),
    [anon_sym_template] = ACTIONS(5511),
    [anon_sym_GT2] = ACTIONS(5513),
    [anon_sym_operator] = ACTIONS(5511),
    [anon_sym_requires] = ACTIONS(5511),
    [anon_sym_precise] = ACTIONS(5511),
    [anon_sym_shared] = ACTIONS(5511),
    [anon_sym_groupshared] = ACTIONS(5511),
    [anon_sym_uniform] = ACTIONS(5511),
    [anon_sym_row_major] = ACTIONS(5511),
    [anon_sym_column_major] = ACTIONS(5511),
    [anon_sym_globallycoherent] = ACTIONS(5511),
    [anon_sym_centroid] = ACTIONS(5511),
    [anon_sym_noperspective] = ACTIONS(5511),
    [anon_sym_nointerpolation] = ACTIONS(5511),
    [anon_sym_sample] = ACTIONS(5511),
    [anon_sym_linear] = ACTIONS(5511),
    [anon_sym_snorm] = ACTIONS(5511),
    [anon_sym_unorm] = ACTIONS(5511),
    [anon_sym_point] = ACTIONS(5511),
    [anon_sym_line] = ACTIONS(5511),
    [anon_sym_triangleadj] = ACTIONS(5511),
    [anon_sym_lineadj] = ACTIONS(5511),
    [anon_sym_triangle] = ACTIONS(5511),
  },
  [2298] = {
    [sym_identifier] = ACTIONS(5515),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5517),
    [anon_sym_COMMA] = ACTIONS(5517),
    [anon_sym_RPAREN] = ACTIONS(5517),
    [anon_sym_LPAREN2] = ACTIONS(5517),
    [anon_sym_TILDE] = ACTIONS(5517),
    [anon_sym_STAR] = ACTIONS(5517),
    [anon_sym_AMP_AMP] = ACTIONS(5517),
    [anon_sym_AMP] = ACTIONS(5515),
    [anon_sym_COLON] = ACTIONS(5515),
    [anon_sym_SEMI] = ACTIONS(5517),
    [anon_sym___extension__] = ACTIONS(5515),
    [anon_sym_in] = ACTIONS(5515),
    [anon_sym_out] = ACTIONS(5515),
    [anon_sym_inout] = ACTIONS(5515),
    [anon_sym_extern] = ACTIONS(5515),
    [anon_sym___attribute__] = ACTIONS(5515),
    [anon_sym_COLON_COLON] = ACTIONS(5517),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5517),
    [anon_sym___declspec] = ACTIONS(5515),
    [anon_sym___based] = ACTIONS(5515),
    [anon_sym___cdecl] = ACTIONS(5515),
    [anon_sym___clrcall] = ACTIONS(5515),
    [anon_sym___stdcall] = ACTIONS(5515),
    [anon_sym___fastcall] = ACTIONS(5515),
    [anon_sym___thiscall] = ACTIONS(5515),
    [anon_sym___vectorcall] = ACTIONS(5515),
    [anon_sym_LBRACK] = ACTIONS(5515),
    [anon_sym_static] = ACTIONS(5515),
    [anon_sym_EQ] = ACTIONS(5517),
    [anon_sym_register] = ACTIONS(5515),
    [anon_sym_inline] = ACTIONS(5515),
    [anon_sym___inline] = ACTIONS(5515),
    [anon_sym___inline__] = ACTIONS(5515),
    [anon_sym___forceinline] = ACTIONS(5515),
    [anon_sym_thread_local] = ACTIONS(5515),
    [anon_sym___thread] = ACTIONS(5515),
    [anon_sym_const] = ACTIONS(5515),
    [anon_sym_constexpr] = ACTIONS(5515),
    [anon_sym_volatile] = ACTIONS(5515),
    [anon_sym_restrict] = ACTIONS(5515),
    [anon_sym___restrict__] = ACTIONS(5515),
    [anon_sym__Atomic] = ACTIONS(5515),
    [anon_sym__Noreturn] = ACTIONS(5515),
    [anon_sym_noreturn] = ACTIONS(5515),
    [anon_sym_mutable] = ACTIONS(5515),
    [anon_sym_constinit] = ACTIONS(5515),
    [anon_sym_consteval] = ACTIONS(5515),
    [anon_sym_alignas] = ACTIONS(5515),
    [anon_sym__Alignas] = ACTIONS(5515),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5515),
    [anon_sym_decltype] = ACTIONS(5515),
    [anon_sym_final] = ACTIONS(5515),
    [anon_sym_override] = ACTIONS(5515),
    [sym_virtual] = ACTIONS(5515),
    [anon_sym_template] = ACTIONS(5515),
    [anon_sym_GT2] = ACTIONS(5517),
    [anon_sym_operator] = ACTIONS(5515),
    [anon_sym_requires] = ACTIONS(5515),
    [anon_sym_precise] = ACTIONS(5515),
    [anon_sym_shared] = ACTIONS(5515),
    [anon_sym_groupshared] = ACTIONS(5515),
    [anon_sym_uniform] = ACTIONS(5515),
    [anon_sym_row_major] = ACTIONS(5515),
    [anon_sym_column_major] = ACTIONS(5515),
    [anon_sym_globallycoherent] = ACTIONS(5515),
    [anon_sym_centroid] = ACTIONS(5515),
    [anon_sym_noperspective] = ACTIONS(5515),
    [anon_sym_nointerpolation] = ACTIONS(5515),
    [anon_sym_sample] = ACTIONS(5515),
    [anon_sym_linear] = ACTIONS(5515),
    [anon_sym_snorm] = ACTIONS(5515),
    [anon_sym_unorm] = ACTIONS(5515),
    [anon_sym_point] = ACTIONS(5515),
    [anon_sym_line] = ACTIONS(5515),
    [anon_sym_triangleadj] = ACTIONS(5515),
    [anon_sym_lineadj] = ACTIONS(5515),
    [anon_sym_triangle] = ACTIONS(5515),
  },
  [2299] = {
    [sym_attribute_specifier] = STATE(2276),
    [sym_enumerator_list] = STATE(2319),
    [sym_identifier] = ACTIONS(5519),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5521),
    [anon_sym_COMMA] = ACTIONS(5521),
    [anon_sym_RPAREN] = ACTIONS(5521),
    [anon_sym_LPAREN2] = ACTIONS(5521),
    [anon_sym_TILDE] = ACTIONS(5521),
    [anon_sym_STAR] = ACTIONS(5521),
    [anon_sym_AMP_AMP] = ACTIONS(5521),
    [anon_sym_AMP] = ACTIONS(5519),
    [anon_sym_COLON] = ACTIONS(5519),
    [anon_sym_SEMI] = ACTIONS(5521),
    [anon_sym___extension__] = ACTIONS(5519),
    [anon_sym_in] = ACTIONS(5519),
    [anon_sym_out] = ACTIONS(5519),
    [anon_sym_inout] = ACTIONS(5519),
    [anon_sym_extern] = ACTIONS(5519),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5521),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5521),
    [anon_sym___declspec] = ACTIONS(5519),
    [anon_sym___based] = ACTIONS(5519),
    [anon_sym___cdecl] = ACTIONS(5519),
    [anon_sym___clrcall] = ACTIONS(5519),
    [anon_sym___stdcall] = ACTIONS(5519),
    [anon_sym___fastcall] = ACTIONS(5519),
    [anon_sym___thiscall] = ACTIONS(5519),
    [anon_sym___vectorcall] = ACTIONS(5519),
    [anon_sym_LBRACE] = ACTIONS(5523),
    [anon_sym_LBRACK] = ACTIONS(5519),
    [anon_sym_static] = ACTIONS(5519),
    [anon_sym_EQ] = ACTIONS(5521),
    [anon_sym_register] = ACTIONS(5519),
    [anon_sym_inline] = ACTIONS(5519),
    [anon_sym___inline] = ACTIONS(5519),
    [anon_sym___inline__] = ACTIONS(5519),
    [anon_sym___forceinline] = ACTIONS(5519),
    [anon_sym_thread_local] = ACTIONS(5519),
    [anon_sym___thread] = ACTIONS(5519),
    [anon_sym_const] = ACTIONS(5519),
    [anon_sym_constexpr] = ACTIONS(5519),
    [anon_sym_volatile] = ACTIONS(5519),
    [anon_sym_restrict] = ACTIONS(5519),
    [anon_sym___restrict__] = ACTIONS(5519),
    [anon_sym__Atomic] = ACTIONS(5519),
    [anon_sym__Noreturn] = ACTIONS(5519),
    [anon_sym_noreturn] = ACTIONS(5519),
    [anon_sym_mutable] = ACTIONS(5519),
    [anon_sym_constinit] = ACTIONS(5519),
    [anon_sym_consteval] = ACTIONS(5519),
    [anon_sym_alignas] = ACTIONS(5519),
    [anon_sym__Alignas] = ACTIONS(5519),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5519),
    [anon_sym_decltype] = ACTIONS(5519),
    [sym_virtual] = ACTIONS(5519),
    [anon_sym_template] = ACTIONS(5519),
    [anon_sym_GT2] = ACTIONS(5521),
    [anon_sym_operator] = ACTIONS(5519),
    [anon_sym_precise] = ACTIONS(5519),
    [anon_sym_shared] = ACTIONS(5519),
    [anon_sym_groupshared] = ACTIONS(5519),
    [anon_sym_uniform] = ACTIONS(5519),
    [anon_sym_row_major] = ACTIONS(5519),
    [anon_sym_column_major] = ACTIONS(5519),
    [anon_sym_globallycoherent] = ACTIONS(5519),
    [anon_sym_centroid] = ACTIONS(5519),
    [anon_sym_noperspective] = ACTIONS(5519),
    [anon_sym_nointerpolation] = ACTIONS(5519),
    [anon_sym_sample] = ACTIONS(5519),
    [anon_sym_linear] = ACTIONS(5519),
    [anon_sym_snorm] = ACTIONS(5519),
    [anon_sym_unorm] = ACTIONS(5519),
    [anon_sym_point] = ACTIONS(5519),
    [anon_sym_line] = ACTIONS(5519),
    [anon_sym_triangleadj] = ACTIONS(5519),
    [anon_sym_lineadj] = ACTIONS(5519),
    [anon_sym_triangle] = ACTIONS(5519),
  },
  [2300] = {
    [sym_identifier] = ACTIONS(5525),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5527),
    [anon_sym_COMMA] = ACTIONS(5527),
    [anon_sym_RPAREN] = ACTIONS(5527),
    [anon_sym_LPAREN2] = ACTIONS(5527),
    [anon_sym_TILDE] = ACTIONS(5527),
    [anon_sym_STAR] = ACTIONS(5527),
    [anon_sym_AMP_AMP] = ACTIONS(5527),
    [anon_sym_AMP] = ACTIONS(5525),
    [anon_sym_COLON] = ACTIONS(5525),
    [anon_sym_SEMI] = ACTIONS(5527),
    [anon_sym___extension__] = ACTIONS(5525),
    [anon_sym_in] = ACTIONS(5525),
    [anon_sym_out] = ACTIONS(5525),
    [anon_sym_inout] = ACTIONS(5525),
    [anon_sym_extern] = ACTIONS(5525),
    [anon_sym___attribute__] = ACTIONS(5525),
    [anon_sym_COLON_COLON] = ACTIONS(5527),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5527),
    [anon_sym___declspec] = ACTIONS(5525),
    [anon_sym___based] = ACTIONS(5525),
    [anon_sym___cdecl] = ACTIONS(5525),
    [anon_sym___clrcall] = ACTIONS(5525),
    [anon_sym___stdcall] = ACTIONS(5525),
    [anon_sym___fastcall] = ACTIONS(5525),
    [anon_sym___thiscall] = ACTIONS(5525),
    [anon_sym___vectorcall] = ACTIONS(5525),
    [anon_sym_LBRACK] = ACTIONS(5525),
    [anon_sym_static] = ACTIONS(5525),
    [anon_sym_EQ] = ACTIONS(5527),
    [anon_sym_register] = ACTIONS(5525),
    [anon_sym_inline] = ACTIONS(5525),
    [anon_sym___inline] = ACTIONS(5525),
    [anon_sym___inline__] = ACTIONS(5525),
    [anon_sym___forceinline] = ACTIONS(5525),
    [anon_sym_thread_local] = ACTIONS(5525),
    [anon_sym___thread] = ACTIONS(5525),
    [anon_sym_const] = ACTIONS(5525),
    [anon_sym_constexpr] = ACTIONS(5525),
    [anon_sym_volatile] = ACTIONS(5525),
    [anon_sym_restrict] = ACTIONS(5525),
    [anon_sym___restrict__] = ACTIONS(5525),
    [anon_sym__Atomic] = ACTIONS(5525),
    [anon_sym__Noreturn] = ACTIONS(5525),
    [anon_sym_noreturn] = ACTIONS(5525),
    [anon_sym_mutable] = ACTIONS(5525),
    [anon_sym_constinit] = ACTIONS(5525),
    [anon_sym_consteval] = ACTIONS(5525),
    [anon_sym_alignas] = ACTIONS(5525),
    [anon_sym__Alignas] = ACTIONS(5525),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5525),
    [anon_sym_decltype] = ACTIONS(5525),
    [anon_sym_final] = ACTIONS(5525),
    [anon_sym_override] = ACTIONS(5525),
    [sym_virtual] = ACTIONS(5525),
    [anon_sym_template] = ACTIONS(5525),
    [anon_sym_GT2] = ACTIONS(5527),
    [anon_sym_operator] = ACTIONS(5525),
    [anon_sym_requires] = ACTIONS(5525),
    [anon_sym_precise] = ACTIONS(5525),
    [anon_sym_shared] = ACTIONS(5525),
    [anon_sym_groupshared] = ACTIONS(5525),
    [anon_sym_uniform] = ACTIONS(5525),
    [anon_sym_row_major] = ACTIONS(5525),
    [anon_sym_column_major] = ACTIONS(5525),
    [anon_sym_globallycoherent] = ACTIONS(5525),
    [anon_sym_centroid] = ACTIONS(5525),
    [anon_sym_noperspective] = ACTIONS(5525),
    [anon_sym_nointerpolation] = ACTIONS(5525),
    [anon_sym_sample] = ACTIONS(5525),
    [anon_sym_linear] = ACTIONS(5525),
    [anon_sym_snorm] = ACTIONS(5525),
    [anon_sym_unorm] = ACTIONS(5525),
    [anon_sym_point] = ACTIONS(5525),
    [anon_sym_line] = ACTIONS(5525),
    [anon_sym_triangleadj] = ACTIONS(5525),
    [anon_sym_lineadj] = ACTIONS(5525),
    [anon_sym_triangle] = ACTIONS(5525),
  },
  [2301] = {
    [sym_attribute_specifier] = STATE(2297),
    [sym_enumerator_list] = STATE(2321),
    [sym_identifier] = ACTIONS(5529),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5531),
    [anon_sym_COMMA] = ACTIONS(5531),
    [anon_sym_RPAREN] = ACTIONS(5531),
    [anon_sym_LPAREN2] = ACTIONS(5531),
    [anon_sym_TILDE] = ACTIONS(5531),
    [anon_sym_STAR] = ACTIONS(5531),
    [anon_sym_AMP_AMP] = ACTIONS(5531),
    [anon_sym_AMP] = ACTIONS(5529),
    [anon_sym_COLON] = ACTIONS(5529),
    [anon_sym_SEMI] = ACTIONS(5531),
    [anon_sym___extension__] = ACTIONS(5529),
    [anon_sym_in] = ACTIONS(5529),
    [anon_sym_out] = ACTIONS(5529),
    [anon_sym_inout] = ACTIONS(5529),
    [anon_sym_extern] = ACTIONS(5529),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5531),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5531),
    [anon_sym___declspec] = ACTIONS(5529),
    [anon_sym___based] = ACTIONS(5529),
    [anon_sym___cdecl] = ACTIONS(5529),
    [anon_sym___clrcall] = ACTIONS(5529),
    [anon_sym___stdcall] = ACTIONS(5529),
    [anon_sym___fastcall] = ACTIONS(5529),
    [anon_sym___thiscall] = ACTIONS(5529),
    [anon_sym___vectorcall] = ACTIONS(5529),
    [anon_sym_LBRACE] = ACTIONS(5523),
    [anon_sym_LBRACK] = ACTIONS(5529),
    [anon_sym_static] = ACTIONS(5529),
    [anon_sym_EQ] = ACTIONS(5531),
    [anon_sym_register] = ACTIONS(5529),
    [anon_sym_inline] = ACTIONS(5529),
    [anon_sym___inline] = ACTIONS(5529),
    [anon_sym___inline__] = ACTIONS(5529),
    [anon_sym___forceinline] = ACTIONS(5529),
    [anon_sym_thread_local] = ACTIONS(5529),
    [anon_sym___thread] = ACTIONS(5529),
    [anon_sym_const] = ACTIONS(5529),
    [anon_sym_constexpr] = ACTIONS(5529),
    [anon_sym_volatile] = ACTIONS(5529),
    [anon_sym_restrict] = ACTIONS(5529),
    [anon_sym___restrict__] = ACTIONS(5529),
    [anon_sym__Atomic] = ACTIONS(5529),
    [anon_sym__Noreturn] = ACTIONS(5529),
    [anon_sym_noreturn] = ACTIONS(5529),
    [anon_sym_mutable] = ACTIONS(5529),
    [anon_sym_constinit] = ACTIONS(5529),
    [anon_sym_consteval] = ACTIONS(5529),
    [anon_sym_alignas] = ACTIONS(5529),
    [anon_sym__Alignas] = ACTIONS(5529),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5529),
    [anon_sym_decltype] = ACTIONS(5529),
    [sym_virtual] = ACTIONS(5529),
    [anon_sym_template] = ACTIONS(5529),
    [anon_sym_GT2] = ACTIONS(5531),
    [anon_sym_operator] = ACTIONS(5529),
    [anon_sym_precise] = ACTIONS(5529),
    [anon_sym_shared] = ACTIONS(5529),
    [anon_sym_groupshared] = ACTIONS(5529),
    [anon_sym_uniform] = ACTIONS(5529),
    [anon_sym_row_major] = ACTIONS(5529),
    [anon_sym_column_major] = ACTIONS(5529),
    [anon_sym_globallycoherent] = ACTIONS(5529),
    [anon_sym_centroid] = ACTIONS(5529),
    [anon_sym_noperspective] = ACTIONS(5529),
    [anon_sym_nointerpolation] = ACTIONS(5529),
    [anon_sym_sample] = ACTIONS(5529),
    [anon_sym_linear] = ACTIONS(5529),
    [anon_sym_snorm] = ACTIONS(5529),
    [anon_sym_unorm] = ACTIONS(5529),
    [anon_sym_point] = ACTIONS(5529),
    [anon_sym_line] = ACTIONS(5529),
    [anon_sym_triangleadj] = ACTIONS(5529),
    [anon_sym_lineadj] = ACTIONS(5529),
    [anon_sym_triangle] = ACTIONS(5529),
  },
  [2302] = {
    [sym_identifier] = ACTIONS(5533),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5535),
    [anon_sym_COMMA] = ACTIONS(5535),
    [anon_sym_RPAREN] = ACTIONS(5535),
    [anon_sym_LPAREN2] = ACTIONS(5535),
    [anon_sym_TILDE] = ACTIONS(5535),
    [anon_sym_STAR] = ACTIONS(5535),
    [anon_sym_AMP_AMP] = ACTIONS(5535),
    [anon_sym_AMP] = ACTIONS(5533),
    [anon_sym_COLON] = ACTIONS(5533),
    [anon_sym_SEMI] = ACTIONS(5535),
    [anon_sym___extension__] = ACTIONS(5533),
    [anon_sym_in] = ACTIONS(5533),
    [anon_sym_out] = ACTIONS(5533),
    [anon_sym_inout] = ACTIONS(5533),
    [anon_sym_extern] = ACTIONS(5533),
    [anon_sym___attribute__] = ACTIONS(5533),
    [anon_sym_COLON_COLON] = ACTIONS(5535),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5535),
    [anon_sym___declspec] = ACTIONS(5533),
    [anon_sym___based] = ACTIONS(5533),
    [anon_sym___cdecl] = ACTIONS(5533),
    [anon_sym___clrcall] = ACTIONS(5533),
    [anon_sym___stdcall] = ACTIONS(5533),
    [anon_sym___fastcall] = ACTIONS(5533),
    [anon_sym___thiscall] = ACTIONS(5533),
    [anon_sym___vectorcall] = ACTIONS(5533),
    [anon_sym_LBRACK] = ACTIONS(5533),
    [anon_sym_static] = ACTIONS(5533),
    [anon_sym_EQ] = ACTIONS(5535),
    [anon_sym_register] = ACTIONS(5533),
    [anon_sym_inline] = ACTIONS(5533),
    [anon_sym___inline] = ACTIONS(5533),
    [anon_sym___inline__] = ACTIONS(5533),
    [anon_sym___forceinline] = ACTIONS(5533),
    [anon_sym_thread_local] = ACTIONS(5533),
    [anon_sym___thread] = ACTIONS(5533),
    [anon_sym_const] = ACTIONS(5533),
    [anon_sym_constexpr] = ACTIONS(5533),
    [anon_sym_volatile] = ACTIONS(5533),
    [anon_sym_restrict] = ACTIONS(5533),
    [anon_sym___restrict__] = ACTIONS(5533),
    [anon_sym__Atomic] = ACTIONS(5533),
    [anon_sym__Noreturn] = ACTIONS(5533),
    [anon_sym_noreturn] = ACTIONS(5533),
    [anon_sym_mutable] = ACTIONS(5533),
    [anon_sym_constinit] = ACTIONS(5533),
    [anon_sym_consteval] = ACTIONS(5533),
    [anon_sym_alignas] = ACTIONS(5533),
    [anon_sym__Alignas] = ACTIONS(5533),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5533),
    [anon_sym_decltype] = ACTIONS(5533),
    [anon_sym_final] = ACTIONS(5533),
    [anon_sym_override] = ACTIONS(5533),
    [sym_virtual] = ACTIONS(5533),
    [anon_sym_template] = ACTIONS(5533),
    [anon_sym_GT2] = ACTIONS(5535),
    [anon_sym_operator] = ACTIONS(5533),
    [anon_sym_requires] = ACTIONS(5533),
    [anon_sym_precise] = ACTIONS(5533),
    [anon_sym_shared] = ACTIONS(5533),
    [anon_sym_groupshared] = ACTIONS(5533),
    [anon_sym_uniform] = ACTIONS(5533),
    [anon_sym_row_major] = ACTIONS(5533),
    [anon_sym_column_major] = ACTIONS(5533),
    [anon_sym_globallycoherent] = ACTIONS(5533),
    [anon_sym_centroid] = ACTIONS(5533),
    [anon_sym_noperspective] = ACTIONS(5533),
    [anon_sym_nointerpolation] = ACTIONS(5533),
    [anon_sym_sample] = ACTIONS(5533),
    [anon_sym_linear] = ACTIONS(5533),
    [anon_sym_snorm] = ACTIONS(5533),
    [anon_sym_unorm] = ACTIONS(5533),
    [anon_sym_point] = ACTIONS(5533),
    [anon_sym_line] = ACTIONS(5533),
    [anon_sym_triangleadj] = ACTIONS(5533),
    [anon_sym_lineadj] = ACTIONS(5533),
    [anon_sym_triangle] = ACTIONS(5533),
  },
  [2303] = {
    [sym_identifier] = ACTIONS(5537),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5539),
    [anon_sym_COMMA] = ACTIONS(5539),
    [anon_sym_RPAREN] = ACTIONS(5539),
    [anon_sym_LPAREN2] = ACTIONS(5539),
    [anon_sym_TILDE] = ACTIONS(5539),
    [anon_sym_STAR] = ACTIONS(5539),
    [anon_sym_AMP_AMP] = ACTIONS(5539),
    [anon_sym_AMP] = ACTIONS(5537),
    [anon_sym_COLON] = ACTIONS(5537),
    [anon_sym_SEMI] = ACTIONS(5539),
    [anon_sym___extension__] = ACTIONS(5537),
    [anon_sym_in] = ACTIONS(5537),
    [anon_sym_out] = ACTIONS(5537),
    [anon_sym_inout] = ACTIONS(5537),
    [anon_sym_extern] = ACTIONS(5537),
    [anon_sym___attribute__] = ACTIONS(5537),
    [anon_sym_COLON_COLON] = ACTIONS(5539),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5539),
    [anon_sym___declspec] = ACTIONS(5537),
    [anon_sym___based] = ACTIONS(5537),
    [anon_sym___cdecl] = ACTIONS(5537),
    [anon_sym___clrcall] = ACTIONS(5537),
    [anon_sym___stdcall] = ACTIONS(5537),
    [anon_sym___fastcall] = ACTIONS(5537),
    [anon_sym___thiscall] = ACTIONS(5537),
    [anon_sym___vectorcall] = ACTIONS(5537),
    [anon_sym_LBRACK] = ACTIONS(5537),
    [anon_sym_static] = ACTIONS(5537),
    [anon_sym_EQ] = ACTIONS(5539),
    [anon_sym_register] = ACTIONS(5537),
    [anon_sym_inline] = ACTIONS(5537),
    [anon_sym___inline] = ACTIONS(5537),
    [anon_sym___inline__] = ACTIONS(5537),
    [anon_sym___forceinline] = ACTIONS(5537),
    [anon_sym_thread_local] = ACTIONS(5537),
    [anon_sym___thread] = ACTIONS(5537),
    [anon_sym_const] = ACTIONS(5537),
    [anon_sym_constexpr] = ACTIONS(5537),
    [anon_sym_volatile] = ACTIONS(5537),
    [anon_sym_restrict] = ACTIONS(5537),
    [anon_sym___restrict__] = ACTIONS(5537),
    [anon_sym__Atomic] = ACTIONS(5537),
    [anon_sym__Noreturn] = ACTIONS(5537),
    [anon_sym_noreturn] = ACTIONS(5537),
    [anon_sym_mutable] = ACTIONS(5537),
    [anon_sym_constinit] = ACTIONS(5537),
    [anon_sym_consteval] = ACTIONS(5537),
    [anon_sym_alignas] = ACTIONS(5537),
    [anon_sym__Alignas] = ACTIONS(5537),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5537),
    [anon_sym_decltype] = ACTIONS(5537),
    [anon_sym_final] = ACTIONS(5537),
    [anon_sym_override] = ACTIONS(5537),
    [sym_virtual] = ACTIONS(5537),
    [anon_sym_template] = ACTIONS(5537),
    [anon_sym_GT2] = ACTIONS(5539),
    [anon_sym_operator] = ACTIONS(5537),
    [anon_sym_requires] = ACTIONS(5537),
    [anon_sym_precise] = ACTIONS(5537),
    [anon_sym_shared] = ACTIONS(5537),
    [anon_sym_groupshared] = ACTIONS(5537),
    [anon_sym_uniform] = ACTIONS(5537),
    [anon_sym_row_major] = ACTIONS(5537),
    [anon_sym_column_major] = ACTIONS(5537),
    [anon_sym_globallycoherent] = ACTIONS(5537),
    [anon_sym_centroid] = ACTIONS(5537),
    [anon_sym_noperspective] = ACTIONS(5537),
    [anon_sym_nointerpolation] = ACTIONS(5537),
    [anon_sym_sample] = ACTIONS(5537),
    [anon_sym_linear] = ACTIONS(5537),
    [anon_sym_snorm] = ACTIONS(5537),
    [anon_sym_unorm] = ACTIONS(5537),
    [anon_sym_point] = ACTIONS(5537),
    [anon_sym_line] = ACTIONS(5537),
    [anon_sym_triangleadj] = ACTIONS(5537),
    [anon_sym_lineadj] = ACTIONS(5537),
    [anon_sym_triangle] = ACTIONS(5537),
  },
  [2304] = {
    [sym_identifier] = ACTIONS(5525),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5527),
    [anon_sym_COMMA] = ACTIONS(5527),
    [anon_sym_RPAREN] = ACTIONS(5527),
    [anon_sym_LPAREN2] = ACTIONS(5527),
    [anon_sym_TILDE] = ACTIONS(5527),
    [anon_sym_STAR] = ACTIONS(5527),
    [anon_sym_AMP_AMP] = ACTIONS(5527),
    [anon_sym_AMP] = ACTIONS(5525),
    [anon_sym_COLON] = ACTIONS(5525),
    [anon_sym_SEMI] = ACTIONS(5527),
    [anon_sym___extension__] = ACTIONS(5525),
    [anon_sym_in] = ACTIONS(5525),
    [anon_sym_out] = ACTIONS(5525),
    [anon_sym_inout] = ACTIONS(5525),
    [anon_sym_extern] = ACTIONS(5525),
    [anon_sym___attribute__] = ACTIONS(5525),
    [anon_sym_COLON_COLON] = ACTIONS(5527),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5527),
    [anon_sym___declspec] = ACTIONS(5525),
    [anon_sym___based] = ACTIONS(5525),
    [anon_sym___cdecl] = ACTIONS(5525),
    [anon_sym___clrcall] = ACTIONS(5525),
    [anon_sym___stdcall] = ACTIONS(5525),
    [anon_sym___fastcall] = ACTIONS(5525),
    [anon_sym___thiscall] = ACTIONS(5525),
    [anon_sym___vectorcall] = ACTIONS(5525),
    [anon_sym_LBRACK] = ACTIONS(5525),
    [anon_sym_static] = ACTIONS(5525),
    [anon_sym_EQ] = ACTIONS(5527),
    [anon_sym_register] = ACTIONS(5525),
    [anon_sym_inline] = ACTIONS(5525),
    [anon_sym___inline] = ACTIONS(5525),
    [anon_sym___inline__] = ACTIONS(5525),
    [anon_sym___forceinline] = ACTIONS(5525),
    [anon_sym_thread_local] = ACTIONS(5525),
    [anon_sym___thread] = ACTIONS(5525),
    [anon_sym_const] = ACTIONS(5525),
    [anon_sym_constexpr] = ACTIONS(5525),
    [anon_sym_volatile] = ACTIONS(5525),
    [anon_sym_restrict] = ACTIONS(5525),
    [anon_sym___restrict__] = ACTIONS(5525),
    [anon_sym__Atomic] = ACTIONS(5525),
    [anon_sym__Noreturn] = ACTIONS(5525),
    [anon_sym_noreturn] = ACTIONS(5525),
    [anon_sym_mutable] = ACTIONS(5525),
    [anon_sym_constinit] = ACTIONS(5525),
    [anon_sym_consteval] = ACTIONS(5525),
    [anon_sym_alignas] = ACTIONS(5525),
    [anon_sym__Alignas] = ACTIONS(5525),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5525),
    [anon_sym_decltype] = ACTIONS(5525),
    [anon_sym_final] = ACTIONS(5525),
    [anon_sym_override] = ACTIONS(5525),
    [sym_virtual] = ACTIONS(5525),
    [anon_sym_template] = ACTIONS(5525),
    [anon_sym_GT2] = ACTIONS(5527),
    [anon_sym_operator] = ACTIONS(5525),
    [anon_sym_requires] = ACTIONS(5525),
    [anon_sym_precise] = ACTIONS(5525),
    [anon_sym_shared] = ACTIONS(5525),
    [anon_sym_groupshared] = ACTIONS(5525),
    [anon_sym_uniform] = ACTIONS(5525),
    [anon_sym_row_major] = ACTIONS(5525),
    [anon_sym_column_major] = ACTIONS(5525),
    [anon_sym_globallycoherent] = ACTIONS(5525),
    [anon_sym_centroid] = ACTIONS(5525),
    [anon_sym_noperspective] = ACTIONS(5525),
    [anon_sym_nointerpolation] = ACTIONS(5525),
    [anon_sym_sample] = ACTIONS(5525),
    [anon_sym_linear] = ACTIONS(5525),
    [anon_sym_snorm] = ACTIONS(5525),
    [anon_sym_unorm] = ACTIONS(5525),
    [anon_sym_point] = ACTIONS(5525),
    [anon_sym_line] = ACTIONS(5525),
    [anon_sym_triangleadj] = ACTIONS(5525),
    [anon_sym_lineadj] = ACTIONS(5525),
    [anon_sym_triangle] = ACTIONS(5525),
  },
  [2305] = {
    [sym_identifier] = ACTIONS(5541),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5543),
    [anon_sym_COMMA] = ACTIONS(5543),
    [anon_sym_RPAREN] = ACTIONS(5543),
    [anon_sym_LPAREN2] = ACTIONS(5543),
    [anon_sym_TILDE] = ACTIONS(5543),
    [anon_sym_STAR] = ACTIONS(5543),
    [anon_sym_AMP_AMP] = ACTIONS(5543),
    [anon_sym_AMP] = ACTIONS(5541),
    [anon_sym_COLON] = ACTIONS(5541),
    [anon_sym_SEMI] = ACTIONS(5543),
    [anon_sym___extension__] = ACTIONS(5541),
    [anon_sym_in] = ACTIONS(5541),
    [anon_sym_out] = ACTIONS(5541),
    [anon_sym_inout] = ACTIONS(5541),
    [anon_sym_extern] = ACTIONS(5541),
    [anon_sym___attribute__] = ACTIONS(5541),
    [anon_sym_COLON_COLON] = ACTIONS(5543),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5543),
    [anon_sym___declspec] = ACTIONS(5541),
    [anon_sym___based] = ACTIONS(5541),
    [anon_sym___cdecl] = ACTIONS(5541),
    [anon_sym___clrcall] = ACTIONS(5541),
    [anon_sym___stdcall] = ACTIONS(5541),
    [anon_sym___fastcall] = ACTIONS(5541),
    [anon_sym___thiscall] = ACTIONS(5541),
    [anon_sym___vectorcall] = ACTIONS(5541),
    [anon_sym_LBRACK] = ACTIONS(5541),
    [anon_sym_static] = ACTIONS(5541),
    [anon_sym_EQ] = ACTIONS(5543),
    [anon_sym_register] = ACTIONS(5541),
    [anon_sym_inline] = ACTIONS(5541),
    [anon_sym___inline] = ACTIONS(5541),
    [anon_sym___inline__] = ACTIONS(5541),
    [anon_sym___forceinline] = ACTIONS(5541),
    [anon_sym_thread_local] = ACTIONS(5541),
    [anon_sym___thread] = ACTIONS(5541),
    [anon_sym_const] = ACTIONS(5541),
    [anon_sym_constexpr] = ACTIONS(5541),
    [anon_sym_volatile] = ACTIONS(5541),
    [anon_sym_restrict] = ACTIONS(5541),
    [anon_sym___restrict__] = ACTIONS(5541),
    [anon_sym__Atomic] = ACTIONS(5541),
    [anon_sym__Noreturn] = ACTIONS(5541),
    [anon_sym_noreturn] = ACTIONS(5541),
    [anon_sym_mutable] = ACTIONS(5541),
    [anon_sym_constinit] = ACTIONS(5541),
    [anon_sym_consteval] = ACTIONS(5541),
    [anon_sym_alignas] = ACTIONS(5541),
    [anon_sym__Alignas] = ACTIONS(5541),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5541),
    [anon_sym_decltype] = ACTIONS(5541),
    [anon_sym_final] = ACTIONS(5541),
    [anon_sym_override] = ACTIONS(5541),
    [sym_virtual] = ACTIONS(5541),
    [anon_sym_template] = ACTIONS(5541),
    [anon_sym_GT2] = ACTIONS(5543),
    [anon_sym_operator] = ACTIONS(5541),
    [anon_sym_requires] = ACTIONS(5541),
    [anon_sym_precise] = ACTIONS(5541),
    [anon_sym_shared] = ACTIONS(5541),
    [anon_sym_groupshared] = ACTIONS(5541),
    [anon_sym_uniform] = ACTIONS(5541),
    [anon_sym_row_major] = ACTIONS(5541),
    [anon_sym_column_major] = ACTIONS(5541),
    [anon_sym_globallycoherent] = ACTIONS(5541),
    [anon_sym_centroid] = ACTIONS(5541),
    [anon_sym_noperspective] = ACTIONS(5541),
    [anon_sym_nointerpolation] = ACTIONS(5541),
    [anon_sym_sample] = ACTIONS(5541),
    [anon_sym_linear] = ACTIONS(5541),
    [anon_sym_snorm] = ACTIONS(5541),
    [anon_sym_unorm] = ACTIONS(5541),
    [anon_sym_point] = ACTIONS(5541),
    [anon_sym_line] = ACTIONS(5541),
    [anon_sym_triangleadj] = ACTIONS(5541),
    [anon_sym_lineadj] = ACTIONS(5541),
    [anon_sym_triangle] = ACTIONS(5541),
  },
  [2306] = {
    [sym_identifier] = ACTIONS(5545),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5547),
    [anon_sym_COMMA] = ACTIONS(5547),
    [anon_sym_RPAREN] = ACTIONS(5547),
    [anon_sym_LPAREN2] = ACTIONS(5547),
    [anon_sym_TILDE] = ACTIONS(5547),
    [anon_sym_STAR] = ACTIONS(5547),
    [anon_sym_AMP_AMP] = ACTIONS(5547),
    [anon_sym_AMP] = ACTIONS(5545),
    [anon_sym_COLON] = ACTIONS(5545),
    [anon_sym_SEMI] = ACTIONS(5547),
    [anon_sym___extension__] = ACTIONS(5545),
    [anon_sym_in] = ACTIONS(5545),
    [anon_sym_out] = ACTIONS(5545),
    [anon_sym_inout] = ACTIONS(5545),
    [anon_sym_extern] = ACTIONS(5545),
    [anon_sym___attribute__] = ACTIONS(5545),
    [anon_sym_COLON_COLON] = ACTIONS(5547),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5547),
    [anon_sym___declspec] = ACTIONS(5545),
    [anon_sym___based] = ACTIONS(5545),
    [anon_sym___cdecl] = ACTIONS(5545),
    [anon_sym___clrcall] = ACTIONS(5545),
    [anon_sym___stdcall] = ACTIONS(5545),
    [anon_sym___fastcall] = ACTIONS(5545),
    [anon_sym___thiscall] = ACTIONS(5545),
    [anon_sym___vectorcall] = ACTIONS(5545),
    [anon_sym_LBRACK] = ACTIONS(5545),
    [anon_sym_static] = ACTIONS(5545),
    [anon_sym_EQ] = ACTIONS(5547),
    [anon_sym_register] = ACTIONS(5545),
    [anon_sym_inline] = ACTIONS(5545),
    [anon_sym___inline] = ACTIONS(5545),
    [anon_sym___inline__] = ACTIONS(5545),
    [anon_sym___forceinline] = ACTIONS(5545),
    [anon_sym_thread_local] = ACTIONS(5545),
    [anon_sym___thread] = ACTIONS(5545),
    [anon_sym_const] = ACTIONS(5545),
    [anon_sym_constexpr] = ACTIONS(5545),
    [anon_sym_volatile] = ACTIONS(5545),
    [anon_sym_restrict] = ACTIONS(5545),
    [anon_sym___restrict__] = ACTIONS(5545),
    [anon_sym__Atomic] = ACTIONS(5545),
    [anon_sym__Noreturn] = ACTIONS(5545),
    [anon_sym_noreturn] = ACTIONS(5545),
    [anon_sym_mutable] = ACTIONS(5545),
    [anon_sym_constinit] = ACTIONS(5545),
    [anon_sym_consteval] = ACTIONS(5545),
    [anon_sym_alignas] = ACTIONS(5545),
    [anon_sym__Alignas] = ACTIONS(5545),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5545),
    [anon_sym_decltype] = ACTIONS(5545),
    [anon_sym_final] = ACTIONS(5545),
    [anon_sym_override] = ACTIONS(5545),
    [sym_virtual] = ACTIONS(5545),
    [anon_sym_template] = ACTIONS(5545),
    [anon_sym_GT2] = ACTIONS(5547),
    [anon_sym_operator] = ACTIONS(5545),
    [anon_sym_requires] = ACTIONS(5545),
    [anon_sym_precise] = ACTIONS(5545),
    [anon_sym_shared] = ACTIONS(5545),
    [anon_sym_groupshared] = ACTIONS(5545),
    [anon_sym_uniform] = ACTIONS(5545),
    [anon_sym_row_major] = ACTIONS(5545),
    [anon_sym_column_major] = ACTIONS(5545),
    [anon_sym_globallycoherent] = ACTIONS(5545),
    [anon_sym_centroid] = ACTIONS(5545),
    [anon_sym_noperspective] = ACTIONS(5545),
    [anon_sym_nointerpolation] = ACTIONS(5545),
    [anon_sym_sample] = ACTIONS(5545),
    [anon_sym_linear] = ACTIONS(5545),
    [anon_sym_snorm] = ACTIONS(5545),
    [anon_sym_unorm] = ACTIONS(5545),
    [anon_sym_point] = ACTIONS(5545),
    [anon_sym_line] = ACTIONS(5545),
    [anon_sym_triangleadj] = ACTIONS(5545),
    [anon_sym_lineadj] = ACTIONS(5545),
    [anon_sym_triangle] = ACTIONS(5545),
  },
  [2307] = {
    [sym_identifier] = ACTIONS(5549),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5551),
    [anon_sym_COMMA] = ACTIONS(5551),
    [anon_sym_RPAREN] = ACTIONS(5551),
    [anon_sym_LPAREN2] = ACTIONS(5551),
    [anon_sym_TILDE] = ACTIONS(5551),
    [anon_sym_STAR] = ACTIONS(5551),
    [anon_sym_AMP_AMP] = ACTIONS(5551),
    [anon_sym_AMP] = ACTIONS(5549),
    [anon_sym_COLON] = ACTIONS(5549),
    [anon_sym_SEMI] = ACTIONS(5551),
    [anon_sym___extension__] = ACTIONS(5549),
    [anon_sym_in] = ACTIONS(5549),
    [anon_sym_out] = ACTIONS(5549),
    [anon_sym_inout] = ACTIONS(5549),
    [anon_sym_extern] = ACTIONS(5549),
    [anon_sym___attribute__] = ACTIONS(5549),
    [anon_sym_COLON_COLON] = ACTIONS(5551),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5551),
    [anon_sym___declspec] = ACTIONS(5549),
    [anon_sym___based] = ACTIONS(5549),
    [anon_sym___cdecl] = ACTIONS(5549),
    [anon_sym___clrcall] = ACTIONS(5549),
    [anon_sym___stdcall] = ACTIONS(5549),
    [anon_sym___fastcall] = ACTIONS(5549),
    [anon_sym___thiscall] = ACTIONS(5549),
    [anon_sym___vectorcall] = ACTIONS(5549),
    [anon_sym_LBRACK] = ACTIONS(5549),
    [anon_sym_static] = ACTIONS(5549),
    [anon_sym_EQ] = ACTIONS(5551),
    [anon_sym_register] = ACTIONS(5549),
    [anon_sym_inline] = ACTIONS(5549),
    [anon_sym___inline] = ACTIONS(5549),
    [anon_sym___inline__] = ACTIONS(5549),
    [anon_sym___forceinline] = ACTIONS(5549),
    [anon_sym_thread_local] = ACTIONS(5549),
    [anon_sym___thread] = ACTIONS(5549),
    [anon_sym_const] = ACTIONS(5549),
    [anon_sym_constexpr] = ACTIONS(5549),
    [anon_sym_volatile] = ACTIONS(5549),
    [anon_sym_restrict] = ACTIONS(5549),
    [anon_sym___restrict__] = ACTIONS(5549),
    [anon_sym__Atomic] = ACTIONS(5549),
    [anon_sym__Noreturn] = ACTIONS(5549),
    [anon_sym_noreturn] = ACTIONS(5549),
    [anon_sym_mutable] = ACTIONS(5549),
    [anon_sym_constinit] = ACTIONS(5549),
    [anon_sym_consteval] = ACTIONS(5549),
    [anon_sym_alignas] = ACTIONS(5549),
    [anon_sym__Alignas] = ACTIONS(5549),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5549),
    [anon_sym_decltype] = ACTIONS(5549),
    [anon_sym_final] = ACTIONS(5549),
    [anon_sym_override] = ACTIONS(5549),
    [sym_virtual] = ACTIONS(5549),
    [anon_sym_template] = ACTIONS(5549),
    [anon_sym_GT2] = ACTIONS(5551),
    [anon_sym_operator] = ACTIONS(5549),
    [anon_sym_requires] = ACTIONS(5549),
    [anon_sym_precise] = ACTIONS(5549),
    [anon_sym_shared] = ACTIONS(5549),
    [anon_sym_groupshared] = ACTIONS(5549),
    [anon_sym_uniform] = ACTIONS(5549),
    [anon_sym_row_major] = ACTIONS(5549),
    [anon_sym_column_major] = ACTIONS(5549),
    [anon_sym_globallycoherent] = ACTIONS(5549),
    [anon_sym_centroid] = ACTIONS(5549),
    [anon_sym_noperspective] = ACTIONS(5549),
    [anon_sym_nointerpolation] = ACTIONS(5549),
    [anon_sym_sample] = ACTIONS(5549),
    [anon_sym_linear] = ACTIONS(5549),
    [anon_sym_snorm] = ACTIONS(5549),
    [anon_sym_unorm] = ACTIONS(5549),
    [anon_sym_point] = ACTIONS(5549),
    [anon_sym_line] = ACTIONS(5549),
    [anon_sym_triangleadj] = ACTIONS(5549),
    [anon_sym_lineadj] = ACTIONS(5549),
    [anon_sym_triangle] = ACTIONS(5549),
  },
  [2308] = {
    [sym_attribute_specifier] = STATE(2286),
    [sym_field_declaration_list] = STATE(2320),
    [sym_virtual_specifier] = STATE(6832),
    [sym_base_class_clause] = STATE(7803),
    [sym_identifier] = ACTIONS(5327),
    [anon_sym_LPAREN2] = ACTIONS(5329),
    [anon_sym_TILDE] = ACTIONS(5329),
    [anon_sym_STAR] = ACTIONS(5329),
    [anon_sym_AMP_AMP] = ACTIONS(5329),
    [anon_sym_AMP] = ACTIONS(5327),
    [anon_sym_COLON] = ACTIONS(1911),
    [anon_sym_SEMI] = ACTIONS(5553),
    [anon_sym___extension__] = ACTIONS(5327),
    [anon_sym_in] = ACTIONS(5327),
    [anon_sym_out] = ACTIONS(5327),
    [anon_sym_inout] = ACTIONS(5327),
    [anon_sym_extern] = ACTIONS(5327),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5329),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5329),
    [anon_sym___declspec] = ACTIONS(5327),
    [anon_sym___based] = ACTIONS(5327),
    [anon_sym___cdecl] = ACTIONS(5327),
    [anon_sym___clrcall] = ACTIONS(5327),
    [anon_sym___stdcall] = ACTIONS(5327),
    [anon_sym___fastcall] = ACTIONS(5327),
    [anon_sym___thiscall] = ACTIONS(5327),
    [anon_sym___vectorcall] = ACTIONS(5327),
    [anon_sym_LBRACE] = ACTIONS(5331),
    [anon_sym_LBRACK] = ACTIONS(5327),
    [anon_sym_static] = ACTIONS(5327),
    [anon_sym_register] = ACTIONS(5327),
    [anon_sym_inline] = ACTIONS(5327),
    [anon_sym___inline] = ACTIONS(5327),
    [anon_sym___inline__] = ACTIONS(5327),
    [anon_sym___forceinline] = ACTIONS(5327),
    [anon_sym_thread_local] = ACTIONS(5327),
    [anon_sym___thread] = ACTIONS(5327),
    [anon_sym_const] = ACTIONS(5327),
    [anon_sym_constexpr] = ACTIONS(5327),
    [anon_sym_volatile] = ACTIONS(5327),
    [anon_sym_restrict] = ACTIONS(5327),
    [anon_sym___restrict__] = ACTIONS(5327),
    [anon_sym__Atomic] = ACTIONS(5327),
    [anon_sym__Noreturn] = ACTIONS(5327),
    [anon_sym_noreturn] = ACTIONS(5327),
    [anon_sym_mutable] = ACTIONS(5327),
    [anon_sym_constinit] = ACTIONS(5327),
    [anon_sym_consteval] = ACTIONS(5327),
    [anon_sym_alignas] = ACTIONS(5327),
    [anon_sym__Alignas] = ACTIONS(5327),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5327),
    [anon_sym_decltype] = ACTIONS(5327),
    [anon_sym_final] = ACTIONS(1915),
    [anon_sym_override] = ACTIONS(1915),
    [sym_virtual] = ACTIONS(5327),
    [anon_sym_template] = ACTIONS(5327),
    [anon_sym_operator] = ACTIONS(5327),
    [anon_sym_precise] = ACTIONS(5327),
    [anon_sym_shared] = ACTIONS(5327),
    [anon_sym_groupshared] = ACTIONS(5327),
    [anon_sym_uniform] = ACTIONS(5327),
    [anon_sym_row_major] = ACTIONS(5327),
    [anon_sym_column_major] = ACTIONS(5327),
    [anon_sym_globallycoherent] = ACTIONS(5327),
    [anon_sym_centroid] = ACTIONS(5327),
    [anon_sym_noperspective] = ACTIONS(5327),
    [anon_sym_nointerpolation] = ACTIONS(5327),
    [anon_sym_sample] = ACTIONS(5327),
    [anon_sym_linear] = ACTIONS(5327),
    [anon_sym_snorm] = ACTIONS(5327),
    [anon_sym_unorm] = ACTIONS(5327),
    [anon_sym_point] = ACTIONS(5327),
    [anon_sym_line] = ACTIONS(5327),
    [anon_sym_triangleadj] = ACTIONS(5327),
    [anon_sym_lineadj] = ACTIONS(5327),
    [anon_sym_triangle] = ACTIONS(5327),
  },
  [2309] = {
    [sym_attribute_specifier] = STATE(2286),
    [sym_field_declaration_list] = STATE(2320),
    [sym_virtual_specifier] = STATE(6832),
    [sym_base_class_clause] = STATE(7803),
    [sym_identifier] = ACTIONS(5327),
    [anon_sym_LPAREN2] = ACTIONS(5329),
    [anon_sym_TILDE] = ACTIONS(5329),
    [anon_sym_STAR] = ACTIONS(5329),
    [anon_sym_AMP_AMP] = ACTIONS(5329),
    [anon_sym_AMP] = ACTIONS(5327),
    [anon_sym_COLON] = ACTIONS(1911),
    [anon_sym_SEMI] = ACTIONS(5555),
    [anon_sym___extension__] = ACTIONS(5327),
    [anon_sym_in] = ACTIONS(5327),
    [anon_sym_out] = ACTIONS(5327),
    [anon_sym_inout] = ACTIONS(5327),
    [anon_sym_extern] = ACTIONS(5327),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5329),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5329),
    [anon_sym___declspec] = ACTIONS(5327),
    [anon_sym___based] = ACTIONS(5327),
    [anon_sym___cdecl] = ACTIONS(5327),
    [anon_sym___clrcall] = ACTIONS(5327),
    [anon_sym___stdcall] = ACTIONS(5327),
    [anon_sym___fastcall] = ACTIONS(5327),
    [anon_sym___thiscall] = ACTIONS(5327),
    [anon_sym___vectorcall] = ACTIONS(5327),
    [anon_sym_LBRACE] = ACTIONS(5331),
    [anon_sym_LBRACK] = ACTIONS(5327),
    [anon_sym_static] = ACTIONS(5327),
    [anon_sym_register] = ACTIONS(5327),
    [anon_sym_inline] = ACTIONS(5327),
    [anon_sym___inline] = ACTIONS(5327),
    [anon_sym___inline__] = ACTIONS(5327),
    [anon_sym___forceinline] = ACTIONS(5327),
    [anon_sym_thread_local] = ACTIONS(5327),
    [anon_sym___thread] = ACTIONS(5327),
    [anon_sym_const] = ACTIONS(5327),
    [anon_sym_constexpr] = ACTIONS(5327),
    [anon_sym_volatile] = ACTIONS(5327),
    [anon_sym_restrict] = ACTIONS(5327),
    [anon_sym___restrict__] = ACTIONS(5327),
    [anon_sym__Atomic] = ACTIONS(5327),
    [anon_sym__Noreturn] = ACTIONS(5327),
    [anon_sym_noreturn] = ACTIONS(5327),
    [anon_sym_mutable] = ACTIONS(5327),
    [anon_sym_constinit] = ACTIONS(5327),
    [anon_sym_consteval] = ACTIONS(5327),
    [anon_sym_alignas] = ACTIONS(5327),
    [anon_sym__Alignas] = ACTIONS(5327),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5327),
    [anon_sym_decltype] = ACTIONS(5327),
    [anon_sym_final] = ACTIONS(1915),
    [anon_sym_override] = ACTIONS(1915),
    [sym_virtual] = ACTIONS(5327),
    [anon_sym_template] = ACTIONS(5327),
    [anon_sym_operator] = ACTIONS(5327),
    [anon_sym_precise] = ACTIONS(5327),
    [anon_sym_shared] = ACTIONS(5327),
    [anon_sym_groupshared] = ACTIONS(5327),
    [anon_sym_uniform] = ACTIONS(5327),
    [anon_sym_row_major] = ACTIONS(5327),
    [anon_sym_column_major] = ACTIONS(5327),
    [anon_sym_globallycoherent] = ACTIONS(5327),
    [anon_sym_centroid] = ACTIONS(5327),
    [anon_sym_noperspective] = ACTIONS(5327),
    [anon_sym_nointerpolation] = ACTIONS(5327),
    [anon_sym_sample] = ACTIONS(5327),
    [anon_sym_linear] = ACTIONS(5327),
    [anon_sym_snorm] = ACTIONS(5327),
    [anon_sym_unorm] = ACTIONS(5327),
    [anon_sym_point] = ACTIONS(5327),
    [anon_sym_line] = ACTIONS(5327),
    [anon_sym_triangleadj] = ACTIONS(5327),
    [anon_sym_lineadj] = ACTIONS(5327),
    [anon_sym_triangle] = ACTIONS(5327),
  },
  [2310] = {
    [sym_attribute_specifier] = STATE(2286),
    [sym_field_declaration_list] = STATE(2320),
    [sym_virtual_specifier] = STATE(6832),
    [sym_base_class_clause] = STATE(7803),
    [sym_identifier] = ACTIONS(5327),
    [anon_sym_LPAREN2] = ACTIONS(5329),
    [anon_sym_TILDE] = ACTIONS(5329),
    [anon_sym_STAR] = ACTIONS(5329),
    [anon_sym_AMP_AMP] = ACTIONS(5329),
    [anon_sym_AMP] = ACTIONS(5327),
    [anon_sym_COLON] = ACTIONS(1911),
    [anon_sym_SEMI] = ACTIONS(5557),
    [anon_sym___extension__] = ACTIONS(5327),
    [anon_sym_in] = ACTIONS(5327),
    [anon_sym_out] = ACTIONS(5327),
    [anon_sym_inout] = ACTIONS(5327),
    [anon_sym_extern] = ACTIONS(5327),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5329),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5329),
    [anon_sym___declspec] = ACTIONS(5327),
    [anon_sym___based] = ACTIONS(5327),
    [anon_sym___cdecl] = ACTIONS(5327),
    [anon_sym___clrcall] = ACTIONS(5327),
    [anon_sym___stdcall] = ACTIONS(5327),
    [anon_sym___fastcall] = ACTIONS(5327),
    [anon_sym___thiscall] = ACTIONS(5327),
    [anon_sym___vectorcall] = ACTIONS(5327),
    [anon_sym_LBRACE] = ACTIONS(5331),
    [anon_sym_LBRACK] = ACTIONS(5327),
    [anon_sym_static] = ACTIONS(5327),
    [anon_sym_register] = ACTIONS(5327),
    [anon_sym_inline] = ACTIONS(5327),
    [anon_sym___inline] = ACTIONS(5327),
    [anon_sym___inline__] = ACTIONS(5327),
    [anon_sym___forceinline] = ACTIONS(5327),
    [anon_sym_thread_local] = ACTIONS(5327),
    [anon_sym___thread] = ACTIONS(5327),
    [anon_sym_const] = ACTIONS(5327),
    [anon_sym_constexpr] = ACTIONS(5327),
    [anon_sym_volatile] = ACTIONS(5327),
    [anon_sym_restrict] = ACTIONS(5327),
    [anon_sym___restrict__] = ACTIONS(5327),
    [anon_sym__Atomic] = ACTIONS(5327),
    [anon_sym__Noreturn] = ACTIONS(5327),
    [anon_sym_noreturn] = ACTIONS(5327),
    [anon_sym_mutable] = ACTIONS(5327),
    [anon_sym_constinit] = ACTIONS(5327),
    [anon_sym_consteval] = ACTIONS(5327),
    [anon_sym_alignas] = ACTIONS(5327),
    [anon_sym__Alignas] = ACTIONS(5327),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5327),
    [anon_sym_decltype] = ACTIONS(5327),
    [anon_sym_final] = ACTIONS(1915),
    [anon_sym_override] = ACTIONS(1915),
    [sym_virtual] = ACTIONS(5327),
    [anon_sym_template] = ACTIONS(5327),
    [anon_sym_operator] = ACTIONS(5327),
    [anon_sym_precise] = ACTIONS(5327),
    [anon_sym_shared] = ACTIONS(5327),
    [anon_sym_groupshared] = ACTIONS(5327),
    [anon_sym_uniform] = ACTIONS(5327),
    [anon_sym_row_major] = ACTIONS(5327),
    [anon_sym_column_major] = ACTIONS(5327),
    [anon_sym_globallycoherent] = ACTIONS(5327),
    [anon_sym_centroid] = ACTIONS(5327),
    [anon_sym_noperspective] = ACTIONS(5327),
    [anon_sym_nointerpolation] = ACTIONS(5327),
    [anon_sym_sample] = ACTIONS(5327),
    [anon_sym_linear] = ACTIONS(5327),
    [anon_sym_snorm] = ACTIONS(5327),
    [anon_sym_unorm] = ACTIONS(5327),
    [anon_sym_point] = ACTIONS(5327),
    [anon_sym_line] = ACTIONS(5327),
    [anon_sym_triangleadj] = ACTIONS(5327),
    [anon_sym_lineadj] = ACTIONS(5327),
    [anon_sym_triangle] = ACTIONS(5327),
  },
  [2311] = {
    [sym_attribute_specifier] = STATE(2286),
    [sym_field_declaration_list] = STATE(2320),
    [sym_virtual_specifier] = STATE(6832),
    [sym_base_class_clause] = STATE(7803),
    [sym_identifier] = ACTIONS(5327),
    [anon_sym_LPAREN2] = ACTIONS(5329),
    [anon_sym_TILDE] = ACTIONS(5329),
    [anon_sym_STAR] = ACTIONS(5329),
    [anon_sym_AMP_AMP] = ACTIONS(5329),
    [anon_sym_AMP] = ACTIONS(5327),
    [anon_sym_COLON] = ACTIONS(1911),
    [anon_sym_SEMI] = ACTIONS(5559),
    [anon_sym___extension__] = ACTIONS(5327),
    [anon_sym_in] = ACTIONS(5327),
    [anon_sym_out] = ACTIONS(5327),
    [anon_sym_inout] = ACTIONS(5327),
    [anon_sym_extern] = ACTIONS(5327),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5329),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5329),
    [anon_sym___declspec] = ACTIONS(5327),
    [anon_sym___based] = ACTIONS(5327),
    [anon_sym___cdecl] = ACTIONS(5327),
    [anon_sym___clrcall] = ACTIONS(5327),
    [anon_sym___stdcall] = ACTIONS(5327),
    [anon_sym___fastcall] = ACTIONS(5327),
    [anon_sym___thiscall] = ACTIONS(5327),
    [anon_sym___vectorcall] = ACTIONS(5327),
    [anon_sym_LBRACE] = ACTIONS(5331),
    [anon_sym_LBRACK] = ACTIONS(5327),
    [anon_sym_static] = ACTIONS(5327),
    [anon_sym_register] = ACTIONS(5327),
    [anon_sym_inline] = ACTIONS(5327),
    [anon_sym___inline] = ACTIONS(5327),
    [anon_sym___inline__] = ACTIONS(5327),
    [anon_sym___forceinline] = ACTIONS(5327),
    [anon_sym_thread_local] = ACTIONS(5327),
    [anon_sym___thread] = ACTIONS(5327),
    [anon_sym_const] = ACTIONS(5327),
    [anon_sym_constexpr] = ACTIONS(5327),
    [anon_sym_volatile] = ACTIONS(5327),
    [anon_sym_restrict] = ACTIONS(5327),
    [anon_sym___restrict__] = ACTIONS(5327),
    [anon_sym__Atomic] = ACTIONS(5327),
    [anon_sym__Noreturn] = ACTIONS(5327),
    [anon_sym_noreturn] = ACTIONS(5327),
    [anon_sym_mutable] = ACTIONS(5327),
    [anon_sym_constinit] = ACTIONS(5327),
    [anon_sym_consteval] = ACTIONS(5327),
    [anon_sym_alignas] = ACTIONS(5327),
    [anon_sym__Alignas] = ACTIONS(5327),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5327),
    [anon_sym_decltype] = ACTIONS(5327),
    [anon_sym_final] = ACTIONS(1915),
    [anon_sym_override] = ACTIONS(1915),
    [sym_virtual] = ACTIONS(5327),
    [anon_sym_template] = ACTIONS(5327),
    [anon_sym_operator] = ACTIONS(5327),
    [anon_sym_precise] = ACTIONS(5327),
    [anon_sym_shared] = ACTIONS(5327),
    [anon_sym_groupshared] = ACTIONS(5327),
    [anon_sym_uniform] = ACTIONS(5327),
    [anon_sym_row_major] = ACTIONS(5327),
    [anon_sym_column_major] = ACTIONS(5327),
    [anon_sym_globallycoherent] = ACTIONS(5327),
    [anon_sym_centroid] = ACTIONS(5327),
    [anon_sym_noperspective] = ACTIONS(5327),
    [anon_sym_nointerpolation] = ACTIONS(5327),
    [anon_sym_sample] = ACTIONS(5327),
    [anon_sym_linear] = ACTIONS(5327),
    [anon_sym_snorm] = ACTIONS(5327),
    [anon_sym_unorm] = ACTIONS(5327),
    [anon_sym_point] = ACTIONS(5327),
    [anon_sym_line] = ACTIONS(5327),
    [anon_sym_triangleadj] = ACTIONS(5327),
    [anon_sym_lineadj] = ACTIONS(5327),
    [anon_sym_triangle] = ACTIONS(5327),
  },
  [2312] = {
    [sym_attribute_specifier] = STATE(2286),
    [sym_field_declaration_list] = STATE(2320),
    [sym_virtual_specifier] = STATE(6832),
    [sym_base_class_clause] = STATE(7803),
    [sym_identifier] = ACTIONS(5327),
    [anon_sym_LPAREN2] = ACTIONS(5329),
    [anon_sym_TILDE] = ACTIONS(5329),
    [anon_sym_STAR] = ACTIONS(5329),
    [anon_sym_AMP_AMP] = ACTIONS(5329),
    [anon_sym_AMP] = ACTIONS(5327),
    [anon_sym_COLON] = ACTIONS(1911),
    [anon_sym_SEMI] = ACTIONS(5561),
    [anon_sym___extension__] = ACTIONS(5327),
    [anon_sym_in] = ACTIONS(5327),
    [anon_sym_out] = ACTIONS(5327),
    [anon_sym_inout] = ACTIONS(5327),
    [anon_sym_extern] = ACTIONS(5327),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5329),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5329),
    [anon_sym___declspec] = ACTIONS(5327),
    [anon_sym___based] = ACTIONS(5327),
    [anon_sym___cdecl] = ACTIONS(5327),
    [anon_sym___clrcall] = ACTIONS(5327),
    [anon_sym___stdcall] = ACTIONS(5327),
    [anon_sym___fastcall] = ACTIONS(5327),
    [anon_sym___thiscall] = ACTIONS(5327),
    [anon_sym___vectorcall] = ACTIONS(5327),
    [anon_sym_LBRACE] = ACTIONS(5331),
    [anon_sym_LBRACK] = ACTIONS(5327),
    [anon_sym_static] = ACTIONS(5327),
    [anon_sym_register] = ACTIONS(5327),
    [anon_sym_inline] = ACTIONS(5327),
    [anon_sym___inline] = ACTIONS(5327),
    [anon_sym___inline__] = ACTIONS(5327),
    [anon_sym___forceinline] = ACTIONS(5327),
    [anon_sym_thread_local] = ACTIONS(5327),
    [anon_sym___thread] = ACTIONS(5327),
    [anon_sym_const] = ACTIONS(5327),
    [anon_sym_constexpr] = ACTIONS(5327),
    [anon_sym_volatile] = ACTIONS(5327),
    [anon_sym_restrict] = ACTIONS(5327),
    [anon_sym___restrict__] = ACTIONS(5327),
    [anon_sym__Atomic] = ACTIONS(5327),
    [anon_sym__Noreturn] = ACTIONS(5327),
    [anon_sym_noreturn] = ACTIONS(5327),
    [anon_sym_mutable] = ACTIONS(5327),
    [anon_sym_constinit] = ACTIONS(5327),
    [anon_sym_consteval] = ACTIONS(5327),
    [anon_sym_alignas] = ACTIONS(5327),
    [anon_sym__Alignas] = ACTIONS(5327),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5327),
    [anon_sym_decltype] = ACTIONS(5327),
    [anon_sym_final] = ACTIONS(1915),
    [anon_sym_override] = ACTIONS(1915),
    [sym_virtual] = ACTIONS(5327),
    [anon_sym_template] = ACTIONS(5327),
    [anon_sym_operator] = ACTIONS(5327),
    [anon_sym_precise] = ACTIONS(5327),
    [anon_sym_shared] = ACTIONS(5327),
    [anon_sym_groupshared] = ACTIONS(5327),
    [anon_sym_uniform] = ACTIONS(5327),
    [anon_sym_row_major] = ACTIONS(5327),
    [anon_sym_column_major] = ACTIONS(5327),
    [anon_sym_globallycoherent] = ACTIONS(5327),
    [anon_sym_centroid] = ACTIONS(5327),
    [anon_sym_noperspective] = ACTIONS(5327),
    [anon_sym_nointerpolation] = ACTIONS(5327),
    [anon_sym_sample] = ACTIONS(5327),
    [anon_sym_linear] = ACTIONS(5327),
    [anon_sym_snorm] = ACTIONS(5327),
    [anon_sym_unorm] = ACTIONS(5327),
    [anon_sym_point] = ACTIONS(5327),
    [anon_sym_line] = ACTIONS(5327),
    [anon_sym_triangleadj] = ACTIONS(5327),
    [anon_sym_lineadj] = ACTIONS(5327),
    [anon_sym_triangle] = ACTIONS(5327),
  },
  [2313] = {
    [sym_attribute_specifier] = STATE(2286),
    [sym_field_declaration_list] = STATE(2320),
    [sym_virtual_specifier] = STATE(6832),
    [sym_base_class_clause] = STATE(7803),
    [sym_identifier] = ACTIONS(5327),
    [anon_sym_LPAREN2] = ACTIONS(5329),
    [anon_sym_TILDE] = ACTIONS(5329),
    [anon_sym_STAR] = ACTIONS(5329),
    [anon_sym_AMP_AMP] = ACTIONS(5329),
    [anon_sym_AMP] = ACTIONS(5327),
    [anon_sym_COLON] = ACTIONS(1911),
    [anon_sym_SEMI] = ACTIONS(5563),
    [anon_sym___extension__] = ACTIONS(5327),
    [anon_sym_in] = ACTIONS(5327),
    [anon_sym_out] = ACTIONS(5327),
    [anon_sym_inout] = ACTIONS(5327),
    [anon_sym_extern] = ACTIONS(5327),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5329),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5329),
    [anon_sym___declspec] = ACTIONS(5327),
    [anon_sym___based] = ACTIONS(5327),
    [anon_sym___cdecl] = ACTIONS(5327),
    [anon_sym___clrcall] = ACTIONS(5327),
    [anon_sym___stdcall] = ACTIONS(5327),
    [anon_sym___fastcall] = ACTIONS(5327),
    [anon_sym___thiscall] = ACTIONS(5327),
    [anon_sym___vectorcall] = ACTIONS(5327),
    [anon_sym_LBRACE] = ACTIONS(5331),
    [anon_sym_LBRACK] = ACTIONS(5327),
    [anon_sym_static] = ACTIONS(5327),
    [anon_sym_register] = ACTIONS(5327),
    [anon_sym_inline] = ACTIONS(5327),
    [anon_sym___inline] = ACTIONS(5327),
    [anon_sym___inline__] = ACTIONS(5327),
    [anon_sym___forceinline] = ACTIONS(5327),
    [anon_sym_thread_local] = ACTIONS(5327),
    [anon_sym___thread] = ACTIONS(5327),
    [anon_sym_const] = ACTIONS(5327),
    [anon_sym_constexpr] = ACTIONS(5327),
    [anon_sym_volatile] = ACTIONS(5327),
    [anon_sym_restrict] = ACTIONS(5327),
    [anon_sym___restrict__] = ACTIONS(5327),
    [anon_sym__Atomic] = ACTIONS(5327),
    [anon_sym__Noreturn] = ACTIONS(5327),
    [anon_sym_noreturn] = ACTIONS(5327),
    [anon_sym_mutable] = ACTIONS(5327),
    [anon_sym_constinit] = ACTIONS(5327),
    [anon_sym_consteval] = ACTIONS(5327),
    [anon_sym_alignas] = ACTIONS(5327),
    [anon_sym__Alignas] = ACTIONS(5327),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5327),
    [anon_sym_decltype] = ACTIONS(5327),
    [anon_sym_final] = ACTIONS(1915),
    [anon_sym_override] = ACTIONS(1915),
    [sym_virtual] = ACTIONS(5327),
    [anon_sym_template] = ACTIONS(5327),
    [anon_sym_operator] = ACTIONS(5327),
    [anon_sym_precise] = ACTIONS(5327),
    [anon_sym_shared] = ACTIONS(5327),
    [anon_sym_groupshared] = ACTIONS(5327),
    [anon_sym_uniform] = ACTIONS(5327),
    [anon_sym_row_major] = ACTIONS(5327),
    [anon_sym_column_major] = ACTIONS(5327),
    [anon_sym_globallycoherent] = ACTIONS(5327),
    [anon_sym_centroid] = ACTIONS(5327),
    [anon_sym_noperspective] = ACTIONS(5327),
    [anon_sym_nointerpolation] = ACTIONS(5327),
    [anon_sym_sample] = ACTIONS(5327),
    [anon_sym_linear] = ACTIONS(5327),
    [anon_sym_snorm] = ACTIONS(5327),
    [anon_sym_unorm] = ACTIONS(5327),
    [anon_sym_point] = ACTIONS(5327),
    [anon_sym_line] = ACTIONS(5327),
    [anon_sym_triangleadj] = ACTIONS(5327),
    [anon_sym_lineadj] = ACTIONS(5327),
    [anon_sym_triangle] = ACTIONS(5327),
  },
  [2314] = {
    [sym_attribute_specifier] = STATE(2286),
    [sym_field_declaration_list] = STATE(2320),
    [sym_virtual_specifier] = STATE(6832),
    [sym_base_class_clause] = STATE(7803),
    [sym_identifier] = ACTIONS(5327),
    [anon_sym_LPAREN2] = ACTIONS(5329),
    [anon_sym_TILDE] = ACTIONS(5329),
    [anon_sym_STAR] = ACTIONS(5329),
    [anon_sym_AMP_AMP] = ACTIONS(5329),
    [anon_sym_AMP] = ACTIONS(5327),
    [anon_sym_COLON] = ACTIONS(1911),
    [anon_sym_SEMI] = ACTIONS(5565),
    [anon_sym___extension__] = ACTIONS(5327),
    [anon_sym_in] = ACTIONS(5327),
    [anon_sym_out] = ACTIONS(5327),
    [anon_sym_inout] = ACTIONS(5327),
    [anon_sym_extern] = ACTIONS(5327),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5329),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5329),
    [anon_sym___declspec] = ACTIONS(5327),
    [anon_sym___based] = ACTIONS(5327),
    [anon_sym___cdecl] = ACTIONS(5327),
    [anon_sym___clrcall] = ACTIONS(5327),
    [anon_sym___stdcall] = ACTIONS(5327),
    [anon_sym___fastcall] = ACTIONS(5327),
    [anon_sym___thiscall] = ACTIONS(5327),
    [anon_sym___vectorcall] = ACTIONS(5327),
    [anon_sym_LBRACE] = ACTIONS(5331),
    [anon_sym_LBRACK] = ACTIONS(5327),
    [anon_sym_static] = ACTIONS(5327),
    [anon_sym_register] = ACTIONS(5327),
    [anon_sym_inline] = ACTIONS(5327),
    [anon_sym___inline] = ACTIONS(5327),
    [anon_sym___inline__] = ACTIONS(5327),
    [anon_sym___forceinline] = ACTIONS(5327),
    [anon_sym_thread_local] = ACTIONS(5327),
    [anon_sym___thread] = ACTIONS(5327),
    [anon_sym_const] = ACTIONS(5327),
    [anon_sym_constexpr] = ACTIONS(5327),
    [anon_sym_volatile] = ACTIONS(5327),
    [anon_sym_restrict] = ACTIONS(5327),
    [anon_sym___restrict__] = ACTIONS(5327),
    [anon_sym__Atomic] = ACTIONS(5327),
    [anon_sym__Noreturn] = ACTIONS(5327),
    [anon_sym_noreturn] = ACTIONS(5327),
    [anon_sym_mutable] = ACTIONS(5327),
    [anon_sym_constinit] = ACTIONS(5327),
    [anon_sym_consteval] = ACTIONS(5327),
    [anon_sym_alignas] = ACTIONS(5327),
    [anon_sym__Alignas] = ACTIONS(5327),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5327),
    [anon_sym_decltype] = ACTIONS(5327),
    [anon_sym_final] = ACTIONS(1915),
    [anon_sym_override] = ACTIONS(1915),
    [sym_virtual] = ACTIONS(5327),
    [anon_sym_template] = ACTIONS(5327),
    [anon_sym_operator] = ACTIONS(5327),
    [anon_sym_precise] = ACTIONS(5327),
    [anon_sym_shared] = ACTIONS(5327),
    [anon_sym_groupshared] = ACTIONS(5327),
    [anon_sym_uniform] = ACTIONS(5327),
    [anon_sym_row_major] = ACTIONS(5327),
    [anon_sym_column_major] = ACTIONS(5327),
    [anon_sym_globallycoherent] = ACTIONS(5327),
    [anon_sym_centroid] = ACTIONS(5327),
    [anon_sym_noperspective] = ACTIONS(5327),
    [anon_sym_nointerpolation] = ACTIONS(5327),
    [anon_sym_sample] = ACTIONS(5327),
    [anon_sym_linear] = ACTIONS(5327),
    [anon_sym_snorm] = ACTIONS(5327),
    [anon_sym_unorm] = ACTIONS(5327),
    [anon_sym_point] = ACTIONS(5327),
    [anon_sym_line] = ACTIONS(5327),
    [anon_sym_triangleadj] = ACTIONS(5327),
    [anon_sym_lineadj] = ACTIONS(5327),
    [anon_sym_triangle] = ACTIONS(5327),
  },
  [2315] = {
    [sym_attribute_specifier] = STATE(2272),
    [sym_identifier] = ACTIONS(5567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5569),
    [anon_sym_COMMA] = ACTIONS(5569),
    [anon_sym_RPAREN] = ACTIONS(5569),
    [anon_sym_LPAREN2] = ACTIONS(5569),
    [anon_sym_TILDE] = ACTIONS(5569),
    [anon_sym_STAR] = ACTIONS(5569),
    [anon_sym_AMP_AMP] = ACTIONS(5569),
    [anon_sym_AMP] = ACTIONS(5567),
    [anon_sym_COLON] = ACTIONS(5567),
    [anon_sym_SEMI] = ACTIONS(5569),
    [anon_sym___extension__] = ACTIONS(5567),
    [anon_sym_in] = ACTIONS(5567),
    [anon_sym_out] = ACTIONS(5567),
    [anon_sym_inout] = ACTIONS(5567),
    [anon_sym_extern] = ACTIONS(5567),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5569),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5569),
    [anon_sym___declspec] = ACTIONS(5567),
    [anon_sym___based] = ACTIONS(5567),
    [anon_sym___cdecl] = ACTIONS(5567),
    [anon_sym___clrcall] = ACTIONS(5567),
    [anon_sym___stdcall] = ACTIONS(5567),
    [anon_sym___fastcall] = ACTIONS(5567),
    [anon_sym___thiscall] = ACTIONS(5567),
    [anon_sym___vectorcall] = ACTIONS(5567),
    [anon_sym_LBRACK] = ACTIONS(5567),
    [anon_sym_static] = ACTIONS(5567),
    [anon_sym_EQ] = ACTIONS(5569),
    [anon_sym_register] = ACTIONS(5567),
    [anon_sym_inline] = ACTIONS(5567),
    [anon_sym___inline] = ACTIONS(5567),
    [anon_sym___inline__] = ACTIONS(5567),
    [anon_sym___forceinline] = ACTIONS(5567),
    [anon_sym_thread_local] = ACTIONS(5567),
    [anon_sym___thread] = ACTIONS(5567),
    [anon_sym_const] = ACTIONS(5567),
    [anon_sym_constexpr] = ACTIONS(5567),
    [anon_sym_volatile] = ACTIONS(5567),
    [anon_sym_restrict] = ACTIONS(5567),
    [anon_sym___restrict__] = ACTIONS(5567),
    [anon_sym__Atomic] = ACTIONS(5567),
    [anon_sym__Noreturn] = ACTIONS(5567),
    [anon_sym_noreturn] = ACTIONS(5567),
    [anon_sym_mutable] = ACTIONS(5567),
    [anon_sym_constinit] = ACTIONS(5567),
    [anon_sym_consteval] = ACTIONS(5567),
    [anon_sym_alignas] = ACTIONS(5567),
    [anon_sym__Alignas] = ACTIONS(5567),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5567),
    [anon_sym_decltype] = ACTIONS(5567),
    [sym_virtual] = ACTIONS(5567),
    [anon_sym_template] = ACTIONS(5567),
    [anon_sym_GT2] = ACTIONS(5569),
    [anon_sym_operator] = ACTIONS(5567),
    [anon_sym_precise] = ACTIONS(5567),
    [anon_sym_shared] = ACTIONS(5567),
    [anon_sym_groupshared] = ACTIONS(5567),
    [anon_sym_uniform] = ACTIONS(5567),
    [anon_sym_row_major] = ACTIONS(5567),
    [anon_sym_column_major] = ACTIONS(5567),
    [anon_sym_globallycoherent] = ACTIONS(5567),
    [anon_sym_centroid] = ACTIONS(5567),
    [anon_sym_noperspective] = ACTIONS(5567),
    [anon_sym_nointerpolation] = ACTIONS(5567),
    [anon_sym_sample] = ACTIONS(5567),
    [anon_sym_linear] = ACTIONS(5567),
    [anon_sym_snorm] = ACTIONS(5567),
    [anon_sym_unorm] = ACTIONS(5567),
    [anon_sym_point] = ACTIONS(5567),
    [anon_sym_line] = ACTIONS(5567),
    [anon_sym_triangleadj] = ACTIONS(5567),
    [anon_sym_lineadj] = ACTIONS(5567),
    [anon_sym_triangle] = ACTIONS(5567),
  },
  [2316] = {
    [sym_template_argument_list] = STATE(2221),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2233),
    [sym_identifier] = ACTIONS(3822),
    [anon_sym_LPAREN2] = ACTIONS(3830),
    [anon_sym_TILDE] = ACTIONS(3830),
    [anon_sym_STAR] = ACTIONS(3830),
    [anon_sym_AMP_AMP] = ACTIONS(3830),
    [anon_sym_AMP] = ACTIONS(3822),
    [anon_sym_LT] = ACTIONS(5298),
    [anon_sym_SEMI] = ACTIONS(3830),
    [anon_sym___extension__] = ACTIONS(3822),
    [anon_sym_in] = ACTIONS(3822),
    [anon_sym_out] = ACTIONS(3822),
    [anon_sym_inout] = ACTIONS(3822),
    [anon_sym_extern] = ACTIONS(3822),
    [anon_sym___attribute__] = ACTIONS(3822),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3830),
    [anon_sym___declspec] = ACTIONS(3822),
    [anon_sym___based] = ACTIONS(3822),
    [anon_sym___cdecl] = ACTIONS(3822),
    [anon_sym___clrcall] = ACTIONS(3822),
    [anon_sym___stdcall] = ACTIONS(3822),
    [anon_sym___fastcall] = ACTIONS(3822),
    [anon_sym___thiscall] = ACTIONS(3822),
    [anon_sym___vectorcall] = ACTIONS(3822),
    [anon_sym_signed] = ACTIONS(3848),
    [anon_sym_unsigned] = ACTIONS(3848),
    [anon_sym_long] = ACTIONS(3848),
    [anon_sym_short] = ACTIONS(3848),
    [anon_sym_LBRACK] = ACTIONS(3822),
    [anon_sym_static] = ACTIONS(3822),
    [anon_sym_register] = ACTIONS(3822),
    [anon_sym_inline] = ACTIONS(3822),
    [anon_sym___inline] = ACTIONS(3822),
    [anon_sym___inline__] = ACTIONS(3822),
    [anon_sym___forceinline] = ACTIONS(3822),
    [anon_sym_thread_local] = ACTIONS(3822),
    [anon_sym___thread] = ACTIONS(3822),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3822),
    [anon_sym_volatile] = ACTIONS(3822),
    [anon_sym_restrict] = ACTIONS(3822),
    [anon_sym___restrict__] = ACTIONS(3822),
    [anon_sym__Atomic] = ACTIONS(3822),
    [anon_sym__Noreturn] = ACTIONS(3822),
    [anon_sym_noreturn] = ACTIONS(3822),
    [anon_sym_mutable] = ACTIONS(3822),
    [anon_sym_constinit] = ACTIONS(3822),
    [anon_sym_consteval] = ACTIONS(3822),
    [anon_sym_alignas] = ACTIONS(3822),
    [anon_sym__Alignas] = ACTIONS(3822),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3822),
    [anon_sym_decltype] = ACTIONS(3822),
    [sym_virtual] = ACTIONS(3822),
    [anon_sym_template] = ACTIONS(3822),
    [anon_sym_operator] = ACTIONS(3822),
    [anon_sym_precise] = ACTIONS(3822),
    [anon_sym_shared] = ACTIONS(3822),
    [anon_sym_groupshared] = ACTIONS(3822),
    [anon_sym_uniform] = ACTIONS(3822),
    [anon_sym_row_major] = ACTIONS(3822),
    [anon_sym_column_major] = ACTIONS(3822),
    [anon_sym_globallycoherent] = ACTIONS(3822),
    [anon_sym_centroid] = ACTIONS(3822),
    [anon_sym_noperspective] = ACTIONS(3822),
    [anon_sym_nointerpolation] = ACTIONS(3822),
    [anon_sym_sample] = ACTIONS(3822),
    [anon_sym_linear] = ACTIONS(3822),
    [anon_sym_snorm] = ACTIONS(3822),
    [anon_sym_unorm] = ACTIONS(3822),
    [anon_sym_point] = ACTIONS(3822),
    [anon_sym_line] = ACTIONS(3822),
    [anon_sym_triangleadj] = ACTIONS(3822),
    [anon_sym_lineadj] = ACTIONS(3822),
    [anon_sym_triangle] = ACTIONS(3822),
  },
  [2317] = {
    [sym_attribute_specifier] = STATE(2289),
    [sym_identifier] = ACTIONS(5571),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5573),
    [anon_sym_COMMA] = ACTIONS(5573),
    [anon_sym_RPAREN] = ACTIONS(5573),
    [anon_sym_LPAREN2] = ACTIONS(5573),
    [anon_sym_TILDE] = ACTIONS(5573),
    [anon_sym_STAR] = ACTIONS(5573),
    [anon_sym_AMP_AMP] = ACTIONS(5573),
    [anon_sym_AMP] = ACTIONS(5571),
    [anon_sym_COLON] = ACTIONS(5571),
    [anon_sym_SEMI] = ACTIONS(5573),
    [anon_sym___extension__] = ACTIONS(5571),
    [anon_sym_in] = ACTIONS(5571),
    [anon_sym_out] = ACTIONS(5571),
    [anon_sym_inout] = ACTIONS(5571),
    [anon_sym_extern] = ACTIONS(5571),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5573),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5573),
    [anon_sym___declspec] = ACTIONS(5571),
    [anon_sym___based] = ACTIONS(5571),
    [anon_sym___cdecl] = ACTIONS(5571),
    [anon_sym___clrcall] = ACTIONS(5571),
    [anon_sym___stdcall] = ACTIONS(5571),
    [anon_sym___fastcall] = ACTIONS(5571),
    [anon_sym___thiscall] = ACTIONS(5571),
    [anon_sym___vectorcall] = ACTIONS(5571),
    [anon_sym_LBRACK] = ACTIONS(5571),
    [anon_sym_static] = ACTIONS(5571),
    [anon_sym_EQ] = ACTIONS(5573),
    [anon_sym_register] = ACTIONS(5571),
    [anon_sym_inline] = ACTIONS(5571),
    [anon_sym___inline] = ACTIONS(5571),
    [anon_sym___inline__] = ACTIONS(5571),
    [anon_sym___forceinline] = ACTIONS(5571),
    [anon_sym_thread_local] = ACTIONS(5571),
    [anon_sym___thread] = ACTIONS(5571),
    [anon_sym_const] = ACTIONS(5571),
    [anon_sym_constexpr] = ACTIONS(5571),
    [anon_sym_volatile] = ACTIONS(5571),
    [anon_sym_restrict] = ACTIONS(5571),
    [anon_sym___restrict__] = ACTIONS(5571),
    [anon_sym__Atomic] = ACTIONS(5571),
    [anon_sym__Noreturn] = ACTIONS(5571),
    [anon_sym_noreturn] = ACTIONS(5571),
    [anon_sym_mutable] = ACTIONS(5571),
    [anon_sym_constinit] = ACTIONS(5571),
    [anon_sym_consteval] = ACTIONS(5571),
    [anon_sym_alignas] = ACTIONS(5571),
    [anon_sym__Alignas] = ACTIONS(5571),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5571),
    [anon_sym_decltype] = ACTIONS(5571),
    [sym_virtual] = ACTIONS(5571),
    [anon_sym_template] = ACTIONS(5571),
    [anon_sym_GT2] = ACTIONS(5573),
    [anon_sym_operator] = ACTIONS(5571),
    [anon_sym_precise] = ACTIONS(5571),
    [anon_sym_shared] = ACTIONS(5571),
    [anon_sym_groupshared] = ACTIONS(5571),
    [anon_sym_uniform] = ACTIONS(5571),
    [anon_sym_row_major] = ACTIONS(5571),
    [anon_sym_column_major] = ACTIONS(5571),
    [anon_sym_globallycoherent] = ACTIONS(5571),
    [anon_sym_centroid] = ACTIONS(5571),
    [anon_sym_noperspective] = ACTIONS(5571),
    [anon_sym_nointerpolation] = ACTIONS(5571),
    [anon_sym_sample] = ACTIONS(5571),
    [anon_sym_linear] = ACTIONS(5571),
    [anon_sym_snorm] = ACTIONS(5571),
    [anon_sym_unorm] = ACTIONS(5571),
    [anon_sym_point] = ACTIONS(5571),
    [anon_sym_line] = ACTIONS(5571),
    [anon_sym_triangleadj] = ACTIONS(5571),
    [anon_sym_lineadj] = ACTIONS(5571),
    [anon_sym_triangle] = ACTIONS(5571),
  },
  [2318] = {
    [sym_attribute_specifier] = STATE(2306),
    [sym_identifier] = ACTIONS(5575),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5577),
    [anon_sym_COMMA] = ACTIONS(5577),
    [anon_sym_RPAREN] = ACTIONS(5577),
    [anon_sym_LPAREN2] = ACTIONS(5577),
    [anon_sym_TILDE] = ACTIONS(5577),
    [anon_sym_STAR] = ACTIONS(5577),
    [anon_sym_AMP_AMP] = ACTIONS(5577),
    [anon_sym_AMP] = ACTIONS(5575),
    [anon_sym_COLON] = ACTIONS(5575),
    [anon_sym_SEMI] = ACTIONS(5577),
    [anon_sym___extension__] = ACTIONS(5575),
    [anon_sym_in] = ACTIONS(5575),
    [anon_sym_out] = ACTIONS(5575),
    [anon_sym_inout] = ACTIONS(5575),
    [anon_sym_extern] = ACTIONS(5575),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5577),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5577),
    [anon_sym___declspec] = ACTIONS(5575),
    [anon_sym___based] = ACTIONS(5575),
    [anon_sym___cdecl] = ACTIONS(5575),
    [anon_sym___clrcall] = ACTIONS(5575),
    [anon_sym___stdcall] = ACTIONS(5575),
    [anon_sym___fastcall] = ACTIONS(5575),
    [anon_sym___thiscall] = ACTIONS(5575),
    [anon_sym___vectorcall] = ACTIONS(5575),
    [anon_sym_LBRACK] = ACTIONS(5575),
    [anon_sym_static] = ACTIONS(5575),
    [anon_sym_EQ] = ACTIONS(5577),
    [anon_sym_register] = ACTIONS(5575),
    [anon_sym_inline] = ACTIONS(5575),
    [anon_sym___inline] = ACTIONS(5575),
    [anon_sym___inline__] = ACTIONS(5575),
    [anon_sym___forceinline] = ACTIONS(5575),
    [anon_sym_thread_local] = ACTIONS(5575),
    [anon_sym___thread] = ACTIONS(5575),
    [anon_sym_const] = ACTIONS(5575),
    [anon_sym_constexpr] = ACTIONS(5575),
    [anon_sym_volatile] = ACTIONS(5575),
    [anon_sym_restrict] = ACTIONS(5575),
    [anon_sym___restrict__] = ACTIONS(5575),
    [anon_sym__Atomic] = ACTIONS(5575),
    [anon_sym__Noreturn] = ACTIONS(5575),
    [anon_sym_noreturn] = ACTIONS(5575),
    [anon_sym_mutable] = ACTIONS(5575),
    [anon_sym_constinit] = ACTIONS(5575),
    [anon_sym_consteval] = ACTIONS(5575),
    [anon_sym_alignas] = ACTIONS(5575),
    [anon_sym__Alignas] = ACTIONS(5575),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5575),
    [anon_sym_decltype] = ACTIONS(5575),
    [sym_virtual] = ACTIONS(5575),
    [anon_sym_template] = ACTIONS(5575),
    [anon_sym_GT2] = ACTIONS(5577),
    [anon_sym_operator] = ACTIONS(5575),
    [anon_sym_precise] = ACTIONS(5575),
    [anon_sym_shared] = ACTIONS(5575),
    [anon_sym_groupshared] = ACTIONS(5575),
    [anon_sym_uniform] = ACTIONS(5575),
    [anon_sym_row_major] = ACTIONS(5575),
    [anon_sym_column_major] = ACTIONS(5575),
    [anon_sym_globallycoherent] = ACTIONS(5575),
    [anon_sym_centroid] = ACTIONS(5575),
    [anon_sym_noperspective] = ACTIONS(5575),
    [anon_sym_nointerpolation] = ACTIONS(5575),
    [anon_sym_sample] = ACTIONS(5575),
    [anon_sym_linear] = ACTIONS(5575),
    [anon_sym_snorm] = ACTIONS(5575),
    [anon_sym_unorm] = ACTIONS(5575),
    [anon_sym_point] = ACTIONS(5575),
    [anon_sym_line] = ACTIONS(5575),
    [anon_sym_triangleadj] = ACTIONS(5575),
    [anon_sym_lineadj] = ACTIONS(5575),
    [anon_sym_triangle] = ACTIONS(5575),
  },
  [2319] = {
    [sym_attribute_specifier] = STATE(2303),
    [sym_identifier] = ACTIONS(5579),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5581),
    [anon_sym_COMMA] = ACTIONS(5581),
    [anon_sym_RPAREN] = ACTIONS(5581),
    [anon_sym_LPAREN2] = ACTIONS(5581),
    [anon_sym_TILDE] = ACTIONS(5581),
    [anon_sym_STAR] = ACTIONS(5581),
    [anon_sym_AMP_AMP] = ACTIONS(5581),
    [anon_sym_AMP] = ACTIONS(5579),
    [anon_sym_COLON] = ACTIONS(5579),
    [anon_sym_SEMI] = ACTIONS(5581),
    [anon_sym___extension__] = ACTIONS(5579),
    [anon_sym_in] = ACTIONS(5579),
    [anon_sym_out] = ACTIONS(5579),
    [anon_sym_inout] = ACTIONS(5579),
    [anon_sym_extern] = ACTIONS(5579),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5581),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5581),
    [anon_sym___declspec] = ACTIONS(5579),
    [anon_sym___based] = ACTIONS(5579),
    [anon_sym___cdecl] = ACTIONS(5579),
    [anon_sym___clrcall] = ACTIONS(5579),
    [anon_sym___stdcall] = ACTIONS(5579),
    [anon_sym___fastcall] = ACTIONS(5579),
    [anon_sym___thiscall] = ACTIONS(5579),
    [anon_sym___vectorcall] = ACTIONS(5579),
    [anon_sym_LBRACK] = ACTIONS(5579),
    [anon_sym_static] = ACTIONS(5579),
    [anon_sym_EQ] = ACTIONS(5581),
    [anon_sym_register] = ACTIONS(5579),
    [anon_sym_inline] = ACTIONS(5579),
    [anon_sym___inline] = ACTIONS(5579),
    [anon_sym___inline__] = ACTIONS(5579),
    [anon_sym___forceinline] = ACTIONS(5579),
    [anon_sym_thread_local] = ACTIONS(5579),
    [anon_sym___thread] = ACTIONS(5579),
    [anon_sym_const] = ACTIONS(5579),
    [anon_sym_constexpr] = ACTIONS(5579),
    [anon_sym_volatile] = ACTIONS(5579),
    [anon_sym_restrict] = ACTIONS(5579),
    [anon_sym___restrict__] = ACTIONS(5579),
    [anon_sym__Atomic] = ACTIONS(5579),
    [anon_sym__Noreturn] = ACTIONS(5579),
    [anon_sym_noreturn] = ACTIONS(5579),
    [anon_sym_mutable] = ACTIONS(5579),
    [anon_sym_constinit] = ACTIONS(5579),
    [anon_sym_consteval] = ACTIONS(5579),
    [anon_sym_alignas] = ACTIONS(5579),
    [anon_sym__Alignas] = ACTIONS(5579),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5579),
    [anon_sym_decltype] = ACTIONS(5579),
    [sym_virtual] = ACTIONS(5579),
    [anon_sym_template] = ACTIONS(5579),
    [anon_sym_GT2] = ACTIONS(5581),
    [anon_sym_operator] = ACTIONS(5579),
    [anon_sym_precise] = ACTIONS(5579),
    [anon_sym_shared] = ACTIONS(5579),
    [anon_sym_groupshared] = ACTIONS(5579),
    [anon_sym_uniform] = ACTIONS(5579),
    [anon_sym_row_major] = ACTIONS(5579),
    [anon_sym_column_major] = ACTIONS(5579),
    [anon_sym_globallycoherent] = ACTIONS(5579),
    [anon_sym_centroid] = ACTIONS(5579),
    [anon_sym_noperspective] = ACTIONS(5579),
    [anon_sym_nointerpolation] = ACTIONS(5579),
    [anon_sym_sample] = ACTIONS(5579),
    [anon_sym_linear] = ACTIONS(5579),
    [anon_sym_snorm] = ACTIONS(5579),
    [anon_sym_unorm] = ACTIONS(5579),
    [anon_sym_point] = ACTIONS(5579),
    [anon_sym_line] = ACTIONS(5579),
    [anon_sym_triangleadj] = ACTIONS(5579),
    [anon_sym_lineadj] = ACTIONS(5579),
    [anon_sym_triangle] = ACTIONS(5579),
  },
  [2320] = {
    [sym_attribute_specifier] = STATE(2302),
    [sym_identifier] = ACTIONS(5583),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5585),
    [anon_sym_COMMA] = ACTIONS(5585),
    [anon_sym_RPAREN] = ACTIONS(5585),
    [anon_sym_LPAREN2] = ACTIONS(5585),
    [anon_sym_TILDE] = ACTIONS(5585),
    [anon_sym_STAR] = ACTIONS(5585),
    [anon_sym_AMP_AMP] = ACTIONS(5585),
    [anon_sym_AMP] = ACTIONS(5583),
    [anon_sym_COLON] = ACTIONS(5583),
    [anon_sym_SEMI] = ACTIONS(5585),
    [anon_sym___extension__] = ACTIONS(5583),
    [anon_sym_in] = ACTIONS(5583),
    [anon_sym_out] = ACTIONS(5583),
    [anon_sym_inout] = ACTIONS(5583),
    [anon_sym_extern] = ACTIONS(5583),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5585),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5585),
    [anon_sym___declspec] = ACTIONS(5583),
    [anon_sym___based] = ACTIONS(5583),
    [anon_sym___cdecl] = ACTIONS(5583),
    [anon_sym___clrcall] = ACTIONS(5583),
    [anon_sym___stdcall] = ACTIONS(5583),
    [anon_sym___fastcall] = ACTIONS(5583),
    [anon_sym___thiscall] = ACTIONS(5583),
    [anon_sym___vectorcall] = ACTIONS(5583),
    [anon_sym_LBRACK] = ACTIONS(5583),
    [anon_sym_static] = ACTIONS(5583),
    [anon_sym_EQ] = ACTIONS(5585),
    [anon_sym_register] = ACTIONS(5583),
    [anon_sym_inline] = ACTIONS(5583),
    [anon_sym___inline] = ACTIONS(5583),
    [anon_sym___inline__] = ACTIONS(5583),
    [anon_sym___forceinline] = ACTIONS(5583),
    [anon_sym_thread_local] = ACTIONS(5583),
    [anon_sym___thread] = ACTIONS(5583),
    [anon_sym_const] = ACTIONS(5583),
    [anon_sym_constexpr] = ACTIONS(5583),
    [anon_sym_volatile] = ACTIONS(5583),
    [anon_sym_restrict] = ACTIONS(5583),
    [anon_sym___restrict__] = ACTIONS(5583),
    [anon_sym__Atomic] = ACTIONS(5583),
    [anon_sym__Noreturn] = ACTIONS(5583),
    [anon_sym_noreturn] = ACTIONS(5583),
    [anon_sym_mutable] = ACTIONS(5583),
    [anon_sym_constinit] = ACTIONS(5583),
    [anon_sym_consteval] = ACTIONS(5583),
    [anon_sym_alignas] = ACTIONS(5583),
    [anon_sym__Alignas] = ACTIONS(5583),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5583),
    [anon_sym_decltype] = ACTIONS(5583),
    [sym_virtual] = ACTIONS(5583),
    [anon_sym_template] = ACTIONS(5583),
    [anon_sym_GT2] = ACTIONS(5585),
    [anon_sym_operator] = ACTIONS(5583),
    [anon_sym_precise] = ACTIONS(5583),
    [anon_sym_shared] = ACTIONS(5583),
    [anon_sym_groupshared] = ACTIONS(5583),
    [anon_sym_uniform] = ACTIONS(5583),
    [anon_sym_row_major] = ACTIONS(5583),
    [anon_sym_column_major] = ACTIONS(5583),
    [anon_sym_globallycoherent] = ACTIONS(5583),
    [anon_sym_centroid] = ACTIONS(5583),
    [anon_sym_noperspective] = ACTIONS(5583),
    [anon_sym_nointerpolation] = ACTIONS(5583),
    [anon_sym_sample] = ACTIONS(5583),
    [anon_sym_linear] = ACTIONS(5583),
    [anon_sym_snorm] = ACTIONS(5583),
    [anon_sym_unorm] = ACTIONS(5583),
    [anon_sym_point] = ACTIONS(5583),
    [anon_sym_line] = ACTIONS(5583),
    [anon_sym_triangleadj] = ACTIONS(5583),
    [anon_sym_lineadj] = ACTIONS(5583),
    [anon_sym_triangle] = ACTIONS(5583),
  },
  [2321] = {
    [sym_attribute_specifier] = STATE(2296),
    [sym_identifier] = ACTIONS(5587),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5589),
    [anon_sym_COMMA] = ACTIONS(5589),
    [anon_sym_RPAREN] = ACTIONS(5589),
    [anon_sym_LPAREN2] = ACTIONS(5589),
    [anon_sym_TILDE] = ACTIONS(5589),
    [anon_sym_STAR] = ACTIONS(5589),
    [anon_sym_AMP_AMP] = ACTIONS(5589),
    [anon_sym_AMP] = ACTIONS(5587),
    [anon_sym_COLON] = ACTIONS(5587),
    [anon_sym_SEMI] = ACTIONS(5589),
    [anon_sym___extension__] = ACTIONS(5587),
    [anon_sym_in] = ACTIONS(5587),
    [anon_sym_out] = ACTIONS(5587),
    [anon_sym_inout] = ACTIONS(5587),
    [anon_sym_extern] = ACTIONS(5587),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5589),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5589),
    [anon_sym___declspec] = ACTIONS(5587),
    [anon_sym___based] = ACTIONS(5587),
    [anon_sym___cdecl] = ACTIONS(5587),
    [anon_sym___clrcall] = ACTIONS(5587),
    [anon_sym___stdcall] = ACTIONS(5587),
    [anon_sym___fastcall] = ACTIONS(5587),
    [anon_sym___thiscall] = ACTIONS(5587),
    [anon_sym___vectorcall] = ACTIONS(5587),
    [anon_sym_LBRACK] = ACTIONS(5587),
    [anon_sym_static] = ACTIONS(5587),
    [anon_sym_EQ] = ACTIONS(5589),
    [anon_sym_register] = ACTIONS(5587),
    [anon_sym_inline] = ACTIONS(5587),
    [anon_sym___inline] = ACTIONS(5587),
    [anon_sym___inline__] = ACTIONS(5587),
    [anon_sym___forceinline] = ACTIONS(5587),
    [anon_sym_thread_local] = ACTIONS(5587),
    [anon_sym___thread] = ACTIONS(5587),
    [anon_sym_const] = ACTIONS(5587),
    [anon_sym_constexpr] = ACTIONS(5587),
    [anon_sym_volatile] = ACTIONS(5587),
    [anon_sym_restrict] = ACTIONS(5587),
    [anon_sym___restrict__] = ACTIONS(5587),
    [anon_sym__Atomic] = ACTIONS(5587),
    [anon_sym__Noreturn] = ACTIONS(5587),
    [anon_sym_noreturn] = ACTIONS(5587),
    [anon_sym_mutable] = ACTIONS(5587),
    [anon_sym_constinit] = ACTIONS(5587),
    [anon_sym_consteval] = ACTIONS(5587),
    [anon_sym_alignas] = ACTIONS(5587),
    [anon_sym__Alignas] = ACTIONS(5587),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5587),
    [anon_sym_decltype] = ACTIONS(5587),
    [sym_virtual] = ACTIONS(5587),
    [anon_sym_template] = ACTIONS(5587),
    [anon_sym_GT2] = ACTIONS(5589),
    [anon_sym_operator] = ACTIONS(5587),
    [anon_sym_precise] = ACTIONS(5587),
    [anon_sym_shared] = ACTIONS(5587),
    [anon_sym_groupshared] = ACTIONS(5587),
    [anon_sym_uniform] = ACTIONS(5587),
    [anon_sym_row_major] = ACTIONS(5587),
    [anon_sym_column_major] = ACTIONS(5587),
    [anon_sym_globallycoherent] = ACTIONS(5587),
    [anon_sym_centroid] = ACTIONS(5587),
    [anon_sym_noperspective] = ACTIONS(5587),
    [anon_sym_nointerpolation] = ACTIONS(5587),
    [anon_sym_sample] = ACTIONS(5587),
    [anon_sym_linear] = ACTIONS(5587),
    [anon_sym_snorm] = ACTIONS(5587),
    [anon_sym_unorm] = ACTIONS(5587),
    [anon_sym_point] = ACTIONS(5587),
    [anon_sym_line] = ACTIONS(5587),
    [anon_sym_triangleadj] = ACTIONS(5587),
    [anon_sym_lineadj] = ACTIONS(5587),
    [anon_sym_triangle] = ACTIONS(5587),
  },
  [2322] = {
    [sym_attribute_specifier] = STATE(2295),
    [sym_identifier] = ACTIONS(5591),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5593),
    [anon_sym_COMMA] = ACTIONS(5593),
    [anon_sym_RPAREN] = ACTIONS(5593),
    [anon_sym_LPAREN2] = ACTIONS(5593),
    [anon_sym_TILDE] = ACTIONS(5593),
    [anon_sym_STAR] = ACTIONS(5593),
    [anon_sym_AMP_AMP] = ACTIONS(5593),
    [anon_sym_AMP] = ACTIONS(5591),
    [anon_sym_COLON] = ACTIONS(5591),
    [anon_sym_SEMI] = ACTIONS(5593),
    [anon_sym___extension__] = ACTIONS(5591),
    [anon_sym_in] = ACTIONS(5591),
    [anon_sym_out] = ACTIONS(5591),
    [anon_sym_inout] = ACTIONS(5591),
    [anon_sym_extern] = ACTIONS(5591),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5593),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5593),
    [anon_sym___declspec] = ACTIONS(5591),
    [anon_sym___based] = ACTIONS(5591),
    [anon_sym___cdecl] = ACTIONS(5591),
    [anon_sym___clrcall] = ACTIONS(5591),
    [anon_sym___stdcall] = ACTIONS(5591),
    [anon_sym___fastcall] = ACTIONS(5591),
    [anon_sym___thiscall] = ACTIONS(5591),
    [anon_sym___vectorcall] = ACTIONS(5591),
    [anon_sym_LBRACK] = ACTIONS(5591),
    [anon_sym_static] = ACTIONS(5591),
    [anon_sym_EQ] = ACTIONS(5593),
    [anon_sym_register] = ACTIONS(5591),
    [anon_sym_inline] = ACTIONS(5591),
    [anon_sym___inline] = ACTIONS(5591),
    [anon_sym___inline__] = ACTIONS(5591),
    [anon_sym___forceinline] = ACTIONS(5591),
    [anon_sym_thread_local] = ACTIONS(5591),
    [anon_sym___thread] = ACTIONS(5591),
    [anon_sym_const] = ACTIONS(5591),
    [anon_sym_constexpr] = ACTIONS(5591),
    [anon_sym_volatile] = ACTIONS(5591),
    [anon_sym_restrict] = ACTIONS(5591),
    [anon_sym___restrict__] = ACTIONS(5591),
    [anon_sym__Atomic] = ACTIONS(5591),
    [anon_sym__Noreturn] = ACTIONS(5591),
    [anon_sym_noreturn] = ACTIONS(5591),
    [anon_sym_mutable] = ACTIONS(5591),
    [anon_sym_constinit] = ACTIONS(5591),
    [anon_sym_consteval] = ACTIONS(5591),
    [anon_sym_alignas] = ACTIONS(5591),
    [anon_sym__Alignas] = ACTIONS(5591),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5591),
    [anon_sym_decltype] = ACTIONS(5591),
    [sym_virtual] = ACTIONS(5591),
    [anon_sym_template] = ACTIONS(5591),
    [anon_sym_GT2] = ACTIONS(5593),
    [anon_sym_operator] = ACTIONS(5591),
    [anon_sym_precise] = ACTIONS(5591),
    [anon_sym_shared] = ACTIONS(5591),
    [anon_sym_groupshared] = ACTIONS(5591),
    [anon_sym_uniform] = ACTIONS(5591),
    [anon_sym_row_major] = ACTIONS(5591),
    [anon_sym_column_major] = ACTIONS(5591),
    [anon_sym_globallycoherent] = ACTIONS(5591),
    [anon_sym_centroid] = ACTIONS(5591),
    [anon_sym_noperspective] = ACTIONS(5591),
    [anon_sym_nointerpolation] = ACTIONS(5591),
    [anon_sym_sample] = ACTIONS(5591),
    [anon_sym_linear] = ACTIONS(5591),
    [anon_sym_snorm] = ACTIONS(5591),
    [anon_sym_unorm] = ACTIONS(5591),
    [anon_sym_point] = ACTIONS(5591),
    [anon_sym_line] = ACTIONS(5591),
    [anon_sym_triangleadj] = ACTIONS(5591),
    [anon_sym_lineadj] = ACTIONS(5591),
    [anon_sym_triangle] = ACTIONS(5591),
  },
  [2323] = {
    [sym_template_argument_list] = STATE(2221),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2233),
    [sym_identifier] = ACTIONS(3822),
    [anon_sym_LPAREN2] = ACTIONS(3830),
    [anon_sym_TILDE] = ACTIONS(3830),
    [anon_sym_STAR] = ACTIONS(3830),
    [anon_sym_AMP_AMP] = ACTIONS(3830),
    [anon_sym_AMP] = ACTIONS(3822),
    [anon_sym_LT] = ACTIONS(5298),
    [anon_sym_SEMI] = ACTIONS(1943),
    [anon_sym___extension__] = ACTIONS(3822),
    [anon_sym_in] = ACTIONS(3822),
    [anon_sym_out] = ACTIONS(3822),
    [anon_sym_inout] = ACTIONS(3822),
    [anon_sym_extern] = ACTIONS(3822),
    [anon_sym___attribute__] = ACTIONS(3822),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3830),
    [anon_sym___declspec] = ACTIONS(3822),
    [anon_sym___based] = ACTIONS(3822),
    [anon_sym___cdecl] = ACTIONS(3822),
    [anon_sym___clrcall] = ACTIONS(3822),
    [anon_sym___stdcall] = ACTIONS(3822),
    [anon_sym___fastcall] = ACTIONS(3822),
    [anon_sym___thiscall] = ACTIONS(3822),
    [anon_sym___vectorcall] = ACTIONS(3822),
    [anon_sym_signed] = ACTIONS(3848),
    [anon_sym_unsigned] = ACTIONS(3848),
    [anon_sym_long] = ACTIONS(3848),
    [anon_sym_short] = ACTIONS(3848),
    [anon_sym_LBRACK] = ACTIONS(3822),
    [anon_sym_static] = ACTIONS(3822),
    [anon_sym_register] = ACTIONS(3822),
    [anon_sym_inline] = ACTIONS(3822),
    [anon_sym___inline] = ACTIONS(3822),
    [anon_sym___inline__] = ACTIONS(3822),
    [anon_sym___forceinline] = ACTIONS(3822),
    [anon_sym_thread_local] = ACTIONS(3822),
    [anon_sym___thread] = ACTIONS(3822),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3822),
    [anon_sym_volatile] = ACTIONS(3822),
    [anon_sym_restrict] = ACTIONS(3822),
    [anon_sym___restrict__] = ACTIONS(3822),
    [anon_sym__Atomic] = ACTIONS(3822),
    [anon_sym__Noreturn] = ACTIONS(3822),
    [anon_sym_noreturn] = ACTIONS(3822),
    [anon_sym_mutable] = ACTIONS(3822),
    [anon_sym_constinit] = ACTIONS(3822),
    [anon_sym_consteval] = ACTIONS(3822),
    [anon_sym_alignas] = ACTIONS(3822),
    [anon_sym__Alignas] = ACTIONS(3822),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3822),
    [anon_sym_decltype] = ACTIONS(3822),
    [sym_virtual] = ACTIONS(3822),
    [anon_sym_template] = ACTIONS(3822),
    [anon_sym_operator] = ACTIONS(3822),
    [anon_sym_precise] = ACTIONS(3822),
    [anon_sym_shared] = ACTIONS(3822),
    [anon_sym_groupshared] = ACTIONS(3822),
    [anon_sym_uniform] = ACTIONS(3822),
    [anon_sym_row_major] = ACTIONS(3822),
    [anon_sym_column_major] = ACTIONS(3822),
    [anon_sym_globallycoherent] = ACTIONS(3822),
    [anon_sym_centroid] = ACTIONS(3822),
    [anon_sym_noperspective] = ACTIONS(3822),
    [anon_sym_nointerpolation] = ACTIONS(3822),
    [anon_sym_sample] = ACTIONS(3822),
    [anon_sym_linear] = ACTIONS(3822),
    [anon_sym_snorm] = ACTIONS(3822),
    [anon_sym_unorm] = ACTIONS(3822),
    [anon_sym_point] = ACTIONS(3822),
    [anon_sym_line] = ACTIONS(3822),
    [anon_sym_triangleadj] = ACTIONS(3822),
    [anon_sym_lineadj] = ACTIONS(3822),
    [anon_sym_triangle] = ACTIONS(3822),
  },
  [2324] = {
    [sym_attribute_specifier] = STATE(2282),
    [sym_identifier] = ACTIONS(5595),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5597),
    [anon_sym_COMMA] = ACTIONS(5597),
    [anon_sym_RPAREN] = ACTIONS(5597),
    [anon_sym_LPAREN2] = ACTIONS(5597),
    [anon_sym_TILDE] = ACTIONS(5597),
    [anon_sym_STAR] = ACTIONS(5597),
    [anon_sym_AMP_AMP] = ACTIONS(5597),
    [anon_sym_AMP] = ACTIONS(5595),
    [anon_sym_COLON] = ACTIONS(5595),
    [anon_sym_SEMI] = ACTIONS(5597),
    [anon_sym___extension__] = ACTIONS(5595),
    [anon_sym_in] = ACTIONS(5595),
    [anon_sym_out] = ACTIONS(5595),
    [anon_sym_inout] = ACTIONS(5595),
    [anon_sym_extern] = ACTIONS(5595),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5597),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5597),
    [anon_sym___declspec] = ACTIONS(5595),
    [anon_sym___based] = ACTIONS(5595),
    [anon_sym___cdecl] = ACTIONS(5595),
    [anon_sym___clrcall] = ACTIONS(5595),
    [anon_sym___stdcall] = ACTIONS(5595),
    [anon_sym___fastcall] = ACTIONS(5595),
    [anon_sym___thiscall] = ACTIONS(5595),
    [anon_sym___vectorcall] = ACTIONS(5595),
    [anon_sym_LBRACK] = ACTIONS(5595),
    [anon_sym_static] = ACTIONS(5595),
    [anon_sym_EQ] = ACTIONS(5597),
    [anon_sym_register] = ACTIONS(5595),
    [anon_sym_inline] = ACTIONS(5595),
    [anon_sym___inline] = ACTIONS(5595),
    [anon_sym___inline__] = ACTIONS(5595),
    [anon_sym___forceinline] = ACTIONS(5595),
    [anon_sym_thread_local] = ACTIONS(5595),
    [anon_sym___thread] = ACTIONS(5595),
    [anon_sym_const] = ACTIONS(5595),
    [anon_sym_constexpr] = ACTIONS(5595),
    [anon_sym_volatile] = ACTIONS(5595),
    [anon_sym_restrict] = ACTIONS(5595),
    [anon_sym___restrict__] = ACTIONS(5595),
    [anon_sym__Atomic] = ACTIONS(5595),
    [anon_sym__Noreturn] = ACTIONS(5595),
    [anon_sym_noreturn] = ACTIONS(5595),
    [anon_sym_mutable] = ACTIONS(5595),
    [anon_sym_constinit] = ACTIONS(5595),
    [anon_sym_consteval] = ACTIONS(5595),
    [anon_sym_alignas] = ACTIONS(5595),
    [anon_sym__Alignas] = ACTIONS(5595),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5595),
    [anon_sym_decltype] = ACTIONS(5595),
    [sym_virtual] = ACTIONS(5595),
    [anon_sym_template] = ACTIONS(5595),
    [anon_sym_GT2] = ACTIONS(5597),
    [anon_sym_operator] = ACTIONS(5595),
    [anon_sym_precise] = ACTIONS(5595),
    [anon_sym_shared] = ACTIONS(5595),
    [anon_sym_groupshared] = ACTIONS(5595),
    [anon_sym_uniform] = ACTIONS(5595),
    [anon_sym_row_major] = ACTIONS(5595),
    [anon_sym_column_major] = ACTIONS(5595),
    [anon_sym_globallycoherent] = ACTIONS(5595),
    [anon_sym_centroid] = ACTIONS(5595),
    [anon_sym_noperspective] = ACTIONS(5595),
    [anon_sym_nointerpolation] = ACTIONS(5595),
    [anon_sym_sample] = ACTIONS(5595),
    [anon_sym_linear] = ACTIONS(5595),
    [anon_sym_snorm] = ACTIONS(5595),
    [anon_sym_unorm] = ACTIONS(5595),
    [anon_sym_point] = ACTIONS(5595),
    [anon_sym_line] = ACTIONS(5595),
    [anon_sym_triangleadj] = ACTIONS(5595),
    [anon_sym_lineadj] = ACTIONS(5595),
    [anon_sym_triangle] = ACTIONS(5595),
  },
  [2325] = {
    [sym_attribute_specifier] = STATE(2287),
    [sym_identifier] = ACTIONS(5599),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5601),
    [anon_sym_COMMA] = ACTIONS(5601),
    [anon_sym_RPAREN] = ACTIONS(5601),
    [anon_sym_LPAREN2] = ACTIONS(5601),
    [anon_sym_TILDE] = ACTIONS(5601),
    [anon_sym_STAR] = ACTIONS(5601),
    [anon_sym_AMP_AMP] = ACTIONS(5601),
    [anon_sym_AMP] = ACTIONS(5599),
    [anon_sym_COLON] = ACTIONS(5599),
    [anon_sym_SEMI] = ACTIONS(5601),
    [anon_sym___extension__] = ACTIONS(5599),
    [anon_sym_in] = ACTIONS(5599),
    [anon_sym_out] = ACTIONS(5599),
    [anon_sym_inout] = ACTIONS(5599),
    [anon_sym_extern] = ACTIONS(5599),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5601),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5601),
    [anon_sym___declspec] = ACTIONS(5599),
    [anon_sym___based] = ACTIONS(5599),
    [anon_sym___cdecl] = ACTIONS(5599),
    [anon_sym___clrcall] = ACTIONS(5599),
    [anon_sym___stdcall] = ACTIONS(5599),
    [anon_sym___fastcall] = ACTIONS(5599),
    [anon_sym___thiscall] = ACTIONS(5599),
    [anon_sym___vectorcall] = ACTIONS(5599),
    [anon_sym_LBRACK] = ACTIONS(5599),
    [anon_sym_static] = ACTIONS(5599),
    [anon_sym_EQ] = ACTIONS(5601),
    [anon_sym_register] = ACTIONS(5599),
    [anon_sym_inline] = ACTIONS(5599),
    [anon_sym___inline] = ACTIONS(5599),
    [anon_sym___inline__] = ACTIONS(5599),
    [anon_sym___forceinline] = ACTIONS(5599),
    [anon_sym_thread_local] = ACTIONS(5599),
    [anon_sym___thread] = ACTIONS(5599),
    [anon_sym_const] = ACTIONS(5599),
    [anon_sym_constexpr] = ACTIONS(5599),
    [anon_sym_volatile] = ACTIONS(5599),
    [anon_sym_restrict] = ACTIONS(5599),
    [anon_sym___restrict__] = ACTIONS(5599),
    [anon_sym__Atomic] = ACTIONS(5599),
    [anon_sym__Noreturn] = ACTIONS(5599),
    [anon_sym_noreturn] = ACTIONS(5599),
    [anon_sym_mutable] = ACTIONS(5599),
    [anon_sym_constinit] = ACTIONS(5599),
    [anon_sym_consteval] = ACTIONS(5599),
    [anon_sym_alignas] = ACTIONS(5599),
    [anon_sym__Alignas] = ACTIONS(5599),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5599),
    [anon_sym_decltype] = ACTIONS(5599),
    [sym_virtual] = ACTIONS(5599),
    [anon_sym_template] = ACTIONS(5599),
    [anon_sym_GT2] = ACTIONS(5601),
    [anon_sym_operator] = ACTIONS(5599),
    [anon_sym_precise] = ACTIONS(5599),
    [anon_sym_shared] = ACTIONS(5599),
    [anon_sym_groupshared] = ACTIONS(5599),
    [anon_sym_uniform] = ACTIONS(5599),
    [anon_sym_row_major] = ACTIONS(5599),
    [anon_sym_column_major] = ACTIONS(5599),
    [anon_sym_globallycoherent] = ACTIONS(5599),
    [anon_sym_centroid] = ACTIONS(5599),
    [anon_sym_noperspective] = ACTIONS(5599),
    [anon_sym_nointerpolation] = ACTIONS(5599),
    [anon_sym_sample] = ACTIONS(5599),
    [anon_sym_linear] = ACTIONS(5599),
    [anon_sym_snorm] = ACTIONS(5599),
    [anon_sym_unorm] = ACTIONS(5599),
    [anon_sym_point] = ACTIONS(5599),
    [anon_sym_line] = ACTIONS(5599),
    [anon_sym_triangleadj] = ACTIONS(5599),
    [anon_sym_lineadj] = ACTIONS(5599),
    [anon_sym_triangle] = ACTIONS(5599),
  },
  [2326] = {
    [sym_template_argument_list] = STATE(2433),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2233),
    [sym_identifier] = ACTIONS(3822),
    [anon_sym_LPAREN2] = ACTIONS(3845),
    [anon_sym_TILDE] = ACTIONS(3830),
    [anon_sym_STAR] = ACTIONS(3830),
    [anon_sym_AMP_AMP] = ACTIONS(3830),
    [anon_sym_AMP] = ACTIONS(3822),
    [anon_sym_LT] = ACTIONS(5298),
    [anon_sym_SEMI] = ACTIONS(3830),
    [anon_sym___extension__] = ACTIONS(3822),
    [anon_sym_in] = ACTIONS(3822),
    [anon_sym_out] = ACTIONS(3822),
    [anon_sym_inout] = ACTIONS(3822),
    [anon_sym_extern] = ACTIONS(3822),
    [anon_sym___attribute__] = ACTIONS(3822),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3845),
    [anon_sym___declspec] = ACTIONS(3822),
    [anon_sym___based] = ACTIONS(3822),
    [anon_sym___cdecl] = ACTIONS(3822),
    [anon_sym___clrcall] = ACTIONS(3822),
    [anon_sym___stdcall] = ACTIONS(3822),
    [anon_sym___fastcall] = ACTIONS(3822),
    [anon_sym___thiscall] = ACTIONS(3822),
    [anon_sym___vectorcall] = ACTIONS(3822),
    [anon_sym_signed] = ACTIONS(3848),
    [anon_sym_unsigned] = ACTIONS(3848),
    [anon_sym_long] = ACTIONS(3848),
    [anon_sym_short] = ACTIONS(3848),
    [anon_sym_LBRACK] = ACTIONS(5603),
    [anon_sym_static] = ACTIONS(3822),
    [anon_sym_register] = ACTIONS(3822),
    [anon_sym_inline] = ACTIONS(3822),
    [anon_sym___inline] = ACTIONS(3822),
    [anon_sym___inline__] = ACTIONS(3822),
    [anon_sym___forceinline] = ACTIONS(3822),
    [anon_sym_thread_local] = ACTIONS(3822),
    [anon_sym___thread] = ACTIONS(3822),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3822),
    [anon_sym_volatile] = ACTIONS(3822),
    [anon_sym_restrict] = ACTIONS(3822),
    [anon_sym___restrict__] = ACTIONS(3822),
    [anon_sym__Atomic] = ACTIONS(3822),
    [anon_sym__Noreturn] = ACTIONS(3822),
    [anon_sym_noreturn] = ACTIONS(3822),
    [anon_sym_mutable] = ACTIONS(3822),
    [anon_sym_constinit] = ACTIONS(3822),
    [anon_sym_consteval] = ACTIONS(3822),
    [anon_sym_alignas] = ACTIONS(3822),
    [anon_sym__Alignas] = ACTIONS(3822),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3822),
    [anon_sym_decltype] = ACTIONS(3822),
    [sym_virtual] = ACTIONS(3822),
    [anon_sym_template] = ACTIONS(3822),
    [anon_sym_operator] = ACTIONS(3822),
    [anon_sym_precise] = ACTIONS(3822),
    [anon_sym_shared] = ACTIONS(3822),
    [anon_sym_groupshared] = ACTIONS(3822),
    [anon_sym_uniform] = ACTIONS(3822),
    [anon_sym_row_major] = ACTIONS(3822),
    [anon_sym_column_major] = ACTIONS(3822),
    [anon_sym_globallycoherent] = ACTIONS(3822),
    [anon_sym_centroid] = ACTIONS(3822),
    [anon_sym_noperspective] = ACTIONS(3822),
    [anon_sym_nointerpolation] = ACTIONS(3822),
    [anon_sym_sample] = ACTIONS(3822),
    [anon_sym_linear] = ACTIONS(3822),
    [anon_sym_snorm] = ACTIONS(3822),
    [anon_sym_unorm] = ACTIONS(3822),
    [anon_sym_point] = ACTIONS(3822),
    [anon_sym_line] = ACTIONS(3822),
    [anon_sym_triangleadj] = ACTIONS(3822),
    [anon_sym_lineadj] = ACTIONS(3822),
    [anon_sym_triangle] = ACTIONS(3822),
  },
  [2327] = {
    [sym_attribute_specifier] = STATE(2307),
    [sym_identifier] = ACTIONS(5606),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5608),
    [anon_sym_COMMA] = ACTIONS(5608),
    [anon_sym_RPAREN] = ACTIONS(5608),
    [anon_sym_LPAREN2] = ACTIONS(5608),
    [anon_sym_TILDE] = ACTIONS(5608),
    [anon_sym_STAR] = ACTIONS(5608),
    [anon_sym_AMP_AMP] = ACTIONS(5608),
    [anon_sym_AMP] = ACTIONS(5606),
    [anon_sym_COLON] = ACTIONS(5606),
    [anon_sym_SEMI] = ACTIONS(5608),
    [anon_sym___extension__] = ACTIONS(5606),
    [anon_sym_in] = ACTIONS(5606),
    [anon_sym_out] = ACTIONS(5606),
    [anon_sym_inout] = ACTIONS(5606),
    [anon_sym_extern] = ACTIONS(5606),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5608),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5608),
    [anon_sym___declspec] = ACTIONS(5606),
    [anon_sym___based] = ACTIONS(5606),
    [anon_sym___cdecl] = ACTIONS(5606),
    [anon_sym___clrcall] = ACTIONS(5606),
    [anon_sym___stdcall] = ACTIONS(5606),
    [anon_sym___fastcall] = ACTIONS(5606),
    [anon_sym___thiscall] = ACTIONS(5606),
    [anon_sym___vectorcall] = ACTIONS(5606),
    [anon_sym_LBRACK] = ACTIONS(5606),
    [anon_sym_static] = ACTIONS(5606),
    [anon_sym_EQ] = ACTIONS(5608),
    [anon_sym_register] = ACTIONS(5606),
    [anon_sym_inline] = ACTIONS(5606),
    [anon_sym___inline] = ACTIONS(5606),
    [anon_sym___inline__] = ACTIONS(5606),
    [anon_sym___forceinline] = ACTIONS(5606),
    [anon_sym_thread_local] = ACTIONS(5606),
    [anon_sym___thread] = ACTIONS(5606),
    [anon_sym_const] = ACTIONS(5606),
    [anon_sym_constexpr] = ACTIONS(5606),
    [anon_sym_volatile] = ACTIONS(5606),
    [anon_sym_restrict] = ACTIONS(5606),
    [anon_sym___restrict__] = ACTIONS(5606),
    [anon_sym__Atomic] = ACTIONS(5606),
    [anon_sym__Noreturn] = ACTIONS(5606),
    [anon_sym_noreturn] = ACTIONS(5606),
    [anon_sym_mutable] = ACTIONS(5606),
    [anon_sym_constinit] = ACTIONS(5606),
    [anon_sym_consteval] = ACTIONS(5606),
    [anon_sym_alignas] = ACTIONS(5606),
    [anon_sym__Alignas] = ACTIONS(5606),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5606),
    [anon_sym_decltype] = ACTIONS(5606),
    [sym_virtual] = ACTIONS(5606),
    [anon_sym_template] = ACTIONS(5606),
    [anon_sym_GT2] = ACTIONS(5608),
    [anon_sym_operator] = ACTIONS(5606),
    [anon_sym_precise] = ACTIONS(5606),
    [anon_sym_shared] = ACTIONS(5606),
    [anon_sym_groupshared] = ACTIONS(5606),
    [anon_sym_uniform] = ACTIONS(5606),
    [anon_sym_row_major] = ACTIONS(5606),
    [anon_sym_column_major] = ACTIONS(5606),
    [anon_sym_globallycoherent] = ACTIONS(5606),
    [anon_sym_centroid] = ACTIONS(5606),
    [anon_sym_noperspective] = ACTIONS(5606),
    [anon_sym_nointerpolation] = ACTIONS(5606),
    [anon_sym_sample] = ACTIONS(5606),
    [anon_sym_linear] = ACTIONS(5606),
    [anon_sym_snorm] = ACTIONS(5606),
    [anon_sym_unorm] = ACTIONS(5606),
    [anon_sym_point] = ACTIONS(5606),
    [anon_sym_line] = ACTIONS(5606),
    [anon_sym_triangleadj] = ACTIONS(5606),
    [anon_sym_lineadj] = ACTIONS(5606),
    [anon_sym_triangle] = ACTIONS(5606),
  },
  [2328] = {
    [sym_attribute_specifier] = STATE(2275),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5612),
    [anon_sym_COMMA] = ACTIONS(5612),
    [anon_sym_RPAREN] = ACTIONS(5612),
    [anon_sym_LPAREN2] = ACTIONS(5612),
    [anon_sym_TILDE] = ACTIONS(5612),
    [anon_sym_STAR] = ACTIONS(5612),
    [anon_sym_AMP_AMP] = ACTIONS(5612),
    [anon_sym_AMP] = ACTIONS(5610),
    [anon_sym_COLON] = ACTIONS(5610),
    [anon_sym_SEMI] = ACTIONS(5612),
    [anon_sym___extension__] = ACTIONS(5610),
    [anon_sym_in] = ACTIONS(5610),
    [anon_sym_out] = ACTIONS(5610),
    [anon_sym_inout] = ACTIONS(5610),
    [anon_sym_extern] = ACTIONS(5610),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5612),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5612),
    [anon_sym___declspec] = ACTIONS(5610),
    [anon_sym___based] = ACTIONS(5610),
    [anon_sym___cdecl] = ACTIONS(5610),
    [anon_sym___clrcall] = ACTIONS(5610),
    [anon_sym___stdcall] = ACTIONS(5610),
    [anon_sym___fastcall] = ACTIONS(5610),
    [anon_sym___thiscall] = ACTIONS(5610),
    [anon_sym___vectorcall] = ACTIONS(5610),
    [anon_sym_LBRACK] = ACTIONS(5610),
    [anon_sym_static] = ACTIONS(5610),
    [anon_sym_EQ] = ACTIONS(5612),
    [anon_sym_register] = ACTIONS(5610),
    [anon_sym_inline] = ACTIONS(5610),
    [anon_sym___inline] = ACTIONS(5610),
    [anon_sym___inline__] = ACTIONS(5610),
    [anon_sym___forceinline] = ACTIONS(5610),
    [anon_sym_thread_local] = ACTIONS(5610),
    [anon_sym___thread] = ACTIONS(5610),
    [anon_sym_const] = ACTIONS(5610),
    [anon_sym_constexpr] = ACTIONS(5610),
    [anon_sym_volatile] = ACTIONS(5610),
    [anon_sym_restrict] = ACTIONS(5610),
    [anon_sym___restrict__] = ACTIONS(5610),
    [anon_sym__Atomic] = ACTIONS(5610),
    [anon_sym__Noreturn] = ACTIONS(5610),
    [anon_sym_noreturn] = ACTIONS(5610),
    [anon_sym_mutable] = ACTIONS(5610),
    [anon_sym_constinit] = ACTIONS(5610),
    [anon_sym_consteval] = ACTIONS(5610),
    [anon_sym_alignas] = ACTIONS(5610),
    [anon_sym__Alignas] = ACTIONS(5610),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5610),
    [anon_sym_decltype] = ACTIONS(5610),
    [sym_virtual] = ACTIONS(5610),
    [anon_sym_template] = ACTIONS(5610),
    [anon_sym_GT2] = ACTIONS(5612),
    [anon_sym_operator] = ACTIONS(5610),
    [anon_sym_precise] = ACTIONS(5610),
    [anon_sym_shared] = ACTIONS(5610),
    [anon_sym_groupshared] = ACTIONS(5610),
    [anon_sym_uniform] = ACTIONS(5610),
    [anon_sym_row_major] = ACTIONS(5610),
    [anon_sym_column_major] = ACTIONS(5610),
    [anon_sym_globallycoherent] = ACTIONS(5610),
    [anon_sym_centroid] = ACTIONS(5610),
    [anon_sym_noperspective] = ACTIONS(5610),
    [anon_sym_nointerpolation] = ACTIONS(5610),
    [anon_sym_sample] = ACTIONS(5610),
    [anon_sym_linear] = ACTIONS(5610),
    [anon_sym_snorm] = ACTIONS(5610),
    [anon_sym_unorm] = ACTIONS(5610),
    [anon_sym_point] = ACTIONS(5610),
    [anon_sym_line] = ACTIONS(5610),
    [anon_sym_triangleadj] = ACTIONS(5610),
    [anon_sym_lineadj] = ACTIONS(5610),
    [anon_sym_triangle] = ACTIONS(5610),
  },
  [2329] = {
    [sym_attribute_specifier] = STATE(2290),
    [sym_identifier] = ACTIONS(5614),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5616),
    [anon_sym_COMMA] = ACTIONS(5616),
    [anon_sym_RPAREN] = ACTIONS(5616),
    [anon_sym_LPAREN2] = ACTIONS(5616),
    [anon_sym_TILDE] = ACTIONS(5616),
    [anon_sym_STAR] = ACTIONS(5616),
    [anon_sym_AMP_AMP] = ACTIONS(5616),
    [anon_sym_AMP] = ACTIONS(5614),
    [anon_sym_COLON] = ACTIONS(5614),
    [anon_sym_SEMI] = ACTIONS(5616),
    [anon_sym___extension__] = ACTIONS(5614),
    [anon_sym_in] = ACTIONS(5614),
    [anon_sym_out] = ACTIONS(5614),
    [anon_sym_inout] = ACTIONS(5614),
    [anon_sym_extern] = ACTIONS(5614),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5616),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5616),
    [anon_sym___declspec] = ACTIONS(5614),
    [anon_sym___based] = ACTIONS(5614),
    [anon_sym___cdecl] = ACTIONS(5614),
    [anon_sym___clrcall] = ACTIONS(5614),
    [anon_sym___stdcall] = ACTIONS(5614),
    [anon_sym___fastcall] = ACTIONS(5614),
    [anon_sym___thiscall] = ACTIONS(5614),
    [anon_sym___vectorcall] = ACTIONS(5614),
    [anon_sym_LBRACK] = ACTIONS(5614),
    [anon_sym_static] = ACTIONS(5614),
    [anon_sym_EQ] = ACTIONS(5616),
    [anon_sym_register] = ACTIONS(5614),
    [anon_sym_inline] = ACTIONS(5614),
    [anon_sym___inline] = ACTIONS(5614),
    [anon_sym___inline__] = ACTIONS(5614),
    [anon_sym___forceinline] = ACTIONS(5614),
    [anon_sym_thread_local] = ACTIONS(5614),
    [anon_sym___thread] = ACTIONS(5614),
    [anon_sym_const] = ACTIONS(5614),
    [anon_sym_constexpr] = ACTIONS(5614),
    [anon_sym_volatile] = ACTIONS(5614),
    [anon_sym_restrict] = ACTIONS(5614),
    [anon_sym___restrict__] = ACTIONS(5614),
    [anon_sym__Atomic] = ACTIONS(5614),
    [anon_sym__Noreturn] = ACTIONS(5614),
    [anon_sym_noreturn] = ACTIONS(5614),
    [anon_sym_mutable] = ACTIONS(5614),
    [anon_sym_constinit] = ACTIONS(5614),
    [anon_sym_consteval] = ACTIONS(5614),
    [anon_sym_alignas] = ACTIONS(5614),
    [anon_sym__Alignas] = ACTIONS(5614),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5614),
    [anon_sym_decltype] = ACTIONS(5614),
    [sym_virtual] = ACTIONS(5614),
    [anon_sym_template] = ACTIONS(5614),
    [anon_sym_GT2] = ACTIONS(5616),
    [anon_sym_operator] = ACTIONS(5614),
    [anon_sym_precise] = ACTIONS(5614),
    [anon_sym_shared] = ACTIONS(5614),
    [anon_sym_groupshared] = ACTIONS(5614),
    [anon_sym_uniform] = ACTIONS(5614),
    [anon_sym_row_major] = ACTIONS(5614),
    [anon_sym_column_major] = ACTIONS(5614),
    [anon_sym_globallycoherent] = ACTIONS(5614),
    [anon_sym_centroid] = ACTIONS(5614),
    [anon_sym_noperspective] = ACTIONS(5614),
    [anon_sym_nointerpolation] = ACTIONS(5614),
    [anon_sym_sample] = ACTIONS(5614),
    [anon_sym_linear] = ACTIONS(5614),
    [anon_sym_snorm] = ACTIONS(5614),
    [anon_sym_unorm] = ACTIONS(5614),
    [anon_sym_point] = ACTIONS(5614),
    [anon_sym_line] = ACTIONS(5614),
    [anon_sym_triangleadj] = ACTIONS(5614),
    [anon_sym_lineadj] = ACTIONS(5614),
    [anon_sym_triangle] = ACTIONS(5614),
  },
  [2330] = {
    [sym_identifier] = ACTIONS(5318),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5320),
    [anon_sym_COMMA] = ACTIONS(5320),
    [anon_sym_RPAREN] = ACTIONS(5320),
    [anon_sym_LPAREN2] = ACTIONS(5320),
    [anon_sym_TILDE] = ACTIONS(5320),
    [anon_sym_STAR] = ACTIONS(5320),
    [anon_sym_AMP_AMP] = ACTIONS(5320),
    [anon_sym_AMP] = ACTIONS(5318),
    [anon_sym_COLON] = ACTIONS(5318),
    [anon_sym_SEMI] = ACTIONS(5320),
    [anon_sym___extension__] = ACTIONS(5318),
    [anon_sym_in] = ACTIONS(5318),
    [anon_sym_out] = ACTIONS(5318),
    [anon_sym_inout] = ACTIONS(5318),
    [anon_sym_extern] = ACTIONS(5318),
    [anon_sym___attribute__] = ACTIONS(5318),
    [anon_sym_COLON_COLON] = ACTIONS(5320),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5320),
    [anon_sym___declspec] = ACTIONS(5318),
    [anon_sym___based] = ACTIONS(5318),
    [anon_sym___cdecl] = ACTIONS(5318),
    [anon_sym___clrcall] = ACTIONS(5318),
    [anon_sym___stdcall] = ACTIONS(5318),
    [anon_sym___fastcall] = ACTIONS(5318),
    [anon_sym___thiscall] = ACTIONS(5318),
    [anon_sym___vectorcall] = ACTIONS(5318),
    [anon_sym_LBRACE] = ACTIONS(1971),
    [anon_sym_LBRACK] = ACTIONS(5318),
    [anon_sym_static] = ACTIONS(5318),
    [anon_sym_EQ] = ACTIONS(5320),
    [anon_sym_register] = ACTIONS(5318),
    [anon_sym_inline] = ACTIONS(5318),
    [anon_sym___inline] = ACTIONS(5318),
    [anon_sym___inline__] = ACTIONS(5318),
    [anon_sym___forceinline] = ACTIONS(5318),
    [anon_sym_thread_local] = ACTIONS(5318),
    [anon_sym___thread] = ACTIONS(5318),
    [anon_sym_const] = ACTIONS(5318),
    [anon_sym_constexpr] = ACTIONS(5318),
    [anon_sym_volatile] = ACTIONS(5318),
    [anon_sym_restrict] = ACTIONS(5318),
    [anon_sym___restrict__] = ACTIONS(5318),
    [anon_sym__Atomic] = ACTIONS(5318),
    [anon_sym__Noreturn] = ACTIONS(5318),
    [anon_sym_noreturn] = ACTIONS(5318),
    [anon_sym_mutable] = ACTIONS(5318),
    [anon_sym_constinit] = ACTIONS(5318),
    [anon_sym_consteval] = ACTIONS(5318),
    [anon_sym_alignas] = ACTIONS(5318),
    [anon_sym__Alignas] = ACTIONS(5318),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5318),
    [anon_sym_decltype] = ACTIONS(5318),
    [sym_virtual] = ACTIONS(5318),
    [anon_sym_template] = ACTIONS(5318),
    [anon_sym_operator] = ACTIONS(5318),
    [anon_sym_precise] = ACTIONS(5318),
    [anon_sym_shared] = ACTIONS(5318),
    [anon_sym_groupshared] = ACTIONS(5318),
    [anon_sym_uniform] = ACTIONS(5318),
    [anon_sym_row_major] = ACTIONS(5318),
    [anon_sym_column_major] = ACTIONS(5318),
    [anon_sym_globallycoherent] = ACTIONS(5318),
    [anon_sym_centroid] = ACTIONS(5318),
    [anon_sym_noperspective] = ACTIONS(5318),
    [anon_sym_nointerpolation] = ACTIONS(5318),
    [anon_sym_sample] = ACTIONS(5318),
    [anon_sym_linear] = ACTIONS(5318),
    [anon_sym_snorm] = ACTIONS(5318),
    [anon_sym_unorm] = ACTIONS(5318),
    [anon_sym_point] = ACTIONS(5318),
    [anon_sym_line] = ACTIONS(5318),
    [anon_sym_triangleadj] = ACTIONS(5318),
    [anon_sym_lineadj] = ACTIONS(5318),
    [anon_sym_triangle] = ACTIONS(5318),
  },
  [2331] = {
    [sym_identifier] = ACTIONS(2849),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2851),
    [anon_sym_COMMA] = ACTIONS(2851),
    [anon_sym_RPAREN] = ACTIONS(2851),
    [anon_sym_LPAREN2] = ACTIONS(2851),
    [anon_sym_TILDE] = ACTIONS(2851),
    [anon_sym_STAR] = ACTIONS(2851),
    [anon_sym_AMP_AMP] = ACTIONS(2851),
    [anon_sym_AMP] = ACTIONS(2849),
    [anon_sym_COLON] = ACTIONS(2849),
    [anon_sym_SEMI] = ACTIONS(2851),
    [anon_sym___extension__] = ACTIONS(2849),
    [anon_sym_in] = ACTIONS(2849),
    [anon_sym_out] = ACTIONS(2849),
    [anon_sym_inout] = ACTIONS(2849),
    [anon_sym_extern] = ACTIONS(2849),
    [anon_sym___attribute__] = ACTIONS(2849),
    [anon_sym_COLON_COLON] = ACTIONS(2851),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2851),
    [anon_sym___declspec] = ACTIONS(2849),
    [anon_sym___based] = ACTIONS(2849),
    [anon_sym___cdecl] = ACTIONS(2849),
    [anon_sym___clrcall] = ACTIONS(2849),
    [anon_sym___stdcall] = ACTIONS(2849),
    [anon_sym___fastcall] = ACTIONS(2849),
    [anon_sym___thiscall] = ACTIONS(2849),
    [anon_sym___vectorcall] = ACTIONS(2849),
    [anon_sym_LBRACK] = ACTIONS(2849),
    [anon_sym_static] = ACTIONS(2849),
    [anon_sym_EQ] = ACTIONS(2851),
    [anon_sym_register] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2849),
    [anon_sym___inline] = ACTIONS(2849),
    [anon_sym___inline__] = ACTIONS(2849),
    [anon_sym___forceinline] = ACTIONS(2849),
    [anon_sym_thread_local] = ACTIONS(2849),
    [anon_sym___thread] = ACTIONS(2849),
    [anon_sym_const] = ACTIONS(2849),
    [anon_sym_constexpr] = ACTIONS(2849),
    [anon_sym_volatile] = ACTIONS(2849),
    [anon_sym_restrict] = ACTIONS(2849),
    [anon_sym___restrict__] = ACTIONS(2849),
    [anon_sym__Atomic] = ACTIONS(2849),
    [anon_sym__Noreturn] = ACTIONS(2849),
    [anon_sym_noreturn] = ACTIONS(2849),
    [anon_sym_mutable] = ACTIONS(2849),
    [anon_sym_constinit] = ACTIONS(2849),
    [anon_sym_consteval] = ACTIONS(2849),
    [anon_sym_alignas] = ACTIONS(2849),
    [anon_sym__Alignas] = ACTIONS(2849),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2849),
    [sym_virtual] = ACTIONS(2849),
    [anon_sym_explicit] = ACTIONS(2849),
    [anon_sym_template] = ACTIONS(2849),
    [anon_sym_GT2] = ACTIONS(2851),
    [anon_sym_operator] = ACTIONS(2849),
    [anon_sym_precise] = ACTIONS(2849),
    [anon_sym_shared] = ACTIONS(2849),
    [anon_sym_groupshared] = ACTIONS(2849),
    [anon_sym_uniform] = ACTIONS(2849),
    [anon_sym_row_major] = ACTIONS(2849),
    [anon_sym_column_major] = ACTIONS(2849),
    [anon_sym_globallycoherent] = ACTIONS(2849),
    [anon_sym_centroid] = ACTIONS(2849),
    [anon_sym_noperspective] = ACTIONS(2849),
    [anon_sym_nointerpolation] = ACTIONS(2849),
    [anon_sym_sample] = ACTIONS(2849),
    [anon_sym_linear] = ACTIONS(2849),
    [anon_sym_snorm] = ACTIONS(2849),
    [anon_sym_unorm] = ACTIONS(2849),
    [anon_sym_point] = ACTIONS(2849),
    [anon_sym_line] = ACTIONS(2849),
    [anon_sym_triangleadj] = ACTIONS(2849),
    [anon_sym_lineadj] = ACTIONS(2849),
    [anon_sym_triangle] = ACTIONS(2849),
  },
  [2332] = {
    [sym_identifier] = ACTIONS(5618),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5620),
    [anon_sym_COMMA] = ACTIONS(5620),
    [anon_sym_RPAREN] = ACTIONS(5620),
    [anon_sym_LPAREN2] = ACTIONS(5620),
    [anon_sym_TILDE] = ACTIONS(5620),
    [anon_sym_STAR] = ACTIONS(5620),
    [anon_sym_AMP_AMP] = ACTIONS(5620),
    [anon_sym_AMP] = ACTIONS(5618),
    [anon_sym_COLON] = ACTIONS(5618),
    [anon_sym_SEMI] = ACTIONS(5620),
    [anon_sym___extension__] = ACTIONS(5618),
    [anon_sym_in] = ACTIONS(5618),
    [anon_sym_out] = ACTIONS(5618),
    [anon_sym_inout] = ACTIONS(5618),
    [anon_sym_extern] = ACTIONS(5618),
    [anon_sym___attribute__] = ACTIONS(5618),
    [anon_sym_COLON_COLON] = ACTIONS(5620),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5620),
    [anon_sym___declspec] = ACTIONS(5618),
    [anon_sym___based] = ACTIONS(5618),
    [anon_sym___cdecl] = ACTIONS(5618),
    [anon_sym___clrcall] = ACTIONS(5618),
    [anon_sym___stdcall] = ACTIONS(5618),
    [anon_sym___fastcall] = ACTIONS(5618),
    [anon_sym___thiscall] = ACTIONS(5618),
    [anon_sym___vectorcall] = ACTIONS(5618),
    [anon_sym_LBRACK] = ACTIONS(5618),
    [anon_sym_static] = ACTIONS(5618),
    [anon_sym_EQ] = ACTIONS(5620),
    [anon_sym_register] = ACTIONS(5618),
    [anon_sym_inline] = ACTIONS(5618),
    [anon_sym___inline] = ACTIONS(5618),
    [anon_sym___inline__] = ACTIONS(5618),
    [anon_sym___forceinline] = ACTIONS(5618),
    [anon_sym_thread_local] = ACTIONS(5618),
    [anon_sym___thread] = ACTIONS(5618),
    [anon_sym_const] = ACTIONS(5618),
    [anon_sym_constexpr] = ACTIONS(5618),
    [anon_sym_volatile] = ACTIONS(5618),
    [anon_sym_restrict] = ACTIONS(5618),
    [anon_sym___restrict__] = ACTIONS(5618),
    [anon_sym__Atomic] = ACTIONS(5618),
    [anon_sym__Noreturn] = ACTIONS(5618),
    [anon_sym_noreturn] = ACTIONS(5618),
    [anon_sym_mutable] = ACTIONS(5618),
    [anon_sym_constinit] = ACTIONS(5618),
    [anon_sym_consteval] = ACTIONS(5618),
    [anon_sym_alignas] = ACTIONS(5618),
    [anon_sym__Alignas] = ACTIONS(5618),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(5618),
    [sym_virtual] = ACTIONS(5618),
    [anon_sym_explicit] = ACTIONS(5618),
    [anon_sym_template] = ACTIONS(5618),
    [anon_sym_GT2] = ACTIONS(5620),
    [anon_sym_operator] = ACTIONS(5618),
    [anon_sym_precise] = ACTIONS(5618),
    [anon_sym_shared] = ACTIONS(5618),
    [anon_sym_groupshared] = ACTIONS(5618),
    [anon_sym_uniform] = ACTIONS(5618),
    [anon_sym_row_major] = ACTIONS(5618),
    [anon_sym_column_major] = ACTIONS(5618),
    [anon_sym_globallycoherent] = ACTIONS(5618),
    [anon_sym_centroid] = ACTIONS(5618),
    [anon_sym_noperspective] = ACTIONS(5618),
    [anon_sym_nointerpolation] = ACTIONS(5618),
    [anon_sym_sample] = ACTIONS(5618),
    [anon_sym_linear] = ACTIONS(5618),
    [anon_sym_snorm] = ACTIONS(5618),
    [anon_sym_unorm] = ACTIONS(5618),
    [anon_sym_point] = ACTIONS(5618),
    [anon_sym_line] = ACTIONS(5618),
    [anon_sym_triangleadj] = ACTIONS(5618),
    [anon_sym_lineadj] = ACTIONS(5618),
    [anon_sym_triangle] = ACTIONS(5618),
  },
  [2333] = {
    [sym_string_literal] = STATE(2344),
    [sym_template_argument_list] = STATE(2687),
    [sym_raw_string_literal] = STATE(2344),
    [sym_identifier] = ACTIONS(3832),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_RPAREN] = ACTIONS(3824),
    [aux_sym_preproc_if_token2] = ACTIONS(3824),
    [aux_sym_preproc_else_token1] = ACTIONS(3824),
    [aux_sym_preproc_elif_token1] = ACTIONS(3832),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(3824),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3824),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5622),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON] = ACTIONS(3832),
    [anon_sym_SEMI] = ACTIONS(3824),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_RBRACE] = ACTIONS(3824),
    [anon_sym_LBRACK] = ACTIONS(3824),
    [anon_sym_RBRACK] = ACTIONS(3824),
    [anon_sym_EQ] = ACTIONS(3832),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3824),
    [anon_sym_SLASH_EQ] = ACTIONS(3824),
    [anon_sym_PERCENT_EQ] = ACTIONS(3824),
    [anon_sym_PLUS_EQ] = ACTIONS(3824),
    [anon_sym_DASH_EQ] = ACTIONS(3824),
    [anon_sym_LT_LT_EQ] = ACTIONS(3824),
    [anon_sym_GT_GT_EQ] = ACTIONS(3824),
    [anon_sym_AMP_EQ] = ACTIONS(3824),
    [anon_sym_CARET_EQ] = ACTIONS(3824),
    [anon_sym_PIPE_EQ] = ACTIONS(3824),
    [anon_sym_and_eq] = ACTIONS(3832),
    [anon_sym_or_eq] = ACTIONS(3832),
    [anon_sym_xor_eq] = ACTIONS(3832),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3832),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3832),
    [anon_sym_not_eq] = ACTIONS(3832),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
  },
  [2334] = {
    [sym_identifier] = ACTIONS(5397),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5399),
    [anon_sym_COMMA] = ACTIONS(5399),
    [anon_sym_RPAREN] = ACTIONS(5399),
    [anon_sym_LPAREN2] = ACTIONS(5399),
    [anon_sym_TILDE] = ACTIONS(5399),
    [anon_sym_STAR] = ACTIONS(5399),
    [anon_sym_AMP_AMP] = ACTIONS(5399),
    [anon_sym_AMP] = ACTIONS(5397),
    [anon_sym_COLON] = ACTIONS(5397),
    [anon_sym_SEMI] = ACTIONS(5399),
    [anon_sym___extension__] = ACTIONS(5397),
    [anon_sym_in] = ACTIONS(5397),
    [anon_sym_out] = ACTIONS(5397),
    [anon_sym_inout] = ACTIONS(5397),
    [anon_sym_extern] = ACTIONS(5397),
    [anon_sym___attribute__] = ACTIONS(5397),
    [anon_sym_COLON_COLON] = ACTIONS(5399),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5399),
    [anon_sym___declspec] = ACTIONS(5397),
    [anon_sym___based] = ACTIONS(5397),
    [anon_sym___cdecl] = ACTIONS(5397),
    [anon_sym___clrcall] = ACTIONS(5397),
    [anon_sym___stdcall] = ACTIONS(5397),
    [anon_sym___fastcall] = ACTIONS(5397),
    [anon_sym___thiscall] = ACTIONS(5397),
    [anon_sym___vectorcall] = ACTIONS(5397),
    [anon_sym_LBRACK] = ACTIONS(5397),
    [anon_sym_static] = ACTIONS(5397),
    [anon_sym_EQ] = ACTIONS(5399),
    [anon_sym_register] = ACTIONS(5397),
    [anon_sym_inline] = ACTIONS(5397),
    [anon_sym___inline] = ACTIONS(5397),
    [anon_sym___inline__] = ACTIONS(5397),
    [anon_sym___forceinline] = ACTIONS(5397),
    [anon_sym_thread_local] = ACTIONS(5397),
    [anon_sym___thread] = ACTIONS(5397),
    [anon_sym_const] = ACTIONS(5397),
    [anon_sym_constexpr] = ACTIONS(5397),
    [anon_sym_volatile] = ACTIONS(5397),
    [anon_sym_restrict] = ACTIONS(5397),
    [anon_sym___restrict__] = ACTIONS(5397),
    [anon_sym__Atomic] = ACTIONS(5397),
    [anon_sym__Noreturn] = ACTIONS(5397),
    [anon_sym_noreturn] = ACTIONS(5397),
    [anon_sym_mutable] = ACTIONS(5397),
    [anon_sym_constinit] = ACTIONS(5397),
    [anon_sym_consteval] = ACTIONS(5397),
    [anon_sym_alignas] = ACTIONS(5397),
    [anon_sym__Alignas] = ACTIONS(5397),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(5397),
    [sym_virtual] = ACTIONS(5397),
    [anon_sym_explicit] = ACTIONS(5397),
    [anon_sym_template] = ACTIONS(5397),
    [anon_sym_GT2] = ACTIONS(5399),
    [anon_sym_operator] = ACTIONS(5397),
    [anon_sym_precise] = ACTIONS(5397),
    [anon_sym_shared] = ACTIONS(5397),
    [anon_sym_groupshared] = ACTIONS(5397),
    [anon_sym_uniform] = ACTIONS(5397),
    [anon_sym_row_major] = ACTIONS(5397),
    [anon_sym_column_major] = ACTIONS(5397),
    [anon_sym_globallycoherent] = ACTIONS(5397),
    [anon_sym_centroid] = ACTIONS(5397),
    [anon_sym_noperspective] = ACTIONS(5397),
    [anon_sym_nointerpolation] = ACTIONS(5397),
    [anon_sym_sample] = ACTIONS(5397),
    [anon_sym_linear] = ACTIONS(5397),
    [anon_sym_snorm] = ACTIONS(5397),
    [anon_sym_unorm] = ACTIONS(5397),
    [anon_sym_point] = ACTIONS(5397),
    [anon_sym_line] = ACTIONS(5397),
    [anon_sym_triangleadj] = ACTIONS(5397),
    [anon_sym_lineadj] = ACTIONS(5397),
    [anon_sym_triangle] = ACTIONS(5397),
  },
  [2335] = {
    [sym_argument_list] = STATE(3570),
    [sym_initializer_list] = STATE(3855),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2240),
    [sym_identifier] = ACTIONS(5318),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5320),
    [anon_sym_COMMA] = ACTIONS(5320),
    [anon_sym_RPAREN] = ACTIONS(5320),
    [anon_sym_LPAREN2] = ACTIONS(5625),
    [anon_sym_TILDE] = ACTIONS(5320),
    [anon_sym_STAR] = ACTIONS(5320),
    [anon_sym_AMP_AMP] = ACTIONS(5320),
    [anon_sym_AMP] = ACTIONS(5318),
    [anon_sym_COLON] = ACTIONS(5318),
    [anon_sym___extension__] = ACTIONS(5318),
    [anon_sym_in] = ACTIONS(5318),
    [anon_sym_out] = ACTIONS(5318),
    [anon_sym_inout] = ACTIONS(5318),
    [anon_sym_extern] = ACTIONS(5318),
    [anon_sym___attribute__] = ACTIONS(5318),
    [anon_sym_COLON_COLON] = ACTIONS(5320),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5320),
    [anon_sym___declspec] = ACTIONS(5318),
    [anon_sym___based] = ACTIONS(5318),
    [anon_sym_LBRACE] = ACTIONS(3741),
    [anon_sym_signed] = ACTIONS(5325),
    [anon_sym_unsigned] = ACTIONS(5325),
    [anon_sym_long] = ACTIONS(5325),
    [anon_sym_short] = ACTIONS(5325),
    [anon_sym_LBRACK] = ACTIONS(5318),
    [anon_sym_static] = ACTIONS(5318),
    [anon_sym_EQ] = ACTIONS(5320),
    [anon_sym_register] = ACTIONS(5318),
    [anon_sym_inline] = ACTIONS(5318),
    [anon_sym___inline] = ACTIONS(5318),
    [anon_sym___inline__] = ACTIONS(5318),
    [anon_sym___forceinline] = ACTIONS(5318),
    [anon_sym_thread_local] = ACTIONS(5318),
    [anon_sym___thread] = ACTIONS(5318),
    [anon_sym_const] = ACTIONS(5318),
    [anon_sym_constexpr] = ACTIONS(5318),
    [anon_sym_volatile] = ACTIONS(5318),
    [anon_sym_restrict] = ACTIONS(5318),
    [anon_sym___restrict__] = ACTIONS(5318),
    [anon_sym__Atomic] = ACTIONS(5318),
    [anon_sym__Noreturn] = ACTIONS(5318),
    [anon_sym_noreturn] = ACTIONS(5318),
    [anon_sym_mutable] = ACTIONS(5318),
    [anon_sym_constinit] = ACTIONS(5318),
    [anon_sym_consteval] = ACTIONS(5318),
    [anon_sym_alignas] = ACTIONS(5318),
    [anon_sym__Alignas] = ACTIONS(5318),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5318),
    [anon_sym_decltype] = ACTIONS(5318),
    [sym_virtual] = ACTIONS(5318),
    [anon_sym_template] = ACTIONS(5318),
    [anon_sym_operator] = ACTIONS(5318),
    [anon_sym_precise] = ACTIONS(5318),
    [anon_sym_shared] = ACTIONS(5318),
    [anon_sym_groupshared] = ACTIONS(5318),
    [anon_sym_uniform] = ACTIONS(5318),
    [anon_sym_row_major] = ACTIONS(5318),
    [anon_sym_column_major] = ACTIONS(5318),
    [anon_sym_globallycoherent] = ACTIONS(5318),
    [anon_sym_centroid] = ACTIONS(5318),
    [anon_sym_noperspective] = ACTIONS(5318),
    [anon_sym_nointerpolation] = ACTIONS(5318),
    [anon_sym_sample] = ACTIONS(5318),
    [anon_sym_linear] = ACTIONS(5318),
    [anon_sym_snorm] = ACTIONS(5318),
    [anon_sym_unorm] = ACTIONS(5318),
    [anon_sym_point] = ACTIONS(5318),
    [anon_sym_line] = ACTIONS(5318),
    [anon_sym_triangleadj] = ACTIONS(5318),
    [anon_sym_lineadj] = ACTIONS(5318),
    [anon_sym_triangle] = ACTIONS(5318),
  },
  [2336] = {
    [sym_identifier] = ACTIONS(5318),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5320),
    [anon_sym_COMMA] = ACTIONS(5320),
    [anon_sym_RPAREN] = ACTIONS(5320),
    [anon_sym_LPAREN2] = ACTIONS(5320),
    [anon_sym_TILDE] = ACTIONS(5320),
    [anon_sym_STAR] = ACTIONS(5320),
    [anon_sym_AMP_AMP] = ACTIONS(5320),
    [anon_sym_AMP] = ACTIONS(5318),
    [anon_sym_COLON] = ACTIONS(5318),
    [anon_sym_SEMI] = ACTIONS(5320),
    [anon_sym___extension__] = ACTIONS(5318),
    [anon_sym_in] = ACTIONS(5318),
    [anon_sym_out] = ACTIONS(5318),
    [anon_sym_inout] = ACTIONS(5318),
    [anon_sym_extern] = ACTIONS(5318),
    [anon_sym___attribute__] = ACTIONS(5318),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5320),
    [anon_sym___declspec] = ACTIONS(5318),
    [anon_sym___based] = ACTIONS(5318),
    [anon_sym___cdecl] = ACTIONS(5318),
    [anon_sym___clrcall] = ACTIONS(5318),
    [anon_sym___stdcall] = ACTIONS(5318),
    [anon_sym___fastcall] = ACTIONS(5318),
    [anon_sym___thiscall] = ACTIONS(5318),
    [anon_sym___vectorcall] = ACTIONS(5318),
    [anon_sym_LBRACE] = ACTIONS(1971),
    [anon_sym_LBRACK] = ACTIONS(5318),
    [anon_sym_static] = ACTIONS(5318),
    [anon_sym_EQ] = ACTIONS(5320),
    [anon_sym_register] = ACTIONS(5318),
    [anon_sym_inline] = ACTIONS(5318),
    [anon_sym___inline] = ACTIONS(5318),
    [anon_sym___inline__] = ACTIONS(5318),
    [anon_sym___forceinline] = ACTIONS(5318),
    [anon_sym_thread_local] = ACTIONS(5318),
    [anon_sym___thread] = ACTIONS(5318),
    [anon_sym_const] = ACTIONS(5318),
    [anon_sym_constexpr] = ACTIONS(5318),
    [anon_sym_volatile] = ACTIONS(5318),
    [anon_sym_restrict] = ACTIONS(5318),
    [anon_sym___restrict__] = ACTIONS(5318),
    [anon_sym__Atomic] = ACTIONS(5318),
    [anon_sym__Noreturn] = ACTIONS(5318),
    [anon_sym_noreturn] = ACTIONS(5318),
    [anon_sym_mutable] = ACTIONS(5318),
    [anon_sym_constinit] = ACTIONS(5318),
    [anon_sym_consteval] = ACTIONS(5318),
    [anon_sym_alignas] = ACTIONS(5318),
    [anon_sym__Alignas] = ACTIONS(5318),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5318),
    [anon_sym_decltype] = ACTIONS(5318),
    [sym_virtual] = ACTIONS(5318),
    [anon_sym_template] = ACTIONS(5318),
    [anon_sym_operator] = ACTIONS(5318),
    [anon_sym_precise] = ACTIONS(5318),
    [anon_sym_shared] = ACTIONS(5318),
    [anon_sym_groupshared] = ACTIONS(5318),
    [anon_sym_uniform] = ACTIONS(5318),
    [anon_sym_row_major] = ACTIONS(5318),
    [anon_sym_column_major] = ACTIONS(5318),
    [anon_sym_globallycoherent] = ACTIONS(5318),
    [anon_sym_centroid] = ACTIONS(5318),
    [anon_sym_noperspective] = ACTIONS(5318),
    [anon_sym_nointerpolation] = ACTIONS(5318),
    [anon_sym_sample] = ACTIONS(5318),
    [anon_sym_linear] = ACTIONS(5318),
    [anon_sym_snorm] = ACTIONS(5318),
    [anon_sym_unorm] = ACTIONS(5318),
    [anon_sym_point] = ACTIONS(5318),
    [anon_sym_line] = ACTIONS(5318),
    [anon_sym_triangleadj] = ACTIONS(5318),
    [anon_sym_lineadj] = ACTIONS(5318),
    [anon_sym_triangle] = ACTIONS(5318),
  },
  [2337] = {
    [sym_template_argument_list] = STATE(2221),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2233),
    [sym_identifier] = ACTIONS(3822),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3830),
    [anon_sym_COMMA] = ACTIONS(3830),
    [anon_sym_RPAREN] = ACTIONS(3830),
    [anon_sym_LPAREN2] = ACTIONS(3830),
    [anon_sym_TILDE] = ACTIONS(3830),
    [anon_sym_STAR] = ACTIONS(3830),
    [anon_sym_AMP_AMP] = ACTIONS(3830),
    [anon_sym_AMP] = ACTIONS(3822),
    [anon_sym_LT] = ACTIONS(5628),
    [anon_sym_COLON] = ACTIONS(3822),
    [anon_sym___extension__] = ACTIONS(3822),
    [anon_sym_in] = ACTIONS(3822),
    [anon_sym_out] = ACTIONS(3822),
    [anon_sym_inout] = ACTIONS(3822),
    [anon_sym_extern] = ACTIONS(3822),
    [anon_sym___attribute__] = ACTIONS(3822),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3830),
    [anon_sym___declspec] = ACTIONS(3822),
    [anon_sym___based] = ACTIONS(3822),
    [anon_sym_signed] = ACTIONS(3848),
    [anon_sym_unsigned] = ACTIONS(3848),
    [anon_sym_long] = ACTIONS(3848),
    [anon_sym_short] = ACTIONS(3848),
    [anon_sym_LBRACK] = ACTIONS(3822),
    [anon_sym_static] = ACTIONS(3822),
    [anon_sym_EQ] = ACTIONS(3830),
    [anon_sym_register] = ACTIONS(3822),
    [anon_sym_inline] = ACTIONS(3822),
    [anon_sym___inline] = ACTIONS(3822),
    [anon_sym___inline__] = ACTIONS(3822),
    [anon_sym___forceinline] = ACTIONS(3822),
    [anon_sym_thread_local] = ACTIONS(3822),
    [anon_sym___thread] = ACTIONS(3822),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3822),
    [anon_sym_volatile] = ACTIONS(3822),
    [anon_sym_restrict] = ACTIONS(3822),
    [anon_sym___restrict__] = ACTIONS(3822),
    [anon_sym__Atomic] = ACTIONS(3822),
    [anon_sym__Noreturn] = ACTIONS(3822),
    [anon_sym_noreturn] = ACTIONS(3822),
    [anon_sym_mutable] = ACTIONS(3822),
    [anon_sym_constinit] = ACTIONS(3822),
    [anon_sym_consteval] = ACTIONS(3822),
    [anon_sym_alignas] = ACTIONS(3822),
    [anon_sym__Alignas] = ACTIONS(3822),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3822),
    [anon_sym_decltype] = ACTIONS(3822),
    [sym_virtual] = ACTIONS(3822),
    [anon_sym_template] = ACTIONS(3822),
    [anon_sym_GT2] = ACTIONS(3830),
    [anon_sym_operator] = ACTIONS(3822),
    [anon_sym_precise] = ACTIONS(3822),
    [anon_sym_shared] = ACTIONS(3822),
    [anon_sym_groupshared] = ACTIONS(3822),
    [anon_sym_uniform] = ACTIONS(3822),
    [anon_sym_row_major] = ACTIONS(3822),
    [anon_sym_column_major] = ACTIONS(3822),
    [anon_sym_globallycoherent] = ACTIONS(3822),
    [anon_sym_centroid] = ACTIONS(3822),
    [anon_sym_noperspective] = ACTIONS(3822),
    [anon_sym_nointerpolation] = ACTIONS(3822),
    [anon_sym_sample] = ACTIONS(3822),
    [anon_sym_linear] = ACTIONS(3822),
    [anon_sym_snorm] = ACTIONS(3822),
    [anon_sym_unorm] = ACTIONS(3822),
    [anon_sym_point] = ACTIONS(3822),
    [anon_sym_line] = ACTIONS(3822),
    [anon_sym_triangleadj] = ACTIONS(3822),
    [anon_sym_lineadj] = ACTIONS(3822),
    [anon_sym_triangle] = ACTIONS(3822),
  },
  [2338] = {
    [sym_identifier] = ACTIONS(5397),
    [anon_sym_LPAREN2] = ACTIONS(5399),
    [anon_sym_TILDE] = ACTIONS(5399),
    [anon_sym_STAR] = ACTIONS(5399),
    [anon_sym_AMP_AMP] = ACTIONS(5399),
    [anon_sym_AMP] = ACTIONS(5397),
    [anon_sym___extension__] = ACTIONS(5397),
    [anon_sym_in] = ACTIONS(5397),
    [anon_sym_out] = ACTIONS(5397),
    [anon_sym_inout] = ACTIONS(5397),
    [anon_sym_extern] = ACTIONS(5397),
    [anon_sym___attribute__] = ACTIONS(5397),
    [anon_sym_COLON_COLON] = ACTIONS(5399),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5399),
    [anon_sym___declspec] = ACTIONS(5397),
    [anon_sym___based] = ACTIONS(5397),
    [anon_sym_signed] = ACTIONS(5397),
    [anon_sym_unsigned] = ACTIONS(5397),
    [anon_sym_long] = ACTIONS(5397),
    [anon_sym_short] = ACTIONS(5397),
    [anon_sym_LBRACK] = ACTIONS(5397),
    [anon_sym_static] = ACTIONS(5397),
    [anon_sym_register] = ACTIONS(5397),
    [anon_sym_inline] = ACTIONS(5397),
    [anon_sym___inline] = ACTIONS(5397),
    [anon_sym___inline__] = ACTIONS(5397),
    [anon_sym___forceinline] = ACTIONS(5397),
    [anon_sym_thread_local] = ACTIONS(5397),
    [anon_sym___thread] = ACTIONS(5397),
    [anon_sym_const] = ACTIONS(5397),
    [anon_sym_constexpr] = ACTIONS(5397),
    [anon_sym_volatile] = ACTIONS(5397),
    [anon_sym_restrict] = ACTIONS(5397),
    [anon_sym___restrict__] = ACTIONS(5397),
    [anon_sym__Atomic] = ACTIONS(5397),
    [anon_sym__Noreturn] = ACTIONS(5397),
    [anon_sym_noreturn] = ACTIONS(5397),
    [anon_sym_mutable] = ACTIONS(5397),
    [anon_sym_constinit] = ACTIONS(5397),
    [anon_sym_consteval] = ACTIONS(5397),
    [anon_sym_alignas] = ACTIONS(5397),
    [anon_sym__Alignas] = ACTIONS(5397),
    [sym_primitive_type] = ACTIONS(5397),
    [anon_sym_enum] = ACTIONS(5397),
    [anon_sym_class] = ACTIONS(5397),
    [anon_sym_struct] = ACTIONS(5397),
    [anon_sym_union] = ACTIONS(5397),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5397),
    [anon_sym_decltype] = ACTIONS(5397),
    [sym_virtual] = ACTIONS(5397),
    [anon_sym_explicit] = ACTIONS(5397),
    [anon_sym_typename] = ACTIONS(5397),
    [anon_sym_template] = ACTIONS(5397),
    [anon_sym_operator] = ACTIONS(5397),
    [anon_sym_namespace] = ACTIONS(5630),
    [anon_sym_precise] = ACTIONS(5397),
    [anon_sym_shared] = ACTIONS(5397),
    [anon_sym_groupshared] = ACTIONS(5397),
    [anon_sym_uniform] = ACTIONS(5397),
    [anon_sym_row_major] = ACTIONS(5397),
    [anon_sym_column_major] = ACTIONS(5397),
    [anon_sym_globallycoherent] = ACTIONS(5397),
    [anon_sym_centroid] = ACTIONS(5397),
    [anon_sym_noperspective] = ACTIONS(5397),
    [anon_sym_nointerpolation] = ACTIONS(5397),
    [anon_sym_sample] = ACTIONS(5397),
    [anon_sym_linear] = ACTIONS(5397),
    [anon_sym_snorm] = ACTIONS(5397),
    [anon_sym_unorm] = ACTIONS(5397),
    [anon_sym_point] = ACTIONS(5397),
    [anon_sym_line] = ACTIONS(5397),
    [anon_sym_triangleadj] = ACTIONS(5397),
    [anon_sym_lineadj] = ACTIONS(5397),
    [anon_sym_triangle] = ACTIONS(5397),
  },
  [2339] = {
    [sym_identifier] = ACTIONS(5397),
    [anon_sym_LPAREN2] = ACTIONS(5399),
    [anon_sym_TILDE] = ACTIONS(5399),
    [anon_sym_STAR] = ACTIONS(5399),
    [anon_sym_AMP_AMP] = ACTIONS(5399),
    [anon_sym_AMP] = ACTIONS(5397),
    [anon_sym___extension__] = ACTIONS(5397),
    [anon_sym_in] = ACTIONS(5397),
    [anon_sym_out] = ACTIONS(5397),
    [anon_sym_inout] = ACTIONS(5397),
    [anon_sym_extern] = ACTIONS(5397),
    [anon_sym___attribute__] = ACTIONS(5397),
    [anon_sym_COLON_COLON] = ACTIONS(5399),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5399),
    [anon_sym___declspec] = ACTIONS(5397),
    [anon_sym___based] = ACTIONS(5397),
    [anon_sym_signed] = ACTIONS(5397),
    [anon_sym_unsigned] = ACTIONS(5397),
    [anon_sym_long] = ACTIONS(5397),
    [anon_sym_short] = ACTIONS(5397),
    [anon_sym_LBRACK] = ACTIONS(5397),
    [anon_sym_static] = ACTIONS(5397),
    [anon_sym_register] = ACTIONS(5397),
    [anon_sym_inline] = ACTIONS(5397),
    [anon_sym___inline] = ACTIONS(5397),
    [anon_sym___inline__] = ACTIONS(5397),
    [anon_sym___forceinline] = ACTIONS(5397),
    [anon_sym_thread_local] = ACTIONS(5397),
    [anon_sym___thread] = ACTIONS(5397),
    [anon_sym_const] = ACTIONS(5397),
    [anon_sym_constexpr] = ACTIONS(5397),
    [anon_sym_volatile] = ACTIONS(5397),
    [anon_sym_restrict] = ACTIONS(5397),
    [anon_sym___restrict__] = ACTIONS(5397),
    [anon_sym__Atomic] = ACTIONS(5397),
    [anon_sym__Noreturn] = ACTIONS(5397),
    [anon_sym_noreturn] = ACTIONS(5397),
    [anon_sym_mutable] = ACTIONS(5397),
    [anon_sym_constinit] = ACTIONS(5397),
    [anon_sym_consteval] = ACTIONS(5397),
    [anon_sym_alignas] = ACTIONS(5397),
    [anon_sym__Alignas] = ACTIONS(5397),
    [sym_primitive_type] = ACTIONS(5397),
    [anon_sym_enum] = ACTIONS(5397),
    [anon_sym_class] = ACTIONS(5397),
    [anon_sym_struct] = ACTIONS(5397),
    [anon_sym_union] = ACTIONS(5397),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5397),
    [anon_sym_decltype] = ACTIONS(5397),
    [sym_virtual] = ACTIONS(5397),
    [anon_sym_explicit] = ACTIONS(5397),
    [anon_sym_typename] = ACTIONS(5397),
    [anon_sym_template] = ACTIONS(5397),
    [anon_sym_operator] = ACTIONS(5397),
    [anon_sym_namespace] = ACTIONS(5632),
    [anon_sym_precise] = ACTIONS(5397),
    [anon_sym_shared] = ACTIONS(5397),
    [anon_sym_groupshared] = ACTIONS(5397),
    [anon_sym_uniform] = ACTIONS(5397),
    [anon_sym_row_major] = ACTIONS(5397),
    [anon_sym_column_major] = ACTIONS(5397),
    [anon_sym_globallycoherent] = ACTIONS(5397),
    [anon_sym_centroid] = ACTIONS(5397),
    [anon_sym_noperspective] = ACTIONS(5397),
    [anon_sym_nointerpolation] = ACTIONS(5397),
    [anon_sym_sample] = ACTIONS(5397),
    [anon_sym_linear] = ACTIONS(5397),
    [anon_sym_snorm] = ACTIONS(5397),
    [anon_sym_unorm] = ACTIONS(5397),
    [anon_sym_point] = ACTIONS(5397),
    [anon_sym_line] = ACTIONS(5397),
    [anon_sym_triangleadj] = ACTIONS(5397),
    [anon_sym_lineadj] = ACTIONS(5397),
    [anon_sym_triangle] = ACTIONS(5397),
  },
  [2340] = {
    [sym_identifier] = ACTIONS(2849),
    [anon_sym_LPAREN2] = ACTIONS(2851),
    [anon_sym_TILDE] = ACTIONS(2851),
    [anon_sym_STAR] = ACTIONS(2851),
    [anon_sym_AMP_AMP] = ACTIONS(2851),
    [anon_sym_AMP] = ACTIONS(2849),
    [anon_sym___extension__] = ACTIONS(2849),
    [anon_sym_typedef] = ACTIONS(5634),
    [anon_sym_in] = ACTIONS(2849),
    [anon_sym_out] = ACTIONS(2849),
    [anon_sym_inout] = ACTIONS(2849),
    [anon_sym_extern] = ACTIONS(2849),
    [anon_sym___attribute__] = ACTIONS(2849),
    [anon_sym_COLON_COLON] = ACTIONS(2851),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2851),
    [anon_sym___declspec] = ACTIONS(2849),
    [anon_sym___based] = ACTIONS(2849),
    [anon_sym_signed] = ACTIONS(2849),
    [anon_sym_unsigned] = ACTIONS(2849),
    [anon_sym_long] = ACTIONS(2849),
    [anon_sym_short] = ACTIONS(2849),
    [anon_sym_LBRACK] = ACTIONS(2849),
    [anon_sym_static] = ACTIONS(2849),
    [anon_sym_register] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2849),
    [anon_sym___inline] = ACTIONS(2849),
    [anon_sym___inline__] = ACTIONS(2849),
    [anon_sym___forceinline] = ACTIONS(2849),
    [anon_sym_thread_local] = ACTIONS(2849),
    [anon_sym___thread] = ACTIONS(2849),
    [anon_sym_const] = ACTIONS(2849),
    [anon_sym_constexpr] = ACTIONS(2849),
    [anon_sym_volatile] = ACTIONS(2849),
    [anon_sym_restrict] = ACTIONS(2849),
    [anon_sym___restrict__] = ACTIONS(2849),
    [anon_sym__Atomic] = ACTIONS(2849),
    [anon_sym__Noreturn] = ACTIONS(2849),
    [anon_sym_noreturn] = ACTIONS(2849),
    [anon_sym_mutable] = ACTIONS(2849),
    [anon_sym_constinit] = ACTIONS(2849),
    [anon_sym_consteval] = ACTIONS(2849),
    [anon_sym_alignas] = ACTIONS(2849),
    [anon_sym__Alignas] = ACTIONS(2849),
    [sym_primitive_type] = ACTIONS(2849),
    [anon_sym_enum] = ACTIONS(2849),
    [anon_sym_class] = ACTIONS(2849),
    [anon_sym_struct] = ACTIONS(2849),
    [anon_sym_union] = ACTIONS(2849),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2849),
    [anon_sym_decltype] = ACTIONS(2849),
    [sym_virtual] = ACTIONS(2849),
    [anon_sym_explicit] = ACTIONS(2849),
    [anon_sym_typename] = ACTIONS(2849),
    [anon_sym_template] = ACTIONS(2849),
    [anon_sym_operator] = ACTIONS(2849),
    [anon_sym_precise] = ACTIONS(2849),
    [anon_sym_shared] = ACTIONS(2849),
    [anon_sym_groupshared] = ACTIONS(2849),
    [anon_sym_uniform] = ACTIONS(2849),
    [anon_sym_row_major] = ACTIONS(2849),
    [anon_sym_column_major] = ACTIONS(2849),
    [anon_sym_globallycoherent] = ACTIONS(2849),
    [anon_sym_centroid] = ACTIONS(2849),
    [anon_sym_noperspective] = ACTIONS(2849),
    [anon_sym_nointerpolation] = ACTIONS(2849),
    [anon_sym_sample] = ACTIONS(2849),
    [anon_sym_linear] = ACTIONS(2849),
    [anon_sym_snorm] = ACTIONS(2849),
    [anon_sym_unorm] = ACTIONS(2849),
    [anon_sym_point] = ACTIONS(2849),
    [anon_sym_line] = ACTIONS(2849),
    [anon_sym_triangleadj] = ACTIONS(2849),
    [anon_sym_lineadj] = ACTIONS(2849),
    [anon_sym_triangle] = ACTIONS(2849),
  },
  [2341] = {
    [sym_attribute_specifier] = STATE(2293),
    [sym_enumerator_list] = STATE(2328),
    [sym__enum_base_clause] = STATE(2299),
    [sym_identifier] = ACTIONS(5636),
    [anon_sym_LPAREN2] = ACTIONS(5638),
    [anon_sym_TILDE] = ACTIONS(5638),
    [anon_sym_STAR] = ACTIONS(5638),
    [anon_sym_AMP_AMP] = ACTIONS(5638),
    [anon_sym_AMP] = ACTIONS(5636),
    [anon_sym_COLON] = ACTIONS(5640),
    [anon_sym_SEMI] = ACTIONS(5638),
    [anon_sym___extension__] = ACTIONS(5636),
    [anon_sym_in] = ACTIONS(5636),
    [anon_sym_out] = ACTIONS(5636),
    [anon_sym_inout] = ACTIONS(5636),
    [anon_sym_extern] = ACTIONS(5636),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5638),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5638),
    [anon_sym___declspec] = ACTIONS(5636),
    [anon_sym___based] = ACTIONS(5636),
    [anon_sym___cdecl] = ACTIONS(5636),
    [anon_sym___clrcall] = ACTIONS(5636),
    [anon_sym___stdcall] = ACTIONS(5636),
    [anon_sym___fastcall] = ACTIONS(5636),
    [anon_sym___thiscall] = ACTIONS(5636),
    [anon_sym___vectorcall] = ACTIONS(5636),
    [anon_sym_LBRACE] = ACTIONS(5523),
    [anon_sym_LBRACK] = ACTIONS(5636),
    [anon_sym_static] = ACTIONS(5636),
    [anon_sym_register] = ACTIONS(5636),
    [anon_sym_inline] = ACTIONS(5636),
    [anon_sym___inline] = ACTIONS(5636),
    [anon_sym___inline__] = ACTIONS(5636),
    [anon_sym___forceinline] = ACTIONS(5636),
    [anon_sym_thread_local] = ACTIONS(5636),
    [anon_sym___thread] = ACTIONS(5636),
    [anon_sym_const] = ACTIONS(5636),
    [anon_sym_constexpr] = ACTIONS(5636),
    [anon_sym_volatile] = ACTIONS(5636),
    [anon_sym_restrict] = ACTIONS(5636),
    [anon_sym___restrict__] = ACTIONS(5636),
    [anon_sym__Atomic] = ACTIONS(5636),
    [anon_sym__Noreturn] = ACTIONS(5636),
    [anon_sym_noreturn] = ACTIONS(5636),
    [anon_sym_mutable] = ACTIONS(5636),
    [anon_sym_constinit] = ACTIONS(5636),
    [anon_sym_consteval] = ACTIONS(5636),
    [anon_sym_alignas] = ACTIONS(5636),
    [anon_sym__Alignas] = ACTIONS(5636),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5636),
    [anon_sym_decltype] = ACTIONS(5636),
    [sym_virtual] = ACTIONS(5636),
    [anon_sym_template] = ACTIONS(5636),
    [anon_sym_operator] = ACTIONS(5636),
    [anon_sym_precise] = ACTIONS(5636),
    [anon_sym_shared] = ACTIONS(5636),
    [anon_sym_groupshared] = ACTIONS(5636),
    [anon_sym_uniform] = ACTIONS(5636),
    [anon_sym_row_major] = ACTIONS(5636),
    [anon_sym_column_major] = ACTIONS(5636),
    [anon_sym_globallycoherent] = ACTIONS(5636),
    [anon_sym_centroid] = ACTIONS(5636),
    [anon_sym_noperspective] = ACTIONS(5636),
    [anon_sym_nointerpolation] = ACTIONS(5636),
    [anon_sym_sample] = ACTIONS(5636),
    [anon_sym_linear] = ACTIONS(5636),
    [anon_sym_snorm] = ACTIONS(5636),
    [anon_sym_unorm] = ACTIONS(5636),
    [anon_sym_point] = ACTIONS(5636),
    [anon_sym_line] = ACTIONS(5636),
    [anon_sym_triangleadj] = ACTIONS(5636),
    [anon_sym_lineadj] = ACTIONS(5636),
    [anon_sym_triangle] = ACTIONS(5636),
  },
  [2342] = {
    [sym_identifier] = ACTIONS(5642),
    [anon_sym_LPAREN2] = ACTIONS(5644),
    [anon_sym_BANG] = ACTIONS(5644),
    [anon_sym_TILDE] = ACTIONS(5644),
    [anon_sym_DASH] = ACTIONS(5642),
    [anon_sym_PLUS] = ACTIONS(5642),
    [anon_sym_STAR] = ACTIONS(5644),
    [anon_sym_AMP] = ACTIONS(5644),
    [anon_sym_SEMI] = ACTIONS(5644),
    [anon_sym_COLON_COLON] = ACTIONS(5644),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5644),
    [anon_sym_LBRACE] = ACTIONS(5644),
    [anon_sym_LBRACK] = ACTIONS(5642),
    [sym_primitive_type] = ACTIONS(5642),
    [anon_sym_if] = ACTIONS(5642),
    [anon_sym_switch] = ACTIONS(5642),
    [anon_sym_case] = ACTIONS(5642),
    [anon_sym_default] = ACTIONS(5642),
    [anon_sym_while] = ACTIONS(5642),
    [anon_sym_do] = ACTIONS(5642),
    [anon_sym_for] = ACTIONS(5642),
    [anon_sym_return] = ACTIONS(5642),
    [anon_sym_break] = ACTIONS(5642),
    [anon_sym_continue] = ACTIONS(5642),
    [anon_sym_goto] = ACTIONS(5642),
    [anon_sym___try] = ACTIONS(5642),
    [anon_sym___leave] = ACTIONS(5642),
    [anon_sym_not] = ACTIONS(5642),
    [anon_sym_compl] = ACTIONS(5642),
    [anon_sym_DASH_DASH] = ACTIONS(5644),
    [anon_sym_PLUS_PLUS] = ACTIONS(5644),
    [anon_sym_sizeof] = ACTIONS(5642),
    [anon_sym___alignof__] = ACTIONS(5642),
    [anon_sym___alignof] = ACTIONS(5642),
    [anon_sym__alignof] = ACTIONS(5642),
    [anon_sym_alignof] = ACTIONS(5642),
    [anon_sym__Alignof] = ACTIONS(5642),
    [anon_sym_offsetof] = ACTIONS(5642),
    [anon_sym__Generic] = ACTIONS(5642),
    [anon_sym_asm] = ACTIONS(5642),
    [anon_sym___asm__] = ACTIONS(5642),
    [sym_number_literal] = ACTIONS(5644),
    [anon_sym_L_SQUOTE] = ACTIONS(5644),
    [anon_sym_u_SQUOTE] = ACTIONS(5644),
    [anon_sym_U_SQUOTE] = ACTIONS(5644),
    [anon_sym_u8_SQUOTE] = ACTIONS(5644),
    [anon_sym_SQUOTE] = ACTIONS(5644),
    [anon_sym_L_DQUOTE] = ACTIONS(5644),
    [anon_sym_u_DQUOTE] = ACTIONS(5644),
    [anon_sym_U_DQUOTE] = ACTIONS(5644),
    [anon_sym_u8_DQUOTE] = ACTIONS(5644),
    [anon_sym_DQUOTE] = ACTIONS(5644),
    [sym_true] = ACTIONS(5642),
    [sym_false] = ACTIONS(5642),
    [anon_sym_NULL] = ACTIONS(5642),
    [anon_sym_nullptr] = ACTIONS(5642),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(5642),
    [anon_sym_template] = ACTIONS(5642),
    [anon_sym_try] = ACTIONS(5642),
    [anon_sym_delete] = ACTIONS(5642),
    [anon_sym_throw] = ACTIONS(5642),
    [anon_sym_co_return] = ACTIONS(5642),
    [anon_sym_co_yield] = ACTIONS(5642),
    [anon_sym_R_DQUOTE] = ACTIONS(5644),
    [anon_sym_LR_DQUOTE] = ACTIONS(5644),
    [anon_sym_uR_DQUOTE] = ACTIONS(5644),
    [anon_sym_UR_DQUOTE] = ACTIONS(5644),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5644),
    [anon_sym_co_await] = ACTIONS(5642),
    [anon_sym_new] = ACTIONS(5642),
    [anon_sym_requires] = ACTIONS(5642),
    [sym_this] = ACTIONS(5642),
    [anon_sym_discard] = ACTIONS(5642),
    [anon_sym_cbuffer] = ACTIONS(5642),
  },
  [2343] = {
    [sym_string_literal] = STATE(2343),
    [sym_raw_string_literal] = STATE(2343),
    [aux_sym_concatenated_string_repeat1] = STATE(2343),
    [sym_identifier] = ACTIONS(5646),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5649),
    [anon_sym_COMMA] = ACTIONS(5649),
    [anon_sym_RPAREN] = ACTIONS(5649),
    [aux_sym_preproc_if_token2] = ACTIONS(5649),
    [aux_sym_preproc_else_token1] = ACTIONS(5649),
    [aux_sym_preproc_elif_token1] = ACTIONS(5651),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5649),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5649),
    [anon_sym_LPAREN2] = ACTIONS(5649),
    [anon_sym_DASH] = ACTIONS(5651),
    [anon_sym_PLUS] = ACTIONS(5651),
    [anon_sym_STAR] = ACTIONS(5651),
    [anon_sym_SLASH] = ACTIONS(5651),
    [anon_sym_PERCENT] = ACTIONS(5651),
    [anon_sym_PIPE_PIPE] = ACTIONS(5649),
    [anon_sym_AMP_AMP] = ACTIONS(5649),
    [anon_sym_PIPE] = ACTIONS(5651),
    [anon_sym_CARET] = ACTIONS(5651),
    [anon_sym_AMP] = ACTIONS(5651),
    [anon_sym_EQ_EQ] = ACTIONS(5649),
    [anon_sym_BANG_EQ] = ACTIONS(5649),
    [anon_sym_GT] = ACTIONS(5651),
    [anon_sym_GT_EQ] = ACTIONS(5649),
    [anon_sym_LT_EQ] = ACTIONS(5651),
    [anon_sym_LT] = ACTIONS(5651),
    [anon_sym_LT_LT] = ACTIONS(5651),
    [anon_sym_GT_GT] = ACTIONS(5651),
    [anon_sym_COLON] = ACTIONS(5649),
    [anon_sym_SEMI] = ACTIONS(5649),
    [anon_sym_RBRACE] = ACTIONS(5649),
    [anon_sym_LBRACK] = ACTIONS(5649),
    [anon_sym_RBRACK] = ACTIONS(5649),
    [anon_sym_EQ] = ACTIONS(5651),
    [anon_sym_QMARK] = ACTIONS(5649),
    [anon_sym_STAR_EQ] = ACTIONS(5649),
    [anon_sym_SLASH_EQ] = ACTIONS(5649),
    [anon_sym_PERCENT_EQ] = ACTIONS(5649),
    [anon_sym_PLUS_EQ] = ACTIONS(5649),
    [anon_sym_DASH_EQ] = ACTIONS(5649),
    [anon_sym_LT_LT_EQ] = ACTIONS(5649),
    [anon_sym_GT_GT_EQ] = ACTIONS(5649),
    [anon_sym_AMP_EQ] = ACTIONS(5649),
    [anon_sym_CARET_EQ] = ACTIONS(5649),
    [anon_sym_PIPE_EQ] = ACTIONS(5649),
    [anon_sym_and_eq] = ACTIONS(5651),
    [anon_sym_or_eq] = ACTIONS(5651),
    [anon_sym_xor_eq] = ACTIONS(5651),
    [anon_sym_LT_EQ_GT] = ACTIONS(5649),
    [anon_sym_or] = ACTIONS(5651),
    [anon_sym_and] = ACTIONS(5651),
    [anon_sym_bitor] = ACTIONS(5651),
    [anon_sym_xor] = ACTIONS(5651),
    [anon_sym_bitand] = ACTIONS(5651),
    [anon_sym_not_eq] = ACTIONS(5651),
    [anon_sym_DASH_DASH] = ACTIONS(5649),
    [anon_sym_PLUS_PLUS] = ACTIONS(5649),
    [anon_sym_DOT] = ACTIONS(5651),
    [anon_sym_DOT_STAR] = ACTIONS(5649),
    [anon_sym_DASH_GT] = ACTIONS(5649),
    [anon_sym_L_DQUOTE] = ACTIONS(5653),
    [anon_sym_u_DQUOTE] = ACTIONS(5653),
    [anon_sym_U_DQUOTE] = ACTIONS(5653),
    [anon_sym_u8_DQUOTE] = ACTIONS(5653),
    [anon_sym_DQUOTE] = ACTIONS(5653),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5656),
    [anon_sym_LR_DQUOTE] = ACTIONS(5656),
    [anon_sym_uR_DQUOTE] = ACTIONS(5656),
    [anon_sym_UR_DQUOTE] = ACTIONS(5656),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5656),
    [sym_literal_suffix] = ACTIONS(5651),
  },
  [2344] = {
    [sym_string_literal] = STATE(2345),
    [sym_raw_string_literal] = STATE(2345),
    [aux_sym_concatenated_string_repeat1] = STATE(2345),
    [sym_identifier] = ACTIONS(5659),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5661),
    [anon_sym_COMMA] = ACTIONS(5661),
    [anon_sym_RPAREN] = ACTIONS(5661),
    [aux_sym_preproc_if_token2] = ACTIONS(5661),
    [aux_sym_preproc_else_token1] = ACTIONS(5661),
    [aux_sym_preproc_elif_token1] = ACTIONS(5663),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5661),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5661),
    [anon_sym_LPAREN2] = ACTIONS(5661),
    [anon_sym_DASH] = ACTIONS(5663),
    [anon_sym_PLUS] = ACTIONS(5663),
    [anon_sym_STAR] = ACTIONS(5663),
    [anon_sym_SLASH] = ACTIONS(5663),
    [anon_sym_PERCENT] = ACTIONS(5663),
    [anon_sym_PIPE_PIPE] = ACTIONS(5661),
    [anon_sym_AMP_AMP] = ACTIONS(5661),
    [anon_sym_PIPE] = ACTIONS(5663),
    [anon_sym_CARET] = ACTIONS(5663),
    [anon_sym_AMP] = ACTIONS(5663),
    [anon_sym_EQ_EQ] = ACTIONS(5661),
    [anon_sym_BANG_EQ] = ACTIONS(5661),
    [anon_sym_GT] = ACTIONS(5663),
    [anon_sym_GT_EQ] = ACTIONS(5661),
    [anon_sym_LT_EQ] = ACTIONS(5663),
    [anon_sym_LT] = ACTIONS(5663),
    [anon_sym_LT_LT] = ACTIONS(5663),
    [anon_sym_GT_GT] = ACTIONS(5663),
    [anon_sym_COLON] = ACTIONS(5661),
    [anon_sym_SEMI] = ACTIONS(5661),
    [anon_sym_RBRACE] = ACTIONS(5661),
    [anon_sym_LBRACK] = ACTIONS(5661),
    [anon_sym_RBRACK] = ACTIONS(5661),
    [anon_sym_EQ] = ACTIONS(5663),
    [anon_sym_QMARK] = ACTIONS(5661),
    [anon_sym_STAR_EQ] = ACTIONS(5661),
    [anon_sym_SLASH_EQ] = ACTIONS(5661),
    [anon_sym_PERCENT_EQ] = ACTIONS(5661),
    [anon_sym_PLUS_EQ] = ACTIONS(5661),
    [anon_sym_DASH_EQ] = ACTIONS(5661),
    [anon_sym_LT_LT_EQ] = ACTIONS(5661),
    [anon_sym_GT_GT_EQ] = ACTIONS(5661),
    [anon_sym_AMP_EQ] = ACTIONS(5661),
    [anon_sym_CARET_EQ] = ACTIONS(5661),
    [anon_sym_PIPE_EQ] = ACTIONS(5661),
    [anon_sym_and_eq] = ACTIONS(5663),
    [anon_sym_or_eq] = ACTIONS(5663),
    [anon_sym_xor_eq] = ACTIONS(5663),
    [anon_sym_LT_EQ_GT] = ACTIONS(5661),
    [anon_sym_or] = ACTIONS(5663),
    [anon_sym_and] = ACTIONS(5663),
    [anon_sym_bitor] = ACTIONS(5663),
    [anon_sym_xor] = ACTIONS(5663),
    [anon_sym_bitand] = ACTIONS(5663),
    [anon_sym_not_eq] = ACTIONS(5663),
    [anon_sym_DASH_DASH] = ACTIONS(5661),
    [anon_sym_PLUS_PLUS] = ACTIONS(5661),
    [anon_sym_DOT] = ACTIONS(5663),
    [anon_sym_DOT_STAR] = ACTIONS(5661),
    [anon_sym_DASH_GT] = ACTIONS(5661),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [sym_literal_suffix] = ACTIONS(5663),
  },
  [2345] = {
    [sym_string_literal] = STATE(2343),
    [sym_raw_string_literal] = STATE(2343),
    [aux_sym_concatenated_string_repeat1] = STATE(2343),
    [sym_identifier] = ACTIONS(5665),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5667),
    [anon_sym_COMMA] = ACTIONS(5667),
    [anon_sym_RPAREN] = ACTIONS(5667),
    [aux_sym_preproc_if_token2] = ACTIONS(5667),
    [aux_sym_preproc_else_token1] = ACTIONS(5667),
    [aux_sym_preproc_elif_token1] = ACTIONS(5669),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5667),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5667),
    [anon_sym_LPAREN2] = ACTIONS(5667),
    [anon_sym_DASH] = ACTIONS(5669),
    [anon_sym_PLUS] = ACTIONS(5669),
    [anon_sym_STAR] = ACTIONS(5669),
    [anon_sym_SLASH] = ACTIONS(5669),
    [anon_sym_PERCENT] = ACTIONS(5669),
    [anon_sym_PIPE_PIPE] = ACTIONS(5667),
    [anon_sym_AMP_AMP] = ACTIONS(5667),
    [anon_sym_PIPE] = ACTIONS(5669),
    [anon_sym_CARET] = ACTIONS(5669),
    [anon_sym_AMP] = ACTIONS(5669),
    [anon_sym_EQ_EQ] = ACTIONS(5667),
    [anon_sym_BANG_EQ] = ACTIONS(5667),
    [anon_sym_GT] = ACTIONS(5669),
    [anon_sym_GT_EQ] = ACTIONS(5667),
    [anon_sym_LT_EQ] = ACTIONS(5669),
    [anon_sym_LT] = ACTIONS(5669),
    [anon_sym_LT_LT] = ACTIONS(5669),
    [anon_sym_GT_GT] = ACTIONS(5669),
    [anon_sym_COLON] = ACTIONS(5667),
    [anon_sym_SEMI] = ACTIONS(5667),
    [anon_sym_RBRACE] = ACTIONS(5667),
    [anon_sym_LBRACK] = ACTIONS(5667),
    [anon_sym_RBRACK] = ACTIONS(5667),
    [anon_sym_EQ] = ACTIONS(5669),
    [anon_sym_QMARK] = ACTIONS(5667),
    [anon_sym_STAR_EQ] = ACTIONS(5667),
    [anon_sym_SLASH_EQ] = ACTIONS(5667),
    [anon_sym_PERCENT_EQ] = ACTIONS(5667),
    [anon_sym_PLUS_EQ] = ACTIONS(5667),
    [anon_sym_DASH_EQ] = ACTIONS(5667),
    [anon_sym_LT_LT_EQ] = ACTIONS(5667),
    [anon_sym_GT_GT_EQ] = ACTIONS(5667),
    [anon_sym_AMP_EQ] = ACTIONS(5667),
    [anon_sym_CARET_EQ] = ACTIONS(5667),
    [anon_sym_PIPE_EQ] = ACTIONS(5667),
    [anon_sym_and_eq] = ACTIONS(5669),
    [anon_sym_or_eq] = ACTIONS(5669),
    [anon_sym_xor_eq] = ACTIONS(5669),
    [anon_sym_LT_EQ_GT] = ACTIONS(5667),
    [anon_sym_or] = ACTIONS(5669),
    [anon_sym_and] = ACTIONS(5669),
    [anon_sym_bitor] = ACTIONS(5669),
    [anon_sym_xor] = ACTIONS(5669),
    [anon_sym_bitand] = ACTIONS(5669),
    [anon_sym_not_eq] = ACTIONS(5669),
    [anon_sym_DASH_DASH] = ACTIONS(5667),
    [anon_sym_PLUS_PLUS] = ACTIONS(5667),
    [anon_sym_DOT] = ACTIONS(5669),
    [anon_sym_DOT_STAR] = ACTIONS(5667),
    [anon_sym_DASH_GT] = ACTIONS(5667),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [sym_literal_suffix] = ACTIONS(5669),
  },
  [2346] = {
    [sym_identifier] = ACTIONS(2849),
    [anon_sym_LPAREN2] = ACTIONS(2851),
    [anon_sym_TILDE] = ACTIONS(2851),
    [anon_sym_STAR] = ACTIONS(2851),
    [anon_sym_AMP_AMP] = ACTIONS(2851),
    [anon_sym_AMP] = ACTIONS(2849),
    [anon_sym___extension__] = ACTIONS(2849),
    [anon_sym_typedef] = ACTIONS(5671),
    [anon_sym_in] = ACTIONS(2849),
    [anon_sym_out] = ACTIONS(2849),
    [anon_sym_inout] = ACTIONS(2849),
    [anon_sym_extern] = ACTIONS(2849),
    [anon_sym___attribute__] = ACTIONS(2849),
    [anon_sym_COLON_COLON] = ACTIONS(2851),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2851),
    [anon_sym___declspec] = ACTIONS(2849),
    [anon_sym___based] = ACTIONS(2849),
    [anon_sym_signed] = ACTIONS(2849),
    [anon_sym_unsigned] = ACTIONS(2849),
    [anon_sym_long] = ACTIONS(2849),
    [anon_sym_short] = ACTIONS(2849),
    [anon_sym_LBRACK] = ACTIONS(2849),
    [anon_sym_static] = ACTIONS(2849),
    [anon_sym_register] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2849),
    [anon_sym___inline] = ACTIONS(2849),
    [anon_sym___inline__] = ACTIONS(2849),
    [anon_sym___forceinline] = ACTIONS(2849),
    [anon_sym_thread_local] = ACTIONS(2849),
    [anon_sym___thread] = ACTIONS(2849),
    [anon_sym_const] = ACTIONS(2849),
    [anon_sym_constexpr] = ACTIONS(2849),
    [anon_sym_volatile] = ACTIONS(2849),
    [anon_sym_restrict] = ACTIONS(2849),
    [anon_sym___restrict__] = ACTIONS(2849),
    [anon_sym__Atomic] = ACTIONS(2849),
    [anon_sym__Noreturn] = ACTIONS(2849),
    [anon_sym_noreturn] = ACTIONS(2849),
    [anon_sym_mutable] = ACTIONS(2849),
    [anon_sym_constinit] = ACTIONS(2849),
    [anon_sym_consteval] = ACTIONS(2849),
    [anon_sym_alignas] = ACTIONS(2849),
    [anon_sym__Alignas] = ACTIONS(2849),
    [sym_primitive_type] = ACTIONS(2849),
    [anon_sym_enum] = ACTIONS(2849),
    [anon_sym_class] = ACTIONS(2849),
    [anon_sym_struct] = ACTIONS(2849),
    [anon_sym_union] = ACTIONS(2849),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2849),
    [anon_sym_decltype] = ACTIONS(2849),
    [sym_virtual] = ACTIONS(2849),
    [anon_sym_explicit] = ACTIONS(2849),
    [anon_sym_typename] = ACTIONS(2849),
    [anon_sym_template] = ACTIONS(2849),
    [anon_sym_operator] = ACTIONS(2849),
    [anon_sym_precise] = ACTIONS(2849),
    [anon_sym_shared] = ACTIONS(2849),
    [anon_sym_groupshared] = ACTIONS(2849),
    [anon_sym_uniform] = ACTIONS(2849),
    [anon_sym_row_major] = ACTIONS(2849),
    [anon_sym_column_major] = ACTIONS(2849),
    [anon_sym_globallycoherent] = ACTIONS(2849),
    [anon_sym_centroid] = ACTIONS(2849),
    [anon_sym_noperspective] = ACTIONS(2849),
    [anon_sym_nointerpolation] = ACTIONS(2849),
    [anon_sym_sample] = ACTIONS(2849),
    [anon_sym_linear] = ACTIONS(2849),
    [anon_sym_snorm] = ACTIONS(2849),
    [anon_sym_unorm] = ACTIONS(2849),
    [anon_sym_point] = ACTIONS(2849),
    [anon_sym_line] = ACTIONS(2849),
    [anon_sym_triangleadj] = ACTIONS(2849),
    [anon_sym_lineadj] = ACTIONS(2849),
    [anon_sym_triangle] = ACTIONS(2849),
  },
  [2347] = {
    [sym_identifier] = ACTIONS(2849),
    [anon_sym_LPAREN2] = ACTIONS(2851),
    [anon_sym_TILDE] = ACTIONS(2851),
    [anon_sym_STAR] = ACTIONS(2851),
    [anon_sym_AMP_AMP] = ACTIONS(2851),
    [anon_sym_AMP] = ACTIONS(2849),
    [anon_sym___extension__] = ACTIONS(2849),
    [anon_sym_typedef] = ACTIONS(5673),
    [anon_sym_in] = ACTIONS(2849),
    [anon_sym_out] = ACTIONS(2849),
    [anon_sym_inout] = ACTIONS(2849),
    [anon_sym_extern] = ACTIONS(2849),
    [anon_sym___attribute__] = ACTIONS(2849),
    [anon_sym_COLON_COLON] = ACTIONS(2851),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2851),
    [anon_sym___declspec] = ACTIONS(2849),
    [anon_sym___based] = ACTIONS(2849),
    [anon_sym_signed] = ACTIONS(2849),
    [anon_sym_unsigned] = ACTIONS(2849),
    [anon_sym_long] = ACTIONS(2849),
    [anon_sym_short] = ACTIONS(2849),
    [anon_sym_LBRACK] = ACTIONS(2849),
    [anon_sym_static] = ACTIONS(2849),
    [anon_sym_register] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2849),
    [anon_sym___inline] = ACTIONS(2849),
    [anon_sym___inline__] = ACTIONS(2849),
    [anon_sym___forceinline] = ACTIONS(2849),
    [anon_sym_thread_local] = ACTIONS(2849),
    [anon_sym___thread] = ACTIONS(2849),
    [anon_sym_const] = ACTIONS(2849),
    [anon_sym_constexpr] = ACTIONS(2849),
    [anon_sym_volatile] = ACTIONS(2849),
    [anon_sym_restrict] = ACTIONS(2849),
    [anon_sym___restrict__] = ACTIONS(2849),
    [anon_sym__Atomic] = ACTIONS(2849),
    [anon_sym__Noreturn] = ACTIONS(2849),
    [anon_sym_noreturn] = ACTIONS(2849),
    [anon_sym_mutable] = ACTIONS(2849),
    [anon_sym_constinit] = ACTIONS(2849),
    [anon_sym_consteval] = ACTIONS(2849),
    [anon_sym_alignas] = ACTIONS(2849),
    [anon_sym__Alignas] = ACTIONS(2849),
    [sym_primitive_type] = ACTIONS(2849),
    [anon_sym_enum] = ACTIONS(2849),
    [anon_sym_class] = ACTIONS(2849),
    [anon_sym_struct] = ACTIONS(2849),
    [anon_sym_union] = ACTIONS(2849),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2849),
    [anon_sym_decltype] = ACTIONS(2849),
    [sym_virtual] = ACTIONS(2849),
    [anon_sym_explicit] = ACTIONS(2849),
    [anon_sym_typename] = ACTIONS(2849),
    [anon_sym_template] = ACTIONS(2849),
    [anon_sym_operator] = ACTIONS(2849),
    [anon_sym_precise] = ACTIONS(2849),
    [anon_sym_shared] = ACTIONS(2849),
    [anon_sym_groupshared] = ACTIONS(2849),
    [anon_sym_uniform] = ACTIONS(2849),
    [anon_sym_row_major] = ACTIONS(2849),
    [anon_sym_column_major] = ACTIONS(2849),
    [anon_sym_globallycoherent] = ACTIONS(2849),
    [anon_sym_centroid] = ACTIONS(2849),
    [anon_sym_noperspective] = ACTIONS(2849),
    [anon_sym_nointerpolation] = ACTIONS(2849),
    [anon_sym_sample] = ACTIONS(2849),
    [anon_sym_linear] = ACTIONS(2849),
    [anon_sym_snorm] = ACTIONS(2849),
    [anon_sym_unorm] = ACTIONS(2849),
    [anon_sym_point] = ACTIONS(2849),
    [anon_sym_line] = ACTIONS(2849),
    [anon_sym_triangleadj] = ACTIONS(2849),
    [anon_sym_lineadj] = ACTIONS(2849),
    [anon_sym_triangle] = ACTIONS(2849),
  },
  [2348] = {
    [sym_identifier] = ACTIONS(2849),
    [anon_sym_LPAREN2] = ACTIONS(2851),
    [anon_sym_TILDE] = ACTIONS(2851),
    [anon_sym_STAR] = ACTIONS(2851),
    [anon_sym_AMP_AMP] = ACTIONS(2851),
    [anon_sym_AMP] = ACTIONS(2849),
    [anon_sym___extension__] = ACTIONS(2849),
    [anon_sym_typedef] = ACTIONS(5675),
    [anon_sym_in] = ACTIONS(2849),
    [anon_sym_out] = ACTIONS(2849),
    [anon_sym_inout] = ACTIONS(2849),
    [anon_sym_extern] = ACTIONS(2849),
    [anon_sym___attribute__] = ACTIONS(2849),
    [anon_sym_COLON_COLON] = ACTIONS(2851),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2851),
    [anon_sym___declspec] = ACTIONS(2849),
    [anon_sym___based] = ACTIONS(2849),
    [anon_sym_signed] = ACTIONS(2849),
    [anon_sym_unsigned] = ACTIONS(2849),
    [anon_sym_long] = ACTIONS(2849),
    [anon_sym_short] = ACTIONS(2849),
    [anon_sym_LBRACK] = ACTIONS(2849),
    [anon_sym_static] = ACTIONS(2849),
    [anon_sym_register] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2849),
    [anon_sym___inline] = ACTIONS(2849),
    [anon_sym___inline__] = ACTIONS(2849),
    [anon_sym___forceinline] = ACTIONS(2849),
    [anon_sym_thread_local] = ACTIONS(2849),
    [anon_sym___thread] = ACTIONS(2849),
    [anon_sym_const] = ACTIONS(2849),
    [anon_sym_constexpr] = ACTIONS(2849),
    [anon_sym_volatile] = ACTIONS(2849),
    [anon_sym_restrict] = ACTIONS(2849),
    [anon_sym___restrict__] = ACTIONS(2849),
    [anon_sym__Atomic] = ACTIONS(2849),
    [anon_sym__Noreturn] = ACTIONS(2849),
    [anon_sym_noreturn] = ACTIONS(2849),
    [anon_sym_mutable] = ACTIONS(2849),
    [anon_sym_constinit] = ACTIONS(2849),
    [anon_sym_consteval] = ACTIONS(2849),
    [anon_sym_alignas] = ACTIONS(2849),
    [anon_sym__Alignas] = ACTIONS(2849),
    [sym_primitive_type] = ACTIONS(2849),
    [anon_sym_enum] = ACTIONS(2849),
    [anon_sym_class] = ACTIONS(2849),
    [anon_sym_struct] = ACTIONS(2849),
    [anon_sym_union] = ACTIONS(2849),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2849),
    [anon_sym_decltype] = ACTIONS(2849),
    [sym_virtual] = ACTIONS(2849),
    [anon_sym_explicit] = ACTIONS(2849),
    [anon_sym_typename] = ACTIONS(2849),
    [anon_sym_template] = ACTIONS(2849),
    [anon_sym_operator] = ACTIONS(2849),
    [anon_sym_precise] = ACTIONS(2849),
    [anon_sym_shared] = ACTIONS(2849),
    [anon_sym_groupshared] = ACTIONS(2849),
    [anon_sym_uniform] = ACTIONS(2849),
    [anon_sym_row_major] = ACTIONS(2849),
    [anon_sym_column_major] = ACTIONS(2849),
    [anon_sym_globallycoherent] = ACTIONS(2849),
    [anon_sym_centroid] = ACTIONS(2849),
    [anon_sym_noperspective] = ACTIONS(2849),
    [anon_sym_nointerpolation] = ACTIONS(2849),
    [anon_sym_sample] = ACTIONS(2849),
    [anon_sym_linear] = ACTIONS(2849),
    [anon_sym_snorm] = ACTIONS(2849),
    [anon_sym_unorm] = ACTIONS(2849),
    [anon_sym_point] = ACTIONS(2849),
    [anon_sym_line] = ACTIONS(2849),
    [anon_sym_triangleadj] = ACTIONS(2849),
    [anon_sym_lineadj] = ACTIONS(2849),
    [anon_sym_triangle] = ACTIONS(2849),
  },
  [2349] = {
    [sym_identifier] = ACTIONS(2849),
    [anon_sym_LPAREN2] = ACTIONS(2851),
    [anon_sym_TILDE] = ACTIONS(2851),
    [anon_sym_STAR] = ACTIONS(2851),
    [anon_sym_AMP_AMP] = ACTIONS(2851),
    [anon_sym_AMP] = ACTIONS(2849),
    [anon_sym___extension__] = ACTIONS(2849),
    [anon_sym_typedef] = ACTIONS(5677),
    [anon_sym_in] = ACTIONS(2849),
    [anon_sym_out] = ACTIONS(2849),
    [anon_sym_inout] = ACTIONS(2849),
    [anon_sym_extern] = ACTIONS(2849),
    [anon_sym___attribute__] = ACTIONS(2849),
    [anon_sym_COLON_COLON] = ACTIONS(2851),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2851),
    [anon_sym___declspec] = ACTIONS(2849),
    [anon_sym___based] = ACTIONS(2849),
    [anon_sym_signed] = ACTIONS(2849),
    [anon_sym_unsigned] = ACTIONS(2849),
    [anon_sym_long] = ACTIONS(2849),
    [anon_sym_short] = ACTIONS(2849),
    [anon_sym_LBRACK] = ACTIONS(2849),
    [anon_sym_static] = ACTIONS(2849),
    [anon_sym_register] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2849),
    [anon_sym___inline] = ACTIONS(2849),
    [anon_sym___inline__] = ACTIONS(2849),
    [anon_sym___forceinline] = ACTIONS(2849),
    [anon_sym_thread_local] = ACTIONS(2849),
    [anon_sym___thread] = ACTIONS(2849),
    [anon_sym_const] = ACTIONS(2849),
    [anon_sym_constexpr] = ACTIONS(2849),
    [anon_sym_volatile] = ACTIONS(2849),
    [anon_sym_restrict] = ACTIONS(2849),
    [anon_sym___restrict__] = ACTIONS(2849),
    [anon_sym__Atomic] = ACTIONS(2849),
    [anon_sym__Noreturn] = ACTIONS(2849),
    [anon_sym_noreturn] = ACTIONS(2849),
    [anon_sym_mutable] = ACTIONS(2849),
    [anon_sym_constinit] = ACTIONS(2849),
    [anon_sym_consteval] = ACTIONS(2849),
    [anon_sym_alignas] = ACTIONS(2849),
    [anon_sym__Alignas] = ACTIONS(2849),
    [sym_primitive_type] = ACTIONS(2849),
    [anon_sym_enum] = ACTIONS(2849),
    [anon_sym_class] = ACTIONS(2849),
    [anon_sym_struct] = ACTIONS(2849),
    [anon_sym_union] = ACTIONS(2849),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2849),
    [anon_sym_decltype] = ACTIONS(2849),
    [sym_virtual] = ACTIONS(2849),
    [anon_sym_explicit] = ACTIONS(2849),
    [anon_sym_typename] = ACTIONS(2849),
    [anon_sym_template] = ACTIONS(2849),
    [anon_sym_operator] = ACTIONS(2849),
    [anon_sym_precise] = ACTIONS(2849),
    [anon_sym_shared] = ACTIONS(2849),
    [anon_sym_groupshared] = ACTIONS(2849),
    [anon_sym_uniform] = ACTIONS(2849),
    [anon_sym_row_major] = ACTIONS(2849),
    [anon_sym_column_major] = ACTIONS(2849),
    [anon_sym_globallycoherent] = ACTIONS(2849),
    [anon_sym_centroid] = ACTIONS(2849),
    [anon_sym_noperspective] = ACTIONS(2849),
    [anon_sym_nointerpolation] = ACTIONS(2849),
    [anon_sym_sample] = ACTIONS(2849),
    [anon_sym_linear] = ACTIONS(2849),
    [anon_sym_snorm] = ACTIONS(2849),
    [anon_sym_unorm] = ACTIONS(2849),
    [anon_sym_point] = ACTIONS(2849),
    [anon_sym_line] = ACTIONS(2849),
    [anon_sym_triangleadj] = ACTIONS(2849),
    [anon_sym_lineadj] = ACTIONS(2849),
    [anon_sym_triangle] = ACTIONS(2849),
  },
  [2350] = {
    [sym_identifier] = ACTIONS(2849),
    [anon_sym_LPAREN2] = ACTIONS(2851),
    [anon_sym_TILDE] = ACTIONS(2851),
    [anon_sym_STAR] = ACTIONS(2851),
    [anon_sym_AMP_AMP] = ACTIONS(2851),
    [anon_sym_AMP] = ACTIONS(2849),
    [anon_sym___extension__] = ACTIONS(2849),
    [anon_sym_typedef] = ACTIONS(5679),
    [anon_sym_in] = ACTIONS(2849),
    [anon_sym_out] = ACTIONS(2849),
    [anon_sym_inout] = ACTIONS(2849),
    [anon_sym_extern] = ACTIONS(2849),
    [anon_sym___attribute__] = ACTIONS(2849),
    [anon_sym_COLON_COLON] = ACTIONS(2851),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2851),
    [anon_sym___declspec] = ACTIONS(2849),
    [anon_sym___based] = ACTIONS(2849),
    [anon_sym_signed] = ACTIONS(2849),
    [anon_sym_unsigned] = ACTIONS(2849),
    [anon_sym_long] = ACTIONS(2849),
    [anon_sym_short] = ACTIONS(2849),
    [anon_sym_LBRACK] = ACTIONS(2849),
    [anon_sym_static] = ACTIONS(2849),
    [anon_sym_register] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2849),
    [anon_sym___inline] = ACTIONS(2849),
    [anon_sym___inline__] = ACTIONS(2849),
    [anon_sym___forceinline] = ACTIONS(2849),
    [anon_sym_thread_local] = ACTIONS(2849),
    [anon_sym___thread] = ACTIONS(2849),
    [anon_sym_const] = ACTIONS(2849),
    [anon_sym_constexpr] = ACTIONS(2849),
    [anon_sym_volatile] = ACTIONS(2849),
    [anon_sym_restrict] = ACTIONS(2849),
    [anon_sym___restrict__] = ACTIONS(2849),
    [anon_sym__Atomic] = ACTIONS(2849),
    [anon_sym__Noreturn] = ACTIONS(2849),
    [anon_sym_noreturn] = ACTIONS(2849),
    [anon_sym_mutable] = ACTIONS(2849),
    [anon_sym_constinit] = ACTIONS(2849),
    [anon_sym_consteval] = ACTIONS(2849),
    [anon_sym_alignas] = ACTIONS(2849),
    [anon_sym__Alignas] = ACTIONS(2849),
    [sym_primitive_type] = ACTIONS(2849),
    [anon_sym_enum] = ACTIONS(2849),
    [anon_sym_class] = ACTIONS(2849),
    [anon_sym_struct] = ACTIONS(2849),
    [anon_sym_union] = ACTIONS(2849),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2849),
    [anon_sym_decltype] = ACTIONS(2849),
    [sym_virtual] = ACTIONS(2849),
    [anon_sym_explicit] = ACTIONS(2849),
    [anon_sym_typename] = ACTIONS(2849),
    [anon_sym_template] = ACTIONS(2849),
    [anon_sym_operator] = ACTIONS(2849),
    [anon_sym_precise] = ACTIONS(2849),
    [anon_sym_shared] = ACTIONS(2849),
    [anon_sym_groupshared] = ACTIONS(2849),
    [anon_sym_uniform] = ACTIONS(2849),
    [anon_sym_row_major] = ACTIONS(2849),
    [anon_sym_column_major] = ACTIONS(2849),
    [anon_sym_globallycoherent] = ACTIONS(2849),
    [anon_sym_centroid] = ACTIONS(2849),
    [anon_sym_noperspective] = ACTIONS(2849),
    [anon_sym_nointerpolation] = ACTIONS(2849),
    [anon_sym_sample] = ACTIONS(2849),
    [anon_sym_linear] = ACTIONS(2849),
    [anon_sym_snorm] = ACTIONS(2849),
    [anon_sym_unorm] = ACTIONS(2849),
    [anon_sym_point] = ACTIONS(2849),
    [anon_sym_line] = ACTIONS(2849),
    [anon_sym_triangleadj] = ACTIONS(2849),
    [anon_sym_lineadj] = ACTIONS(2849),
    [anon_sym_triangle] = ACTIONS(2849),
  },
  [2351] = {
    [sym_identifier] = ACTIONS(5681),
    [anon_sym_LPAREN2] = ACTIONS(5683),
    [anon_sym_BANG] = ACTIONS(5683),
    [anon_sym_TILDE] = ACTIONS(5683),
    [anon_sym_DASH] = ACTIONS(5681),
    [anon_sym_PLUS] = ACTIONS(5681),
    [anon_sym_STAR] = ACTIONS(5683),
    [anon_sym_AMP] = ACTIONS(5683),
    [anon_sym_SEMI] = ACTIONS(5683),
    [anon_sym_COLON_COLON] = ACTIONS(5683),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5683),
    [anon_sym_LBRACE] = ACTIONS(5683),
    [anon_sym_LBRACK] = ACTIONS(5681),
    [sym_primitive_type] = ACTIONS(5681),
    [anon_sym_if] = ACTIONS(5681),
    [anon_sym_switch] = ACTIONS(5681),
    [anon_sym_case] = ACTIONS(5681),
    [anon_sym_default] = ACTIONS(5681),
    [anon_sym_while] = ACTIONS(5681),
    [anon_sym_do] = ACTIONS(5681),
    [anon_sym_for] = ACTIONS(5681),
    [anon_sym_return] = ACTIONS(5681),
    [anon_sym_break] = ACTIONS(5681),
    [anon_sym_continue] = ACTIONS(5681),
    [anon_sym_goto] = ACTIONS(5681),
    [anon_sym___try] = ACTIONS(5681),
    [anon_sym___leave] = ACTIONS(5681),
    [anon_sym_not] = ACTIONS(5681),
    [anon_sym_compl] = ACTIONS(5681),
    [anon_sym_DASH_DASH] = ACTIONS(5683),
    [anon_sym_PLUS_PLUS] = ACTIONS(5683),
    [anon_sym_sizeof] = ACTIONS(5681),
    [anon_sym___alignof__] = ACTIONS(5681),
    [anon_sym___alignof] = ACTIONS(5681),
    [anon_sym__alignof] = ACTIONS(5681),
    [anon_sym_alignof] = ACTIONS(5681),
    [anon_sym__Alignof] = ACTIONS(5681),
    [anon_sym_offsetof] = ACTIONS(5681),
    [anon_sym__Generic] = ACTIONS(5681),
    [anon_sym_asm] = ACTIONS(5681),
    [anon_sym___asm__] = ACTIONS(5681),
    [sym_number_literal] = ACTIONS(5683),
    [anon_sym_L_SQUOTE] = ACTIONS(5683),
    [anon_sym_u_SQUOTE] = ACTIONS(5683),
    [anon_sym_U_SQUOTE] = ACTIONS(5683),
    [anon_sym_u8_SQUOTE] = ACTIONS(5683),
    [anon_sym_SQUOTE] = ACTIONS(5683),
    [anon_sym_L_DQUOTE] = ACTIONS(5683),
    [anon_sym_u_DQUOTE] = ACTIONS(5683),
    [anon_sym_U_DQUOTE] = ACTIONS(5683),
    [anon_sym_u8_DQUOTE] = ACTIONS(5683),
    [anon_sym_DQUOTE] = ACTIONS(5683),
    [sym_true] = ACTIONS(5681),
    [sym_false] = ACTIONS(5681),
    [anon_sym_NULL] = ACTIONS(5681),
    [anon_sym_nullptr] = ACTIONS(5681),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(5681),
    [anon_sym_template] = ACTIONS(5681),
    [anon_sym_try] = ACTIONS(5681),
    [anon_sym_delete] = ACTIONS(5681),
    [anon_sym_throw] = ACTIONS(5681),
    [anon_sym_co_return] = ACTIONS(5681),
    [anon_sym_co_yield] = ACTIONS(5681),
    [anon_sym_R_DQUOTE] = ACTIONS(5683),
    [anon_sym_LR_DQUOTE] = ACTIONS(5683),
    [anon_sym_uR_DQUOTE] = ACTIONS(5683),
    [anon_sym_UR_DQUOTE] = ACTIONS(5683),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5683),
    [anon_sym_co_await] = ACTIONS(5681),
    [anon_sym_new] = ACTIONS(5681),
    [anon_sym_requires] = ACTIONS(5681),
    [sym_this] = ACTIONS(5681),
    [anon_sym_discard] = ACTIONS(5681),
    [anon_sym_cbuffer] = ACTIONS(5681),
  },
  [2352] = {
    [sym_template_argument_list] = STATE(2441),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2233),
    [sym_identifier] = ACTIONS(3822),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3830),
    [anon_sym_COMMA] = ACTIONS(3830),
    [anon_sym_RPAREN] = ACTIONS(3845),
    [anon_sym_LPAREN2] = ACTIONS(3845),
    [anon_sym_TILDE] = ACTIONS(3830),
    [anon_sym_STAR] = ACTIONS(3830),
    [anon_sym_AMP_AMP] = ACTIONS(3830),
    [anon_sym_AMP] = ACTIONS(3822),
    [anon_sym_LT] = ACTIONS(5628),
    [anon_sym_COLON] = ACTIONS(3822),
    [anon_sym___extension__] = ACTIONS(3822),
    [anon_sym_in] = ACTIONS(3822),
    [anon_sym_out] = ACTIONS(3822),
    [anon_sym_inout] = ACTIONS(3822),
    [anon_sym_extern] = ACTIONS(3822),
    [anon_sym___attribute__] = ACTIONS(3822),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3845),
    [anon_sym___declspec] = ACTIONS(3822),
    [anon_sym___based] = ACTIONS(3822),
    [anon_sym_signed] = ACTIONS(3848),
    [anon_sym_unsigned] = ACTIONS(3848),
    [anon_sym_long] = ACTIONS(3848),
    [anon_sym_short] = ACTIONS(3848),
    [anon_sym_LBRACK] = ACTIONS(5603),
    [anon_sym_static] = ACTIONS(3822),
    [anon_sym_EQ] = ACTIONS(3830),
    [anon_sym_register] = ACTIONS(3822),
    [anon_sym_inline] = ACTIONS(3822),
    [anon_sym___inline] = ACTIONS(3822),
    [anon_sym___inline__] = ACTIONS(3822),
    [anon_sym___forceinline] = ACTIONS(3822),
    [anon_sym_thread_local] = ACTIONS(3822),
    [anon_sym___thread] = ACTIONS(3822),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3822),
    [anon_sym_volatile] = ACTIONS(3822),
    [anon_sym_restrict] = ACTIONS(3822),
    [anon_sym___restrict__] = ACTIONS(3822),
    [anon_sym__Atomic] = ACTIONS(3822),
    [anon_sym__Noreturn] = ACTIONS(3822),
    [anon_sym_noreturn] = ACTIONS(3822),
    [anon_sym_mutable] = ACTIONS(3822),
    [anon_sym_constinit] = ACTIONS(3822),
    [anon_sym_consteval] = ACTIONS(3822),
    [anon_sym_alignas] = ACTIONS(3822),
    [anon_sym__Alignas] = ACTIONS(3822),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3822),
    [anon_sym_decltype] = ACTIONS(3822),
    [sym_virtual] = ACTIONS(3822),
    [anon_sym_template] = ACTIONS(3822),
    [anon_sym_operator] = ACTIONS(3822),
    [anon_sym_precise] = ACTIONS(3822),
    [anon_sym_shared] = ACTIONS(3822),
    [anon_sym_groupshared] = ACTIONS(3822),
    [anon_sym_uniform] = ACTIONS(3822),
    [anon_sym_row_major] = ACTIONS(3822),
    [anon_sym_column_major] = ACTIONS(3822),
    [anon_sym_globallycoherent] = ACTIONS(3822),
    [anon_sym_centroid] = ACTIONS(3822),
    [anon_sym_noperspective] = ACTIONS(3822),
    [anon_sym_nointerpolation] = ACTIONS(3822),
    [anon_sym_sample] = ACTIONS(3822),
    [anon_sym_linear] = ACTIONS(3822),
    [anon_sym_snorm] = ACTIONS(3822),
    [anon_sym_unorm] = ACTIONS(3822),
    [anon_sym_point] = ACTIONS(3822),
    [anon_sym_line] = ACTIONS(3822),
    [anon_sym_triangleadj] = ACTIONS(3822),
    [anon_sym_lineadj] = ACTIONS(3822),
    [anon_sym_triangle] = ACTIONS(3822),
  },
  [2353] = {
    [sym_identifier] = ACTIONS(5397),
    [anon_sym_LPAREN2] = ACTIONS(5399),
    [anon_sym_TILDE] = ACTIONS(5399),
    [anon_sym_STAR] = ACTIONS(5399),
    [anon_sym_AMP_AMP] = ACTIONS(5399),
    [anon_sym_AMP] = ACTIONS(5397),
    [anon_sym___extension__] = ACTIONS(5397),
    [anon_sym_in] = ACTIONS(5397),
    [anon_sym_out] = ACTIONS(5397),
    [anon_sym_inout] = ACTIONS(5397),
    [anon_sym_extern] = ACTIONS(5397),
    [anon_sym___attribute__] = ACTIONS(5397),
    [anon_sym_COLON_COLON] = ACTIONS(5399),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5399),
    [anon_sym___declspec] = ACTIONS(5397),
    [anon_sym___based] = ACTIONS(5397),
    [anon_sym_signed] = ACTIONS(5397),
    [anon_sym_unsigned] = ACTIONS(5397),
    [anon_sym_long] = ACTIONS(5397),
    [anon_sym_short] = ACTIONS(5397),
    [anon_sym_LBRACK] = ACTIONS(5397),
    [anon_sym_static] = ACTIONS(5397),
    [anon_sym_register] = ACTIONS(5397),
    [anon_sym_inline] = ACTIONS(5397),
    [anon_sym___inline] = ACTIONS(5397),
    [anon_sym___inline__] = ACTIONS(5397),
    [anon_sym___forceinline] = ACTIONS(5397),
    [anon_sym_thread_local] = ACTIONS(5397),
    [anon_sym___thread] = ACTIONS(5397),
    [anon_sym_const] = ACTIONS(5397),
    [anon_sym_constexpr] = ACTIONS(5397),
    [anon_sym_volatile] = ACTIONS(5397),
    [anon_sym_restrict] = ACTIONS(5397),
    [anon_sym___restrict__] = ACTIONS(5397),
    [anon_sym__Atomic] = ACTIONS(5397),
    [anon_sym__Noreturn] = ACTIONS(5397),
    [anon_sym_noreturn] = ACTIONS(5397),
    [anon_sym_mutable] = ACTIONS(5397),
    [anon_sym_constinit] = ACTIONS(5397),
    [anon_sym_consteval] = ACTIONS(5397),
    [anon_sym_alignas] = ACTIONS(5397),
    [anon_sym__Alignas] = ACTIONS(5397),
    [sym_primitive_type] = ACTIONS(5397),
    [anon_sym_enum] = ACTIONS(5397),
    [anon_sym_class] = ACTIONS(5397),
    [anon_sym_struct] = ACTIONS(5397),
    [anon_sym_union] = ACTIONS(5397),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5397),
    [anon_sym_decltype] = ACTIONS(5397),
    [sym_virtual] = ACTIONS(5397),
    [anon_sym_explicit] = ACTIONS(5397),
    [anon_sym_typename] = ACTIONS(5397),
    [anon_sym_template] = ACTIONS(5397),
    [anon_sym_operator] = ACTIONS(5397),
    [anon_sym_namespace] = ACTIONS(5685),
    [anon_sym_precise] = ACTIONS(5397),
    [anon_sym_shared] = ACTIONS(5397),
    [anon_sym_groupshared] = ACTIONS(5397),
    [anon_sym_uniform] = ACTIONS(5397),
    [anon_sym_row_major] = ACTIONS(5397),
    [anon_sym_column_major] = ACTIONS(5397),
    [anon_sym_globallycoherent] = ACTIONS(5397),
    [anon_sym_centroid] = ACTIONS(5397),
    [anon_sym_noperspective] = ACTIONS(5397),
    [anon_sym_nointerpolation] = ACTIONS(5397),
    [anon_sym_sample] = ACTIONS(5397),
    [anon_sym_linear] = ACTIONS(5397),
    [anon_sym_snorm] = ACTIONS(5397),
    [anon_sym_unorm] = ACTIONS(5397),
    [anon_sym_point] = ACTIONS(5397),
    [anon_sym_line] = ACTIONS(5397),
    [anon_sym_triangleadj] = ACTIONS(5397),
    [anon_sym_lineadj] = ACTIONS(5397),
    [anon_sym_triangle] = ACTIONS(5397),
  },
  [2354] = {
    [sym_identifier] = ACTIONS(5397),
    [anon_sym_LPAREN2] = ACTIONS(5399),
    [anon_sym_TILDE] = ACTIONS(5399),
    [anon_sym_STAR] = ACTIONS(5399),
    [anon_sym_AMP_AMP] = ACTIONS(5399),
    [anon_sym_AMP] = ACTIONS(5397),
    [anon_sym___extension__] = ACTIONS(5397),
    [anon_sym_in] = ACTIONS(5397),
    [anon_sym_out] = ACTIONS(5397),
    [anon_sym_inout] = ACTIONS(5397),
    [anon_sym_extern] = ACTIONS(5397),
    [anon_sym___attribute__] = ACTIONS(5397),
    [anon_sym_COLON_COLON] = ACTIONS(5399),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5399),
    [anon_sym___declspec] = ACTIONS(5397),
    [anon_sym___based] = ACTIONS(5397),
    [anon_sym_signed] = ACTIONS(5397),
    [anon_sym_unsigned] = ACTIONS(5397),
    [anon_sym_long] = ACTIONS(5397),
    [anon_sym_short] = ACTIONS(5397),
    [anon_sym_LBRACK] = ACTIONS(5397),
    [anon_sym_static] = ACTIONS(5397),
    [anon_sym_register] = ACTIONS(5397),
    [anon_sym_inline] = ACTIONS(5397),
    [anon_sym___inline] = ACTIONS(5397),
    [anon_sym___inline__] = ACTIONS(5397),
    [anon_sym___forceinline] = ACTIONS(5397),
    [anon_sym_thread_local] = ACTIONS(5397),
    [anon_sym___thread] = ACTIONS(5397),
    [anon_sym_const] = ACTIONS(5397),
    [anon_sym_constexpr] = ACTIONS(5397),
    [anon_sym_volatile] = ACTIONS(5397),
    [anon_sym_restrict] = ACTIONS(5397),
    [anon_sym___restrict__] = ACTIONS(5397),
    [anon_sym__Atomic] = ACTIONS(5397),
    [anon_sym__Noreturn] = ACTIONS(5397),
    [anon_sym_noreturn] = ACTIONS(5397),
    [anon_sym_mutable] = ACTIONS(5397),
    [anon_sym_constinit] = ACTIONS(5397),
    [anon_sym_consteval] = ACTIONS(5397),
    [anon_sym_alignas] = ACTIONS(5397),
    [anon_sym__Alignas] = ACTIONS(5397),
    [sym_primitive_type] = ACTIONS(5397),
    [anon_sym_enum] = ACTIONS(5397),
    [anon_sym_class] = ACTIONS(5397),
    [anon_sym_struct] = ACTIONS(5397),
    [anon_sym_union] = ACTIONS(5397),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5397),
    [anon_sym_decltype] = ACTIONS(5397),
    [sym_virtual] = ACTIONS(5397),
    [anon_sym_explicit] = ACTIONS(5397),
    [anon_sym_typename] = ACTIONS(5397),
    [anon_sym_template] = ACTIONS(5397),
    [anon_sym_operator] = ACTIONS(5397),
    [anon_sym_namespace] = ACTIONS(5687),
    [anon_sym_precise] = ACTIONS(5397),
    [anon_sym_shared] = ACTIONS(5397),
    [anon_sym_groupshared] = ACTIONS(5397),
    [anon_sym_uniform] = ACTIONS(5397),
    [anon_sym_row_major] = ACTIONS(5397),
    [anon_sym_column_major] = ACTIONS(5397),
    [anon_sym_globallycoherent] = ACTIONS(5397),
    [anon_sym_centroid] = ACTIONS(5397),
    [anon_sym_noperspective] = ACTIONS(5397),
    [anon_sym_nointerpolation] = ACTIONS(5397),
    [anon_sym_sample] = ACTIONS(5397),
    [anon_sym_linear] = ACTIONS(5397),
    [anon_sym_snorm] = ACTIONS(5397),
    [anon_sym_unorm] = ACTIONS(5397),
    [anon_sym_point] = ACTIONS(5397),
    [anon_sym_line] = ACTIONS(5397),
    [anon_sym_triangleadj] = ACTIONS(5397),
    [anon_sym_lineadj] = ACTIONS(5397),
    [anon_sym_triangle] = ACTIONS(5397),
  },
  [2355] = {
    [sym_attribute_specifier] = STATE(2269),
    [sym_enumerator_list] = STATE(2322),
    [sym__enum_base_clause] = STATE(2301),
    [sym_identifier] = ACTIONS(5689),
    [anon_sym_LPAREN2] = ACTIONS(5691),
    [anon_sym_TILDE] = ACTIONS(5691),
    [anon_sym_STAR] = ACTIONS(5691),
    [anon_sym_AMP_AMP] = ACTIONS(5691),
    [anon_sym_AMP] = ACTIONS(5689),
    [anon_sym_COLON] = ACTIONS(5640),
    [anon_sym_SEMI] = ACTIONS(5691),
    [anon_sym___extension__] = ACTIONS(5689),
    [anon_sym_in] = ACTIONS(5689),
    [anon_sym_out] = ACTIONS(5689),
    [anon_sym_inout] = ACTIONS(5689),
    [anon_sym_extern] = ACTIONS(5689),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5691),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5691),
    [anon_sym___declspec] = ACTIONS(5689),
    [anon_sym___based] = ACTIONS(5689),
    [anon_sym___cdecl] = ACTIONS(5689),
    [anon_sym___clrcall] = ACTIONS(5689),
    [anon_sym___stdcall] = ACTIONS(5689),
    [anon_sym___fastcall] = ACTIONS(5689),
    [anon_sym___thiscall] = ACTIONS(5689),
    [anon_sym___vectorcall] = ACTIONS(5689),
    [anon_sym_LBRACE] = ACTIONS(5523),
    [anon_sym_LBRACK] = ACTIONS(5689),
    [anon_sym_static] = ACTIONS(5689),
    [anon_sym_register] = ACTIONS(5689),
    [anon_sym_inline] = ACTIONS(5689),
    [anon_sym___inline] = ACTIONS(5689),
    [anon_sym___inline__] = ACTIONS(5689),
    [anon_sym___forceinline] = ACTIONS(5689),
    [anon_sym_thread_local] = ACTIONS(5689),
    [anon_sym___thread] = ACTIONS(5689),
    [anon_sym_const] = ACTIONS(5689),
    [anon_sym_constexpr] = ACTIONS(5689),
    [anon_sym_volatile] = ACTIONS(5689),
    [anon_sym_restrict] = ACTIONS(5689),
    [anon_sym___restrict__] = ACTIONS(5689),
    [anon_sym__Atomic] = ACTIONS(5689),
    [anon_sym__Noreturn] = ACTIONS(5689),
    [anon_sym_noreturn] = ACTIONS(5689),
    [anon_sym_mutable] = ACTIONS(5689),
    [anon_sym_constinit] = ACTIONS(5689),
    [anon_sym_consteval] = ACTIONS(5689),
    [anon_sym_alignas] = ACTIONS(5689),
    [anon_sym__Alignas] = ACTIONS(5689),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5689),
    [anon_sym_decltype] = ACTIONS(5689),
    [sym_virtual] = ACTIONS(5689),
    [anon_sym_template] = ACTIONS(5689),
    [anon_sym_operator] = ACTIONS(5689),
    [anon_sym_precise] = ACTIONS(5689),
    [anon_sym_shared] = ACTIONS(5689),
    [anon_sym_groupshared] = ACTIONS(5689),
    [anon_sym_uniform] = ACTIONS(5689),
    [anon_sym_row_major] = ACTIONS(5689),
    [anon_sym_column_major] = ACTIONS(5689),
    [anon_sym_globallycoherent] = ACTIONS(5689),
    [anon_sym_centroid] = ACTIONS(5689),
    [anon_sym_noperspective] = ACTIONS(5689),
    [anon_sym_nointerpolation] = ACTIONS(5689),
    [anon_sym_sample] = ACTIONS(5689),
    [anon_sym_linear] = ACTIONS(5689),
    [anon_sym_snorm] = ACTIONS(5689),
    [anon_sym_unorm] = ACTIONS(5689),
    [anon_sym_point] = ACTIONS(5689),
    [anon_sym_line] = ACTIONS(5689),
    [anon_sym_triangleadj] = ACTIONS(5689),
    [anon_sym_lineadj] = ACTIONS(5689),
    [anon_sym_triangle] = ACTIONS(5689),
  },
  [2356] = {
    [sym_identifier] = ACTIONS(2849),
    [anon_sym_LPAREN2] = ACTIONS(2851),
    [anon_sym_TILDE] = ACTIONS(2851),
    [anon_sym_STAR] = ACTIONS(2851),
    [anon_sym_AMP_AMP] = ACTIONS(2851),
    [anon_sym_AMP] = ACTIONS(2849),
    [anon_sym___extension__] = ACTIONS(2849),
    [anon_sym_typedef] = ACTIONS(5693),
    [anon_sym_in] = ACTIONS(2849),
    [anon_sym_out] = ACTIONS(2849),
    [anon_sym_inout] = ACTIONS(2849),
    [anon_sym_extern] = ACTIONS(2849),
    [anon_sym___attribute__] = ACTIONS(2849),
    [anon_sym_COLON_COLON] = ACTIONS(2851),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2851),
    [anon_sym___declspec] = ACTIONS(2849),
    [anon_sym___based] = ACTIONS(2849),
    [anon_sym_signed] = ACTIONS(2849),
    [anon_sym_unsigned] = ACTIONS(2849),
    [anon_sym_long] = ACTIONS(2849),
    [anon_sym_short] = ACTIONS(2849),
    [anon_sym_LBRACK] = ACTIONS(2849),
    [anon_sym_static] = ACTIONS(2849),
    [anon_sym_register] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2849),
    [anon_sym___inline] = ACTIONS(2849),
    [anon_sym___inline__] = ACTIONS(2849),
    [anon_sym___forceinline] = ACTIONS(2849),
    [anon_sym_thread_local] = ACTIONS(2849),
    [anon_sym___thread] = ACTIONS(2849),
    [anon_sym_const] = ACTIONS(2849),
    [anon_sym_constexpr] = ACTIONS(2849),
    [anon_sym_volatile] = ACTIONS(2849),
    [anon_sym_restrict] = ACTIONS(2849),
    [anon_sym___restrict__] = ACTIONS(2849),
    [anon_sym__Atomic] = ACTIONS(2849),
    [anon_sym__Noreturn] = ACTIONS(2849),
    [anon_sym_noreturn] = ACTIONS(2849),
    [anon_sym_mutable] = ACTIONS(2849),
    [anon_sym_constinit] = ACTIONS(2849),
    [anon_sym_consteval] = ACTIONS(2849),
    [anon_sym_alignas] = ACTIONS(2849),
    [anon_sym__Alignas] = ACTIONS(2849),
    [sym_primitive_type] = ACTIONS(2849),
    [anon_sym_enum] = ACTIONS(2849),
    [anon_sym_class] = ACTIONS(2849),
    [anon_sym_struct] = ACTIONS(2849),
    [anon_sym_union] = ACTIONS(2849),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2849),
    [anon_sym_decltype] = ACTIONS(2849),
    [sym_virtual] = ACTIONS(2849),
    [anon_sym_explicit] = ACTIONS(2849),
    [anon_sym_typename] = ACTIONS(2849),
    [anon_sym_template] = ACTIONS(2849),
    [anon_sym_operator] = ACTIONS(2849),
    [anon_sym_precise] = ACTIONS(2849),
    [anon_sym_shared] = ACTIONS(2849),
    [anon_sym_groupshared] = ACTIONS(2849),
    [anon_sym_uniform] = ACTIONS(2849),
    [anon_sym_row_major] = ACTIONS(2849),
    [anon_sym_column_major] = ACTIONS(2849),
    [anon_sym_globallycoherent] = ACTIONS(2849),
    [anon_sym_centroid] = ACTIONS(2849),
    [anon_sym_noperspective] = ACTIONS(2849),
    [anon_sym_nointerpolation] = ACTIONS(2849),
    [anon_sym_sample] = ACTIONS(2849),
    [anon_sym_linear] = ACTIONS(2849),
    [anon_sym_snorm] = ACTIONS(2849),
    [anon_sym_unorm] = ACTIONS(2849),
    [anon_sym_point] = ACTIONS(2849),
    [anon_sym_line] = ACTIONS(2849),
    [anon_sym_triangleadj] = ACTIONS(2849),
    [anon_sym_lineadj] = ACTIONS(2849),
    [anon_sym_triangle] = ACTIONS(2849),
  },
  [2357] = {
    [sym_template_argument_list] = STATE(2221),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2233),
    [sym_identifier] = ACTIONS(3822),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3830),
    [anon_sym_COMMA] = ACTIONS(5695),
    [anon_sym_LPAREN2] = ACTIONS(3830),
    [anon_sym_TILDE] = ACTIONS(3830),
    [anon_sym_STAR] = ACTIONS(3830),
    [anon_sym_AMP_AMP] = ACTIONS(3830),
    [anon_sym_AMP] = ACTIONS(3822),
    [anon_sym_LT] = ACTIONS(5628),
    [anon_sym_COLON] = ACTIONS(3822),
    [anon_sym___extension__] = ACTIONS(3822),
    [anon_sym_in] = ACTIONS(3822),
    [anon_sym_out] = ACTIONS(3822),
    [anon_sym_inout] = ACTIONS(3822),
    [anon_sym_extern] = ACTIONS(3822),
    [anon_sym___attribute__] = ACTIONS(3822),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3830),
    [anon_sym___declspec] = ACTIONS(3822),
    [anon_sym___based] = ACTIONS(3822),
    [anon_sym_signed] = ACTIONS(3848),
    [anon_sym_unsigned] = ACTIONS(3848),
    [anon_sym_long] = ACTIONS(3848),
    [anon_sym_short] = ACTIONS(3848),
    [anon_sym_LBRACK] = ACTIONS(3822),
    [anon_sym_static] = ACTIONS(3822),
    [anon_sym_EQ] = ACTIONS(5697),
    [anon_sym_register] = ACTIONS(3822),
    [anon_sym_inline] = ACTIONS(3822),
    [anon_sym___inline] = ACTIONS(3822),
    [anon_sym___inline__] = ACTIONS(3822),
    [anon_sym___forceinline] = ACTIONS(3822),
    [anon_sym_thread_local] = ACTIONS(3822),
    [anon_sym___thread] = ACTIONS(3822),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3822),
    [anon_sym_volatile] = ACTIONS(3822),
    [anon_sym_restrict] = ACTIONS(3822),
    [anon_sym___restrict__] = ACTIONS(3822),
    [anon_sym__Atomic] = ACTIONS(3822),
    [anon_sym__Noreturn] = ACTIONS(3822),
    [anon_sym_noreturn] = ACTIONS(3822),
    [anon_sym_mutable] = ACTIONS(3822),
    [anon_sym_constinit] = ACTIONS(3822),
    [anon_sym_consteval] = ACTIONS(3822),
    [anon_sym_alignas] = ACTIONS(3822),
    [anon_sym__Alignas] = ACTIONS(3822),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3822),
    [anon_sym_decltype] = ACTIONS(3822),
    [sym_virtual] = ACTIONS(3822),
    [anon_sym_template] = ACTIONS(3822),
    [anon_sym_GT2] = ACTIONS(5695),
    [anon_sym_operator] = ACTIONS(3822),
    [anon_sym_precise] = ACTIONS(3822),
    [anon_sym_shared] = ACTIONS(3822),
    [anon_sym_groupshared] = ACTIONS(3822),
    [anon_sym_uniform] = ACTIONS(3822),
    [anon_sym_row_major] = ACTIONS(3822),
    [anon_sym_column_major] = ACTIONS(3822),
    [anon_sym_globallycoherent] = ACTIONS(3822),
    [anon_sym_centroid] = ACTIONS(3822),
    [anon_sym_noperspective] = ACTIONS(3822),
    [anon_sym_nointerpolation] = ACTIONS(3822),
    [anon_sym_sample] = ACTIONS(3822),
    [anon_sym_linear] = ACTIONS(3822),
    [anon_sym_snorm] = ACTIONS(3822),
    [anon_sym_unorm] = ACTIONS(3822),
    [anon_sym_point] = ACTIONS(3822),
    [anon_sym_line] = ACTIONS(3822),
    [anon_sym_triangleadj] = ACTIONS(3822),
    [anon_sym_lineadj] = ACTIONS(3822),
    [anon_sym_triangle] = ACTIONS(3822),
  },
  [2358] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1905),
    [anon_sym_COMMA] = ACTIONS(1905),
    [anon_sym_RPAREN] = ACTIONS(1905),
    [anon_sym_LPAREN2] = ACTIONS(1905),
    [anon_sym_DASH] = ACTIONS(1903),
    [anon_sym_PLUS] = ACTIONS(1903),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_SLASH] = ACTIONS(1903),
    [anon_sym_PERCENT] = ACTIONS(1903),
    [anon_sym_PIPE_PIPE] = ACTIONS(1905),
    [anon_sym_AMP_AMP] = ACTIONS(1905),
    [anon_sym_PIPE] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1903),
    [anon_sym_AMP] = ACTIONS(1903),
    [anon_sym_EQ_EQ] = ACTIONS(1905),
    [anon_sym_BANG_EQ] = ACTIONS(1905),
    [anon_sym_GT] = ACTIONS(1903),
    [anon_sym_GT_EQ] = ACTIONS(1905),
    [anon_sym_LT_EQ] = ACTIONS(1903),
    [anon_sym_LT] = ACTIONS(1903),
    [anon_sym_LT_LT] = ACTIONS(1903),
    [anon_sym_GT_GT] = ACTIONS(1903),
    [anon_sym_COLON] = ACTIONS(1903),
    [anon_sym___extension__] = ACTIONS(1905),
    [anon_sym___attribute__] = ACTIONS(1905),
    [anon_sym_COLON_COLON] = ACTIONS(1905),
    [anon_sym_LBRACE] = ACTIONS(1905),
    [anon_sym_LBRACK] = ACTIONS(1905),
    [anon_sym_EQ] = ACTIONS(1903),
    [anon_sym_const] = ACTIONS(1903),
    [anon_sym_constexpr] = ACTIONS(1905),
    [anon_sym_volatile] = ACTIONS(1905),
    [anon_sym_restrict] = ACTIONS(1905),
    [anon_sym___restrict__] = ACTIONS(1905),
    [anon_sym__Atomic] = ACTIONS(1905),
    [anon_sym__Noreturn] = ACTIONS(1905),
    [anon_sym_noreturn] = ACTIONS(1905),
    [anon_sym_mutable] = ACTIONS(1905),
    [anon_sym_constinit] = ACTIONS(1905),
    [anon_sym_consteval] = ACTIONS(1905),
    [anon_sym_alignas] = ACTIONS(1905),
    [anon_sym__Alignas] = ACTIONS(1905),
    [anon_sym_QMARK] = ACTIONS(1905),
    [anon_sym_STAR_EQ] = ACTIONS(1905),
    [anon_sym_SLASH_EQ] = ACTIONS(1905),
    [anon_sym_PERCENT_EQ] = ACTIONS(1905),
    [anon_sym_PLUS_EQ] = ACTIONS(1905),
    [anon_sym_DASH_EQ] = ACTIONS(1905),
    [anon_sym_LT_LT_EQ] = ACTIONS(1905),
    [anon_sym_GT_GT_EQ] = ACTIONS(1905),
    [anon_sym_AMP_EQ] = ACTIONS(1905),
    [anon_sym_CARET_EQ] = ACTIONS(1905),
    [anon_sym_PIPE_EQ] = ACTIONS(1905),
    [anon_sym_and_eq] = ACTIONS(1905),
    [anon_sym_or_eq] = ACTIONS(1905),
    [anon_sym_xor_eq] = ACTIONS(1905),
    [anon_sym_LT_EQ_GT] = ACTIONS(1905),
    [anon_sym_or] = ACTIONS(1903),
    [anon_sym_and] = ACTIONS(1903),
    [anon_sym_bitor] = ACTIONS(1905),
    [anon_sym_xor] = ACTIONS(1903),
    [anon_sym_bitand] = ACTIONS(1905),
    [anon_sym_not_eq] = ACTIONS(1905),
    [anon_sym_DASH_DASH] = ACTIONS(1905),
    [anon_sym_PLUS_PLUS] = ACTIONS(1905),
    [anon_sym_DOT] = ACTIONS(1903),
    [anon_sym_DOT_STAR] = ACTIONS(1905),
    [anon_sym_DASH_GT] = ACTIONS(1903),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1905),
    [anon_sym_decltype] = ACTIONS(1905),
    [anon_sym_final] = ACTIONS(1905),
    [anon_sym_override] = ACTIONS(1905),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1905),
  },
  [2359] = {
    [sym_template_argument_list] = STATE(2221),
    [sym_identifier] = ACTIONS(1933),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1935),
    [anon_sym_COMMA] = ACTIONS(1935),
    [anon_sym_RPAREN] = ACTIONS(1935),
    [anon_sym_LPAREN2] = ACTIONS(1935),
    [anon_sym_TILDE] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1935),
    [anon_sym_AMP_AMP] = ACTIONS(1935),
    [anon_sym_AMP] = ACTIONS(1933),
    [anon_sym_LT] = ACTIONS(5628),
    [anon_sym_COLON] = ACTIONS(1933),
    [anon_sym___extension__] = ACTIONS(1933),
    [anon_sym_in] = ACTIONS(1933),
    [anon_sym_out] = ACTIONS(1933),
    [anon_sym_inout] = ACTIONS(1933),
    [anon_sym_extern] = ACTIONS(1933),
    [anon_sym___attribute__] = ACTIONS(1933),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1935),
    [anon_sym___declspec] = ACTIONS(1933),
    [anon_sym___based] = ACTIONS(1933),
    [anon_sym_LBRACE] = ACTIONS(1935),
    [anon_sym_LBRACK] = ACTIONS(1933),
    [anon_sym_static] = ACTIONS(1933),
    [anon_sym_EQ] = ACTIONS(1935),
    [anon_sym_register] = ACTIONS(1933),
    [anon_sym_inline] = ACTIONS(1933),
    [anon_sym___inline] = ACTIONS(1933),
    [anon_sym___inline__] = ACTIONS(1933),
    [anon_sym___forceinline] = ACTIONS(1933),
    [anon_sym_thread_local] = ACTIONS(1933),
    [anon_sym___thread] = ACTIONS(1933),
    [anon_sym_const] = ACTIONS(1933),
    [anon_sym_constexpr] = ACTIONS(1933),
    [anon_sym_volatile] = ACTIONS(1933),
    [anon_sym_restrict] = ACTIONS(1933),
    [anon_sym___restrict__] = ACTIONS(1933),
    [anon_sym__Atomic] = ACTIONS(1933),
    [anon_sym__Noreturn] = ACTIONS(1933),
    [anon_sym_noreturn] = ACTIONS(1933),
    [anon_sym_mutable] = ACTIONS(1933),
    [anon_sym_constinit] = ACTIONS(1933),
    [anon_sym_consteval] = ACTIONS(1933),
    [anon_sym_alignas] = ACTIONS(1933),
    [anon_sym__Alignas] = ACTIONS(1933),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1933),
    [anon_sym_decltype] = ACTIONS(1933),
    [anon_sym_final] = ACTIONS(1933),
    [anon_sym_override] = ACTIONS(1933),
    [sym_virtual] = ACTIONS(1933),
    [anon_sym_template] = ACTIONS(1933),
    [anon_sym_GT2] = ACTIONS(1935),
    [anon_sym_operator] = ACTIONS(1933),
    [anon_sym_precise] = ACTIONS(1933),
    [anon_sym_shared] = ACTIONS(1933),
    [anon_sym_groupshared] = ACTIONS(1933),
    [anon_sym_uniform] = ACTIONS(1933),
    [anon_sym_row_major] = ACTIONS(1933),
    [anon_sym_column_major] = ACTIONS(1933),
    [anon_sym_globallycoherent] = ACTIONS(1933),
    [anon_sym_centroid] = ACTIONS(1933),
    [anon_sym_noperspective] = ACTIONS(1933),
    [anon_sym_nointerpolation] = ACTIONS(1933),
    [anon_sym_sample] = ACTIONS(1933),
    [anon_sym_linear] = ACTIONS(1933),
    [anon_sym_snorm] = ACTIONS(1933),
    [anon_sym_unorm] = ACTIONS(1933),
    [anon_sym_point] = ACTIONS(1933),
    [anon_sym_line] = ACTIONS(1933),
    [anon_sym_triangleadj] = ACTIONS(1933),
    [anon_sym_lineadj] = ACTIONS(1933),
    [anon_sym_triangle] = ACTIONS(1933),
  },
  [2360] = {
    [sym_identifier] = ACTIONS(5435),
    [anon_sym_LPAREN2] = ACTIONS(5437),
    [anon_sym_TILDE] = ACTIONS(5437),
    [anon_sym_STAR] = ACTIONS(5437),
    [anon_sym_AMP_AMP] = ACTIONS(5437),
    [anon_sym_AMP] = ACTIONS(5435),
    [anon_sym___extension__] = ACTIONS(5435),
    [anon_sym_in] = ACTIONS(5435),
    [anon_sym_out] = ACTIONS(5435),
    [anon_sym_inout] = ACTIONS(5435),
    [anon_sym_extern] = ACTIONS(5435),
    [anon_sym___attribute__] = ACTIONS(5435),
    [anon_sym_COLON_COLON] = ACTIONS(5437),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5437),
    [anon_sym___declspec] = ACTIONS(5435),
    [anon_sym___based] = ACTIONS(5435),
    [anon_sym_signed] = ACTIONS(5435),
    [anon_sym_unsigned] = ACTIONS(5435),
    [anon_sym_long] = ACTIONS(5435),
    [anon_sym_short] = ACTIONS(5435),
    [anon_sym_LBRACK] = ACTIONS(5435),
    [anon_sym_static] = ACTIONS(5435),
    [anon_sym_register] = ACTIONS(5435),
    [anon_sym_inline] = ACTIONS(5435),
    [anon_sym___inline] = ACTIONS(5435),
    [anon_sym___inline__] = ACTIONS(5435),
    [anon_sym___forceinline] = ACTIONS(5435),
    [anon_sym_thread_local] = ACTIONS(5435),
    [anon_sym___thread] = ACTIONS(5435),
    [anon_sym_const] = ACTIONS(5435),
    [anon_sym_constexpr] = ACTIONS(5435),
    [anon_sym_volatile] = ACTIONS(5435),
    [anon_sym_restrict] = ACTIONS(5435),
    [anon_sym___restrict__] = ACTIONS(5435),
    [anon_sym__Atomic] = ACTIONS(5435),
    [anon_sym__Noreturn] = ACTIONS(5435),
    [anon_sym_noreturn] = ACTIONS(5435),
    [anon_sym_mutable] = ACTIONS(5435),
    [anon_sym_constinit] = ACTIONS(5435),
    [anon_sym_consteval] = ACTIONS(5435),
    [anon_sym_alignas] = ACTIONS(5435),
    [anon_sym__Alignas] = ACTIONS(5435),
    [sym_primitive_type] = ACTIONS(5435),
    [anon_sym_enum] = ACTIONS(5435),
    [anon_sym_class] = ACTIONS(5435),
    [anon_sym_struct] = ACTIONS(5435),
    [anon_sym_union] = ACTIONS(5435),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5435),
    [anon_sym_decltype] = ACTIONS(5435),
    [sym_virtual] = ACTIONS(5435),
    [anon_sym_explicit] = ACTIONS(5435),
    [anon_sym_typename] = ACTIONS(5435),
    [anon_sym_template] = ACTIONS(5435),
    [anon_sym_operator] = ACTIONS(5435),
    [anon_sym_precise] = ACTIONS(5435),
    [anon_sym_shared] = ACTIONS(5435),
    [anon_sym_groupshared] = ACTIONS(5435),
    [anon_sym_uniform] = ACTIONS(5435),
    [anon_sym_row_major] = ACTIONS(5435),
    [anon_sym_column_major] = ACTIONS(5435),
    [anon_sym_globallycoherent] = ACTIONS(5435),
    [anon_sym_centroid] = ACTIONS(5435),
    [anon_sym_noperspective] = ACTIONS(5435),
    [anon_sym_nointerpolation] = ACTIONS(5435),
    [anon_sym_sample] = ACTIONS(5435),
    [anon_sym_linear] = ACTIONS(5435),
    [anon_sym_snorm] = ACTIONS(5435),
    [anon_sym_unorm] = ACTIONS(5435),
    [anon_sym_point] = ACTIONS(5435),
    [anon_sym_line] = ACTIONS(5435),
    [anon_sym_triangleadj] = ACTIONS(5435),
    [anon_sym_lineadj] = ACTIONS(5435),
    [anon_sym_triangle] = ACTIONS(5435),
  },
  [2361] = {
    [sym_identifier] = ACTIONS(3657),
    [anon_sym_LPAREN2] = ACTIONS(3659),
    [anon_sym_TILDE] = ACTIONS(3659),
    [anon_sym_STAR] = ACTIONS(3659),
    [anon_sym_AMP_AMP] = ACTIONS(3659),
    [anon_sym_AMP] = ACTIONS(3657),
    [anon_sym___extension__] = ACTIONS(3657),
    [anon_sym_in] = ACTIONS(3657),
    [anon_sym_out] = ACTIONS(3657),
    [anon_sym_inout] = ACTIONS(3657),
    [anon_sym_extern] = ACTIONS(3657),
    [anon_sym___attribute__] = ACTIONS(3657),
    [anon_sym_COLON_COLON] = ACTIONS(3659),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3659),
    [anon_sym___declspec] = ACTIONS(3657),
    [anon_sym___based] = ACTIONS(3657),
    [anon_sym_signed] = ACTIONS(3657),
    [anon_sym_unsigned] = ACTIONS(3657),
    [anon_sym_long] = ACTIONS(3657),
    [anon_sym_short] = ACTIONS(3657),
    [anon_sym_LBRACK] = ACTIONS(3657),
    [anon_sym_static] = ACTIONS(3657),
    [anon_sym_register] = ACTIONS(3657),
    [anon_sym_inline] = ACTIONS(3657),
    [anon_sym___inline] = ACTIONS(3657),
    [anon_sym___inline__] = ACTIONS(3657),
    [anon_sym___forceinline] = ACTIONS(3657),
    [anon_sym_thread_local] = ACTIONS(3657),
    [anon_sym___thread] = ACTIONS(3657),
    [anon_sym_const] = ACTIONS(3657),
    [anon_sym_constexpr] = ACTIONS(3657),
    [anon_sym_volatile] = ACTIONS(3657),
    [anon_sym_restrict] = ACTIONS(3657),
    [anon_sym___restrict__] = ACTIONS(3657),
    [anon_sym__Atomic] = ACTIONS(3657),
    [anon_sym__Noreturn] = ACTIONS(3657),
    [anon_sym_noreturn] = ACTIONS(3657),
    [anon_sym_mutable] = ACTIONS(3657),
    [anon_sym_constinit] = ACTIONS(3657),
    [anon_sym_consteval] = ACTIONS(3657),
    [anon_sym_alignas] = ACTIONS(3657),
    [anon_sym__Alignas] = ACTIONS(3657),
    [sym_primitive_type] = ACTIONS(3657),
    [anon_sym_enum] = ACTIONS(3657),
    [anon_sym_class] = ACTIONS(3657),
    [anon_sym_struct] = ACTIONS(3657),
    [anon_sym_union] = ACTIONS(3657),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3657),
    [anon_sym_decltype] = ACTIONS(3657),
    [sym_virtual] = ACTIONS(3657),
    [anon_sym_explicit] = ACTIONS(3657),
    [anon_sym_typename] = ACTIONS(3657),
    [anon_sym_template] = ACTIONS(3657),
    [anon_sym_operator] = ACTIONS(3657),
    [anon_sym_precise] = ACTIONS(3657),
    [anon_sym_shared] = ACTIONS(3657),
    [anon_sym_groupshared] = ACTIONS(3657),
    [anon_sym_uniform] = ACTIONS(3657),
    [anon_sym_row_major] = ACTIONS(3657),
    [anon_sym_column_major] = ACTIONS(3657),
    [anon_sym_globallycoherent] = ACTIONS(3657),
    [anon_sym_centroid] = ACTIONS(3657),
    [anon_sym_noperspective] = ACTIONS(3657),
    [anon_sym_nointerpolation] = ACTIONS(3657),
    [anon_sym_sample] = ACTIONS(3657),
    [anon_sym_linear] = ACTIONS(3657),
    [anon_sym_snorm] = ACTIONS(3657),
    [anon_sym_unorm] = ACTIONS(3657),
    [anon_sym_point] = ACTIONS(3657),
    [anon_sym_line] = ACTIONS(3657),
    [anon_sym_triangleadj] = ACTIONS(3657),
    [anon_sym_lineadj] = ACTIONS(3657),
    [anon_sym_triangle] = ACTIONS(3657),
  },
  [2362] = {
    [sym_identifier] = ACTIONS(3631),
    [anon_sym_LPAREN2] = ACTIONS(3633),
    [anon_sym_TILDE] = ACTIONS(3633),
    [anon_sym_STAR] = ACTIONS(3633),
    [anon_sym_AMP_AMP] = ACTIONS(3633),
    [anon_sym_AMP] = ACTIONS(3631),
    [anon_sym___extension__] = ACTIONS(3631),
    [anon_sym_in] = ACTIONS(3631),
    [anon_sym_out] = ACTIONS(3631),
    [anon_sym_inout] = ACTIONS(3631),
    [anon_sym_extern] = ACTIONS(3631),
    [anon_sym___attribute__] = ACTIONS(3631),
    [anon_sym_COLON_COLON] = ACTIONS(3633),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3633),
    [anon_sym___declspec] = ACTIONS(3631),
    [anon_sym___based] = ACTIONS(3631),
    [anon_sym_signed] = ACTIONS(3631),
    [anon_sym_unsigned] = ACTIONS(3631),
    [anon_sym_long] = ACTIONS(3631),
    [anon_sym_short] = ACTIONS(3631),
    [anon_sym_LBRACK] = ACTIONS(3631),
    [anon_sym_static] = ACTIONS(3631),
    [anon_sym_register] = ACTIONS(3631),
    [anon_sym_inline] = ACTIONS(3631),
    [anon_sym___inline] = ACTIONS(3631),
    [anon_sym___inline__] = ACTIONS(3631),
    [anon_sym___forceinline] = ACTIONS(3631),
    [anon_sym_thread_local] = ACTIONS(3631),
    [anon_sym___thread] = ACTIONS(3631),
    [anon_sym_const] = ACTIONS(3631),
    [anon_sym_constexpr] = ACTIONS(3631),
    [anon_sym_volatile] = ACTIONS(3631),
    [anon_sym_restrict] = ACTIONS(3631),
    [anon_sym___restrict__] = ACTIONS(3631),
    [anon_sym__Atomic] = ACTIONS(3631),
    [anon_sym__Noreturn] = ACTIONS(3631),
    [anon_sym_noreturn] = ACTIONS(3631),
    [anon_sym_mutable] = ACTIONS(3631),
    [anon_sym_constinit] = ACTIONS(3631),
    [anon_sym_consteval] = ACTIONS(3631),
    [anon_sym_alignas] = ACTIONS(3631),
    [anon_sym__Alignas] = ACTIONS(3631),
    [sym_primitive_type] = ACTIONS(3631),
    [anon_sym_enum] = ACTIONS(3631),
    [anon_sym_class] = ACTIONS(3631),
    [anon_sym_struct] = ACTIONS(3631),
    [anon_sym_union] = ACTIONS(3631),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3631),
    [anon_sym_decltype] = ACTIONS(3631),
    [sym_virtual] = ACTIONS(3631),
    [anon_sym_explicit] = ACTIONS(3631),
    [anon_sym_typename] = ACTIONS(3631),
    [anon_sym_template] = ACTIONS(3631),
    [anon_sym_operator] = ACTIONS(3631),
    [anon_sym_precise] = ACTIONS(3631),
    [anon_sym_shared] = ACTIONS(3631),
    [anon_sym_groupshared] = ACTIONS(3631),
    [anon_sym_uniform] = ACTIONS(3631),
    [anon_sym_row_major] = ACTIONS(3631),
    [anon_sym_column_major] = ACTIONS(3631),
    [anon_sym_globallycoherent] = ACTIONS(3631),
    [anon_sym_centroid] = ACTIONS(3631),
    [anon_sym_noperspective] = ACTIONS(3631),
    [anon_sym_nointerpolation] = ACTIONS(3631),
    [anon_sym_sample] = ACTIONS(3631),
    [anon_sym_linear] = ACTIONS(3631),
    [anon_sym_snorm] = ACTIONS(3631),
    [anon_sym_unorm] = ACTIONS(3631),
    [anon_sym_point] = ACTIONS(3631),
    [anon_sym_line] = ACTIONS(3631),
    [anon_sym_triangleadj] = ACTIONS(3631),
    [anon_sym_lineadj] = ACTIONS(3631),
    [anon_sym_triangle] = ACTIONS(3631),
  },
  [2363] = {
    [sym_identifier] = ACTIONS(1953),
    [anon_sym_COMMA] = ACTIONS(1955),
    [anon_sym_RPAREN] = ACTIONS(1955),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_PIPE_PIPE] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym_COLON] = ACTIONS(1955),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym_in] = ACTIONS(1953),
    [anon_sym_out] = ACTIONS(1953),
    [anon_sym_inout] = ACTIONS(1953),
    [anon_sym_extern] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1955),
    [anon_sym___declspec] = ACTIONS(1953),
    [anon_sym___based] = ACTIONS(1953),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_LBRACK] = ACTIONS(1953),
    [anon_sym_static] = ACTIONS(1953),
    [anon_sym_EQ] = ACTIONS(1955),
    [anon_sym_register] = ACTIONS(1953),
    [anon_sym_inline] = ACTIONS(1953),
    [anon_sym___inline] = ACTIONS(1953),
    [anon_sym___inline__] = ACTIONS(1953),
    [anon_sym___forceinline] = ACTIONS(1953),
    [anon_sym_thread_local] = ACTIONS(1953),
    [anon_sym___thread] = ACTIONS(1953),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [anon_sym_or] = ACTIONS(1953),
    [anon_sym_and] = ACTIONS(1953),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
    [sym_virtual] = ACTIONS(1953),
    [anon_sym_GT2] = ACTIONS(1955),
    [anon_sym_operator] = ACTIONS(1953),
    [anon_sym_try] = ACTIONS(1953),
    [anon_sym_requires] = ACTIONS(1953),
    [anon_sym_precise] = ACTIONS(1953),
    [anon_sym_shared] = ACTIONS(1953),
    [anon_sym_groupshared] = ACTIONS(1953),
    [anon_sym_uniform] = ACTIONS(1953),
    [anon_sym_row_major] = ACTIONS(1953),
    [anon_sym_column_major] = ACTIONS(1953),
    [anon_sym_globallycoherent] = ACTIONS(1953),
    [anon_sym_centroid] = ACTIONS(1953),
    [anon_sym_noperspective] = ACTIONS(1953),
    [anon_sym_nointerpolation] = ACTIONS(1953),
    [anon_sym_sample] = ACTIONS(1953),
    [anon_sym_linear] = ACTIONS(1953),
    [anon_sym_snorm] = ACTIONS(1953),
    [anon_sym_unorm] = ACTIONS(1953),
    [anon_sym_point] = ACTIONS(1953),
    [anon_sym_line] = ACTIONS(1953),
    [anon_sym_triangleadj] = ACTIONS(1953),
    [anon_sym_lineadj] = ACTIONS(1953),
    [anon_sym_triangle] = ACTIONS(1953),
  },
  [2364] = {
    [sym_identifier] = ACTIONS(5397),
    [anon_sym_LPAREN2] = ACTIONS(5399),
    [anon_sym_TILDE] = ACTIONS(5399),
    [anon_sym_STAR] = ACTIONS(5399),
    [anon_sym_AMP_AMP] = ACTIONS(5399),
    [anon_sym_AMP] = ACTIONS(5397),
    [anon_sym___extension__] = ACTIONS(5397),
    [anon_sym_in] = ACTIONS(5397),
    [anon_sym_out] = ACTIONS(5397),
    [anon_sym_inout] = ACTIONS(5397),
    [anon_sym_extern] = ACTIONS(5397),
    [anon_sym___attribute__] = ACTIONS(5397),
    [anon_sym_COLON_COLON] = ACTIONS(5399),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5399),
    [anon_sym___declspec] = ACTIONS(5397),
    [anon_sym___based] = ACTIONS(5397),
    [anon_sym_signed] = ACTIONS(5397),
    [anon_sym_unsigned] = ACTIONS(5397),
    [anon_sym_long] = ACTIONS(5397),
    [anon_sym_short] = ACTIONS(5397),
    [anon_sym_LBRACK] = ACTIONS(5397),
    [anon_sym_static] = ACTIONS(5397),
    [anon_sym_register] = ACTIONS(5397),
    [anon_sym_inline] = ACTIONS(5397),
    [anon_sym___inline] = ACTIONS(5397),
    [anon_sym___inline__] = ACTIONS(5397),
    [anon_sym___forceinline] = ACTIONS(5397),
    [anon_sym_thread_local] = ACTIONS(5397),
    [anon_sym___thread] = ACTIONS(5397),
    [anon_sym_const] = ACTIONS(5397),
    [anon_sym_constexpr] = ACTIONS(5397),
    [anon_sym_volatile] = ACTIONS(5397),
    [anon_sym_restrict] = ACTIONS(5397),
    [anon_sym___restrict__] = ACTIONS(5397),
    [anon_sym__Atomic] = ACTIONS(5397),
    [anon_sym__Noreturn] = ACTIONS(5397),
    [anon_sym_noreturn] = ACTIONS(5397),
    [anon_sym_mutable] = ACTIONS(5397),
    [anon_sym_constinit] = ACTIONS(5397),
    [anon_sym_consteval] = ACTIONS(5397),
    [anon_sym_alignas] = ACTIONS(5397),
    [anon_sym__Alignas] = ACTIONS(5397),
    [sym_primitive_type] = ACTIONS(5397),
    [anon_sym_enum] = ACTIONS(5397),
    [anon_sym_class] = ACTIONS(5397),
    [anon_sym_struct] = ACTIONS(5397),
    [anon_sym_union] = ACTIONS(5397),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5397),
    [anon_sym_decltype] = ACTIONS(5397),
    [sym_virtual] = ACTIONS(5397),
    [anon_sym_explicit] = ACTIONS(5397),
    [anon_sym_typename] = ACTIONS(5397),
    [anon_sym_template] = ACTIONS(5397),
    [anon_sym_operator] = ACTIONS(5397),
    [anon_sym_precise] = ACTIONS(5397),
    [anon_sym_shared] = ACTIONS(5397),
    [anon_sym_groupshared] = ACTIONS(5397),
    [anon_sym_uniform] = ACTIONS(5397),
    [anon_sym_row_major] = ACTIONS(5397),
    [anon_sym_column_major] = ACTIONS(5397),
    [anon_sym_globallycoherent] = ACTIONS(5397),
    [anon_sym_centroid] = ACTIONS(5397),
    [anon_sym_noperspective] = ACTIONS(5397),
    [anon_sym_nointerpolation] = ACTIONS(5397),
    [anon_sym_sample] = ACTIONS(5397),
    [anon_sym_linear] = ACTIONS(5397),
    [anon_sym_snorm] = ACTIONS(5397),
    [anon_sym_unorm] = ACTIONS(5397),
    [anon_sym_point] = ACTIONS(5397),
    [anon_sym_line] = ACTIONS(5397),
    [anon_sym_triangleadj] = ACTIONS(5397),
    [anon_sym_lineadj] = ACTIONS(5397),
    [anon_sym_triangle] = ACTIONS(5397),
  },
  [2365] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1919),
    [anon_sym_COMMA] = ACTIONS(1919),
    [anon_sym_RPAREN] = ACTIONS(1919),
    [anon_sym_LPAREN2] = ACTIONS(1919),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1917),
    [anon_sym_SLASH] = ACTIONS(1917),
    [anon_sym_PERCENT] = ACTIONS(1917),
    [anon_sym_PIPE_PIPE] = ACTIONS(1919),
    [anon_sym_AMP_AMP] = ACTIONS(1919),
    [anon_sym_PIPE] = ACTIONS(1917),
    [anon_sym_CARET] = ACTIONS(1917),
    [anon_sym_AMP] = ACTIONS(1917),
    [anon_sym_EQ_EQ] = ACTIONS(1919),
    [anon_sym_BANG_EQ] = ACTIONS(1919),
    [anon_sym_GT] = ACTIONS(1917),
    [anon_sym_GT_EQ] = ACTIONS(1919),
    [anon_sym_LT_EQ] = ACTIONS(1917),
    [anon_sym_LT] = ACTIONS(1917),
    [anon_sym_LT_LT] = ACTIONS(1917),
    [anon_sym_GT_GT] = ACTIONS(1917),
    [anon_sym_COLON] = ACTIONS(1917),
    [anon_sym___extension__] = ACTIONS(1919),
    [anon_sym___attribute__] = ACTIONS(1919),
    [anon_sym_COLON_COLON] = ACTIONS(1919),
    [anon_sym_LBRACE] = ACTIONS(1919),
    [anon_sym_LBRACK] = ACTIONS(1919),
    [anon_sym_EQ] = ACTIONS(1917),
    [anon_sym_const] = ACTIONS(1917),
    [anon_sym_constexpr] = ACTIONS(1919),
    [anon_sym_volatile] = ACTIONS(1919),
    [anon_sym_restrict] = ACTIONS(1919),
    [anon_sym___restrict__] = ACTIONS(1919),
    [anon_sym__Atomic] = ACTIONS(1919),
    [anon_sym__Noreturn] = ACTIONS(1919),
    [anon_sym_noreturn] = ACTIONS(1919),
    [anon_sym_mutable] = ACTIONS(1919),
    [anon_sym_constinit] = ACTIONS(1919),
    [anon_sym_consteval] = ACTIONS(1919),
    [anon_sym_alignas] = ACTIONS(1919),
    [anon_sym__Alignas] = ACTIONS(1919),
    [anon_sym_QMARK] = ACTIONS(1919),
    [anon_sym_STAR_EQ] = ACTIONS(1919),
    [anon_sym_SLASH_EQ] = ACTIONS(1919),
    [anon_sym_PERCENT_EQ] = ACTIONS(1919),
    [anon_sym_PLUS_EQ] = ACTIONS(1919),
    [anon_sym_DASH_EQ] = ACTIONS(1919),
    [anon_sym_LT_LT_EQ] = ACTIONS(1919),
    [anon_sym_GT_GT_EQ] = ACTIONS(1919),
    [anon_sym_AMP_EQ] = ACTIONS(1919),
    [anon_sym_CARET_EQ] = ACTIONS(1919),
    [anon_sym_PIPE_EQ] = ACTIONS(1919),
    [anon_sym_and_eq] = ACTIONS(1919),
    [anon_sym_or_eq] = ACTIONS(1919),
    [anon_sym_xor_eq] = ACTIONS(1919),
    [anon_sym_LT_EQ_GT] = ACTIONS(1919),
    [anon_sym_or] = ACTIONS(1917),
    [anon_sym_and] = ACTIONS(1917),
    [anon_sym_bitor] = ACTIONS(1919),
    [anon_sym_xor] = ACTIONS(1917),
    [anon_sym_bitand] = ACTIONS(1919),
    [anon_sym_not_eq] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DOT] = ACTIONS(1917),
    [anon_sym_DOT_STAR] = ACTIONS(1919),
    [anon_sym_DASH_GT] = ACTIONS(1917),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1919),
    [anon_sym_decltype] = ACTIONS(1919),
    [anon_sym_final] = ACTIONS(1919),
    [anon_sym_override] = ACTIONS(1919),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1919),
  },
  [2366] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1901),
    [anon_sym_COMMA] = ACTIONS(1901),
    [anon_sym_RPAREN] = ACTIONS(1901),
    [anon_sym_LPAREN2] = ACTIONS(1901),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1899),
    [anon_sym_SLASH] = ACTIONS(1899),
    [anon_sym_PERCENT] = ACTIONS(1899),
    [anon_sym_PIPE_PIPE] = ACTIONS(1901),
    [anon_sym_AMP_AMP] = ACTIONS(1901),
    [anon_sym_PIPE] = ACTIONS(1899),
    [anon_sym_CARET] = ACTIONS(1899),
    [anon_sym_AMP] = ACTIONS(1899),
    [anon_sym_EQ_EQ] = ACTIONS(1901),
    [anon_sym_BANG_EQ] = ACTIONS(1901),
    [anon_sym_GT] = ACTIONS(1899),
    [anon_sym_GT_EQ] = ACTIONS(1901),
    [anon_sym_LT_EQ] = ACTIONS(1899),
    [anon_sym_LT] = ACTIONS(1899),
    [anon_sym_LT_LT] = ACTIONS(1899),
    [anon_sym_GT_GT] = ACTIONS(1899),
    [anon_sym_COLON] = ACTIONS(1899),
    [anon_sym___extension__] = ACTIONS(1901),
    [anon_sym___attribute__] = ACTIONS(1901),
    [anon_sym_COLON_COLON] = ACTIONS(1901),
    [anon_sym_LBRACE] = ACTIONS(1901),
    [anon_sym_LBRACK] = ACTIONS(1901),
    [anon_sym_EQ] = ACTIONS(1899),
    [anon_sym_const] = ACTIONS(1899),
    [anon_sym_constexpr] = ACTIONS(1901),
    [anon_sym_volatile] = ACTIONS(1901),
    [anon_sym_restrict] = ACTIONS(1901),
    [anon_sym___restrict__] = ACTIONS(1901),
    [anon_sym__Atomic] = ACTIONS(1901),
    [anon_sym__Noreturn] = ACTIONS(1901),
    [anon_sym_noreturn] = ACTIONS(1901),
    [anon_sym_mutable] = ACTIONS(1901),
    [anon_sym_constinit] = ACTIONS(1901),
    [anon_sym_consteval] = ACTIONS(1901),
    [anon_sym_alignas] = ACTIONS(1901),
    [anon_sym__Alignas] = ACTIONS(1901),
    [anon_sym_QMARK] = ACTIONS(1901),
    [anon_sym_STAR_EQ] = ACTIONS(1901),
    [anon_sym_SLASH_EQ] = ACTIONS(1901),
    [anon_sym_PERCENT_EQ] = ACTIONS(1901),
    [anon_sym_PLUS_EQ] = ACTIONS(1901),
    [anon_sym_DASH_EQ] = ACTIONS(1901),
    [anon_sym_LT_LT_EQ] = ACTIONS(1901),
    [anon_sym_GT_GT_EQ] = ACTIONS(1901),
    [anon_sym_AMP_EQ] = ACTIONS(1901),
    [anon_sym_CARET_EQ] = ACTIONS(1901),
    [anon_sym_PIPE_EQ] = ACTIONS(1901),
    [anon_sym_and_eq] = ACTIONS(1901),
    [anon_sym_or_eq] = ACTIONS(1901),
    [anon_sym_xor_eq] = ACTIONS(1901),
    [anon_sym_LT_EQ_GT] = ACTIONS(1901),
    [anon_sym_or] = ACTIONS(1899),
    [anon_sym_and] = ACTIONS(1899),
    [anon_sym_bitor] = ACTIONS(1901),
    [anon_sym_xor] = ACTIONS(1899),
    [anon_sym_bitand] = ACTIONS(1901),
    [anon_sym_not_eq] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DOT] = ACTIONS(1899),
    [anon_sym_DOT_STAR] = ACTIONS(1901),
    [anon_sym_DASH_GT] = ACTIONS(1899),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1901),
    [anon_sym_decltype] = ACTIONS(1901),
    [anon_sym_final] = ACTIONS(1901),
    [anon_sym_override] = ACTIONS(1901),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1901),
  },
  [2367] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1889),
    [anon_sym_COMMA] = ACTIONS(1889),
    [anon_sym_RPAREN] = ACTIONS(1889),
    [anon_sym_LPAREN2] = ACTIONS(1889),
    [anon_sym_DASH] = ACTIONS(1887),
    [anon_sym_PLUS] = ACTIONS(1887),
    [anon_sym_STAR] = ACTIONS(1887),
    [anon_sym_SLASH] = ACTIONS(1887),
    [anon_sym_PERCENT] = ACTIONS(1887),
    [anon_sym_PIPE_PIPE] = ACTIONS(1889),
    [anon_sym_AMP_AMP] = ACTIONS(1889),
    [anon_sym_PIPE] = ACTIONS(1887),
    [anon_sym_CARET] = ACTIONS(1887),
    [anon_sym_AMP] = ACTIONS(1887),
    [anon_sym_EQ_EQ] = ACTIONS(1889),
    [anon_sym_BANG_EQ] = ACTIONS(1889),
    [anon_sym_GT] = ACTIONS(1887),
    [anon_sym_GT_EQ] = ACTIONS(1889),
    [anon_sym_LT_EQ] = ACTIONS(1887),
    [anon_sym_LT] = ACTIONS(1887),
    [anon_sym_LT_LT] = ACTIONS(1887),
    [anon_sym_GT_GT] = ACTIONS(1887),
    [anon_sym_COLON] = ACTIONS(1887),
    [anon_sym___extension__] = ACTIONS(1889),
    [anon_sym___attribute__] = ACTIONS(1889),
    [anon_sym_COLON_COLON] = ACTIONS(1889),
    [anon_sym_LBRACE] = ACTIONS(1889),
    [anon_sym_LBRACK] = ACTIONS(1889),
    [anon_sym_EQ] = ACTIONS(1887),
    [anon_sym_const] = ACTIONS(1887),
    [anon_sym_constexpr] = ACTIONS(1889),
    [anon_sym_volatile] = ACTIONS(1889),
    [anon_sym_restrict] = ACTIONS(1889),
    [anon_sym___restrict__] = ACTIONS(1889),
    [anon_sym__Atomic] = ACTIONS(1889),
    [anon_sym__Noreturn] = ACTIONS(1889),
    [anon_sym_noreturn] = ACTIONS(1889),
    [anon_sym_mutable] = ACTIONS(1889),
    [anon_sym_constinit] = ACTIONS(1889),
    [anon_sym_consteval] = ACTIONS(1889),
    [anon_sym_alignas] = ACTIONS(1889),
    [anon_sym__Alignas] = ACTIONS(1889),
    [anon_sym_QMARK] = ACTIONS(1889),
    [anon_sym_STAR_EQ] = ACTIONS(1889),
    [anon_sym_SLASH_EQ] = ACTIONS(1889),
    [anon_sym_PERCENT_EQ] = ACTIONS(1889),
    [anon_sym_PLUS_EQ] = ACTIONS(1889),
    [anon_sym_DASH_EQ] = ACTIONS(1889),
    [anon_sym_LT_LT_EQ] = ACTIONS(1889),
    [anon_sym_GT_GT_EQ] = ACTIONS(1889),
    [anon_sym_AMP_EQ] = ACTIONS(1889),
    [anon_sym_CARET_EQ] = ACTIONS(1889),
    [anon_sym_PIPE_EQ] = ACTIONS(1889),
    [anon_sym_and_eq] = ACTIONS(1889),
    [anon_sym_or_eq] = ACTIONS(1889),
    [anon_sym_xor_eq] = ACTIONS(1889),
    [anon_sym_LT_EQ_GT] = ACTIONS(1889),
    [anon_sym_or] = ACTIONS(1887),
    [anon_sym_and] = ACTIONS(1887),
    [anon_sym_bitor] = ACTIONS(1889),
    [anon_sym_xor] = ACTIONS(1887),
    [anon_sym_bitand] = ACTIONS(1889),
    [anon_sym_not_eq] = ACTIONS(1889),
    [anon_sym_DASH_DASH] = ACTIONS(1889),
    [anon_sym_PLUS_PLUS] = ACTIONS(1889),
    [anon_sym_DOT] = ACTIONS(1887),
    [anon_sym_DOT_STAR] = ACTIONS(1889),
    [anon_sym_DASH_GT] = ACTIONS(1887),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1889),
    [anon_sym_decltype] = ACTIONS(1889),
    [anon_sym_final] = ACTIONS(1889),
    [anon_sym_override] = ACTIONS(1889),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1889),
  },
  [2368] = {
    [sym__declaration_modifiers] = STATE(2368),
    [sym_attribute_specifier] = STATE(2368),
    [sym_attribute_declaration] = STATE(2368),
    [sym_ms_declspec_modifier] = STATE(2368),
    [sym_storage_class_specifier] = STATE(2368),
    [sym_type_qualifier] = STATE(2368),
    [sym_alignas_qualifier] = STATE(1957),
    [sym_qualifiers] = STATE(2368),
    [aux_sym__declaration_specifiers_repeat1] = STATE(2368),
    [sym_identifier] = ACTIONS(5266),
    [anon_sym___extension__] = ACTIONS(5699),
    [anon_sym_in] = ACTIONS(5702),
    [anon_sym_out] = ACTIONS(5702),
    [anon_sym_inout] = ACTIONS(5702),
    [anon_sym_extern] = ACTIONS(5705),
    [anon_sym___attribute__] = ACTIONS(5708),
    [anon_sym_COLON_COLON] = ACTIONS(5268),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5711),
    [anon_sym___declspec] = ACTIONS(5714),
    [anon_sym_signed] = ACTIONS(5266),
    [anon_sym_unsigned] = ACTIONS(5266),
    [anon_sym_long] = ACTIONS(5266),
    [anon_sym_short] = ACTIONS(5266),
    [anon_sym_static] = ACTIONS(5705),
    [anon_sym_register] = ACTIONS(5705),
    [anon_sym_inline] = ACTIONS(5705),
    [anon_sym___inline] = ACTIONS(5705),
    [anon_sym___inline__] = ACTIONS(5705),
    [anon_sym___forceinline] = ACTIONS(5705),
    [anon_sym_thread_local] = ACTIONS(5705),
    [anon_sym___thread] = ACTIONS(5705),
    [anon_sym_const] = ACTIONS(5699),
    [anon_sym_constexpr] = ACTIONS(5699),
    [anon_sym_volatile] = ACTIONS(5699),
    [anon_sym_restrict] = ACTIONS(5699),
    [anon_sym___restrict__] = ACTIONS(5699),
    [anon_sym__Atomic] = ACTIONS(5699),
    [anon_sym__Noreturn] = ACTIONS(5699),
    [anon_sym_noreturn] = ACTIONS(5699),
    [anon_sym_mutable] = ACTIONS(5699),
    [anon_sym_constinit] = ACTIONS(5699),
    [anon_sym_consteval] = ACTIONS(5699),
    [anon_sym_alignas] = ACTIONS(5717),
    [anon_sym__Alignas] = ACTIONS(5717),
    [sym_primitive_type] = ACTIONS(5266),
    [anon_sym_enum] = ACTIONS(5266),
    [anon_sym_class] = ACTIONS(5266),
    [anon_sym_struct] = ACTIONS(5266),
    [anon_sym_union] = ACTIONS(5266),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5266),
    [anon_sym_decltype] = ACTIONS(5266),
    [sym_virtual] = ACTIONS(5702),
    [anon_sym_typename] = ACTIONS(5266),
    [anon_sym_template] = ACTIONS(5266),
    [anon_sym_precise] = ACTIONS(5720),
    [anon_sym_shared] = ACTIONS(5720),
    [anon_sym_groupshared] = ACTIONS(5720),
    [anon_sym_uniform] = ACTIONS(5720),
    [anon_sym_row_major] = ACTIONS(5720),
    [anon_sym_column_major] = ACTIONS(5720),
    [anon_sym_globallycoherent] = ACTIONS(5720),
    [anon_sym_centroid] = ACTIONS(5720),
    [anon_sym_noperspective] = ACTIONS(5720),
    [anon_sym_nointerpolation] = ACTIONS(5720),
    [anon_sym_sample] = ACTIONS(5720),
    [anon_sym_linear] = ACTIONS(5720),
    [anon_sym_snorm] = ACTIONS(5720),
    [anon_sym_unorm] = ACTIONS(5720),
    [anon_sym_point] = ACTIONS(5720),
    [anon_sym_line] = ACTIONS(5720),
    [anon_sym_triangleadj] = ACTIONS(5720),
    [anon_sym_lineadj] = ACTIONS(5720),
    [anon_sym_triangle] = ACTIONS(5720),
  },
  [2369] = {
    [sym_identifier] = ACTIONS(5723),
    [anon_sym_LPAREN2] = ACTIONS(5726),
    [anon_sym_TILDE] = ACTIONS(5726),
    [anon_sym_STAR] = ACTIONS(5726),
    [anon_sym_AMP_AMP] = ACTIONS(5726),
    [anon_sym_AMP] = ACTIONS(5728),
    [anon_sym___extension__] = ACTIONS(5723),
    [anon_sym_in] = ACTIONS(5723),
    [anon_sym_out] = ACTIONS(5723),
    [anon_sym_inout] = ACTIONS(5723),
    [anon_sym_extern] = ACTIONS(5723),
    [anon_sym___attribute__] = ACTIONS(5723),
    [anon_sym_COLON_COLON] = ACTIONS(5730),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5730),
    [anon_sym___declspec] = ACTIONS(5723),
    [anon_sym___based] = ACTIONS(5728),
    [anon_sym_signed] = ACTIONS(5733),
    [anon_sym_unsigned] = ACTIONS(5733),
    [anon_sym_long] = ACTIONS(5733),
    [anon_sym_short] = ACTIONS(5733),
    [anon_sym_LBRACK] = ACTIONS(5728),
    [anon_sym_static] = ACTIONS(5723),
    [anon_sym_register] = ACTIONS(5723),
    [anon_sym_inline] = ACTIONS(5723),
    [anon_sym___inline] = ACTIONS(5723),
    [anon_sym___inline__] = ACTIONS(5723),
    [anon_sym___forceinline] = ACTIONS(5723),
    [anon_sym_thread_local] = ACTIONS(5723),
    [anon_sym___thread] = ACTIONS(5723),
    [anon_sym_const] = ACTIONS(5723),
    [anon_sym_constexpr] = ACTIONS(5723),
    [anon_sym_volatile] = ACTIONS(5723),
    [anon_sym_restrict] = ACTIONS(5723),
    [anon_sym___restrict__] = ACTIONS(5723),
    [anon_sym__Atomic] = ACTIONS(5723),
    [anon_sym__Noreturn] = ACTIONS(5723),
    [anon_sym_noreturn] = ACTIONS(5723),
    [anon_sym_mutable] = ACTIONS(5723),
    [anon_sym_constinit] = ACTIONS(5723),
    [anon_sym_consteval] = ACTIONS(5723),
    [anon_sym_alignas] = ACTIONS(5723),
    [anon_sym__Alignas] = ACTIONS(5723),
    [sym_primitive_type] = ACTIONS(5733),
    [anon_sym_enum] = ACTIONS(5733),
    [anon_sym_class] = ACTIONS(5733),
    [anon_sym_struct] = ACTIONS(5733),
    [anon_sym_union] = ACTIONS(5733),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5733),
    [anon_sym_decltype] = ACTIONS(5723),
    [sym_virtual] = ACTIONS(5723),
    [anon_sym_explicit] = ACTIONS(5728),
    [anon_sym_typename] = ACTIONS(5733),
    [anon_sym_template] = ACTIONS(5723),
    [anon_sym_operator] = ACTIONS(5728),
    [anon_sym_precise] = ACTIONS(5723),
    [anon_sym_shared] = ACTIONS(5723),
    [anon_sym_groupshared] = ACTIONS(5723),
    [anon_sym_uniform] = ACTIONS(5723),
    [anon_sym_row_major] = ACTIONS(5723),
    [anon_sym_column_major] = ACTIONS(5723),
    [anon_sym_globallycoherent] = ACTIONS(5723),
    [anon_sym_centroid] = ACTIONS(5723),
    [anon_sym_noperspective] = ACTIONS(5723),
    [anon_sym_nointerpolation] = ACTIONS(5723),
    [anon_sym_sample] = ACTIONS(5723),
    [anon_sym_linear] = ACTIONS(5723),
    [anon_sym_snorm] = ACTIONS(5723),
    [anon_sym_unorm] = ACTIONS(5723),
    [anon_sym_point] = ACTIONS(5723),
    [anon_sym_line] = ACTIONS(5723),
    [anon_sym_triangleadj] = ACTIONS(5723),
    [anon_sym_lineadj] = ACTIONS(5723),
    [anon_sym_triangle] = ACTIONS(5723),
  },
  [2370] = {
    [sym__declaration_modifiers] = STATE(2370),
    [sym_attribute_specifier] = STATE(2370),
    [sym_attribute_declaration] = STATE(2370),
    [sym_ms_declspec_modifier] = STATE(2370),
    [sym_storage_class_specifier] = STATE(2370),
    [sym_type_qualifier] = STATE(2370),
    [sym_alignas_qualifier] = STATE(2331),
    [sym_explicit_function_specifier] = STATE(2370),
    [sym__constructor_specifiers] = STATE(2370),
    [sym_qualifiers] = STATE(2370),
    [aux_sym_operator_cast_definition_repeat1] = STATE(2370),
    [sym_identifier] = ACTIONS(5735),
    [anon_sym_LPAREN2] = ACTIONS(5737),
    [anon_sym_TILDE] = ACTIONS(5737),
    [anon_sym_STAR] = ACTIONS(5737),
    [anon_sym_AMP_AMP] = ACTIONS(5737),
    [anon_sym_AMP] = ACTIONS(5735),
    [anon_sym___extension__] = ACTIONS(5739),
    [anon_sym_in] = ACTIONS(5742),
    [anon_sym_out] = ACTIONS(5742),
    [anon_sym_inout] = ACTIONS(5742),
    [anon_sym_extern] = ACTIONS(5745),
    [anon_sym___attribute__] = ACTIONS(5748),
    [anon_sym_COLON_COLON] = ACTIONS(5737),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5751),
    [anon_sym___declspec] = ACTIONS(5754),
    [anon_sym___based] = ACTIONS(5735),
    [anon_sym_LBRACK] = ACTIONS(5735),
    [anon_sym_static] = ACTIONS(5745),
    [anon_sym_register] = ACTIONS(5745),
    [anon_sym_inline] = ACTIONS(5745),
    [anon_sym___inline] = ACTIONS(5745),
    [anon_sym___inline__] = ACTIONS(5745),
    [anon_sym___forceinline] = ACTIONS(5745),
    [anon_sym_thread_local] = ACTIONS(5745),
    [anon_sym___thread] = ACTIONS(5745),
    [anon_sym_const] = ACTIONS(5739),
    [anon_sym_constexpr] = ACTIONS(5739),
    [anon_sym_volatile] = ACTIONS(5739),
    [anon_sym_restrict] = ACTIONS(5739),
    [anon_sym___restrict__] = ACTIONS(5739),
    [anon_sym__Atomic] = ACTIONS(5739),
    [anon_sym__Noreturn] = ACTIONS(5739),
    [anon_sym_noreturn] = ACTIONS(5739),
    [anon_sym_mutable] = ACTIONS(5739),
    [anon_sym_constinit] = ACTIONS(5739),
    [anon_sym_consteval] = ACTIONS(5739),
    [anon_sym_alignas] = ACTIONS(5757),
    [anon_sym__Alignas] = ACTIONS(5757),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(5735),
    [sym_virtual] = ACTIONS(5742),
    [anon_sym_explicit] = ACTIONS(5760),
    [anon_sym_template] = ACTIONS(5735),
    [anon_sym_operator] = ACTIONS(5735),
    [anon_sym_precise] = ACTIONS(5763),
    [anon_sym_shared] = ACTIONS(5763),
    [anon_sym_groupshared] = ACTIONS(5763),
    [anon_sym_uniform] = ACTIONS(5763),
    [anon_sym_row_major] = ACTIONS(5763),
    [anon_sym_column_major] = ACTIONS(5763),
    [anon_sym_globallycoherent] = ACTIONS(5763),
    [anon_sym_centroid] = ACTIONS(5763),
    [anon_sym_noperspective] = ACTIONS(5763),
    [anon_sym_nointerpolation] = ACTIONS(5763),
    [anon_sym_sample] = ACTIONS(5763),
    [anon_sym_linear] = ACTIONS(5763),
    [anon_sym_snorm] = ACTIONS(5763),
    [anon_sym_unorm] = ACTIONS(5763),
    [anon_sym_point] = ACTIONS(5763),
    [anon_sym_line] = ACTIONS(5763),
    [anon_sym_triangleadj] = ACTIONS(5763),
    [anon_sym_lineadj] = ACTIONS(5763),
    [anon_sym_triangle] = ACTIONS(5763),
  },
  [2371] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1893),
    [anon_sym_COMMA] = ACTIONS(1893),
    [anon_sym_RPAREN] = ACTIONS(1893),
    [anon_sym_LPAREN2] = ACTIONS(1893),
    [anon_sym_DASH] = ACTIONS(1891),
    [anon_sym_PLUS] = ACTIONS(1891),
    [anon_sym_STAR] = ACTIONS(1891),
    [anon_sym_SLASH] = ACTIONS(1891),
    [anon_sym_PERCENT] = ACTIONS(1891),
    [anon_sym_PIPE_PIPE] = ACTIONS(1893),
    [anon_sym_AMP_AMP] = ACTIONS(1893),
    [anon_sym_PIPE] = ACTIONS(1891),
    [anon_sym_CARET] = ACTIONS(1891),
    [anon_sym_AMP] = ACTIONS(1891),
    [anon_sym_EQ_EQ] = ACTIONS(1893),
    [anon_sym_BANG_EQ] = ACTIONS(1893),
    [anon_sym_GT] = ACTIONS(1891),
    [anon_sym_GT_EQ] = ACTIONS(1893),
    [anon_sym_LT_EQ] = ACTIONS(1891),
    [anon_sym_LT] = ACTIONS(1891),
    [anon_sym_LT_LT] = ACTIONS(1891),
    [anon_sym_GT_GT] = ACTIONS(1891),
    [anon_sym_COLON] = ACTIONS(1891),
    [anon_sym___extension__] = ACTIONS(1893),
    [anon_sym___attribute__] = ACTIONS(1893),
    [anon_sym_COLON_COLON] = ACTIONS(1893),
    [anon_sym_LBRACE] = ACTIONS(1893),
    [anon_sym_LBRACK] = ACTIONS(1893),
    [anon_sym_EQ] = ACTIONS(1891),
    [anon_sym_const] = ACTIONS(1891),
    [anon_sym_constexpr] = ACTIONS(1893),
    [anon_sym_volatile] = ACTIONS(1893),
    [anon_sym_restrict] = ACTIONS(1893),
    [anon_sym___restrict__] = ACTIONS(1893),
    [anon_sym__Atomic] = ACTIONS(1893),
    [anon_sym__Noreturn] = ACTIONS(1893),
    [anon_sym_noreturn] = ACTIONS(1893),
    [anon_sym_mutable] = ACTIONS(1893),
    [anon_sym_constinit] = ACTIONS(1893),
    [anon_sym_consteval] = ACTIONS(1893),
    [anon_sym_alignas] = ACTIONS(1893),
    [anon_sym__Alignas] = ACTIONS(1893),
    [anon_sym_QMARK] = ACTIONS(1893),
    [anon_sym_STAR_EQ] = ACTIONS(1893),
    [anon_sym_SLASH_EQ] = ACTIONS(1893),
    [anon_sym_PERCENT_EQ] = ACTIONS(1893),
    [anon_sym_PLUS_EQ] = ACTIONS(1893),
    [anon_sym_DASH_EQ] = ACTIONS(1893),
    [anon_sym_LT_LT_EQ] = ACTIONS(1893),
    [anon_sym_GT_GT_EQ] = ACTIONS(1893),
    [anon_sym_AMP_EQ] = ACTIONS(1893),
    [anon_sym_CARET_EQ] = ACTIONS(1893),
    [anon_sym_PIPE_EQ] = ACTIONS(1893),
    [anon_sym_and_eq] = ACTIONS(1893),
    [anon_sym_or_eq] = ACTIONS(1893),
    [anon_sym_xor_eq] = ACTIONS(1893),
    [anon_sym_LT_EQ_GT] = ACTIONS(1893),
    [anon_sym_or] = ACTIONS(1891),
    [anon_sym_and] = ACTIONS(1891),
    [anon_sym_bitor] = ACTIONS(1893),
    [anon_sym_xor] = ACTIONS(1891),
    [anon_sym_bitand] = ACTIONS(1893),
    [anon_sym_not_eq] = ACTIONS(1893),
    [anon_sym_DASH_DASH] = ACTIONS(1893),
    [anon_sym_PLUS_PLUS] = ACTIONS(1893),
    [anon_sym_DOT] = ACTIONS(1891),
    [anon_sym_DOT_STAR] = ACTIONS(1893),
    [anon_sym_DASH_GT] = ACTIONS(1891),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1893),
    [anon_sym_decltype] = ACTIONS(1893),
    [anon_sym_final] = ACTIONS(1893),
    [anon_sym_override] = ACTIONS(1893),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1893),
  },
  [2372] = {
    [sym_template_argument_list] = STATE(2221),
    [sym_identifier] = ACTIONS(1941),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1943),
    [anon_sym_COMMA] = ACTIONS(1943),
    [anon_sym_RPAREN] = ACTIONS(1943),
    [anon_sym_LPAREN2] = ACTIONS(1943),
    [anon_sym_TILDE] = ACTIONS(1943),
    [anon_sym_STAR] = ACTIONS(1943),
    [anon_sym_AMP_AMP] = ACTIONS(1943),
    [anon_sym_AMP] = ACTIONS(1941),
    [anon_sym_LT] = ACTIONS(5628),
    [anon_sym_COLON] = ACTIONS(1941),
    [anon_sym___extension__] = ACTIONS(1941),
    [anon_sym_in] = ACTIONS(1941),
    [anon_sym_out] = ACTIONS(1941),
    [anon_sym_inout] = ACTIONS(1941),
    [anon_sym_extern] = ACTIONS(1941),
    [anon_sym___attribute__] = ACTIONS(1941),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1943),
    [anon_sym___declspec] = ACTIONS(1941),
    [anon_sym___based] = ACTIONS(1941),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_LBRACK] = ACTIONS(1941),
    [anon_sym_static] = ACTIONS(1941),
    [anon_sym_EQ] = ACTIONS(1943),
    [anon_sym_register] = ACTIONS(1941),
    [anon_sym_inline] = ACTIONS(1941),
    [anon_sym___inline] = ACTIONS(1941),
    [anon_sym___inline__] = ACTIONS(1941),
    [anon_sym___forceinline] = ACTIONS(1941),
    [anon_sym_thread_local] = ACTIONS(1941),
    [anon_sym___thread] = ACTIONS(1941),
    [anon_sym_const] = ACTIONS(1941),
    [anon_sym_constexpr] = ACTIONS(1941),
    [anon_sym_volatile] = ACTIONS(1941),
    [anon_sym_restrict] = ACTIONS(1941),
    [anon_sym___restrict__] = ACTIONS(1941),
    [anon_sym__Atomic] = ACTIONS(1941),
    [anon_sym__Noreturn] = ACTIONS(1941),
    [anon_sym_noreturn] = ACTIONS(1941),
    [anon_sym_mutable] = ACTIONS(1941),
    [anon_sym_constinit] = ACTIONS(1941),
    [anon_sym_consteval] = ACTIONS(1941),
    [anon_sym_alignas] = ACTIONS(1941),
    [anon_sym__Alignas] = ACTIONS(1941),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1941),
    [anon_sym_decltype] = ACTIONS(1941),
    [anon_sym_final] = ACTIONS(1941),
    [anon_sym_override] = ACTIONS(1941),
    [sym_virtual] = ACTIONS(1941),
    [anon_sym_template] = ACTIONS(1941),
    [anon_sym_GT2] = ACTIONS(1943),
    [anon_sym_operator] = ACTIONS(1941),
    [anon_sym_precise] = ACTIONS(1941),
    [anon_sym_shared] = ACTIONS(1941),
    [anon_sym_groupshared] = ACTIONS(1941),
    [anon_sym_uniform] = ACTIONS(1941),
    [anon_sym_row_major] = ACTIONS(1941),
    [anon_sym_column_major] = ACTIONS(1941),
    [anon_sym_globallycoherent] = ACTIONS(1941),
    [anon_sym_centroid] = ACTIONS(1941),
    [anon_sym_noperspective] = ACTIONS(1941),
    [anon_sym_nointerpolation] = ACTIONS(1941),
    [anon_sym_sample] = ACTIONS(1941),
    [anon_sym_linear] = ACTIONS(1941),
    [anon_sym_snorm] = ACTIONS(1941),
    [anon_sym_unorm] = ACTIONS(1941),
    [anon_sym_point] = ACTIONS(1941),
    [anon_sym_line] = ACTIONS(1941),
    [anon_sym_triangleadj] = ACTIONS(1941),
    [anon_sym_lineadj] = ACTIONS(1941),
    [anon_sym_triangle] = ACTIONS(1941),
  },
  [2373] = {
    [sym_identifier] = ACTIONS(5618),
    [anon_sym_LPAREN2] = ACTIONS(5620),
    [anon_sym_TILDE] = ACTIONS(5620),
    [anon_sym_STAR] = ACTIONS(5620),
    [anon_sym_AMP_AMP] = ACTIONS(5620),
    [anon_sym_AMP] = ACTIONS(5618),
    [anon_sym___extension__] = ACTIONS(5618),
    [anon_sym_in] = ACTIONS(5618),
    [anon_sym_out] = ACTIONS(5618),
    [anon_sym_inout] = ACTIONS(5618),
    [anon_sym_extern] = ACTIONS(5618),
    [anon_sym___attribute__] = ACTIONS(5618),
    [anon_sym_COLON_COLON] = ACTIONS(5620),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5620),
    [anon_sym___declspec] = ACTIONS(5618),
    [anon_sym___based] = ACTIONS(5618),
    [anon_sym_signed] = ACTIONS(5618),
    [anon_sym_unsigned] = ACTIONS(5618),
    [anon_sym_long] = ACTIONS(5618),
    [anon_sym_short] = ACTIONS(5618),
    [anon_sym_LBRACK] = ACTIONS(5618),
    [anon_sym_static] = ACTIONS(5618),
    [anon_sym_register] = ACTIONS(5618),
    [anon_sym_inline] = ACTIONS(5618),
    [anon_sym___inline] = ACTIONS(5618),
    [anon_sym___inline__] = ACTIONS(5618),
    [anon_sym___forceinline] = ACTIONS(5618),
    [anon_sym_thread_local] = ACTIONS(5618),
    [anon_sym___thread] = ACTIONS(5618),
    [anon_sym_const] = ACTIONS(5618),
    [anon_sym_constexpr] = ACTIONS(5618),
    [anon_sym_volatile] = ACTIONS(5618),
    [anon_sym_restrict] = ACTIONS(5618),
    [anon_sym___restrict__] = ACTIONS(5618),
    [anon_sym__Atomic] = ACTIONS(5618),
    [anon_sym__Noreturn] = ACTIONS(5618),
    [anon_sym_noreturn] = ACTIONS(5618),
    [anon_sym_mutable] = ACTIONS(5618),
    [anon_sym_constinit] = ACTIONS(5618),
    [anon_sym_consteval] = ACTIONS(5618),
    [anon_sym_alignas] = ACTIONS(5618),
    [anon_sym__Alignas] = ACTIONS(5618),
    [sym_primitive_type] = ACTIONS(5618),
    [anon_sym_enum] = ACTIONS(5618),
    [anon_sym_class] = ACTIONS(5618),
    [anon_sym_struct] = ACTIONS(5618),
    [anon_sym_union] = ACTIONS(5618),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5618),
    [anon_sym_decltype] = ACTIONS(5618),
    [sym_virtual] = ACTIONS(5618),
    [anon_sym_explicit] = ACTIONS(5618),
    [anon_sym_typename] = ACTIONS(5618),
    [anon_sym_template] = ACTIONS(5618),
    [anon_sym_operator] = ACTIONS(5618),
    [anon_sym_precise] = ACTIONS(5618),
    [anon_sym_shared] = ACTIONS(5618),
    [anon_sym_groupshared] = ACTIONS(5618),
    [anon_sym_uniform] = ACTIONS(5618),
    [anon_sym_row_major] = ACTIONS(5618),
    [anon_sym_column_major] = ACTIONS(5618),
    [anon_sym_globallycoherent] = ACTIONS(5618),
    [anon_sym_centroid] = ACTIONS(5618),
    [anon_sym_noperspective] = ACTIONS(5618),
    [anon_sym_nointerpolation] = ACTIONS(5618),
    [anon_sym_sample] = ACTIONS(5618),
    [anon_sym_linear] = ACTIONS(5618),
    [anon_sym_snorm] = ACTIONS(5618),
    [anon_sym_unorm] = ACTIONS(5618),
    [anon_sym_point] = ACTIONS(5618),
    [anon_sym_line] = ACTIONS(5618),
    [anon_sym_triangleadj] = ACTIONS(5618),
    [anon_sym_lineadj] = ACTIONS(5618),
    [anon_sym_triangle] = ACTIONS(5618),
  },
  [2374] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2374),
    [sym_identifier] = ACTIONS(5224),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5226),
    [anon_sym_COMMA] = ACTIONS(5226),
    [anon_sym_RPAREN] = ACTIONS(5226),
    [aux_sym_preproc_if_token2] = ACTIONS(5226),
    [aux_sym_preproc_else_token1] = ACTIONS(5226),
    [aux_sym_preproc_elif_token1] = ACTIONS(5224),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5226),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5226),
    [anon_sym_LPAREN2] = ACTIONS(5226),
    [anon_sym_DASH] = ACTIONS(5224),
    [anon_sym_PLUS] = ACTIONS(5224),
    [anon_sym_STAR] = ACTIONS(5226),
    [anon_sym_SLASH] = ACTIONS(5224),
    [anon_sym_PERCENT] = ACTIONS(5226),
    [anon_sym_PIPE_PIPE] = ACTIONS(5226),
    [anon_sym_AMP_AMP] = ACTIONS(5226),
    [anon_sym_PIPE] = ACTIONS(5224),
    [anon_sym_CARET] = ACTIONS(5226),
    [anon_sym_AMP] = ACTIONS(5224),
    [anon_sym_EQ_EQ] = ACTIONS(5226),
    [anon_sym_BANG_EQ] = ACTIONS(5226),
    [anon_sym_GT] = ACTIONS(5224),
    [anon_sym_GT_EQ] = ACTIONS(5226),
    [anon_sym_LT_EQ] = ACTIONS(5224),
    [anon_sym_LT] = ACTIONS(5224),
    [anon_sym_LT_LT] = ACTIONS(5226),
    [anon_sym_GT_GT] = ACTIONS(5226),
    [anon_sym_COLON] = ACTIONS(5226),
    [anon_sym_SEMI] = ACTIONS(5226),
    [anon_sym___extension__] = ACTIONS(5224),
    [anon_sym___attribute__] = ACTIONS(5224),
    [anon_sym_LBRACE] = ACTIONS(5226),
    [anon_sym_RBRACE] = ACTIONS(5226),
    [anon_sym_signed] = ACTIONS(5766),
    [anon_sym_unsigned] = ACTIONS(5766),
    [anon_sym_long] = ACTIONS(5766),
    [anon_sym_short] = ACTIONS(5766),
    [anon_sym_LBRACK] = ACTIONS(5226),
    [anon_sym_RBRACK] = ACTIONS(5226),
    [anon_sym_const] = ACTIONS(5224),
    [anon_sym_constexpr] = ACTIONS(5224),
    [anon_sym_volatile] = ACTIONS(5224),
    [anon_sym_restrict] = ACTIONS(5224),
    [anon_sym___restrict__] = ACTIONS(5224),
    [anon_sym__Atomic] = ACTIONS(5224),
    [anon_sym__Noreturn] = ACTIONS(5224),
    [anon_sym_noreturn] = ACTIONS(5224),
    [anon_sym_mutable] = ACTIONS(5224),
    [anon_sym_constinit] = ACTIONS(5224),
    [anon_sym_consteval] = ACTIONS(5224),
    [anon_sym_alignas] = ACTIONS(5224),
    [anon_sym__Alignas] = ACTIONS(5224),
    [sym_primitive_type] = ACTIONS(5224),
    [anon_sym_QMARK] = ACTIONS(5226),
    [anon_sym_LT_EQ_GT] = ACTIONS(5226),
    [anon_sym_or] = ACTIONS(5224),
    [anon_sym_and] = ACTIONS(5224),
    [anon_sym_bitor] = ACTIONS(5224),
    [anon_sym_xor] = ACTIONS(5224),
    [anon_sym_bitand] = ACTIONS(5224),
    [anon_sym_not_eq] = ACTIONS(5224),
    [anon_sym_DASH_DASH] = ACTIONS(5226),
    [anon_sym_PLUS_PLUS] = ACTIONS(5226),
    [anon_sym_DOT] = ACTIONS(5224),
    [anon_sym_DOT_STAR] = ACTIONS(5226),
    [anon_sym_DASH_GT] = ACTIONS(5226),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5224),
    [anon_sym_decltype] = ACTIONS(5224),
    [anon_sym_final] = ACTIONS(5224),
    [anon_sym_override] = ACTIONS(5224),
    [anon_sym_requires] = ACTIONS(5224),
  },
  [2375] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1927),
    [anon_sym_COMMA] = ACTIONS(1927),
    [anon_sym_RPAREN] = ACTIONS(1927),
    [anon_sym_LPAREN2] = ACTIONS(1927),
    [anon_sym_DASH] = ACTIONS(1925),
    [anon_sym_PLUS] = ACTIONS(1925),
    [anon_sym_STAR] = ACTIONS(1925),
    [anon_sym_SLASH] = ACTIONS(1925),
    [anon_sym_PERCENT] = ACTIONS(1925),
    [anon_sym_PIPE_PIPE] = ACTIONS(1927),
    [anon_sym_AMP_AMP] = ACTIONS(1927),
    [anon_sym_PIPE] = ACTIONS(1925),
    [anon_sym_CARET] = ACTIONS(1925),
    [anon_sym_AMP] = ACTIONS(1925),
    [anon_sym_EQ_EQ] = ACTIONS(1927),
    [anon_sym_BANG_EQ] = ACTIONS(1927),
    [anon_sym_GT] = ACTIONS(1925),
    [anon_sym_GT_EQ] = ACTIONS(1927),
    [anon_sym_LT_EQ] = ACTIONS(1925),
    [anon_sym_LT] = ACTIONS(1925),
    [anon_sym_LT_LT] = ACTIONS(1925),
    [anon_sym_GT_GT] = ACTIONS(1925),
    [anon_sym_COLON] = ACTIONS(1925),
    [anon_sym___extension__] = ACTIONS(1927),
    [anon_sym___attribute__] = ACTIONS(1927),
    [anon_sym_COLON_COLON] = ACTIONS(1927),
    [anon_sym_LBRACE] = ACTIONS(1927),
    [anon_sym_LBRACK] = ACTIONS(1927),
    [anon_sym_EQ] = ACTIONS(1925),
    [anon_sym_const] = ACTIONS(1925),
    [anon_sym_constexpr] = ACTIONS(1927),
    [anon_sym_volatile] = ACTIONS(1927),
    [anon_sym_restrict] = ACTIONS(1927),
    [anon_sym___restrict__] = ACTIONS(1927),
    [anon_sym__Atomic] = ACTIONS(1927),
    [anon_sym__Noreturn] = ACTIONS(1927),
    [anon_sym_noreturn] = ACTIONS(1927),
    [anon_sym_mutable] = ACTIONS(1927),
    [anon_sym_constinit] = ACTIONS(1927),
    [anon_sym_consteval] = ACTIONS(1927),
    [anon_sym_alignas] = ACTIONS(1927),
    [anon_sym__Alignas] = ACTIONS(1927),
    [anon_sym_QMARK] = ACTIONS(1927),
    [anon_sym_STAR_EQ] = ACTIONS(1927),
    [anon_sym_SLASH_EQ] = ACTIONS(1927),
    [anon_sym_PERCENT_EQ] = ACTIONS(1927),
    [anon_sym_PLUS_EQ] = ACTIONS(1927),
    [anon_sym_DASH_EQ] = ACTIONS(1927),
    [anon_sym_LT_LT_EQ] = ACTIONS(1927),
    [anon_sym_GT_GT_EQ] = ACTIONS(1927),
    [anon_sym_AMP_EQ] = ACTIONS(1927),
    [anon_sym_CARET_EQ] = ACTIONS(1927),
    [anon_sym_PIPE_EQ] = ACTIONS(1927),
    [anon_sym_and_eq] = ACTIONS(1927),
    [anon_sym_or_eq] = ACTIONS(1927),
    [anon_sym_xor_eq] = ACTIONS(1927),
    [anon_sym_LT_EQ_GT] = ACTIONS(1927),
    [anon_sym_or] = ACTIONS(1925),
    [anon_sym_and] = ACTIONS(1925),
    [anon_sym_bitor] = ACTIONS(1927),
    [anon_sym_xor] = ACTIONS(1925),
    [anon_sym_bitand] = ACTIONS(1927),
    [anon_sym_not_eq] = ACTIONS(1927),
    [anon_sym_DASH_DASH] = ACTIONS(1927),
    [anon_sym_PLUS_PLUS] = ACTIONS(1927),
    [anon_sym_DOT] = ACTIONS(1925),
    [anon_sym_DOT_STAR] = ACTIONS(1927),
    [anon_sym_DASH_GT] = ACTIONS(1925),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1927),
    [anon_sym_decltype] = ACTIONS(1927),
    [anon_sym_final] = ACTIONS(1927),
    [anon_sym_override] = ACTIONS(1927),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1927),
  },
  [2376] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1897),
    [anon_sym_COMMA] = ACTIONS(1897),
    [anon_sym_RPAREN] = ACTIONS(1897),
    [anon_sym_LPAREN2] = ACTIONS(1897),
    [anon_sym_DASH] = ACTIONS(1895),
    [anon_sym_PLUS] = ACTIONS(1895),
    [anon_sym_STAR] = ACTIONS(1895),
    [anon_sym_SLASH] = ACTIONS(1895),
    [anon_sym_PERCENT] = ACTIONS(1895),
    [anon_sym_PIPE_PIPE] = ACTIONS(1897),
    [anon_sym_AMP_AMP] = ACTIONS(1897),
    [anon_sym_PIPE] = ACTIONS(1895),
    [anon_sym_CARET] = ACTIONS(1895),
    [anon_sym_AMP] = ACTIONS(1895),
    [anon_sym_EQ_EQ] = ACTIONS(1897),
    [anon_sym_BANG_EQ] = ACTIONS(1897),
    [anon_sym_GT] = ACTIONS(1895),
    [anon_sym_GT_EQ] = ACTIONS(1897),
    [anon_sym_LT_EQ] = ACTIONS(1895),
    [anon_sym_LT] = ACTIONS(1895),
    [anon_sym_LT_LT] = ACTIONS(1895),
    [anon_sym_GT_GT] = ACTIONS(1895),
    [anon_sym_COLON] = ACTIONS(1895),
    [anon_sym___extension__] = ACTIONS(1897),
    [anon_sym___attribute__] = ACTIONS(1897),
    [anon_sym_COLON_COLON] = ACTIONS(1897),
    [anon_sym_LBRACE] = ACTIONS(1897),
    [anon_sym_LBRACK] = ACTIONS(1897),
    [anon_sym_EQ] = ACTIONS(1895),
    [anon_sym_const] = ACTIONS(1895),
    [anon_sym_constexpr] = ACTIONS(1897),
    [anon_sym_volatile] = ACTIONS(1897),
    [anon_sym_restrict] = ACTIONS(1897),
    [anon_sym___restrict__] = ACTIONS(1897),
    [anon_sym__Atomic] = ACTIONS(1897),
    [anon_sym__Noreturn] = ACTIONS(1897),
    [anon_sym_noreturn] = ACTIONS(1897),
    [anon_sym_mutable] = ACTIONS(1897),
    [anon_sym_constinit] = ACTIONS(1897),
    [anon_sym_consteval] = ACTIONS(1897),
    [anon_sym_alignas] = ACTIONS(1897),
    [anon_sym__Alignas] = ACTIONS(1897),
    [anon_sym_QMARK] = ACTIONS(1897),
    [anon_sym_STAR_EQ] = ACTIONS(1897),
    [anon_sym_SLASH_EQ] = ACTIONS(1897),
    [anon_sym_PERCENT_EQ] = ACTIONS(1897),
    [anon_sym_PLUS_EQ] = ACTIONS(1897),
    [anon_sym_DASH_EQ] = ACTIONS(1897),
    [anon_sym_LT_LT_EQ] = ACTIONS(1897),
    [anon_sym_GT_GT_EQ] = ACTIONS(1897),
    [anon_sym_AMP_EQ] = ACTIONS(1897),
    [anon_sym_CARET_EQ] = ACTIONS(1897),
    [anon_sym_PIPE_EQ] = ACTIONS(1897),
    [anon_sym_and_eq] = ACTIONS(1897),
    [anon_sym_or_eq] = ACTIONS(1897),
    [anon_sym_xor_eq] = ACTIONS(1897),
    [anon_sym_LT_EQ_GT] = ACTIONS(1897),
    [anon_sym_or] = ACTIONS(1895),
    [anon_sym_and] = ACTIONS(1895),
    [anon_sym_bitor] = ACTIONS(1897),
    [anon_sym_xor] = ACTIONS(1895),
    [anon_sym_bitand] = ACTIONS(1897),
    [anon_sym_not_eq] = ACTIONS(1897),
    [anon_sym_DASH_DASH] = ACTIONS(1897),
    [anon_sym_PLUS_PLUS] = ACTIONS(1897),
    [anon_sym_DOT] = ACTIONS(1895),
    [anon_sym_DOT_STAR] = ACTIONS(1897),
    [anon_sym_DASH_GT] = ACTIONS(1895),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1897),
    [anon_sym_decltype] = ACTIONS(1897),
    [anon_sym_final] = ACTIONS(1897),
    [anon_sym_override] = ACTIONS(1897),
    [anon_sym_DASH_GT_STAR] = ACTIONS(1897),
  },
  [2377] = {
    [sym_attribute_specifier] = STATE(2269),
    [sym_enumerator_list] = STATE(2322),
    [sym__enum_base_clause] = STATE(2301),
    [sym_identifier] = ACTIONS(5689),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5691),
    [anon_sym_COMMA] = ACTIONS(5691),
    [anon_sym_RPAREN] = ACTIONS(5691),
    [anon_sym_LPAREN2] = ACTIONS(5691),
    [anon_sym_TILDE] = ACTIONS(5691),
    [anon_sym_STAR] = ACTIONS(5691),
    [anon_sym_AMP_AMP] = ACTIONS(5691),
    [anon_sym_AMP] = ACTIONS(5689),
    [anon_sym_COLON] = ACTIONS(5769),
    [anon_sym___extension__] = ACTIONS(5689),
    [anon_sym_in] = ACTIONS(5689),
    [anon_sym_out] = ACTIONS(5689),
    [anon_sym_inout] = ACTIONS(5689),
    [anon_sym_extern] = ACTIONS(5689),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5691),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5691),
    [anon_sym___declspec] = ACTIONS(5689),
    [anon_sym___based] = ACTIONS(5689),
    [anon_sym_LBRACE] = ACTIONS(5523),
    [anon_sym_LBRACK] = ACTIONS(5689),
    [anon_sym_static] = ACTIONS(5689),
    [anon_sym_EQ] = ACTIONS(5691),
    [anon_sym_register] = ACTIONS(5689),
    [anon_sym_inline] = ACTIONS(5689),
    [anon_sym___inline] = ACTIONS(5689),
    [anon_sym___inline__] = ACTIONS(5689),
    [anon_sym___forceinline] = ACTIONS(5689),
    [anon_sym_thread_local] = ACTIONS(5689),
    [anon_sym___thread] = ACTIONS(5689),
    [anon_sym_const] = ACTIONS(5689),
    [anon_sym_constexpr] = ACTIONS(5689),
    [anon_sym_volatile] = ACTIONS(5689),
    [anon_sym_restrict] = ACTIONS(5689),
    [anon_sym___restrict__] = ACTIONS(5689),
    [anon_sym__Atomic] = ACTIONS(5689),
    [anon_sym__Noreturn] = ACTIONS(5689),
    [anon_sym_noreturn] = ACTIONS(5689),
    [anon_sym_mutable] = ACTIONS(5689),
    [anon_sym_constinit] = ACTIONS(5689),
    [anon_sym_consteval] = ACTIONS(5689),
    [anon_sym_alignas] = ACTIONS(5689),
    [anon_sym__Alignas] = ACTIONS(5689),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5689),
    [anon_sym_decltype] = ACTIONS(5689),
    [sym_virtual] = ACTIONS(5689),
    [anon_sym_template] = ACTIONS(5689),
    [anon_sym_GT2] = ACTIONS(5691),
    [anon_sym_operator] = ACTIONS(5689),
    [anon_sym_precise] = ACTIONS(5689),
    [anon_sym_shared] = ACTIONS(5689),
    [anon_sym_groupshared] = ACTIONS(5689),
    [anon_sym_uniform] = ACTIONS(5689),
    [anon_sym_row_major] = ACTIONS(5689),
    [anon_sym_column_major] = ACTIONS(5689),
    [anon_sym_globallycoherent] = ACTIONS(5689),
    [anon_sym_centroid] = ACTIONS(5689),
    [anon_sym_noperspective] = ACTIONS(5689),
    [anon_sym_nointerpolation] = ACTIONS(5689),
    [anon_sym_sample] = ACTIONS(5689),
    [anon_sym_linear] = ACTIONS(5689),
    [anon_sym_snorm] = ACTIONS(5689),
    [anon_sym_unorm] = ACTIONS(5689),
    [anon_sym_point] = ACTIONS(5689),
    [anon_sym_line] = ACTIONS(5689),
    [anon_sym_triangleadj] = ACTIONS(5689),
    [anon_sym_lineadj] = ACTIONS(5689),
    [anon_sym_triangle] = ACTIONS(5689),
  },
  [2378] = {
    [sym_template_argument_list] = STATE(2221),
    [sym_identifier] = ACTIONS(1941),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1943),
    [anon_sym_COMMA] = ACTIONS(5695),
    [anon_sym_LPAREN2] = ACTIONS(1943),
    [anon_sym_TILDE] = ACTIONS(1943),
    [anon_sym_STAR] = ACTIONS(1943),
    [anon_sym_AMP_AMP] = ACTIONS(1943),
    [anon_sym_AMP] = ACTIONS(1941),
    [anon_sym_LT] = ACTIONS(5628),
    [anon_sym_COLON] = ACTIONS(1941),
    [anon_sym___extension__] = ACTIONS(1941),
    [anon_sym_in] = ACTIONS(1941),
    [anon_sym_out] = ACTIONS(1941),
    [anon_sym_inout] = ACTIONS(1941),
    [anon_sym_extern] = ACTIONS(1941),
    [anon_sym___attribute__] = ACTIONS(1941),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1943),
    [anon_sym___declspec] = ACTIONS(1941),
    [anon_sym___based] = ACTIONS(1941),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_LBRACK] = ACTIONS(1941),
    [anon_sym_static] = ACTIONS(1941),
    [anon_sym_EQ] = ACTIONS(5697),
    [anon_sym_register] = ACTIONS(1941),
    [anon_sym_inline] = ACTIONS(1941),
    [anon_sym___inline] = ACTIONS(1941),
    [anon_sym___inline__] = ACTIONS(1941),
    [anon_sym___forceinline] = ACTIONS(1941),
    [anon_sym_thread_local] = ACTIONS(1941),
    [anon_sym___thread] = ACTIONS(1941),
    [anon_sym_const] = ACTIONS(1941),
    [anon_sym_constexpr] = ACTIONS(1941),
    [anon_sym_volatile] = ACTIONS(1941),
    [anon_sym_restrict] = ACTIONS(1941),
    [anon_sym___restrict__] = ACTIONS(1941),
    [anon_sym__Atomic] = ACTIONS(1941),
    [anon_sym__Noreturn] = ACTIONS(1941),
    [anon_sym_noreturn] = ACTIONS(1941),
    [anon_sym_mutable] = ACTIONS(1941),
    [anon_sym_constinit] = ACTIONS(1941),
    [anon_sym_consteval] = ACTIONS(1941),
    [anon_sym_alignas] = ACTIONS(1941),
    [anon_sym__Alignas] = ACTIONS(1941),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1941),
    [anon_sym_decltype] = ACTIONS(1941),
    [anon_sym_final] = ACTIONS(1941),
    [anon_sym_override] = ACTIONS(1941),
    [sym_virtual] = ACTIONS(1941),
    [anon_sym_template] = ACTIONS(1941),
    [anon_sym_GT2] = ACTIONS(5695),
    [anon_sym_operator] = ACTIONS(1941),
    [anon_sym_precise] = ACTIONS(1941),
    [anon_sym_shared] = ACTIONS(1941),
    [anon_sym_groupshared] = ACTIONS(1941),
    [anon_sym_uniform] = ACTIONS(1941),
    [anon_sym_row_major] = ACTIONS(1941),
    [anon_sym_column_major] = ACTIONS(1941),
    [anon_sym_globallycoherent] = ACTIONS(1941),
    [anon_sym_centroid] = ACTIONS(1941),
    [anon_sym_noperspective] = ACTIONS(1941),
    [anon_sym_nointerpolation] = ACTIONS(1941),
    [anon_sym_sample] = ACTIONS(1941),
    [anon_sym_linear] = ACTIONS(1941),
    [anon_sym_snorm] = ACTIONS(1941),
    [anon_sym_unorm] = ACTIONS(1941),
    [anon_sym_point] = ACTIONS(1941),
    [anon_sym_line] = ACTIONS(1941),
    [anon_sym_triangleadj] = ACTIONS(1941),
    [anon_sym_lineadj] = ACTIONS(1941),
    [anon_sym_triangle] = ACTIONS(1941),
  },
  [2379] = {
    [sym_identifier] = ACTIONS(5771),
    [anon_sym___extension__] = ACTIONS(5771),
    [anon_sym_in] = ACTIONS(5771),
    [anon_sym_out] = ACTIONS(5771),
    [anon_sym_inout] = ACTIONS(5771),
    [anon_sym_extern] = ACTIONS(5771),
    [anon_sym___attribute__] = ACTIONS(5771),
    [anon_sym_COLON_COLON] = ACTIONS(5773),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5773),
    [anon_sym___declspec] = ACTIONS(5771),
    [anon_sym___cdecl] = ACTIONS(5771),
    [anon_sym___clrcall] = ACTIONS(5771),
    [anon_sym___stdcall] = ACTIONS(5771),
    [anon_sym___fastcall] = ACTIONS(5771),
    [anon_sym___thiscall] = ACTIONS(5771),
    [anon_sym___vectorcall] = ACTIONS(5771),
    [anon_sym_LBRACE] = ACTIONS(5773),
    [anon_sym_signed] = ACTIONS(5771),
    [anon_sym_unsigned] = ACTIONS(5771),
    [anon_sym_long] = ACTIONS(5771),
    [anon_sym_short] = ACTIONS(5771),
    [anon_sym_LBRACK] = ACTIONS(5771),
    [anon_sym_static] = ACTIONS(5771),
    [anon_sym_register] = ACTIONS(5771),
    [anon_sym_inline] = ACTIONS(5771),
    [anon_sym___inline] = ACTIONS(5771),
    [anon_sym___inline__] = ACTIONS(5771),
    [anon_sym___forceinline] = ACTIONS(5771),
    [anon_sym_thread_local] = ACTIONS(5771),
    [anon_sym___thread] = ACTIONS(5771),
    [anon_sym_const] = ACTIONS(5771),
    [anon_sym_constexpr] = ACTIONS(5771),
    [anon_sym_volatile] = ACTIONS(5771),
    [anon_sym_restrict] = ACTIONS(5771),
    [anon_sym___restrict__] = ACTIONS(5771),
    [anon_sym__Atomic] = ACTIONS(5771),
    [anon_sym__Noreturn] = ACTIONS(5771),
    [anon_sym_noreturn] = ACTIONS(5771),
    [anon_sym_mutable] = ACTIONS(5771),
    [anon_sym_constinit] = ACTIONS(5771),
    [anon_sym_consteval] = ACTIONS(5771),
    [anon_sym_alignas] = ACTIONS(5771),
    [anon_sym__Alignas] = ACTIONS(5771),
    [sym_primitive_type] = ACTIONS(5771),
    [anon_sym_enum] = ACTIONS(5771),
    [anon_sym_class] = ACTIONS(5771),
    [anon_sym_struct] = ACTIONS(5771),
    [anon_sym_union] = ACTIONS(5771),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5771),
    [anon_sym_decltype] = ACTIONS(5771),
    [sym_virtual] = ACTIONS(5771),
    [anon_sym_typename] = ACTIONS(5771),
    [anon_sym_template] = ACTIONS(5771),
    [anon_sym_precise] = ACTIONS(5771),
    [anon_sym_shared] = ACTIONS(5771),
    [anon_sym_groupshared] = ACTIONS(5771),
    [anon_sym_uniform] = ACTIONS(5771),
    [anon_sym_row_major] = ACTIONS(5771),
    [anon_sym_column_major] = ACTIONS(5771),
    [anon_sym_globallycoherent] = ACTIONS(5771),
    [anon_sym_centroid] = ACTIONS(5771),
    [anon_sym_noperspective] = ACTIONS(5771),
    [anon_sym_nointerpolation] = ACTIONS(5771),
    [anon_sym_sample] = ACTIONS(5771),
    [anon_sym_linear] = ACTIONS(5771),
    [anon_sym_snorm] = ACTIONS(5771),
    [anon_sym_unorm] = ACTIONS(5771),
    [anon_sym_point] = ACTIONS(5771),
    [anon_sym_line] = ACTIONS(5771),
    [anon_sym_triangleadj] = ACTIONS(5771),
    [anon_sym_lineadj] = ACTIONS(5771),
    [anon_sym_triangle] = ACTIONS(5771),
  },
  [2380] = {
    [sym_identifier] = ACTIONS(5775),
    [anon_sym___extension__] = ACTIONS(5775),
    [anon_sym_in] = ACTIONS(5775),
    [anon_sym_out] = ACTIONS(5775),
    [anon_sym_inout] = ACTIONS(5775),
    [anon_sym_extern] = ACTIONS(5775),
    [anon_sym___attribute__] = ACTIONS(5775),
    [anon_sym_COLON_COLON] = ACTIONS(5777),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5777),
    [anon_sym___declspec] = ACTIONS(5775),
    [anon_sym___cdecl] = ACTIONS(5775),
    [anon_sym___clrcall] = ACTIONS(5775),
    [anon_sym___stdcall] = ACTIONS(5775),
    [anon_sym___fastcall] = ACTIONS(5775),
    [anon_sym___thiscall] = ACTIONS(5775),
    [anon_sym___vectorcall] = ACTIONS(5775),
    [anon_sym_LBRACE] = ACTIONS(5777),
    [anon_sym_signed] = ACTIONS(5775),
    [anon_sym_unsigned] = ACTIONS(5775),
    [anon_sym_long] = ACTIONS(5775),
    [anon_sym_short] = ACTIONS(5775),
    [anon_sym_LBRACK] = ACTIONS(5775),
    [anon_sym_static] = ACTIONS(5775),
    [anon_sym_register] = ACTIONS(5775),
    [anon_sym_inline] = ACTIONS(5775),
    [anon_sym___inline] = ACTIONS(5775),
    [anon_sym___inline__] = ACTIONS(5775),
    [anon_sym___forceinline] = ACTIONS(5775),
    [anon_sym_thread_local] = ACTIONS(5775),
    [anon_sym___thread] = ACTIONS(5775),
    [anon_sym_const] = ACTIONS(5775),
    [anon_sym_constexpr] = ACTIONS(5775),
    [anon_sym_volatile] = ACTIONS(5775),
    [anon_sym_restrict] = ACTIONS(5775),
    [anon_sym___restrict__] = ACTIONS(5775),
    [anon_sym__Atomic] = ACTIONS(5775),
    [anon_sym__Noreturn] = ACTIONS(5775),
    [anon_sym_noreturn] = ACTIONS(5775),
    [anon_sym_mutable] = ACTIONS(5775),
    [anon_sym_constinit] = ACTIONS(5775),
    [anon_sym_consteval] = ACTIONS(5775),
    [anon_sym_alignas] = ACTIONS(5775),
    [anon_sym__Alignas] = ACTIONS(5775),
    [sym_primitive_type] = ACTIONS(5775),
    [anon_sym_enum] = ACTIONS(5775),
    [anon_sym_class] = ACTIONS(5775),
    [anon_sym_struct] = ACTIONS(5775),
    [anon_sym_union] = ACTIONS(5775),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5775),
    [anon_sym_decltype] = ACTIONS(5775),
    [sym_virtual] = ACTIONS(5775),
    [anon_sym_typename] = ACTIONS(5775),
    [anon_sym_template] = ACTIONS(5775),
    [anon_sym_precise] = ACTIONS(5775),
    [anon_sym_shared] = ACTIONS(5775),
    [anon_sym_groupshared] = ACTIONS(5775),
    [anon_sym_uniform] = ACTIONS(5775),
    [anon_sym_row_major] = ACTIONS(5775),
    [anon_sym_column_major] = ACTIONS(5775),
    [anon_sym_globallycoherent] = ACTIONS(5775),
    [anon_sym_centroid] = ACTIONS(5775),
    [anon_sym_noperspective] = ACTIONS(5775),
    [anon_sym_nointerpolation] = ACTIONS(5775),
    [anon_sym_sample] = ACTIONS(5775),
    [anon_sym_linear] = ACTIONS(5775),
    [anon_sym_snorm] = ACTIONS(5775),
    [anon_sym_unorm] = ACTIONS(5775),
    [anon_sym_point] = ACTIONS(5775),
    [anon_sym_line] = ACTIONS(5775),
    [anon_sym_triangleadj] = ACTIONS(5775),
    [anon_sym_lineadj] = ACTIONS(5775),
    [anon_sym_triangle] = ACTIONS(5775),
  },
  [2381] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1893),
    [anon_sym_COMMA] = ACTIONS(1893),
    [anon_sym_LPAREN2] = ACTIONS(1893),
    [anon_sym_DASH] = ACTIONS(1891),
    [anon_sym_PLUS] = ACTIONS(1891),
    [anon_sym_STAR] = ACTIONS(1891),
    [anon_sym_SLASH] = ACTIONS(1891),
    [anon_sym_PERCENT] = ACTIONS(1891),
    [anon_sym_PIPE_PIPE] = ACTIONS(1893),
    [anon_sym_AMP_AMP] = ACTIONS(1893),
    [anon_sym_PIPE] = ACTIONS(1891),
    [anon_sym_CARET] = ACTIONS(1891),
    [anon_sym_AMP] = ACTIONS(1891),
    [anon_sym_EQ_EQ] = ACTIONS(1893),
    [anon_sym_BANG_EQ] = ACTIONS(1893),
    [anon_sym_GT] = ACTIONS(1891),
    [anon_sym_GT_EQ] = ACTIONS(1891),
    [anon_sym_LT_EQ] = ACTIONS(1891),
    [anon_sym_LT] = ACTIONS(1891),
    [anon_sym_LT_LT] = ACTIONS(1891),
    [anon_sym_GT_GT] = ACTIONS(1891),
    [anon_sym_COLON] = ACTIONS(1891),
    [anon_sym___extension__] = ACTIONS(1893),
    [anon_sym___attribute__] = ACTIONS(1893),
    [anon_sym_COLON_COLON] = ACTIONS(1893),
    [anon_sym_LBRACE] = ACTIONS(1893),
    [anon_sym_LBRACK] = ACTIONS(1893),
    [anon_sym_EQ] = ACTIONS(1891),
    [anon_sym_const] = ACTIONS(1891),
    [anon_sym_constexpr] = ACTIONS(1893),
    [anon_sym_volatile] = ACTIONS(1893),
    [anon_sym_restrict] = ACTIONS(1893),
    [anon_sym___restrict__] = ACTIONS(1893),
    [anon_sym__Atomic] = ACTIONS(1893),
    [anon_sym__Noreturn] = ACTIONS(1893),
    [anon_sym_noreturn] = ACTIONS(1893),
    [anon_sym_mutable] = ACTIONS(1893),
    [anon_sym_constinit] = ACTIONS(1893),
    [anon_sym_consteval] = ACTIONS(1893),
    [anon_sym_alignas] = ACTIONS(1893),
    [anon_sym__Alignas] = ACTIONS(1893),
    [anon_sym_QMARK] = ACTIONS(1893),
    [anon_sym_STAR_EQ] = ACTIONS(1893),
    [anon_sym_SLASH_EQ] = ACTIONS(1893),
    [anon_sym_PERCENT_EQ] = ACTIONS(1893),
    [anon_sym_PLUS_EQ] = ACTIONS(1893),
    [anon_sym_DASH_EQ] = ACTIONS(1893),
    [anon_sym_LT_LT_EQ] = ACTIONS(1893),
    [anon_sym_GT_GT_EQ] = ACTIONS(1891),
    [anon_sym_AMP_EQ] = ACTIONS(1893),
    [anon_sym_CARET_EQ] = ACTIONS(1893),
    [anon_sym_PIPE_EQ] = ACTIONS(1893),
    [anon_sym_and_eq] = ACTIONS(1893),
    [anon_sym_or_eq] = ACTIONS(1893),
    [anon_sym_xor_eq] = ACTIONS(1893),
    [anon_sym_LT_EQ_GT] = ACTIONS(1893),
    [anon_sym_or] = ACTIONS(1891),
    [anon_sym_and] = ACTIONS(1891),
    [anon_sym_bitor] = ACTIONS(1893),
    [anon_sym_xor] = ACTIONS(1891),
    [anon_sym_bitand] = ACTIONS(1893),
    [anon_sym_not_eq] = ACTIONS(1893),
    [anon_sym_DASH_DASH] = ACTIONS(1893),
    [anon_sym_PLUS_PLUS] = ACTIONS(1893),
    [anon_sym_DOT] = ACTIONS(1891),
    [anon_sym_DOT_STAR] = ACTIONS(1893),
    [anon_sym_DASH_GT] = ACTIONS(1893),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1893),
    [anon_sym_decltype] = ACTIONS(1893),
    [anon_sym_final] = ACTIONS(1893),
    [anon_sym_override] = ACTIONS(1893),
    [anon_sym_GT2] = ACTIONS(1893),
  },
  [2382] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1897),
    [anon_sym_COMMA] = ACTIONS(1897),
    [anon_sym_LPAREN2] = ACTIONS(1897),
    [anon_sym_DASH] = ACTIONS(1895),
    [anon_sym_PLUS] = ACTIONS(1895),
    [anon_sym_STAR] = ACTIONS(1895),
    [anon_sym_SLASH] = ACTIONS(1895),
    [anon_sym_PERCENT] = ACTIONS(1895),
    [anon_sym_PIPE_PIPE] = ACTIONS(1897),
    [anon_sym_AMP_AMP] = ACTIONS(1897),
    [anon_sym_PIPE] = ACTIONS(1895),
    [anon_sym_CARET] = ACTIONS(1895),
    [anon_sym_AMP] = ACTIONS(1895),
    [anon_sym_EQ_EQ] = ACTIONS(1897),
    [anon_sym_BANG_EQ] = ACTIONS(1897),
    [anon_sym_GT] = ACTIONS(1895),
    [anon_sym_GT_EQ] = ACTIONS(1895),
    [anon_sym_LT_EQ] = ACTIONS(1895),
    [anon_sym_LT] = ACTIONS(1895),
    [anon_sym_LT_LT] = ACTIONS(1895),
    [anon_sym_GT_GT] = ACTIONS(1895),
    [anon_sym_COLON] = ACTIONS(1895),
    [anon_sym___extension__] = ACTIONS(1897),
    [anon_sym___attribute__] = ACTIONS(1897),
    [anon_sym_COLON_COLON] = ACTIONS(1897),
    [anon_sym_LBRACE] = ACTIONS(1897),
    [anon_sym_LBRACK] = ACTIONS(1897),
    [anon_sym_EQ] = ACTIONS(1895),
    [anon_sym_const] = ACTIONS(1895),
    [anon_sym_constexpr] = ACTIONS(1897),
    [anon_sym_volatile] = ACTIONS(1897),
    [anon_sym_restrict] = ACTIONS(1897),
    [anon_sym___restrict__] = ACTIONS(1897),
    [anon_sym__Atomic] = ACTIONS(1897),
    [anon_sym__Noreturn] = ACTIONS(1897),
    [anon_sym_noreturn] = ACTIONS(1897),
    [anon_sym_mutable] = ACTIONS(1897),
    [anon_sym_constinit] = ACTIONS(1897),
    [anon_sym_consteval] = ACTIONS(1897),
    [anon_sym_alignas] = ACTIONS(1897),
    [anon_sym__Alignas] = ACTIONS(1897),
    [anon_sym_QMARK] = ACTIONS(1897),
    [anon_sym_STAR_EQ] = ACTIONS(1897),
    [anon_sym_SLASH_EQ] = ACTIONS(1897),
    [anon_sym_PERCENT_EQ] = ACTIONS(1897),
    [anon_sym_PLUS_EQ] = ACTIONS(1897),
    [anon_sym_DASH_EQ] = ACTIONS(1897),
    [anon_sym_LT_LT_EQ] = ACTIONS(1897),
    [anon_sym_GT_GT_EQ] = ACTIONS(1895),
    [anon_sym_AMP_EQ] = ACTIONS(1897),
    [anon_sym_CARET_EQ] = ACTIONS(1897),
    [anon_sym_PIPE_EQ] = ACTIONS(1897),
    [anon_sym_and_eq] = ACTIONS(1897),
    [anon_sym_or_eq] = ACTIONS(1897),
    [anon_sym_xor_eq] = ACTIONS(1897),
    [anon_sym_LT_EQ_GT] = ACTIONS(1897),
    [anon_sym_or] = ACTIONS(1895),
    [anon_sym_and] = ACTIONS(1895),
    [anon_sym_bitor] = ACTIONS(1897),
    [anon_sym_xor] = ACTIONS(1895),
    [anon_sym_bitand] = ACTIONS(1897),
    [anon_sym_not_eq] = ACTIONS(1897),
    [anon_sym_DASH_DASH] = ACTIONS(1897),
    [anon_sym_PLUS_PLUS] = ACTIONS(1897),
    [anon_sym_DOT] = ACTIONS(1895),
    [anon_sym_DOT_STAR] = ACTIONS(1897),
    [anon_sym_DASH_GT] = ACTIONS(1897),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1897),
    [anon_sym_decltype] = ACTIONS(1897),
    [anon_sym_final] = ACTIONS(1897),
    [anon_sym_override] = ACTIONS(1897),
    [anon_sym_GT2] = ACTIONS(1897),
  },
  [2383] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1901),
    [anon_sym_COMMA] = ACTIONS(1901),
    [anon_sym_LPAREN2] = ACTIONS(1901),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1899),
    [anon_sym_SLASH] = ACTIONS(1899),
    [anon_sym_PERCENT] = ACTIONS(1899),
    [anon_sym_PIPE_PIPE] = ACTIONS(1901),
    [anon_sym_AMP_AMP] = ACTIONS(1901),
    [anon_sym_PIPE] = ACTIONS(1899),
    [anon_sym_CARET] = ACTIONS(1899),
    [anon_sym_AMP] = ACTIONS(1899),
    [anon_sym_EQ_EQ] = ACTIONS(1901),
    [anon_sym_BANG_EQ] = ACTIONS(1901),
    [anon_sym_GT] = ACTIONS(1899),
    [anon_sym_GT_EQ] = ACTIONS(1899),
    [anon_sym_LT_EQ] = ACTIONS(1899),
    [anon_sym_LT] = ACTIONS(1899),
    [anon_sym_LT_LT] = ACTIONS(1899),
    [anon_sym_GT_GT] = ACTIONS(1899),
    [anon_sym_COLON] = ACTIONS(1899),
    [anon_sym___extension__] = ACTIONS(1901),
    [anon_sym___attribute__] = ACTIONS(1901),
    [anon_sym_COLON_COLON] = ACTIONS(1901),
    [anon_sym_LBRACE] = ACTIONS(1901),
    [anon_sym_LBRACK] = ACTIONS(1901),
    [anon_sym_EQ] = ACTIONS(1899),
    [anon_sym_const] = ACTIONS(1899),
    [anon_sym_constexpr] = ACTIONS(1901),
    [anon_sym_volatile] = ACTIONS(1901),
    [anon_sym_restrict] = ACTIONS(1901),
    [anon_sym___restrict__] = ACTIONS(1901),
    [anon_sym__Atomic] = ACTIONS(1901),
    [anon_sym__Noreturn] = ACTIONS(1901),
    [anon_sym_noreturn] = ACTIONS(1901),
    [anon_sym_mutable] = ACTIONS(1901),
    [anon_sym_constinit] = ACTIONS(1901),
    [anon_sym_consteval] = ACTIONS(1901),
    [anon_sym_alignas] = ACTIONS(1901),
    [anon_sym__Alignas] = ACTIONS(1901),
    [anon_sym_QMARK] = ACTIONS(1901),
    [anon_sym_STAR_EQ] = ACTIONS(1901),
    [anon_sym_SLASH_EQ] = ACTIONS(1901),
    [anon_sym_PERCENT_EQ] = ACTIONS(1901),
    [anon_sym_PLUS_EQ] = ACTIONS(1901),
    [anon_sym_DASH_EQ] = ACTIONS(1901),
    [anon_sym_LT_LT_EQ] = ACTIONS(1901),
    [anon_sym_GT_GT_EQ] = ACTIONS(1899),
    [anon_sym_AMP_EQ] = ACTIONS(1901),
    [anon_sym_CARET_EQ] = ACTIONS(1901),
    [anon_sym_PIPE_EQ] = ACTIONS(1901),
    [anon_sym_and_eq] = ACTIONS(1901),
    [anon_sym_or_eq] = ACTIONS(1901),
    [anon_sym_xor_eq] = ACTIONS(1901),
    [anon_sym_LT_EQ_GT] = ACTIONS(1901),
    [anon_sym_or] = ACTIONS(1899),
    [anon_sym_and] = ACTIONS(1899),
    [anon_sym_bitor] = ACTIONS(1901),
    [anon_sym_xor] = ACTIONS(1899),
    [anon_sym_bitand] = ACTIONS(1901),
    [anon_sym_not_eq] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DOT] = ACTIONS(1899),
    [anon_sym_DOT_STAR] = ACTIONS(1901),
    [anon_sym_DASH_GT] = ACTIONS(1901),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1901),
    [anon_sym_decltype] = ACTIONS(1901),
    [anon_sym_final] = ACTIONS(1901),
    [anon_sym_override] = ACTIONS(1901),
    [anon_sym_GT2] = ACTIONS(1901),
  },
  [2384] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1927),
    [anon_sym_COMMA] = ACTIONS(1927),
    [anon_sym_LPAREN2] = ACTIONS(1927),
    [anon_sym_DASH] = ACTIONS(1925),
    [anon_sym_PLUS] = ACTIONS(1925),
    [anon_sym_STAR] = ACTIONS(1925),
    [anon_sym_SLASH] = ACTIONS(1925),
    [anon_sym_PERCENT] = ACTIONS(1925),
    [anon_sym_PIPE_PIPE] = ACTIONS(1927),
    [anon_sym_AMP_AMP] = ACTIONS(1927),
    [anon_sym_PIPE] = ACTIONS(1925),
    [anon_sym_CARET] = ACTIONS(1925),
    [anon_sym_AMP] = ACTIONS(1925),
    [anon_sym_EQ_EQ] = ACTIONS(1927),
    [anon_sym_BANG_EQ] = ACTIONS(1927),
    [anon_sym_GT] = ACTIONS(1925),
    [anon_sym_GT_EQ] = ACTIONS(1925),
    [anon_sym_LT_EQ] = ACTIONS(1925),
    [anon_sym_LT] = ACTIONS(1925),
    [anon_sym_LT_LT] = ACTIONS(1925),
    [anon_sym_GT_GT] = ACTIONS(1925),
    [anon_sym_COLON] = ACTIONS(1925),
    [anon_sym___extension__] = ACTIONS(1927),
    [anon_sym___attribute__] = ACTIONS(1927),
    [anon_sym_COLON_COLON] = ACTIONS(1927),
    [anon_sym_LBRACE] = ACTIONS(1927),
    [anon_sym_LBRACK] = ACTIONS(1927),
    [anon_sym_EQ] = ACTIONS(1925),
    [anon_sym_const] = ACTIONS(1925),
    [anon_sym_constexpr] = ACTIONS(1927),
    [anon_sym_volatile] = ACTIONS(1927),
    [anon_sym_restrict] = ACTIONS(1927),
    [anon_sym___restrict__] = ACTIONS(1927),
    [anon_sym__Atomic] = ACTIONS(1927),
    [anon_sym__Noreturn] = ACTIONS(1927),
    [anon_sym_noreturn] = ACTIONS(1927),
    [anon_sym_mutable] = ACTIONS(1927),
    [anon_sym_constinit] = ACTIONS(1927),
    [anon_sym_consteval] = ACTIONS(1927),
    [anon_sym_alignas] = ACTIONS(1927),
    [anon_sym__Alignas] = ACTIONS(1927),
    [anon_sym_QMARK] = ACTIONS(1927),
    [anon_sym_STAR_EQ] = ACTIONS(1927),
    [anon_sym_SLASH_EQ] = ACTIONS(1927),
    [anon_sym_PERCENT_EQ] = ACTIONS(1927),
    [anon_sym_PLUS_EQ] = ACTIONS(1927),
    [anon_sym_DASH_EQ] = ACTIONS(1927),
    [anon_sym_LT_LT_EQ] = ACTIONS(1927),
    [anon_sym_GT_GT_EQ] = ACTIONS(1925),
    [anon_sym_AMP_EQ] = ACTIONS(1927),
    [anon_sym_CARET_EQ] = ACTIONS(1927),
    [anon_sym_PIPE_EQ] = ACTIONS(1927),
    [anon_sym_and_eq] = ACTIONS(1927),
    [anon_sym_or_eq] = ACTIONS(1927),
    [anon_sym_xor_eq] = ACTIONS(1927),
    [anon_sym_LT_EQ_GT] = ACTIONS(1927),
    [anon_sym_or] = ACTIONS(1925),
    [anon_sym_and] = ACTIONS(1925),
    [anon_sym_bitor] = ACTIONS(1927),
    [anon_sym_xor] = ACTIONS(1925),
    [anon_sym_bitand] = ACTIONS(1927),
    [anon_sym_not_eq] = ACTIONS(1927),
    [anon_sym_DASH_DASH] = ACTIONS(1927),
    [anon_sym_PLUS_PLUS] = ACTIONS(1927),
    [anon_sym_DOT] = ACTIONS(1925),
    [anon_sym_DOT_STAR] = ACTIONS(1927),
    [anon_sym_DASH_GT] = ACTIONS(1927),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1927),
    [anon_sym_decltype] = ACTIONS(1927),
    [anon_sym_final] = ACTIONS(1927),
    [anon_sym_override] = ACTIONS(1927),
    [anon_sym_GT2] = ACTIONS(1927),
  },
  [2385] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1889),
    [anon_sym_COMMA] = ACTIONS(1889),
    [anon_sym_LPAREN2] = ACTIONS(1889),
    [anon_sym_DASH] = ACTIONS(1887),
    [anon_sym_PLUS] = ACTIONS(1887),
    [anon_sym_STAR] = ACTIONS(1887),
    [anon_sym_SLASH] = ACTIONS(1887),
    [anon_sym_PERCENT] = ACTIONS(1887),
    [anon_sym_PIPE_PIPE] = ACTIONS(1889),
    [anon_sym_AMP_AMP] = ACTIONS(1889),
    [anon_sym_PIPE] = ACTIONS(1887),
    [anon_sym_CARET] = ACTIONS(1887),
    [anon_sym_AMP] = ACTIONS(1887),
    [anon_sym_EQ_EQ] = ACTIONS(1889),
    [anon_sym_BANG_EQ] = ACTIONS(1889),
    [anon_sym_GT] = ACTIONS(1887),
    [anon_sym_GT_EQ] = ACTIONS(1887),
    [anon_sym_LT_EQ] = ACTIONS(1887),
    [anon_sym_LT] = ACTIONS(1887),
    [anon_sym_LT_LT] = ACTIONS(1887),
    [anon_sym_GT_GT] = ACTIONS(1887),
    [anon_sym_COLON] = ACTIONS(1887),
    [anon_sym___extension__] = ACTIONS(1889),
    [anon_sym___attribute__] = ACTIONS(1889),
    [anon_sym_COLON_COLON] = ACTIONS(1889),
    [anon_sym_LBRACE] = ACTIONS(1889),
    [anon_sym_LBRACK] = ACTIONS(1889),
    [anon_sym_EQ] = ACTIONS(1887),
    [anon_sym_const] = ACTIONS(1887),
    [anon_sym_constexpr] = ACTIONS(1889),
    [anon_sym_volatile] = ACTIONS(1889),
    [anon_sym_restrict] = ACTIONS(1889),
    [anon_sym___restrict__] = ACTIONS(1889),
    [anon_sym__Atomic] = ACTIONS(1889),
    [anon_sym__Noreturn] = ACTIONS(1889),
    [anon_sym_noreturn] = ACTIONS(1889),
    [anon_sym_mutable] = ACTIONS(1889),
    [anon_sym_constinit] = ACTIONS(1889),
    [anon_sym_consteval] = ACTIONS(1889),
    [anon_sym_alignas] = ACTIONS(1889),
    [anon_sym__Alignas] = ACTIONS(1889),
    [anon_sym_QMARK] = ACTIONS(1889),
    [anon_sym_STAR_EQ] = ACTIONS(1889),
    [anon_sym_SLASH_EQ] = ACTIONS(1889),
    [anon_sym_PERCENT_EQ] = ACTIONS(1889),
    [anon_sym_PLUS_EQ] = ACTIONS(1889),
    [anon_sym_DASH_EQ] = ACTIONS(1889),
    [anon_sym_LT_LT_EQ] = ACTIONS(1889),
    [anon_sym_GT_GT_EQ] = ACTIONS(1887),
    [anon_sym_AMP_EQ] = ACTIONS(1889),
    [anon_sym_CARET_EQ] = ACTIONS(1889),
    [anon_sym_PIPE_EQ] = ACTIONS(1889),
    [anon_sym_and_eq] = ACTIONS(1889),
    [anon_sym_or_eq] = ACTIONS(1889),
    [anon_sym_xor_eq] = ACTIONS(1889),
    [anon_sym_LT_EQ_GT] = ACTIONS(1889),
    [anon_sym_or] = ACTIONS(1887),
    [anon_sym_and] = ACTIONS(1887),
    [anon_sym_bitor] = ACTIONS(1889),
    [anon_sym_xor] = ACTIONS(1887),
    [anon_sym_bitand] = ACTIONS(1889),
    [anon_sym_not_eq] = ACTIONS(1889),
    [anon_sym_DASH_DASH] = ACTIONS(1889),
    [anon_sym_PLUS_PLUS] = ACTIONS(1889),
    [anon_sym_DOT] = ACTIONS(1887),
    [anon_sym_DOT_STAR] = ACTIONS(1889),
    [anon_sym_DASH_GT] = ACTIONS(1889),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1889),
    [anon_sym_decltype] = ACTIONS(1889),
    [anon_sym_final] = ACTIONS(1889),
    [anon_sym_override] = ACTIONS(1889),
    [anon_sym_GT2] = ACTIONS(1889),
  },
  [2386] = {
    [sym_attribute_specifier] = STATE(2293),
    [sym_enumerator_list] = STATE(2328),
    [sym__enum_base_clause] = STATE(2299),
    [sym_identifier] = ACTIONS(5636),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5638),
    [anon_sym_COMMA] = ACTIONS(5638),
    [anon_sym_RPAREN] = ACTIONS(5638),
    [anon_sym_LPAREN2] = ACTIONS(5638),
    [anon_sym_TILDE] = ACTIONS(5638),
    [anon_sym_STAR] = ACTIONS(5638),
    [anon_sym_AMP_AMP] = ACTIONS(5638),
    [anon_sym_AMP] = ACTIONS(5636),
    [anon_sym_COLON] = ACTIONS(5769),
    [anon_sym___extension__] = ACTIONS(5636),
    [anon_sym_in] = ACTIONS(5636),
    [anon_sym_out] = ACTIONS(5636),
    [anon_sym_inout] = ACTIONS(5636),
    [anon_sym_extern] = ACTIONS(5636),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_COLON_COLON] = ACTIONS(5638),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5638),
    [anon_sym___declspec] = ACTIONS(5636),
    [anon_sym___based] = ACTIONS(5636),
    [anon_sym_LBRACE] = ACTIONS(5523),
    [anon_sym_LBRACK] = ACTIONS(5636),
    [anon_sym_static] = ACTIONS(5636),
    [anon_sym_EQ] = ACTIONS(5638),
    [anon_sym_register] = ACTIONS(5636),
    [anon_sym_inline] = ACTIONS(5636),
    [anon_sym___inline] = ACTIONS(5636),
    [anon_sym___inline__] = ACTIONS(5636),
    [anon_sym___forceinline] = ACTIONS(5636),
    [anon_sym_thread_local] = ACTIONS(5636),
    [anon_sym___thread] = ACTIONS(5636),
    [anon_sym_const] = ACTIONS(5636),
    [anon_sym_constexpr] = ACTIONS(5636),
    [anon_sym_volatile] = ACTIONS(5636),
    [anon_sym_restrict] = ACTIONS(5636),
    [anon_sym___restrict__] = ACTIONS(5636),
    [anon_sym__Atomic] = ACTIONS(5636),
    [anon_sym__Noreturn] = ACTIONS(5636),
    [anon_sym_noreturn] = ACTIONS(5636),
    [anon_sym_mutable] = ACTIONS(5636),
    [anon_sym_constinit] = ACTIONS(5636),
    [anon_sym_consteval] = ACTIONS(5636),
    [anon_sym_alignas] = ACTIONS(5636),
    [anon_sym__Alignas] = ACTIONS(5636),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5636),
    [anon_sym_decltype] = ACTIONS(5636),
    [sym_virtual] = ACTIONS(5636),
    [anon_sym_template] = ACTIONS(5636),
    [anon_sym_GT2] = ACTIONS(5638),
    [anon_sym_operator] = ACTIONS(5636),
    [anon_sym_precise] = ACTIONS(5636),
    [anon_sym_shared] = ACTIONS(5636),
    [anon_sym_groupshared] = ACTIONS(5636),
    [anon_sym_uniform] = ACTIONS(5636),
    [anon_sym_row_major] = ACTIONS(5636),
    [anon_sym_column_major] = ACTIONS(5636),
    [anon_sym_globallycoherent] = ACTIONS(5636),
    [anon_sym_centroid] = ACTIONS(5636),
    [anon_sym_noperspective] = ACTIONS(5636),
    [anon_sym_nointerpolation] = ACTIONS(5636),
    [anon_sym_sample] = ACTIONS(5636),
    [anon_sym_linear] = ACTIONS(5636),
    [anon_sym_snorm] = ACTIONS(5636),
    [anon_sym_unorm] = ACTIONS(5636),
    [anon_sym_point] = ACTIONS(5636),
    [anon_sym_line] = ACTIONS(5636),
    [anon_sym_triangleadj] = ACTIONS(5636),
    [anon_sym_lineadj] = ACTIONS(5636),
    [anon_sym_triangle] = ACTIONS(5636),
  },
  [2387] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1919),
    [anon_sym_COMMA] = ACTIONS(1919),
    [anon_sym_LPAREN2] = ACTIONS(1919),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1917),
    [anon_sym_SLASH] = ACTIONS(1917),
    [anon_sym_PERCENT] = ACTIONS(1917),
    [anon_sym_PIPE_PIPE] = ACTIONS(1919),
    [anon_sym_AMP_AMP] = ACTIONS(1919),
    [anon_sym_PIPE] = ACTIONS(1917),
    [anon_sym_CARET] = ACTIONS(1917),
    [anon_sym_AMP] = ACTIONS(1917),
    [anon_sym_EQ_EQ] = ACTIONS(1919),
    [anon_sym_BANG_EQ] = ACTIONS(1919),
    [anon_sym_GT] = ACTIONS(1917),
    [anon_sym_GT_EQ] = ACTIONS(1917),
    [anon_sym_LT_EQ] = ACTIONS(1917),
    [anon_sym_LT] = ACTIONS(1917),
    [anon_sym_LT_LT] = ACTIONS(1917),
    [anon_sym_GT_GT] = ACTIONS(1917),
    [anon_sym_COLON] = ACTIONS(1917),
    [anon_sym___extension__] = ACTIONS(1919),
    [anon_sym___attribute__] = ACTIONS(1919),
    [anon_sym_COLON_COLON] = ACTIONS(1919),
    [anon_sym_LBRACE] = ACTIONS(1919),
    [anon_sym_LBRACK] = ACTIONS(1919),
    [anon_sym_EQ] = ACTIONS(1917),
    [anon_sym_const] = ACTIONS(1917),
    [anon_sym_constexpr] = ACTIONS(1919),
    [anon_sym_volatile] = ACTIONS(1919),
    [anon_sym_restrict] = ACTIONS(1919),
    [anon_sym___restrict__] = ACTIONS(1919),
    [anon_sym__Atomic] = ACTIONS(1919),
    [anon_sym__Noreturn] = ACTIONS(1919),
    [anon_sym_noreturn] = ACTIONS(1919),
    [anon_sym_mutable] = ACTIONS(1919),
    [anon_sym_constinit] = ACTIONS(1919),
    [anon_sym_consteval] = ACTIONS(1919),
    [anon_sym_alignas] = ACTIONS(1919),
    [anon_sym__Alignas] = ACTIONS(1919),
    [anon_sym_QMARK] = ACTIONS(1919),
    [anon_sym_STAR_EQ] = ACTIONS(1919),
    [anon_sym_SLASH_EQ] = ACTIONS(1919),
    [anon_sym_PERCENT_EQ] = ACTIONS(1919),
    [anon_sym_PLUS_EQ] = ACTIONS(1919),
    [anon_sym_DASH_EQ] = ACTIONS(1919),
    [anon_sym_LT_LT_EQ] = ACTIONS(1919),
    [anon_sym_GT_GT_EQ] = ACTIONS(1917),
    [anon_sym_AMP_EQ] = ACTIONS(1919),
    [anon_sym_CARET_EQ] = ACTIONS(1919),
    [anon_sym_PIPE_EQ] = ACTIONS(1919),
    [anon_sym_and_eq] = ACTIONS(1919),
    [anon_sym_or_eq] = ACTIONS(1919),
    [anon_sym_xor_eq] = ACTIONS(1919),
    [anon_sym_LT_EQ_GT] = ACTIONS(1919),
    [anon_sym_or] = ACTIONS(1917),
    [anon_sym_and] = ACTIONS(1917),
    [anon_sym_bitor] = ACTIONS(1919),
    [anon_sym_xor] = ACTIONS(1917),
    [anon_sym_bitand] = ACTIONS(1919),
    [anon_sym_not_eq] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DOT] = ACTIONS(1917),
    [anon_sym_DOT_STAR] = ACTIONS(1919),
    [anon_sym_DASH_GT] = ACTIONS(1919),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1919),
    [anon_sym_decltype] = ACTIONS(1919),
    [anon_sym_final] = ACTIONS(1919),
    [anon_sym_override] = ACTIONS(1919),
    [anon_sym_GT2] = ACTIONS(1919),
  },
  [2388] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1905),
    [anon_sym_COMMA] = ACTIONS(1905),
    [anon_sym_LPAREN2] = ACTIONS(1905),
    [anon_sym_DASH] = ACTIONS(1903),
    [anon_sym_PLUS] = ACTIONS(1903),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_SLASH] = ACTIONS(1903),
    [anon_sym_PERCENT] = ACTIONS(1903),
    [anon_sym_PIPE_PIPE] = ACTIONS(1905),
    [anon_sym_AMP_AMP] = ACTIONS(1905),
    [anon_sym_PIPE] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1903),
    [anon_sym_AMP] = ACTIONS(1903),
    [anon_sym_EQ_EQ] = ACTIONS(1905),
    [anon_sym_BANG_EQ] = ACTIONS(1905),
    [anon_sym_GT] = ACTIONS(1903),
    [anon_sym_GT_EQ] = ACTIONS(1903),
    [anon_sym_LT_EQ] = ACTIONS(1903),
    [anon_sym_LT] = ACTIONS(1903),
    [anon_sym_LT_LT] = ACTIONS(1903),
    [anon_sym_GT_GT] = ACTIONS(1903),
    [anon_sym_COLON] = ACTIONS(1903),
    [anon_sym___extension__] = ACTIONS(1905),
    [anon_sym___attribute__] = ACTIONS(1905),
    [anon_sym_COLON_COLON] = ACTIONS(1905),
    [anon_sym_LBRACE] = ACTIONS(1905),
    [anon_sym_LBRACK] = ACTIONS(1905),
    [anon_sym_EQ] = ACTIONS(1903),
    [anon_sym_const] = ACTIONS(1903),
    [anon_sym_constexpr] = ACTIONS(1905),
    [anon_sym_volatile] = ACTIONS(1905),
    [anon_sym_restrict] = ACTIONS(1905),
    [anon_sym___restrict__] = ACTIONS(1905),
    [anon_sym__Atomic] = ACTIONS(1905),
    [anon_sym__Noreturn] = ACTIONS(1905),
    [anon_sym_noreturn] = ACTIONS(1905),
    [anon_sym_mutable] = ACTIONS(1905),
    [anon_sym_constinit] = ACTIONS(1905),
    [anon_sym_consteval] = ACTIONS(1905),
    [anon_sym_alignas] = ACTIONS(1905),
    [anon_sym__Alignas] = ACTIONS(1905),
    [anon_sym_QMARK] = ACTIONS(1905),
    [anon_sym_STAR_EQ] = ACTIONS(1905),
    [anon_sym_SLASH_EQ] = ACTIONS(1905),
    [anon_sym_PERCENT_EQ] = ACTIONS(1905),
    [anon_sym_PLUS_EQ] = ACTIONS(1905),
    [anon_sym_DASH_EQ] = ACTIONS(1905),
    [anon_sym_LT_LT_EQ] = ACTIONS(1905),
    [anon_sym_GT_GT_EQ] = ACTIONS(1903),
    [anon_sym_AMP_EQ] = ACTIONS(1905),
    [anon_sym_CARET_EQ] = ACTIONS(1905),
    [anon_sym_PIPE_EQ] = ACTIONS(1905),
    [anon_sym_and_eq] = ACTIONS(1905),
    [anon_sym_or_eq] = ACTIONS(1905),
    [anon_sym_xor_eq] = ACTIONS(1905),
    [anon_sym_LT_EQ_GT] = ACTIONS(1905),
    [anon_sym_or] = ACTIONS(1903),
    [anon_sym_and] = ACTIONS(1903),
    [anon_sym_bitor] = ACTIONS(1905),
    [anon_sym_xor] = ACTIONS(1903),
    [anon_sym_bitand] = ACTIONS(1905),
    [anon_sym_not_eq] = ACTIONS(1905),
    [anon_sym_DASH_DASH] = ACTIONS(1905),
    [anon_sym_PLUS_PLUS] = ACTIONS(1905),
    [anon_sym_DOT] = ACTIONS(1903),
    [anon_sym_DOT_STAR] = ACTIONS(1905),
    [anon_sym_DASH_GT] = ACTIONS(1905),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1905),
    [anon_sym_decltype] = ACTIONS(1905),
    [anon_sym_final] = ACTIONS(1905),
    [anon_sym_override] = ACTIONS(1905),
    [anon_sym_GT2] = ACTIONS(1905),
  },
  [2389] = {
    [sym_template_argument_list] = STATE(2433),
    [sym_identifier] = ACTIONS(1933),
    [anon_sym_LPAREN2] = ACTIONS(4047),
    [anon_sym_TILDE] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1935),
    [anon_sym_AMP_AMP] = ACTIONS(1935),
    [anon_sym_AMP] = ACTIONS(1933),
    [anon_sym_LT] = ACTIONS(5298),
    [anon_sym_SEMI] = ACTIONS(1935),
    [anon_sym___extension__] = ACTIONS(1933),
    [anon_sym_in] = ACTIONS(1933),
    [anon_sym_out] = ACTIONS(1933),
    [anon_sym_inout] = ACTIONS(1933),
    [anon_sym_extern] = ACTIONS(1933),
    [anon_sym___attribute__] = ACTIONS(1933),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4047),
    [anon_sym___declspec] = ACTIONS(1933),
    [anon_sym___based] = ACTIONS(1933),
    [anon_sym___cdecl] = ACTIONS(1933),
    [anon_sym___clrcall] = ACTIONS(1933),
    [anon_sym___stdcall] = ACTIONS(1933),
    [anon_sym___fastcall] = ACTIONS(1933),
    [anon_sym___thiscall] = ACTIONS(1933),
    [anon_sym___vectorcall] = ACTIONS(1933),
    [anon_sym_LBRACK] = ACTIONS(4052),
    [anon_sym_static] = ACTIONS(1933),
    [anon_sym_register] = ACTIONS(1933),
    [anon_sym_inline] = ACTIONS(1933),
    [anon_sym___inline] = ACTIONS(1933),
    [anon_sym___inline__] = ACTIONS(1933),
    [anon_sym___forceinline] = ACTIONS(1933),
    [anon_sym_thread_local] = ACTIONS(1933),
    [anon_sym___thread] = ACTIONS(1933),
    [anon_sym_const] = ACTIONS(1933),
    [anon_sym_constexpr] = ACTIONS(1933),
    [anon_sym_volatile] = ACTIONS(1933),
    [anon_sym_restrict] = ACTIONS(1933),
    [anon_sym___restrict__] = ACTIONS(1933),
    [anon_sym__Atomic] = ACTIONS(1933),
    [anon_sym__Noreturn] = ACTIONS(1933),
    [anon_sym_noreturn] = ACTIONS(1933),
    [anon_sym_mutable] = ACTIONS(1933),
    [anon_sym_constinit] = ACTIONS(1933),
    [anon_sym_consteval] = ACTIONS(1933),
    [anon_sym_alignas] = ACTIONS(1933),
    [anon_sym__Alignas] = ACTIONS(1933),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1933),
    [anon_sym_decltype] = ACTIONS(1933),
    [sym_virtual] = ACTIONS(1933),
    [anon_sym_template] = ACTIONS(1933),
    [anon_sym_operator] = ACTIONS(1933),
    [anon_sym_precise] = ACTIONS(1933),
    [anon_sym_shared] = ACTIONS(1933),
    [anon_sym_groupshared] = ACTIONS(1933),
    [anon_sym_uniform] = ACTIONS(1933),
    [anon_sym_row_major] = ACTIONS(1933),
    [anon_sym_column_major] = ACTIONS(1933),
    [anon_sym_globallycoherent] = ACTIONS(1933),
    [anon_sym_centroid] = ACTIONS(1933),
    [anon_sym_noperspective] = ACTIONS(1933),
    [anon_sym_nointerpolation] = ACTIONS(1933),
    [anon_sym_sample] = ACTIONS(1933),
    [anon_sym_linear] = ACTIONS(1933),
    [anon_sym_snorm] = ACTIONS(1933),
    [anon_sym_unorm] = ACTIONS(1933),
    [anon_sym_point] = ACTIONS(1933),
    [anon_sym_line] = ACTIONS(1933),
    [anon_sym_triangleadj] = ACTIONS(1933),
    [anon_sym_lineadj] = ACTIONS(1933),
    [anon_sym_triangle] = ACTIONS(1933),
  },
  [2390] = {
    [sym_identifier] = ACTIONS(1959),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1961),
    [anon_sym_COMMA] = ACTIONS(1961),
    [anon_sym_RPAREN] = ACTIONS(1961),
    [anon_sym_LPAREN2] = ACTIONS(1961),
    [anon_sym_DASH] = ACTIONS(1959),
    [anon_sym_PLUS] = ACTIONS(1959),
    [anon_sym_STAR] = ACTIONS(1961),
    [anon_sym_SLASH] = ACTIONS(1959),
    [anon_sym_PERCENT] = ACTIONS(1961),
    [anon_sym_PIPE_PIPE] = ACTIONS(1961),
    [anon_sym_AMP_AMP] = ACTIONS(1961),
    [anon_sym_PIPE] = ACTIONS(1959),
    [anon_sym_CARET] = ACTIONS(1961),
    [anon_sym_AMP] = ACTIONS(1959),
    [anon_sym_EQ_EQ] = ACTIONS(1961),
    [anon_sym_BANG_EQ] = ACTIONS(1961),
    [anon_sym_GT] = ACTIONS(1959),
    [anon_sym_GT_EQ] = ACTIONS(1961),
    [anon_sym_LT_EQ] = ACTIONS(1959),
    [anon_sym_LT] = ACTIONS(1959),
    [anon_sym_LT_LT] = ACTIONS(1961),
    [anon_sym_GT_GT] = ACTIONS(1961),
    [anon_sym_COLON] = ACTIONS(1959),
    [anon_sym_SEMI] = ACTIONS(1961),
    [anon_sym___extension__] = ACTIONS(1959),
    [anon_sym___attribute__] = ACTIONS(1959),
    [anon_sym_COLON_COLON] = ACTIONS(1961),
    [anon_sym___based] = ACTIONS(1959),
    [anon_sym_LBRACE] = ACTIONS(1961),
    [anon_sym_RBRACE] = ACTIONS(1961),
    [anon_sym_signed] = ACTIONS(1959),
    [anon_sym_unsigned] = ACTIONS(1959),
    [anon_sym_long] = ACTIONS(1959),
    [anon_sym_short] = ACTIONS(1959),
    [anon_sym_LBRACK] = ACTIONS(1961),
    [anon_sym_RBRACK] = ACTIONS(1961),
    [anon_sym_const] = ACTIONS(1959),
    [anon_sym_constexpr] = ACTIONS(1959),
    [anon_sym_volatile] = ACTIONS(1959),
    [anon_sym_restrict] = ACTIONS(1959),
    [anon_sym___restrict__] = ACTIONS(1959),
    [anon_sym__Atomic] = ACTIONS(1959),
    [anon_sym__Noreturn] = ACTIONS(1959),
    [anon_sym_noreturn] = ACTIONS(1959),
    [anon_sym_mutable] = ACTIONS(1959),
    [anon_sym_constinit] = ACTIONS(1959),
    [anon_sym_consteval] = ACTIONS(1959),
    [anon_sym_alignas] = ACTIONS(1959),
    [anon_sym__Alignas] = ACTIONS(1959),
    [sym_primitive_type] = ACTIONS(1959),
    [anon_sym_else] = ACTIONS(1959),
    [anon_sym_while] = ACTIONS(1959),
    [anon_sym_QMARK] = ACTIONS(1961),
    [anon_sym_LT_EQ_GT] = ACTIONS(1961),
    [anon_sym_or] = ACTIONS(1959),
    [anon_sym_and] = ACTIONS(1959),
    [anon_sym_bitor] = ACTIONS(1959),
    [anon_sym_xor] = ACTIONS(1959),
    [anon_sym_bitand] = ACTIONS(1959),
    [anon_sym_not_eq] = ACTIONS(1959),
    [anon_sym_DASH_DASH] = ACTIONS(1961),
    [anon_sym_PLUS_PLUS] = ACTIONS(1961),
    [anon_sym_DOT] = ACTIONS(1959),
    [anon_sym_DOT_STAR] = ACTIONS(1961),
    [anon_sym_DASH_GT] = ACTIONS(1961),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1959),
    [anon_sym_decltype] = ACTIONS(1959),
    [anon_sym_final] = ACTIONS(1959),
    [anon_sym_override] = ACTIONS(1959),
    [anon_sym_requires] = ACTIONS(1959),
  },
  [2391] = {
    [sym_identifier] = ACTIONS(5779),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5781),
    [anon_sym_COMMA] = ACTIONS(5781),
    [anon_sym_RPAREN] = ACTIONS(5781),
    [aux_sym_preproc_if_token2] = ACTIONS(5781),
    [aux_sym_preproc_else_token1] = ACTIONS(5781),
    [aux_sym_preproc_elif_token1] = ACTIONS(5779),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5781),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5781),
    [anon_sym_LPAREN2] = ACTIONS(5781),
    [anon_sym_DASH] = ACTIONS(5779),
    [anon_sym_PLUS] = ACTIONS(5779),
    [anon_sym_STAR] = ACTIONS(5779),
    [anon_sym_SLASH] = ACTIONS(5779),
    [anon_sym_PERCENT] = ACTIONS(5779),
    [anon_sym_PIPE_PIPE] = ACTIONS(5781),
    [anon_sym_AMP_AMP] = ACTIONS(5781),
    [anon_sym_PIPE] = ACTIONS(5779),
    [anon_sym_CARET] = ACTIONS(5779),
    [anon_sym_AMP] = ACTIONS(5779),
    [anon_sym_EQ_EQ] = ACTIONS(5781),
    [anon_sym_BANG_EQ] = ACTIONS(5781),
    [anon_sym_GT] = ACTIONS(5779),
    [anon_sym_GT_EQ] = ACTIONS(5781),
    [anon_sym_LT_EQ] = ACTIONS(5779),
    [anon_sym_LT] = ACTIONS(5779),
    [anon_sym_LT_LT] = ACTIONS(5779),
    [anon_sym_GT_GT] = ACTIONS(5779),
    [anon_sym_COLON] = ACTIONS(5781),
    [anon_sym_SEMI] = ACTIONS(5781),
    [anon_sym_RBRACE] = ACTIONS(5781),
    [anon_sym_LBRACK] = ACTIONS(5781),
    [anon_sym_RBRACK] = ACTIONS(5781),
    [anon_sym_EQ] = ACTIONS(5779),
    [anon_sym_QMARK] = ACTIONS(5781),
    [anon_sym_STAR_EQ] = ACTIONS(5781),
    [anon_sym_SLASH_EQ] = ACTIONS(5781),
    [anon_sym_PERCENT_EQ] = ACTIONS(5781),
    [anon_sym_PLUS_EQ] = ACTIONS(5781),
    [anon_sym_DASH_EQ] = ACTIONS(5781),
    [anon_sym_LT_LT_EQ] = ACTIONS(5781),
    [anon_sym_GT_GT_EQ] = ACTIONS(5781),
    [anon_sym_AMP_EQ] = ACTIONS(5781),
    [anon_sym_CARET_EQ] = ACTIONS(5781),
    [anon_sym_PIPE_EQ] = ACTIONS(5781),
    [anon_sym_and_eq] = ACTIONS(5779),
    [anon_sym_or_eq] = ACTIONS(5779),
    [anon_sym_xor_eq] = ACTIONS(5779),
    [anon_sym_LT_EQ_GT] = ACTIONS(5781),
    [anon_sym_or] = ACTIONS(5779),
    [anon_sym_and] = ACTIONS(5779),
    [anon_sym_bitor] = ACTIONS(5779),
    [anon_sym_xor] = ACTIONS(5779),
    [anon_sym_bitand] = ACTIONS(5779),
    [anon_sym_not_eq] = ACTIONS(5779),
    [anon_sym_DASH_DASH] = ACTIONS(5781),
    [anon_sym_PLUS_PLUS] = ACTIONS(5781),
    [anon_sym_DOT] = ACTIONS(5779),
    [anon_sym_DOT_STAR] = ACTIONS(5781),
    [anon_sym_DASH_GT] = ACTIONS(5781),
    [anon_sym_L_DQUOTE] = ACTIONS(5781),
    [anon_sym_u_DQUOTE] = ACTIONS(5781),
    [anon_sym_U_DQUOTE] = ACTIONS(5781),
    [anon_sym_u8_DQUOTE] = ACTIONS(5781),
    [anon_sym_DQUOTE] = ACTIONS(5781),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5781),
    [anon_sym_LR_DQUOTE] = ACTIONS(5781),
    [anon_sym_uR_DQUOTE] = ACTIONS(5781),
    [anon_sym_UR_DQUOTE] = ACTIONS(5781),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5781),
    [sym_literal_suffix] = ACTIONS(5779),
  },
  [2392] = {
    [sym_identifier] = ACTIONS(1903),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1905),
    [anon_sym_COMMA] = ACTIONS(1905),
    [anon_sym_RPAREN] = ACTIONS(1905),
    [anon_sym_LPAREN2] = ACTIONS(1905),
    [anon_sym_TILDE] = ACTIONS(1905),
    [anon_sym_STAR] = ACTIONS(1905),
    [anon_sym_AMP_AMP] = ACTIONS(1905),
    [anon_sym_AMP] = ACTIONS(1903),
    [anon_sym_COLON] = ACTIONS(1903),
    [anon_sym___extension__] = ACTIONS(1903),
    [anon_sym_in] = ACTIONS(1903),
    [anon_sym_out] = ACTIONS(1903),
    [anon_sym_inout] = ACTIONS(1903),
    [anon_sym_extern] = ACTIONS(1903),
    [anon_sym___attribute__] = ACTIONS(1903),
    [anon_sym_COLON_COLON] = ACTIONS(1905),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1905),
    [anon_sym___declspec] = ACTIONS(1903),
    [anon_sym___based] = ACTIONS(1903),
    [anon_sym_LBRACE] = ACTIONS(1905),
    [anon_sym_LBRACK] = ACTIONS(1903),
    [anon_sym_static] = ACTIONS(1903),
    [anon_sym_EQ] = ACTIONS(1905),
    [anon_sym_register] = ACTIONS(1903),
    [anon_sym_inline] = ACTIONS(1903),
    [anon_sym___inline] = ACTIONS(1903),
    [anon_sym___inline__] = ACTIONS(1903),
    [anon_sym___forceinline] = ACTIONS(1903),
    [anon_sym_thread_local] = ACTIONS(1903),
    [anon_sym___thread] = ACTIONS(1903),
    [anon_sym_const] = ACTIONS(1903),
    [anon_sym_constexpr] = ACTIONS(1903),
    [anon_sym_volatile] = ACTIONS(1903),
    [anon_sym_restrict] = ACTIONS(1903),
    [anon_sym___restrict__] = ACTIONS(1903),
    [anon_sym__Atomic] = ACTIONS(1903),
    [anon_sym__Noreturn] = ACTIONS(1903),
    [anon_sym_noreturn] = ACTIONS(1903),
    [anon_sym_mutable] = ACTIONS(1903),
    [anon_sym_constinit] = ACTIONS(1903),
    [anon_sym_consteval] = ACTIONS(1903),
    [anon_sym_alignas] = ACTIONS(1903),
    [anon_sym__Alignas] = ACTIONS(1903),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1903),
    [anon_sym_decltype] = ACTIONS(1903),
    [anon_sym_final] = ACTIONS(1903),
    [anon_sym_override] = ACTIONS(1903),
    [sym_virtual] = ACTIONS(1903),
    [anon_sym_template] = ACTIONS(1903),
    [anon_sym_GT2] = ACTIONS(1905),
    [anon_sym_operator] = ACTIONS(1903),
    [anon_sym_precise] = ACTIONS(1903),
    [anon_sym_shared] = ACTIONS(1903),
    [anon_sym_groupshared] = ACTIONS(1903),
    [anon_sym_uniform] = ACTIONS(1903),
    [anon_sym_row_major] = ACTIONS(1903),
    [anon_sym_column_major] = ACTIONS(1903),
    [anon_sym_globallycoherent] = ACTIONS(1903),
    [anon_sym_centroid] = ACTIONS(1903),
    [anon_sym_noperspective] = ACTIONS(1903),
    [anon_sym_nointerpolation] = ACTIONS(1903),
    [anon_sym_sample] = ACTIONS(1903),
    [anon_sym_linear] = ACTIONS(1903),
    [anon_sym_snorm] = ACTIONS(1903),
    [anon_sym_unorm] = ACTIONS(1903),
    [anon_sym_point] = ACTIONS(1903),
    [anon_sym_line] = ACTIONS(1903),
    [anon_sym_triangleadj] = ACTIONS(1903),
    [anon_sym_lineadj] = ACTIONS(1903),
    [anon_sym_triangle] = ACTIONS(1903),
  },
  [2393] = {
    [sym_identifier] = ACTIONS(5775),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5777),
    [anon_sym_COMMA] = ACTIONS(5777),
    [anon_sym_RPAREN] = ACTIONS(5777),
    [aux_sym_preproc_if_token2] = ACTIONS(5777),
    [aux_sym_preproc_else_token1] = ACTIONS(5777),
    [aux_sym_preproc_elif_token1] = ACTIONS(5775),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5777),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5777),
    [anon_sym_LPAREN2] = ACTIONS(5777),
    [anon_sym_DASH] = ACTIONS(5775),
    [anon_sym_PLUS] = ACTIONS(5775),
    [anon_sym_STAR] = ACTIONS(5775),
    [anon_sym_SLASH] = ACTIONS(5775),
    [anon_sym_PERCENT] = ACTIONS(5775),
    [anon_sym_PIPE_PIPE] = ACTIONS(5777),
    [anon_sym_AMP_AMP] = ACTIONS(5777),
    [anon_sym_PIPE] = ACTIONS(5775),
    [anon_sym_CARET] = ACTIONS(5775),
    [anon_sym_AMP] = ACTIONS(5775),
    [anon_sym_EQ_EQ] = ACTIONS(5777),
    [anon_sym_BANG_EQ] = ACTIONS(5777),
    [anon_sym_GT] = ACTIONS(5775),
    [anon_sym_GT_EQ] = ACTIONS(5777),
    [anon_sym_LT_EQ] = ACTIONS(5775),
    [anon_sym_LT] = ACTIONS(5775),
    [anon_sym_LT_LT] = ACTIONS(5775),
    [anon_sym_GT_GT] = ACTIONS(5775),
    [anon_sym_COLON] = ACTIONS(5777),
    [anon_sym_SEMI] = ACTIONS(5777),
    [anon_sym_RBRACE] = ACTIONS(5777),
    [anon_sym_LBRACK] = ACTIONS(5777),
    [anon_sym_RBRACK] = ACTIONS(5777),
    [anon_sym_EQ] = ACTIONS(5775),
    [anon_sym_QMARK] = ACTIONS(5777),
    [anon_sym_STAR_EQ] = ACTIONS(5777),
    [anon_sym_SLASH_EQ] = ACTIONS(5777),
    [anon_sym_PERCENT_EQ] = ACTIONS(5777),
    [anon_sym_PLUS_EQ] = ACTIONS(5777),
    [anon_sym_DASH_EQ] = ACTIONS(5777),
    [anon_sym_LT_LT_EQ] = ACTIONS(5777),
    [anon_sym_GT_GT_EQ] = ACTIONS(5777),
    [anon_sym_AMP_EQ] = ACTIONS(5777),
    [anon_sym_CARET_EQ] = ACTIONS(5777),
    [anon_sym_PIPE_EQ] = ACTIONS(5777),
    [anon_sym_and_eq] = ACTIONS(5775),
    [anon_sym_or_eq] = ACTIONS(5775),
    [anon_sym_xor_eq] = ACTIONS(5775),
    [anon_sym_LT_EQ_GT] = ACTIONS(5777),
    [anon_sym_or] = ACTIONS(5775),
    [anon_sym_and] = ACTIONS(5775),
    [anon_sym_bitor] = ACTIONS(5775),
    [anon_sym_xor] = ACTIONS(5775),
    [anon_sym_bitand] = ACTIONS(5775),
    [anon_sym_not_eq] = ACTIONS(5775),
    [anon_sym_DASH_DASH] = ACTIONS(5777),
    [anon_sym_PLUS_PLUS] = ACTIONS(5777),
    [anon_sym_DOT] = ACTIONS(5775),
    [anon_sym_DOT_STAR] = ACTIONS(5777),
    [anon_sym_DASH_GT] = ACTIONS(5777),
    [anon_sym_L_DQUOTE] = ACTIONS(5777),
    [anon_sym_u_DQUOTE] = ACTIONS(5777),
    [anon_sym_U_DQUOTE] = ACTIONS(5777),
    [anon_sym_u8_DQUOTE] = ACTIONS(5777),
    [anon_sym_DQUOTE] = ACTIONS(5777),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5777),
    [anon_sym_LR_DQUOTE] = ACTIONS(5777),
    [anon_sym_uR_DQUOTE] = ACTIONS(5777),
    [anon_sym_UR_DQUOTE] = ACTIONS(5777),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5777),
    [sym_literal_suffix] = ACTIONS(5775),
  },
  [2394] = {
    [sym_identifier] = ACTIONS(5771),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5773),
    [anon_sym_COMMA] = ACTIONS(5773),
    [anon_sym_RPAREN] = ACTIONS(5773),
    [aux_sym_preproc_if_token2] = ACTIONS(5773),
    [aux_sym_preproc_else_token1] = ACTIONS(5773),
    [aux_sym_preproc_elif_token1] = ACTIONS(5771),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5773),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5773),
    [anon_sym_LPAREN2] = ACTIONS(5773),
    [anon_sym_DASH] = ACTIONS(5771),
    [anon_sym_PLUS] = ACTIONS(5771),
    [anon_sym_STAR] = ACTIONS(5771),
    [anon_sym_SLASH] = ACTIONS(5771),
    [anon_sym_PERCENT] = ACTIONS(5771),
    [anon_sym_PIPE_PIPE] = ACTIONS(5773),
    [anon_sym_AMP_AMP] = ACTIONS(5773),
    [anon_sym_PIPE] = ACTIONS(5771),
    [anon_sym_CARET] = ACTIONS(5771),
    [anon_sym_AMP] = ACTIONS(5771),
    [anon_sym_EQ_EQ] = ACTIONS(5773),
    [anon_sym_BANG_EQ] = ACTIONS(5773),
    [anon_sym_GT] = ACTIONS(5771),
    [anon_sym_GT_EQ] = ACTIONS(5773),
    [anon_sym_LT_EQ] = ACTIONS(5771),
    [anon_sym_LT] = ACTIONS(5771),
    [anon_sym_LT_LT] = ACTIONS(5771),
    [anon_sym_GT_GT] = ACTIONS(5771),
    [anon_sym_COLON] = ACTIONS(5773),
    [anon_sym_SEMI] = ACTIONS(5773),
    [anon_sym_RBRACE] = ACTIONS(5773),
    [anon_sym_LBRACK] = ACTIONS(5773),
    [anon_sym_RBRACK] = ACTIONS(5773),
    [anon_sym_EQ] = ACTIONS(5771),
    [anon_sym_QMARK] = ACTIONS(5773),
    [anon_sym_STAR_EQ] = ACTIONS(5773),
    [anon_sym_SLASH_EQ] = ACTIONS(5773),
    [anon_sym_PERCENT_EQ] = ACTIONS(5773),
    [anon_sym_PLUS_EQ] = ACTIONS(5773),
    [anon_sym_DASH_EQ] = ACTIONS(5773),
    [anon_sym_LT_LT_EQ] = ACTIONS(5773),
    [anon_sym_GT_GT_EQ] = ACTIONS(5773),
    [anon_sym_AMP_EQ] = ACTIONS(5773),
    [anon_sym_CARET_EQ] = ACTIONS(5773),
    [anon_sym_PIPE_EQ] = ACTIONS(5773),
    [anon_sym_and_eq] = ACTIONS(5771),
    [anon_sym_or_eq] = ACTIONS(5771),
    [anon_sym_xor_eq] = ACTIONS(5771),
    [anon_sym_LT_EQ_GT] = ACTIONS(5773),
    [anon_sym_or] = ACTIONS(5771),
    [anon_sym_and] = ACTIONS(5771),
    [anon_sym_bitor] = ACTIONS(5771),
    [anon_sym_xor] = ACTIONS(5771),
    [anon_sym_bitand] = ACTIONS(5771),
    [anon_sym_not_eq] = ACTIONS(5771),
    [anon_sym_DASH_DASH] = ACTIONS(5773),
    [anon_sym_PLUS_PLUS] = ACTIONS(5773),
    [anon_sym_DOT] = ACTIONS(5771),
    [anon_sym_DOT_STAR] = ACTIONS(5773),
    [anon_sym_DASH_GT] = ACTIONS(5773),
    [anon_sym_L_DQUOTE] = ACTIONS(5773),
    [anon_sym_u_DQUOTE] = ACTIONS(5773),
    [anon_sym_U_DQUOTE] = ACTIONS(5773),
    [anon_sym_u8_DQUOTE] = ACTIONS(5773),
    [anon_sym_DQUOTE] = ACTIONS(5773),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5773),
    [anon_sym_LR_DQUOTE] = ACTIONS(5773),
    [anon_sym_uR_DQUOTE] = ACTIONS(5773),
    [anon_sym_UR_DQUOTE] = ACTIONS(5773),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5773),
    [sym_literal_suffix] = ACTIONS(5771),
  },
  [2395] = {
    [sym_identifier] = ACTIONS(1895),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1897),
    [anon_sym_COMMA] = ACTIONS(1897),
    [anon_sym_RPAREN] = ACTIONS(1897),
    [anon_sym_LPAREN2] = ACTIONS(1897),
    [anon_sym_TILDE] = ACTIONS(1897),
    [anon_sym_STAR] = ACTIONS(1897),
    [anon_sym_AMP_AMP] = ACTIONS(1897),
    [anon_sym_AMP] = ACTIONS(1895),
    [anon_sym_COLON] = ACTIONS(1895),
    [anon_sym___extension__] = ACTIONS(1895),
    [anon_sym_in] = ACTIONS(1895),
    [anon_sym_out] = ACTIONS(1895),
    [anon_sym_inout] = ACTIONS(1895),
    [anon_sym_extern] = ACTIONS(1895),
    [anon_sym___attribute__] = ACTIONS(1895),
    [anon_sym_COLON_COLON] = ACTIONS(1897),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1897),
    [anon_sym___declspec] = ACTIONS(1895),
    [anon_sym___based] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1897),
    [anon_sym_LBRACK] = ACTIONS(1895),
    [anon_sym_static] = ACTIONS(1895),
    [anon_sym_EQ] = ACTIONS(1897),
    [anon_sym_register] = ACTIONS(1895),
    [anon_sym_inline] = ACTIONS(1895),
    [anon_sym___inline] = ACTIONS(1895),
    [anon_sym___inline__] = ACTIONS(1895),
    [anon_sym___forceinline] = ACTIONS(1895),
    [anon_sym_thread_local] = ACTIONS(1895),
    [anon_sym___thread] = ACTIONS(1895),
    [anon_sym_const] = ACTIONS(1895),
    [anon_sym_constexpr] = ACTIONS(1895),
    [anon_sym_volatile] = ACTIONS(1895),
    [anon_sym_restrict] = ACTIONS(1895),
    [anon_sym___restrict__] = ACTIONS(1895),
    [anon_sym__Atomic] = ACTIONS(1895),
    [anon_sym__Noreturn] = ACTIONS(1895),
    [anon_sym_noreturn] = ACTIONS(1895),
    [anon_sym_mutable] = ACTIONS(1895),
    [anon_sym_constinit] = ACTIONS(1895),
    [anon_sym_consteval] = ACTIONS(1895),
    [anon_sym_alignas] = ACTIONS(1895),
    [anon_sym__Alignas] = ACTIONS(1895),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1895),
    [anon_sym_decltype] = ACTIONS(1895),
    [anon_sym_final] = ACTIONS(1895),
    [anon_sym_override] = ACTIONS(1895),
    [sym_virtual] = ACTIONS(1895),
    [anon_sym_template] = ACTIONS(1895),
    [anon_sym_GT2] = ACTIONS(1897),
    [anon_sym_operator] = ACTIONS(1895),
    [anon_sym_precise] = ACTIONS(1895),
    [anon_sym_shared] = ACTIONS(1895),
    [anon_sym_groupshared] = ACTIONS(1895),
    [anon_sym_uniform] = ACTIONS(1895),
    [anon_sym_row_major] = ACTIONS(1895),
    [anon_sym_column_major] = ACTIONS(1895),
    [anon_sym_globallycoherent] = ACTIONS(1895),
    [anon_sym_centroid] = ACTIONS(1895),
    [anon_sym_noperspective] = ACTIONS(1895),
    [anon_sym_nointerpolation] = ACTIONS(1895),
    [anon_sym_sample] = ACTIONS(1895),
    [anon_sym_linear] = ACTIONS(1895),
    [anon_sym_snorm] = ACTIONS(1895),
    [anon_sym_unorm] = ACTIONS(1895),
    [anon_sym_point] = ACTIONS(1895),
    [anon_sym_line] = ACTIONS(1895),
    [anon_sym_triangleadj] = ACTIONS(1895),
    [anon_sym_lineadj] = ACTIONS(1895),
    [anon_sym_triangle] = ACTIONS(1895),
  },
  [2396] = {
    [sym_template_argument_list] = STATE(2404),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4045),
    [anon_sym_COMMA] = ACTIONS(4045),
    [anon_sym_RPAREN] = ACTIONS(4047),
    [anon_sym_LPAREN2] = ACTIONS(4047),
    [anon_sym_DASH] = ACTIONS(4050),
    [anon_sym_PLUS] = ACTIONS(4050),
    [anon_sym_STAR] = ACTIONS(4052),
    [anon_sym_SLASH] = ACTIONS(4050),
    [anon_sym_PERCENT] = ACTIONS(4050),
    [anon_sym_PIPE_PIPE] = ACTIONS(4045),
    [anon_sym_AMP_AMP] = ACTIONS(4047),
    [anon_sym_PIPE] = ACTIONS(4050),
    [anon_sym_CARET] = ACTIONS(4050),
    [anon_sym_AMP] = ACTIONS(4052),
    [anon_sym_EQ_EQ] = ACTIONS(4045),
    [anon_sym_BANG_EQ] = ACTIONS(4045),
    [anon_sym_GT] = ACTIONS(4050),
    [anon_sym_GT_EQ] = ACTIONS(4045),
    [anon_sym_LT_EQ] = ACTIONS(4050),
    [anon_sym_LT] = ACTIONS(4196),
    [anon_sym_LT_LT] = ACTIONS(4050),
    [anon_sym_GT_GT] = ACTIONS(4050),
    [anon_sym___extension__] = ACTIONS(1935),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4045),
    [anon_sym_LBRACE] = ACTIONS(1935),
    [anon_sym_LBRACK] = ACTIONS(4052),
    [anon_sym_EQ] = ACTIONS(4050),
    [anon_sym_const] = ACTIONS(1933),
    [anon_sym_constexpr] = ACTIONS(1935),
    [anon_sym_volatile] = ACTIONS(1935),
    [anon_sym_restrict] = ACTIONS(1935),
    [anon_sym___restrict__] = ACTIONS(1935),
    [anon_sym__Atomic] = ACTIONS(1935),
    [anon_sym__Noreturn] = ACTIONS(1935),
    [anon_sym_noreturn] = ACTIONS(1935),
    [anon_sym_mutable] = ACTIONS(1935),
    [anon_sym_constinit] = ACTIONS(1935),
    [anon_sym_consteval] = ACTIONS(1935),
    [anon_sym_alignas] = ACTIONS(1935),
    [anon_sym__Alignas] = ACTIONS(1935),
    [anon_sym_QMARK] = ACTIONS(4045),
    [anon_sym_STAR_EQ] = ACTIONS(4045),
    [anon_sym_SLASH_EQ] = ACTIONS(4045),
    [anon_sym_PERCENT_EQ] = ACTIONS(4045),
    [anon_sym_PLUS_EQ] = ACTIONS(4045),
    [anon_sym_DASH_EQ] = ACTIONS(4045),
    [anon_sym_LT_LT_EQ] = ACTIONS(4045),
    [anon_sym_GT_GT_EQ] = ACTIONS(4045),
    [anon_sym_AMP_EQ] = ACTIONS(4045),
    [anon_sym_CARET_EQ] = ACTIONS(4045),
    [anon_sym_PIPE_EQ] = ACTIONS(4045),
    [anon_sym_and_eq] = ACTIONS(4045),
    [anon_sym_or_eq] = ACTIONS(4045),
    [anon_sym_xor_eq] = ACTIONS(4045),
    [anon_sym_LT_EQ_GT] = ACTIONS(4045),
    [anon_sym_or] = ACTIONS(4050),
    [anon_sym_and] = ACTIONS(4050),
    [anon_sym_bitor] = ACTIONS(4045),
    [anon_sym_xor] = ACTIONS(4050),
    [anon_sym_bitand] = ACTIONS(4045),
    [anon_sym_not_eq] = ACTIONS(4045),
    [anon_sym_DASH_DASH] = ACTIONS(4045),
    [anon_sym_PLUS_PLUS] = ACTIONS(4045),
    [anon_sym_DOT] = ACTIONS(4050),
    [anon_sym_DOT_STAR] = ACTIONS(4045),
    [anon_sym_DASH_GT] = ACTIONS(4050),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1935),
    [anon_sym_decltype] = ACTIONS(1935),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4045),
  },
  [2397] = {
    [sym_identifier] = ACTIONS(1917),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1919),
    [anon_sym_COMMA] = ACTIONS(1919),
    [anon_sym_RPAREN] = ACTIONS(1919),
    [anon_sym_LPAREN2] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_STAR] = ACTIONS(1919),
    [anon_sym_AMP_AMP] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1917),
    [anon_sym_COLON] = ACTIONS(1917),
    [anon_sym___extension__] = ACTIONS(1917),
    [anon_sym_in] = ACTIONS(1917),
    [anon_sym_out] = ACTIONS(1917),
    [anon_sym_inout] = ACTIONS(1917),
    [anon_sym_extern] = ACTIONS(1917),
    [anon_sym___attribute__] = ACTIONS(1917),
    [anon_sym_COLON_COLON] = ACTIONS(1919),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1919),
    [anon_sym___declspec] = ACTIONS(1917),
    [anon_sym___based] = ACTIONS(1917),
    [anon_sym_LBRACE] = ACTIONS(1919),
    [anon_sym_LBRACK] = ACTIONS(1917),
    [anon_sym_static] = ACTIONS(1917),
    [anon_sym_EQ] = ACTIONS(1919),
    [anon_sym_register] = ACTIONS(1917),
    [anon_sym_inline] = ACTIONS(1917),
    [anon_sym___inline] = ACTIONS(1917),
    [anon_sym___inline__] = ACTIONS(1917),
    [anon_sym___forceinline] = ACTIONS(1917),
    [anon_sym_thread_local] = ACTIONS(1917),
    [anon_sym___thread] = ACTIONS(1917),
    [anon_sym_const] = ACTIONS(1917),
    [anon_sym_constexpr] = ACTIONS(1917),
    [anon_sym_volatile] = ACTIONS(1917),
    [anon_sym_restrict] = ACTIONS(1917),
    [anon_sym___restrict__] = ACTIONS(1917),
    [anon_sym__Atomic] = ACTIONS(1917),
    [anon_sym__Noreturn] = ACTIONS(1917),
    [anon_sym_noreturn] = ACTIONS(1917),
    [anon_sym_mutable] = ACTIONS(1917),
    [anon_sym_constinit] = ACTIONS(1917),
    [anon_sym_consteval] = ACTIONS(1917),
    [anon_sym_alignas] = ACTIONS(1917),
    [anon_sym__Alignas] = ACTIONS(1917),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1917),
    [anon_sym_decltype] = ACTIONS(1917),
    [anon_sym_final] = ACTIONS(1917),
    [anon_sym_override] = ACTIONS(1917),
    [sym_virtual] = ACTIONS(1917),
    [anon_sym_template] = ACTIONS(1917),
    [anon_sym_GT2] = ACTIONS(1919),
    [anon_sym_operator] = ACTIONS(1917),
    [anon_sym_precise] = ACTIONS(1917),
    [anon_sym_shared] = ACTIONS(1917),
    [anon_sym_groupshared] = ACTIONS(1917),
    [anon_sym_uniform] = ACTIONS(1917),
    [anon_sym_row_major] = ACTIONS(1917),
    [anon_sym_column_major] = ACTIONS(1917),
    [anon_sym_globallycoherent] = ACTIONS(1917),
    [anon_sym_centroid] = ACTIONS(1917),
    [anon_sym_noperspective] = ACTIONS(1917),
    [anon_sym_nointerpolation] = ACTIONS(1917),
    [anon_sym_sample] = ACTIONS(1917),
    [anon_sym_linear] = ACTIONS(1917),
    [anon_sym_snorm] = ACTIONS(1917),
    [anon_sym_unorm] = ACTIONS(1917),
    [anon_sym_point] = ACTIONS(1917),
    [anon_sym_line] = ACTIONS(1917),
    [anon_sym_triangleadj] = ACTIONS(1917),
    [anon_sym_lineadj] = ACTIONS(1917),
    [anon_sym_triangle] = ACTIONS(1917),
  },
  [2398] = {
    [sym_identifier] = ACTIONS(1887),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1889),
    [anon_sym_COMMA] = ACTIONS(1889),
    [anon_sym_RPAREN] = ACTIONS(1889),
    [anon_sym_LPAREN2] = ACTIONS(1889),
    [anon_sym_TILDE] = ACTIONS(1889),
    [anon_sym_STAR] = ACTIONS(1889),
    [anon_sym_AMP_AMP] = ACTIONS(1889),
    [anon_sym_AMP] = ACTIONS(1887),
    [anon_sym_COLON] = ACTIONS(1887),
    [anon_sym___extension__] = ACTIONS(1887),
    [anon_sym_in] = ACTIONS(1887),
    [anon_sym_out] = ACTIONS(1887),
    [anon_sym_inout] = ACTIONS(1887),
    [anon_sym_extern] = ACTIONS(1887),
    [anon_sym___attribute__] = ACTIONS(1887),
    [anon_sym_COLON_COLON] = ACTIONS(1889),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1889),
    [anon_sym___declspec] = ACTIONS(1887),
    [anon_sym___based] = ACTIONS(1887),
    [anon_sym_LBRACE] = ACTIONS(1889),
    [anon_sym_LBRACK] = ACTIONS(1887),
    [anon_sym_static] = ACTIONS(1887),
    [anon_sym_EQ] = ACTIONS(1889),
    [anon_sym_register] = ACTIONS(1887),
    [anon_sym_inline] = ACTIONS(1887),
    [anon_sym___inline] = ACTIONS(1887),
    [anon_sym___inline__] = ACTIONS(1887),
    [anon_sym___forceinline] = ACTIONS(1887),
    [anon_sym_thread_local] = ACTIONS(1887),
    [anon_sym___thread] = ACTIONS(1887),
    [anon_sym_const] = ACTIONS(1887),
    [anon_sym_constexpr] = ACTIONS(1887),
    [anon_sym_volatile] = ACTIONS(1887),
    [anon_sym_restrict] = ACTIONS(1887),
    [anon_sym___restrict__] = ACTIONS(1887),
    [anon_sym__Atomic] = ACTIONS(1887),
    [anon_sym__Noreturn] = ACTIONS(1887),
    [anon_sym_noreturn] = ACTIONS(1887),
    [anon_sym_mutable] = ACTIONS(1887),
    [anon_sym_constinit] = ACTIONS(1887),
    [anon_sym_consteval] = ACTIONS(1887),
    [anon_sym_alignas] = ACTIONS(1887),
    [anon_sym__Alignas] = ACTIONS(1887),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1887),
    [anon_sym_decltype] = ACTIONS(1887),
    [anon_sym_final] = ACTIONS(1887),
    [anon_sym_override] = ACTIONS(1887),
    [sym_virtual] = ACTIONS(1887),
    [anon_sym_template] = ACTIONS(1887),
    [anon_sym_GT2] = ACTIONS(1889),
    [anon_sym_operator] = ACTIONS(1887),
    [anon_sym_precise] = ACTIONS(1887),
    [anon_sym_shared] = ACTIONS(1887),
    [anon_sym_groupshared] = ACTIONS(1887),
    [anon_sym_uniform] = ACTIONS(1887),
    [anon_sym_row_major] = ACTIONS(1887),
    [anon_sym_column_major] = ACTIONS(1887),
    [anon_sym_globallycoherent] = ACTIONS(1887),
    [anon_sym_centroid] = ACTIONS(1887),
    [anon_sym_noperspective] = ACTIONS(1887),
    [anon_sym_nointerpolation] = ACTIONS(1887),
    [anon_sym_sample] = ACTIONS(1887),
    [anon_sym_linear] = ACTIONS(1887),
    [anon_sym_snorm] = ACTIONS(1887),
    [anon_sym_unorm] = ACTIONS(1887),
    [anon_sym_point] = ACTIONS(1887),
    [anon_sym_line] = ACTIONS(1887),
    [anon_sym_triangleadj] = ACTIONS(1887),
    [anon_sym_lineadj] = ACTIONS(1887),
    [anon_sym_triangle] = ACTIONS(1887),
  },
  [2399] = {
    [sym_type_qualifier] = STATE(2399),
    [sym_alignas_qualifier] = STATE(2435),
    [aux_sym_array_declarator_repeat1] = STATE(2399),
    [sym_identifier] = ACTIONS(5783),
    [anon_sym_LPAREN2] = ACTIONS(5785),
    [anon_sym_BANG] = ACTIONS(5785),
    [anon_sym_TILDE] = ACTIONS(5785),
    [anon_sym_DASH] = ACTIONS(5783),
    [anon_sym_PLUS] = ACTIONS(5783),
    [anon_sym_STAR] = ACTIONS(5785),
    [anon_sym_AMP] = ACTIONS(5785),
    [anon_sym___extension__] = ACTIONS(5787),
    [anon_sym_COLON_COLON] = ACTIONS(5785),
    [anon_sym_LBRACK] = ACTIONS(5785),
    [anon_sym_static] = ACTIONS(5790),
    [anon_sym_RBRACK] = ACTIONS(5785),
    [anon_sym_const] = ACTIONS(5787),
    [anon_sym_constexpr] = ACTIONS(5787),
    [anon_sym_volatile] = ACTIONS(5787),
    [anon_sym_restrict] = ACTIONS(5787),
    [anon_sym___restrict__] = ACTIONS(5787),
    [anon_sym__Atomic] = ACTIONS(5787),
    [anon_sym__Noreturn] = ACTIONS(5787),
    [anon_sym_noreturn] = ACTIONS(5787),
    [anon_sym_mutable] = ACTIONS(5787),
    [anon_sym_constinit] = ACTIONS(5787),
    [anon_sym_consteval] = ACTIONS(5787),
    [anon_sym_alignas] = ACTIONS(5793),
    [anon_sym__Alignas] = ACTIONS(5793),
    [sym_primitive_type] = ACTIONS(5783),
    [anon_sym_not] = ACTIONS(5783),
    [anon_sym_compl] = ACTIONS(5783),
    [anon_sym_DASH_DASH] = ACTIONS(5785),
    [anon_sym_PLUS_PLUS] = ACTIONS(5785),
    [anon_sym_sizeof] = ACTIONS(5783),
    [anon_sym___alignof__] = ACTIONS(5783),
    [anon_sym___alignof] = ACTIONS(5783),
    [anon_sym__alignof] = ACTIONS(5783),
    [anon_sym_alignof] = ACTIONS(5783),
    [anon_sym__Alignof] = ACTIONS(5783),
    [anon_sym_offsetof] = ACTIONS(5783),
    [anon_sym__Generic] = ACTIONS(5783),
    [anon_sym_asm] = ACTIONS(5783),
    [anon_sym___asm__] = ACTIONS(5783),
    [sym_number_literal] = ACTIONS(5785),
    [anon_sym_L_SQUOTE] = ACTIONS(5785),
    [anon_sym_u_SQUOTE] = ACTIONS(5785),
    [anon_sym_U_SQUOTE] = ACTIONS(5785),
    [anon_sym_u8_SQUOTE] = ACTIONS(5785),
    [anon_sym_SQUOTE] = ACTIONS(5785),
    [anon_sym_L_DQUOTE] = ACTIONS(5785),
    [anon_sym_u_DQUOTE] = ACTIONS(5785),
    [anon_sym_U_DQUOTE] = ACTIONS(5785),
    [anon_sym_u8_DQUOTE] = ACTIONS(5785),
    [anon_sym_DQUOTE] = ACTIONS(5785),
    [sym_true] = ACTIONS(5783),
    [sym_false] = ACTIONS(5783),
    [anon_sym_NULL] = ACTIONS(5783),
    [anon_sym_nullptr] = ACTIONS(5783),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(5783),
    [anon_sym_template] = ACTIONS(5783),
    [anon_sym_delete] = ACTIONS(5783),
    [anon_sym_R_DQUOTE] = ACTIONS(5785),
    [anon_sym_LR_DQUOTE] = ACTIONS(5785),
    [anon_sym_uR_DQUOTE] = ACTIONS(5785),
    [anon_sym_UR_DQUOTE] = ACTIONS(5785),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5785),
    [anon_sym_co_await] = ACTIONS(5783),
    [anon_sym_new] = ACTIONS(5783),
    [anon_sym_requires] = ACTIONS(5783),
    [sym_this] = ACTIONS(5783),
  },
  [2400] = {
    [sym_identifier] = ACTIONS(1899),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1901),
    [anon_sym_COMMA] = ACTIONS(1901),
    [anon_sym_RPAREN] = ACTIONS(1901),
    [anon_sym_LPAREN2] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_STAR] = ACTIONS(1901),
    [anon_sym_AMP_AMP] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1899),
    [anon_sym_COLON] = ACTIONS(1899),
    [anon_sym___extension__] = ACTIONS(1899),
    [anon_sym_in] = ACTIONS(1899),
    [anon_sym_out] = ACTIONS(1899),
    [anon_sym_inout] = ACTIONS(1899),
    [anon_sym_extern] = ACTIONS(1899),
    [anon_sym___attribute__] = ACTIONS(1899),
    [anon_sym_COLON_COLON] = ACTIONS(1901),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1901),
    [anon_sym___declspec] = ACTIONS(1899),
    [anon_sym___based] = ACTIONS(1899),
    [anon_sym_LBRACE] = ACTIONS(1901),
    [anon_sym_LBRACK] = ACTIONS(1899),
    [anon_sym_static] = ACTIONS(1899),
    [anon_sym_EQ] = ACTIONS(1901),
    [anon_sym_register] = ACTIONS(1899),
    [anon_sym_inline] = ACTIONS(1899),
    [anon_sym___inline] = ACTIONS(1899),
    [anon_sym___inline__] = ACTIONS(1899),
    [anon_sym___forceinline] = ACTIONS(1899),
    [anon_sym_thread_local] = ACTIONS(1899),
    [anon_sym___thread] = ACTIONS(1899),
    [anon_sym_const] = ACTIONS(1899),
    [anon_sym_constexpr] = ACTIONS(1899),
    [anon_sym_volatile] = ACTIONS(1899),
    [anon_sym_restrict] = ACTIONS(1899),
    [anon_sym___restrict__] = ACTIONS(1899),
    [anon_sym__Atomic] = ACTIONS(1899),
    [anon_sym__Noreturn] = ACTIONS(1899),
    [anon_sym_noreturn] = ACTIONS(1899),
    [anon_sym_mutable] = ACTIONS(1899),
    [anon_sym_constinit] = ACTIONS(1899),
    [anon_sym_consteval] = ACTIONS(1899),
    [anon_sym_alignas] = ACTIONS(1899),
    [anon_sym__Alignas] = ACTIONS(1899),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1899),
    [anon_sym_decltype] = ACTIONS(1899),
    [anon_sym_final] = ACTIONS(1899),
    [anon_sym_override] = ACTIONS(1899),
    [sym_virtual] = ACTIONS(1899),
    [anon_sym_template] = ACTIONS(1899),
    [anon_sym_GT2] = ACTIONS(1901),
    [anon_sym_operator] = ACTIONS(1899),
    [anon_sym_precise] = ACTIONS(1899),
    [anon_sym_shared] = ACTIONS(1899),
    [anon_sym_groupshared] = ACTIONS(1899),
    [anon_sym_uniform] = ACTIONS(1899),
    [anon_sym_row_major] = ACTIONS(1899),
    [anon_sym_column_major] = ACTIONS(1899),
    [anon_sym_globallycoherent] = ACTIONS(1899),
    [anon_sym_centroid] = ACTIONS(1899),
    [anon_sym_noperspective] = ACTIONS(1899),
    [anon_sym_nointerpolation] = ACTIONS(1899),
    [anon_sym_sample] = ACTIONS(1899),
    [anon_sym_linear] = ACTIONS(1899),
    [anon_sym_snorm] = ACTIONS(1899),
    [anon_sym_unorm] = ACTIONS(1899),
    [anon_sym_point] = ACTIONS(1899),
    [anon_sym_line] = ACTIONS(1899),
    [anon_sym_triangleadj] = ACTIONS(1899),
    [anon_sym_lineadj] = ACTIONS(1899),
    [anon_sym_triangle] = ACTIONS(1899),
  },
  [2401] = {
    [sym_identifier] = ACTIONS(1925),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1927),
    [anon_sym_COMMA] = ACTIONS(1927),
    [anon_sym_RPAREN] = ACTIONS(1927),
    [anon_sym_LPAREN2] = ACTIONS(1927),
    [anon_sym_TILDE] = ACTIONS(1927),
    [anon_sym_STAR] = ACTIONS(1927),
    [anon_sym_AMP_AMP] = ACTIONS(1927),
    [anon_sym_AMP] = ACTIONS(1925),
    [anon_sym_COLON] = ACTIONS(1925),
    [anon_sym___extension__] = ACTIONS(1925),
    [anon_sym_in] = ACTIONS(1925),
    [anon_sym_out] = ACTIONS(1925),
    [anon_sym_inout] = ACTIONS(1925),
    [anon_sym_extern] = ACTIONS(1925),
    [anon_sym___attribute__] = ACTIONS(1925),
    [anon_sym_COLON_COLON] = ACTIONS(1927),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1927),
    [anon_sym___declspec] = ACTIONS(1925),
    [anon_sym___based] = ACTIONS(1925),
    [anon_sym_LBRACE] = ACTIONS(1927),
    [anon_sym_LBRACK] = ACTIONS(1925),
    [anon_sym_static] = ACTIONS(1925),
    [anon_sym_EQ] = ACTIONS(1927),
    [anon_sym_register] = ACTIONS(1925),
    [anon_sym_inline] = ACTIONS(1925),
    [anon_sym___inline] = ACTIONS(1925),
    [anon_sym___inline__] = ACTIONS(1925),
    [anon_sym___forceinline] = ACTIONS(1925),
    [anon_sym_thread_local] = ACTIONS(1925),
    [anon_sym___thread] = ACTIONS(1925),
    [anon_sym_const] = ACTIONS(1925),
    [anon_sym_constexpr] = ACTIONS(1925),
    [anon_sym_volatile] = ACTIONS(1925),
    [anon_sym_restrict] = ACTIONS(1925),
    [anon_sym___restrict__] = ACTIONS(1925),
    [anon_sym__Atomic] = ACTIONS(1925),
    [anon_sym__Noreturn] = ACTIONS(1925),
    [anon_sym_noreturn] = ACTIONS(1925),
    [anon_sym_mutable] = ACTIONS(1925),
    [anon_sym_constinit] = ACTIONS(1925),
    [anon_sym_consteval] = ACTIONS(1925),
    [anon_sym_alignas] = ACTIONS(1925),
    [anon_sym__Alignas] = ACTIONS(1925),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1925),
    [anon_sym_decltype] = ACTIONS(1925),
    [anon_sym_final] = ACTIONS(1925),
    [anon_sym_override] = ACTIONS(1925),
    [sym_virtual] = ACTIONS(1925),
    [anon_sym_template] = ACTIONS(1925),
    [anon_sym_GT2] = ACTIONS(1927),
    [anon_sym_operator] = ACTIONS(1925),
    [anon_sym_precise] = ACTIONS(1925),
    [anon_sym_shared] = ACTIONS(1925),
    [anon_sym_groupshared] = ACTIONS(1925),
    [anon_sym_uniform] = ACTIONS(1925),
    [anon_sym_row_major] = ACTIONS(1925),
    [anon_sym_column_major] = ACTIONS(1925),
    [anon_sym_globallycoherent] = ACTIONS(1925),
    [anon_sym_centroid] = ACTIONS(1925),
    [anon_sym_noperspective] = ACTIONS(1925),
    [anon_sym_nointerpolation] = ACTIONS(1925),
    [anon_sym_sample] = ACTIONS(1925),
    [anon_sym_linear] = ACTIONS(1925),
    [anon_sym_snorm] = ACTIONS(1925),
    [anon_sym_unorm] = ACTIONS(1925),
    [anon_sym_point] = ACTIONS(1925),
    [anon_sym_line] = ACTIONS(1925),
    [anon_sym_triangleadj] = ACTIONS(1925),
    [anon_sym_lineadj] = ACTIONS(1925),
    [anon_sym_triangle] = ACTIONS(1925),
  },
  [2402] = {
    [sym_identifier] = ACTIONS(1891),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1893),
    [anon_sym_COMMA] = ACTIONS(1893),
    [anon_sym_RPAREN] = ACTIONS(1893),
    [anon_sym_LPAREN2] = ACTIONS(1893),
    [anon_sym_TILDE] = ACTIONS(1893),
    [anon_sym_STAR] = ACTIONS(1893),
    [anon_sym_AMP_AMP] = ACTIONS(1893),
    [anon_sym_AMP] = ACTIONS(1891),
    [anon_sym_COLON] = ACTIONS(1891),
    [anon_sym___extension__] = ACTIONS(1891),
    [anon_sym_in] = ACTIONS(1891),
    [anon_sym_out] = ACTIONS(1891),
    [anon_sym_inout] = ACTIONS(1891),
    [anon_sym_extern] = ACTIONS(1891),
    [anon_sym___attribute__] = ACTIONS(1891),
    [anon_sym_COLON_COLON] = ACTIONS(1893),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(1893),
    [anon_sym___declspec] = ACTIONS(1891),
    [anon_sym___based] = ACTIONS(1891),
    [anon_sym_LBRACE] = ACTIONS(1893),
    [anon_sym_LBRACK] = ACTIONS(1891),
    [anon_sym_static] = ACTIONS(1891),
    [anon_sym_EQ] = ACTIONS(1893),
    [anon_sym_register] = ACTIONS(1891),
    [anon_sym_inline] = ACTIONS(1891),
    [anon_sym___inline] = ACTIONS(1891),
    [anon_sym___inline__] = ACTIONS(1891),
    [anon_sym___forceinline] = ACTIONS(1891),
    [anon_sym_thread_local] = ACTIONS(1891),
    [anon_sym___thread] = ACTIONS(1891),
    [anon_sym_const] = ACTIONS(1891),
    [anon_sym_constexpr] = ACTIONS(1891),
    [anon_sym_volatile] = ACTIONS(1891),
    [anon_sym_restrict] = ACTIONS(1891),
    [anon_sym___restrict__] = ACTIONS(1891),
    [anon_sym__Atomic] = ACTIONS(1891),
    [anon_sym__Noreturn] = ACTIONS(1891),
    [anon_sym_noreturn] = ACTIONS(1891),
    [anon_sym_mutable] = ACTIONS(1891),
    [anon_sym_constinit] = ACTIONS(1891),
    [anon_sym_consteval] = ACTIONS(1891),
    [anon_sym_alignas] = ACTIONS(1891),
    [anon_sym__Alignas] = ACTIONS(1891),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1891),
    [anon_sym_decltype] = ACTIONS(1891),
    [anon_sym_final] = ACTIONS(1891),
    [anon_sym_override] = ACTIONS(1891),
    [sym_virtual] = ACTIONS(1891),
    [anon_sym_template] = ACTIONS(1891),
    [anon_sym_GT2] = ACTIONS(1893),
    [anon_sym_operator] = ACTIONS(1891),
    [anon_sym_precise] = ACTIONS(1891),
    [anon_sym_shared] = ACTIONS(1891),
    [anon_sym_groupshared] = ACTIONS(1891),
    [anon_sym_uniform] = ACTIONS(1891),
    [anon_sym_row_major] = ACTIONS(1891),
    [anon_sym_column_major] = ACTIONS(1891),
    [anon_sym_globallycoherent] = ACTIONS(1891),
    [anon_sym_centroid] = ACTIONS(1891),
    [anon_sym_noperspective] = ACTIONS(1891),
    [anon_sym_nointerpolation] = ACTIONS(1891),
    [anon_sym_sample] = ACTIONS(1891),
    [anon_sym_linear] = ACTIONS(1891),
    [anon_sym_snorm] = ACTIONS(1891),
    [anon_sym_unorm] = ACTIONS(1891),
    [anon_sym_point] = ACTIONS(1891),
    [anon_sym_line] = ACTIONS(1891),
    [anon_sym_triangleadj] = ACTIONS(1891),
    [anon_sym_lineadj] = ACTIONS(1891),
    [anon_sym_triangle] = ACTIONS(1891),
  },
  [2403] = {
    [sym_identifier] = ACTIONS(5796),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5798),
    [anon_sym_COMMA] = ACTIONS(5798),
    [anon_sym_RPAREN] = ACTIONS(5798),
    [aux_sym_preproc_if_token2] = ACTIONS(5798),
    [aux_sym_preproc_else_token1] = ACTIONS(5798),
    [aux_sym_preproc_elif_token1] = ACTIONS(5796),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5798),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5798),
    [anon_sym_LPAREN2] = ACTIONS(5798),
    [anon_sym_DASH] = ACTIONS(5796),
    [anon_sym_PLUS] = ACTIONS(5796),
    [anon_sym_STAR] = ACTIONS(5796),
    [anon_sym_SLASH] = ACTIONS(5796),
    [anon_sym_PERCENT] = ACTIONS(5796),
    [anon_sym_PIPE_PIPE] = ACTIONS(5798),
    [anon_sym_AMP_AMP] = ACTIONS(5798),
    [anon_sym_PIPE] = ACTIONS(5796),
    [anon_sym_CARET] = ACTIONS(5796),
    [anon_sym_AMP] = ACTIONS(5796),
    [anon_sym_EQ_EQ] = ACTIONS(5798),
    [anon_sym_BANG_EQ] = ACTIONS(5798),
    [anon_sym_GT] = ACTIONS(5796),
    [anon_sym_GT_EQ] = ACTIONS(5798),
    [anon_sym_LT_EQ] = ACTIONS(5796),
    [anon_sym_LT] = ACTIONS(5796),
    [anon_sym_LT_LT] = ACTIONS(5796),
    [anon_sym_GT_GT] = ACTIONS(5796),
    [anon_sym_COLON] = ACTIONS(5798),
    [anon_sym_SEMI] = ACTIONS(5798),
    [anon_sym_RBRACE] = ACTIONS(5798),
    [anon_sym_LBRACK] = ACTIONS(5798),
    [anon_sym_RBRACK] = ACTIONS(5798),
    [anon_sym_EQ] = ACTIONS(5796),
    [anon_sym_QMARK] = ACTIONS(5798),
    [anon_sym_STAR_EQ] = ACTIONS(5798),
    [anon_sym_SLASH_EQ] = ACTIONS(5798),
    [anon_sym_PERCENT_EQ] = ACTIONS(5798),
    [anon_sym_PLUS_EQ] = ACTIONS(5798),
    [anon_sym_DASH_EQ] = ACTIONS(5798),
    [anon_sym_LT_LT_EQ] = ACTIONS(5798),
    [anon_sym_GT_GT_EQ] = ACTIONS(5798),
    [anon_sym_AMP_EQ] = ACTIONS(5798),
    [anon_sym_CARET_EQ] = ACTIONS(5798),
    [anon_sym_PIPE_EQ] = ACTIONS(5798),
    [anon_sym_and_eq] = ACTIONS(5796),
    [anon_sym_or_eq] = ACTIONS(5796),
    [anon_sym_xor_eq] = ACTIONS(5796),
    [anon_sym_LT_EQ_GT] = ACTIONS(5798),
    [anon_sym_or] = ACTIONS(5796),
    [anon_sym_and] = ACTIONS(5796),
    [anon_sym_bitor] = ACTIONS(5796),
    [anon_sym_xor] = ACTIONS(5796),
    [anon_sym_bitand] = ACTIONS(5796),
    [anon_sym_not_eq] = ACTIONS(5796),
    [anon_sym_DASH_DASH] = ACTIONS(5798),
    [anon_sym_PLUS_PLUS] = ACTIONS(5798),
    [anon_sym_DOT] = ACTIONS(5796),
    [anon_sym_DOT_STAR] = ACTIONS(5798),
    [anon_sym_DASH_GT] = ACTIONS(5798),
    [anon_sym_L_DQUOTE] = ACTIONS(5798),
    [anon_sym_u_DQUOTE] = ACTIONS(5798),
    [anon_sym_U_DQUOTE] = ACTIONS(5798),
    [anon_sym_u8_DQUOTE] = ACTIONS(5798),
    [anon_sym_DQUOTE] = ACTIONS(5798),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5798),
    [anon_sym_LR_DQUOTE] = ACTIONS(5798),
    [anon_sym_uR_DQUOTE] = ACTIONS(5798),
    [anon_sym_UR_DQUOTE] = ACTIONS(5798),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5798),
    [sym_literal_suffix] = ACTIONS(5796),
  },
  [2404] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4058),
    [anon_sym_COMMA] = ACTIONS(4058),
    [anon_sym_RPAREN] = ACTIONS(4060),
    [anon_sym_LPAREN2] = ACTIONS(4060),
    [anon_sym_DASH] = ACTIONS(4063),
    [anon_sym_PLUS] = ACTIONS(4063),
    [anon_sym_STAR] = ACTIONS(4065),
    [anon_sym_SLASH] = ACTIONS(4063),
    [anon_sym_PERCENT] = ACTIONS(4063),
    [anon_sym_PIPE_PIPE] = ACTIONS(4058),
    [anon_sym_AMP_AMP] = ACTIONS(4060),
    [anon_sym_PIPE] = ACTIONS(4063),
    [anon_sym_CARET] = ACTIONS(4063),
    [anon_sym_AMP] = ACTIONS(4065),
    [anon_sym_EQ_EQ] = ACTIONS(4058),
    [anon_sym_BANG_EQ] = ACTIONS(4058),
    [anon_sym_GT] = ACTIONS(4063),
    [anon_sym_GT_EQ] = ACTIONS(4058),
    [anon_sym_LT_EQ] = ACTIONS(4063),
    [anon_sym_LT] = ACTIONS(4063),
    [anon_sym_LT_LT] = ACTIONS(4063),
    [anon_sym_GT_GT] = ACTIONS(4063),
    [anon_sym_SEMI] = ACTIONS(4058),
    [anon_sym___extension__] = ACTIONS(1961),
    [anon_sym_COLON_COLON] = ACTIONS(1961),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4058),
    [anon_sym_LBRACE] = ACTIONS(1961),
    [anon_sym_LBRACK] = ACTIONS(4065),
    [anon_sym_EQ] = ACTIONS(4063),
    [anon_sym_const] = ACTIONS(1959),
    [anon_sym_constexpr] = ACTIONS(1961),
    [anon_sym_volatile] = ACTIONS(1961),
    [anon_sym_restrict] = ACTIONS(1961),
    [anon_sym___restrict__] = ACTIONS(1961),
    [anon_sym__Atomic] = ACTIONS(1961),
    [anon_sym__Noreturn] = ACTIONS(1961),
    [anon_sym_noreturn] = ACTIONS(1961),
    [anon_sym_mutable] = ACTIONS(1961),
    [anon_sym_constinit] = ACTIONS(1961),
    [anon_sym_consteval] = ACTIONS(1961),
    [anon_sym_alignas] = ACTIONS(1961),
    [anon_sym__Alignas] = ACTIONS(1961),
    [anon_sym_QMARK] = ACTIONS(4058),
    [anon_sym_STAR_EQ] = ACTIONS(4058),
    [anon_sym_SLASH_EQ] = ACTIONS(4058),
    [anon_sym_PERCENT_EQ] = ACTIONS(4058),
    [anon_sym_PLUS_EQ] = ACTIONS(4058),
    [anon_sym_DASH_EQ] = ACTIONS(4058),
    [anon_sym_LT_LT_EQ] = ACTIONS(4058),
    [anon_sym_GT_GT_EQ] = ACTIONS(4058),
    [anon_sym_AMP_EQ] = ACTIONS(4058),
    [anon_sym_CARET_EQ] = ACTIONS(4058),
    [anon_sym_PIPE_EQ] = ACTIONS(4058),
    [anon_sym_and_eq] = ACTIONS(4058),
    [anon_sym_or_eq] = ACTIONS(4058),
    [anon_sym_xor_eq] = ACTIONS(4058),
    [anon_sym_LT_EQ_GT] = ACTIONS(4058),
    [anon_sym_or] = ACTIONS(4063),
    [anon_sym_and] = ACTIONS(4063),
    [anon_sym_bitor] = ACTIONS(4058),
    [anon_sym_xor] = ACTIONS(4063),
    [anon_sym_bitand] = ACTIONS(4058),
    [anon_sym_not_eq] = ACTIONS(4058),
    [anon_sym_DASH_DASH] = ACTIONS(4058),
    [anon_sym_PLUS_PLUS] = ACTIONS(4058),
    [anon_sym_DOT] = ACTIONS(4063),
    [anon_sym_DOT_STAR] = ACTIONS(4058),
    [anon_sym_DASH_GT] = ACTIONS(4063),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1961),
    [anon_sym_decltype] = ACTIONS(1961),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4058),
  },
  [2405] = {
    [sym_identifier] = ACTIONS(1953),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1955),
    [anon_sym_COMMA] = ACTIONS(1955),
    [anon_sym_RPAREN] = ACTIONS(1955),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_DASH] = ACTIONS(1953),
    [anon_sym_PLUS] = ACTIONS(1953),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_SLASH] = ACTIONS(1953),
    [anon_sym_PERCENT] = ACTIONS(1955),
    [anon_sym_PIPE_PIPE] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_PIPE] = ACTIONS(1953),
    [anon_sym_CARET] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym_EQ_EQ] = ACTIONS(1955),
    [anon_sym_BANG_EQ] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1953),
    [anon_sym_GT_EQ] = ACTIONS(1955),
    [anon_sym_LT_EQ] = ACTIONS(1953),
    [anon_sym_LT] = ACTIONS(1953),
    [anon_sym_LT_LT] = ACTIONS(1955),
    [anon_sym_GT_GT] = ACTIONS(1955),
    [anon_sym_COLON] = ACTIONS(1955),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym___based] = ACTIONS(1953),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_RBRACE] = ACTIONS(1955),
    [anon_sym_signed] = ACTIONS(1953),
    [anon_sym_unsigned] = ACTIONS(1953),
    [anon_sym_long] = ACTIONS(1953),
    [anon_sym_short] = ACTIONS(1953),
    [anon_sym_LBRACK] = ACTIONS(1955),
    [anon_sym_RBRACK] = ACTIONS(1955),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [sym_primitive_type] = ACTIONS(1953),
    [anon_sym_else] = ACTIONS(1953),
    [anon_sym_while] = ACTIONS(1953),
    [anon_sym_QMARK] = ACTIONS(1955),
    [anon_sym_LT_EQ_GT] = ACTIONS(1955),
    [anon_sym_or] = ACTIONS(1953),
    [anon_sym_and] = ACTIONS(1953),
    [anon_sym_bitor] = ACTIONS(1953),
    [anon_sym_xor] = ACTIONS(1953),
    [anon_sym_bitand] = ACTIONS(1953),
    [anon_sym_not_eq] = ACTIONS(1953),
    [anon_sym_DASH_DASH] = ACTIONS(1955),
    [anon_sym_PLUS_PLUS] = ACTIONS(1955),
    [anon_sym_DOT] = ACTIONS(1953),
    [anon_sym_DOT_STAR] = ACTIONS(1955),
    [anon_sym_DASH_GT] = ACTIONS(1955),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
    [anon_sym_requires] = ACTIONS(1953),
  },
  [2406] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(3821),
    [sym_raw_string_literal] = STATE(2868),
    [sym_identifier] = ACTIONS(3832),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [aux_sym_preproc_if_token2] = ACTIONS(3824),
    [aux_sym_preproc_else_token1] = ACTIONS(3824),
    [aux_sym_preproc_elif_token1] = ACTIONS(3832),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(3824),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3824),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5800),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_LBRACK] = ACTIONS(3824),
    [anon_sym_EQ] = ACTIONS(5803),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(5805),
    [anon_sym_SLASH_EQ] = ACTIONS(5805),
    [anon_sym_PERCENT_EQ] = ACTIONS(5805),
    [anon_sym_PLUS_EQ] = ACTIONS(5805),
    [anon_sym_DASH_EQ] = ACTIONS(5805),
    [anon_sym_LT_LT_EQ] = ACTIONS(5805),
    [anon_sym_GT_GT_EQ] = ACTIONS(5805),
    [anon_sym_AMP_EQ] = ACTIONS(5805),
    [anon_sym_CARET_EQ] = ACTIONS(5805),
    [anon_sym_PIPE_EQ] = ACTIONS(5805),
    [anon_sym_and_eq] = ACTIONS(5803),
    [anon_sym_or_eq] = ACTIONS(5803),
    [anon_sym_xor_eq] = ACTIONS(5803),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3832),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3832),
    [anon_sym_not_eq] = ACTIONS(3832),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
  },
  [2407] = {
    [sym_identifier] = ACTIONS(5357),
    [anon_sym___extension__] = ACTIONS(5357),
    [anon_sym_in] = ACTIONS(5357),
    [anon_sym_out] = ACTIONS(5357),
    [anon_sym_inout] = ACTIONS(5357),
    [anon_sym_extern] = ACTIONS(5357),
    [anon_sym___attribute__] = ACTIONS(5357),
    [anon_sym_COLON_COLON] = ACTIONS(5363),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5363),
    [anon_sym___declspec] = ACTIONS(5357),
    [anon_sym___cdecl] = ACTIONS(5357),
    [anon_sym___clrcall] = ACTIONS(5357),
    [anon_sym___stdcall] = ACTIONS(5357),
    [anon_sym___fastcall] = ACTIONS(5357),
    [anon_sym___thiscall] = ACTIONS(5357),
    [anon_sym___vectorcall] = ACTIONS(5357),
    [anon_sym_signed] = ACTIONS(5357),
    [anon_sym_unsigned] = ACTIONS(5357),
    [anon_sym_long] = ACTIONS(5357),
    [anon_sym_short] = ACTIONS(5357),
    [anon_sym_static] = ACTIONS(5357),
    [anon_sym_register] = ACTIONS(5357),
    [anon_sym_inline] = ACTIONS(5357),
    [anon_sym___inline] = ACTIONS(5357),
    [anon_sym___inline__] = ACTIONS(5357),
    [anon_sym___forceinline] = ACTIONS(5357),
    [anon_sym_thread_local] = ACTIONS(5357),
    [anon_sym___thread] = ACTIONS(5357),
    [anon_sym_const] = ACTIONS(5357),
    [anon_sym_constexpr] = ACTIONS(5357),
    [anon_sym_volatile] = ACTIONS(5357),
    [anon_sym_restrict] = ACTIONS(5357),
    [anon_sym___restrict__] = ACTIONS(5357),
    [anon_sym__Atomic] = ACTIONS(5357),
    [anon_sym__Noreturn] = ACTIONS(5357),
    [anon_sym_noreturn] = ACTIONS(5357),
    [anon_sym_mutable] = ACTIONS(5357),
    [anon_sym_constinit] = ACTIONS(5357),
    [anon_sym_consteval] = ACTIONS(5357),
    [anon_sym_alignas] = ACTIONS(5357),
    [anon_sym__Alignas] = ACTIONS(5357),
    [sym_primitive_type] = ACTIONS(5357),
    [anon_sym_enum] = ACTIONS(5357),
    [anon_sym_class] = ACTIONS(5357),
    [anon_sym_struct] = ACTIONS(5357),
    [anon_sym_union] = ACTIONS(5357),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5357),
    [anon_sym_decltype] = ACTIONS(5357),
    [sym_virtual] = ACTIONS(5357),
    [anon_sym_typename] = ACTIONS(5357),
    [anon_sym_template] = ACTIONS(5357),
    [anon_sym_precise] = ACTIONS(5357),
    [anon_sym_shared] = ACTIONS(5357),
    [anon_sym_groupshared] = ACTIONS(5357),
    [anon_sym_uniform] = ACTIONS(5357),
    [anon_sym_row_major] = ACTIONS(5357),
    [anon_sym_column_major] = ACTIONS(5357),
    [anon_sym_globallycoherent] = ACTIONS(5357),
    [anon_sym_centroid] = ACTIONS(5357),
    [anon_sym_noperspective] = ACTIONS(5357),
    [anon_sym_nointerpolation] = ACTIONS(5357),
    [anon_sym_sample] = ACTIONS(5357),
    [anon_sym_linear] = ACTIONS(5357),
    [anon_sym_snorm] = ACTIONS(5357),
    [anon_sym_unorm] = ACTIONS(5357),
    [anon_sym_point] = ACTIONS(5357),
    [anon_sym_line] = ACTIONS(5357),
    [anon_sym_triangleadj] = ACTIONS(5357),
    [anon_sym_lineadj] = ACTIONS(5357),
    [anon_sym_triangle] = ACTIONS(5357),
  },
  [2408] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2408),
    [sym_identifier] = ACTIONS(5224),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5226),
    [anon_sym_COMMA] = ACTIONS(5226),
    [anon_sym_RPAREN] = ACTIONS(5226),
    [aux_sym_preproc_if_token2] = ACTIONS(5226),
    [aux_sym_preproc_else_token1] = ACTIONS(5226),
    [aux_sym_preproc_elif_token1] = ACTIONS(5224),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5226),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5226),
    [anon_sym_LPAREN2] = ACTIONS(5226),
    [anon_sym_DASH] = ACTIONS(5224),
    [anon_sym_PLUS] = ACTIONS(5224),
    [anon_sym_STAR] = ACTIONS(5224),
    [anon_sym_SLASH] = ACTIONS(5224),
    [anon_sym_PERCENT] = ACTIONS(5224),
    [anon_sym_PIPE_PIPE] = ACTIONS(5226),
    [anon_sym_AMP_AMP] = ACTIONS(5226),
    [anon_sym_PIPE] = ACTIONS(5224),
    [anon_sym_CARET] = ACTIONS(5224),
    [anon_sym_AMP] = ACTIONS(5224),
    [anon_sym_EQ_EQ] = ACTIONS(5226),
    [anon_sym_BANG_EQ] = ACTIONS(5226),
    [anon_sym_GT] = ACTIONS(5224),
    [anon_sym_GT_EQ] = ACTIONS(5226),
    [anon_sym_LT_EQ] = ACTIONS(5224),
    [anon_sym_LT] = ACTIONS(5224),
    [anon_sym_LT_LT] = ACTIONS(5224),
    [anon_sym_GT_GT] = ACTIONS(5224),
    [anon_sym_COLON] = ACTIONS(5226),
    [anon_sym_SEMI] = ACTIONS(5226),
    [anon_sym___attribute__] = ACTIONS(5224),
    [anon_sym_LBRACE] = ACTIONS(5226),
    [anon_sym_RBRACE] = ACTIONS(5226),
    [anon_sym_signed] = ACTIONS(5807),
    [anon_sym_unsigned] = ACTIONS(5807),
    [anon_sym_long] = ACTIONS(5807),
    [anon_sym_short] = ACTIONS(5807),
    [anon_sym_LBRACK] = ACTIONS(5226),
    [anon_sym_RBRACK] = ACTIONS(5226),
    [anon_sym_EQ] = ACTIONS(5224),
    [sym_primitive_type] = ACTIONS(5224),
    [anon_sym_QMARK] = ACTIONS(5226),
    [anon_sym_STAR_EQ] = ACTIONS(5226),
    [anon_sym_SLASH_EQ] = ACTIONS(5226),
    [anon_sym_PERCENT_EQ] = ACTIONS(5226),
    [anon_sym_PLUS_EQ] = ACTIONS(5226),
    [anon_sym_DASH_EQ] = ACTIONS(5226),
    [anon_sym_LT_LT_EQ] = ACTIONS(5226),
    [anon_sym_GT_GT_EQ] = ACTIONS(5226),
    [anon_sym_AMP_EQ] = ACTIONS(5226),
    [anon_sym_CARET_EQ] = ACTIONS(5226),
    [anon_sym_PIPE_EQ] = ACTIONS(5226),
    [anon_sym_and_eq] = ACTIONS(5224),
    [anon_sym_or_eq] = ACTIONS(5224),
    [anon_sym_xor_eq] = ACTIONS(5224),
    [anon_sym_LT_EQ_GT] = ACTIONS(5226),
    [anon_sym_or] = ACTIONS(5224),
    [anon_sym_and] = ACTIONS(5224),
    [anon_sym_bitor] = ACTIONS(5224),
    [anon_sym_xor] = ACTIONS(5224),
    [anon_sym_bitand] = ACTIONS(5224),
    [anon_sym_not_eq] = ACTIONS(5224),
    [anon_sym_DASH_DASH] = ACTIONS(5226),
    [anon_sym_PLUS_PLUS] = ACTIONS(5226),
    [anon_sym_DOT] = ACTIONS(5224),
    [anon_sym_DOT_STAR] = ACTIONS(5226),
    [anon_sym_DASH_GT] = ACTIONS(5226),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5224),
    [anon_sym_decltype] = ACTIONS(5224),
  },
  [2409] = {
    [sym_template_argument_list] = STATE(2441),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2233),
    [sym_identifier] = ACTIONS(3822),
    [anon_sym_LPAREN2] = ACTIONS(3845),
    [anon_sym_TILDE] = ACTIONS(3830),
    [anon_sym_STAR] = ACTIONS(3830),
    [anon_sym_AMP_AMP] = ACTIONS(3830),
    [anon_sym_AMP] = ACTIONS(3822),
    [anon_sym_LT] = ACTIONS(5298),
    [anon_sym_SEMI] = ACTIONS(5188),
    [anon_sym___extension__] = ACTIONS(3822),
    [anon_sym_in] = ACTIONS(3822),
    [anon_sym_out] = ACTIONS(3822),
    [anon_sym_inout] = ACTIONS(3822),
    [anon_sym_extern] = ACTIONS(3822),
    [anon_sym___attribute__] = ACTIONS(3822),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3845),
    [anon_sym___declspec] = ACTIONS(3822),
    [anon_sym___based] = ACTIONS(3822),
    [anon_sym_signed] = ACTIONS(3848),
    [anon_sym_unsigned] = ACTIONS(3848),
    [anon_sym_long] = ACTIONS(3848),
    [anon_sym_short] = ACTIONS(3848),
    [anon_sym_LBRACK] = ACTIONS(5603),
    [anon_sym_static] = ACTIONS(3822),
    [anon_sym_register] = ACTIONS(3822),
    [anon_sym_inline] = ACTIONS(3822),
    [anon_sym___inline] = ACTIONS(3822),
    [anon_sym___inline__] = ACTIONS(3822),
    [anon_sym___forceinline] = ACTIONS(3822),
    [anon_sym_thread_local] = ACTIONS(3822),
    [anon_sym___thread] = ACTIONS(3822),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3822),
    [anon_sym_volatile] = ACTIONS(3822),
    [anon_sym_restrict] = ACTIONS(3822),
    [anon_sym___restrict__] = ACTIONS(3822),
    [anon_sym__Atomic] = ACTIONS(3822),
    [anon_sym__Noreturn] = ACTIONS(3822),
    [anon_sym_noreturn] = ACTIONS(3822),
    [anon_sym_mutable] = ACTIONS(3822),
    [anon_sym_constinit] = ACTIONS(3822),
    [anon_sym_consteval] = ACTIONS(3822),
    [anon_sym_alignas] = ACTIONS(3822),
    [anon_sym__Alignas] = ACTIONS(3822),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3822),
    [anon_sym_decltype] = ACTIONS(3822),
    [sym_virtual] = ACTIONS(3822),
    [anon_sym_template] = ACTIONS(3822),
    [anon_sym_operator] = ACTIONS(3822),
    [anon_sym_precise] = ACTIONS(3822),
    [anon_sym_shared] = ACTIONS(3822),
    [anon_sym_groupshared] = ACTIONS(3822),
    [anon_sym_uniform] = ACTIONS(3822),
    [anon_sym_row_major] = ACTIONS(3822),
    [anon_sym_column_major] = ACTIONS(3822),
    [anon_sym_globallycoherent] = ACTIONS(3822),
    [anon_sym_centroid] = ACTIONS(3822),
    [anon_sym_noperspective] = ACTIONS(3822),
    [anon_sym_nointerpolation] = ACTIONS(3822),
    [anon_sym_sample] = ACTIONS(3822),
    [anon_sym_linear] = ACTIONS(3822),
    [anon_sym_snorm] = ACTIONS(3822),
    [anon_sym_unorm] = ACTIONS(3822),
    [anon_sym_point] = ACTIONS(3822),
    [anon_sym_line] = ACTIONS(3822),
    [anon_sym_triangleadj] = ACTIONS(3822),
    [anon_sym_lineadj] = ACTIONS(3822),
    [anon_sym_triangle] = ACTIONS(3822),
  },
  [2410] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2197),
    [sym_identifier] = ACTIONS(5224),
    [anon_sym_COMMA] = ACTIONS(5315),
    [anon_sym_RPAREN] = ACTIONS(5315),
    [anon_sym_LPAREN2] = ACTIONS(5315),
    [anon_sym_STAR] = ACTIONS(5315),
    [anon_sym_AMP_AMP] = ACTIONS(5315),
    [anon_sym_AMP] = ACTIONS(5312),
    [anon_sym___extension__] = ACTIONS(5312),
    [anon_sym_in] = ACTIONS(5312),
    [anon_sym_out] = ACTIONS(5312),
    [anon_sym_inout] = ACTIONS(5312),
    [anon_sym_extern] = ACTIONS(5312),
    [anon_sym___attribute__] = ACTIONS(5312),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5315),
    [anon_sym___declspec] = ACTIONS(5312),
    [anon_sym_LBRACE] = ACTIONS(5315),
    [anon_sym_signed] = ACTIONS(5228),
    [anon_sym_unsigned] = ACTIONS(5228),
    [anon_sym_long] = ACTIONS(5228),
    [anon_sym_short] = ACTIONS(5228),
    [anon_sym_LBRACK] = ACTIONS(5312),
    [anon_sym_static] = ACTIONS(5312),
    [anon_sym_register] = ACTIONS(5312),
    [anon_sym_inline] = ACTIONS(5312),
    [anon_sym___inline] = ACTIONS(5312),
    [anon_sym___inline__] = ACTIONS(5312),
    [anon_sym___forceinline] = ACTIONS(5312),
    [anon_sym_thread_local] = ACTIONS(5312),
    [anon_sym___thread] = ACTIONS(5312),
    [anon_sym_const] = ACTIONS(5312),
    [anon_sym_constexpr] = ACTIONS(5312),
    [anon_sym_volatile] = ACTIONS(5312),
    [anon_sym_restrict] = ACTIONS(5312),
    [anon_sym___restrict__] = ACTIONS(5312),
    [anon_sym__Atomic] = ACTIONS(5312),
    [anon_sym__Noreturn] = ACTIONS(5312),
    [anon_sym_noreturn] = ACTIONS(5312),
    [anon_sym_mutable] = ACTIONS(5312),
    [anon_sym_constinit] = ACTIONS(5312),
    [anon_sym_consteval] = ACTIONS(5312),
    [anon_sym_alignas] = ACTIONS(5312),
    [anon_sym__Alignas] = ACTIONS(5312),
    [sym_primitive_type] = ACTIONS(5224),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5312),
    [anon_sym_decltype] = ACTIONS(5312),
    [anon_sym_final] = ACTIONS(5312),
    [anon_sym_override] = ACTIONS(5312),
    [sym_virtual] = ACTIONS(5312),
    [anon_sym_GT2] = ACTIONS(5315),
    [anon_sym_requires] = ACTIONS(5312),
    [anon_sym_precise] = ACTIONS(5312),
    [anon_sym_shared] = ACTIONS(5312),
    [anon_sym_groupshared] = ACTIONS(5312),
    [anon_sym_uniform] = ACTIONS(5312),
    [anon_sym_row_major] = ACTIONS(5312),
    [anon_sym_column_major] = ACTIONS(5312),
    [anon_sym_globallycoherent] = ACTIONS(5312),
    [anon_sym_centroid] = ACTIONS(5312),
    [anon_sym_noperspective] = ACTIONS(5312),
    [anon_sym_nointerpolation] = ACTIONS(5312),
    [anon_sym_sample] = ACTIONS(5312),
    [anon_sym_linear] = ACTIONS(5312),
    [anon_sym_snorm] = ACTIONS(5312),
    [anon_sym_unorm] = ACTIONS(5312),
    [anon_sym_point] = ACTIONS(5312),
    [anon_sym_line] = ACTIONS(5312),
    [anon_sym_triangleadj] = ACTIONS(5312),
    [anon_sym_lineadj] = ACTIONS(5312),
    [anon_sym_triangle] = ACTIONS(5312),
  },
  [2411] = {
    [sym_template_argument_list] = STATE(2415),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4045),
    [anon_sym_COMMA] = ACTIONS(4045),
    [anon_sym_RPAREN] = ACTIONS(4047),
    [anon_sym_LPAREN2] = ACTIONS(4047),
    [anon_sym_DASH] = ACTIONS(4050),
    [anon_sym_PLUS] = ACTIONS(4050),
    [anon_sym_STAR] = ACTIONS(4052),
    [anon_sym_SLASH] = ACTIONS(4050),
    [anon_sym_PERCENT] = ACTIONS(4050),
    [anon_sym_PIPE_PIPE] = ACTIONS(4045),
    [anon_sym_AMP_AMP] = ACTIONS(4047),
    [anon_sym_PIPE] = ACTIONS(4050),
    [anon_sym_CARET] = ACTIONS(4050),
    [anon_sym_AMP] = ACTIONS(4052),
    [anon_sym_EQ_EQ] = ACTIONS(4045),
    [anon_sym_BANG_EQ] = ACTIONS(4045),
    [anon_sym_GT] = ACTIONS(4050),
    [anon_sym_GT_EQ] = ACTIONS(4045),
    [anon_sym_LT_EQ] = ACTIONS(4050),
    [anon_sym_LT] = ACTIONS(5810),
    [anon_sym_LT_LT] = ACTIONS(4050),
    [anon_sym_GT_GT] = ACTIONS(4050),
    [anon_sym___extension__] = ACTIONS(1935),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1935),
    [anon_sym_LBRACK] = ACTIONS(4047),
    [anon_sym_EQ] = ACTIONS(4050),
    [anon_sym_const] = ACTIONS(1933),
    [anon_sym_constexpr] = ACTIONS(1935),
    [anon_sym_volatile] = ACTIONS(1935),
    [anon_sym_restrict] = ACTIONS(1935),
    [anon_sym___restrict__] = ACTIONS(1935),
    [anon_sym__Atomic] = ACTIONS(1935),
    [anon_sym__Noreturn] = ACTIONS(1935),
    [anon_sym_noreturn] = ACTIONS(1935),
    [anon_sym_mutable] = ACTIONS(1935),
    [anon_sym_constinit] = ACTIONS(1935),
    [anon_sym_consteval] = ACTIONS(1935),
    [anon_sym_alignas] = ACTIONS(1935),
    [anon_sym__Alignas] = ACTIONS(1935),
    [anon_sym_QMARK] = ACTIONS(4045),
    [anon_sym_STAR_EQ] = ACTIONS(4045),
    [anon_sym_SLASH_EQ] = ACTIONS(4045),
    [anon_sym_PERCENT_EQ] = ACTIONS(4045),
    [anon_sym_PLUS_EQ] = ACTIONS(4045),
    [anon_sym_DASH_EQ] = ACTIONS(4045),
    [anon_sym_LT_LT_EQ] = ACTIONS(4045),
    [anon_sym_GT_GT_EQ] = ACTIONS(4045),
    [anon_sym_AMP_EQ] = ACTIONS(4045),
    [anon_sym_CARET_EQ] = ACTIONS(4045),
    [anon_sym_PIPE_EQ] = ACTIONS(4045),
    [anon_sym_and_eq] = ACTIONS(4045),
    [anon_sym_or_eq] = ACTIONS(4045),
    [anon_sym_xor_eq] = ACTIONS(4045),
    [anon_sym_LT_EQ_GT] = ACTIONS(4045),
    [anon_sym_or] = ACTIONS(4050),
    [anon_sym_and] = ACTIONS(4050),
    [anon_sym_bitor] = ACTIONS(4045),
    [anon_sym_xor] = ACTIONS(4050),
    [anon_sym_bitand] = ACTIONS(4045),
    [anon_sym_not_eq] = ACTIONS(4045),
    [anon_sym_DASH_DASH] = ACTIONS(4045),
    [anon_sym_PLUS_PLUS] = ACTIONS(4045),
    [anon_sym_DOT] = ACTIONS(4050),
    [anon_sym_DOT_STAR] = ACTIONS(4045),
    [anon_sym_DASH_GT] = ACTIONS(4050),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1935),
    [anon_sym_decltype] = ACTIONS(1935),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4045),
  },
  [2412] = {
    [sym_attribute_specifier] = STATE(2594),
    [sym_field_declaration_list] = STATE(2579),
    [sym_virtual_specifier] = STATE(6947),
    [sym_base_class_clause] = STATE(7751),
    [sym_identifier] = ACTIONS(5327),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5329),
    [anon_sym_COMMA] = ACTIONS(5329),
    [anon_sym_RPAREN] = ACTIONS(5329),
    [aux_sym_preproc_if_token2] = ACTIONS(5329),
    [aux_sym_preproc_else_token1] = ACTIONS(5329),
    [aux_sym_preproc_elif_token1] = ACTIONS(5327),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5329),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5329),
    [anon_sym_LPAREN2] = ACTIONS(5329),
    [anon_sym_DASH] = ACTIONS(5327),
    [anon_sym_PLUS] = ACTIONS(5327),
    [anon_sym_STAR] = ACTIONS(5327),
    [anon_sym_SLASH] = ACTIONS(5327),
    [anon_sym_PERCENT] = ACTIONS(5327),
    [anon_sym_PIPE_PIPE] = ACTIONS(5329),
    [anon_sym_AMP_AMP] = ACTIONS(5329),
    [anon_sym_PIPE] = ACTIONS(5327),
    [anon_sym_CARET] = ACTIONS(5327),
    [anon_sym_AMP] = ACTIONS(5327),
    [anon_sym_EQ_EQ] = ACTIONS(5329),
    [anon_sym_BANG_EQ] = ACTIONS(5329),
    [anon_sym_GT] = ACTIONS(5327),
    [anon_sym_GT_EQ] = ACTIONS(5329),
    [anon_sym_LT_EQ] = ACTIONS(5327),
    [anon_sym_LT] = ACTIONS(5327),
    [anon_sym_LT_LT] = ACTIONS(5327),
    [anon_sym_GT_GT] = ACTIONS(5327),
    [anon_sym_COLON] = ACTIONS(5813),
    [anon_sym_SEMI] = ACTIONS(5329),
    [anon_sym___attribute__] = ACTIONS(5815),
    [anon_sym_LBRACE] = ACTIONS(5817),
    [anon_sym_RBRACE] = ACTIONS(5329),
    [anon_sym_LBRACK] = ACTIONS(5329),
    [anon_sym_RBRACK] = ACTIONS(5329),
    [anon_sym_EQ] = ACTIONS(5327),
    [anon_sym_QMARK] = ACTIONS(5329),
    [anon_sym_STAR_EQ] = ACTIONS(5329),
    [anon_sym_SLASH_EQ] = ACTIONS(5329),
    [anon_sym_PERCENT_EQ] = ACTIONS(5329),
    [anon_sym_PLUS_EQ] = ACTIONS(5329),
    [anon_sym_DASH_EQ] = ACTIONS(5329),
    [anon_sym_LT_LT_EQ] = ACTIONS(5329),
    [anon_sym_GT_GT_EQ] = ACTIONS(5329),
    [anon_sym_AMP_EQ] = ACTIONS(5329),
    [anon_sym_CARET_EQ] = ACTIONS(5329),
    [anon_sym_PIPE_EQ] = ACTIONS(5329),
    [anon_sym_and_eq] = ACTIONS(5327),
    [anon_sym_or_eq] = ACTIONS(5327),
    [anon_sym_xor_eq] = ACTIONS(5327),
    [anon_sym_LT_EQ_GT] = ACTIONS(5329),
    [anon_sym_or] = ACTIONS(5327),
    [anon_sym_and] = ACTIONS(5327),
    [anon_sym_bitor] = ACTIONS(5327),
    [anon_sym_xor] = ACTIONS(5327),
    [anon_sym_bitand] = ACTIONS(5327),
    [anon_sym_not_eq] = ACTIONS(5327),
    [anon_sym_DASH_DASH] = ACTIONS(5329),
    [anon_sym_PLUS_PLUS] = ACTIONS(5329),
    [anon_sym_DOT] = ACTIONS(5327),
    [anon_sym_DOT_STAR] = ACTIONS(5329),
    [anon_sym_DASH_GT] = ACTIONS(5329),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5327),
    [anon_sym_decltype] = ACTIONS(5327),
    [anon_sym_final] = ACTIONS(1915),
    [anon_sym_override] = ACTIONS(1915),
  },
  [2413] = {
    [sym_template_argument_list] = STATE(2441),
    [sym_identifier] = ACTIONS(1933),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1935),
    [anon_sym_COMMA] = ACTIONS(1935),
    [anon_sym_RPAREN] = ACTIONS(4047),
    [anon_sym_LPAREN2] = ACTIONS(4047),
    [anon_sym_TILDE] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1935),
    [anon_sym_AMP_AMP] = ACTIONS(1935),
    [anon_sym_AMP] = ACTIONS(1933),
    [anon_sym_LT] = ACTIONS(5628),
    [anon_sym_COLON] = ACTIONS(1933),
    [anon_sym___extension__] = ACTIONS(1933),
    [anon_sym_in] = ACTIONS(1933),
    [anon_sym_out] = ACTIONS(1933),
    [anon_sym_inout] = ACTIONS(1933),
    [anon_sym_extern] = ACTIONS(1933),
    [anon_sym___attribute__] = ACTIONS(1933),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4047),
    [anon_sym___declspec] = ACTIONS(1933),
    [anon_sym___based] = ACTIONS(1933),
    [anon_sym_LBRACK] = ACTIONS(4052),
    [anon_sym_static] = ACTIONS(1933),
    [anon_sym_EQ] = ACTIONS(1935),
    [anon_sym_register] = ACTIONS(1933),
    [anon_sym_inline] = ACTIONS(1933),
    [anon_sym___inline] = ACTIONS(1933),
    [anon_sym___inline__] = ACTIONS(1933),
    [anon_sym___forceinline] = ACTIONS(1933),
    [anon_sym_thread_local] = ACTIONS(1933),
    [anon_sym___thread] = ACTIONS(1933),
    [anon_sym_const] = ACTIONS(1933),
    [anon_sym_constexpr] = ACTIONS(1933),
    [anon_sym_volatile] = ACTIONS(1933),
    [anon_sym_restrict] = ACTIONS(1933),
    [anon_sym___restrict__] = ACTIONS(1933),
    [anon_sym__Atomic] = ACTIONS(1933),
    [anon_sym__Noreturn] = ACTIONS(1933),
    [anon_sym_noreturn] = ACTIONS(1933),
    [anon_sym_mutable] = ACTIONS(1933),
    [anon_sym_constinit] = ACTIONS(1933),
    [anon_sym_consteval] = ACTIONS(1933),
    [anon_sym_alignas] = ACTIONS(1933),
    [anon_sym__Alignas] = ACTIONS(1933),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1933),
    [anon_sym_decltype] = ACTIONS(1933),
    [sym_virtual] = ACTIONS(1933),
    [anon_sym_template] = ACTIONS(1933),
    [anon_sym_operator] = ACTIONS(1933),
    [anon_sym_precise] = ACTIONS(1933),
    [anon_sym_shared] = ACTIONS(1933),
    [anon_sym_groupshared] = ACTIONS(1933),
    [anon_sym_uniform] = ACTIONS(1933),
    [anon_sym_row_major] = ACTIONS(1933),
    [anon_sym_column_major] = ACTIONS(1933),
    [anon_sym_globallycoherent] = ACTIONS(1933),
    [anon_sym_centroid] = ACTIONS(1933),
    [anon_sym_noperspective] = ACTIONS(1933),
    [anon_sym_nointerpolation] = ACTIONS(1933),
    [anon_sym_sample] = ACTIONS(1933),
    [anon_sym_linear] = ACTIONS(1933),
    [anon_sym_snorm] = ACTIONS(1933),
    [anon_sym_unorm] = ACTIONS(1933),
    [anon_sym_point] = ACTIONS(1933),
    [anon_sym_line] = ACTIONS(1933),
    [anon_sym_triangleadj] = ACTIONS(1933),
    [anon_sym_lineadj] = ACTIONS(1933),
    [anon_sym_triangle] = ACTIONS(1933),
  },
  [2414] = {
    [sym_identifier] = ACTIONS(1925),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1927),
    [anon_sym_COMMA] = ACTIONS(1927),
    [anon_sym_RPAREN] = ACTIONS(1927),
    [anon_sym_LPAREN2] = ACTIONS(1927),
    [anon_sym_DASH] = ACTIONS(1925),
    [anon_sym_PLUS] = ACTIONS(1925),
    [anon_sym_STAR] = ACTIONS(1927),
    [anon_sym_SLASH] = ACTIONS(1925),
    [anon_sym_PERCENT] = ACTIONS(1927),
    [anon_sym_PIPE_PIPE] = ACTIONS(1927),
    [anon_sym_AMP_AMP] = ACTIONS(1927),
    [anon_sym_PIPE] = ACTIONS(1925),
    [anon_sym_CARET] = ACTIONS(1927),
    [anon_sym_AMP] = ACTIONS(1925),
    [anon_sym_EQ_EQ] = ACTIONS(1927),
    [anon_sym_BANG_EQ] = ACTIONS(1927),
    [anon_sym_GT] = ACTIONS(1925),
    [anon_sym_GT_EQ] = ACTIONS(1927),
    [anon_sym_LT_EQ] = ACTIONS(1925),
    [anon_sym_LT] = ACTIONS(1925),
    [anon_sym_LT_LT] = ACTIONS(1927),
    [anon_sym_GT_GT] = ACTIONS(1927),
    [anon_sym_COLON] = ACTIONS(1925),
    [anon_sym_SEMI] = ACTIONS(1927),
    [anon_sym___extension__] = ACTIONS(1925),
    [anon_sym___attribute__] = ACTIONS(1925),
    [anon_sym_COLON_COLON] = ACTIONS(1927),
    [anon_sym___based] = ACTIONS(1925),
    [anon_sym_LBRACE] = ACTIONS(1927),
    [anon_sym_RBRACE] = ACTIONS(1927),
    [anon_sym_signed] = ACTIONS(1925),
    [anon_sym_unsigned] = ACTIONS(1925),
    [anon_sym_long] = ACTIONS(1925),
    [anon_sym_short] = ACTIONS(1925),
    [anon_sym_LBRACK] = ACTIONS(1927),
    [anon_sym_RBRACK] = ACTIONS(1927),
    [anon_sym_const] = ACTIONS(1925),
    [anon_sym_constexpr] = ACTIONS(1925),
    [anon_sym_volatile] = ACTIONS(1925),
    [anon_sym_restrict] = ACTIONS(1925),
    [anon_sym___restrict__] = ACTIONS(1925),
    [anon_sym__Atomic] = ACTIONS(1925),
    [anon_sym__Noreturn] = ACTIONS(1925),
    [anon_sym_noreturn] = ACTIONS(1925),
    [anon_sym_mutable] = ACTIONS(1925),
    [anon_sym_constinit] = ACTIONS(1925),
    [anon_sym_consteval] = ACTIONS(1925),
    [anon_sym_alignas] = ACTIONS(1925),
    [anon_sym__Alignas] = ACTIONS(1925),
    [sym_primitive_type] = ACTIONS(1925),
    [anon_sym_QMARK] = ACTIONS(1927),
    [anon_sym_LT_EQ_GT] = ACTIONS(1927),
    [anon_sym_or] = ACTIONS(1925),
    [anon_sym_and] = ACTIONS(1925),
    [anon_sym_bitor] = ACTIONS(1925),
    [anon_sym_xor] = ACTIONS(1925),
    [anon_sym_bitand] = ACTIONS(1925),
    [anon_sym_not_eq] = ACTIONS(1925),
    [anon_sym_DASH_DASH] = ACTIONS(1927),
    [anon_sym_PLUS_PLUS] = ACTIONS(1927),
    [anon_sym_DOT] = ACTIONS(1925),
    [anon_sym_DOT_STAR] = ACTIONS(1927),
    [anon_sym_DASH_GT] = ACTIONS(1927),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1925),
    [anon_sym_decltype] = ACTIONS(1925),
    [anon_sym_final] = ACTIONS(1925),
    [anon_sym_override] = ACTIONS(1925),
    [anon_sym_requires] = ACTIONS(1925),
  },
  [2415] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4058),
    [anon_sym_COMMA] = ACTIONS(4058),
    [anon_sym_RPAREN] = ACTIONS(4060),
    [anon_sym_LPAREN2] = ACTIONS(4060),
    [anon_sym_DASH] = ACTIONS(4063),
    [anon_sym_PLUS] = ACTIONS(4063),
    [anon_sym_STAR] = ACTIONS(4065),
    [anon_sym_SLASH] = ACTIONS(4063),
    [anon_sym_PERCENT] = ACTIONS(4063),
    [anon_sym_PIPE_PIPE] = ACTIONS(4058),
    [anon_sym_AMP_AMP] = ACTIONS(4060),
    [anon_sym_PIPE] = ACTIONS(4063),
    [anon_sym_CARET] = ACTIONS(4063),
    [anon_sym_AMP] = ACTIONS(4065),
    [anon_sym_EQ_EQ] = ACTIONS(4058),
    [anon_sym_BANG_EQ] = ACTIONS(4058),
    [anon_sym_GT] = ACTIONS(4063),
    [anon_sym_GT_EQ] = ACTIONS(4058),
    [anon_sym_LT_EQ] = ACTIONS(4063),
    [anon_sym_LT] = ACTIONS(4063),
    [anon_sym_LT_LT] = ACTIONS(4063),
    [anon_sym_GT_GT] = ACTIONS(4063),
    [anon_sym___extension__] = ACTIONS(1961),
    [anon_sym_COLON_COLON] = ACTIONS(1961),
    [anon_sym_LBRACE] = ACTIONS(1961),
    [anon_sym_LBRACK] = ACTIONS(4060),
    [anon_sym_EQ] = ACTIONS(4063),
    [anon_sym_const] = ACTIONS(1959),
    [anon_sym_constexpr] = ACTIONS(1961),
    [anon_sym_volatile] = ACTIONS(1961),
    [anon_sym_restrict] = ACTIONS(1961),
    [anon_sym___restrict__] = ACTIONS(1961),
    [anon_sym__Atomic] = ACTIONS(1961),
    [anon_sym__Noreturn] = ACTIONS(1961),
    [anon_sym_noreturn] = ACTIONS(1961),
    [anon_sym_mutable] = ACTIONS(1961),
    [anon_sym_constinit] = ACTIONS(1961),
    [anon_sym_consteval] = ACTIONS(1961),
    [anon_sym_alignas] = ACTIONS(1961),
    [anon_sym__Alignas] = ACTIONS(1961),
    [anon_sym_QMARK] = ACTIONS(4058),
    [anon_sym_STAR_EQ] = ACTIONS(4058),
    [anon_sym_SLASH_EQ] = ACTIONS(4058),
    [anon_sym_PERCENT_EQ] = ACTIONS(4058),
    [anon_sym_PLUS_EQ] = ACTIONS(4058),
    [anon_sym_DASH_EQ] = ACTIONS(4058),
    [anon_sym_LT_LT_EQ] = ACTIONS(4058),
    [anon_sym_GT_GT_EQ] = ACTIONS(4058),
    [anon_sym_AMP_EQ] = ACTIONS(4058),
    [anon_sym_CARET_EQ] = ACTIONS(4058),
    [anon_sym_PIPE_EQ] = ACTIONS(4058),
    [anon_sym_and_eq] = ACTIONS(4058),
    [anon_sym_or_eq] = ACTIONS(4058),
    [anon_sym_xor_eq] = ACTIONS(4058),
    [anon_sym_LT_EQ_GT] = ACTIONS(4058),
    [anon_sym_or] = ACTIONS(4063),
    [anon_sym_and] = ACTIONS(4063),
    [anon_sym_bitor] = ACTIONS(4058),
    [anon_sym_xor] = ACTIONS(4063),
    [anon_sym_bitand] = ACTIONS(4058),
    [anon_sym_not_eq] = ACTIONS(4058),
    [anon_sym_DASH_DASH] = ACTIONS(4058),
    [anon_sym_PLUS_PLUS] = ACTIONS(4058),
    [anon_sym_DOT] = ACTIONS(4063),
    [anon_sym_DOT_STAR] = ACTIONS(4058),
    [anon_sym_DASH_GT] = ACTIONS(4063),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1961),
    [anon_sym_decltype] = ACTIONS(1961),
    [anon_sym_DASH_GT_STAR] = ACTIONS(4058),
  },
  [2416] = {
    [sym_identifier] = ACTIONS(1949),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1951),
    [anon_sym_COMMA] = ACTIONS(1951),
    [anon_sym_RPAREN] = ACTIONS(1951),
    [anon_sym_LPAREN2] = ACTIONS(1951),
    [anon_sym_DASH] = ACTIONS(1949),
    [anon_sym_PLUS] = ACTIONS(1949),
    [anon_sym_STAR] = ACTIONS(1951),
    [anon_sym_SLASH] = ACTIONS(1949),
    [anon_sym_PERCENT] = ACTIONS(1951),
    [anon_sym_PIPE_PIPE] = ACTIONS(1951),
    [anon_sym_AMP_AMP] = ACTIONS(1951),
    [anon_sym_PIPE] = ACTIONS(1949),
    [anon_sym_CARET] = ACTIONS(1951),
    [anon_sym_AMP] = ACTIONS(1949),
    [anon_sym_EQ_EQ] = ACTIONS(1951),
    [anon_sym_BANG_EQ] = ACTIONS(1951),
    [anon_sym_GT] = ACTIONS(1949),
    [anon_sym_GT_EQ] = ACTIONS(1951),
    [anon_sym_LT_EQ] = ACTIONS(1949),
    [anon_sym_LT] = ACTIONS(1949),
    [anon_sym_LT_LT] = ACTIONS(1951),
    [anon_sym_GT_GT] = ACTIONS(1951),
    [anon_sym_COLON] = ACTIONS(1949),
    [anon_sym_SEMI] = ACTIONS(1951),
    [anon_sym___extension__] = ACTIONS(1949),
    [anon_sym___attribute__] = ACTIONS(1949),
    [anon_sym_COLON_COLON] = ACTIONS(1951),
    [anon_sym___based] = ACTIONS(1949),
    [anon_sym_LBRACE] = ACTIONS(1951),
    [anon_sym_RBRACE] = ACTIONS(1951),
    [anon_sym_signed] = ACTIONS(1949),
    [anon_sym_unsigned] = ACTIONS(1949),
    [anon_sym_long] = ACTIONS(1949),
    [anon_sym_short] = ACTIONS(1949),
    [anon_sym_LBRACK] = ACTIONS(1951),
    [anon_sym_RBRACK] = ACTIONS(1951),
    [anon_sym_const] = ACTIONS(1949),
    [anon_sym_constexpr] = ACTIONS(1949),
    [anon_sym_volatile] = ACTIONS(1949),
    [anon_sym_restrict] = ACTIONS(1949),
    [anon_sym___restrict__] = ACTIONS(1949),
    [anon_sym__Atomic] = ACTIONS(1949),
    [anon_sym__Noreturn] = ACTIONS(1949),
    [anon_sym_noreturn] = ACTIONS(1949),
    [anon_sym_mutable] = ACTIONS(1949),
    [anon_sym_constinit] = ACTIONS(1949),
    [anon_sym_consteval] = ACTIONS(1949),
    [anon_sym_alignas] = ACTIONS(1949),
    [anon_sym__Alignas] = ACTIONS(1949),
    [sym_primitive_type] = ACTIONS(1949),
    [anon_sym_QMARK] = ACTIONS(1951),
    [anon_sym_LT_EQ_GT] = ACTIONS(1951),
    [anon_sym_or] = ACTIONS(1949),
    [anon_sym_and] = ACTIONS(1949),
    [anon_sym_bitor] = ACTIONS(1949),
    [anon_sym_xor] = ACTIONS(1949),
    [anon_sym_bitand] = ACTIONS(1949),
    [anon_sym_not_eq] = ACTIONS(1949),
    [anon_sym_DASH_DASH] = ACTIONS(1951),
    [anon_sym_PLUS_PLUS] = ACTIONS(1951),
    [anon_sym_DOT] = ACTIONS(1949),
    [anon_sym_DOT_STAR] = ACTIONS(1951),
    [anon_sym_DASH_GT] = ACTIONS(1951),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1949),
    [anon_sym_decltype] = ACTIONS(1949),
    [anon_sym_final] = ACTIONS(1949),
    [anon_sym_override] = ACTIONS(1949),
    [anon_sym_requires] = ACTIONS(1949),
  },
  [2417] = {
    [sym_decltype_auto] = STATE(2460),
    [sym_identifier] = ACTIONS(5413),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5415),
    [anon_sym_COMMA] = ACTIONS(5415),
    [anon_sym_RPAREN] = ACTIONS(5415),
    [anon_sym_LPAREN2] = ACTIONS(5415),
    [anon_sym_DASH] = ACTIONS(5413),
    [anon_sym_PLUS] = ACTIONS(5413),
    [anon_sym_STAR] = ACTIONS(5415),
    [anon_sym_SLASH] = ACTIONS(5413),
    [anon_sym_PERCENT] = ACTIONS(5415),
    [anon_sym_PIPE_PIPE] = ACTIONS(5415),
    [anon_sym_AMP_AMP] = ACTIONS(5415),
    [anon_sym_PIPE] = ACTIONS(5413),
    [anon_sym_CARET] = ACTIONS(5415),
    [anon_sym_AMP] = ACTIONS(5413),
    [anon_sym_EQ_EQ] = ACTIONS(5415),
    [anon_sym_BANG_EQ] = ACTIONS(5415),
    [anon_sym_GT] = ACTIONS(5413),
    [anon_sym_GT_EQ] = ACTIONS(5415),
    [anon_sym_LT_EQ] = ACTIONS(5413),
    [anon_sym_LT] = ACTIONS(5413),
    [anon_sym_LT_LT] = ACTIONS(5415),
    [anon_sym_GT_GT] = ACTIONS(5415),
    [anon_sym_COLON] = ACTIONS(5415),
    [anon_sym_SEMI] = ACTIONS(5415),
    [anon_sym___extension__] = ACTIONS(5413),
    [anon_sym___attribute__] = ACTIONS(5413),
    [anon_sym___based] = ACTIONS(5413),
    [anon_sym_LBRACE] = ACTIONS(5415),
    [anon_sym_RBRACE] = ACTIONS(5415),
    [anon_sym_signed] = ACTIONS(5413),
    [anon_sym_unsigned] = ACTIONS(5413),
    [anon_sym_long] = ACTIONS(5413),
    [anon_sym_short] = ACTIONS(5413),
    [anon_sym_LBRACK] = ACTIONS(5415),
    [anon_sym_RBRACK] = ACTIONS(5415),
    [anon_sym_const] = ACTIONS(5413),
    [anon_sym_constexpr] = ACTIONS(5413),
    [anon_sym_volatile] = ACTIONS(5413),
    [anon_sym_restrict] = ACTIONS(5413),
    [anon_sym___restrict__] = ACTIONS(5413),
    [anon_sym__Atomic] = ACTIONS(5413),
    [anon_sym__Noreturn] = ACTIONS(5413),
    [anon_sym_noreturn] = ACTIONS(5413),
    [anon_sym_mutable] = ACTIONS(5413),
    [anon_sym_constinit] = ACTIONS(5413),
    [anon_sym_consteval] = ACTIONS(5413),
    [anon_sym_alignas] = ACTIONS(5413),
    [anon_sym__Alignas] = ACTIONS(5413),
    [sym_primitive_type] = ACTIONS(5413),
    [anon_sym_QMARK] = ACTIONS(5415),
    [anon_sym_LT_EQ_GT] = ACTIONS(5415),
    [anon_sym_or] = ACTIONS(5413),
    [anon_sym_and] = ACTIONS(5413),
    [anon_sym_bitor] = ACTIONS(5413),
    [anon_sym_xor] = ACTIONS(5413),
    [anon_sym_bitand] = ACTIONS(5413),
    [anon_sym_not_eq] = ACTIONS(5413),
    [anon_sym_DASH_DASH] = ACTIONS(5415),
    [anon_sym_PLUS_PLUS] = ACTIONS(5415),
    [anon_sym_DOT] = ACTIONS(5413),
    [anon_sym_DOT_STAR] = ACTIONS(5415),
    [anon_sym_DASH_GT] = ACTIONS(5415),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5819),
    [anon_sym_decltype] = ACTIONS(5821),
    [anon_sym_final] = ACTIONS(5413),
    [anon_sym_override] = ACTIONS(5413),
    [anon_sym_requires] = ACTIONS(5413),
  },
  [2418] = {
    [sym_identifier] = ACTIONS(5823),
    [anon_sym_LPAREN2] = ACTIONS(5825),
    [anon_sym_STAR] = ACTIONS(5825),
    [anon_sym_AMP_AMP] = ACTIONS(5825),
    [anon_sym_AMP] = ACTIONS(5823),
    [anon_sym___extension__] = ACTIONS(5823),
    [anon_sym_in] = ACTIONS(5823),
    [anon_sym_out] = ACTIONS(5823),
    [anon_sym_inout] = ACTIONS(5823),
    [anon_sym_extern] = ACTIONS(5823),
    [anon_sym___attribute__] = ACTIONS(5823),
    [anon_sym_COLON_COLON] = ACTIONS(5825),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5825),
    [anon_sym___declspec] = ACTIONS(5823),
    [anon_sym___based] = ACTIONS(5823),
    [anon_sym_signed] = ACTIONS(5823),
    [anon_sym_unsigned] = ACTIONS(5823),
    [anon_sym_long] = ACTIONS(5823),
    [anon_sym_short] = ACTIONS(5823),
    [anon_sym_static] = ACTIONS(5823),
    [anon_sym_register] = ACTIONS(5823),
    [anon_sym_inline] = ACTIONS(5823),
    [anon_sym___inline] = ACTIONS(5823),
    [anon_sym___inline__] = ACTIONS(5823),
    [anon_sym___forceinline] = ACTIONS(5823),
    [anon_sym_thread_local] = ACTIONS(5823),
    [anon_sym___thread] = ACTIONS(5823),
    [anon_sym_const] = ACTIONS(5823),
    [anon_sym_constexpr] = ACTIONS(5823),
    [anon_sym_volatile] = ACTIONS(5823),
    [anon_sym_restrict] = ACTIONS(5823),
    [anon_sym___restrict__] = ACTIONS(5823),
    [anon_sym__Atomic] = ACTIONS(5823),
    [anon_sym__Noreturn] = ACTIONS(5823),
    [anon_sym_noreturn] = ACTIONS(5823),
    [anon_sym_mutable] = ACTIONS(5823),
    [anon_sym_constinit] = ACTIONS(5823),
    [anon_sym_consteval] = ACTIONS(5823),
    [anon_sym_alignas] = ACTIONS(5823),
    [anon_sym__Alignas] = ACTIONS(5823),
    [sym_primitive_type] = ACTIONS(5823),
    [anon_sym_enum] = ACTIONS(5823),
    [anon_sym_class] = ACTIONS(5823),
    [anon_sym_struct] = ACTIONS(5823),
    [anon_sym_union] = ACTIONS(5823),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5823),
    [anon_sym_decltype] = ACTIONS(5823),
    [sym_virtual] = ACTIONS(5823),
    [anon_sym_typename] = ACTIONS(5823),
    [anon_sym_template] = ACTIONS(5823),
    [anon_sym_precise] = ACTIONS(5823),
    [anon_sym_shared] = ACTIONS(5823),
    [anon_sym_groupshared] = ACTIONS(5823),
    [anon_sym_uniform] = ACTIONS(5823),
    [anon_sym_row_major] = ACTIONS(5823),
    [anon_sym_column_major] = ACTIONS(5823),
    [anon_sym_globallycoherent] = ACTIONS(5823),
    [anon_sym_centroid] = ACTIONS(5823),
    [anon_sym_noperspective] = ACTIONS(5823),
    [anon_sym_nointerpolation] = ACTIONS(5823),
    [anon_sym_sample] = ACTIONS(5823),
    [anon_sym_linear] = ACTIONS(5823),
    [anon_sym_snorm] = ACTIONS(5823),
    [anon_sym_unorm] = ACTIONS(5823),
    [anon_sym_point] = ACTIONS(5823),
    [anon_sym_line] = ACTIONS(5823),
    [anon_sym_triangleadj] = ACTIONS(5823),
    [anon_sym_lineadj] = ACTIONS(5823),
    [anon_sym_triangle] = ACTIONS(5823),
  },
  [2419] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1971),
    [anon_sym_COMMA] = ACTIONS(1971),
    [anon_sym_RPAREN] = ACTIONS(1971),
    [anon_sym_LPAREN2] = ACTIONS(1971),
    [anon_sym_DASH] = ACTIONS(1969),
    [anon_sym_PLUS] = ACTIONS(1969),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_SLASH] = ACTIONS(1969),
    [anon_sym_PERCENT] = ACTIONS(1971),
    [anon_sym_PIPE_PIPE] = ACTIONS(1971),
    [anon_sym_AMP_AMP] = ACTIONS(1971),
    [anon_sym_PIPE] = ACTIONS(1969),
    [anon_sym_CARET] = ACTIONS(1971),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_EQ_EQ] = ACTIONS(1971),
    [anon_sym_BANG_EQ] = ACTIONS(1971),
    [anon_sym_GT] = ACTIONS(1969),
    [anon_sym_GT_EQ] = ACTIONS(1971),
    [anon_sym_LT_EQ] = ACTIONS(1969),
    [anon_sym_LT] = ACTIONS(1969),
    [anon_sym_LT_LT] = ACTIONS(1971),
    [anon_sym_GT_GT] = ACTIONS(1971),
    [anon_sym_COLON] = ACTIONS(1969),
    [anon_sym_SEMI] = ACTIONS(1971),
    [anon_sym___extension__] = ACTIONS(1969),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym___based] = ACTIONS(1969),
    [anon_sym_LBRACE] = ACTIONS(1971),
    [anon_sym_RBRACE] = ACTIONS(1971),
    [anon_sym_signed] = ACTIONS(1969),
    [anon_sym_unsigned] = ACTIONS(1969),
    [anon_sym_long] = ACTIONS(1969),
    [anon_sym_short] = ACTIONS(1969),
    [anon_sym_LBRACK] = ACTIONS(1971),
    [anon_sym_RBRACK] = ACTIONS(1971),
    [anon_sym_const] = ACTIONS(1969),
    [anon_sym_constexpr] = ACTIONS(1969),
    [anon_sym_volatile] = ACTIONS(1969),
    [anon_sym_restrict] = ACTIONS(1969),
    [anon_sym___restrict__] = ACTIONS(1969),
    [anon_sym__Atomic] = ACTIONS(1969),
    [anon_sym__Noreturn] = ACTIONS(1969),
    [anon_sym_noreturn] = ACTIONS(1969),
    [anon_sym_mutable] = ACTIONS(1969),
    [anon_sym_constinit] = ACTIONS(1969),
    [anon_sym_consteval] = ACTIONS(1969),
    [anon_sym_alignas] = ACTIONS(1969),
    [anon_sym__Alignas] = ACTIONS(1969),
    [sym_primitive_type] = ACTIONS(1969),
    [anon_sym_QMARK] = ACTIONS(1971),
    [anon_sym_LT_EQ_GT] = ACTIONS(1971),
    [anon_sym_or] = ACTIONS(1969),
    [anon_sym_and] = ACTIONS(1969),
    [anon_sym_bitor] = ACTIONS(1969),
    [anon_sym_xor] = ACTIONS(1969),
    [anon_sym_bitand] = ACTIONS(1969),
    [anon_sym_not_eq] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1971),
    [anon_sym_PLUS_PLUS] = ACTIONS(1971),
    [anon_sym_DOT] = ACTIONS(1969),
    [anon_sym_DOT_STAR] = ACTIONS(1971),
    [anon_sym_DASH_GT] = ACTIONS(1971),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_final] = ACTIONS(1969),
    [anon_sym_override] = ACTIONS(1969),
    [anon_sym_requires] = ACTIONS(1969),
  },
  [2420] = {
    [sym_identifier] = ACTIONS(1917),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1919),
    [anon_sym_COMMA] = ACTIONS(1919),
    [anon_sym_RPAREN] = ACTIONS(1919),
    [anon_sym_LPAREN2] = ACTIONS(1919),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1919),
    [anon_sym_SLASH] = ACTIONS(1917),
    [anon_sym_PERCENT] = ACTIONS(1919),
    [anon_sym_PIPE_PIPE] = ACTIONS(1919),
    [anon_sym_AMP_AMP] = ACTIONS(1919),
    [anon_sym_PIPE] = ACTIONS(1917),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1917),
    [anon_sym_EQ_EQ] = ACTIONS(1919),
    [anon_sym_BANG_EQ] = ACTIONS(1919),
    [anon_sym_GT] = ACTIONS(1917),
    [anon_sym_GT_EQ] = ACTIONS(1919),
    [anon_sym_LT_EQ] = ACTIONS(1917),
    [anon_sym_LT] = ACTIONS(1917),
    [anon_sym_LT_LT] = ACTIONS(1919),
    [anon_sym_GT_GT] = ACTIONS(1919),
    [anon_sym_COLON] = ACTIONS(1917),
    [anon_sym_SEMI] = ACTIONS(1919),
    [anon_sym___extension__] = ACTIONS(1917),
    [anon_sym___attribute__] = ACTIONS(1917),
    [anon_sym_COLON_COLON] = ACTIONS(1919),
    [anon_sym___based] = ACTIONS(1917),
    [anon_sym_LBRACE] = ACTIONS(1919),
    [anon_sym_RBRACE] = ACTIONS(1919),
    [anon_sym_signed] = ACTIONS(1917),
    [anon_sym_unsigned] = ACTIONS(1917),
    [anon_sym_long] = ACTIONS(1917),
    [anon_sym_short] = ACTIONS(1917),
    [anon_sym_LBRACK] = ACTIONS(1919),
    [anon_sym_RBRACK] = ACTIONS(1919),
    [anon_sym_const] = ACTIONS(1917),
    [anon_sym_constexpr] = ACTIONS(1917),
    [anon_sym_volatile] = ACTIONS(1917),
    [anon_sym_restrict] = ACTIONS(1917),
    [anon_sym___restrict__] = ACTIONS(1917),
    [anon_sym__Atomic] = ACTIONS(1917),
    [anon_sym__Noreturn] = ACTIONS(1917),
    [anon_sym_noreturn] = ACTIONS(1917),
    [anon_sym_mutable] = ACTIONS(1917),
    [anon_sym_constinit] = ACTIONS(1917),
    [anon_sym_consteval] = ACTIONS(1917),
    [anon_sym_alignas] = ACTIONS(1917),
    [anon_sym__Alignas] = ACTIONS(1917),
    [sym_primitive_type] = ACTIONS(1917),
    [anon_sym_QMARK] = ACTIONS(1919),
    [anon_sym_LT_EQ_GT] = ACTIONS(1919),
    [anon_sym_or] = ACTIONS(1917),
    [anon_sym_and] = ACTIONS(1917),
    [anon_sym_bitor] = ACTIONS(1917),
    [anon_sym_xor] = ACTIONS(1917),
    [anon_sym_bitand] = ACTIONS(1917),
    [anon_sym_not_eq] = ACTIONS(1917),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DOT] = ACTIONS(1917),
    [anon_sym_DOT_STAR] = ACTIONS(1919),
    [anon_sym_DASH_GT] = ACTIONS(1919),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1917),
    [anon_sym_decltype] = ACTIONS(1917),
    [anon_sym_final] = ACTIONS(1917),
    [anon_sym_override] = ACTIONS(1917),
    [anon_sym_requires] = ACTIONS(1917),
  },
  [2421] = {
    [sym_identifier] = ACTIONS(1887),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1889),
    [anon_sym_COMMA] = ACTIONS(1889),
    [anon_sym_RPAREN] = ACTIONS(1889),
    [anon_sym_LPAREN2] = ACTIONS(1889),
    [anon_sym_DASH] = ACTIONS(1887),
    [anon_sym_PLUS] = ACTIONS(1887),
    [anon_sym_STAR] = ACTIONS(1889),
    [anon_sym_SLASH] = ACTIONS(1887),
    [anon_sym_PERCENT] = ACTIONS(1889),
    [anon_sym_PIPE_PIPE] = ACTIONS(1889),
    [anon_sym_AMP_AMP] = ACTIONS(1889),
    [anon_sym_PIPE] = ACTIONS(1887),
    [anon_sym_CARET] = ACTIONS(1889),
    [anon_sym_AMP] = ACTIONS(1887),
    [anon_sym_EQ_EQ] = ACTIONS(1889),
    [anon_sym_BANG_EQ] = ACTIONS(1889),
    [anon_sym_GT] = ACTIONS(1887),
    [anon_sym_GT_EQ] = ACTIONS(1889),
    [anon_sym_LT_EQ] = ACTIONS(1887),
    [anon_sym_LT] = ACTIONS(1887),
    [anon_sym_LT_LT] = ACTIONS(1889),
    [anon_sym_GT_GT] = ACTIONS(1889),
    [anon_sym_COLON] = ACTIONS(1887),
    [anon_sym_SEMI] = ACTIONS(1889),
    [anon_sym___extension__] = ACTIONS(1887),
    [anon_sym___attribute__] = ACTIONS(1887),
    [anon_sym_COLON_COLON] = ACTIONS(1889),
    [anon_sym___based] = ACTIONS(1887),
    [anon_sym_LBRACE] = ACTIONS(1889),
    [anon_sym_RBRACE] = ACTIONS(1889),
    [anon_sym_signed] = ACTIONS(1887),
    [anon_sym_unsigned] = ACTIONS(1887),
    [anon_sym_long] = ACTIONS(1887),
    [anon_sym_short] = ACTIONS(1887),
    [anon_sym_LBRACK] = ACTIONS(1889),
    [anon_sym_RBRACK] = ACTIONS(1889),
    [anon_sym_const] = ACTIONS(1887),
    [anon_sym_constexpr] = ACTIONS(1887),
    [anon_sym_volatile] = ACTIONS(1887),
    [anon_sym_restrict] = ACTIONS(1887),
    [anon_sym___restrict__] = ACTIONS(1887),
    [anon_sym__Atomic] = ACTIONS(1887),
    [anon_sym__Noreturn] = ACTIONS(1887),
    [anon_sym_noreturn] = ACTIONS(1887),
    [anon_sym_mutable] = ACTIONS(1887),
    [anon_sym_constinit] = ACTIONS(1887),
    [anon_sym_consteval] = ACTIONS(1887),
    [anon_sym_alignas] = ACTIONS(1887),
    [anon_sym__Alignas] = ACTIONS(1887),
    [sym_primitive_type] = ACTIONS(1887),
    [anon_sym_QMARK] = ACTIONS(1889),
    [anon_sym_LT_EQ_GT] = ACTIONS(1889),
    [anon_sym_or] = ACTIONS(1887),
    [anon_sym_and] = ACTIONS(1887),
    [anon_sym_bitor] = ACTIONS(1887),
    [anon_sym_xor] = ACTIONS(1887),
    [anon_sym_bitand] = ACTIONS(1887),
    [anon_sym_not_eq] = ACTIONS(1887),
    [anon_sym_DASH_DASH] = ACTIONS(1889),
    [anon_sym_PLUS_PLUS] = ACTIONS(1889),
    [anon_sym_DOT] = ACTIONS(1887),
    [anon_sym_DOT_STAR] = ACTIONS(1889),
    [anon_sym_DASH_GT] = ACTIONS(1889),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1887),
    [anon_sym_decltype] = ACTIONS(1887),
    [anon_sym_final] = ACTIONS(1887),
    [anon_sym_override] = ACTIONS(1887),
    [anon_sym_requires] = ACTIONS(1887),
  },
  [2422] = {
    [sym_identifier] = ACTIONS(1903),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1905),
    [anon_sym_COMMA] = ACTIONS(1905),
    [anon_sym_RPAREN] = ACTIONS(1905),
    [anon_sym_LPAREN2] = ACTIONS(1905),
    [anon_sym_DASH] = ACTIONS(1903),
    [anon_sym_PLUS] = ACTIONS(1903),
    [anon_sym_STAR] = ACTIONS(1905),
    [anon_sym_SLASH] = ACTIONS(1903),
    [anon_sym_PERCENT] = ACTIONS(1905),
    [anon_sym_PIPE_PIPE] = ACTIONS(1905),
    [anon_sym_AMP_AMP] = ACTIONS(1905),
    [anon_sym_PIPE] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1905),
    [anon_sym_AMP] = ACTIONS(1903),
    [anon_sym_EQ_EQ] = ACTIONS(1905),
    [anon_sym_BANG_EQ] = ACTIONS(1905),
    [anon_sym_GT] = ACTIONS(1903),
    [anon_sym_GT_EQ] = ACTIONS(1905),
    [anon_sym_LT_EQ] = ACTIONS(1903),
    [anon_sym_LT] = ACTIONS(1903),
    [anon_sym_LT_LT] = ACTIONS(1905),
    [anon_sym_GT_GT] = ACTIONS(1905),
    [anon_sym_COLON] = ACTIONS(1903),
    [anon_sym_SEMI] = ACTIONS(1905),
    [anon_sym___extension__] = ACTIONS(1903),
    [anon_sym___attribute__] = ACTIONS(1903),
    [anon_sym_COLON_COLON] = ACTIONS(1905),
    [anon_sym___based] = ACTIONS(1903),
    [anon_sym_LBRACE] = ACTIONS(1905),
    [anon_sym_RBRACE] = ACTIONS(1905),
    [anon_sym_signed] = ACTIONS(1903),
    [anon_sym_unsigned] = ACTIONS(1903),
    [anon_sym_long] = ACTIONS(1903),
    [anon_sym_short] = ACTIONS(1903),
    [anon_sym_LBRACK] = ACTIONS(1905),
    [anon_sym_RBRACK] = ACTIONS(1905),
    [anon_sym_const] = ACTIONS(1903),
    [anon_sym_constexpr] = ACTIONS(1903),
    [anon_sym_volatile] = ACTIONS(1903),
    [anon_sym_restrict] = ACTIONS(1903),
    [anon_sym___restrict__] = ACTIONS(1903),
    [anon_sym__Atomic] = ACTIONS(1903),
    [anon_sym__Noreturn] = ACTIONS(1903),
    [anon_sym_noreturn] = ACTIONS(1903),
    [anon_sym_mutable] = ACTIONS(1903),
    [anon_sym_constinit] = ACTIONS(1903),
    [anon_sym_consteval] = ACTIONS(1903),
    [anon_sym_alignas] = ACTIONS(1903),
    [anon_sym__Alignas] = ACTIONS(1903),
    [sym_primitive_type] = ACTIONS(1903),
    [anon_sym_QMARK] = ACTIONS(1905),
    [anon_sym_LT_EQ_GT] = ACTIONS(1905),
    [anon_sym_or] = ACTIONS(1903),
    [anon_sym_and] = ACTIONS(1903),
    [anon_sym_bitor] = ACTIONS(1903),
    [anon_sym_xor] = ACTIONS(1903),
    [anon_sym_bitand] = ACTIONS(1903),
    [anon_sym_not_eq] = ACTIONS(1903),
    [anon_sym_DASH_DASH] = ACTIONS(1905),
    [anon_sym_PLUS_PLUS] = ACTIONS(1905),
    [anon_sym_DOT] = ACTIONS(1903),
    [anon_sym_DOT_STAR] = ACTIONS(1905),
    [anon_sym_DASH_GT] = ACTIONS(1905),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1903),
    [anon_sym_decltype] = ACTIONS(1903),
    [anon_sym_final] = ACTIONS(1903),
    [anon_sym_override] = ACTIONS(1903),
    [anon_sym_requires] = ACTIONS(1903),
  },
  [2423] = {
    [sym_identifier] = ACTIONS(1891),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1893),
    [anon_sym_COMMA] = ACTIONS(1893),
    [anon_sym_RPAREN] = ACTIONS(1893),
    [anon_sym_LPAREN2] = ACTIONS(1893),
    [anon_sym_DASH] = ACTIONS(1891),
    [anon_sym_PLUS] = ACTIONS(1891),
    [anon_sym_STAR] = ACTIONS(1893),
    [anon_sym_SLASH] = ACTIONS(1891),
    [anon_sym_PERCENT] = ACTIONS(1893),
    [anon_sym_PIPE_PIPE] = ACTIONS(1893),
    [anon_sym_AMP_AMP] = ACTIONS(1893),
    [anon_sym_PIPE] = ACTIONS(1891),
    [anon_sym_CARET] = ACTIONS(1893),
    [anon_sym_AMP] = ACTIONS(1891),
    [anon_sym_EQ_EQ] = ACTIONS(1893),
    [anon_sym_BANG_EQ] = ACTIONS(1893),
    [anon_sym_GT] = ACTIONS(1891),
    [anon_sym_GT_EQ] = ACTIONS(1893),
    [anon_sym_LT_EQ] = ACTIONS(1891),
    [anon_sym_LT] = ACTIONS(1891),
    [anon_sym_LT_LT] = ACTIONS(1893),
    [anon_sym_GT_GT] = ACTIONS(1893),
    [anon_sym_COLON] = ACTIONS(1891),
    [anon_sym_SEMI] = ACTIONS(1893),
    [anon_sym___extension__] = ACTIONS(1891),
    [anon_sym___attribute__] = ACTIONS(1891),
    [anon_sym_COLON_COLON] = ACTIONS(1893),
    [anon_sym___based] = ACTIONS(1891),
    [anon_sym_LBRACE] = ACTIONS(1893),
    [anon_sym_RBRACE] = ACTIONS(1893),
    [anon_sym_signed] = ACTIONS(1891),
    [anon_sym_unsigned] = ACTIONS(1891),
    [anon_sym_long] = ACTIONS(1891),
    [anon_sym_short] = ACTIONS(1891),
    [anon_sym_LBRACK] = ACTIONS(1893),
    [anon_sym_RBRACK] = ACTIONS(1893),
    [anon_sym_const] = ACTIONS(1891),
    [anon_sym_constexpr] = ACTIONS(1891),
    [anon_sym_volatile] = ACTIONS(1891),
    [anon_sym_restrict] = ACTIONS(1891),
    [anon_sym___restrict__] = ACTIONS(1891),
    [anon_sym__Atomic] = ACTIONS(1891),
    [anon_sym__Noreturn] = ACTIONS(1891),
    [anon_sym_noreturn] = ACTIONS(1891),
    [anon_sym_mutable] = ACTIONS(1891),
    [anon_sym_constinit] = ACTIONS(1891),
    [anon_sym_consteval] = ACTIONS(1891),
    [anon_sym_alignas] = ACTIONS(1891),
    [anon_sym__Alignas] = ACTIONS(1891),
    [sym_primitive_type] = ACTIONS(1891),
    [anon_sym_QMARK] = ACTIONS(1893),
    [anon_sym_LT_EQ_GT] = ACTIONS(1893),
    [anon_sym_or] = ACTIONS(1891),
    [anon_sym_and] = ACTIONS(1891),
    [anon_sym_bitor] = ACTIONS(1891),
    [anon_sym_xor] = ACTIONS(1891),
    [anon_sym_bitand] = ACTIONS(1891),
    [anon_sym_not_eq] = ACTIONS(1891),
    [anon_sym_DASH_DASH] = ACTIONS(1893),
    [anon_sym_PLUS_PLUS] = ACTIONS(1893),
    [anon_sym_DOT] = ACTIONS(1891),
    [anon_sym_DOT_STAR] = ACTIONS(1893),
    [anon_sym_DASH_GT] = ACTIONS(1893),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1891),
    [anon_sym_decltype] = ACTIONS(1891),
    [anon_sym_final] = ACTIONS(1891),
    [anon_sym_override] = ACTIONS(1891),
    [anon_sym_requires] = ACTIONS(1891),
  },
  [2424] = {
    [sym_identifier] = ACTIONS(1895),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1897),
    [anon_sym_COMMA] = ACTIONS(1897),
    [anon_sym_RPAREN] = ACTIONS(1897),
    [anon_sym_LPAREN2] = ACTIONS(1897),
    [anon_sym_DASH] = ACTIONS(1895),
    [anon_sym_PLUS] = ACTIONS(1895),
    [anon_sym_STAR] = ACTIONS(1897),
    [anon_sym_SLASH] = ACTIONS(1895),
    [anon_sym_PERCENT] = ACTIONS(1897),
    [anon_sym_PIPE_PIPE] = ACTIONS(1897),
    [anon_sym_AMP_AMP] = ACTIONS(1897),
    [anon_sym_PIPE] = ACTIONS(1895),
    [anon_sym_CARET] = ACTIONS(1897),
    [anon_sym_AMP] = ACTIONS(1895),
    [anon_sym_EQ_EQ] = ACTIONS(1897),
    [anon_sym_BANG_EQ] = ACTIONS(1897),
    [anon_sym_GT] = ACTIONS(1895),
    [anon_sym_GT_EQ] = ACTIONS(1897),
    [anon_sym_LT_EQ] = ACTIONS(1895),
    [anon_sym_LT] = ACTIONS(1895),
    [anon_sym_LT_LT] = ACTIONS(1897),
    [anon_sym_GT_GT] = ACTIONS(1897),
    [anon_sym_COLON] = ACTIONS(1895),
    [anon_sym_SEMI] = ACTIONS(1897),
    [anon_sym___extension__] = ACTIONS(1895),
    [anon_sym___attribute__] = ACTIONS(1895),
    [anon_sym_COLON_COLON] = ACTIONS(1897),
    [anon_sym___based] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1897),
    [anon_sym_RBRACE] = ACTIONS(1897),
    [anon_sym_signed] = ACTIONS(1895),
    [anon_sym_unsigned] = ACTIONS(1895),
    [anon_sym_long] = ACTIONS(1895),
    [anon_sym_short] = ACTIONS(1895),
    [anon_sym_LBRACK] = ACTIONS(1897),
    [anon_sym_RBRACK] = ACTIONS(1897),
    [anon_sym_const] = ACTIONS(1895),
    [anon_sym_constexpr] = ACTIONS(1895),
    [anon_sym_volatile] = ACTIONS(1895),
    [anon_sym_restrict] = ACTIONS(1895),
    [anon_sym___restrict__] = ACTIONS(1895),
    [anon_sym__Atomic] = ACTIONS(1895),
    [anon_sym__Noreturn] = ACTIONS(1895),
    [anon_sym_noreturn] = ACTIONS(1895),
    [anon_sym_mutable] = ACTIONS(1895),
    [anon_sym_constinit] = ACTIONS(1895),
    [anon_sym_consteval] = ACTIONS(1895),
    [anon_sym_alignas] = ACTIONS(1895),
    [anon_sym__Alignas] = ACTIONS(1895),
    [sym_primitive_type] = ACTIONS(1895),
    [anon_sym_QMARK] = ACTIONS(1897),
    [anon_sym_LT_EQ_GT] = ACTIONS(1897),
    [anon_sym_or] = ACTIONS(1895),
    [anon_sym_and] = ACTIONS(1895),
    [anon_sym_bitor] = ACTIONS(1895),
    [anon_sym_xor] = ACTIONS(1895),
    [anon_sym_bitand] = ACTIONS(1895),
    [anon_sym_not_eq] = ACTIONS(1895),
    [anon_sym_DASH_DASH] = ACTIONS(1897),
    [anon_sym_PLUS_PLUS] = ACTIONS(1897),
    [anon_sym_DOT] = ACTIONS(1895),
    [anon_sym_DOT_STAR] = ACTIONS(1897),
    [anon_sym_DASH_GT] = ACTIONS(1897),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1895),
    [anon_sym_decltype] = ACTIONS(1895),
    [anon_sym_final] = ACTIONS(1895),
    [anon_sym_override] = ACTIONS(1895),
    [anon_sym_requires] = ACTIONS(1895),
  },
  [2425] = {
    [sym_template_argument_list] = STATE(2436),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4047),
    [anon_sym_COMMA] = ACTIONS(4047),
    [anon_sym_LPAREN2] = ACTIONS(4047),
    [anon_sym_DASH] = ACTIONS(4050),
    [anon_sym_PLUS] = ACTIONS(4050),
    [anon_sym_STAR] = ACTIONS(4052),
    [anon_sym_SLASH] = ACTIONS(4050),
    [anon_sym_PERCENT] = ACTIONS(4050),
    [anon_sym_PIPE_PIPE] = ACTIONS(4045),
    [anon_sym_AMP_AMP] = ACTIONS(4047),
    [anon_sym_PIPE] = ACTIONS(4050),
    [anon_sym_CARET] = ACTIONS(4050),
    [anon_sym_AMP] = ACTIONS(4052),
    [anon_sym_EQ_EQ] = ACTIONS(4045),
    [anon_sym_BANG_EQ] = ACTIONS(4045),
    [anon_sym_GT] = ACTIONS(4050),
    [anon_sym_GT_EQ] = ACTIONS(4050),
    [anon_sym_LT_EQ] = ACTIONS(4050),
    [anon_sym_LT] = ACTIONS(5827),
    [anon_sym_LT_LT] = ACTIONS(4050),
    [anon_sym_GT_GT] = ACTIONS(4050),
    [anon_sym___extension__] = ACTIONS(1935),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1935),
    [anon_sym_LBRACK] = ACTIONS(4047),
    [anon_sym_EQ] = ACTIONS(4050),
    [anon_sym_const] = ACTIONS(1933),
    [anon_sym_constexpr] = ACTIONS(1935),
    [anon_sym_volatile] = ACTIONS(1935),
    [anon_sym_restrict] = ACTIONS(1935),
    [anon_sym___restrict__] = ACTIONS(1935),
    [anon_sym__Atomic] = ACTIONS(1935),
    [anon_sym__Noreturn] = ACTIONS(1935),
    [anon_sym_noreturn] = ACTIONS(1935),
    [anon_sym_mutable] = ACTIONS(1935),
    [anon_sym_constinit] = ACTIONS(1935),
    [anon_sym_consteval] = ACTIONS(1935),
    [anon_sym_alignas] = ACTIONS(1935),
    [anon_sym__Alignas] = ACTIONS(1935),
    [anon_sym_QMARK] = ACTIONS(4045),
    [anon_sym_STAR_EQ] = ACTIONS(4045),
    [anon_sym_SLASH_EQ] = ACTIONS(4045),
    [anon_sym_PERCENT_EQ] = ACTIONS(4045),
    [anon_sym_PLUS_EQ] = ACTIONS(4045),
    [anon_sym_DASH_EQ] = ACTIONS(4045),
    [anon_sym_LT_LT_EQ] = ACTIONS(4045),
    [anon_sym_GT_GT_EQ] = ACTIONS(4050),
    [anon_sym_AMP_EQ] = ACTIONS(4045),
    [anon_sym_CARET_EQ] = ACTIONS(4045),
    [anon_sym_PIPE_EQ] = ACTIONS(4045),
    [anon_sym_and_eq] = ACTIONS(4045),
    [anon_sym_or_eq] = ACTIONS(4045),
    [anon_sym_xor_eq] = ACTIONS(4045),
    [anon_sym_LT_EQ_GT] = ACTIONS(4045),
    [anon_sym_or] = ACTIONS(4050),
    [anon_sym_and] = ACTIONS(4050),
    [anon_sym_bitor] = ACTIONS(4045),
    [anon_sym_xor] = ACTIONS(4050),
    [anon_sym_bitand] = ACTIONS(4045),
    [anon_sym_not_eq] = ACTIONS(4045),
    [anon_sym_DASH_DASH] = ACTIONS(4045),
    [anon_sym_PLUS_PLUS] = ACTIONS(4045),
    [anon_sym_DOT] = ACTIONS(4050),
    [anon_sym_DOT_STAR] = ACTIONS(4045),
    [anon_sym_DASH_GT] = ACTIONS(4045),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1935),
    [anon_sym_decltype] = ACTIONS(1935),
    [anon_sym_GT2] = ACTIONS(4047),
  },
  [2426] = {
    [sym_identifier] = ACTIONS(1899),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1901),
    [anon_sym_COMMA] = ACTIONS(1901),
    [anon_sym_RPAREN] = ACTIONS(1901),
    [anon_sym_LPAREN2] = ACTIONS(1901),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1901),
    [anon_sym_SLASH] = ACTIONS(1899),
    [anon_sym_PERCENT] = ACTIONS(1901),
    [anon_sym_PIPE_PIPE] = ACTIONS(1901),
    [anon_sym_AMP_AMP] = ACTIONS(1901),
    [anon_sym_PIPE] = ACTIONS(1899),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1899),
    [anon_sym_EQ_EQ] = ACTIONS(1901),
    [anon_sym_BANG_EQ] = ACTIONS(1901),
    [anon_sym_GT] = ACTIONS(1899),
    [anon_sym_GT_EQ] = ACTIONS(1901),
    [anon_sym_LT_EQ] = ACTIONS(1899),
    [anon_sym_LT] = ACTIONS(1899),
    [anon_sym_LT_LT] = ACTIONS(1901),
    [anon_sym_GT_GT] = ACTIONS(1901),
    [anon_sym_COLON] = ACTIONS(1899),
    [anon_sym_SEMI] = ACTIONS(1901),
    [anon_sym___extension__] = ACTIONS(1899),
    [anon_sym___attribute__] = ACTIONS(1899),
    [anon_sym_COLON_COLON] = ACTIONS(1901),
    [anon_sym___based] = ACTIONS(1899),
    [anon_sym_LBRACE] = ACTIONS(1901),
    [anon_sym_RBRACE] = ACTIONS(1901),
    [anon_sym_signed] = ACTIONS(1899),
    [anon_sym_unsigned] = ACTIONS(1899),
    [anon_sym_long] = ACTIONS(1899),
    [anon_sym_short] = ACTIONS(1899),
    [anon_sym_LBRACK] = ACTIONS(1901),
    [anon_sym_RBRACK] = ACTIONS(1901),
    [anon_sym_const] = ACTIONS(1899),
    [anon_sym_constexpr] = ACTIONS(1899),
    [anon_sym_volatile] = ACTIONS(1899),
    [anon_sym_restrict] = ACTIONS(1899),
    [anon_sym___restrict__] = ACTIONS(1899),
    [anon_sym__Atomic] = ACTIONS(1899),
    [anon_sym__Noreturn] = ACTIONS(1899),
    [anon_sym_noreturn] = ACTIONS(1899),
    [anon_sym_mutable] = ACTIONS(1899),
    [anon_sym_constinit] = ACTIONS(1899),
    [anon_sym_consteval] = ACTIONS(1899),
    [anon_sym_alignas] = ACTIONS(1899),
    [anon_sym__Alignas] = ACTIONS(1899),
    [sym_primitive_type] = ACTIONS(1899),
    [anon_sym_QMARK] = ACTIONS(1901),
    [anon_sym_LT_EQ_GT] = ACTIONS(1901),
    [anon_sym_or] = ACTIONS(1899),
    [anon_sym_and] = ACTIONS(1899),
    [anon_sym_bitor] = ACTIONS(1899),
    [anon_sym_xor] = ACTIONS(1899),
    [anon_sym_bitand] = ACTIONS(1899),
    [anon_sym_not_eq] = ACTIONS(1899),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DOT] = ACTIONS(1899),
    [anon_sym_DOT_STAR] = ACTIONS(1901),
    [anon_sym_DASH_GT] = ACTIONS(1901),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1899),
    [anon_sym_decltype] = ACTIONS(1899),
    [anon_sym_final] = ACTIONS(1899),
    [anon_sym_override] = ACTIONS(1899),
    [anon_sym_requires] = ACTIONS(1899),
  },
  [2427] = {
    [sym_identifier] = ACTIONS(1953),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1955),
    [anon_sym_COMMA] = ACTIONS(1955),
    [anon_sym_RPAREN] = ACTIONS(1955),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_DASH] = ACTIONS(1953),
    [anon_sym_PLUS] = ACTIONS(1953),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_SLASH] = ACTIONS(1953),
    [anon_sym_PERCENT] = ACTIONS(1955),
    [anon_sym_PIPE_PIPE] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_PIPE] = ACTIONS(1953),
    [anon_sym_CARET] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym_EQ_EQ] = ACTIONS(1955),
    [anon_sym_BANG_EQ] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1953),
    [anon_sym_GT_EQ] = ACTIONS(1955),
    [anon_sym_LT_EQ] = ACTIONS(1953),
    [anon_sym_LT] = ACTIONS(1953),
    [anon_sym_LT_LT] = ACTIONS(1955),
    [anon_sym_GT_GT] = ACTIONS(1955),
    [anon_sym_COLON] = ACTIONS(1953),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym___based] = ACTIONS(1953),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_RBRACE] = ACTIONS(1955),
    [anon_sym_signed] = ACTIONS(1953),
    [anon_sym_unsigned] = ACTIONS(1953),
    [anon_sym_long] = ACTIONS(1953),
    [anon_sym_short] = ACTIONS(1953),
    [anon_sym_LBRACK] = ACTIONS(1955),
    [anon_sym_RBRACK] = ACTIONS(1955),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [sym_primitive_type] = ACTIONS(1953),
    [anon_sym_QMARK] = ACTIONS(1955),
    [anon_sym_LT_EQ_GT] = ACTIONS(1955),
    [anon_sym_or] = ACTIONS(1953),
    [anon_sym_and] = ACTIONS(1953),
    [anon_sym_bitor] = ACTIONS(1953),
    [anon_sym_xor] = ACTIONS(1953),
    [anon_sym_bitand] = ACTIONS(1953),
    [anon_sym_not_eq] = ACTIONS(1953),
    [anon_sym_DASH_DASH] = ACTIONS(1955),
    [anon_sym_PLUS_PLUS] = ACTIONS(1955),
    [anon_sym_DOT] = ACTIONS(1953),
    [anon_sym_DOT_STAR] = ACTIONS(1955),
    [anon_sym_DASH_GT] = ACTIONS(1955),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
    [anon_sym_requires] = ACTIONS(1953),
  },
  [2428] = {
    [sym_identifier] = ACTIONS(1953),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1955),
    [anon_sym_COMMA] = ACTIONS(1955),
    [anon_sym_RPAREN] = ACTIONS(1955),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_DASH] = ACTIONS(1953),
    [anon_sym_PLUS] = ACTIONS(1953),
    [anon_sym_STAR] = ACTIONS(1955),
    [anon_sym_SLASH] = ACTIONS(1953),
    [anon_sym_PERCENT] = ACTIONS(1955),
    [anon_sym_PIPE_PIPE] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_PIPE] = ACTIONS(1953),
    [anon_sym_CARET] = ACTIONS(1955),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym_EQ_EQ] = ACTIONS(1955),
    [anon_sym_BANG_EQ] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1953),
    [anon_sym_GT_EQ] = ACTIONS(1955),
    [anon_sym_LT_EQ] = ACTIONS(1953),
    [anon_sym_LT] = ACTIONS(1953),
    [anon_sym_LT_LT] = ACTIONS(1955),
    [anon_sym_GT_GT] = ACTIONS(1955),
    [anon_sym_COLON] = ACTIONS(1953),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___extension__] = ACTIONS(1953),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym___based] = ACTIONS(1953),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_RBRACE] = ACTIONS(1955),
    [anon_sym_signed] = ACTIONS(1953),
    [anon_sym_unsigned] = ACTIONS(1953),
    [anon_sym_long] = ACTIONS(1953),
    [anon_sym_short] = ACTIONS(1953),
    [anon_sym_LBRACK] = ACTIONS(1955),
    [anon_sym_RBRACK] = ACTIONS(1955),
    [anon_sym_const] = ACTIONS(1953),
    [anon_sym_constexpr] = ACTIONS(1953),
    [anon_sym_volatile] = ACTIONS(1953),
    [anon_sym_restrict] = ACTIONS(1953),
    [anon_sym___restrict__] = ACTIONS(1953),
    [anon_sym__Atomic] = ACTIONS(1953),
    [anon_sym__Noreturn] = ACTIONS(1953),
    [anon_sym_noreturn] = ACTIONS(1953),
    [anon_sym_mutable] = ACTIONS(1953),
    [anon_sym_constinit] = ACTIONS(1953),
    [anon_sym_consteval] = ACTIONS(1953),
    [anon_sym_alignas] = ACTIONS(1953),
    [anon_sym__Alignas] = ACTIONS(1953),
    [sym_primitive_type] = ACTIONS(1953),
    [anon_sym_QMARK] = ACTIONS(1955),
    [anon_sym_LT_EQ_GT] = ACTIONS(1955),
    [anon_sym_or] = ACTIONS(1953),
    [anon_sym_and] = ACTIONS(1953),
    [anon_sym_bitor] = ACTIONS(1953),
    [anon_sym_xor] = ACTIONS(1953),
    [anon_sym_bitand] = ACTIONS(1953),
    [anon_sym_not_eq] = ACTIONS(1953),
    [anon_sym_DASH_DASH] = ACTIONS(1955),
    [anon_sym_PLUS_PLUS] = ACTIONS(1955),
    [anon_sym_DOT] = ACTIONS(1953),
    [anon_sym_DOT_STAR] = ACTIONS(1955),
    [anon_sym_DASH_GT] = ACTIONS(1955),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
    [anon_sym_requires] = ACTIONS(1953),
  },
  [2429] = {
    [sym_identifier] = ACTIONS(5318),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5320),
    [anon_sym_COMMA] = ACTIONS(5320),
    [anon_sym_RPAREN] = ACTIONS(5320),
    [anon_sym_LPAREN2] = ACTIONS(5320),
    [anon_sym_DASH] = ACTIONS(5318),
    [anon_sym_PLUS] = ACTIONS(5318),
    [anon_sym_STAR] = ACTIONS(5320),
    [anon_sym_SLASH] = ACTIONS(5318),
    [anon_sym_PERCENT] = ACTIONS(5320),
    [anon_sym_PIPE_PIPE] = ACTIONS(5320),
    [anon_sym_AMP_AMP] = ACTIONS(5320),
    [anon_sym_PIPE] = ACTIONS(5318),
    [anon_sym_CARET] = ACTIONS(5320),
    [anon_sym_AMP] = ACTIONS(5318),
    [anon_sym_EQ_EQ] = ACTIONS(5320),
    [anon_sym_BANG_EQ] = ACTIONS(5320),
    [anon_sym_GT] = ACTIONS(5318),
    [anon_sym_GT_EQ] = ACTIONS(5320),
    [anon_sym_LT_EQ] = ACTIONS(5318),
    [anon_sym_LT] = ACTIONS(5318),
    [anon_sym_LT_LT] = ACTIONS(5320),
    [anon_sym_GT_GT] = ACTIONS(5320),
    [anon_sym_COLON] = ACTIONS(5318),
    [anon_sym_SEMI] = ACTIONS(5320),
    [anon_sym___extension__] = ACTIONS(5318),
    [anon_sym___attribute__] = ACTIONS(5318),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym___based] = ACTIONS(5318),
    [anon_sym_LBRACE] = ACTIONS(5320),
    [anon_sym_RBRACE] = ACTIONS(5320),
    [anon_sym_signed] = ACTIONS(5318),
    [anon_sym_unsigned] = ACTIONS(5318),
    [anon_sym_long] = ACTIONS(5318),
    [anon_sym_short] = ACTIONS(5318),
    [anon_sym_LBRACK] = ACTIONS(5320),
    [anon_sym_RBRACK] = ACTIONS(5320),
    [anon_sym_const] = ACTIONS(5318),
    [anon_sym_constexpr] = ACTIONS(5318),
    [anon_sym_volatile] = ACTIONS(5318),
    [anon_sym_restrict] = ACTIONS(5318),
    [anon_sym___restrict__] = ACTIONS(5318),
    [anon_sym__Atomic] = ACTIONS(5318),
    [anon_sym__Noreturn] = ACTIONS(5318),
    [anon_sym_noreturn] = ACTIONS(5318),
    [anon_sym_mutable] = ACTIONS(5318),
    [anon_sym_constinit] = ACTIONS(5318),
    [anon_sym_consteval] = ACTIONS(5318),
    [anon_sym_alignas] = ACTIONS(5318),
    [anon_sym__Alignas] = ACTIONS(5318),
    [sym_primitive_type] = ACTIONS(5318),
    [anon_sym_QMARK] = ACTIONS(5320),
    [anon_sym_LT_EQ_GT] = ACTIONS(5320),
    [anon_sym_or] = ACTIONS(5318),
    [anon_sym_and] = ACTIONS(5318),
    [anon_sym_bitor] = ACTIONS(5318),
    [anon_sym_xor] = ACTIONS(5318),
    [anon_sym_bitand] = ACTIONS(5318),
    [anon_sym_not_eq] = ACTIONS(5318),
    [anon_sym_DASH_DASH] = ACTIONS(5320),
    [anon_sym_PLUS_PLUS] = ACTIONS(5320),
    [anon_sym_DOT] = ACTIONS(5318),
    [anon_sym_DOT_STAR] = ACTIONS(5320),
    [anon_sym_DASH_GT] = ACTIONS(5320),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5318),
    [anon_sym_decltype] = ACTIONS(5318),
    [anon_sym_final] = ACTIONS(5318),
    [anon_sym_override] = ACTIONS(5318),
    [anon_sym_requires] = ACTIONS(5318),
  },
  [2430] = {
    [sym_identifier] = ACTIONS(5391),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5393),
    [anon_sym_COMMA] = ACTIONS(5393),
    [anon_sym_RPAREN] = ACTIONS(5393),
    [anon_sym_LPAREN2] = ACTIONS(5393),
    [anon_sym_DASH] = ACTIONS(5391),
    [anon_sym_PLUS] = ACTIONS(5391),
    [anon_sym_STAR] = ACTIONS(5393),
    [anon_sym_SLASH] = ACTIONS(5391),
    [anon_sym_PERCENT] = ACTIONS(5393),
    [anon_sym_PIPE_PIPE] = ACTIONS(5393),
    [anon_sym_AMP_AMP] = ACTIONS(5393),
    [anon_sym_PIPE] = ACTIONS(5391),
    [anon_sym_CARET] = ACTIONS(5393),
    [anon_sym_AMP] = ACTIONS(5391),
    [anon_sym_EQ_EQ] = ACTIONS(5393),
    [anon_sym_BANG_EQ] = ACTIONS(5393),
    [anon_sym_GT] = ACTIONS(5391),
    [anon_sym_GT_EQ] = ACTIONS(5393),
    [anon_sym_LT_EQ] = ACTIONS(5391),
    [anon_sym_LT] = ACTIONS(5391),
    [anon_sym_LT_LT] = ACTIONS(5393),
    [anon_sym_GT_GT] = ACTIONS(5393),
    [anon_sym_COLON] = ACTIONS(5391),
    [anon_sym_SEMI] = ACTIONS(5393),
    [anon_sym___extension__] = ACTIONS(5391),
    [anon_sym___attribute__] = ACTIONS(5391),
    [anon_sym_COLON_COLON] = ACTIONS(5393),
    [anon_sym___based] = ACTIONS(5391),
    [anon_sym_LBRACE] = ACTIONS(5393),
    [anon_sym_RBRACE] = ACTIONS(5393),
    [anon_sym_signed] = ACTIONS(5391),
    [anon_sym_unsigned] = ACTIONS(5391),
    [anon_sym_long] = ACTIONS(5391),
    [anon_sym_short] = ACTIONS(5391),
    [anon_sym_LBRACK] = ACTIONS(5393),
    [anon_sym_RBRACK] = ACTIONS(5393),
    [anon_sym_const] = ACTIONS(5391),
    [anon_sym_constexpr] = ACTIONS(5391),
    [anon_sym_volatile] = ACTIONS(5391),
    [anon_sym_restrict] = ACTIONS(5391),
    [anon_sym___restrict__] = ACTIONS(5391),
    [anon_sym__Atomic] = ACTIONS(5391),
    [anon_sym__Noreturn] = ACTIONS(5391),
    [anon_sym_noreturn] = ACTIONS(5391),
    [anon_sym_mutable] = ACTIONS(5391),
    [anon_sym_constinit] = ACTIONS(5391),
    [anon_sym_consteval] = ACTIONS(5391),
    [anon_sym_alignas] = ACTIONS(5391),
    [anon_sym__Alignas] = ACTIONS(5391),
    [sym_primitive_type] = ACTIONS(5391),
    [anon_sym_QMARK] = ACTIONS(5393),
    [anon_sym_LT_EQ_GT] = ACTIONS(5393),
    [anon_sym_or] = ACTIONS(5391),
    [anon_sym_and] = ACTIONS(5391),
    [anon_sym_bitor] = ACTIONS(5391),
    [anon_sym_xor] = ACTIONS(5391),
    [anon_sym_bitand] = ACTIONS(5391),
    [anon_sym_not_eq] = ACTIONS(5391),
    [anon_sym_DASH_DASH] = ACTIONS(5393),
    [anon_sym_PLUS_PLUS] = ACTIONS(5393),
    [anon_sym_DOT] = ACTIONS(5391),
    [anon_sym_DOT_STAR] = ACTIONS(5393),
    [anon_sym_DASH_GT] = ACTIONS(5393),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5391),
    [anon_sym_decltype] = ACTIONS(5391),
    [anon_sym_final] = ACTIONS(5391),
    [anon_sym_override] = ACTIONS(5391),
    [anon_sym_requires] = ACTIONS(5391),
  },
  [2431] = {
    [sym_identifier] = ACTIONS(5318),
    [anon_sym_LPAREN2] = ACTIONS(5320),
    [anon_sym_TILDE] = ACTIONS(5320),
    [anon_sym_STAR] = ACTIONS(5320),
    [anon_sym_AMP_AMP] = ACTIONS(5320),
    [anon_sym_AMP] = ACTIONS(5318),
    [anon_sym_SEMI] = ACTIONS(1971),
    [anon_sym___extension__] = ACTIONS(5318),
    [anon_sym_in] = ACTIONS(5318),
    [anon_sym_out] = ACTIONS(5318),
    [anon_sym_inout] = ACTIONS(5318),
    [anon_sym_extern] = ACTIONS(5318),
    [anon_sym___attribute__] = ACTIONS(5318),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5320),
    [anon_sym___declspec] = ACTIONS(5318),
    [anon_sym___based] = ACTIONS(5318),
    [anon_sym___cdecl] = ACTIONS(5318),
    [anon_sym___clrcall] = ACTIONS(5318),
    [anon_sym___stdcall] = ACTIONS(5318),
    [anon_sym___fastcall] = ACTIONS(5318),
    [anon_sym___thiscall] = ACTIONS(5318),
    [anon_sym___vectorcall] = ACTIONS(5318),
    [anon_sym_LBRACK] = ACTIONS(5318),
    [anon_sym_static] = ACTIONS(5318),
    [anon_sym_register] = ACTIONS(5318),
    [anon_sym_inline] = ACTIONS(5318),
    [anon_sym___inline] = ACTIONS(5318),
    [anon_sym___inline__] = ACTIONS(5318),
    [anon_sym___forceinline] = ACTIONS(5318),
    [anon_sym_thread_local] = ACTIONS(5318),
    [anon_sym___thread] = ACTIONS(5318),
    [anon_sym_const] = ACTIONS(5318),
    [anon_sym_constexpr] = ACTIONS(5318),
    [anon_sym_volatile] = ACTIONS(5318),
    [anon_sym_restrict] = ACTIONS(5318),
    [anon_sym___restrict__] = ACTIONS(5318),
    [anon_sym__Atomic] = ACTIONS(5318),
    [anon_sym__Noreturn] = ACTIONS(5318),
    [anon_sym_noreturn] = ACTIONS(5318),
    [anon_sym_mutable] = ACTIONS(5318),
    [anon_sym_constinit] = ACTIONS(5318),
    [anon_sym_consteval] = ACTIONS(5318),
    [anon_sym_alignas] = ACTIONS(5318),
    [anon_sym__Alignas] = ACTIONS(5318),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5318),
    [anon_sym_decltype] = ACTIONS(5318),
    [sym_virtual] = ACTIONS(5318),
    [anon_sym_template] = ACTIONS(5318),
    [anon_sym_operator] = ACTIONS(5318),
    [anon_sym_precise] = ACTIONS(5318),
    [anon_sym_shared] = ACTIONS(5318),
    [anon_sym_groupshared] = ACTIONS(5318),
    [anon_sym_uniform] = ACTIONS(5318),
    [anon_sym_row_major] = ACTIONS(5318),
    [anon_sym_column_major] = ACTIONS(5318),
    [anon_sym_globallycoherent] = ACTIONS(5318),
    [anon_sym_centroid] = ACTIONS(5318),
    [anon_sym_noperspective] = ACTIONS(5318),
    [anon_sym_nointerpolation] = ACTIONS(5318),
    [anon_sym_sample] = ACTIONS(5318),
    [anon_sym_linear] = ACTIONS(5318),
    [anon_sym_snorm] = ACTIONS(5318),
    [anon_sym_unorm] = ACTIONS(5318),
    [anon_sym_point] = ACTIONS(5318),
    [anon_sym_line] = ACTIONS(5318),
    [anon_sym_triangleadj] = ACTIONS(5318),
    [anon_sym_lineadj] = ACTIONS(5318),
    [anon_sym_triangle] = ACTIONS(5318),
  },
  [2432] = {
    [sym_identifier] = ACTIONS(5318),
    [anon_sym_LPAREN2] = ACTIONS(5320),
    [anon_sym_TILDE] = ACTIONS(5320),
    [anon_sym_STAR] = ACTIONS(5320),
    [anon_sym_AMP_AMP] = ACTIONS(5320),
    [anon_sym_AMP] = ACTIONS(5318),
    [anon_sym_SEMI] = ACTIONS(1971),
    [anon_sym___extension__] = ACTIONS(5318),
    [anon_sym_in] = ACTIONS(5318),
    [anon_sym_out] = ACTIONS(5318),
    [anon_sym_inout] = ACTIONS(5318),
    [anon_sym_extern] = ACTIONS(5318),
    [anon_sym___attribute__] = ACTIONS(5318),
    [anon_sym_COLON_COLON] = ACTIONS(5320),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5320),
    [anon_sym___declspec] = ACTIONS(5318),
    [anon_sym___based] = ACTIONS(5318),
    [anon_sym___cdecl] = ACTIONS(5318),
    [anon_sym___clrcall] = ACTIONS(5318),
    [anon_sym___stdcall] = ACTIONS(5318),
    [anon_sym___fastcall] = ACTIONS(5318),
    [anon_sym___thiscall] = ACTIONS(5318),
    [anon_sym___vectorcall] = ACTIONS(5318),
    [anon_sym_LBRACK] = ACTIONS(5318),
    [anon_sym_static] = ACTIONS(5318),
    [anon_sym_register] = ACTIONS(5318),
    [anon_sym_inline] = ACTIONS(5318),
    [anon_sym___inline] = ACTIONS(5318),
    [anon_sym___inline__] = ACTIONS(5318),
    [anon_sym___forceinline] = ACTIONS(5318),
    [anon_sym_thread_local] = ACTIONS(5318),
    [anon_sym___thread] = ACTIONS(5318),
    [anon_sym_const] = ACTIONS(5318),
    [anon_sym_constexpr] = ACTIONS(5318),
    [anon_sym_volatile] = ACTIONS(5318),
    [anon_sym_restrict] = ACTIONS(5318),
    [anon_sym___restrict__] = ACTIONS(5318),
    [anon_sym__Atomic] = ACTIONS(5318),
    [anon_sym__Noreturn] = ACTIONS(5318),
    [anon_sym_noreturn] = ACTIONS(5318),
    [anon_sym_mutable] = ACTIONS(5318),
    [anon_sym_constinit] = ACTIONS(5318),
    [anon_sym_consteval] = ACTIONS(5318),
    [anon_sym_alignas] = ACTIONS(5318),
    [anon_sym__Alignas] = ACTIONS(5318),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5318),
    [anon_sym_decltype] = ACTIONS(5318),
    [sym_virtual] = ACTIONS(5318),
    [anon_sym_template] = ACTIONS(5318),
    [anon_sym_operator] = ACTIONS(5318),
    [anon_sym_precise] = ACTIONS(5318),
    [anon_sym_shared] = ACTIONS(5318),
    [anon_sym_groupshared] = ACTIONS(5318),
    [anon_sym_uniform] = ACTIONS(5318),
    [anon_sym_row_major] = ACTIONS(5318),
    [anon_sym_column_major] = ACTIONS(5318),
    [anon_sym_globallycoherent] = ACTIONS(5318),
    [anon_sym_centroid] = ACTIONS(5318),
    [anon_sym_noperspective] = ACTIONS(5318),
    [anon_sym_nointerpolation] = ACTIONS(5318),
    [anon_sym_sample] = ACTIONS(5318),
    [anon_sym_linear] = ACTIONS(5318),
    [anon_sym_snorm] = ACTIONS(5318),
    [anon_sym_unorm] = ACTIONS(5318),
    [anon_sym_point] = ACTIONS(5318),
    [anon_sym_line] = ACTIONS(5318),
    [anon_sym_triangleadj] = ACTIONS(5318),
    [anon_sym_lineadj] = ACTIONS(5318),
    [anon_sym_triangle] = ACTIONS(5318),
  },
  [2433] = {
    [sym_identifier] = ACTIONS(1959),
    [anon_sym_LPAREN2] = ACTIONS(4060),
    [anon_sym_TILDE] = ACTIONS(1961),
    [anon_sym_STAR] = ACTIONS(1961),
    [anon_sym_AMP_AMP] = ACTIONS(1961),
    [anon_sym_AMP] = ACTIONS(1959),
    [anon_sym_SEMI] = ACTIONS(1961),
    [anon_sym___extension__] = ACTIONS(1959),
    [anon_sym_in] = ACTIONS(1959),
    [anon_sym_out] = ACTIONS(1959),
    [anon_sym_inout] = ACTIONS(1959),
    [anon_sym_extern] = ACTIONS(1959),
    [anon_sym___attribute__] = ACTIONS(1959),
    [anon_sym_COLON_COLON] = ACTIONS(1961),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4060),
    [anon_sym___declspec] = ACTIONS(1959),
    [anon_sym___based] = ACTIONS(1959),
    [anon_sym___cdecl] = ACTIONS(1959),
    [anon_sym___clrcall] = ACTIONS(1959),
    [anon_sym___stdcall] = ACTIONS(1959),
    [anon_sym___fastcall] = ACTIONS(1959),
    [anon_sym___thiscall] = ACTIONS(1959),
    [anon_sym___vectorcall] = ACTIONS(1959),
    [anon_sym_LBRACK] = ACTIONS(4065),
    [anon_sym_static] = ACTIONS(1959),
    [anon_sym_register] = ACTIONS(1959),
    [anon_sym_inline] = ACTIONS(1959),
    [anon_sym___inline] = ACTIONS(1959),
    [anon_sym___inline__] = ACTIONS(1959),
    [anon_sym___forceinline] = ACTIONS(1959),
    [anon_sym_thread_local] = ACTIONS(1959),
    [anon_sym___thread] = ACTIONS(1959),
    [anon_sym_const] = ACTIONS(1959),
    [anon_sym_constexpr] = ACTIONS(1959),
    [anon_sym_volatile] = ACTIONS(1959),
    [anon_sym_restrict] = ACTIONS(1959),
    [anon_sym___restrict__] = ACTIONS(1959),
    [anon_sym__Atomic] = ACTIONS(1959),
    [anon_sym__Noreturn] = ACTIONS(1959),
    [anon_sym_noreturn] = ACTIONS(1959),
    [anon_sym_mutable] = ACTIONS(1959),
    [anon_sym_constinit] = ACTIONS(1959),
    [anon_sym_consteval] = ACTIONS(1959),
    [anon_sym_alignas] = ACTIONS(1959),
    [anon_sym__Alignas] = ACTIONS(1959),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1959),
    [anon_sym_decltype] = ACTIONS(1959),
    [sym_virtual] = ACTIONS(1959),
    [anon_sym_template] = ACTIONS(1959),
    [anon_sym_operator] = ACTIONS(1959),
    [anon_sym_precise] = ACTIONS(1959),
    [anon_sym_shared] = ACTIONS(1959),
    [anon_sym_groupshared] = ACTIONS(1959),
    [anon_sym_uniform] = ACTIONS(1959),
    [anon_sym_row_major] = ACTIONS(1959),
    [anon_sym_column_major] = ACTIONS(1959),
    [anon_sym_globallycoherent] = ACTIONS(1959),
    [anon_sym_centroid] = ACTIONS(1959),
    [anon_sym_noperspective] = ACTIONS(1959),
    [anon_sym_nointerpolation] = ACTIONS(1959),
    [anon_sym_sample] = ACTIONS(1959),
    [anon_sym_linear] = ACTIONS(1959),
    [anon_sym_snorm] = ACTIONS(1959),
    [anon_sym_unorm] = ACTIONS(1959),
    [anon_sym_point] = ACTIONS(1959),
    [anon_sym_line] = ACTIONS(1959),
    [anon_sym_triangleadj] = ACTIONS(1959),
    [anon_sym_lineadj] = ACTIONS(1959),
    [anon_sym_triangle] = ACTIONS(1959),
  },
  [2434] = {
    [sym_identifier] = ACTIONS(5463),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5465),
    [anon_sym_COMMA] = ACTIONS(5465),
    [anon_sym_RPAREN] = ACTIONS(5465),
    [anon_sym_LPAREN2] = ACTIONS(5465),
    [anon_sym_DASH] = ACTIONS(5463),
    [anon_sym_PLUS] = ACTIONS(5463),
    [anon_sym_STAR] = ACTIONS(5465),
    [anon_sym_SLASH] = ACTIONS(5463),
    [anon_sym_PERCENT] = ACTIONS(5465),
    [anon_sym_PIPE_PIPE] = ACTIONS(5465),
    [anon_sym_AMP_AMP] = ACTIONS(5465),
    [anon_sym_PIPE] = ACTIONS(5463),
    [anon_sym_CARET] = ACTIONS(5465),
    [anon_sym_AMP] = ACTIONS(5463),
    [anon_sym_EQ_EQ] = ACTIONS(5465),
    [anon_sym_BANG_EQ] = ACTIONS(5465),
    [anon_sym_GT] = ACTIONS(5463),
    [anon_sym_GT_EQ] = ACTIONS(5465),
    [anon_sym_LT_EQ] = ACTIONS(5463),
    [anon_sym_LT] = ACTIONS(5463),
    [anon_sym_LT_LT] = ACTIONS(5465),
    [anon_sym_GT_GT] = ACTIONS(5465),
    [anon_sym_COLON] = ACTIONS(5465),
    [anon_sym_SEMI] = ACTIONS(5465),
    [anon_sym___extension__] = ACTIONS(5463),
    [anon_sym___attribute__] = ACTIONS(5463),
    [anon_sym___based] = ACTIONS(5463),
    [anon_sym_LBRACE] = ACTIONS(5465),
    [anon_sym_RBRACE] = ACTIONS(5465),
    [anon_sym_signed] = ACTIONS(5463),
    [anon_sym_unsigned] = ACTIONS(5463),
    [anon_sym_long] = ACTIONS(5463),
    [anon_sym_short] = ACTIONS(5463),
    [anon_sym_LBRACK] = ACTIONS(5465),
    [anon_sym_RBRACK] = ACTIONS(5465),
    [anon_sym_const] = ACTIONS(5463),
    [anon_sym_constexpr] = ACTIONS(5463),
    [anon_sym_volatile] = ACTIONS(5463),
    [anon_sym_restrict] = ACTIONS(5463),
    [anon_sym___restrict__] = ACTIONS(5463),
    [anon_sym__Atomic] = ACTIONS(5463),
    [anon_sym__Noreturn] = ACTIONS(5463),
    [anon_sym_noreturn] = ACTIONS(5463),
    [anon_sym_mutable] = ACTIONS(5463),
    [anon_sym_constinit] = ACTIONS(5463),
    [anon_sym_consteval] = ACTIONS(5463),
    [anon_sym_alignas] = ACTIONS(5463),
    [anon_sym__Alignas] = ACTIONS(5463),
    [sym_primitive_type] = ACTIONS(5463),
    [anon_sym_QMARK] = ACTIONS(5465),
    [anon_sym_LT_EQ_GT] = ACTIONS(5465),
    [anon_sym_or] = ACTIONS(5463),
    [anon_sym_and] = ACTIONS(5463),
    [anon_sym_bitor] = ACTIONS(5463),
    [anon_sym_xor] = ACTIONS(5463),
    [anon_sym_bitand] = ACTIONS(5463),
    [anon_sym_not_eq] = ACTIONS(5463),
    [anon_sym_DASH_DASH] = ACTIONS(5465),
    [anon_sym_PLUS_PLUS] = ACTIONS(5465),
    [anon_sym_DOT] = ACTIONS(5463),
    [anon_sym_DOT_STAR] = ACTIONS(5465),
    [anon_sym_DASH_GT] = ACTIONS(5465),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5463),
    [anon_sym_decltype] = ACTIONS(5463),
    [anon_sym_final] = ACTIONS(5463),
    [anon_sym_override] = ACTIONS(5463),
    [anon_sym_requires] = ACTIONS(5463),
  },
  [2435] = {
    [sym_identifier] = ACTIONS(2849),
    [anon_sym_LPAREN2] = ACTIONS(2851),
    [anon_sym_BANG] = ACTIONS(2851),
    [anon_sym_TILDE] = ACTIONS(2851),
    [anon_sym_DASH] = ACTIONS(2849),
    [anon_sym_PLUS] = ACTIONS(2849),
    [anon_sym_STAR] = ACTIONS(2851),
    [anon_sym_AMP] = ACTIONS(2851),
    [anon_sym___extension__] = ACTIONS(2849),
    [anon_sym_COLON_COLON] = ACTIONS(2851),
    [anon_sym_LBRACK] = ACTIONS(2851),
    [anon_sym_static] = ACTIONS(2849),
    [anon_sym_RBRACK] = ACTIONS(2851),
    [anon_sym_const] = ACTIONS(2849),
    [anon_sym_constexpr] = ACTIONS(2849),
    [anon_sym_volatile] = ACTIONS(2849),
    [anon_sym_restrict] = ACTIONS(2849),
    [anon_sym___restrict__] = ACTIONS(2849),
    [anon_sym__Atomic] = ACTIONS(2849),
    [anon_sym__Noreturn] = ACTIONS(2849),
    [anon_sym_noreturn] = ACTIONS(2849),
    [anon_sym_mutable] = ACTIONS(2849),
    [anon_sym_constinit] = ACTIONS(2849),
    [anon_sym_consteval] = ACTIONS(2849),
    [anon_sym_alignas] = ACTIONS(2849),
    [anon_sym__Alignas] = ACTIONS(2849),
    [sym_primitive_type] = ACTIONS(2849),
    [anon_sym_not] = ACTIONS(2849),
    [anon_sym_compl] = ACTIONS(2849),
    [anon_sym_DASH_DASH] = ACTIONS(2851),
    [anon_sym_PLUS_PLUS] = ACTIONS(2851),
    [anon_sym_sizeof] = ACTIONS(2849),
    [anon_sym___alignof__] = ACTIONS(2849),
    [anon_sym___alignof] = ACTIONS(2849),
    [anon_sym__alignof] = ACTIONS(2849),
    [anon_sym_alignof] = ACTIONS(2849),
    [anon_sym__Alignof] = ACTIONS(2849),
    [anon_sym_offsetof] = ACTIONS(2849),
    [anon_sym__Generic] = ACTIONS(2849),
    [anon_sym_asm] = ACTIONS(2849),
    [anon_sym___asm__] = ACTIONS(2849),
    [sym_number_literal] = ACTIONS(2851),
    [anon_sym_L_SQUOTE] = ACTIONS(2851),
    [anon_sym_u_SQUOTE] = ACTIONS(2851),
    [anon_sym_U_SQUOTE] = ACTIONS(2851),
    [anon_sym_u8_SQUOTE] = ACTIONS(2851),
    [anon_sym_SQUOTE] = ACTIONS(2851),
    [anon_sym_L_DQUOTE] = ACTIONS(2851),
    [anon_sym_u_DQUOTE] = ACTIONS(2851),
    [anon_sym_U_DQUOTE] = ACTIONS(2851),
    [anon_sym_u8_DQUOTE] = ACTIONS(2851),
    [anon_sym_DQUOTE] = ACTIONS(2851),
    [sym_true] = ACTIONS(2849),
    [sym_false] = ACTIONS(2849),
    [anon_sym_NULL] = ACTIONS(2849),
    [anon_sym_nullptr] = ACTIONS(2849),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2849),
    [anon_sym_template] = ACTIONS(2849),
    [anon_sym_delete] = ACTIONS(2849),
    [anon_sym_R_DQUOTE] = ACTIONS(2851),
    [anon_sym_LR_DQUOTE] = ACTIONS(2851),
    [anon_sym_uR_DQUOTE] = ACTIONS(2851),
    [anon_sym_UR_DQUOTE] = ACTIONS(2851),
    [anon_sym_u8R_DQUOTE] = ACTIONS(2851),
    [anon_sym_co_await] = ACTIONS(2849),
    [anon_sym_new] = ACTIONS(2849),
    [anon_sym_requires] = ACTIONS(2849),
    [sym_this] = ACTIONS(2849),
  },
  [2436] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4060),
    [anon_sym_COMMA] = ACTIONS(4060),
    [anon_sym_LPAREN2] = ACTIONS(4060),
    [anon_sym_DASH] = ACTIONS(4063),
    [anon_sym_PLUS] = ACTIONS(4063),
    [anon_sym_STAR] = ACTIONS(4065),
    [anon_sym_SLASH] = ACTIONS(4063),
    [anon_sym_PERCENT] = ACTIONS(4063),
    [anon_sym_PIPE_PIPE] = ACTIONS(4058),
    [anon_sym_AMP_AMP] = ACTIONS(4060),
    [anon_sym_PIPE] = ACTIONS(4063),
    [anon_sym_CARET] = ACTIONS(4063),
    [anon_sym_AMP] = ACTIONS(4065),
    [anon_sym_EQ_EQ] = ACTIONS(4058),
    [anon_sym_BANG_EQ] = ACTIONS(4058),
    [anon_sym_GT] = ACTIONS(4063),
    [anon_sym_GT_EQ] = ACTIONS(4063),
    [anon_sym_LT_EQ] = ACTIONS(4063),
    [anon_sym_LT] = ACTIONS(4063),
    [anon_sym_LT_LT] = ACTIONS(4063),
    [anon_sym_GT_GT] = ACTIONS(4063),
    [anon_sym___extension__] = ACTIONS(1961),
    [anon_sym_COLON_COLON] = ACTIONS(1961),
    [anon_sym_LBRACE] = ACTIONS(1961),
    [anon_sym_LBRACK] = ACTIONS(4060),
    [anon_sym_EQ] = ACTIONS(4063),
    [anon_sym_const] = ACTIONS(1959),
    [anon_sym_constexpr] = ACTIONS(1961),
    [anon_sym_volatile] = ACTIONS(1961),
    [anon_sym_restrict] = ACTIONS(1961),
    [anon_sym___restrict__] = ACTIONS(1961),
    [anon_sym__Atomic] = ACTIONS(1961),
    [anon_sym__Noreturn] = ACTIONS(1961),
    [anon_sym_noreturn] = ACTIONS(1961),
    [anon_sym_mutable] = ACTIONS(1961),
    [anon_sym_constinit] = ACTIONS(1961),
    [anon_sym_consteval] = ACTIONS(1961),
    [anon_sym_alignas] = ACTIONS(1961),
    [anon_sym__Alignas] = ACTIONS(1961),
    [anon_sym_QMARK] = ACTIONS(4058),
    [anon_sym_STAR_EQ] = ACTIONS(4058),
    [anon_sym_SLASH_EQ] = ACTIONS(4058),
    [anon_sym_PERCENT_EQ] = ACTIONS(4058),
    [anon_sym_PLUS_EQ] = ACTIONS(4058),
    [anon_sym_DASH_EQ] = ACTIONS(4058),
    [anon_sym_LT_LT_EQ] = ACTIONS(4058),
    [anon_sym_GT_GT_EQ] = ACTIONS(4063),
    [anon_sym_AMP_EQ] = ACTIONS(4058),
    [anon_sym_CARET_EQ] = ACTIONS(4058),
    [anon_sym_PIPE_EQ] = ACTIONS(4058),
    [anon_sym_and_eq] = ACTIONS(4058),
    [anon_sym_or_eq] = ACTIONS(4058),
    [anon_sym_xor_eq] = ACTIONS(4058),
    [anon_sym_LT_EQ_GT] = ACTIONS(4058),
    [anon_sym_or] = ACTIONS(4063),
    [anon_sym_and] = ACTIONS(4063),
    [anon_sym_bitor] = ACTIONS(4058),
    [anon_sym_xor] = ACTIONS(4063),
    [anon_sym_bitand] = ACTIONS(4058),
    [anon_sym_not_eq] = ACTIONS(4058),
    [anon_sym_DASH_DASH] = ACTIONS(4058),
    [anon_sym_PLUS_PLUS] = ACTIONS(4058),
    [anon_sym_DOT] = ACTIONS(4063),
    [anon_sym_DOT_STAR] = ACTIONS(4058),
    [anon_sym_DASH_GT] = ACTIONS(4058),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1961),
    [anon_sym_decltype] = ACTIONS(1961),
    [anon_sym_GT2] = ACTIONS(4060),
  },
  [2437] = {
    [sym_identifier] = ACTIONS(5467),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5469),
    [anon_sym_COMMA] = ACTIONS(5469),
    [anon_sym_RPAREN] = ACTIONS(5469),
    [anon_sym_LPAREN2] = ACTIONS(5469),
    [anon_sym_DASH] = ACTIONS(5467),
    [anon_sym_PLUS] = ACTIONS(5467),
    [anon_sym_STAR] = ACTIONS(5469),
    [anon_sym_SLASH] = ACTIONS(5467),
    [anon_sym_PERCENT] = ACTIONS(5469),
    [anon_sym_PIPE_PIPE] = ACTIONS(5469),
    [anon_sym_AMP_AMP] = ACTIONS(5469),
    [anon_sym_PIPE] = ACTIONS(5467),
    [anon_sym_CARET] = ACTIONS(5469),
    [anon_sym_AMP] = ACTIONS(5467),
    [anon_sym_EQ_EQ] = ACTIONS(5469),
    [anon_sym_BANG_EQ] = ACTIONS(5469),
    [anon_sym_GT] = ACTIONS(5467),
    [anon_sym_GT_EQ] = ACTIONS(5469),
    [anon_sym_LT_EQ] = ACTIONS(5467),
    [anon_sym_LT] = ACTIONS(5467),
    [anon_sym_LT_LT] = ACTIONS(5469),
    [anon_sym_GT_GT] = ACTIONS(5469),
    [anon_sym_COLON] = ACTIONS(5469),
    [anon_sym_SEMI] = ACTIONS(5469),
    [anon_sym___extension__] = ACTIONS(5467),
    [anon_sym___attribute__] = ACTIONS(5467),
    [anon_sym___based] = ACTIONS(5467),
    [anon_sym_LBRACE] = ACTIONS(5469),
    [anon_sym_RBRACE] = ACTIONS(5469),
    [anon_sym_signed] = ACTIONS(5467),
    [anon_sym_unsigned] = ACTIONS(5467),
    [anon_sym_long] = ACTIONS(5467),
    [anon_sym_short] = ACTIONS(5467),
    [anon_sym_LBRACK] = ACTIONS(5469),
    [anon_sym_RBRACK] = ACTIONS(5469),
    [anon_sym_const] = ACTIONS(5467),
    [anon_sym_constexpr] = ACTIONS(5467),
    [anon_sym_volatile] = ACTIONS(5467),
    [anon_sym_restrict] = ACTIONS(5467),
    [anon_sym___restrict__] = ACTIONS(5467),
    [anon_sym__Atomic] = ACTIONS(5467),
    [anon_sym__Noreturn] = ACTIONS(5467),
    [anon_sym_noreturn] = ACTIONS(5467),
    [anon_sym_mutable] = ACTIONS(5467),
    [anon_sym_constinit] = ACTIONS(5467),
    [anon_sym_consteval] = ACTIONS(5467),
    [anon_sym_alignas] = ACTIONS(5467),
    [anon_sym__Alignas] = ACTIONS(5467),
    [sym_primitive_type] = ACTIONS(5467),
    [anon_sym_QMARK] = ACTIONS(5469),
    [anon_sym_LT_EQ_GT] = ACTIONS(5469),
    [anon_sym_or] = ACTIONS(5467),
    [anon_sym_and] = ACTIONS(5467),
    [anon_sym_bitor] = ACTIONS(5467),
    [anon_sym_xor] = ACTIONS(5467),
    [anon_sym_bitand] = ACTIONS(5467),
    [anon_sym_not_eq] = ACTIONS(5467),
    [anon_sym_DASH_DASH] = ACTIONS(5469),
    [anon_sym_PLUS_PLUS] = ACTIONS(5469),
    [anon_sym_DOT] = ACTIONS(5467),
    [anon_sym_DOT_STAR] = ACTIONS(5469),
    [anon_sym_DASH_GT] = ACTIONS(5469),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5467),
    [anon_sym_decltype] = ACTIONS(5467),
    [anon_sym_final] = ACTIONS(5467),
    [anon_sym_override] = ACTIONS(5467),
    [anon_sym_requires] = ACTIONS(5467),
  },
  [2438] = {
    [sym_identifier] = ACTIONS(5423),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5425),
    [anon_sym_COMMA] = ACTIONS(5425),
    [anon_sym_RPAREN] = ACTIONS(5425),
    [anon_sym_LPAREN2] = ACTIONS(5425),
    [anon_sym_DASH] = ACTIONS(5423),
    [anon_sym_PLUS] = ACTIONS(5423),
    [anon_sym_STAR] = ACTIONS(5425),
    [anon_sym_SLASH] = ACTIONS(5423),
    [anon_sym_PERCENT] = ACTIONS(5425),
    [anon_sym_PIPE_PIPE] = ACTIONS(5425),
    [anon_sym_AMP_AMP] = ACTIONS(5425),
    [anon_sym_PIPE] = ACTIONS(5423),
    [anon_sym_CARET] = ACTIONS(5425),
    [anon_sym_AMP] = ACTIONS(5423),
    [anon_sym_EQ_EQ] = ACTIONS(5425),
    [anon_sym_BANG_EQ] = ACTIONS(5425),
    [anon_sym_GT] = ACTIONS(5423),
    [anon_sym_GT_EQ] = ACTIONS(5425),
    [anon_sym_LT_EQ] = ACTIONS(5423),
    [anon_sym_LT] = ACTIONS(5423),
    [anon_sym_LT_LT] = ACTIONS(5425),
    [anon_sym_GT_GT] = ACTIONS(5425),
    [anon_sym_COLON] = ACTIONS(5425),
    [anon_sym_SEMI] = ACTIONS(5425),
    [anon_sym___extension__] = ACTIONS(5423),
    [anon_sym___attribute__] = ACTIONS(5423),
    [anon_sym___based] = ACTIONS(5423),
    [anon_sym_LBRACE] = ACTIONS(5425),
    [anon_sym_RBRACE] = ACTIONS(5425),
    [anon_sym_signed] = ACTIONS(5423),
    [anon_sym_unsigned] = ACTIONS(5423),
    [anon_sym_long] = ACTIONS(5423),
    [anon_sym_short] = ACTIONS(5423),
    [anon_sym_LBRACK] = ACTIONS(5425),
    [anon_sym_RBRACK] = ACTIONS(5425),
    [anon_sym_const] = ACTIONS(5423),
    [anon_sym_constexpr] = ACTIONS(5423),
    [anon_sym_volatile] = ACTIONS(5423),
    [anon_sym_restrict] = ACTIONS(5423),
    [anon_sym___restrict__] = ACTIONS(5423),
    [anon_sym__Atomic] = ACTIONS(5423),
    [anon_sym__Noreturn] = ACTIONS(5423),
    [anon_sym_noreturn] = ACTIONS(5423),
    [anon_sym_mutable] = ACTIONS(5423),
    [anon_sym_constinit] = ACTIONS(5423),
    [anon_sym_consteval] = ACTIONS(5423),
    [anon_sym_alignas] = ACTIONS(5423),
    [anon_sym__Alignas] = ACTIONS(5423),
    [sym_primitive_type] = ACTIONS(5423),
    [anon_sym_QMARK] = ACTIONS(5425),
    [anon_sym_LT_EQ_GT] = ACTIONS(5425),
    [anon_sym_or] = ACTIONS(5423),
    [anon_sym_and] = ACTIONS(5423),
    [anon_sym_bitor] = ACTIONS(5423),
    [anon_sym_xor] = ACTIONS(5423),
    [anon_sym_bitand] = ACTIONS(5423),
    [anon_sym_not_eq] = ACTIONS(5423),
    [anon_sym_DASH_DASH] = ACTIONS(5425),
    [anon_sym_PLUS_PLUS] = ACTIONS(5425),
    [anon_sym_DOT] = ACTIONS(5423),
    [anon_sym_DOT_STAR] = ACTIONS(5425),
    [anon_sym_DASH_GT] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5423),
    [anon_sym_decltype] = ACTIONS(5423),
    [anon_sym_final] = ACTIONS(5423),
    [anon_sym_override] = ACTIONS(5423),
    [anon_sym_requires] = ACTIONS(5423),
  },
  [2439] = {
    [sym_identifier] = ACTIONS(5541),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5543),
    [anon_sym_COMMA] = ACTIONS(5543),
    [anon_sym_RPAREN] = ACTIONS(5543),
    [anon_sym_LPAREN2] = ACTIONS(5543),
    [anon_sym_DASH] = ACTIONS(5541),
    [anon_sym_PLUS] = ACTIONS(5541),
    [anon_sym_STAR] = ACTIONS(5543),
    [anon_sym_SLASH] = ACTIONS(5541),
    [anon_sym_PERCENT] = ACTIONS(5543),
    [anon_sym_PIPE_PIPE] = ACTIONS(5543),
    [anon_sym_AMP_AMP] = ACTIONS(5543),
    [anon_sym_PIPE] = ACTIONS(5541),
    [anon_sym_CARET] = ACTIONS(5543),
    [anon_sym_AMP] = ACTIONS(5541),
    [anon_sym_EQ_EQ] = ACTIONS(5543),
    [anon_sym_BANG_EQ] = ACTIONS(5543),
    [anon_sym_GT] = ACTIONS(5541),
    [anon_sym_GT_EQ] = ACTIONS(5543),
    [anon_sym_LT_EQ] = ACTIONS(5541),
    [anon_sym_LT] = ACTIONS(5541),
    [anon_sym_LT_LT] = ACTIONS(5543),
    [anon_sym_GT_GT] = ACTIONS(5543),
    [anon_sym_COLON] = ACTIONS(5543),
    [anon_sym_SEMI] = ACTIONS(5543),
    [anon_sym___extension__] = ACTIONS(5541),
    [anon_sym___attribute__] = ACTIONS(5541),
    [anon_sym___based] = ACTIONS(5541),
    [anon_sym_LBRACE] = ACTIONS(5543),
    [anon_sym_RBRACE] = ACTIONS(5543),
    [anon_sym_signed] = ACTIONS(5541),
    [anon_sym_unsigned] = ACTIONS(5541),
    [anon_sym_long] = ACTIONS(5541),
    [anon_sym_short] = ACTIONS(5541),
    [anon_sym_LBRACK] = ACTIONS(5543),
    [anon_sym_RBRACK] = ACTIONS(5543),
    [anon_sym_const] = ACTIONS(5541),
    [anon_sym_constexpr] = ACTIONS(5541),
    [anon_sym_volatile] = ACTIONS(5541),
    [anon_sym_restrict] = ACTIONS(5541),
    [anon_sym___restrict__] = ACTIONS(5541),
    [anon_sym__Atomic] = ACTIONS(5541),
    [anon_sym__Noreturn] = ACTIONS(5541),
    [anon_sym_noreturn] = ACTIONS(5541),
    [anon_sym_mutable] = ACTIONS(5541),
    [anon_sym_constinit] = ACTIONS(5541),
    [anon_sym_consteval] = ACTIONS(5541),
    [anon_sym_alignas] = ACTIONS(5541),
    [anon_sym__Alignas] = ACTIONS(5541),
    [sym_primitive_type] = ACTIONS(5541),
    [anon_sym_QMARK] = ACTIONS(5543),
    [anon_sym_LT_EQ_GT] = ACTIONS(5543),
    [anon_sym_or] = ACTIONS(5541),
    [anon_sym_and] = ACTIONS(5541),
    [anon_sym_bitor] = ACTIONS(5541),
    [anon_sym_xor] = ACTIONS(5541),
    [anon_sym_bitand] = ACTIONS(5541),
    [anon_sym_not_eq] = ACTIONS(5541),
    [anon_sym_DASH_DASH] = ACTIONS(5543),
    [anon_sym_PLUS_PLUS] = ACTIONS(5543),
    [anon_sym_DOT] = ACTIONS(5541),
    [anon_sym_DOT_STAR] = ACTIONS(5543),
    [anon_sym_DASH_GT] = ACTIONS(5543),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5541),
    [anon_sym_decltype] = ACTIONS(5541),
    [anon_sym_final] = ACTIONS(5541),
    [anon_sym_override] = ACTIONS(5541),
    [anon_sym_requires] = ACTIONS(5541),
  },
  [2440] = {
    [sym_identifier] = ACTIONS(5507),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5509),
    [anon_sym_COMMA] = ACTIONS(5509),
    [anon_sym_RPAREN] = ACTIONS(5509),
    [anon_sym_LPAREN2] = ACTIONS(5509),
    [anon_sym_DASH] = ACTIONS(5507),
    [anon_sym_PLUS] = ACTIONS(5507),
    [anon_sym_STAR] = ACTIONS(5509),
    [anon_sym_SLASH] = ACTIONS(5507),
    [anon_sym_PERCENT] = ACTIONS(5509),
    [anon_sym_PIPE_PIPE] = ACTIONS(5509),
    [anon_sym_AMP_AMP] = ACTIONS(5509),
    [anon_sym_PIPE] = ACTIONS(5507),
    [anon_sym_CARET] = ACTIONS(5509),
    [anon_sym_AMP] = ACTIONS(5507),
    [anon_sym_EQ_EQ] = ACTIONS(5509),
    [anon_sym_BANG_EQ] = ACTIONS(5509),
    [anon_sym_GT] = ACTIONS(5507),
    [anon_sym_GT_EQ] = ACTIONS(5509),
    [anon_sym_LT_EQ] = ACTIONS(5507),
    [anon_sym_LT] = ACTIONS(5507),
    [anon_sym_LT_LT] = ACTIONS(5509),
    [anon_sym_GT_GT] = ACTIONS(5509),
    [anon_sym_COLON] = ACTIONS(5509),
    [anon_sym_SEMI] = ACTIONS(5509),
    [anon_sym___extension__] = ACTIONS(5507),
    [anon_sym___attribute__] = ACTIONS(5507),
    [anon_sym___based] = ACTIONS(5507),
    [anon_sym_LBRACE] = ACTIONS(5509),
    [anon_sym_RBRACE] = ACTIONS(5509),
    [anon_sym_signed] = ACTIONS(5507),
    [anon_sym_unsigned] = ACTIONS(5507),
    [anon_sym_long] = ACTIONS(5507),
    [anon_sym_short] = ACTIONS(5507),
    [anon_sym_LBRACK] = ACTIONS(5509),
    [anon_sym_RBRACK] = ACTIONS(5509),
    [anon_sym_const] = ACTIONS(5507),
    [anon_sym_constexpr] = ACTIONS(5507),
    [anon_sym_volatile] = ACTIONS(5507),
    [anon_sym_restrict] = ACTIONS(5507),
    [anon_sym___restrict__] = ACTIONS(5507),
    [anon_sym__Atomic] = ACTIONS(5507),
    [anon_sym__Noreturn] = ACTIONS(5507),
    [anon_sym_noreturn] = ACTIONS(5507),
    [anon_sym_mutable] = ACTIONS(5507),
    [anon_sym_constinit] = ACTIONS(5507),
    [anon_sym_consteval] = ACTIONS(5507),
    [anon_sym_alignas] = ACTIONS(5507),
    [anon_sym__Alignas] = ACTIONS(5507),
    [sym_primitive_type] = ACTIONS(5507),
    [anon_sym_QMARK] = ACTIONS(5509),
    [anon_sym_LT_EQ_GT] = ACTIONS(5509),
    [anon_sym_or] = ACTIONS(5507),
    [anon_sym_and] = ACTIONS(5507),
    [anon_sym_bitor] = ACTIONS(5507),
    [anon_sym_xor] = ACTIONS(5507),
    [anon_sym_bitand] = ACTIONS(5507),
    [anon_sym_not_eq] = ACTIONS(5507),
    [anon_sym_DASH_DASH] = ACTIONS(5509),
    [anon_sym_PLUS_PLUS] = ACTIONS(5509),
    [anon_sym_DOT] = ACTIONS(5507),
    [anon_sym_DOT_STAR] = ACTIONS(5509),
    [anon_sym_DASH_GT] = ACTIONS(5509),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5507),
    [anon_sym_decltype] = ACTIONS(5507),
    [anon_sym_final] = ACTIONS(5507),
    [anon_sym_override] = ACTIONS(5507),
    [anon_sym_requires] = ACTIONS(5507),
  },
  [2441] = {
    [sym_identifier] = ACTIONS(1959),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1961),
    [anon_sym_COMMA] = ACTIONS(1961),
    [anon_sym_RPAREN] = ACTIONS(4060),
    [anon_sym_LPAREN2] = ACTIONS(4060),
    [anon_sym_TILDE] = ACTIONS(1961),
    [anon_sym_STAR] = ACTIONS(1961),
    [anon_sym_AMP_AMP] = ACTIONS(1961),
    [anon_sym_AMP] = ACTIONS(1959),
    [anon_sym_COLON] = ACTIONS(1959),
    [anon_sym_SEMI] = ACTIONS(4058),
    [anon_sym___extension__] = ACTIONS(1959),
    [anon_sym_in] = ACTIONS(1959),
    [anon_sym_out] = ACTIONS(1959),
    [anon_sym_inout] = ACTIONS(1959),
    [anon_sym_extern] = ACTIONS(1959),
    [anon_sym___attribute__] = ACTIONS(1959),
    [anon_sym_COLON_COLON] = ACTIONS(1961),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4060),
    [anon_sym___declspec] = ACTIONS(1959),
    [anon_sym___based] = ACTIONS(1959),
    [anon_sym_LBRACK] = ACTIONS(4065),
    [anon_sym_static] = ACTIONS(1959),
    [anon_sym_EQ] = ACTIONS(1961),
    [anon_sym_register] = ACTIONS(1959),
    [anon_sym_inline] = ACTIONS(1959),
    [anon_sym___inline] = ACTIONS(1959),
    [anon_sym___inline__] = ACTIONS(1959),
    [anon_sym___forceinline] = ACTIONS(1959),
    [anon_sym_thread_local] = ACTIONS(1959),
    [anon_sym___thread] = ACTIONS(1959),
    [anon_sym_const] = ACTIONS(1959),
    [anon_sym_constexpr] = ACTIONS(1959),
    [anon_sym_volatile] = ACTIONS(1959),
    [anon_sym_restrict] = ACTIONS(1959),
    [anon_sym___restrict__] = ACTIONS(1959),
    [anon_sym__Atomic] = ACTIONS(1959),
    [anon_sym__Noreturn] = ACTIONS(1959),
    [anon_sym_noreturn] = ACTIONS(1959),
    [anon_sym_mutable] = ACTIONS(1959),
    [anon_sym_constinit] = ACTIONS(1959),
    [anon_sym_consteval] = ACTIONS(1959),
    [anon_sym_alignas] = ACTIONS(1959),
    [anon_sym__Alignas] = ACTIONS(1959),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1959),
    [anon_sym_decltype] = ACTIONS(1959),
    [sym_virtual] = ACTIONS(1959),
    [anon_sym_template] = ACTIONS(1959),
    [anon_sym_operator] = ACTIONS(1959),
    [anon_sym_precise] = ACTIONS(1959),
    [anon_sym_shared] = ACTIONS(1959),
    [anon_sym_groupshared] = ACTIONS(1959),
    [anon_sym_uniform] = ACTIONS(1959),
    [anon_sym_row_major] = ACTIONS(1959),
    [anon_sym_column_major] = ACTIONS(1959),
    [anon_sym_globallycoherent] = ACTIONS(1959),
    [anon_sym_centroid] = ACTIONS(1959),
    [anon_sym_noperspective] = ACTIONS(1959),
    [anon_sym_nointerpolation] = ACTIONS(1959),
    [anon_sym_sample] = ACTIONS(1959),
    [anon_sym_linear] = ACTIONS(1959),
    [anon_sym_snorm] = ACTIONS(1959),
    [anon_sym_unorm] = ACTIONS(1959),
    [anon_sym_point] = ACTIONS(1959),
    [anon_sym_line] = ACTIONS(1959),
    [anon_sym_triangleadj] = ACTIONS(1959),
    [anon_sym_lineadj] = ACTIONS(1959),
    [anon_sym_triangle] = ACTIONS(1959),
  },
  [2442] = {
    [sym_identifier] = ACTIONS(5537),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5539),
    [anon_sym_COMMA] = ACTIONS(5539),
    [anon_sym_RPAREN] = ACTIONS(5539),
    [anon_sym_LPAREN2] = ACTIONS(5539),
    [anon_sym_DASH] = ACTIONS(5537),
    [anon_sym_PLUS] = ACTIONS(5537),
    [anon_sym_STAR] = ACTIONS(5539),
    [anon_sym_SLASH] = ACTIONS(5537),
    [anon_sym_PERCENT] = ACTIONS(5539),
    [anon_sym_PIPE_PIPE] = ACTIONS(5539),
    [anon_sym_AMP_AMP] = ACTIONS(5539),
    [anon_sym_PIPE] = ACTIONS(5537),
    [anon_sym_CARET] = ACTIONS(5539),
    [anon_sym_AMP] = ACTIONS(5537),
    [anon_sym_EQ_EQ] = ACTIONS(5539),
    [anon_sym_BANG_EQ] = ACTIONS(5539),
    [anon_sym_GT] = ACTIONS(5537),
    [anon_sym_GT_EQ] = ACTIONS(5539),
    [anon_sym_LT_EQ] = ACTIONS(5537),
    [anon_sym_LT] = ACTIONS(5537),
    [anon_sym_LT_LT] = ACTIONS(5539),
    [anon_sym_GT_GT] = ACTIONS(5539),
    [anon_sym_COLON] = ACTIONS(5539),
    [anon_sym_SEMI] = ACTIONS(5539),
    [anon_sym___extension__] = ACTIONS(5537),
    [anon_sym___attribute__] = ACTIONS(5537),
    [anon_sym___based] = ACTIONS(5537),
    [anon_sym_LBRACE] = ACTIONS(5539),
    [anon_sym_RBRACE] = ACTIONS(5539),
    [anon_sym_signed] = ACTIONS(5537),
    [anon_sym_unsigned] = ACTIONS(5537),
    [anon_sym_long] = ACTIONS(5537),
    [anon_sym_short] = ACTIONS(5537),
    [anon_sym_LBRACK] = ACTIONS(5539),
    [anon_sym_RBRACK] = ACTIONS(5539),
    [anon_sym_const] = ACTIONS(5537),
    [anon_sym_constexpr] = ACTIONS(5537),
    [anon_sym_volatile] = ACTIONS(5537),
    [anon_sym_restrict] = ACTIONS(5537),
    [anon_sym___restrict__] = ACTIONS(5537),
    [anon_sym__Atomic] = ACTIONS(5537),
    [anon_sym__Noreturn] = ACTIONS(5537),
    [anon_sym_noreturn] = ACTIONS(5537),
    [anon_sym_mutable] = ACTIONS(5537),
    [anon_sym_constinit] = ACTIONS(5537),
    [anon_sym_consteval] = ACTIONS(5537),
    [anon_sym_alignas] = ACTIONS(5537),
    [anon_sym__Alignas] = ACTIONS(5537),
    [sym_primitive_type] = ACTIONS(5537),
    [anon_sym_QMARK] = ACTIONS(5539),
    [anon_sym_LT_EQ_GT] = ACTIONS(5539),
    [anon_sym_or] = ACTIONS(5537),
    [anon_sym_and] = ACTIONS(5537),
    [anon_sym_bitor] = ACTIONS(5537),
    [anon_sym_xor] = ACTIONS(5537),
    [anon_sym_bitand] = ACTIONS(5537),
    [anon_sym_not_eq] = ACTIONS(5537),
    [anon_sym_DASH_DASH] = ACTIONS(5539),
    [anon_sym_PLUS_PLUS] = ACTIONS(5539),
    [anon_sym_DOT] = ACTIONS(5537),
    [anon_sym_DOT_STAR] = ACTIONS(5539),
    [anon_sym_DASH_GT] = ACTIONS(5539),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5537),
    [anon_sym_decltype] = ACTIONS(5537),
    [anon_sym_final] = ACTIONS(5537),
    [anon_sym_override] = ACTIONS(5537),
    [anon_sym_requires] = ACTIONS(5537),
  },
  [2443] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2461),
    [sym_identifier] = ACTIONS(5830),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5336),
    [anon_sym_COMMA] = ACTIONS(5336),
    [anon_sym_RPAREN] = ACTIONS(5336),
    [anon_sym_LPAREN2] = ACTIONS(5336),
    [anon_sym_DASH] = ACTIONS(5338),
    [anon_sym_PLUS] = ACTIONS(5338),
    [anon_sym_STAR] = ACTIONS(5336),
    [anon_sym_SLASH] = ACTIONS(5338),
    [anon_sym_PERCENT] = ACTIONS(5336),
    [anon_sym_PIPE_PIPE] = ACTIONS(5336),
    [anon_sym_AMP_AMP] = ACTIONS(5336),
    [anon_sym_PIPE] = ACTIONS(5338),
    [anon_sym_CARET] = ACTIONS(5336),
    [anon_sym_AMP] = ACTIONS(5338),
    [anon_sym_EQ_EQ] = ACTIONS(5336),
    [anon_sym_BANG_EQ] = ACTIONS(5336),
    [anon_sym_GT] = ACTIONS(5338),
    [anon_sym_GT_EQ] = ACTIONS(5336),
    [anon_sym_LT_EQ] = ACTIONS(5338),
    [anon_sym_LT] = ACTIONS(5338),
    [anon_sym_LT_LT] = ACTIONS(5336),
    [anon_sym_GT_GT] = ACTIONS(5336),
    [anon_sym_COLON] = ACTIONS(5336),
    [anon_sym_SEMI] = ACTIONS(5336),
    [anon_sym___extension__] = ACTIONS(5338),
    [anon_sym___attribute__] = ACTIONS(5338),
    [anon_sym_LBRACE] = ACTIONS(5336),
    [anon_sym_RBRACE] = ACTIONS(5336),
    [anon_sym_signed] = ACTIONS(5832),
    [anon_sym_unsigned] = ACTIONS(5832),
    [anon_sym_long] = ACTIONS(5832),
    [anon_sym_short] = ACTIONS(5832),
    [anon_sym_LBRACK] = ACTIONS(5336),
    [anon_sym_RBRACK] = ACTIONS(5336),
    [anon_sym_const] = ACTIONS(5338),
    [anon_sym_constexpr] = ACTIONS(5338),
    [anon_sym_volatile] = ACTIONS(5338),
    [anon_sym_restrict] = ACTIONS(5338),
    [anon_sym___restrict__] = ACTIONS(5338),
    [anon_sym__Atomic] = ACTIONS(5338),
    [anon_sym__Noreturn] = ACTIONS(5338),
    [anon_sym_noreturn] = ACTIONS(5338),
    [anon_sym_mutable] = ACTIONS(5338),
    [anon_sym_constinit] = ACTIONS(5338),
    [anon_sym_consteval] = ACTIONS(5338),
    [anon_sym_alignas] = ACTIONS(5338),
    [anon_sym__Alignas] = ACTIONS(5338),
    [sym_primitive_type] = ACTIONS(5834),
    [anon_sym_QMARK] = ACTIONS(5336),
    [anon_sym_LT_EQ_GT] = ACTIONS(5336),
    [anon_sym_or] = ACTIONS(5338),
    [anon_sym_and] = ACTIONS(5338),
    [anon_sym_bitor] = ACTIONS(5338),
    [anon_sym_xor] = ACTIONS(5338),
    [anon_sym_bitand] = ACTIONS(5338),
    [anon_sym_not_eq] = ACTIONS(5338),
    [anon_sym_DASH_DASH] = ACTIONS(5336),
    [anon_sym_PLUS_PLUS] = ACTIONS(5336),
    [anon_sym_DOT] = ACTIONS(5338),
    [anon_sym_DOT_STAR] = ACTIONS(5336),
    [anon_sym_DASH_GT] = ACTIONS(5336),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5338),
    [anon_sym_decltype] = ACTIONS(5338),
    [anon_sym_final] = ACTIONS(5338),
    [anon_sym_override] = ACTIONS(5338),
    [anon_sym_requires] = ACTIONS(5338),
  },
  [2444] = {
    [sym_string_literal] = STATE(2344),
    [sym_raw_string_literal] = STATE(2344),
    [sym_identifier] = ACTIONS(3832),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [aux_sym_preproc_if_token2] = ACTIONS(3824),
    [aux_sym_preproc_else_token1] = ACTIONS(3824),
    [aux_sym_preproc_elif_token1] = ACTIONS(3832),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(3824),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3824),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(3832),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_LBRACK] = ACTIONS(3824),
    [anon_sym_EQ] = ACTIONS(3832),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3824),
    [anon_sym_SLASH_EQ] = ACTIONS(3824),
    [anon_sym_PERCENT_EQ] = ACTIONS(3824),
    [anon_sym_PLUS_EQ] = ACTIONS(3824),
    [anon_sym_DASH_EQ] = ACTIONS(3824),
    [anon_sym_LT_LT_EQ] = ACTIONS(3824),
    [anon_sym_GT_GT_EQ] = ACTIONS(3824),
    [anon_sym_AMP_EQ] = ACTIONS(3824),
    [anon_sym_CARET_EQ] = ACTIONS(3824),
    [anon_sym_PIPE_EQ] = ACTIONS(3824),
    [anon_sym_and_eq] = ACTIONS(3832),
    [anon_sym_or_eq] = ACTIONS(3832),
    [anon_sym_xor_eq] = ACTIONS(3832),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3832),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3832),
    [anon_sym_not_eq] = ACTIONS(3832),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [sym_literal_suffix] = ACTIONS(5836),
  },
  [2445] = {
    [sym_identifier] = ACTIONS(5455),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5457),
    [anon_sym_COMMA] = ACTIONS(5457),
    [anon_sym_RPAREN] = ACTIONS(5457),
    [anon_sym_LPAREN2] = ACTIONS(5457),
    [anon_sym_DASH] = ACTIONS(5455),
    [anon_sym_PLUS] = ACTIONS(5455),
    [anon_sym_STAR] = ACTIONS(5457),
    [anon_sym_SLASH] = ACTIONS(5455),
    [anon_sym_PERCENT] = ACTIONS(5457),
    [anon_sym_PIPE_PIPE] = ACTIONS(5457),
    [anon_sym_AMP_AMP] = ACTIONS(5457),
    [anon_sym_PIPE] = ACTIONS(5455),
    [anon_sym_CARET] = ACTIONS(5457),
    [anon_sym_AMP] = ACTIONS(5455),
    [anon_sym_EQ_EQ] = ACTIONS(5457),
    [anon_sym_BANG_EQ] = ACTIONS(5457),
    [anon_sym_GT] = ACTIONS(5455),
    [anon_sym_GT_EQ] = ACTIONS(5457),
    [anon_sym_LT_EQ] = ACTIONS(5455),
    [anon_sym_LT] = ACTIONS(5455),
    [anon_sym_LT_LT] = ACTIONS(5457),
    [anon_sym_GT_GT] = ACTIONS(5457),
    [anon_sym_COLON] = ACTIONS(5457),
    [anon_sym_SEMI] = ACTIONS(5457),
    [anon_sym___extension__] = ACTIONS(5455),
    [anon_sym___attribute__] = ACTIONS(5455),
    [anon_sym___based] = ACTIONS(5455),
    [anon_sym_LBRACE] = ACTIONS(5457),
    [anon_sym_RBRACE] = ACTIONS(5457),
    [anon_sym_signed] = ACTIONS(5455),
    [anon_sym_unsigned] = ACTIONS(5455),
    [anon_sym_long] = ACTIONS(5455),
    [anon_sym_short] = ACTIONS(5455),
    [anon_sym_LBRACK] = ACTIONS(5457),
    [anon_sym_RBRACK] = ACTIONS(5457),
    [anon_sym_const] = ACTIONS(5455),
    [anon_sym_constexpr] = ACTIONS(5455),
    [anon_sym_volatile] = ACTIONS(5455),
    [anon_sym_restrict] = ACTIONS(5455),
    [anon_sym___restrict__] = ACTIONS(5455),
    [anon_sym__Atomic] = ACTIONS(5455),
    [anon_sym__Noreturn] = ACTIONS(5455),
    [anon_sym_noreturn] = ACTIONS(5455),
    [anon_sym_mutable] = ACTIONS(5455),
    [anon_sym_constinit] = ACTIONS(5455),
    [anon_sym_consteval] = ACTIONS(5455),
    [anon_sym_alignas] = ACTIONS(5455),
    [anon_sym__Alignas] = ACTIONS(5455),
    [sym_primitive_type] = ACTIONS(5455),
    [anon_sym_QMARK] = ACTIONS(5457),
    [anon_sym_LT_EQ_GT] = ACTIONS(5457),
    [anon_sym_or] = ACTIONS(5455),
    [anon_sym_and] = ACTIONS(5455),
    [anon_sym_bitor] = ACTIONS(5455),
    [anon_sym_xor] = ACTIONS(5455),
    [anon_sym_bitand] = ACTIONS(5455),
    [anon_sym_not_eq] = ACTIONS(5455),
    [anon_sym_DASH_DASH] = ACTIONS(5457),
    [anon_sym_PLUS_PLUS] = ACTIONS(5457),
    [anon_sym_DOT] = ACTIONS(5455),
    [anon_sym_DOT_STAR] = ACTIONS(5457),
    [anon_sym_DASH_GT] = ACTIONS(5457),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5455),
    [anon_sym_decltype] = ACTIONS(5455),
    [anon_sym_final] = ACTIONS(5455),
    [anon_sym_override] = ACTIONS(5455),
    [anon_sym_requires] = ACTIONS(5455),
  },
  [2446] = {
    [sym_identifier] = ACTIONS(5487),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5489),
    [anon_sym_COMMA] = ACTIONS(5489),
    [anon_sym_RPAREN] = ACTIONS(5489),
    [anon_sym_LPAREN2] = ACTIONS(5489),
    [anon_sym_DASH] = ACTIONS(5487),
    [anon_sym_PLUS] = ACTIONS(5487),
    [anon_sym_STAR] = ACTIONS(5489),
    [anon_sym_SLASH] = ACTIONS(5487),
    [anon_sym_PERCENT] = ACTIONS(5489),
    [anon_sym_PIPE_PIPE] = ACTIONS(5489),
    [anon_sym_AMP_AMP] = ACTIONS(5489),
    [anon_sym_PIPE] = ACTIONS(5487),
    [anon_sym_CARET] = ACTIONS(5489),
    [anon_sym_AMP] = ACTIONS(5487),
    [anon_sym_EQ_EQ] = ACTIONS(5489),
    [anon_sym_BANG_EQ] = ACTIONS(5489),
    [anon_sym_GT] = ACTIONS(5487),
    [anon_sym_GT_EQ] = ACTIONS(5489),
    [anon_sym_LT_EQ] = ACTIONS(5487),
    [anon_sym_LT] = ACTIONS(5487),
    [anon_sym_LT_LT] = ACTIONS(5489),
    [anon_sym_GT_GT] = ACTIONS(5489),
    [anon_sym_COLON] = ACTIONS(5489),
    [anon_sym_SEMI] = ACTIONS(5489),
    [anon_sym___extension__] = ACTIONS(5487),
    [anon_sym___attribute__] = ACTIONS(5487),
    [anon_sym___based] = ACTIONS(5487),
    [anon_sym_LBRACE] = ACTIONS(5489),
    [anon_sym_RBRACE] = ACTIONS(5489),
    [anon_sym_signed] = ACTIONS(5487),
    [anon_sym_unsigned] = ACTIONS(5487),
    [anon_sym_long] = ACTIONS(5487),
    [anon_sym_short] = ACTIONS(5487),
    [anon_sym_LBRACK] = ACTIONS(5489),
    [anon_sym_RBRACK] = ACTIONS(5489),
    [anon_sym_const] = ACTIONS(5487),
    [anon_sym_constexpr] = ACTIONS(5487),
    [anon_sym_volatile] = ACTIONS(5487),
    [anon_sym_restrict] = ACTIONS(5487),
    [anon_sym___restrict__] = ACTIONS(5487),
    [anon_sym__Atomic] = ACTIONS(5487),
    [anon_sym__Noreturn] = ACTIONS(5487),
    [anon_sym_noreturn] = ACTIONS(5487),
    [anon_sym_mutable] = ACTIONS(5487),
    [anon_sym_constinit] = ACTIONS(5487),
    [anon_sym_consteval] = ACTIONS(5487),
    [anon_sym_alignas] = ACTIONS(5487),
    [anon_sym__Alignas] = ACTIONS(5487),
    [sym_primitive_type] = ACTIONS(5487),
    [anon_sym_QMARK] = ACTIONS(5489),
    [anon_sym_LT_EQ_GT] = ACTIONS(5489),
    [anon_sym_or] = ACTIONS(5487),
    [anon_sym_and] = ACTIONS(5487),
    [anon_sym_bitor] = ACTIONS(5487),
    [anon_sym_xor] = ACTIONS(5487),
    [anon_sym_bitand] = ACTIONS(5487),
    [anon_sym_not_eq] = ACTIONS(5487),
    [anon_sym_DASH_DASH] = ACTIONS(5489),
    [anon_sym_PLUS_PLUS] = ACTIONS(5489),
    [anon_sym_DOT] = ACTIONS(5487),
    [anon_sym_DOT_STAR] = ACTIONS(5489),
    [anon_sym_DASH_GT] = ACTIONS(5489),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5487),
    [anon_sym_decltype] = ACTIONS(5487),
    [anon_sym_final] = ACTIONS(5487),
    [anon_sym_override] = ACTIONS(5487),
    [anon_sym_requires] = ACTIONS(5487),
  },
  [2447] = {
    [sym_identifier] = ACTIONS(5467),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5469),
    [anon_sym_COMMA] = ACTIONS(5469),
    [anon_sym_RPAREN] = ACTIONS(5469),
    [anon_sym_LPAREN2] = ACTIONS(5469),
    [anon_sym_DASH] = ACTIONS(5467),
    [anon_sym_PLUS] = ACTIONS(5467),
    [anon_sym_STAR] = ACTIONS(5469),
    [anon_sym_SLASH] = ACTIONS(5467),
    [anon_sym_PERCENT] = ACTIONS(5469),
    [anon_sym_PIPE_PIPE] = ACTIONS(5469),
    [anon_sym_AMP_AMP] = ACTIONS(5469),
    [anon_sym_PIPE] = ACTIONS(5467),
    [anon_sym_CARET] = ACTIONS(5469),
    [anon_sym_AMP] = ACTIONS(5467),
    [anon_sym_EQ_EQ] = ACTIONS(5469),
    [anon_sym_BANG_EQ] = ACTIONS(5469),
    [anon_sym_GT] = ACTIONS(5467),
    [anon_sym_GT_EQ] = ACTIONS(5469),
    [anon_sym_LT_EQ] = ACTIONS(5467),
    [anon_sym_LT] = ACTIONS(5467),
    [anon_sym_LT_LT] = ACTIONS(5469),
    [anon_sym_GT_GT] = ACTIONS(5469),
    [anon_sym_COLON] = ACTIONS(5469),
    [anon_sym_SEMI] = ACTIONS(5469),
    [anon_sym___extension__] = ACTIONS(5467),
    [anon_sym___attribute__] = ACTIONS(5467),
    [anon_sym___based] = ACTIONS(5467),
    [anon_sym_LBRACE] = ACTIONS(5469),
    [anon_sym_RBRACE] = ACTIONS(5469),
    [anon_sym_signed] = ACTIONS(5467),
    [anon_sym_unsigned] = ACTIONS(5467),
    [anon_sym_long] = ACTIONS(5467),
    [anon_sym_short] = ACTIONS(5467),
    [anon_sym_LBRACK] = ACTIONS(5469),
    [anon_sym_RBRACK] = ACTIONS(5469),
    [anon_sym_const] = ACTIONS(5467),
    [anon_sym_constexpr] = ACTIONS(5467),
    [anon_sym_volatile] = ACTIONS(5467),
    [anon_sym_restrict] = ACTIONS(5467),
    [anon_sym___restrict__] = ACTIONS(5467),
    [anon_sym__Atomic] = ACTIONS(5467),
    [anon_sym__Noreturn] = ACTIONS(5467),
    [anon_sym_noreturn] = ACTIONS(5467),
    [anon_sym_mutable] = ACTIONS(5467),
    [anon_sym_constinit] = ACTIONS(5467),
    [anon_sym_consteval] = ACTIONS(5467),
    [anon_sym_alignas] = ACTIONS(5467),
    [anon_sym__Alignas] = ACTIONS(5467),
    [sym_primitive_type] = ACTIONS(5467),
    [anon_sym_QMARK] = ACTIONS(5469),
    [anon_sym_LT_EQ_GT] = ACTIONS(5469),
    [anon_sym_or] = ACTIONS(5467),
    [anon_sym_and] = ACTIONS(5467),
    [anon_sym_bitor] = ACTIONS(5467),
    [anon_sym_xor] = ACTIONS(5467),
    [anon_sym_bitand] = ACTIONS(5467),
    [anon_sym_not_eq] = ACTIONS(5467),
    [anon_sym_DASH_DASH] = ACTIONS(5469),
    [anon_sym_PLUS_PLUS] = ACTIONS(5469),
    [anon_sym_DOT] = ACTIONS(5467),
    [anon_sym_DOT_STAR] = ACTIONS(5469),
    [anon_sym_DASH_GT] = ACTIONS(5469),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5467),
    [anon_sym_decltype] = ACTIONS(5467),
    [anon_sym_final] = ACTIONS(5467),
    [anon_sym_override] = ACTIONS(5467),
    [anon_sym_requires] = ACTIONS(5467),
  },
  [2448] = {
    [sym_identifier] = ACTIONS(5431),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5433),
    [anon_sym_COMMA] = ACTIONS(5433),
    [anon_sym_RPAREN] = ACTIONS(5433),
    [anon_sym_LPAREN2] = ACTIONS(5433),
    [anon_sym_DASH] = ACTIONS(5431),
    [anon_sym_PLUS] = ACTIONS(5431),
    [anon_sym_STAR] = ACTIONS(5433),
    [anon_sym_SLASH] = ACTIONS(5431),
    [anon_sym_PERCENT] = ACTIONS(5433),
    [anon_sym_PIPE_PIPE] = ACTIONS(5433),
    [anon_sym_AMP_AMP] = ACTIONS(5433),
    [anon_sym_PIPE] = ACTIONS(5431),
    [anon_sym_CARET] = ACTIONS(5433),
    [anon_sym_AMP] = ACTIONS(5431),
    [anon_sym_EQ_EQ] = ACTIONS(5433),
    [anon_sym_BANG_EQ] = ACTIONS(5433),
    [anon_sym_GT] = ACTIONS(5431),
    [anon_sym_GT_EQ] = ACTIONS(5433),
    [anon_sym_LT_EQ] = ACTIONS(5431),
    [anon_sym_LT] = ACTIONS(5431),
    [anon_sym_LT_LT] = ACTIONS(5433),
    [anon_sym_GT_GT] = ACTIONS(5433),
    [anon_sym_COLON] = ACTIONS(5433),
    [anon_sym_SEMI] = ACTIONS(5433),
    [anon_sym___extension__] = ACTIONS(5431),
    [anon_sym___attribute__] = ACTIONS(5431),
    [anon_sym___based] = ACTIONS(5431),
    [anon_sym_LBRACE] = ACTIONS(5433),
    [anon_sym_RBRACE] = ACTIONS(5433),
    [anon_sym_signed] = ACTIONS(5431),
    [anon_sym_unsigned] = ACTIONS(5431),
    [anon_sym_long] = ACTIONS(5431),
    [anon_sym_short] = ACTIONS(5431),
    [anon_sym_LBRACK] = ACTIONS(5433),
    [anon_sym_RBRACK] = ACTIONS(5433),
    [anon_sym_const] = ACTIONS(5431),
    [anon_sym_constexpr] = ACTIONS(5431),
    [anon_sym_volatile] = ACTIONS(5431),
    [anon_sym_restrict] = ACTIONS(5431),
    [anon_sym___restrict__] = ACTIONS(5431),
    [anon_sym__Atomic] = ACTIONS(5431),
    [anon_sym__Noreturn] = ACTIONS(5431),
    [anon_sym_noreturn] = ACTIONS(5431),
    [anon_sym_mutable] = ACTIONS(5431),
    [anon_sym_constinit] = ACTIONS(5431),
    [anon_sym_consteval] = ACTIONS(5431),
    [anon_sym_alignas] = ACTIONS(5431),
    [anon_sym__Alignas] = ACTIONS(5431),
    [sym_primitive_type] = ACTIONS(5431),
    [anon_sym_QMARK] = ACTIONS(5433),
    [anon_sym_LT_EQ_GT] = ACTIONS(5433),
    [anon_sym_or] = ACTIONS(5431),
    [anon_sym_and] = ACTIONS(5431),
    [anon_sym_bitor] = ACTIONS(5431),
    [anon_sym_xor] = ACTIONS(5431),
    [anon_sym_bitand] = ACTIONS(5431),
    [anon_sym_not_eq] = ACTIONS(5431),
    [anon_sym_DASH_DASH] = ACTIONS(5433),
    [anon_sym_PLUS_PLUS] = ACTIONS(5433),
    [anon_sym_DOT] = ACTIONS(5431),
    [anon_sym_DOT_STAR] = ACTIONS(5433),
    [anon_sym_DASH_GT] = ACTIONS(5433),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5431),
    [anon_sym_decltype] = ACTIONS(5431),
    [anon_sym_final] = ACTIONS(5431),
    [anon_sym_override] = ACTIONS(5431),
    [anon_sym_requires] = ACTIONS(5431),
  },
  [2449] = {
    [sym_string_literal] = STATE(2344),
    [sym_raw_string_literal] = STATE(2344),
    [sym_identifier] = ACTIONS(5838),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5840),
    [anon_sym_COMMA] = ACTIONS(5840),
    [aux_sym_preproc_if_token2] = ACTIONS(5840),
    [aux_sym_preproc_else_token1] = ACTIONS(5840),
    [aux_sym_preproc_elif_token1] = ACTIONS(5838),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5840),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5840),
    [anon_sym_LPAREN2] = ACTIONS(5840),
    [anon_sym_DASH] = ACTIONS(5838),
    [anon_sym_PLUS] = ACTIONS(5838),
    [anon_sym_STAR] = ACTIONS(5838),
    [anon_sym_SLASH] = ACTIONS(5838),
    [anon_sym_PERCENT] = ACTIONS(5838),
    [anon_sym_PIPE_PIPE] = ACTIONS(5840),
    [anon_sym_AMP_AMP] = ACTIONS(5840),
    [anon_sym_PIPE] = ACTIONS(5838),
    [anon_sym_CARET] = ACTIONS(5838),
    [anon_sym_AMP] = ACTIONS(5838),
    [anon_sym_EQ_EQ] = ACTIONS(5840),
    [anon_sym_BANG_EQ] = ACTIONS(5840),
    [anon_sym_GT] = ACTIONS(5838),
    [anon_sym_GT_EQ] = ACTIONS(5840),
    [anon_sym_LT_EQ] = ACTIONS(5838),
    [anon_sym_LT] = ACTIONS(5838),
    [anon_sym_LT_LT] = ACTIONS(5838),
    [anon_sym_GT_GT] = ACTIONS(5838),
    [anon_sym_LBRACK] = ACTIONS(5840),
    [anon_sym_EQ] = ACTIONS(5838),
    [anon_sym_QMARK] = ACTIONS(5840),
    [anon_sym_STAR_EQ] = ACTIONS(5840),
    [anon_sym_SLASH_EQ] = ACTIONS(5840),
    [anon_sym_PERCENT_EQ] = ACTIONS(5840),
    [anon_sym_PLUS_EQ] = ACTIONS(5840),
    [anon_sym_DASH_EQ] = ACTIONS(5840),
    [anon_sym_LT_LT_EQ] = ACTIONS(5840),
    [anon_sym_GT_GT_EQ] = ACTIONS(5840),
    [anon_sym_AMP_EQ] = ACTIONS(5840),
    [anon_sym_CARET_EQ] = ACTIONS(5840),
    [anon_sym_PIPE_EQ] = ACTIONS(5840),
    [anon_sym_and_eq] = ACTIONS(5838),
    [anon_sym_or_eq] = ACTIONS(5838),
    [anon_sym_xor_eq] = ACTIONS(5838),
    [anon_sym_LT_EQ_GT] = ACTIONS(5840),
    [anon_sym_or] = ACTIONS(5838),
    [anon_sym_and] = ACTIONS(5838),
    [anon_sym_bitor] = ACTIONS(5838),
    [anon_sym_xor] = ACTIONS(5838),
    [anon_sym_bitand] = ACTIONS(5838),
    [anon_sym_not_eq] = ACTIONS(5838),
    [anon_sym_DASH_DASH] = ACTIONS(5840),
    [anon_sym_PLUS_PLUS] = ACTIONS(5840),
    [anon_sym_DOT] = ACTIONS(5838),
    [anon_sym_DOT_STAR] = ACTIONS(5840),
    [anon_sym_DASH_GT] = ACTIONS(5840),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [sym_literal_suffix] = ACTIONS(5836),
  },
  [2450] = {
    [sym_identifier] = ACTIONS(5483),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5485),
    [anon_sym_COMMA] = ACTIONS(5485),
    [anon_sym_RPAREN] = ACTIONS(5485),
    [anon_sym_LPAREN2] = ACTIONS(5485),
    [anon_sym_DASH] = ACTIONS(5483),
    [anon_sym_PLUS] = ACTIONS(5483),
    [anon_sym_STAR] = ACTIONS(5485),
    [anon_sym_SLASH] = ACTIONS(5483),
    [anon_sym_PERCENT] = ACTIONS(5485),
    [anon_sym_PIPE_PIPE] = ACTIONS(5485),
    [anon_sym_AMP_AMP] = ACTIONS(5485),
    [anon_sym_PIPE] = ACTIONS(5483),
    [anon_sym_CARET] = ACTIONS(5485),
    [anon_sym_AMP] = ACTIONS(5483),
    [anon_sym_EQ_EQ] = ACTIONS(5485),
    [anon_sym_BANG_EQ] = ACTIONS(5485),
    [anon_sym_GT] = ACTIONS(5483),
    [anon_sym_GT_EQ] = ACTIONS(5485),
    [anon_sym_LT_EQ] = ACTIONS(5483),
    [anon_sym_LT] = ACTIONS(5483),
    [anon_sym_LT_LT] = ACTIONS(5485),
    [anon_sym_GT_GT] = ACTIONS(5485),
    [anon_sym_COLON] = ACTIONS(5485),
    [anon_sym_SEMI] = ACTIONS(5485),
    [anon_sym___extension__] = ACTIONS(5483),
    [anon_sym___attribute__] = ACTIONS(5483),
    [anon_sym___based] = ACTIONS(5483),
    [anon_sym_LBRACE] = ACTIONS(5485),
    [anon_sym_RBRACE] = ACTIONS(5485),
    [anon_sym_signed] = ACTIONS(5483),
    [anon_sym_unsigned] = ACTIONS(5483),
    [anon_sym_long] = ACTIONS(5483),
    [anon_sym_short] = ACTIONS(5483),
    [anon_sym_LBRACK] = ACTIONS(5485),
    [anon_sym_RBRACK] = ACTIONS(5485),
    [anon_sym_const] = ACTIONS(5483),
    [anon_sym_constexpr] = ACTIONS(5483),
    [anon_sym_volatile] = ACTIONS(5483),
    [anon_sym_restrict] = ACTIONS(5483),
    [anon_sym___restrict__] = ACTIONS(5483),
    [anon_sym__Atomic] = ACTIONS(5483),
    [anon_sym__Noreturn] = ACTIONS(5483),
    [anon_sym_noreturn] = ACTIONS(5483),
    [anon_sym_mutable] = ACTIONS(5483),
    [anon_sym_constinit] = ACTIONS(5483),
    [anon_sym_consteval] = ACTIONS(5483),
    [anon_sym_alignas] = ACTIONS(5483),
    [anon_sym__Alignas] = ACTIONS(5483),
    [sym_primitive_type] = ACTIONS(5483),
    [anon_sym_QMARK] = ACTIONS(5485),
    [anon_sym_LT_EQ_GT] = ACTIONS(5485),
    [anon_sym_or] = ACTIONS(5483),
    [anon_sym_and] = ACTIONS(5483),
    [anon_sym_bitor] = ACTIONS(5483),
    [anon_sym_xor] = ACTIONS(5483),
    [anon_sym_bitand] = ACTIONS(5483),
    [anon_sym_not_eq] = ACTIONS(5483),
    [anon_sym_DASH_DASH] = ACTIONS(5485),
    [anon_sym_PLUS_PLUS] = ACTIONS(5485),
    [anon_sym_DOT] = ACTIONS(5483),
    [anon_sym_DOT_STAR] = ACTIONS(5485),
    [anon_sym_DASH_GT] = ACTIONS(5485),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5483),
    [anon_sym_decltype] = ACTIONS(5483),
    [anon_sym_final] = ACTIONS(5483),
    [anon_sym_override] = ACTIONS(5483),
    [anon_sym_requires] = ACTIONS(5483),
  },
  [2451] = {
    [sym_identifier] = ACTIONS(5545),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5547),
    [anon_sym_COMMA] = ACTIONS(5547),
    [anon_sym_RPAREN] = ACTIONS(5547),
    [anon_sym_LPAREN2] = ACTIONS(5547),
    [anon_sym_DASH] = ACTIONS(5545),
    [anon_sym_PLUS] = ACTIONS(5545),
    [anon_sym_STAR] = ACTIONS(5547),
    [anon_sym_SLASH] = ACTIONS(5545),
    [anon_sym_PERCENT] = ACTIONS(5547),
    [anon_sym_PIPE_PIPE] = ACTIONS(5547),
    [anon_sym_AMP_AMP] = ACTIONS(5547),
    [anon_sym_PIPE] = ACTIONS(5545),
    [anon_sym_CARET] = ACTIONS(5547),
    [anon_sym_AMP] = ACTIONS(5545),
    [anon_sym_EQ_EQ] = ACTIONS(5547),
    [anon_sym_BANG_EQ] = ACTIONS(5547),
    [anon_sym_GT] = ACTIONS(5545),
    [anon_sym_GT_EQ] = ACTIONS(5547),
    [anon_sym_LT_EQ] = ACTIONS(5545),
    [anon_sym_LT] = ACTIONS(5545),
    [anon_sym_LT_LT] = ACTIONS(5547),
    [anon_sym_GT_GT] = ACTIONS(5547),
    [anon_sym_COLON] = ACTIONS(5547),
    [anon_sym_SEMI] = ACTIONS(5547),
    [anon_sym___extension__] = ACTIONS(5545),
    [anon_sym___attribute__] = ACTIONS(5545),
    [anon_sym___based] = ACTIONS(5545),
    [anon_sym_LBRACE] = ACTIONS(5547),
    [anon_sym_RBRACE] = ACTIONS(5547),
    [anon_sym_signed] = ACTIONS(5545),
    [anon_sym_unsigned] = ACTIONS(5545),
    [anon_sym_long] = ACTIONS(5545),
    [anon_sym_short] = ACTIONS(5545),
    [anon_sym_LBRACK] = ACTIONS(5547),
    [anon_sym_RBRACK] = ACTIONS(5547),
    [anon_sym_const] = ACTIONS(5545),
    [anon_sym_constexpr] = ACTIONS(5545),
    [anon_sym_volatile] = ACTIONS(5545),
    [anon_sym_restrict] = ACTIONS(5545),
    [anon_sym___restrict__] = ACTIONS(5545),
    [anon_sym__Atomic] = ACTIONS(5545),
    [anon_sym__Noreturn] = ACTIONS(5545),
    [anon_sym_noreturn] = ACTIONS(5545),
    [anon_sym_mutable] = ACTIONS(5545),
    [anon_sym_constinit] = ACTIONS(5545),
    [anon_sym_consteval] = ACTIONS(5545),
    [anon_sym_alignas] = ACTIONS(5545),
    [anon_sym__Alignas] = ACTIONS(5545),
    [sym_primitive_type] = ACTIONS(5545),
    [anon_sym_QMARK] = ACTIONS(5547),
    [anon_sym_LT_EQ_GT] = ACTIONS(5547),
    [anon_sym_or] = ACTIONS(5545),
    [anon_sym_and] = ACTIONS(5545),
    [anon_sym_bitor] = ACTIONS(5545),
    [anon_sym_xor] = ACTIONS(5545),
    [anon_sym_bitand] = ACTIONS(5545),
    [anon_sym_not_eq] = ACTIONS(5545),
    [anon_sym_DASH_DASH] = ACTIONS(5547),
    [anon_sym_PLUS_PLUS] = ACTIONS(5547),
    [anon_sym_DOT] = ACTIONS(5545),
    [anon_sym_DOT_STAR] = ACTIONS(5547),
    [anon_sym_DASH_GT] = ACTIONS(5547),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5545),
    [anon_sym_decltype] = ACTIONS(5545),
    [anon_sym_final] = ACTIONS(5545),
    [anon_sym_override] = ACTIONS(5545),
    [anon_sym_requires] = ACTIONS(5545),
  },
  [2452] = {
    [sym_identifier] = ACTIONS(5467),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5469),
    [anon_sym_COMMA] = ACTIONS(5469),
    [anon_sym_RPAREN] = ACTIONS(5469),
    [anon_sym_LPAREN2] = ACTIONS(5469),
    [anon_sym_DASH] = ACTIONS(5467),
    [anon_sym_PLUS] = ACTIONS(5467),
    [anon_sym_STAR] = ACTIONS(5469),
    [anon_sym_SLASH] = ACTIONS(5467),
    [anon_sym_PERCENT] = ACTIONS(5469),
    [anon_sym_PIPE_PIPE] = ACTIONS(5469),
    [anon_sym_AMP_AMP] = ACTIONS(5469),
    [anon_sym_PIPE] = ACTIONS(5467),
    [anon_sym_CARET] = ACTIONS(5469),
    [anon_sym_AMP] = ACTIONS(5467),
    [anon_sym_EQ_EQ] = ACTIONS(5469),
    [anon_sym_BANG_EQ] = ACTIONS(5469),
    [anon_sym_GT] = ACTIONS(5467),
    [anon_sym_GT_EQ] = ACTIONS(5469),
    [anon_sym_LT_EQ] = ACTIONS(5467),
    [anon_sym_LT] = ACTIONS(5467),
    [anon_sym_LT_LT] = ACTIONS(5469),
    [anon_sym_GT_GT] = ACTIONS(5469),
    [anon_sym_COLON] = ACTIONS(5469),
    [anon_sym_SEMI] = ACTIONS(5469),
    [anon_sym___extension__] = ACTIONS(5467),
    [anon_sym___attribute__] = ACTIONS(5467),
    [anon_sym___based] = ACTIONS(5467),
    [anon_sym_LBRACE] = ACTIONS(5469),
    [anon_sym_RBRACE] = ACTIONS(5469),
    [anon_sym_signed] = ACTIONS(5467),
    [anon_sym_unsigned] = ACTIONS(5467),
    [anon_sym_long] = ACTIONS(5467),
    [anon_sym_short] = ACTIONS(5467),
    [anon_sym_LBRACK] = ACTIONS(5469),
    [anon_sym_RBRACK] = ACTIONS(5469),
    [anon_sym_const] = ACTIONS(5467),
    [anon_sym_constexpr] = ACTIONS(5467),
    [anon_sym_volatile] = ACTIONS(5467),
    [anon_sym_restrict] = ACTIONS(5467),
    [anon_sym___restrict__] = ACTIONS(5467),
    [anon_sym__Atomic] = ACTIONS(5467),
    [anon_sym__Noreturn] = ACTIONS(5467),
    [anon_sym_noreturn] = ACTIONS(5467),
    [anon_sym_mutable] = ACTIONS(5467),
    [anon_sym_constinit] = ACTIONS(5467),
    [anon_sym_consteval] = ACTIONS(5467),
    [anon_sym_alignas] = ACTIONS(5467),
    [anon_sym__Alignas] = ACTIONS(5467),
    [sym_primitive_type] = ACTIONS(5467),
    [anon_sym_QMARK] = ACTIONS(5469),
    [anon_sym_LT_EQ_GT] = ACTIONS(5469),
    [anon_sym_or] = ACTIONS(5467),
    [anon_sym_and] = ACTIONS(5467),
    [anon_sym_bitor] = ACTIONS(5467),
    [anon_sym_xor] = ACTIONS(5467),
    [anon_sym_bitand] = ACTIONS(5467),
    [anon_sym_not_eq] = ACTIONS(5467),
    [anon_sym_DASH_DASH] = ACTIONS(5469),
    [anon_sym_PLUS_PLUS] = ACTIONS(5469),
    [anon_sym_DOT] = ACTIONS(5467),
    [anon_sym_DOT_STAR] = ACTIONS(5469),
    [anon_sym_DASH_GT] = ACTIONS(5469),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5467),
    [anon_sym_decltype] = ACTIONS(5467),
    [anon_sym_final] = ACTIONS(5467),
    [anon_sym_override] = ACTIONS(5467),
    [anon_sym_requires] = ACTIONS(5467),
  },
  [2453] = {
    [sym_identifier] = ACTIONS(2142),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2144),
    [anon_sym_COMMA] = ACTIONS(2144),
    [anon_sym_RPAREN] = ACTIONS(2144),
    [anon_sym_LPAREN2] = ACTIONS(2144),
    [anon_sym_DASH] = ACTIONS(2142),
    [anon_sym_PLUS] = ACTIONS(2142),
    [anon_sym_STAR] = ACTIONS(2144),
    [anon_sym_SLASH] = ACTIONS(2142),
    [anon_sym_PERCENT] = ACTIONS(2144),
    [anon_sym_PIPE_PIPE] = ACTIONS(2144),
    [anon_sym_AMP_AMP] = ACTIONS(2144),
    [anon_sym_PIPE] = ACTIONS(2142),
    [anon_sym_CARET] = ACTIONS(2144),
    [anon_sym_AMP] = ACTIONS(2142),
    [anon_sym_EQ_EQ] = ACTIONS(2144),
    [anon_sym_BANG_EQ] = ACTIONS(2144),
    [anon_sym_GT] = ACTIONS(2142),
    [anon_sym_GT_EQ] = ACTIONS(2144),
    [anon_sym_LT_EQ] = ACTIONS(2142),
    [anon_sym_LT] = ACTIONS(2142),
    [anon_sym_LT_LT] = ACTIONS(2144),
    [anon_sym_GT_GT] = ACTIONS(2144),
    [anon_sym_COLON] = ACTIONS(2144),
    [anon_sym_SEMI] = ACTIONS(2144),
    [anon_sym___extension__] = ACTIONS(2142),
    [anon_sym___attribute__] = ACTIONS(2142),
    [anon_sym___based] = ACTIONS(2142),
    [anon_sym_LBRACE] = ACTIONS(2144),
    [anon_sym_RBRACE] = ACTIONS(2144),
    [anon_sym_signed] = ACTIONS(2142),
    [anon_sym_unsigned] = ACTIONS(2142),
    [anon_sym_long] = ACTIONS(2142),
    [anon_sym_short] = ACTIONS(2142),
    [anon_sym_LBRACK] = ACTIONS(2144),
    [anon_sym_RBRACK] = ACTIONS(2144),
    [anon_sym_const] = ACTIONS(2142),
    [anon_sym_constexpr] = ACTIONS(2142),
    [anon_sym_volatile] = ACTIONS(2142),
    [anon_sym_restrict] = ACTIONS(2142),
    [anon_sym___restrict__] = ACTIONS(2142),
    [anon_sym__Atomic] = ACTIONS(2142),
    [anon_sym__Noreturn] = ACTIONS(2142),
    [anon_sym_noreturn] = ACTIONS(2142),
    [anon_sym_mutable] = ACTIONS(2142),
    [anon_sym_constinit] = ACTIONS(2142),
    [anon_sym_consteval] = ACTIONS(2142),
    [anon_sym_alignas] = ACTIONS(2142),
    [anon_sym__Alignas] = ACTIONS(2142),
    [sym_primitive_type] = ACTIONS(2142),
    [anon_sym_QMARK] = ACTIONS(2144),
    [anon_sym_LT_EQ_GT] = ACTIONS(2144),
    [anon_sym_or] = ACTIONS(2142),
    [anon_sym_and] = ACTIONS(2142),
    [anon_sym_bitor] = ACTIONS(2142),
    [anon_sym_xor] = ACTIONS(2142),
    [anon_sym_bitand] = ACTIONS(2142),
    [anon_sym_not_eq] = ACTIONS(2142),
    [anon_sym_DASH_DASH] = ACTIONS(2144),
    [anon_sym_PLUS_PLUS] = ACTIONS(2144),
    [anon_sym_DOT] = ACTIONS(2142),
    [anon_sym_DOT_STAR] = ACTIONS(2144),
    [anon_sym_DASH_GT] = ACTIONS(2144),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2142),
    [anon_sym_decltype] = ACTIONS(2142),
    [anon_sym_final] = ACTIONS(2142),
    [anon_sym_override] = ACTIONS(2142),
    [anon_sym_requires] = ACTIONS(2142),
  },
  [2454] = {
    [sym_identifier] = ACTIONS(5427),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5429),
    [anon_sym_COMMA] = ACTIONS(5429),
    [anon_sym_RPAREN] = ACTIONS(5429),
    [anon_sym_LPAREN2] = ACTIONS(5429),
    [anon_sym_DASH] = ACTIONS(5427),
    [anon_sym_PLUS] = ACTIONS(5427),
    [anon_sym_STAR] = ACTIONS(5429),
    [anon_sym_SLASH] = ACTIONS(5427),
    [anon_sym_PERCENT] = ACTIONS(5429),
    [anon_sym_PIPE_PIPE] = ACTIONS(5429),
    [anon_sym_AMP_AMP] = ACTIONS(5429),
    [anon_sym_PIPE] = ACTIONS(5427),
    [anon_sym_CARET] = ACTIONS(5429),
    [anon_sym_AMP] = ACTIONS(5427),
    [anon_sym_EQ_EQ] = ACTIONS(5429),
    [anon_sym_BANG_EQ] = ACTIONS(5429),
    [anon_sym_GT] = ACTIONS(5427),
    [anon_sym_GT_EQ] = ACTIONS(5429),
    [anon_sym_LT_EQ] = ACTIONS(5427),
    [anon_sym_LT] = ACTIONS(5427),
    [anon_sym_LT_LT] = ACTIONS(5429),
    [anon_sym_GT_GT] = ACTIONS(5429),
    [anon_sym_COLON] = ACTIONS(5429),
    [anon_sym_SEMI] = ACTIONS(5429),
    [anon_sym___extension__] = ACTIONS(5427),
    [anon_sym___attribute__] = ACTIONS(5427),
    [anon_sym___based] = ACTIONS(5427),
    [anon_sym_LBRACE] = ACTIONS(5429),
    [anon_sym_RBRACE] = ACTIONS(5429),
    [anon_sym_signed] = ACTIONS(5427),
    [anon_sym_unsigned] = ACTIONS(5427),
    [anon_sym_long] = ACTIONS(5427),
    [anon_sym_short] = ACTIONS(5427),
    [anon_sym_LBRACK] = ACTIONS(5429),
    [anon_sym_RBRACK] = ACTIONS(5429),
    [anon_sym_const] = ACTIONS(5427),
    [anon_sym_constexpr] = ACTIONS(5427),
    [anon_sym_volatile] = ACTIONS(5427),
    [anon_sym_restrict] = ACTIONS(5427),
    [anon_sym___restrict__] = ACTIONS(5427),
    [anon_sym__Atomic] = ACTIONS(5427),
    [anon_sym__Noreturn] = ACTIONS(5427),
    [anon_sym_noreturn] = ACTIONS(5427),
    [anon_sym_mutable] = ACTIONS(5427),
    [anon_sym_constinit] = ACTIONS(5427),
    [anon_sym_consteval] = ACTIONS(5427),
    [anon_sym_alignas] = ACTIONS(5427),
    [anon_sym__Alignas] = ACTIONS(5427),
    [sym_primitive_type] = ACTIONS(5427),
    [anon_sym_QMARK] = ACTIONS(5429),
    [anon_sym_LT_EQ_GT] = ACTIONS(5429),
    [anon_sym_or] = ACTIONS(5427),
    [anon_sym_and] = ACTIONS(5427),
    [anon_sym_bitor] = ACTIONS(5427),
    [anon_sym_xor] = ACTIONS(5427),
    [anon_sym_bitand] = ACTIONS(5427),
    [anon_sym_not_eq] = ACTIONS(5427),
    [anon_sym_DASH_DASH] = ACTIONS(5429),
    [anon_sym_PLUS_PLUS] = ACTIONS(5429),
    [anon_sym_DOT] = ACTIONS(5427),
    [anon_sym_DOT_STAR] = ACTIONS(5429),
    [anon_sym_DASH_GT] = ACTIONS(5429),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5427),
    [anon_sym_decltype] = ACTIONS(5427),
    [anon_sym_final] = ACTIONS(5427),
    [anon_sym_override] = ACTIONS(5427),
    [anon_sym_requires] = ACTIONS(5427),
  },
  [2455] = {
    [sym_identifier] = ACTIONS(5499),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5501),
    [anon_sym_COMMA] = ACTIONS(5501),
    [anon_sym_RPAREN] = ACTIONS(5501),
    [anon_sym_LPAREN2] = ACTIONS(5501),
    [anon_sym_DASH] = ACTIONS(5499),
    [anon_sym_PLUS] = ACTIONS(5499),
    [anon_sym_STAR] = ACTIONS(5501),
    [anon_sym_SLASH] = ACTIONS(5499),
    [anon_sym_PERCENT] = ACTIONS(5501),
    [anon_sym_PIPE_PIPE] = ACTIONS(5501),
    [anon_sym_AMP_AMP] = ACTIONS(5501),
    [anon_sym_PIPE] = ACTIONS(5499),
    [anon_sym_CARET] = ACTIONS(5501),
    [anon_sym_AMP] = ACTIONS(5499),
    [anon_sym_EQ_EQ] = ACTIONS(5501),
    [anon_sym_BANG_EQ] = ACTIONS(5501),
    [anon_sym_GT] = ACTIONS(5499),
    [anon_sym_GT_EQ] = ACTIONS(5501),
    [anon_sym_LT_EQ] = ACTIONS(5499),
    [anon_sym_LT] = ACTIONS(5499),
    [anon_sym_LT_LT] = ACTIONS(5501),
    [anon_sym_GT_GT] = ACTIONS(5501),
    [anon_sym_COLON] = ACTIONS(5501),
    [anon_sym_SEMI] = ACTIONS(5501),
    [anon_sym___extension__] = ACTIONS(5499),
    [anon_sym___attribute__] = ACTIONS(5499),
    [anon_sym___based] = ACTIONS(5499),
    [anon_sym_LBRACE] = ACTIONS(5501),
    [anon_sym_RBRACE] = ACTIONS(5501),
    [anon_sym_signed] = ACTIONS(5499),
    [anon_sym_unsigned] = ACTIONS(5499),
    [anon_sym_long] = ACTIONS(5499),
    [anon_sym_short] = ACTIONS(5499),
    [anon_sym_LBRACK] = ACTIONS(5501),
    [anon_sym_RBRACK] = ACTIONS(5501),
    [anon_sym_const] = ACTIONS(5499),
    [anon_sym_constexpr] = ACTIONS(5499),
    [anon_sym_volatile] = ACTIONS(5499),
    [anon_sym_restrict] = ACTIONS(5499),
    [anon_sym___restrict__] = ACTIONS(5499),
    [anon_sym__Atomic] = ACTIONS(5499),
    [anon_sym__Noreturn] = ACTIONS(5499),
    [anon_sym_noreturn] = ACTIONS(5499),
    [anon_sym_mutable] = ACTIONS(5499),
    [anon_sym_constinit] = ACTIONS(5499),
    [anon_sym_consteval] = ACTIONS(5499),
    [anon_sym_alignas] = ACTIONS(5499),
    [anon_sym__Alignas] = ACTIONS(5499),
    [sym_primitive_type] = ACTIONS(5499),
    [anon_sym_QMARK] = ACTIONS(5501),
    [anon_sym_LT_EQ_GT] = ACTIONS(5501),
    [anon_sym_or] = ACTIONS(5499),
    [anon_sym_and] = ACTIONS(5499),
    [anon_sym_bitor] = ACTIONS(5499),
    [anon_sym_xor] = ACTIONS(5499),
    [anon_sym_bitand] = ACTIONS(5499),
    [anon_sym_not_eq] = ACTIONS(5499),
    [anon_sym_DASH_DASH] = ACTIONS(5501),
    [anon_sym_PLUS_PLUS] = ACTIONS(5501),
    [anon_sym_DOT] = ACTIONS(5499),
    [anon_sym_DOT_STAR] = ACTIONS(5501),
    [anon_sym_DASH_GT] = ACTIONS(5501),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5499),
    [anon_sym_decltype] = ACTIONS(5499),
    [anon_sym_final] = ACTIONS(5499),
    [anon_sym_override] = ACTIONS(5499),
    [anon_sym_requires] = ACTIONS(5499),
  },
  [2456] = {
    [sym_identifier] = ACTIONS(5491),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5493),
    [anon_sym_COMMA] = ACTIONS(5493),
    [anon_sym_RPAREN] = ACTIONS(5493),
    [anon_sym_LPAREN2] = ACTIONS(5493),
    [anon_sym_DASH] = ACTIONS(5491),
    [anon_sym_PLUS] = ACTIONS(5491),
    [anon_sym_STAR] = ACTIONS(5493),
    [anon_sym_SLASH] = ACTIONS(5491),
    [anon_sym_PERCENT] = ACTIONS(5493),
    [anon_sym_PIPE_PIPE] = ACTIONS(5493),
    [anon_sym_AMP_AMP] = ACTIONS(5493),
    [anon_sym_PIPE] = ACTIONS(5491),
    [anon_sym_CARET] = ACTIONS(5493),
    [anon_sym_AMP] = ACTIONS(5491),
    [anon_sym_EQ_EQ] = ACTIONS(5493),
    [anon_sym_BANG_EQ] = ACTIONS(5493),
    [anon_sym_GT] = ACTIONS(5491),
    [anon_sym_GT_EQ] = ACTIONS(5493),
    [anon_sym_LT_EQ] = ACTIONS(5491),
    [anon_sym_LT] = ACTIONS(5491),
    [anon_sym_LT_LT] = ACTIONS(5493),
    [anon_sym_GT_GT] = ACTIONS(5493),
    [anon_sym_COLON] = ACTIONS(5493),
    [anon_sym_SEMI] = ACTIONS(5493),
    [anon_sym___extension__] = ACTIONS(5491),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym___based] = ACTIONS(5491),
    [anon_sym_LBRACE] = ACTIONS(5493),
    [anon_sym_RBRACE] = ACTIONS(5493),
    [anon_sym_signed] = ACTIONS(5491),
    [anon_sym_unsigned] = ACTIONS(5491),
    [anon_sym_long] = ACTIONS(5491),
    [anon_sym_short] = ACTIONS(5491),
    [anon_sym_LBRACK] = ACTIONS(5493),
    [anon_sym_RBRACK] = ACTIONS(5493),
    [anon_sym_const] = ACTIONS(5491),
    [anon_sym_constexpr] = ACTIONS(5491),
    [anon_sym_volatile] = ACTIONS(5491),
    [anon_sym_restrict] = ACTIONS(5491),
    [anon_sym___restrict__] = ACTIONS(5491),
    [anon_sym__Atomic] = ACTIONS(5491),
    [anon_sym__Noreturn] = ACTIONS(5491),
    [anon_sym_noreturn] = ACTIONS(5491),
    [anon_sym_mutable] = ACTIONS(5491),
    [anon_sym_constinit] = ACTIONS(5491),
    [anon_sym_consteval] = ACTIONS(5491),
    [anon_sym_alignas] = ACTIONS(5491),
    [anon_sym__Alignas] = ACTIONS(5491),
    [sym_primitive_type] = ACTIONS(5491),
    [anon_sym_QMARK] = ACTIONS(5493),
    [anon_sym_LT_EQ_GT] = ACTIONS(5493),
    [anon_sym_or] = ACTIONS(5491),
    [anon_sym_and] = ACTIONS(5491),
    [anon_sym_bitor] = ACTIONS(5491),
    [anon_sym_xor] = ACTIONS(5491),
    [anon_sym_bitand] = ACTIONS(5491),
    [anon_sym_not_eq] = ACTIONS(5491),
    [anon_sym_DASH_DASH] = ACTIONS(5493),
    [anon_sym_PLUS_PLUS] = ACTIONS(5493),
    [anon_sym_DOT] = ACTIONS(5491),
    [anon_sym_DOT_STAR] = ACTIONS(5493),
    [anon_sym_DASH_GT] = ACTIONS(5493),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5491),
    [anon_sym_decltype] = ACTIONS(5491),
    [anon_sym_final] = ACTIONS(5491),
    [anon_sym_override] = ACTIONS(5491),
    [anon_sym_requires] = ACTIONS(5491),
  },
  [2457] = {
    [sym_identifier] = ACTIONS(5475),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5477),
    [anon_sym_COMMA] = ACTIONS(5477),
    [anon_sym_RPAREN] = ACTIONS(5477),
    [anon_sym_LPAREN2] = ACTIONS(5477),
    [anon_sym_DASH] = ACTIONS(5475),
    [anon_sym_PLUS] = ACTIONS(5475),
    [anon_sym_STAR] = ACTIONS(5477),
    [anon_sym_SLASH] = ACTIONS(5475),
    [anon_sym_PERCENT] = ACTIONS(5477),
    [anon_sym_PIPE_PIPE] = ACTIONS(5477),
    [anon_sym_AMP_AMP] = ACTIONS(5477),
    [anon_sym_PIPE] = ACTIONS(5475),
    [anon_sym_CARET] = ACTIONS(5477),
    [anon_sym_AMP] = ACTIONS(5475),
    [anon_sym_EQ_EQ] = ACTIONS(5477),
    [anon_sym_BANG_EQ] = ACTIONS(5477),
    [anon_sym_GT] = ACTIONS(5475),
    [anon_sym_GT_EQ] = ACTIONS(5477),
    [anon_sym_LT_EQ] = ACTIONS(5475),
    [anon_sym_LT] = ACTIONS(5475),
    [anon_sym_LT_LT] = ACTIONS(5477),
    [anon_sym_GT_GT] = ACTIONS(5477),
    [anon_sym_COLON] = ACTIONS(5477),
    [anon_sym_SEMI] = ACTIONS(5477),
    [anon_sym___extension__] = ACTIONS(5475),
    [anon_sym___attribute__] = ACTIONS(5475),
    [anon_sym___based] = ACTIONS(5475),
    [anon_sym_LBRACE] = ACTIONS(5477),
    [anon_sym_RBRACE] = ACTIONS(5477),
    [anon_sym_signed] = ACTIONS(5475),
    [anon_sym_unsigned] = ACTIONS(5475),
    [anon_sym_long] = ACTIONS(5475),
    [anon_sym_short] = ACTIONS(5475),
    [anon_sym_LBRACK] = ACTIONS(5477),
    [anon_sym_RBRACK] = ACTIONS(5477),
    [anon_sym_const] = ACTIONS(5475),
    [anon_sym_constexpr] = ACTIONS(5475),
    [anon_sym_volatile] = ACTIONS(5475),
    [anon_sym_restrict] = ACTIONS(5475),
    [anon_sym___restrict__] = ACTIONS(5475),
    [anon_sym__Atomic] = ACTIONS(5475),
    [anon_sym__Noreturn] = ACTIONS(5475),
    [anon_sym_noreturn] = ACTIONS(5475),
    [anon_sym_mutable] = ACTIONS(5475),
    [anon_sym_constinit] = ACTIONS(5475),
    [anon_sym_consteval] = ACTIONS(5475),
    [anon_sym_alignas] = ACTIONS(5475),
    [anon_sym__Alignas] = ACTIONS(5475),
    [sym_primitive_type] = ACTIONS(5475),
    [anon_sym_QMARK] = ACTIONS(5477),
    [anon_sym_LT_EQ_GT] = ACTIONS(5477),
    [anon_sym_or] = ACTIONS(5475),
    [anon_sym_and] = ACTIONS(5475),
    [anon_sym_bitor] = ACTIONS(5475),
    [anon_sym_xor] = ACTIONS(5475),
    [anon_sym_bitand] = ACTIONS(5475),
    [anon_sym_not_eq] = ACTIONS(5475),
    [anon_sym_DASH_DASH] = ACTIONS(5477),
    [anon_sym_PLUS_PLUS] = ACTIONS(5477),
    [anon_sym_DOT] = ACTIONS(5475),
    [anon_sym_DOT_STAR] = ACTIONS(5477),
    [anon_sym_DASH_GT] = ACTIONS(5477),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5475),
    [anon_sym_decltype] = ACTIONS(5475),
    [anon_sym_final] = ACTIONS(5475),
    [anon_sym_override] = ACTIONS(5475),
    [anon_sym_requires] = ACTIONS(5475),
  },
  [2458] = {
    [sym_template_argument_list] = STATE(2851),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2233),
    [sym_identifier] = ACTIONS(3822),
    [anon_sym_LPAREN2] = ACTIONS(3845),
    [anon_sym_STAR] = ACTIONS(3830),
    [anon_sym_AMP_AMP] = ACTIONS(3830),
    [anon_sym_AMP] = ACTIONS(3822),
    [anon_sym_LT] = ACTIONS(5298),
    [anon_sym_SEMI] = ACTIONS(3830),
    [anon_sym___extension__] = ACTIONS(3822),
    [anon_sym_in] = ACTIONS(3822),
    [anon_sym_out] = ACTIONS(3822),
    [anon_sym_inout] = ACTIONS(3822),
    [anon_sym_extern] = ACTIONS(3822),
    [anon_sym___attribute__] = ACTIONS(3822),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(3845),
    [anon_sym___declspec] = ACTIONS(3822),
    [anon_sym___based] = ACTIONS(3822),
    [anon_sym_signed] = ACTIONS(3848),
    [anon_sym_unsigned] = ACTIONS(3848),
    [anon_sym_long] = ACTIONS(3848),
    [anon_sym_short] = ACTIONS(3848),
    [anon_sym_LBRACK] = ACTIONS(5842),
    [anon_sym_static] = ACTIONS(3822),
    [anon_sym_register] = ACTIONS(3822),
    [anon_sym_inline] = ACTIONS(3822),
    [anon_sym___inline] = ACTIONS(3822),
    [anon_sym___inline__] = ACTIONS(3822),
    [anon_sym___forceinline] = ACTIONS(3822),
    [anon_sym_thread_local] = ACTIONS(3822),
    [anon_sym___thread] = ACTIONS(3822),
    [anon_sym_const] = ACTIONS(3822),
    [anon_sym_constexpr] = ACTIONS(3822),
    [anon_sym_volatile] = ACTIONS(3822),
    [anon_sym_restrict] = ACTIONS(3822),
    [anon_sym___restrict__] = ACTIONS(3822),
    [anon_sym__Atomic] = ACTIONS(3822),
    [anon_sym__Noreturn] = ACTIONS(3822),
    [anon_sym_noreturn] = ACTIONS(3822),
    [anon_sym_mutable] = ACTIONS(3822),
    [anon_sym_constinit] = ACTIONS(3822),
    [anon_sym_consteval] = ACTIONS(3822),
    [anon_sym_alignas] = ACTIONS(3822),
    [anon_sym__Alignas] = ACTIONS(3822),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3822),
    [anon_sym_decltype] = ACTIONS(3822),
    [sym_virtual] = ACTIONS(3822),
    [anon_sym_operator] = ACTIONS(3822),
    [anon_sym_precise] = ACTIONS(3822),
    [anon_sym_shared] = ACTIONS(3822),
    [anon_sym_groupshared] = ACTIONS(3822),
    [anon_sym_uniform] = ACTIONS(3822),
    [anon_sym_row_major] = ACTIONS(3822),
    [anon_sym_column_major] = ACTIONS(3822),
    [anon_sym_globallycoherent] = ACTIONS(3822),
    [anon_sym_centroid] = ACTIONS(3822),
    [anon_sym_noperspective] = ACTIONS(3822),
    [anon_sym_nointerpolation] = ACTIONS(3822),
    [anon_sym_sample] = ACTIONS(3822),
    [anon_sym_linear] = ACTIONS(3822),
    [anon_sym_snorm] = ACTIONS(3822),
    [anon_sym_unorm] = ACTIONS(3822),
    [anon_sym_point] = ACTIONS(3822),
    [anon_sym_line] = ACTIONS(3822),
    [anon_sym_triangleadj] = ACTIONS(3822),
    [anon_sym_lineadj] = ACTIONS(3822),
    [anon_sym_triangle] = ACTIONS(3822),
  },
  [2459] = {
    [sym_identifier] = ACTIONS(5451),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5453),
    [anon_sym_COMMA] = ACTIONS(5453),
    [anon_sym_RPAREN] = ACTIONS(5453),
    [anon_sym_LPAREN2] = ACTIONS(5453),
    [anon_sym_DASH] = ACTIONS(5451),
    [anon_sym_PLUS] = ACTIONS(5451),
    [anon_sym_STAR] = ACTIONS(5453),
    [anon_sym_SLASH] = ACTIONS(5451),
    [anon_sym_PERCENT] = ACTIONS(5453),
    [anon_sym_PIPE_PIPE] = ACTIONS(5453),
    [anon_sym_AMP_AMP] = ACTIONS(5453),
    [anon_sym_PIPE] = ACTIONS(5451),
    [anon_sym_CARET] = ACTIONS(5453),
    [anon_sym_AMP] = ACTIONS(5451),
    [anon_sym_EQ_EQ] = ACTIONS(5453),
    [anon_sym_BANG_EQ] = ACTIONS(5453),
    [anon_sym_GT] = ACTIONS(5451),
    [anon_sym_GT_EQ] = ACTIONS(5453),
    [anon_sym_LT_EQ] = ACTIONS(5451),
    [anon_sym_LT] = ACTIONS(5451),
    [anon_sym_LT_LT] = ACTIONS(5453),
    [anon_sym_GT_GT] = ACTIONS(5453),
    [anon_sym_COLON] = ACTIONS(5453),
    [anon_sym_SEMI] = ACTIONS(5453),
    [anon_sym___extension__] = ACTIONS(5451),
    [anon_sym___attribute__] = ACTIONS(5451),
    [anon_sym___based] = ACTIONS(5451),
    [anon_sym_LBRACE] = ACTIONS(5453),
    [anon_sym_RBRACE] = ACTIONS(5453),
    [anon_sym_signed] = ACTIONS(5451),
    [anon_sym_unsigned] = ACTIONS(5451),
    [anon_sym_long] = ACTIONS(5451),
    [anon_sym_short] = ACTIONS(5451),
    [anon_sym_LBRACK] = ACTIONS(5453),
    [anon_sym_RBRACK] = ACTIONS(5453),
    [anon_sym_const] = ACTIONS(5451),
    [anon_sym_constexpr] = ACTIONS(5451),
    [anon_sym_volatile] = ACTIONS(5451),
    [anon_sym_restrict] = ACTIONS(5451),
    [anon_sym___restrict__] = ACTIONS(5451),
    [anon_sym__Atomic] = ACTIONS(5451),
    [anon_sym__Noreturn] = ACTIONS(5451),
    [anon_sym_noreturn] = ACTIONS(5451),
    [anon_sym_mutable] = ACTIONS(5451),
    [anon_sym_constinit] = ACTIONS(5451),
    [anon_sym_consteval] = ACTIONS(5451),
    [anon_sym_alignas] = ACTIONS(5451),
    [anon_sym__Alignas] = ACTIONS(5451),
    [sym_primitive_type] = ACTIONS(5451),
    [anon_sym_QMARK] = ACTIONS(5453),
    [anon_sym_LT_EQ_GT] = ACTIONS(5453),
    [anon_sym_or] = ACTIONS(5451),
    [anon_sym_and] = ACTIONS(5451),
    [anon_sym_bitor] = ACTIONS(5451),
    [anon_sym_xor] = ACTIONS(5451),
    [anon_sym_bitand] = ACTIONS(5451),
    [anon_sym_not_eq] = ACTIONS(5451),
    [anon_sym_DASH_DASH] = ACTIONS(5453),
    [anon_sym_PLUS_PLUS] = ACTIONS(5453),
    [anon_sym_DOT] = ACTIONS(5451),
    [anon_sym_DOT_STAR] = ACTIONS(5453),
    [anon_sym_DASH_GT] = ACTIONS(5453),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5451),
    [anon_sym_decltype] = ACTIONS(5451),
    [anon_sym_final] = ACTIONS(5451),
    [anon_sym_override] = ACTIONS(5451),
    [anon_sym_requires] = ACTIONS(5451),
  },
  [2460] = {
    [sym_identifier] = ACTIONS(5439),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5441),
    [anon_sym_COMMA] = ACTIONS(5441),
    [anon_sym_RPAREN] = ACTIONS(5441),
    [anon_sym_LPAREN2] = ACTIONS(5441),
    [anon_sym_DASH] = ACTIONS(5439),
    [anon_sym_PLUS] = ACTIONS(5439),
    [anon_sym_STAR] = ACTIONS(5441),
    [anon_sym_SLASH] = ACTIONS(5439),
    [anon_sym_PERCENT] = ACTIONS(5441),
    [anon_sym_PIPE_PIPE] = ACTIONS(5441),
    [anon_sym_AMP_AMP] = ACTIONS(5441),
    [anon_sym_PIPE] = ACTIONS(5439),
    [anon_sym_CARET] = ACTIONS(5441),
    [anon_sym_AMP] = ACTIONS(5439),
    [anon_sym_EQ_EQ] = ACTIONS(5441),
    [anon_sym_BANG_EQ] = ACTIONS(5441),
    [anon_sym_GT] = ACTIONS(5439),
    [anon_sym_GT_EQ] = ACTIONS(5441),
    [anon_sym_LT_EQ] = ACTIONS(5439),
    [anon_sym_LT] = ACTIONS(5439),
    [anon_sym_LT_LT] = ACTIONS(5441),
    [anon_sym_GT_GT] = ACTIONS(5441),
    [anon_sym_COLON] = ACTIONS(5441),
    [anon_sym_SEMI] = ACTIONS(5441),
    [anon_sym___extension__] = ACTIONS(5439),
    [anon_sym___attribute__] = ACTIONS(5439),
    [anon_sym___based] = ACTIONS(5439),
    [anon_sym_LBRACE] = ACTIONS(5441),
    [anon_sym_RBRACE] = ACTIONS(5441),
    [anon_sym_signed] = ACTIONS(5439),
    [anon_sym_unsigned] = ACTIONS(5439),
    [anon_sym_long] = ACTIONS(5439),
    [anon_sym_short] = ACTIONS(5439),
    [anon_sym_LBRACK] = ACTIONS(5441),
    [anon_sym_RBRACK] = ACTIONS(5441),
    [anon_sym_const] = ACTIONS(5439),
    [anon_sym_constexpr] = ACTIONS(5439),
    [anon_sym_volatile] = ACTIONS(5439),
    [anon_sym_restrict] = ACTIONS(5439),
    [anon_sym___restrict__] = ACTIONS(5439),
    [anon_sym__Atomic] = ACTIONS(5439),
    [anon_sym__Noreturn] = ACTIONS(5439),
    [anon_sym_noreturn] = ACTIONS(5439),
    [anon_sym_mutable] = ACTIONS(5439),
    [anon_sym_constinit] = ACTIONS(5439),
    [anon_sym_consteval] = ACTIONS(5439),
    [anon_sym_alignas] = ACTIONS(5439),
    [anon_sym__Alignas] = ACTIONS(5439),
    [sym_primitive_type] = ACTIONS(5439),
    [anon_sym_QMARK] = ACTIONS(5441),
    [anon_sym_LT_EQ_GT] = ACTIONS(5441),
    [anon_sym_or] = ACTIONS(5439),
    [anon_sym_and] = ACTIONS(5439),
    [anon_sym_bitor] = ACTIONS(5439),
    [anon_sym_xor] = ACTIONS(5439),
    [anon_sym_bitand] = ACTIONS(5439),
    [anon_sym_not_eq] = ACTIONS(5439),
    [anon_sym_DASH_DASH] = ACTIONS(5441),
    [anon_sym_PLUS_PLUS] = ACTIONS(5441),
    [anon_sym_DOT] = ACTIONS(5439),
    [anon_sym_DOT_STAR] = ACTIONS(5441),
    [anon_sym_DASH_GT] = ACTIONS(5441),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5439),
    [anon_sym_decltype] = ACTIONS(5439),
    [anon_sym_final] = ACTIONS(5439),
    [anon_sym_override] = ACTIONS(5439),
    [anon_sym_requires] = ACTIONS(5439),
  },
  [2461] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2374),
    [sym_identifier] = ACTIONS(5224),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5315),
    [anon_sym_COMMA] = ACTIONS(5315),
    [anon_sym_RPAREN] = ACTIONS(5315),
    [anon_sym_LPAREN2] = ACTIONS(5315),
    [anon_sym_DASH] = ACTIONS(5312),
    [anon_sym_PLUS] = ACTIONS(5312),
    [anon_sym_STAR] = ACTIONS(5315),
    [anon_sym_SLASH] = ACTIONS(5312),
    [anon_sym_PERCENT] = ACTIONS(5315),
    [anon_sym_PIPE_PIPE] = ACTIONS(5315),
    [anon_sym_AMP_AMP] = ACTIONS(5315),
    [anon_sym_PIPE] = ACTIONS(5312),
    [anon_sym_CARET] = ACTIONS(5315),
    [anon_sym_AMP] = ACTIONS(5312),
    [anon_sym_EQ_EQ] = ACTIONS(5315),
    [anon_sym_BANG_EQ] = ACTIONS(5315),
    [anon_sym_GT] = ACTIONS(5312),
    [anon_sym_GT_EQ] = ACTIONS(5315),
    [anon_sym_LT_EQ] = ACTIONS(5312),
    [anon_sym_LT] = ACTIONS(5312),
    [anon_sym_LT_LT] = ACTIONS(5315),
    [anon_sym_GT_GT] = ACTIONS(5315),
    [anon_sym_COLON] = ACTIONS(5315),
    [anon_sym_SEMI] = ACTIONS(5315),
    [anon_sym___extension__] = ACTIONS(5312),
    [anon_sym___attribute__] = ACTIONS(5312),
    [anon_sym_LBRACE] = ACTIONS(5315),
    [anon_sym_RBRACE] = ACTIONS(5315),
    [anon_sym_signed] = ACTIONS(5766),
    [anon_sym_unsigned] = ACTIONS(5766),
    [anon_sym_long] = ACTIONS(5766),
    [anon_sym_short] = ACTIONS(5766),
    [anon_sym_LBRACK] = ACTIONS(5315),
    [anon_sym_RBRACK] = ACTIONS(5315),
    [anon_sym_const] = ACTIONS(5312),
    [anon_sym_constexpr] = ACTIONS(5312),
    [anon_sym_volatile] = ACTIONS(5312),
    [anon_sym_restrict] = ACTIONS(5312),
    [anon_sym___restrict__] = ACTIONS(5312),
    [anon_sym__Atomic] = ACTIONS(5312),
    [anon_sym__Noreturn] = ACTIONS(5312),
    [anon_sym_noreturn] = ACTIONS(5312),
    [anon_sym_mutable] = ACTIONS(5312),
    [anon_sym_constinit] = ACTIONS(5312),
    [anon_sym_consteval] = ACTIONS(5312),
    [anon_sym_alignas] = ACTIONS(5312),
    [anon_sym__Alignas] = ACTIONS(5312),
    [sym_primitive_type] = ACTIONS(5224),
    [anon_sym_QMARK] = ACTIONS(5315),
    [anon_sym_LT_EQ_GT] = ACTIONS(5315),
    [anon_sym_or] = ACTIONS(5312),
    [anon_sym_and] = ACTIONS(5312),
    [anon_sym_bitor] = ACTIONS(5312),
    [anon_sym_xor] = ACTIONS(5312),
    [anon_sym_bitand] = ACTIONS(5312),
    [anon_sym_not_eq] = ACTIONS(5312),
    [anon_sym_DASH_DASH] = ACTIONS(5315),
    [anon_sym_PLUS_PLUS] = ACTIONS(5315),
    [anon_sym_DOT] = ACTIONS(5312),
    [anon_sym_DOT_STAR] = ACTIONS(5315),
    [anon_sym_DASH_GT] = ACTIONS(5315),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5312),
    [anon_sym_decltype] = ACTIONS(5312),
    [anon_sym_final] = ACTIONS(5312),
    [anon_sym_override] = ACTIONS(5312),
    [anon_sym_requires] = ACTIONS(5312),
  },
  [2462] = {
    [sym_identifier] = ACTIONS(5511),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5513),
    [anon_sym_COMMA] = ACTIONS(5513),
    [anon_sym_RPAREN] = ACTIONS(5513),
    [anon_sym_LPAREN2] = ACTIONS(5513),
    [anon_sym_DASH] = ACTIONS(5511),
    [anon_sym_PLUS] = ACTIONS(5511),
    [anon_sym_STAR] = ACTIONS(5513),
    [anon_sym_SLASH] = ACTIONS(5511),
    [anon_sym_PERCENT] = ACTIONS(5513),
    [anon_sym_PIPE_PIPE] = ACTIONS(5513),
    [anon_sym_AMP_AMP] = ACTIONS(5513),
    [anon_sym_PIPE] = ACTIONS(5511),
    [anon_sym_CARET] = ACTIONS(5513),
    [anon_sym_AMP] = ACTIONS(5511),
    [anon_sym_EQ_EQ] = ACTIONS(5513),
    [anon_sym_BANG_EQ] = ACTIONS(5513),
    [anon_sym_GT] = ACTIONS(5511),
    [anon_sym_GT_EQ] = ACTIONS(5513),
    [anon_sym_LT_EQ] = ACTIONS(5511),
    [anon_sym_LT] = ACTIONS(5511),
    [anon_sym_LT_LT] = ACTIONS(5513),
    [anon_sym_GT_GT] = ACTIONS(5513),
    [anon_sym_COLON] = ACTIONS(5513),
    [anon_sym_SEMI] = ACTIONS(5513),
    [anon_sym___extension__] = ACTIONS(5511),
    [anon_sym___attribute__] = ACTIONS(5511),
    [anon_sym___based] = ACTIONS(5511),
    [anon_sym_LBRACE] = ACTIONS(5513),
    [anon_sym_RBRACE] = ACTIONS(5513),
    [anon_sym_signed] = ACTIONS(5511),
    [anon_sym_unsigned] = ACTIONS(5511),
    [anon_sym_long] = ACTIONS(5511),
    [anon_sym_short] = ACTIONS(5511),
    [anon_sym_LBRACK] = ACTIONS(5513),
    [anon_sym_RBRACK] = ACTIONS(5513),
    [anon_sym_const] = ACTIONS(5511),
    [anon_sym_constexpr] = ACTIONS(5511),
    [anon_sym_volatile] = ACTIONS(5511),
    [anon_sym_restrict] = ACTIONS(5511),
    [anon_sym___restrict__] = ACTIONS(5511),
    [anon_sym__Atomic] = ACTIONS(5511),
    [anon_sym__Noreturn] = ACTIONS(5511),
    [anon_sym_noreturn] = ACTIONS(5511),
    [anon_sym_mutable] = ACTIONS(5511),
    [anon_sym_constinit] = ACTIONS(5511),
    [anon_sym_consteval] = ACTIONS(5511),
    [anon_sym_alignas] = ACTIONS(5511),
    [anon_sym__Alignas] = ACTIONS(5511),
    [sym_primitive_type] = ACTIONS(5511),
    [anon_sym_QMARK] = ACTIONS(5513),
    [anon_sym_LT_EQ_GT] = ACTIONS(5513),
    [anon_sym_or] = ACTIONS(5511),
    [anon_sym_and] = ACTIONS(5511),
    [anon_sym_bitor] = ACTIONS(5511),
    [anon_sym_xor] = ACTIONS(5511),
    [anon_sym_bitand] = ACTIONS(5511),
    [anon_sym_not_eq] = ACTIONS(5511),
    [anon_sym_DASH_DASH] = ACTIONS(5513),
    [anon_sym_PLUS_PLUS] = ACTIONS(5513),
    [anon_sym_DOT] = ACTIONS(5511),
    [anon_sym_DOT_STAR] = ACTIONS(5513),
    [anon_sym_DASH_GT] = ACTIONS(5513),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5511),
    [anon_sym_decltype] = ACTIONS(5511),
    [anon_sym_final] = ACTIONS(5511),
    [anon_sym_override] = ACTIONS(5511),
    [anon_sym_requires] = ACTIONS(5511),
  },
  [2463] = {
    [sym_identifier] = ACTIONS(5459),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5461),
    [anon_sym_COMMA] = ACTIONS(5461),
    [anon_sym_RPAREN] = ACTIONS(5461),
    [anon_sym_LPAREN2] = ACTIONS(5461),
    [anon_sym_DASH] = ACTIONS(5459),
    [anon_sym_PLUS] = ACTIONS(5459),
    [anon_sym_STAR] = ACTIONS(5461),
    [anon_sym_SLASH] = ACTIONS(5459),
    [anon_sym_PERCENT] = ACTIONS(5461),
    [anon_sym_PIPE_PIPE] = ACTIONS(5461),
    [anon_sym_AMP_AMP] = ACTIONS(5461),
    [anon_sym_PIPE] = ACTIONS(5459),
    [anon_sym_CARET] = ACTIONS(5461),
    [anon_sym_AMP] = ACTIONS(5459),
    [anon_sym_EQ_EQ] = ACTIONS(5461),
    [anon_sym_BANG_EQ] = ACTIONS(5461),
    [anon_sym_GT] = ACTIONS(5459),
    [anon_sym_GT_EQ] = ACTIONS(5461),
    [anon_sym_LT_EQ] = ACTIONS(5459),
    [anon_sym_LT] = ACTIONS(5459),
    [anon_sym_LT_LT] = ACTIONS(5461),
    [anon_sym_GT_GT] = ACTIONS(5461),
    [anon_sym_COLON] = ACTIONS(5461),
    [anon_sym_SEMI] = ACTIONS(5461),
    [anon_sym___extension__] = ACTIONS(5459),
    [anon_sym___attribute__] = ACTIONS(5459),
    [anon_sym___based] = ACTIONS(5459),
    [anon_sym_LBRACE] = ACTIONS(5461),
    [anon_sym_RBRACE] = ACTIONS(5461),
    [anon_sym_signed] = ACTIONS(5459),
    [anon_sym_unsigned] = ACTIONS(5459),
    [anon_sym_long] = ACTIONS(5459),
    [anon_sym_short] = ACTIONS(5459),
    [anon_sym_LBRACK] = ACTIONS(5461),
    [anon_sym_RBRACK] = ACTIONS(5461),
    [anon_sym_const] = ACTIONS(5459),
    [anon_sym_constexpr] = ACTIONS(5459),
    [anon_sym_volatile] = ACTIONS(5459),
    [anon_sym_restrict] = ACTIONS(5459),
    [anon_sym___restrict__] = ACTIONS(5459),
    [anon_sym__Atomic] = ACTIONS(5459),
    [anon_sym__Noreturn] = ACTIONS(5459),
    [anon_sym_noreturn] = ACTIONS(5459),
    [anon_sym_mutable] = ACTIONS(5459),
    [anon_sym_constinit] = ACTIONS(5459),
    [anon_sym_consteval] = ACTIONS(5459),
    [anon_sym_alignas] = ACTIONS(5459),
    [anon_sym__Alignas] = ACTIONS(5459),
    [sym_primitive_type] = ACTIONS(5459),
    [anon_sym_QMARK] = ACTIONS(5461),
    [anon_sym_LT_EQ_GT] = ACTIONS(5461),
    [anon_sym_or] = ACTIONS(5459),
    [anon_sym_and] = ACTIONS(5459),
    [anon_sym_bitor] = ACTIONS(5459),
    [anon_sym_xor] = ACTIONS(5459),
    [anon_sym_bitand] = ACTIONS(5459),
    [anon_sym_not_eq] = ACTIONS(5459),
    [anon_sym_DASH_DASH] = ACTIONS(5461),
    [anon_sym_PLUS_PLUS] = ACTIONS(5461),
    [anon_sym_DOT] = ACTIONS(5459),
    [anon_sym_DOT_STAR] = ACTIONS(5461),
    [anon_sym_DASH_GT] = ACTIONS(5461),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5459),
    [anon_sym_decltype] = ACTIONS(5459),
    [anon_sym_final] = ACTIONS(5459),
    [anon_sym_override] = ACTIONS(5459),
    [anon_sym_requires] = ACTIONS(5459),
  },
  [2464] = {
    [sym_template_argument_list] = STATE(2502),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4045),
    [anon_sym_RPAREN] = ACTIONS(4047),
    [anon_sym_LPAREN2] = ACTIONS(4047),
    [anon_sym_DASH] = ACTIONS(4050),
    [anon_sym_PLUS] = ACTIONS(4050),
    [anon_sym_STAR] = ACTIONS(4052),
    [anon_sym_SLASH] = ACTIONS(4050),
    [anon_sym_PERCENT] = ACTIONS(4050),
    [anon_sym_PIPE_PIPE] = ACTIONS(4045),
    [anon_sym_AMP_AMP] = ACTIONS(4047),
    [anon_sym_PIPE] = ACTIONS(4050),
    [anon_sym_CARET] = ACTIONS(4050),
    [anon_sym_AMP] = ACTIONS(4052),
    [anon_sym_EQ_EQ] = ACTIONS(4045),
    [anon_sym_BANG_EQ] = ACTIONS(4045),
    [anon_sym_GT] = ACTIONS(4050),
    [anon_sym_GT_EQ] = ACTIONS(4045),
    [anon_sym_LT_EQ] = ACTIONS(4050),
    [anon_sym_LT] = ACTIONS(5844),
    [anon_sym_LT_LT] = ACTIONS(4050),
    [anon_sym_GT_GT] = ACTIONS(4050),
    [anon_sym___extension__] = ACTIONS(1935),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1935),
    [anon_sym_LBRACK] = ACTIONS(4047),
    [anon_sym_EQ] = ACTIONS(4050),
    [anon_sym_const] = ACTIONS(1933),
    [anon_sym_constexpr] = ACTIONS(1935),
    [anon_sym_volatile] = ACTIONS(1935),
    [anon_sym_restrict] = ACTIONS(1935),
    [anon_sym___restrict__] = ACTIONS(1935),
    [anon_sym__Atomic] = ACTIONS(1935),
    [anon_sym__Noreturn] = ACTIONS(1935),
    [anon_sym_noreturn] = ACTIONS(1935),
    [anon_sym_mutable] = ACTIONS(1935),
    [anon_sym_constinit] = ACTIONS(1935),
    [anon_sym_consteval] = ACTIONS(1935),
    [anon_sym_alignas] = ACTIONS(1935),
    [anon_sym__Alignas] = ACTIONS(1935),
    [anon_sym_QMARK] = ACTIONS(4045),
    [anon_sym_STAR_EQ] = ACTIONS(4045),
    [anon_sym_SLASH_EQ] = ACTIONS(4045),
    [anon_sym_PERCENT_EQ] = ACTIONS(4045),
    [anon_sym_PLUS_EQ] = ACTIONS(4045),
    [anon_sym_DASH_EQ] = ACTIONS(4045),
    [anon_sym_LT_LT_EQ] = ACTIONS(4045),
    [anon_sym_GT_GT_EQ] = ACTIONS(4045),
    [anon_sym_AMP_EQ] = ACTIONS(4045),
    [anon_sym_CARET_EQ] = ACTIONS(4045),
    [anon_sym_PIPE_EQ] = ACTIONS(4045),
    [anon_sym_and_eq] = ACTIONS(4045),
    [anon_sym_or_eq] = ACTIONS(4045),
    [anon_sym_xor_eq] = ACTIONS(4045),
    [anon_sym_LT_EQ_GT] = ACTIONS(4045),
    [anon_sym_or] = ACTIONS(4050),
    [anon_sym_and] = ACTIONS(4050),
    [anon_sym_bitor] = ACTIONS(4045),
    [anon_sym_xor] = ACTIONS(4050),
    [anon_sym_bitand] = ACTIONS(4045),
    [anon_sym_not_eq] = ACTIONS(4045),
    [anon_sym_DASH_DASH] = ACTIONS(4045),
    [anon_sym_PLUS_PLUS] = ACTIONS(4045),
    [anon_sym_DOT] = ACTIONS(4050),
    [anon_sym_DOT_STAR] = ACTIONS(4045),
    [anon_sym_DASH_GT] = ACTIONS(4045),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1935),
    [anon_sym_decltype] = ACTIONS(1935),
  },
  [2465] = {
    [sym_identifier] = ACTIONS(5503),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5505),
    [anon_sym_COMMA] = ACTIONS(5505),
    [anon_sym_RPAREN] = ACTIONS(5505),
    [anon_sym_LPAREN2] = ACTIONS(5505),
    [anon_sym_DASH] = ACTIONS(5503),
    [anon_sym_PLUS] = ACTIONS(5503),
    [anon_sym_STAR] = ACTIONS(5505),
    [anon_sym_SLASH] = ACTIONS(5503),
    [anon_sym_PERCENT] = ACTIONS(5505),
    [anon_sym_PIPE_PIPE] = ACTIONS(5505),
    [anon_sym_AMP_AMP] = ACTIONS(5505),
    [anon_sym_PIPE] = ACTIONS(5503),
    [anon_sym_CARET] = ACTIONS(5505),
    [anon_sym_AMP] = ACTIONS(5503),
    [anon_sym_EQ_EQ] = ACTIONS(5505),
    [anon_sym_BANG_EQ] = ACTIONS(5505),
    [anon_sym_GT] = ACTIONS(5503),
    [anon_sym_GT_EQ] = ACTIONS(5505),
    [anon_sym_LT_EQ] = ACTIONS(5503),
    [anon_sym_LT] = ACTIONS(5503),
    [anon_sym_LT_LT] = ACTIONS(5505),
    [anon_sym_GT_GT] = ACTIONS(5505),
    [anon_sym_COLON] = ACTIONS(5505),
    [anon_sym_SEMI] = ACTIONS(5505),
    [anon_sym___extension__] = ACTIONS(5503),
    [anon_sym___attribute__] = ACTIONS(5503),
    [anon_sym___based] = ACTIONS(5503),
    [anon_sym_LBRACE] = ACTIONS(5505),
    [anon_sym_RBRACE] = ACTIONS(5505),
    [anon_sym_signed] = ACTIONS(5503),
    [anon_sym_unsigned] = ACTIONS(5503),
    [anon_sym_long] = ACTIONS(5503),
    [anon_sym_short] = ACTIONS(5503),
    [anon_sym_LBRACK] = ACTIONS(5505),
    [anon_sym_RBRACK] = ACTIONS(5505),
    [anon_sym_const] = ACTIONS(5503),
    [anon_sym_constexpr] = ACTIONS(5503),
    [anon_sym_volatile] = ACTIONS(5503),
    [anon_sym_restrict] = ACTIONS(5503),
    [anon_sym___restrict__] = ACTIONS(5503),
    [anon_sym__Atomic] = ACTIONS(5503),
    [anon_sym__Noreturn] = ACTIONS(5503),
    [anon_sym_noreturn] = ACTIONS(5503),
    [anon_sym_mutable] = ACTIONS(5503),
    [anon_sym_constinit] = ACTIONS(5503),
    [anon_sym_consteval] = ACTIONS(5503),
    [anon_sym_alignas] = ACTIONS(5503),
    [anon_sym__Alignas] = ACTIONS(5503),
    [sym_primitive_type] = ACTIONS(5503),
    [anon_sym_QMARK] = ACTIONS(5505),
    [anon_sym_LT_EQ_GT] = ACTIONS(5505),
    [anon_sym_or] = ACTIONS(5503),
    [anon_sym_and] = ACTIONS(5503),
    [anon_sym_bitor] = ACTIONS(5503),
    [anon_sym_xor] = ACTIONS(5503),
    [anon_sym_bitand] = ACTIONS(5503),
    [anon_sym_not_eq] = ACTIONS(5503),
    [anon_sym_DASH_DASH] = ACTIONS(5505),
    [anon_sym_PLUS_PLUS] = ACTIONS(5505),
    [anon_sym_DOT] = ACTIONS(5503),
    [anon_sym_DOT_STAR] = ACTIONS(5505),
    [anon_sym_DASH_GT] = ACTIONS(5505),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5503),
    [anon_sym_decltype] = ACTIONS(5503),
    [anon_sym_final] = ACTIONS(5503),
    [anon_sym_override] = ACTIONS(5503),
    [anon_sym_requires] = ACTIONS(5503),
  },
  [2466] = {
    [sym_attribute_specifier] = STATE(2286),
    [sym_field_declaration_list] = STATE(2320),
    [sym_virtual_specifier] = STATE(6832),
    [sym_base_class_clause] = STATE(7803),
    [sym_identifier] = ACTIONS(5327),
    [anon_sym_LPAREN2] = ACTIONS(5329),
    [anon_sym_STAR] = ACTIONS(5329),
    [anon_sym_AMP_AMP] = ACTIONS(5329),
    [anon_sym_AMP] = ACTIONS(5327),
    [anon_sym_COLON] = ACTIONS(5813),
    [anon_sym_SEMI] = ACTIONS(5329),
    [anon_sym___extension__] = ACTIONS(5327),
    [anon_sym_in] = ACTIONS(5327),
    [anon_sym_out] = ACTIONS(5327),
    [anon_sym_inout] = ACTIONS(5327),
    [anon_sym_extern] = ACTIONS(5327),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5329),
    [anon_sym___declspec] = ACTIONS(5327),
    [anon_sym___based] = ACTIONS(5327),
    [anon_sym_LBRACE] = ACTIONS(5331),
    [anon_sym_LBRACK] = ACTIONS(5327),
    [anon_sym_static] = ACTIONS(5327),
    [anon_sym_register] = ACTIONS(5327),
    [anon_sym_inline] = ACTIONS(5327),
    [anon_sym___inline] = ACTIONS(5327),
    [anon_sym___inline__] = ACTIONS(5327),
    [anon_sym___forceinline] = ACTIONS(5327),
    [anon_sym_thread_local] = ACTIONS(5327),
    [anon_sym___thread] = ACTIONS(5327),
    [anon_sym_const] = ACTIONS(5327),
    [anon_sym_constexpr] = ACTIONS(5327),
    [anon_sym_volatile] = ACTIONS(5327),
    [anon_sym_restrict] = ACTIONS(5327),
    [anon_sym___restrict__] = ACTIONS(5327),
    [anon_sym__Atomic] = ACTIONS(5327),
    [anon_sym__Noreturn] = ACTIONS(5327),
    [anon_sym_noreturn] = ACTIONS(5327),
    [anon_sym_mutable] = ACTIONS(5327),
    [anon_sym_constinit] = ACTIONS(5327),
    [anon_sym_consteval] = ACTIONS(5327),
    [anon_sym_alignas] = ACTIONS(5327),
    [anon_sym__Alignas] = ACTIONS(5327),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5327),
    [anon_sym_decltype] = ACTIONS(5327),
    [anon_sym_final] = ACTIONS(1915),
    [anon_sym_override] = ACTIONS(1915),
    [sym_virtual] = ACTIONS(5327),
    [anon_sym_operator] = ACTIONS(5327),
    [anon_sym_precise] = ACTIONS(5327),
    [anon_sym_shared] = ACTIONS(5327),
    [anon_sym_groupshared] = ACTIONS(5327),
    [anon_sym_uniform] = ACTIONS(5327),
    [anon_sym_row_major] = ACTIONS(5327),
    [anon_sym_column_major] = ACTIONS(5327),
    [anon_sym_globallycoherent] = ACTIONS(5327),
    [anon_sym_centroid] = ACTIONS(5327),
    [anon_sym_noperspective] = ACTIONS(5327),
    [anon_sym_nointerpolation] = ACTIONS(5327),
    [anon_sym_sample] = ACTIONS(5327),
    [anon_sym_linear] = ACTIONS(5327),
    [anon_sym_snorm] = ACTIONS(5327),
    [anon_sym_unorm] = ACTIONS(5327),
    [anon_sym_point] = ACTIONS(5327),
    [anon_sym_line] = ACTIONS(5327),
    [anon_sym_triangleadj] = ACTIONS(5327),
    [anon_sym_lineadj] = ACTIONS(5327),
    [anon_sym_triangle] = ACTIONS(5327),
  },
  [2467] = {
    [sym_identifier] = ACTIONS(5495),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5497),
    [anon_sym_COMMA] = ACTIONS(5497),
    [anon_sym_RPAREN] = ACTIONS(5497),
    [anon_sym_LPAREN2] = ACTIONS(5497),
    [anon_sym_DASH] = ACTIONS(5495),
    [anon_sym_PLUS] = ACTIONS(5495),
    [anon_sym_STAR] = ACTIONS(5497),
    [anon_sym_SLASH] = ACTIONS(5495),
    [anon_sym_PERCENT] = ACTIONS(5497),
    [anon_sym_PIPE_PIPE] = ACTIONS(5497),
    [anon_sym_AMP_AMP] = ACTIONS(5497),
    [anon_sym_PIPE] = ACTIONS(5495),
    [anon_sym_CARET] = ACTIONS(5497),
    [anon_sym_AMP] = ACTIONS(5495),
    [anon_sym_EQ_EQ] = ACTIONS(5497),
    [anon_sym_BANG_EQ] = ACTIONS(5497),
    [anon_sym_GT] = ACTIONS(5495),
    [anon_sym_GT_EQ] = ACTIONS(5497),
    [anon_sym_LT_EQ] = ACTIONS(5495),
    [anon_sym_LT] = ACTIONS(5495),
    [anon_sym_LT_LT] = ACTIONS(5497),
    [anon_sym_GT_GT] = ACTIONS(5497),
    [anon_sym_COLON] = ACTIONS(5497),
    [anon_sym_SEMI] = ACTIONS(5497),
    [anon_sym___extension__] = ACTIONS(5495),
    [anon_sym___attribute__] = ACTIONS(5495),
    [anon_sym___based] = ACTIONS(5495),
    [anon_sym_LBRACE] = ACTIONS(5497),
    [anon_sym_RBRACE] = ACTIONS(5497),
    [anon_sym_signed] = ACTIONS(5495),
    [anon_sym_unsigned] = ACTIONS(5495),
    [anon_sym_long] = ACTIONS(5495),
    [anon_sym_short] = ACTIONS(5495),
    [anon_sym_LBRACK] = ACTIONS(5497),
    [anon_sym_RBRACK] = ACTIONS(5497),
    [anon_sym_const] = ACTIONS(5495),
    [anon_sym_constexpr] = ACTIONS(5495),
    [anon_sym_volatile] = ACTIONS(5495),
    [anon_sym_restrict] = ACTIONS(5495),
    [anon_sym___restrict__] = ACTIONS(5495),
    [anon_sym__Atomic] = ACTIONS(5495),
    [anon_sym__Noreturn] = ACTIONS(5495),
    [anon_sym_noreturn] = ACTIONS(5495),
    [anon_sym_mutable] = ACTIONS(5495),
    [anon_sym_constinit] = ACTIONS(5495),
    [anon_sym_consteval] = ACTIONS(5495),
    [anon_sym_alignas] = ACTIONS(5495),
    [anon_sym__Alignas] = ACTIONS(5495),
    [sym_primitive_type] = ACTIONS(5495),
    [anon_sym_QMARK] = ACTIONS(5497),
    [anon_sym_LT_EQ_GT] = ACTIONS(5497),
    [anon_sym_or] = ACTIONS(5495),
    [anon_sym_and] = ACTIONS(5495),
    [anon_sym_bitor] = ACTIONS(5495),
    [anon_sym_xor] = ACTIONS(5495),
    [anon_sym_bitand] = ACTIONS(5495),
    [anon_sym_not_eq] = ACTIONS(5495),
    [anon_sym_DASH_DASH] = ACTIONS(5497),
    [anon_sym_PLUS_PLUS] = ACTIONS(5497),
    [anon_sym_DOT] = ACTIONS(5495),
    [anon_sym_DOT_STAR] = ACTIONS(5497),
    [anon_sym_DASH_GT] = ACTIONS(5497),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5495),
    [anon_sym_decltype] = ACTIONS(5495),
    [anon_sym_final] = ACTIONS(5495),
    [anon_sym_override] = ACTIONS(5495),
    [anon_sym_requires] = ACTIONS(5495),
  },
  [2468] = {
    [sym_identifier] = ACTIONS(5515),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5517),
    [anon_sym_COMMA] = ACTIONS(5517),
    [anon_sym_RPAREN] = ACTIONS(5517),
    [anon_sym_LPAREN2] = ACTIONS(5517),
    [anon_sym_DASH] = ACTIONS(5515),
    [anon_sym_PLUS] = ACTIONS(5515),
    [anon_sym_STAR] = ACTIONS(5517),
    [anon_sym_SLASH] = ACTIONS(5515),
    [anon_sym_PERCENT] = ACTIONS(5517),
    [anon_sym_PIPE_PIPE] = ACTIONS(5517),
    [anon_sym_AMP_AMP] = ACTIONS(5517),
    [anon_sym_PIPE] = ACTIONS(5515),
    [anon_sym_CARET] = ACTIONS(5517),
    [anon_sym_AMP] = ACTIONS(5515),
    [anon_sym_EQ_EQ] = ACTIONS(5517),
    [anon_sym_BANG_EQ] = ACTIONS(5517),
    [anon_sym_GT] = ACTIONS(5515),
    [anon_sym_GT_EQ] = ACTIONS(5517),
    [anon_sym_LT_EQ] = ACTIONS(5515),
    [anon_sym_LT] = ACTIONS(5515),
    [anon_sym_LT_LT] = ACTIONS(5517),
    [anon_sym_GT_GT] = ACTIONS(5517),
    [anon_sym_COLON] = ACTIONS(5517),
    [anon_sym_SEMI] = ACTIONS(5517),
    [anon_sym___extension__] = ACTIONS(5515),
    [anon_sym___attribute__] = ACTIONS(5515),
    [anon_sym___based] = ACTIONS(5515),
    [anon_sym_LBRACE] = ACTIONS(5517),
    [anon_sym_RBRACE] = ACTIONS(5517),
    [anon_sym_signed] = ACTIONS(5515),
    [anon_sym_unsigned] = ACTIONS(5515),
    [anon_sym_long] = ACTIONS(5515),
    [anon_sym_short] = ACTIONS(5515),
    [anon_sym_LBRACK] = ACTIONS(5517),
    [anon_sym_RBRACK] = ACTIONS(5517),
    [anon_sym_const] = ACTIONS(5515),
    [anon_sym_constexpr] = ACTIONS(5515),
    [anon_sym_volatile] = ACTIONS(5515),
    [anon_sym_restrict] = ACTIONS(5515),
    [anon_sym___restrict__] = ACTIONS(5515),
    [anon_sym__Atomic] = ACTIONS(5515),
    [anon_sym__Noreturn] = ACTIONS(5515),
    [anon_sym_noreturn] = ACTIONS(5515),
    [anon_sym_mutable] = ACTIONS(5515),
    [anon_sym_constinit] = ACTIONS(5515),
    [anon_sym_consteval] = ACTIONS(5515),
    [anon_sym_alignas] = ACTIONS(5515),
    [anon_sym__Alignas] = ACTIONS(5515),
    [sym_primitive_type] = ACTIONS(5515),
    [anon_sym_QMARK] = ACTIONS(5517),
    [anon_sym_LT_EQ_GT] = ACTIONS(5517),
    [anon_sym_or] = ACTIONS(5515),
    [anon_sym_and] = ACTIONS(5515),
    [anon_sym_bitor] = ACTIONS(5515),
    [anon_sym_xor] = ACTIONS(5515),
    [anon_sym_bitand] = ACTIONS(5515),
    [anon_sym_not_eq] = ACTIONS(5515),
    [anon_sym_DASH_DASH] = ACTIONS(5517),
    [anon_sym_PLUS_PLUS] = ACTIONS(5517),
    [anon_sym_DOT] = ACTIONS(5515),
    [anon_sym_DOT_STAR] = ACTIONS(5517),
    [anon_sym_DASH_GT] = ACTIONS(5517),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5515),
    [anon_sym_decltype] = ACTIONS(5515),
    [anon_sym_final] = ACTIONS(5515),
    [anon_sym_override] = ACTIONS(5515),
    [anon_sym_requires] = ACTIONS(5515),
  },
  [2469] = {
    [sym_template_argument_list] = STATE(2489),
    [sym_identifier] = ACTIONS(1933),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1935),
    [anon_sym_COMMA] = ACTIONS(1935),
    [anon_sym_RPAREN] = ACTIONS(1935),
    [aux_sym_preproc_if_token2] = ACTIONS(1935),
    [aux_sym_preproc_else_token1] = ACTIONS(1935),
    [aux_sym_preproc_elif_token1] = ACTIONS(1933),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1935),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1935),
    [anon_sym_LPAREN2] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1933),
    [anon_sym_PLUS] = ACTIONS(1933),
    [anon_sym_STAR] = ACTIONS(1933),
    [anon_sym_SLASH] = ACTIONS(1933),
    [anon_sym_PERCENT] = ACTIONS(1933),
    [anon_sym_PIPE_PIPE] = ACTIONS(1935),
    [anon_sym_AMP_AMP] = ACTIONS(1935),
    [anon_sym_PIPE] = ACTIONS(1933),
    [anon_sym_CARET] = ACTIONS(1933),
    [anon_sym_AMP] = ACTIONS(1933),
    [anon_sym_EQ_EQ] = ACTIONS(1935),
    [anon_sym_BANG_EQ] = ACTIONS(1935),
    [anon_sym_GT] = ACTIONS(1933),
    [anon_sym_GT_EQ] = ACTIONS(1935),
    [anon_sym_LT_EQ] = ACTIONS(1933),
    [anon_sym_LT] = ACTIONS(5847),
    [anon_sym_LT_LT] = ACTIONS(1933),
    [anon_sym_GT_GT] = ACTIONS(1933),
    [anon_sym_COLON] = ACTIONS(1933),
    [anon_sym_SEMI] = ACTIONS(1935),
    [anon_sym___attribute__] = ACTIONS(1933),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1935),
    [anon_sym_RBRACE] = ACTIONS(1935),
    [anon_sym_LBRACK] = ACTIONS(1935),
    [anon_sym_RBRACK] = ACTIONS(1935),
    [anon_sym_EQ] = ACTIONS(1933),
    [anon_sym_QMARK] = ACTIONS(1935),
    [anon_sym_STAR_EQ] = ACTIONS(1935),
    [anon_sym_SLASH_EQ] = ACTIONS(1935),
    [anon_sym_PERCENT_EQ] = ACTIONS(1935),
    [anon_sym_PLUS_EQ] = ACTIONS(1935),
    [anon_sym_DASH_EQ] = ACTIONS(1935),
    [anon_sym_LT_LT_EQ] = ACTIONS(1935),
    [anon_sym_GT_GT_EQ] = ACTIONS(1935),
    [anon_sym_AMP_EQ] = ACTIONS(1935),
    [anon_sym_CARET_EQ] = ACTIONS(1935),
    [anon_sym_PIPE_EQ] = ACTIONS(1935),
    [anon_sym_and_eq] = ACTIONS(1933),
    [anon_sym_or_eq] = ACTIONS(1933),
    [anon_sym_xor_eq] = ACTIONS(1933),
    [anon_sym_LT_EQ_GT] = ACTIONS(1935),
    [anon_sym_or] = ACTIONS(1933),
    [anon_sym_and] = ACTIONS(1933),
    [anon_sym_bitor] = ACTIONS(1933),
    [anon_sym_xor] = ACTIONS(1933),
    [anon_sym_bitand] = ACTIONS(1933),
    [anon_sym_not_eq] = ACTIONS(1933),
    [anon_sym_DASH_DASH] = ACTIONS(1935),
    [anon_sym_PLUS_PLUS] = ACTIONS(1935),
    [anon_sym_DOT] = ACTIONS(1933),
    [anon_sym_DOT_STAR] = ACTIONS(1935),
    [anon_sym_DASH_GT] = ACTIONS(1935),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1933),
    [anon_sym_decltype] = ACTIONS(1933),
    [anon_sym_final] = ACTIONS(1933),
    [anon_sym_override] = ACTIONS(1933),
  },
  [2470] = {
    [sym_argument_list] = STATE(2794),
    [sym_initializer_list] = STATE(2794),
    [sym_decltype_auto] = STATE(2607),
    [sym_new_declarator] = STATE(2636),
    [sym_identifier] = ACTIONS(5850),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5852),
    [anon_sym_COMMA] = ACTIONS(5852),
    [anon_sym_RPAREN] = ACTIONS(5852),
    [aux_sym_preproc_if_token2] = ACTIONS(5852),
    [aux_sym_preproc_else_token1] = ACTIONS(5852),
    [aux_sym_preproc_elif_token1] = ACTIONS(5850),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5852),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5852),
    [anon_sym_LPAREN2] = ACTIONS(5854),
    [anon_sym_DASH] = ACTIONS(5850),
    [anon_sym_PLUS] = ACTIONS(5850),
    [anon_sym_STAR] = ACTIONS(5850),
    [anon_sym_SLASH] = ACTIONS(5850),
    [anon_sym_PERCENT] = ACTIONS(5850),
    [anon_sym_PIPE_PIPE] = ACTIONS(5852),
    [anon_sym_AMP_AMP] = ACTIONS(5852),
    [anon_sym_PIPE] = ACTIONS(5850),
    [anon_sym_CARET] = ACTIONS(5850),
    [anon_sym_AMP] = ACTIONS(5850),
    [anon_sym_EQ_EQ] = ACTIONS(5852),
    [anon_sym_BANG_EQ] = ACTIONS(5852),
    [anon_sym_GT] = ACTIONS(5850),
    [anon_sym_GT_EQ] = ACTIONS(5852),
    [anon_sym_LT_EQ] = ACTIONS(5850),
    [anon_sym_LT] = ACTIONS(5850),
    [anon_sym_LT_LT] = ACTIONS(5850),
    [anon_sym_GT_GT] = ACTIONS(5850),
    [anon_sym_COLON] = ACTIONS(5852),
    [anon_sym_SEMI] = ACTIONS(5852),
    [anon_sym___attribute__] = ACTIONS(5850),
    [anon_sym_LBRACE] = ACTIONS(3523),
    [anon_sym_RBRACE] = ACTIONS(5852),
    [anon_sym_LBRACK] = ACTIONS(5856),
    [anon_sym_RBRACK] = ACTIONS(5852),
    [anon_sym_EQ] = ACTIONS(5850),
    [anon_sym_QMARK] = ACTIONS(5852),
    [anon_sym_STAR_EQ] = ACTIONS(5852),
    [anon_sym_SLASH_EQ] = ACTIONS(5852),
    [anon_sym_PERCENT_EQ] = ACTIONS(5852),
    [anon_sym_PLUS_EQ] = ACTIONS(5852),
    [anon_sym_DASH_EQ] = ACTIONS(5852),
    [anon_sym_LT_LT_EQ] = ACTIONS(5852),
    [anon_sym_GT_GT_EQ] = ACTIONS(5852),
    [anon_sym_AMP_EQ] = ACTIONS(5852),
    [anon_sym_CARET_EQ] = ACTIONS(5852),
    [anon_sym_PIPE_EQ] = ACTIONS(5852),
    [anon_sym_and_eq] = ACTIONS(5850),
    [anon_sym_or_eq] = ACTIONS(5850),
    [anon_sym_xor_eq] = ACTIONS(5850),
    [anon_sym_LT_EQ_GT] = ACTIONS(5852),
    [anon_sym_or] = ACTIONS(5850),
    [anon_sym_and] = ACTIONS(5850),
    [anon_sym_bitor] = ACTIONS(5850),
    [anon_sym_xor] = ACTIONS(5850),
    [anon_sym_bitand] = ACTIONS(5850),
    [anon_sym_not_eq] = ACTIONS(5850),
    [anon_sym_DASH_DASH] = ACTIONS(5852),
    [anon_sym_PLUS_PLUS] = ACTIONS(5852),
    [anon_sym_DOT] = ACTIONS(5850),
    [anon_sym_DOT_STAR] = ACTIONS(5852),
    [anon_sym_DASH_GT] = ACTIONS(5852),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5858),
    [anon_sym_decltype] = ACTIONS(5860),
  },
  [2471] = {
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5421),
    [anon_sym_COMMA] = ACTIONS(5421),
    [anon_sym_RPAREN] = ACTIONS(5421),
    [anon_sym_LPAREN2] = ACTIONS(5421),
    [anon_sym_DASH] = ACTIONS(5419),
    [anon_sym_PLUS] = ACTIONS(5419),
    [anon_sym_STAR] = ACTIONS(5421),
    [anon_sym_SLASH] = ACTIONS(5419),
    [anon_sym_PERCENT] = ACTIONS(5421),
    [anon_sym_PIPE_PIPE] = ACTIONS(5421),
    [anon_sym_AMP_AMP] = ACTIONS(5421),
    [anon_sym_PIPE] = ACTIONS(5419),
    [anon_sym_CARET] = ACTIONS(5421),
    [anon_sym_AMP] = ACTIONS(5419),
    [anon_sym_EQ_EQ] = ACTIONS(5421),
    [anon_sym_BANG_EQ] = ACTIONS(5421),
    [anon_sym_GT] = ACTIONS(5419),
    [anon_sym_GT_EQ] = ACTIONS(5421),
    [anon_sym_LT_EQ] = ACTIONS(5419),
    [anon_sym_LT] = ACTIONS(5419),
    [anon_sym_LT_LT] = ACTIONS(5421),
    [anon_sym_GT_GT] = ACTIONS(5421),
    [anon_sym_COLON] = ACTIONS(5421),
    [anon_sym_SEMI] = ACTIONS(5421),
    [anon_sym___extension__] = ACTIONS(5419),
    [anon_sym___attribute__] = ACTIONS(5419),
    [anon_sym___based] = ACTIONS(5419),
    [anon_sym_LBRACE] = ACTIONS(5421),
    [anon_sym_RBRACE] = ACTIONS(5421),
    [anon_sym_signed] = ACTIONS(5419),
    [anon_sym_unsigned] = ACTIONS(5419),
    [anon_sym_long] = ACTIONS(5419),
    [anon_sym_short] = ACTIONS(5419),
    [anon_sym_LBRACK] = ACTIONS(5421),
    [anon_sym_RBRACK] = ACTIONS(5421),
    [anon_sym_const] = ACTIONS(5419),
    [anon_sym_constexpr] = ACTIONS(5419),
    [anon_sym_volatile] = ACTIONS(5419),
    [anon_sym_restrict] = ACTIONS(5419),
    [anon_sym___restrict__] = ACTIONS(5419),
    [anon_sym__Atomic] = ACTIONS(5419),
    [anon_sym__Noreturn] = ACTIONS(5419),
    [anon_sym_noreturn] = ACTIONS(5419),
    [anon_sym_mutable] = ACTIONS(5419),
    [anon_sym_constinit] = ACTIONS(5419),
    [anon_sym_consteval] = ACTIONS(5419),
    [anon_sym_alignas] = ACTIONS(5419),
    [anon_sym__Alignas] = ACTIONS(5419),
    [sym_primitive_type] = ACTIONS(5419),
    [anon_sym_QMARK] = ACTIONS(5421),
    [anon_sym_LT_EQ_GT] = ACTIONS(5421),
    [anon_sym_or] = ACTIONS(5419),
    [anon_sym_and] = ACTIONS(5419),
    [anon_sym_bitor] = ACTIONS(5419),
    [anon_sym_xor] = ACTIONS(5419),
    [anon_sym_bitand] = ACTIONS(5419),
    [anon_sym_not_eq] = ACTIONS(5419),
    [anon_sym_DASH_DASH] = ACTIONS(5421),
    [anon_sym_PLUS_PLUS] = ACTIONS(5421),
    [anon_sym_DOT] = ACTIONS(5419),
    [anon_sym_DOT_STAR] = ACTIONS(5421),
    [anon_sym_DASH_GT] = ACTIONS(5421),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5419),
    [anon_sym_decltype] = ACTIONS(5419),
    [anon_sym_final] = ACTIONS(5419),
    [anon_sym_override] = ACTIONS(5419),
    [anon_sym_requires] = ACTIONS(5419),
  },
  [2472] = {
    [sym_identifier] = ACTIONS(5153),
    [anon_sym_LPAREN2] = ACTIONS(5155),
    [anon_sym_BANG] = ACTIONS(5155),
    [anon_sym_TILDE] = ACTIONS(5155),
    [anon_sym_DASH] = ACTIONS(5153),
    [anon_sym_PLUS] = ACTIONS(5153),
    [anon_sym_STAR] = ACTIONS(5155),
    [anon_sym_AMP] = ACTIONS(5155),
    [anon_sym___extension__] = ACTIONS(5153),
    [anon_sym_COLON_COLON] = ACTIONS(5155),
    [anon_sym_LBRACK] = ACTIONS(5155),
    [anon_sym_static] = ACTIONS(5153),
    [anon_sym_RBRACK] = ACTIONS(5155),
    [anon_sym_const] = ACTIONS(5153),
    [anon_sym_constexpr] = ACTIONS(5153),
    [anon_sym_volatile] = ACTIONS(5153),
    [anon_sym_restrict] = ACTIONS(5153),
    [anon_sym___restrict__] = ACTIONS(5153),
    [anon_sym__Atomic] = ACTIONS(5153),
    [anon_sym__Noreturn] = ACTIONS(5153),
    [anon_sym_noreturn] = ACTIONS(5153),
    [anon_sym_mutable] = ACTIONS(5153),
    [anon_sym_constinit] = ACTIONS(5153),
    [anon_sym_consteval] = ACTIONS(5153),
    [anon_sym_alignas] = ACTIONS(5153),
    [anon_sym__Alignas] = ACTIONS(5153),
    [sym_primitive_type] = ACTIONS(5153),
    [anon_sym_not] = ACTIONS(5153),
    [anon_sym_compl] = ACTIONS(5153),
    [anon_sym_DASH_DASH] = ACTIONS(5155),
    [anon_sym_PLUS_PLUS] = ACTIONS(5155),
    [anon_sym_sizeof] = ACTIONS(5153),
    [anon_sym___alignof__] = ACTIONS(5153),
    [anon_sym___alignof] = ACTIONS(5153),
    [anon_sym__alignof] = ACTIONS(5153),
    [anon_sym_alignof] = ACTIONS(5153),
    [anon_sym__Alignof] = ACTIONS(5153),
    [anon_sym_offsetof] = ACTIONS(5153),
    [anon_sym__Generic] = ACTIONS(5153),
    [anon_sym_asm] = ACTIONS(5153),
    [anon_sym___asm__] = ACTIONS(5153),
    [sym_number_literal] = ACTIONS(5155),
    [anon_sym_L_SQUOTE] = ACTIONS(5155),
    [anon_sym_u_SQUOTE] = ACTIONS(5155),
    [anon_sym_U_SQUOTE] = ACTIONS(5155),
    [anon_sym_u8_SQUOTE] = ACTIONS(5155),
    [anon_sym_SQUOTE] = ACTIONS(5155),
    [anon_sym_L_DQUOTE] = ACTIONS(5155),
    [anon_sym_u_DQUOTE] = ACTIONS(5155),
    [anon_sym_U_DQUOTE] = ACTIONS(5155),
    [anon_sym_u8_DQUOTE] = ACTIONS(5155),
    [anon_sym_DQUOTE] = ACTIONS(5155),
    [sym_true] = ACTIONS(5153),
    [sym_false] = ACTIONS(5153),
    [anon_sym_NULL] = ACTIONS(5153),
    [anon_sym_nullptr] = ACTIONS(5153),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(5153),
    [anon_sym_template] = ACTIONS(5153),
    [anon_sym_delete] = ACTIONS(5153),
    [anon_sym_R_DQUOTE] = ACTIONS(5155),
    [anon_sym_LR_DQUOTE] = ACTIONS(5155),
    [anon_sym_uR_DQUOTE] = ACTIONS(5155),
    [anon_sym_UR_DQUOTE] = ACTIONS(5155),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5155),
    [anon_sym_co_await] = ACTIONS(5153),
    [anon_sym_new] = ACTIONS(5153),
    [anon_sym_requires] = ACTIONS(5153),
    [sym_this] = ACTIONS(5153),
  },
  [2473] = {
    [sym_argument_list] = STATE(2849),
    [sym_initializer_list] = STATE(2849),
    [sym_decltype_auto] = STATE(2607),
    [sym_new_declarator] = STATE(2643),
    [sym_identifier] = ACTIONS(5862),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5864),
    [anon_sym_COMMA] = ACTIONS(5864),
    [anon_sym_RPAREN] = ACTIONS(5864),
    [aux_sym_preproc_if_token2] = ACTIONS(5864),
    [aux_sym_preproc_else_token1] = ACTIONS(5864),
    [aux_sym_preproc_elif_token1] = ACTIONS(5862),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5864),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5864),
    [anon_sym_LPAREN2] = ACTIONS(5854),
    [anon_sym_DASH] = ACTIONS(5862),
    [anon_sym_PLUS] = ACTIONS(5862),
    [anon_sym_STAR] = ACTIONS(5862),
    [anon_sym_SLASH] = ACTIONS(5862),
    [anon_sym_PERCENT] = ACTIONS(5862),
    [anon_sym_PIPE_PIPE] = ACTIONS(5864),
    [anon_sym_AMP_AMP] = ACTIONS(5864),
    [anon_sym_PIPE] = ACTIONS(5862),
    [anon_sym_CARET] = ACTIONS(5862),
    [anon_sym_AMP] = ACTIONS(5862),
    [anon_sym_EQ_EQ] = ACTIONS(5864),
    [anon_sym_BANG_EQ] = ACTIONS(5864),
    [anon_sym_GT] = ACTIONS(5862),
    [anon_sym_GT_EQ] = ACTIONS(5864),
    [anon_sym_LT_EQ] = ACTIONS(5862),
    [anon_sym_LT] = ACTIONS(5862),
    [anon_sym_LT_LT] = ACTIONS(5862),
    [anon_sym_GT_GT] = ACTIONS(5862),
    [anon_sym_COLON] = ACTIONS(5864),
    [anon_sym_SEMI] = ACTIONS(5864),
    [anon_sym___attribute__] = ACTIONS(5862),
    [anon_sym_LBRACE] = ACTIONS(3523),
    [anon_sym_RBRACE] = ACTIONS(5864),
    [anon_sym_LBRACK] = ACTIONS(5856),
    [anon_sym_RBRACK] = ACTIONS(5864),
    [anon_sym_EQ] = ACTIONS(5862),
    [anon_sym_QMARK] = ACTIONS(5864),
    [anon_sym_STAR_EQ] = ACTIONS(5864),
    [anon_sym_SLASH_EQ] = ACTIONS(5864),
    [anon_sym_PERCENT_EQ] = ACTIONS(5864),
    [anon_sym_PLUS_EQ] = ACTIONS(5864),
    [anon_sym_DASH_EQ] = ACTIONS(5864),
    [anon_sym_LT_LT_EQ] = ACTIONS(5864),
    [anon_sym_GT_GT_EQ] = ACTIONS(5864),
    [anon_sym_AMP_EQ] = ACTIONS(5864),
    [anon_sym_CARET_EQ] = ACTIONS(5864),
    [anon_sym_PIPE_EQ] = ACTIONS(5864),
    [anon_sym_and_eq] = ACTIONS(5862),
    [anon_sym_or_eq] = ACTIONS(5862),
    [anon_sym_xor_eq] = ACTIONS(5862),
    [anon_sym_LT_EQ_GT] = ACTIONS(5864),
    [anon_sym_or] = ACTIONS(5862),
    [anon_sym_and] = ACTIONS(5862),
    [anon_sym_bitor] = ACTIONS(5862),
    [anon_sym_xor] = ACTIONS(5862),
    [anon_sym_bitand] = ACTIONS(5862),
    [anon_sym_not_eq] = ACTIONS(5862),
    [anon_sym_DASH_DASH] = ACTIONS(5864),
    [anon_sym_PLUS_PLUS] = ACTIONS(5864),
    [anon_sym_DOT] = ACTIONS(5862),
    [anon_sym_DOT_STAR] = ACTIONS(5864),
    [anon_sym_DASH_GT] = ACTIONS(5864),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5858),
    [anon_sym_decltype] = ACTIONS(5860),
  },
  [2474] = {
    [sym_identifier] = ACTIONS(5318),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5320),
    [anon_sym_COMMA] = ACTIONS(5320),
    [anon_sym_RPAREN] = ACTIONS(5320),
    [anon_sym_LPAREN2] = ACTIONS(5320),
    [anon_sym_DASH] = ACTIONS(5318),
    [anon_sym_PLUS] = ACTIONS(5318),
    [anon_sym_STAR] = ACTIONS(5320),
    [anon_sym_SLASH] = ACTIONS(5318),
    [anon_sym_PERCENT] = ACTIONS(5320),
    [anon_sym_PIPE_PIPE] = ACTIONS(5320),
    [anon_sym_AMP_AMP] = ACTIONS(5320),
    [anon_sym_PIPE] = ACTIONS(5318),
    [anon_sym_CARET] = ACTIONS(5320),
    [anon_sym_AMP] = ACTIONS(5318),
    [anon_sym_EQ_EQ] = ACTIONS(5320),
    [anon_sym_BANG_EQ] = ACTIONS(5320),
    [anon_sym_GT] = ACTIONS(5318),
    [anon_sym_GT_EQ] = ACTIONS(5320),
    [anon_sym_LT_EQ] = ACTIONS(5318),
    [anon_sym_LT] = ACTIONS(5318),
    [anon_sym_LT_LT] = ACTIONS(5320),
    [anon_sym_GT_GT] = ACTIONS(5320),
    [anon_sym_COLON] = ACTIONS(5320),
    [anon_sym_SEMI] = ACTIONS(5320),
    [anon_sym___extension__] = ACTIONS(5318),
    [anon_sym___attribute__] = ACTIONS(5318),
    [anon_sym___based] = ACTIONS(5318),
    [anon_sym_LBRACE] = ACTIONS(5320),
    [anon_sym_RBRACE] = ACTIONS(5320),
    [anon_sym_signed] = ACTIONS(5318),
    [anon_sym_unsigned] = ACTIONS(5318),
    [anon_sym_long] = ACTIONS(5318),
    [anon_sym_short] = ACTIONS(5318),
    [anon_sym_LBRACK] = ACTIONS(5320),
    [anon_sym_RBRACK] = ACTIONS(5320),
    [anon_sym_const] = ACTIONS(5318),
    [anon_sym_constexpr] = ACTIONS(5318),
    [anon_sym_volatile] = ACTIONS(5318),
    [anon_sym_restrict] = ACTIONS(5318),
    [anon_sym___restrict__] = ACTIONS(5318),
    [anon_sym__Atomic] = ACTIONS(5318),
    [anon_sym__Noreturn] = ACTIONS(5318),
    [anon_sym_noreturn] = ACTIONS(5318),
    [anon_sym_mutable] = ACTIONS(5318),
    [anon_sym_constinit] = ACTIONS(5318),
    [anon_sym_consteval] = ACTIONS(5318),
    [anon_sym_alignas] = ACTIONS(5318),
    [anon_sym__Alignas] = ACTIONS(5318),
    [sym_primitive_type] = ACTIONS(5318),
    [anon_sym_QMARK] = ACTIONS(5320),
    [anon_sym_LT_EQ_GT] = ACTIONS(5320),
    [anon_sym_or] = ACTIONS(5318),
    [anon_sym_and] = ACTIONS(5318),
    [anon_sym_bitor] = ACTIONS(5318),
    [anon_sym_xor] = ACTIONS(5318),
    [anon_sym_bitand] = ACTIONS(5318),
    [anon_sym_not_eq] = ACTIONS(5318),
    [anon_sym_DASH_DASH] = ACTIONS(5320),
    [anon_sym_PLUS_PLUS] = ACTIONS(5320),
    [anon_sym_DOT] = ACTIONS(5318),
    [anon_sym_DOT_STAR] = ACTIONS(5320),
    [anon_sym_DASH_GT] = ACTIONS(5320),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5318),
    [anon_sym_decltype] = ACTIONS(5318),
    [anon_sym_final] = ACTIONS(5318),
    [anon_sym_override] = ACTIONS(5318),
    [anon_sym_requires] = ACTIONS(5318),
  },
  [2475] = {
    [sym_identifier] = ACTIONS(5318),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5320),
    [anon_sym_COMMA] = ACTIONS(5320),
    [anon_sym_RPAREN] = ACTIONS(5320),
    [anon_sym_LPAREN2] = ACTIONS(5320),
    [anon_sym_DASH] = ACTIONS(5318),
    [anon_sym_PLUS] = ACTIONS(5318),
    [anon_sym_STAR] = ACTIONS(5320),
    [anon_sym_SLASH] = ACTIONS(5318),
    [anon_sym_PERCENT] = ACTIONS(5320),
    [anon_sym_PIPE_PIPE] = ACTIONS(5320),
    [anon_sym_AMP_AMP] = ACTIONS(5320),
    [anon_sym_PIPE] = ACTIONS(5318),
    [anon_sym_CARET] = ACTIONS(5320),
    [anon_sym_AMP] = ACTIONS(5318),
    [anon_sym_EQ_EQ] = ACTIONS(5320),
    [anon_sym_BANG_EQ] = ACTIONS(5320),
    [anon_sym_GT] = ACTIONS(5318),
    [anon_sym_GT_EQ] = ACTIONS(5320),
    [anon_sym_LT_EQ] = ACTIONS(5318),
    [anon_sym_LT] = ACTIONS(5318),
    [anon_sym_LT_LT] = ACTIONS(5320),
    [anon_sym_GT_GT] = ACTIONS(5320),
    [anon_sym_COLON] = ACTIONS(5320),
    [anon_sym_SEMI] = ACTIONS(5320),
    [anon_sym___extension__] = ACTIONS(5318),
    [anon_sym___attribute__] = ACTIONS(5318),
    [anon_sym___based] = ACTIONS(5318),
    [anon_sym_LBRACE] = ACTIONS(5320),
    [anon_sym_RBRACE] = ACTIONS(5320),
    [anon_sym_signed] = ACTIONS(5318),
    [anon_sym_unsigned] = ACTIONS(5318),
    [anon_sym_long] = ACTIONS(5318),
    [anon_sym_short] = ACTIONS(5318),
    [anon_sym_LBRACK] = ACTIONS(5320),
    [anon_sym_RBRACK] = ACTIONS(5320),
    [anon_sym_const] = ACTIONS(5318),
    [anon_sym_constexpr] = ACTIONS(5318),
    [anon_sym_volatile] = ACTIONS(5318),
    [anon_sym_restrict] = ACTIONS(5318),
    [anon_sym___restrict__] = ACTIONS(5318),
    [anon_sym__Atomic] = ACTIONS(5318),
    [anon_sym__Noreturn] = ACTIONS(5318),
    [anon_sym_noreturn] = ACTIONS(5318),
    [anon_sym_mutable] = ACTIONS(5318),
    [anon_sym_constinit] = ACTIONS(5318),
    [anon_sym_consteval] = ACTIONS(5318),
    [anon_sym_alignas] = ACTIONS(5318),
    [anon_sym__Alignas] = ACTIONS(5318),
    [sym_primitive_type] = ACTIONS(5318),
    [anon_sym_QMARK] = ACTIONS(5320),
    [anon_sym_LT_EQ_GT] = ACTIONS(5320),
    [anon_sym_or] = ACTIONS(5318),
    [anon_sym_and] = ACTIONS(5318),
    [anon_sym_bitor] = ACTIONS(5318),
    [anon_sym_xor] = ACTIONS(5318),
    [anon_sym_bitand] = ACTIONS(5318),
    [anon_sym_not_eq] = ACTIONS(5318),
    [anon_sym_DASH_DASH] = ACTIONS(5320),
    [anon_sym_PLUS_PLUS] = ACTIONS(5320),
    [anon_sym_DOT] = ACTIONS(5318),
    [anon_sym_DOT_STAR] = ACTIONS(5320),
    [anon_sym_DASH_GT] = ACTIONS(5320),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5318),
    [anon_sym_decltype] = ACTIONS(5318),
    [anon_sym_final] = ACTIONS(5318),
    [anon_sym_override] = ACTIONS(5318),
    [anon_sym_requires] = ACTIONS(5318),
  },
  [2476] = {
    [sym_identifier] = ACTIONS(5353),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5355),
    [anon_sym_COMMA] = ACTIONS(5355),
    [anon_sym_RPAREN] = ACTIONS(5355),
    [anon_sym_LPAREN2] = ACTIONS(5355),
    [anon_sym_DASH] = ACTIONS(5353),
    [anon_sym_PLUS] = ACTIONS(5353),
    [anon_sym_STAR] = ACTIONS(5355),
    [anon_sym_SLASH] = ACTIONS(5353),
    [anon_sym_PERCENT] = ACTIONS(5355),
    [anon_sym_PIPE_PIPE] = ACTIONS(5355),
    [anon_sym_AMP_AMP] = ACTIONS(5355),
    [anon_sym_PIPE] = ACTIONS(5353),
    [anon_sym_CARET] = ACTIONS(5355),
    [anon_sym_AMP] = ACTIONS(5353),
    [anon_sym_EQ_EQ] = ACTIONS(5355),
    [anon_sym_BANG_EQ] = ACTIONS(5355),
    [anon_sym_GT] = ACTIONS(5353),
    [anon_sym_GT_EQ] = ACTIONS(5355),
    [anon_sym_LT_EQ] = ACTIONS(5353),
    [anon_sym_LT] = ACTIONS(5353),
    [anon_sym_LT_LT] = ACTIONS(5355),
    [anon_sym_GT_GT] = ACTIONS(5355),
    [anon_sym_COLON] = ACTIONS(5355),
    [anon_sym_SEMI] = ACTIONS(5355),
    [anon_sym___extension__] = ACTIONS(5353),
    [anon_sym___attribute__] = ACTIONS(5353),
    [anon_sym___based] = ACTIONS(5353),
    [anon_sym_LBRACE] = ACTIONS(5355),
    [anon_sym_RBRACE] = ACTIONS(5355),
    [anon_sym_signed] = ACTIONS(5353),
    [anon_sym_unsigned] = ACTIONS(5353),
    [anon_sym_long] = ACTIONS(5353),
    [anon_sym_short] = ACTIONS(5353),
    [anon_sym_LBRACK] = ACTIONS(5355),
    [anon_sym_RBRACK] = ACTIONS(5355),
    [anon_sym_const] = ACTIONS(5353),
    [anon_sym_constexpr] = ACTIONS(5353),
    [anon_sym_volatile] = ACTIONS(5353),
    [anon_sym_restrict] = ACTIONS(5353),
    [anon_sym___restrict__] = ACTIONS(5353),
    [anon_sym__Atomic] = ACTIONS(5353),
    [anon_sym__Noreturn] = ACTIONS(5353),
    [anon_sym_noreturn] = ACTIONS(5353),
    [anon_sym_mutable] = ACTIONS(5353),
    [anon_sym_constinit] = ACTIONS(5353),
    [anon_sym_consteval] = ACTIONS(5353),
    [anon_sym_alignas] = ACTIONS(5353),
    [anon_sym__Alignas] = ACTIONS(5353),
    [sym_primitive_type] = ACTIONS(5353),
    [anon_sym_QMARK] = ACTIONS(5355),
    [anon_sym_LT_EQ_GT] = ACTIONS(5355),
    [anon_sym_or] = ACTIONS(5353),
    [anon_sym_and] = ACTIONS(5353),
    [anon_sym_bitor] = ACTIONS(5353),
    [anon_sym_xor] = ACTIONS(5353),
    [anon_sym_bitand] = ACTIONS(5353),
    [anon_sym_not_eq] = ACTIONS(5353),
    [anon_sym_DASH_DASH] = ACTIONS(5355),
    [anon_sym_PLUS_PLUS] = ACTIONS(5355),
    [anon_sym_DOT] = ACTIONS(5353),
    [anon_sym_DOT_STAR] = ACTIONS(5355),
    [anon_sym_DASH_GT] = ACTIONS(5355),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5353),
    [anon_sym_decltype] = ACTIONS(5353),
    [anon_sym_final] = ACTIONS(5353),
    [anon_sym_override] = ACTIONS(5353),
    [anon_sym_requires] = ACTIONS(5353),
  },
  [2477] = {
    [sym_identifier] = ACTIONS(5443),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5445),
    [anon_sym_COMMA] = ACTIONS(5445),
    [anon_sym_RPAREN] = ACTIONS(5445),
    [anon_sym_LPAREN2] = ACTIONS(5445),
    [anon_sym_DASH] = ACTIONS(5443),
    [anon_sym_PLUS] = ACTIONS(5443),
    [anon_sym_STAR] = ACTIONS(5445),
    [anon_sym_SLASH] = ACTIONS(5443),
    [anon_sym_PERCENT] = ACTIONS(5445),
    [anon_sym_PIPE_PIPE] = ACTIONS(5445),
    [anon_sym_AMP_AMP] = ACTIONS(5445),
    [anon_sym_PIPE] = ACTIONS(5443),
    [anon_sym_CARET] = ACTIONS(5445),
    [anon_sym_AMP] = ACTIONS(5443),
    [anon_sym_EQ_EQ] = ACTIONS(5445),
    [anon_sym_BANG_EQ] = ACTIONS(5445),
    [anon_sym_GT] = ACTIONS(5443),
    [anon_sym_GT_EQ] = ACTIONS(5445),
    [anon_sym_LT_EQ] = ACTIONS(5443),
    [anon_sym_LT] = ACTIONS(5443),
    [anon_sym_LT_LT] = ACTIONS(5445),
    [anon_sym_GT_GT] = ACTIONS(5445),
    [anon_sym_COLON] = ACTIONS(5445),
    [anon_sym_SEMI] = ACTIONS(5445),
    [anon_sym___extension__] = ACTIONS(5443),
    [anon_sym___attribute__] = ACTIONS(5443),
    [anon_sym___based] = ACTIONS(5443),
    [anon_sym_LBRACE] = ACTIONS(5445),
    [anon_sym_RBRACE] = ACTIONS(5445),
    [anon_sym_signed] = ACTIONS(5443),
    [anon_sym_unsigned] = ACTIONS(5443),
    [anon_sym_long] = ACTIONS(5443),
    [anon_sym_short] = ACTIONS(5443),
    [anon_sym_LBRACK] = ACTIONS(5445),
    [anon_sym_RBRACK] = ACTIONS(5445),
    [anon_sym_const] = ACTIONS(5443),
    [anon_sym_constexpr] = ACTIONS(5443),
    [anon_sym_volatile] = ACTIONS(5443),
    [anon_sym_restrict] = ACTIONS(5443),
    [anon_sym___restrict__] = ACTIONS(5443),
    [anon_sym__Atomic] = ACTIONS(5443),
    [anon_sym__Noreturn] = ACTIONS(5443),
    [anon_sym_noreturn] = ACTIONS(5443),
    [anon_sym_mutable] = ACTIONS(5443),
    [anon_sym_constinit] = ACTIONS(5443),
    [anon_sym_consteval] = ACTIONS(5443),
    [anon_sym_alignas] = ACTIONS(5443),
    [anon_sym__Alignas] = ACTIONS(5443),
    [sym_primitive_type] = ACTIONS(5443),
    [anon_sym_QMARK] = ACTIONS(5445),
    [anon_sym_LT_EQ_GT] = ACTIONS(5445),
    [anon_sym_or] = ACTIONS(5443),
    [anon_sym_and] = ACTIONS(5443),
    [anon_sym_bitor] = ACTIONS(5443),
    [anon_sym_xor] = ACTIONS(5443),
    [anon_sym_bitand] = ACTIONS(5443),
    [anon_sym_not_eq] = ACTIONS(5443),
    [anon_sym_DASH_DASH] = ACTIONS(5445),
    [anon_sym_PLUS_PLUS] = ACTIONS(5445),
    [anon_sym_DOT] = ACTIONS(5443),
    [anon_sym_DOT_STAR] = ACTIONS(5445),
    [anon_sym_DASH_GT] = ACTIONS(5445),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5443),
    [anon_sym_decltype] = ACTIONS(5443),
    [anon_sym_final] = ACTIONS(5443),
    [anon_sym_override] = ACTIONS(5443),
    [anon_sym_requires] = ACTIONS(5443),
  },
  [2478] = {
    [sym_identifier] = ACTIONS(5447),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5449),
    [anon_sym_COMMA] = ACTIONS(5449),
    [anon_sym_RPAREN] = ACTIONS(5449),
    [anon_sym_LPAREN2] = ACTIONS(5449),
    [anon_sym_DASH] = ACTIONS(5447),
    [anon_sym_PLUS] = ACTIONS(5447),
    [anon_sym_STAR] = ACTIONS(5449),
    [anon_sym_SLASH] = ACTIONS(5447),
    [anon_sym_PERCENT] = ACTIONS(5449),
    [anon_sym_PIPE_PIPE] = ACTIONS(5449),
    [anon_sym_AMP_AMP] = ACTIONS(5449),
    [anon_sym_PIPE] = ACTIONS(5447),
    [anon_sym_CARET] = ACTIONS(5449),
    [anon_sym_AMP] = ACTIONS(5447),
    [anon_sym_EQ_EQ] = ACTIONS(5449),
    [anon_sym_BANG_EQ] = ACTIONS(5449),
    [anon_sym_GT] = ACTIONS(5447),
    [anon_sym_GT_EQ] = ACTIONS(5449),
    [anon_sym_LT_EQ] = ACTIONS(5447),
    [anon_sym_LT] = ACTIONS(5447),
    [anon_sym_LT_LT] = ACTIONS(5449),
    [anon_sym_GT_GT] = ACTIONS(5449),
    [anon_sym_COLON] = ACTIONS(5449),
    [anon_sym_SEMI] = ACTIONS(5449),
    [anon_sym___extension__] = ACTIONS(5447),
    [anon_sym___attribute__] = ACTIONS(5447),
    [anon_sym___based] = ACTIONS(5447),
    [anon_sym_LBRACE] = ACTIONS(5449),
    [anon_sym_RBRACE] = ACTIONS(5449),
    [anon_sym_signed] = ACTIONS(5447),
    [anon_sym_unsigned] = ACTIONS(5447),
    [anon_sym_long] = ACTIONS(5447),
    [anon_sym_short] = ACTIONS(5447),
    [anon_sym_LBRACK] = ACTIONS(5449),
    [anon_sym_RBRACK] = ACTIONS(5449),
    [anon_sym_const] = ACTIONS(5447),
    [anon_sym_constexpr] = ACTIONS(5447),
    [anon_sym_volatile] = ACTIONS(5447),
    [anon_sym_restrict] = ACTIONS(5447),
    [anon_sym___restrict__] = ACTIONS(5447),
    [anon_sym__Atomic] = ACTIONS(5447),
    [anon_sym__Noreturn] = ACTIONS(5447),
    [anon_sym_noreturn] = ACTIONS(5447),
    [anon_sym_mutable] = ACTIONS(5447),
    [anon_sym_constinit] = ACTIONS(5447),
    [anon_sym_consteval] = ACTIONS(5447),
    [anon_sym_alignas] = ACTIONS(5447),
    [anon_sym__Alignas] = ACTIONS(5447),
    [sym_primitive_type] = ACTIONS(5447),
    [anon_sym_QMARK] = ACTIONS(5449),
    [anon_sym_LT_EQ_GT] = ACTIONS(5449),
    [anon_sym_or] = ACTIONS(5447),
    [anon_sym_and] = ACTIONS(5447),
    [anon_sym_bitor] = ACTIONS(5447),
    [anon_sym_xor] = ACTIONS(5447),
    [anon_sym_bitand] = ACTIONS(5447),
    [anon_sym_not_eq] = ACTIONS(5447),
    [anon_sym_DASH_DASH] = ACTIONS(5449),
    [anon_sym_PLUS_PLUS] = ACTIONS(5449),
    [anon_sym_DOT] = ACTIONS(5447),
    [anon_sym_DOT_STAR] = ACTIONS(5449),
    [anon_sym_DASH_GT] = ACTIONS(5449),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5447),
    [anon_sym_decltype] = ACTIONS(5447),
    [anon_sym_final] = ACTIONS(5447),
    [anon_sym_override] = ACTIONS(5447),
    [anon_sym_requires] = ACTIONS(5447),
  },
  [2479] = {
    [sym_identifier] = ACTIONS(2260),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2262),
    [anon_sym_COMMA] = ACTIONS(2262),
    [anon_sym_RPAREN] = ACTIONS(2262),
    [anon_sym_LPAREN2] = ACTIONS(2262),
    [anon_sym_DASH] = ACTIONS(2260),
    [anon_sym_PLUS] = ACTIONS(2260),
    [anon_sym_STAR] = ACTIONS(2262),
    [anon_sym_SLASH] = ACTIONS(2260),
    [anon_sym_PERCENT] = ACTIONS(2262),
    [anon_sym_PIPE_PIPE] = ACTIONS(2262),
    [anon_sym_AMP_AMP] = ACTIONS(2262),
    [anon_sym_PIPE] = ACTIONS(2260),
    [anon_sym_CARET] = ACTIONS(2262),
    [anon_sym_AMP] = ACTIONS(2260),
    [anon_sym_EQ_EQ] = ACTIONS(2262),
    [anon_sym_BANG_EQ] = ACTIONS(2262),
    [anon_sym_GT] = ACTIONS(2260),
    [anon_sym_GT_EQ] = ACTIONS(2262),
    [anon_sym_LT_EQ] = ACTIONS(2260),
    [anon_sym_LT] = ACTIONS(2260),
    [anon_sym_LT_LT] = ACTIONS(2262),
    [anon_sym_GT_GT] = ACTIONS(2262),
    [anon_sym_COLON] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(2262),
    [anon_sym___extension__] = ACTIONS(2260),
    [anon_sym___attribute__] = ACTIONS(2260),
    [anon_sym___based] = ACTIONS(2260),
    [anon_sym_LBRACE] = ACTIONS(2262),
    [anon_sym_RBRACE] = ACTIONS(2262),
    [anon_sym_signed] = ACTIONS(2260),
    [anon_sym_unsigned] = ACTIONS(2260),
    [anon_sym_long] = ACTIONS(2260),
    [anon_sym_short] = ACTIONS(2260),
    [anon_sym_LBRACK] = ACTIONS(2262),
    [anon_sym_RBRACK] = ACTIONS(2262),
    [anon_sym_const] = ACTIONS(2260),
    [anon_sym_constexpr] = ACTIONS(2260),
    [anon_sym_volatile] = ACTIONS(2260),
    [anon_sym_restrict] = ACTIONS(2260),
    [anon_sym___restrict__] = ACTIONS(2260),
    [anon_sym__Atomic] = ACTIONS(2260),
    [anon_sym__Noreturn] = ACTIONS(2260),
    [anon_sym_noreturn] = ACTIONS(2260),
    [anon_sym_mutable] = ACTIONS(2260),
    [anon_sym_constinit] = ACTIONS(2260),
    [anon_sym_consteval] = ACTIONS(2260),
    [anon_sym_alignas] = ACTIONS(2260),
    [anon_sym__Alignas] = ACTIONS(2260),
    [sym_primitive_type] = ACTIONS(2260),
    [anon_sym_QMARK] = ACTIONS(2262),
    [anon_sym_LT_EQ_GT] = ACTIONS(2262),
    [anon_sym_or] = ACTIONS(2260),
    [anon_sym_and] = ACTIONS(2260),
    [anon_sym_bitor] = ACTIONS(2260),
    [anon_sym_xor] = ACTIONS(2260),
    [anon_sym_bitand] = ACTIONS(2260),
    [anon_sym_not_eq] = ACTIONS(2260),
    [anon_sym_DASH_DASH] = ACTIONS(2262),
    [anon_sym_PLUS_PLUS] = ACTIONS(2262),
    [anon_sym_DOT] = ACTIONS(2260),
    [anon_sym_DOT_STAR] = ACTIONS(2262),
    [anon_sym_DASH_GT] = ACTIONS(2262),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2260),
    [anon_sym_decltype] = ACTIONS(2260),
    [anon_sym_final] = ACTIONS(2260),
    [anon_sym_override] = ACTIONS(2260),
    [anon_sym_requires] = ACTIONS(2260),
  },
  [2480] = {
    [sym_identifier] = ACTIONS(5471),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5473),
    [anon_sym_COMMA] = ACTIONS(5473),
    [anon_sym_RPAREN] = ACTIONS(5473),
    [anon_sym_LPAREN2] = ACTIONS(5473),
    [anon_sym_DASH] = ACTIONS(5471),
    [anon_sym_PLUS] = ACTIONS(5471),
    [anon_sym_STAR] = ACTIONS(5473),
    [anon_sym_SLASH] = ACTIONS(5471),
    [anon_sym_PERCENT] = ACTIONS(5473),
    [anon_sym_PIPE_PIPE] = ACTIONS(5473),
    [anon_sym_AMP_AMP] = ACTIONS(5473),
    [anon_sym_PIPE] = ACTIONS(5471),
    [anon_sym_CARET] = ACTIONS(5473),
    [anon_sym_AMP] = ACTIONS(5471),
    [anon_sym_EQ_EQ] = ACTIONS(5473),
    [anon_sym_BANG_EQ] = ACTIONS(5473),
    [anon_sym_GT] = ACTIONS(5471),
    [anon_sym_GT_EQ] = ACTIONS(5473),
    [anon_sym_LT_EQ] = ACTIONS(5471),
    [anon_sym_LT] = ACTIONS(5471),
    [anon_sym_LT_LT] = ACTIONS(5473),
    [anon_sym_GT_GT] = ACTIONS(5473),
    [anon_sym_COLON] = ACTIONS(5473),
    [anon_sym_SEMI] = ACTIONS(5473),
    [anon_sym___extension__] = ACTIONS(5471),
    [anon_sym___attribute__] = ACTIONS(5471),
    [anon_sym___based] = ACTIONS(5471),
    [anon_sym_LBRACE] = ACTIONS(5473),
    [anon_sym_RBRACE] = ACTIONS(5473),
    [anon_sym_signed] = ACTIONS(5471),
    [anon_sym_unsigned] = ACTIONS(5471),
    [anon_sym_long] = ACTIONS(5471),
    [anon_sym_short] = ACTIONS(5471),
    [anon_sym_LBRACK] = ACTIONS(5473),
    [anon_sym_RBRACK] = ACTIONS(5473),
    [anon_sym_const] = ACTIONS(5471),
    [anon_sym_constexpr] = ACTIONS(5471),
    [anon_sym_volatile] = ACTIONS(5471),
    [anon_sym_restrict] = ACTIONS(5471),
    [anon_sym___restrict__] = ACTIONS(5471),
    [anon_sym__Atomic] = ACTIONS(5471),
    [anon_sym__Noreturn] = ACTIONS(5471),
    [anon_sym_noreturn] = ACTIONS(5471),
    [anon_sym_mutable] = ACTIONS(5471),
    [anon_sym_constinit] = ACTIONS(5471),
    [anon_sym_consteval] = ACTIONS(5471),
    [anon_sym_alignas] = ACTIONS(5471),
    [anon_sym__Alignas] = ACTIONS(5471),
    [sym_primitive_type] = ACTIONS(5471),
    [anon_sym_QMARK] = ACTIONS(5473),
    [anon_sym_LT_EQ_GT] = ACTIONS(5473),
    [anon_sym_or] = ACTIONS(5471),
    [anon_sym_and] = ACTIONS(5471),
    [anon_sym_bitor] = ACTIONS(5471),
    [anon_sym_xor] = ACTIONS(5471),
    [anon_sym_bitand] = ACTIONS(5471),
    [anon_sym_not_eq] = ACTIONS(5471),
    [anon_sym_DASH_DASH] = ACTIONS(5473),
    [anon_sym_PLUS_PLUS] = ACTIONS(5473),
    [anon_sym_DOT] = ACTIONS(5471),
    [anon_sym_DOT_STAR] = ACTIONS(5473),
    [anon_sym_DASH_GT] = ACTIONS(5473),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5471),
    [anon_sym_decltype] = ACTIONS(5471),
    [anon_sym_final] = ACTIONS(5471),
    [anon_sym_override] = ACTIONS(5471),
    [anon_sym_requires] = ACTIONS(5471),
  },
  [2481] = {
    [sym_identifier] = ACTIONS(5525),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5527),
    [anon_sym_COMMA] = ACTIONS(5527),
    [anon_sym_RPAREN] = ACTIONS(5527),
    [anon_sym_LPAREN2] = ACTIONS(5527),
    [anon_sym_DASH] = ACTIONS(5525),
    [anon_sym_PLUS] = ACTIONS(5525),
    [anon_sym_STAR] = ACTIONS(5527),
    [anon_sym_SLASH] = ACTIONS(5525),
    [anon_sym_PERCENT] = ACTIONS(5527),
    [anon_sym_PIPE_PIPE] = ACTIONS(5527),
    [anon_sym_AMP_AMP] = ACTIONS(5527),
    [anon_sym_PIPE] = ACTIONS(5525),
    [anon_sym_CARET] = ACTIONS(5527),
    [anon_sym_AMP] = ACTIONS(5525),
    [anon_sym_EQ_EQ] = ACTIONS(5527),
    [anon_sym_BANG_EQ] = ACTIONS(5527),
    [anon_sym_GT] = ACTIONS(5525),
    [anon_sym_GT_EQ] = ACTIONS(5527),
    [anon_sym_LT_EQ] = ACTIONS(5525),
    [anon_sym_LT] = ACTIONS(5525),
    [anon_sym_LT_LT] = ACTIONS(5527),
    [anon_sym_GT_GT] = ACTIONS(5527),
    [anon_sym_COLON] = ACTIONS(5527),
    [anon_sym_SEMI] = ACTIONS(5527),
    [anon_sym___extension__] = ACTIONS(5525),
    [anon_sym___attribute__] = ACTIONS(5525),
    [anon_sym___based] = ACTIONS(5525),
    [anon_sym_LBRACE] = ACTIONS(5527),
    [anon_sym_RBRACE] = ACTIONS(5527),
    [anon_sym_signed] = ACTIONS(5525),
    [anon_sym_unsigned] = ACTIONS(5525),
    [anon_sym_long] = ACTIONS(5525),
    [anon_sym_short] = ACTIONS(5525),
    [anon_sym_LBRACK] = ACTIONS(5527),
    [anon_sym_RBRACK] = ACTIONS(5527),
    [anon_sym_const] = ACTIONS(5525),
    [anon_sym_constexpr] = ACTIONS(5525),
    [anon_sym_volatile] = ACTIONS(5525),
    [anon_sym_restrict] = ACTIONS(5525),
    [anon_sym___restrict__] = ACTIONS(5525),
    [anon_sym__Atomic] = ACTIONS(5525),
    [anon_sym__Noreturn] = ACTIONS(5525),
    [anon_sym_noreturn] = ACTIONS(5525),
    [anon_sym_mutable] = ACTIONS(5525),
    [anon_sym_constinit] = ACTIONS(5525),
    [anon_sym_consteval] = ACTIONS(5525),
    [anon_sym_alignas] = ACTIONS(5525),
    [anon_sym__Alignas] = ACTIONS(5525),
    [sym_primitive_type] = ACTIONS(5525),
    [anon_sym_QMARK] = ACTIONS(5527),
    [anon_sym_LT_EQ_GT] = ACTIONS(5527),
    [anon_sym_or] = ACTIONS(5525),
    [anon_sym_and] = ACTIONS(5525),
    [anon_sym_bitor] = ACTIONS(5525),
    [anon_sym_xor] = ACTIONS(5525),
    [anon_sym_bitand] = ACTIONS(5525),
    [anon_sym_not_eq] = ACTIONS(5525),
    [anon_sym_DASH_DASH] = ACTIONS(5527),
    [anon_sym_PLUS_PLUS] = ACTIONS(5527),
    [anon_sym_DOT] = ACTIONS(5525),
    [anon_sym_DOT_STAR] = ACTIONS(5527),
    [anon_sym_DASH_GT] = ACTIONS(5527),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5525),
    [anon_sym_decltype] = ACTIONS(5525),
    [anon_sym_final] = ACTIONS(5525),
    [anon_sym_override] = ACTIONS(5525),
    [anon_sym_requires] = ACTIONS(5525),
  },
  [2482] = {
    [sym_identifier] = ACTIONS(5479),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5481),
    [anon_sym_COMMA] = ACTIONS(5481),
    [anon_sym_RPAREN] = ACTIONS(5481),
    [anon_sym_LPAREN2] = ACTIONS(5481),
    [anon_sym_DASH] = ACTIONS(5479),
    [anon_sym_PLUS] = ACTIONS(5479),
    [anon_sym_STAR] = ACTIONS(5481),
    [anon_sym_SLASH] = ACTIONS(5479),
    [anon_sym_PERCENT] = ACTIONS(5481),
    [anon_sym_PIPE_PIPE] = ACTIONS(5481),
    [anon_sym_AMP_AMP] = ACTIONS(5481),
    [anon_sym_PIPE] = ACTIONS(5479),
    [anon_sym_CARET] = ACTIONS(5481),
    [anon_sym_AMP] = ACTIONS(5479),
    [anon_sym_EQ_EQ] = ACTIONS(5481),
    [anon_sym_BANG_EQ] = ACTIONS(5481),
    [anon_sym_GT] = ACTIONS(5479),
    [anon_sym_GT_EQ] = ACTIONS(5481),
    [anon_sym_LT_EQ] = ACTIONS(5479),
    [anon_sym_LT] = ACTIONS(5479),
    [anon_sym_LT_LT] = ACTIONS(5481),
    [anon_sym_GT_GT] = ACTIONS(5481),
    [anon_sym_COLON] = ACTIONS(5481),
    [anon_sym_SEMI] = ACTIONS(5481),
    [anon_sym___extension__] = ACTIONS(5479),
    [anon_sym___attribute__] = ACTIONS(5479),
    [anon_sym___based] = ACTIONS(5479),
    [anon_sym_LBRACE] = ACTIONS(5481),
    [anon_sym_RBRACE] = ACTIONS(5481),
    [anon_sym_signed] = ACTIONS(5479),
    [anon_sym_unsigned] = ACTIONS(5479),
    [anon_sym_long] = ACTIONS(5479),
    [anon_sym_short] = ACTIONS(5479),
    [anon_sym_LBRACK] = ACTIONS(5481),
    [anon_sym_RBRACK] = ACTIONS(5481),
    [anon_sym_const] = ACTIONS(5479),
    [anon_sym_constexpr] = ACTIONS(5479),
    [anon_sym_volatile] = ACTIONS(5479),
    [anon_sym_restrict] = ACTIONS(5479),
    [anon_sym___restrict__] = ACTIONS(5479),
    [anon_sym__Atomic] = ACTIONS(5479),
    [anon_sym__Noreturn] = ACTIONS(5479),
    [anon_sym_noreturn] = ACTIONS(5479),
    [anon_sym_mutable] = ACTIONS(5479),
    [anon_sym_constinit] = ACTIONS(5479),
    [anon_sym_consteval] = ACTIONS(5479),
    [anon_sym_alignas] = ACTIONS(5479),
    [anon_sym__Alignas] = ACTIONS(5479),
    [sym_primitive_type] = ACTIONS(5479),
    [anon_sym_QMARK] = ACTIONS(5481),
    [anon_sym_LT_EQ_GT] = ACTIONS(5481),
    [anon_sym_or] = ACTIONS(5479),
    [anon_sym_and] = ACTIONS(5479),
    [anon_sym_bitor] = ACTIONS(5479),
    [anon_sym_xor] = ACTIONS(5479),
    [anon_sym_bitand] = ACTIONS(5479),
    [anon_sym_not_eq] = ACTIONS(5479),
    [anon_sym_DASH_DASH] = ACTIONS(5481),
    [anon_sym_PLUS_PLUS] = ACTIONS(5481),
    [anon_sym_DOT] = ACTIONS(5479),
    [anon_sym_DOT_STAR] = ACTIONS(5481),
    [anon_sym_DASH_GT] = ACTIONS(5481),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5479),
    [anon_sym_decltype] = ACTIONS(5479),
    [anon_sym_final] = ACTIONS(5479),
    [anon_sym_override] = ACTIONS(5479),
    [anon_sym_requires] = ACTIONS(5479),
  },
  [2483] = {
    [sym_identifier] = ACTIONS(5549),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5551),
    [anon_sym_COMMA] = ACTIONS(5551),
    [anon_sym_RPAREN] = ACTIONS(5551),
    [anon_sym_LPAREN2] = ACTIONS(5551),
    [anon_sym_DASH] = ACTIONS(5549),
    [anon_sym_PLUS] = ACTIONS(5549),
    [anon_sym_STAR] = ACTIONS(5551),
    [anon_sym_SLASH] = ACTIONS(5549),
    [anon_sym_PERCENT] = ACTIONS(5551),
    [anon_sym_PIPE_PIPE] = ACTIONS(5551),
    [anon_sym_AMP_AMP] = ACTIONS(5551),
    [anon_sym_PIPE] = ACTIONS(5549),
    [anon_sym_CARET] = ACTIONS(5551),
    [anon_sym_AMP] = ACTIONS(5549),
    [anon_sym_EQ_EQ] = ACTIONS(5551),
    [anon_sym_BANG_EQ] = ACTIONS(5551),
    [anon_sym_GT] = ACTIONS(5549),
    [anon_sym_GT_EQ] = ACTIONS(5551),
    [anon_sym_LT_EQ] = ACTIONS(5549),
    [anon_sym_LT] = ACTIONS(5549),
    [anon_sym_LT_LT] = ACTIONS(5551),
    [anon_sym_GT_GT] = ACTIONS(5551),
    [anon_sym_COLON] = ACTIONS(5551),
    [anon_sym_SEMI] = ACTIONS(5551),
    [anon_sym___extension__] = ACTIONS(5549),
    [anon_sym___attribute__] = ACTIONS(5549),
    [anon_sym___based] = ACTIONS(5549),
    [anon_sym_LBRACE] = ACTIONS(5551),
    [anon_sym_RBRACE] = ACTIONS(5551),
    [anon_sym_signed] = ACTIONS(5549),
    [anon_sym_unsigned] = ACTIONS(5549),
    [anon_sym_long] = ACTIONS(5549),
    [anon_sym_short] = ACTIONS(5549),
    [anon_sym_LBRACK] = ACTIONS(5551),
    [anon_sym_RBRACK] = ACTIONS(5551),
    [anon_sym_const] = ACTIONS(5549),
    [anon_sym_constexpr] = ACTIONS(5549),
    [anon_sym_volatile] = ACTIONS(5549),
    [anon_sym_restrict] = ACTIONS(5549),
    [anon_sym___restrict__] = ACTIONS(5549),
    [anon_sym__Atomic] = ACTIONS(5549),
    [anon_sym__Noreturn] = ACTIONS(5549),
    [anon_sym_noreturn] = ACTIONS(5549),
    [anon_sym_mutable] = ACTIONS(5549),
    [anon_sym_constinit] = ACTIONS(5549),
    [anon_sym_consteval] = ACTIONS(5549),
    [anon_sym_alignas] = ACTIONS(5549),
    [anon_sym__Alignas] = ACTIONS(5549),
    [sym_primitive_type] = ACTIONS(5549),
    [anon_sym_QMARK] = ACTIONS(5551),
    [anon_sym_LT_EQ_GT] = ACTIONS(5551),
    [anon_sym_or] = ACTIONS(5549),
    [anon_sym_and] = ACTIONS(5549),
    [anon_sym_bitor] = ACTIONS(5549),
    [anon_sym_xor] = ACTIONS(5549),
    [anon_sym_bitand] = ACTIONS(5549),
    [anon_sym_not_eq] = ACTIONS(5549),
    [anon_sym_DASH_DASH] = ACTIONS(5551),
    [anon_sym_PLUS_PLUS] = ACTIONS(5551),
    [anon_sym_DOT] = ACTIONS(5549),
    [anon_sym_DOT_STAR] = ACTIONS(5551),
    [anon_sym_DASH_GT] = ACTIONS(5551),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5549),
    [anon_sym_decltype] = ACTIONS(5549),
    [anon_sym_final] = ACTIONS(5549),
    [anon_sym_override] = ACTIONS(5549),
    [anon_sym_requires] = ACTIONS(5549),
  },
  [2484] = {
    [sym_identifier] = ACTIONS(5533),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5535),
    [anon_sym_COMMA] = ACTIONS(5535),
    [anon_sym_RPAREN] = ACTIONS(5535),
    [anon_sym_LPAREN2] = ACTIONS(5535),
    [anon_sym_DASH] = ACTIONS(5533),
    [anon_sym_PLUS] = ACTIONS(5533),
    [anon_sym_STAR] = ACTIONS(5535),
    [anon_sym_SLASH] = ACTIONS(5533),
    [anon_sym_PERCENT] = ACTIONS(5535),
    [anon_sym_PIPE_PIPE] = ACTIONS(5535),
    [anon_sym_AMP_AMP] = ACTIONS(5535),
    [anon_sym_PIPE] = ACTIONS(5533),
    [anon_sym_CARET] = ACTIONS(5535),
    [anon_sym_AMP] = ACTIONS(5533),
    [anon_sym_EQ_EQ] = ACTIONS(5535),
    [anon_sym_BANG_EQ] = ACTIONS(5535),
    [anon_sym_GT] = ACTIONS(5533),
    [anon_sym_GT_EQ] = ACTIONS(5535),
    [anon_sym_LT_EQ] = ACTIONS(5533),
    [anon_sym_LT] = ACTIONS(5533),
    [anon_sym_LT_LT] = ACTIONS(5535),
    [anon_sym_GT_GT] = ACTIONS(5535),
    [anon_sym_COLON] = ACTIONS(5535),
    [anon_sym_SEMI] = ACTIONS(5535),
    [anon_sym___extension__] = ACTIONS(5533),
    [anon_sym___attribute__] = ACTIONS(5533),
    [anon_sym___based] = ACTIONS(5533),
    [anon_sym_LBRACE] = ACTIONS(5535),
    [anon_sym_RBRACE] = ACTIONS(5535),
    [anon_sym_signed] = ACTIONS(5533),
    [anon_sym_unsigned] = ACTIONS(5533),
    [anon_sym_long] = ACTIONS(5533),
    [anon_sym_short] = ACTIONS(5533),
    [anon_sym_LBRACK] = ACTIONS(5535),
    [anon_sym_RBRACK] = ACTIONS(5535),
    [anon_sym_const] = ACTIONS(5533),
    [anon_sym_constexpr] = ACTIONS(5533),
    [anon_sym_volatile] = ACTIONS(5533),
    [anon_sym_restrict] = ACTIONS(5533),
    [anon_sym___restrict__] = ACTIONS(5533),
    [anon_sym__Atomic] = ACTIONS(5533),
    [anon_sym__Noreturn] = ACTIONS(5533),
    [anon_sym_noreturn] = ACTIONS(5533),
    [anon_sym_mutable] = ACTIONS(5533),
    [anon_sym_constinit] = ACTIONS(5533),
    [anon_sym_consteval] = ACTIONS(5533),
    [anon_sym_alignas] = ACTIONS(5533),
    [anon_sym__Alignas] = ACTIONS(5533),
    [sym_primitive_type] = ACTIONS(5533),
    [anon_sym_QMARK] = ACTIONS(5535),
    [anon_sym_LT_EQ_GT] = ACTIONS(5535),
    [anon_sym_or] = ACTIONS(5533),
    [anon_sym_and] = ACTIONS(5533),
    [anon_sym_bitor] = ACTIONS(5533),
    [anon_sym_xor] = ACTIONS(5533),
    [anon_sym_bitand] = ACTIONS(5533),
    [anon_sym_not_eq] = ACTIONS(5533),
    [anon_sym_DASH_DASH] = ACTIONS(5535),
    [anon_sym_PLUS_PLUS] = ACTIONS(5535),
    [anon_sym_DOT] = ACTIONS(5533),
    [anon_sym_DOT_STAR] = ACTIONS(5535),
    [anon_sym_DASH_GT] = ACTIONS(5535),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5533),
    [anon_sym_decltype] = ACTIONS(5533),
    [anon_sym_final] = ACTIONS(5533),
    [anon_sym_override] = ACTIONS(5533),
    [anon_sym_requires] = ACTIONS(5533),
  },
  [2485] = {
    [sym_identifier] = ACTIONS(5525),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5527),
    [anon_sym_COMMA] = ACTIONS(5527),
    [anon_sym_RPAREN] = ACTIONS(5527),
    [anon_sym_LPAREN2] = ACTIONS(5527),
    [anon_sym_DASH] = ACTIONS(5525),
    [anon_sym_PLUS] = ACTIONS(5525),
    [anon_sym_STAR] = ACTIONS(5527),
    [anon_sym_SLASH] = ACTIONS(5525),
    [anon_sym_PERCENT] = ACTIONS(5527),
    [anon_sym_PIPE_PIPE] = ACTIONS(5527),
    [anon_sym_AMP_AMP] = ACTIONS(5527),
    [anon_sym_PIPE] = ACTIONS(5525),
    [anon_sym_CARET] = ACTIONS(5527),
    [anon_sym_AMP] = ACTIONS(5525),
    [anon_sym_EQ_EQ] = ACTIONS(5527),
    [anon_sym_BANG_EQ] = ACTIONS(5527),
    [anon_sym_GT] = ACTIONS(5525),
    [anon_sym_GT_EQ] = ACTIONS(5527),
    [anon_sym_LT_EQ] = ACTIONS(5525),
    [anon_sym_LT] = ACTIONS(5525),
    [anon_sym_LT_LT] = ACTIONS(5527),
    [anon_sym_GT_GT] = ACTIONS(5527),
    [anon_sym_COLON] = ACTIONS(5527),
    [anon_sym_SEMI] = ACTIONS(5527),
    [anon_sym___extension__] = ACTIONS(5525),
    [anon_sym___attribute__] = ACTIONS(5525),
    [anon_sym___based] = ACTIONS(5525),
    [anon_sym_LBRACE] = ACTIONS(5527),
    [anon_sym_RBRACE] = ACTIONS(5527),
    [anon_sym_signed] = ACTIONS(5525),
    [anon_sym_unsigned] = ACTIONS(5525),
    [anon_sym_long] = ACTIONS(5525),
    [anon_sym_short] = ACTIONS(5525),
    [anon_sym_LBRACK] = ACTIONS(5527),
    [anon_sym_RBRACK] = ACTIONS(5527),
    [anon_sym_const] = ACTIONS(5525),
    [anon_sym_constexpr] = ACTIONS(5525),
    [anon_sym_volatile] = ACTIONS(5525),
    [anon_sym_restrict] = ACTIONS(5525),
    [anon_sym___restrict__] = ACTIONS(5525),
    [anon_sym__Atomic] = ACTIONS(5525),
    [anon_sym__Noreturn] = ACTIONS(5525),
    [anon_sym_noreturn] = ACTIONS(5525),
    [anon_sym_mutable] = ACTIONS(5525),
    [anon_sym_constinit] = ACTIONS(5525),
    [anon_sym_consteval] = ACTIONS(5525),
    [anon_sym_alignas] = ACTIONS(5525),
    [anon_sym__Alignas] = ACTIONS(5525),
    [sym_primitive_type] = ACTIONS(5525),
    [anon_sym_QMARK] = ACTIONS(5527),
    [anon_sym_LT_EQ_GT] = ACTIONS(5527),
    [anon_sym_or] = ACTIONS(5525),
    [anon_sym_and] = ACTIONS(5525),
    [anon_sym_bitor] = ACTIONS(5525),
    [anon_sym_xor] = ACTIONS(5525),
    [anon_sym_bitand] = ACTIONS(5525),
    [anon_sym_not_eq] = ACTIONS(5525),
    [anon_sym_DASH_DASH] = ACTIONS(5527),
    [anon_sym_PLUS_PLUS] = ACTIONS(5527),
    [anon_sym_DOT] = ACTIONS(5525),
    [anon_sym_DOT_STAR] = ACTIONS(5527),
    [anon_sym_DASH_GT] = ACTIONS(5527),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5525),
    [anon_sym_decltype] = ACTIONS(5525),
    [anon_sym_final] = ACTIONS(5525),
    [anon_sym_override] = ACTIONS(5525),
    [anon_sym_requires] = ACTIONS(5525),
  },
  [2486] = {
    [sym_template_argument_list] = STATE(2489),
    [sym_identifier] = ACTIONS(1941),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1943),
    [anon_sym_COMMA] = ACTIONS(1943),
    [anon_sym_RPAREN] = ACTIONS(1943),
    [aux_sym_preproc_if_token2] = ACTIONS(1943),
    [aux_sym_preproc_else_token1] = ACTIONS(1943),
    [aux_sym_preproc_elif_token1] = ACTIONS(1941),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1943),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1943),
    [anon_sym_LPAREN2] = ACTIONS(1943),
    [anon_sym_DASH] = ACTIONS(1941),
    [anon_sym_PLUS] = ACTIONS(1941),
    [anon_sym_STAR] = ACTIONS(1941),
    [anon_sym_SLASH] = ACTIONS(1941),
    [anon_sym_PERCENT] = ACTIONS(1941),
    [anon_sym_PIPE_PIPE] = ACTIONS(1943),
    [anon_sym_AMP_AMP] = ACTIONS(1943),
    [anon_sym_PIPE] = ACTIONS(1941),
    [anon_sym_CARET] = ACTIONS(1941),
    [anon_sym_AMP] = ACTIONS(1941),
    [anon_sym_EQ_EQ] = ACTIONS(1943),
    [anon_sym_BANG_EQ] = ACTIONS(1943),
    [anon_sym_GT] = ACTIONS(1941),
    [anon_sym_GT_EQ] = ACTIONS(1943),
    [anon_sym_LT_EQ] = ACTIONS(1941),
    [anon_sym_LT] = ACTIONS(5866),
    [anon_sym_LT_LT] = ACTIONS(1941),
    [anon_sym_GT_GT] = ACTIONS(1941),
    [anon_sym_COLON] = ACTIONS(1941),
    [anon_sym_SEMI] = ACTIONS(1943),
    [anon_sym___attribute__] = ACTIONS(1941),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_RBRACE] = ACTIONS(1943),
    [anon_sym_LBRACK] = ACTIONS(1943),
    [anon_sym_RBRACK] = ACTIONS(1943),
    [anon_sym_EQ] = ACTIONS(1941),
    [anon_sym_QMARK] = ACTIONS(1943),
    [anon_sym_STAR_EQ] = ACTIONS(1943),
    [anon_sym_SLASH_EQ] = ACTIONS(1943),
    [anon_sym_PERCENT_EQ] = ACTIONS(1943),
    [anon_sym_PLUS_EQ] = ACTIONS(1943),
    [anon_sym_DASH_EQ] = ACTIONS(1943),
    [anon_sym_LT_LT_EQ] = ACTIONS(1943),
    [anon_sym_GT_GT_EQ] = ACTIONS(1943),
    [anon_sym_AMP_EQ] = ACTIONS(1943),
    [anon_sym_CARET_EQ] = ACTIONS(1943),
    [anon_sym_PIPE_EQ] = ACTIONS(1943),
    [anon_sym_and_eq] = ACTIONS(1941),
    [anon_sym_or_eq] = ACTIONS(1941),
    [anon_sym_xor_eq] = ACTIONS(1941),
    [anon_sym_LT_EQ_GT] = ACTIONS(1943),
    [anon_sym_or] = ACTIONS(1941),
    [anon_sym_and] = ACTIONS(1941),
    [anon_sym_bitor] = ACTIONS(1941),
    [anon_sym_xor] = ACTIONS(1941),
    [anon_sym_bitand] = ACTIONS(1941),
    [anon_sym_not_eq] = ACTIONS(1941),
    [anon_sym_DASH_DASH] = ACTIONS(1943),
    [anon_sym_PLUS_PLUS] = ACTIONS(1943),
    [anon_sym_DOT] = ACTIONS(1941),
    [anon_sym_DOT_STAR] = ACTIONS(1943),
    [anon_sym_DASH_GT] = ACTIONS(1943),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1941),
    [anon_sym_decltype] = ACTIONS(1941),
    [anon_sym_final] = ACTIONS(1941),
    [anon_sym_override] = ACTIONS(1941),
  },
  [2487] = {
    [sym_argument_list] = STATE(2815),
    [sym_initializer_list] = STATE(2815),
    [sym_decltype_auto] = STATE(2607),
    [sym_new_declarator] = STATE(2660),
    [sym_identifier] = ACTIONS(5868),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5870),
    [anon_sym_COMMA] = ACTIONS(5870),
    [anon_sym_RPAREN] = ACTIONS(5870),
    [aux_sym_preproc_if_token2] = ACTIONS(5870),
    [aux_sym_preproc_else_token1] = ACTIONS(5870),
    [aux_sym_preproc_elif_token1] = ACTIONS(5868),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5870),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5870),
    [anon_sym_LPAREN2] = ACTIONS(5854),
    [anon_sym_DASH] = ACTIONS(5868),
    [anon_sym_PLUS] = ACTIONS(5868),
    [anon_sym_STAR] = ACTIONS(5868),
    [anon_sym_SLASH] = ACTIONS(5868),
    [anon_sym_PERCENT] = ACTIONS(5868),
    [anon_sym_PIPE_PIPE] = ACTIONS(5870),
    [anon_sym_AMP_AMP] = ACTIONS(5870),
    [anon_sym_PIPE] = ACTIONS(5868),
    [anon_sym_CARET] = ACTIONS(5868),
    [anon_sym_AMP] = ACTIONS(5868),
    [anon_sym_EQ_EQ] = ACTIONS(5870),
    [anon_sym_BANG_EQ] = ACTIONS(5870),
    [anon_sym_GT] = ACTIONS(5868),
    [anon_sym_GT_EQ] = ACTIONS(5870),
    [anon_sym_LT_EQ] = ACTIONS(5868),
    [anon_sym_LT] = ACTIONS(5868),
    [anon_sym_LT_LT] = ACTIONS(5868),
    [anon_sym_GT_GT] = ACTIONS(5868),
    [anon_sym_COLON] = ACTIONS(5870),
    [anon_sym_SEMI] = ACTIONS(5870),
    [anon_sym___attribute__] = ACTIONS(5868),
    [anon_sym_LBRACE] = ACTIONS(3523),
    [anon_sym_RBRACE] = ACTIONS(5870),
    [anon_sym_LBRACK] = ACTIONS(5856),
    [anon_sym_RBRACK] = ACTIONS(5870),
    [anon_sym_EQ] = ACTIONS(5868),
    [anon_sym_QMARK] = ACTIONS(5870),
    [anon_sym_STAR_EQ] = ACTIONS(5870),
    [anon_sym_SLASH_EQ] = ACTIONS(5870),
    [anon_sym_PERCENT_EQ] = ACTIONS(5870),
    [anon_sym_PLUS_EQ] = ACTIONS(5870),
    [anon_sym_DASH_EQ] = ACTIONS(5870),
    [anon_sym_LT_LT_EQ] = ACTIONS(5870),
    [anon_sym_GT_GT_EQ] = ACTIONS(5870),
    [anon_sym_AMP_EQ] = ACTIONS(5870),
    [anon_sym_CARET_EQ] = ACTIONS(5870),
    [anon_sym_PIPE_EQ] = ACTIONS(5870),
    [anon_sym_and_eq] = ACTIONS(5868),
    [anon_sym_or_eq] = ACTIONS(5868),
    [anon_sym_xor_eq] = ACTIONS(5868),
    [anon_sym_LT_EQ_GT] = ACTIONS(5870),
    [anon_sym_or] = ACTIONS(5868),
    [anon_sym_and] = ACTIONS(5868),
    [anon_sym_bitor] = ACTIONS(5868),
    [anon_sym_xor] = ACTIONS(5868),
    [anon_sym_bitand] = ACTIONS(5868),
    [anon_sym_not_eq] = ACTIONS(5868),
    [anon_sym_DASH_DASH] = ACTIONS(5870),
    [anon_sym_PLUS_PLUS] = ACTIONS(5870),
    [anon_sym_DOT] = ACTIONS(5868),
    [anon_sym_DOT_STAR] = ACTIONS(5870),
    [anon_sym_DASH_GT] = ACTIONS(5870),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5858),
    [anon_sym_decltype] = ACTIONS(5860),
  },
  [2488] = {
    [sym_argument_list] = STATE(2812),
    [sym_initializer_list] = STATE(2812),
    [sym_decltype_auto] = STATE(2607),
    [sym_new_declarator] = STATE(2619),
    [sym_identifier] = ACTIONS(5872),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5874),
    [anon_sym_COMMA] = ACTIONS(5874),
    [anon_sym_RPAREN] = ACTIONS(5874),
    [aux_sym_preproc_if_token2] = ACTIONS(5874),
    [aux_sym_preproc_else_token1] = ACTIONS(5874),
    [aux_sym_preproc_elif_token1] = ACTIONS(5872),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5874),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5874),
    [anon_sym_LPAREN2] = ACTIONS(5854),
    [anon_sym_DASH] = ACTIONS(5872),
    [anon_sym_PLUS] = ACTIONS(5872),
    [anon_sym_STAR] = ACTIONS(5872),
    [anon_sym_SLASH] = ACTIONS(5872),
    [anon_sym_PERCENT] = ACTIONS(5872),
    [anon_sym_PIPE_PIPE] = ACTIONS(5874),
    [anon_sym_AMP_AMP] = ACTIONS(5874),
    [anon_sym_PIPE] = ACTIONS(5872),
    [anon_sym_CARET] = ACTIONS(5872),
    [anon_sym_AMP] = ACTIONS(5872),
    [anon_sym_EQ_EQ] = ACTIONS(5874),
    [anon_sym_BANG_EQ] = ACTIONS(5874),
    [anon_sym_GT] = ACTIONS(5872),
    [anon_sym_GT_EQ] = ACTIONS(5874),
    [anon_sym_LT_EQ] = ACTIONS(5872),
    [anon_sym_LT] = ACTIONS(5872),
    [anon_sym_LT_LT] = ACTIONS(5872),
    [anon_sym_GT_GT] = ACTIONS(5872),
    [anon_sym_COLON] = ACTIONS(5874),
    [anon_sym_SEMI] = ACTIONS(5874),
    [anon_sym___attribute__] = ACTIONS(5872),
    [anon_sym_LBRACE] = ACTIONS(3523),
    [anon_sym_RBRACE] = ACTIONS(5874),
    [anon_sym_LBRACK] = ACTIONS(5856),
    [anon_sym_RBRACK] = ACTIONS(5874),
    [anon_sym_EQ] = ACTIONS(5872),
    [anon_sym_QMARK] = ACTIONS(5874),
    [anon_sym_STAR_EQ] = ACTIONS(5874),
    [anon_sym_SLASH_EQ] = ACTIONS(5874),
    [anon_sym_PERCENT_EQ] = ACTIONS(5874),
    [anon_sym_PLUS_EQ] = ACTIONS(5874),
    [anon_sym_DASH_EQ] = ACTIONS(5874),
    [anon_sym_LT_LT_EQ] = ACTIONS(5874),
    [anon_sym_GT_GT_EQ] = ACTIONS(5874),
    [anon_sym_AMP_EQ] = ACTIONS(5874),
    [anon_sym_CARET_EQ] = ACTIONS(5874),
    [anon_sym_PIPE_EQ] = ACTIONS(5874),
    [anon_sym_and_eq] = ACTIONS(5872),
    [anon_sym_or_eq] = ACTIONS(5872),
    [anon_sym_xor_eq] = ACTIONS(5872),
    [anon_sym_LT_EQ_GT] = ACTIONS(5874),
    [anon_sym_or] = ACTIONS(5872),
    [anon_sym_and] = ACTIONS(5872),
    [anon_sym_bitor] = ACTIONS(5872),
    [anon_sym_xor] = ACTIONS(5872),
    [anon_sym_bitand] = ACTIONS(5872),
    [anon_sym_not_eq] = ACTIONS(5872),
    [anon_sym_DASH_DASH] = ACTIONS(5874),
    [anon_sym_PLUS_PLUS] = ACTIONS(5874),
    [anon_sym_DOT] = ACTIONS(5872),
    [anon_sym_DOT_STAR] = ACTIONS(5874),
    [anon_sym_DASH_GT] = ACTIONS(5874),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5858),
    [anon_sym_decltype] = ACTIONS(5860),
  },
  [2489] = {
    [sym_identifier] = ACTIONS(1959),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1961),
    [anon_sym_COMMA] = ACTIONS(1961),
    [anon_sym_RPAREN] = ACTIONS(1961),
    [aux_sym_preproc_if_token2] = ACTIONS(1961),
    [aux_sym_preproc_else_token1] = ACTIONS(1961),
    [aux_sym_preproc_elif_token1] = ACTIONS(1959),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1961),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1961),
    [anon_sym_LPAREN2] = ACTIONS(1961),
    [anon_sym_DASH] = ACTIONS(1959),
    [anon_sym_PLUS] = ACTIONS(1959),
    [anon_sym_STAR] = ACTIONS(1959),
    [anon_sym_SLASH] = ACTIONS(1959),
    [anon_sym_PERCENT] = ACTIONS(1959),
    [anon_sym_PIPE_PIPE] = ACTIONS(1961),
    [anon_sym_AMP_AMP] = ACTIONS(1961),
    [anon_sym_PIPE] = ACTIONS(1959),
    [anon_sym_CARET] = ACTIONS(1959),
    [anon_sym_AMP] = ACTIONS(1959),
    [anon_sym_EQ_EQ] = ACTIONS(1961),
    [anon_sym_BANG_EQ] = ACTIONS(1961),
    [anon_sym_GT] = ACTIONS(1959),
    [anon_sym_GT_EQ] = ACTIONS(1961),
    [anon_sym_LT_EQ] = ACTIONS(1959),
    [anon_sym_LT] = ACTIONS(1959),
    [anon_sym_LT_LT] = ACTIONS(1959),
    [anon_sym_GT_GT] = ACTIONS(1959),
    [anon_sym_COLON] = ACTIONS(1959),
    [anon_sym_SEMI] = ACTIONS(1961),
    [anon_sym___attribute__] = ACTIONS(1959),
    [anon_sym_COLON_COLON] = ACTIONS(1961),
    [anon_sym_LBRACE] = ACTIONS(1961),
    [anon_sym_RBRACE] = ACTIONS(1961),
    [anon_sym_LBRACK] = ACTIONS(1961),
    [anon_sym_RBRACK] = ACTIONS(1961),
    [anon_sym_EQ] = ACTIONS(1959),
    [anon_sym_QMARK] = ACTIONS(1961),
    [anon_sym_STAR_EQ] = ACTIONS(1961),
    [anon_sym_SLASH_EQ] = ACTIONS(1961),
    [anon_sym_PERCENT_EQ] = ACTIONS(1961),
    [anon_sym_PLUS_EQ] = ACTIONS(1961),
    [anon_sym_DASH_EQ] = ACTIONS(1961),
    [anon_sym_LT_LT_EQ] = ACTIONS(1961),
    [anon_sym_GT_GT_EQ] = ACTIONS(1961),
    [anon_sym_AMP_EQ] = ACTIONS(1961),
    [anon_sym_CARET_EQ] = ACTIONS(1961),
    [anon_sym_PIPE_EQ] = ACTIONS(1961),
    [anon_sym_and_eq] = ACTIONS(1959),
    [anon_sym_or_eq] = ACTIONS(1959),
    [anon_sym_xor_eq] = ACTIONS(1959),
    [anon_sym_LT_EQ_GT] = ACTIONS(1961),
    [anon_sym_or] = ACTIONS(1959),
    [anon_sym_and] = ACTIONS(1959),
    [anon_sym_bitor] = ACTIONS(1959),
    [anon_sym_xor] = ACTIONS(1959),
    [anon_sym_bitand] = ACTIONS(1959),
    [anon_sym_not_eq] = ACTIONS(1959),
    [anon_sym_DASH_DASH] = ACTIONS(1961),
    [anon_sym_PLUS_PLUS] = ACTIONS(1961),
    [anon_sym_DOT] = ACTIONS(1959),
    [anon_sym_DOT_STAR] = ACTIONS(1961),
    [anon_sym_DASH_GT] = ACTIONS(1961),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1959),
    [anon_sym_decltype] = ACTIONS(1959),
    [anon_sym_final] = ACTIONS(1959),
    [anon_sym_override] = ACTIONS(1959),
  },
  [2490] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(3821),
    [sym_raw_string_literal] = STATE(2868),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3824),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5243),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON] = ACTIONS(3896),
    [anon_sym_SEMI] = ACTIONS(3824),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_RBRACE] = ACTIONS(3824),
    [anon_sym_LBRACK] = ACTIONS(3824),
    [anon_sym_EQ] = ACTIONS(3854),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3856),
    [anon_sym_SLASH_EQ] = ACTIONS(3856),
    [anon_sym_PERCENT_EQ] = ACTIONS(3856),
    [anon_sym_PLUS_EQ] = ACTIONS(3856),
    [anon_sym_DASH_EQ] = ACTIONS(3856),
    [anon_sym_LT_LT_EQ] = ACTIONS(3856),
    [anon_sym_GT_GT_EQ] = ACTIONS(3856),
    [anon_sym_AMP_EQ] = ACTIONS(3856),
    [anon_sym_CARET_EQ] = ACTIONS(3856),
    [anon_sym_PIPE_EQ] = ACTIONS(3856),
    [anon_sym_and_eq] = ACTIONS(3856),
    [anon_sym_or_eq] = ACTIONS(3856),
    [anon_sym_xor_eq] = ACTIONS(3856),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
  },
  [2491] = {
    [sym_string_literal] = STATE(2344),
    [sym_template_argument_list] = STATE(3035),
    [sym_raw_string_literal] = STATE(2344),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(5876),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5879),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_SEMI] = ACTIONS(3824),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5188),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_RBRACE] = ACTIONS(3824),
    [anon_sym_LBRACK] = ACTIONS(5882),
    [anon_sym_EQ] = ACTIONS(3832),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3824),
    [anon_sym_SLASH_EQ] = ACTIONS(3824),
    [anon_sym_PERCENT_EQ] = ACTIONS(3824),
    [anon_sym_PLUS_EQ] = ACTIONS(3824),
    [anon_sym_DASH_EQ] = ACTIONS(3824),
    [anon_sym_LT_LT_EQ] = ACTIONS(3824),
    [anon_sym_GT_GT_EQ] = ACTIONS(3824),
    [anon_sym_AMP_EQ] = ACTIONS(3824),
    [anon_sym_CARET_EQ] = ACTIONS(3824),
    [anon_sym_PIPE_EQ] = ACTIONS(3824),
    [anon_sym_and_eq] = ACTIONS(3824),
    [anon_sym_or_eq] = ACTIONS(3824),
    [anon_sym_xor_eq] = ACTIONS(3824),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
  },
  [2492] = {
    [sym_string_literal] = STATE(2344),
    [sym_raw_string_literal] = STATE(2344),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_RPAREN] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3824),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(3832),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON] = ACTIONS(3824),
    [anon_sym_SEMI] = ACTIONS(3824),
    [anon_sym_RBRACE] = ACTIONS(3824),
    [anon_sym_LBRACK] = ACTIONS(3824),
    [anon_sym_RBRACK] = ACTIONS(3824),
    [anon_sym_EQ] = ACTIONS(3832),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3824),
    [anon_sym_SLASH_EQ] = ACTIONS(3824),
    [anon_sym_PERCENT_EQ] = ACTIONS(3824),
    [anon_sym_PLUS_EQ] = ACTIONS(3824),
    [anon_sym_DASH_EQ] = ACTIONS(3824),
    [anon_sym_LT_LT_EQ] = ACTIONS(3824),
    [anon_sym_GT_GT_EQ] = ACTIONS(3824),
    [anon_sym_AMP_EQ] = ACTIONS(3824),
    [anon_sym_CARET_EQ] = ACTIONS(3824),
    [anon_sym_PIPE_EQ] = ACTIONS(3824),
    [anon_sym_and_eq] = ACTIONS(3832),
    [anon_sym_or_eq] = ACTIONS(3832),
    [anon_sym_xor_eq] = ACTIONS(3832),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3832),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3832),
    [anon_sym_not_eq] = ACTIONS(3832),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [sym_literal_suffix] = ACTIONS(5836),
  },
  [2493] = {
    [sym_identifier] = ACTIONS(1949),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1951),
    [anon_sym_COMMA] = ACTIONS(1951),
    [anon_sym_RPAREN] = ACTIONS(1951),
    [aux_sym_preproc_if_token2] = ACTIONS(1951),
    [aux_sym_preproc_else_token1] = ACTIONS(1951),
    [aux_sym_preproc_elif_token1] = ACTIONS(1949),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1951),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1951),
    [anon_sym_LPAREN2] = ACTIONS(1951),
    [anon_sym_DASH] = ACTIONS(1949),
    [anon_sym_PLUS] = ACTIONS(1949),
    [anon_sym_STAR] = ACTIONS(1949),
    [anon_sym_SLASH] = ACTIONS(1949),
    [anon_sym_PERCENT] = ACTIONS(1949),
    [anon_sym_PIPE_PIPE] = ACTIONS(1951),
    [anon_sym_AMP_AMP] = ACTIONS(1951),
    [anon_sym_PIPE] = ACTIONS(1949),
    [anon_sym_CARET] = ACTIONS(1949),
    [anon_sym_AMP] = ACTIONS(1949),
    [anon_sym_EQ_EQ] = ACTIONS(1951),
    [anon_sym_BANG_EQ] = ACTIONS(1951),
    [anon_sym_GT] = ACTIONS(1949),
    [anon_sym_GT_EQ] = ACTIONS(1951),
    [anon_sym_LT_EQ] = ACTIONS(1949),
    [anon_sym_LT] = ACTIONS(1949),
    [anon_sym_LT_LT] = ACTIONS(1949),
    [anon_sym_GT_GT] = ACTIONS(1949),
    [anon_sym_COLON] = ACTIONS(1949),
    [anon_sym_SEMI] = ACTIONS(1951),
    [anon_sym___attribute__] = ACTIONS(1949),
    [anon_sym_COLON_COLON] = ACTIONS(1951),
    [anon_sym_LBRACE] = ACTIONS(1951),
    [anon_sym_RBRACE] = ACTIONS(1951),
    [anon_sym_LBRACK] = ACTIONS(1951),
    [anon_sym_RBRACK] = ACTIONS(1951),
    [anon_sym_EQ] = ACTIONS(1949),
    [anon_sym_QMARK] = ACTIONS(1951),
    [anon_sym_STAR_EQ] = ACTIONS(1951),
    [anon_sym_SLASH_EQ] = ACTIONS(1951),
    [anon_sym_PERCENT_EQ] = ACTIONS(1951),
    [anon_sym_PLUS_EQ] = ACTIONS(1951),
    [anon_sym_DASH_EQ] = ACTIONS(1951),
    [anon_sym_LT_LT_EQ] = ACTIONS(1951),
    [anon_sym_GT_GT_EQ] = ACTIONS(1951),
    [anon_sym_AMP_EQ] = ACTIONS(1951),
    [anon_sym_CARET_EQ] = ACTIONS(1951),
    [anon_sym_PIPE_EQ] = ACTIONS(1951),
    [anon_sym_and_eq] = ACTIONS(1949),
    [anon_sym_or_eq] = ACTIONS(1949),
    [anon_sym_xor_eq] = ACTIONS(1949),
    [anon_sym_LT_EQ_GT] = ACTIONS(1951),
    [anon_sym_or] = ACTIONS(1949),
    [anon_sym_and] = ACTIONS(1949),
    [anon_sym_bitor] = ACTIONS(1949),
    [anon_sym_xor] = ACTIONS(1949),
    [anon_sym_bitand] = ACTIONS(1949),
    [anon_sym_not_eq] = ACTIONS(1949),
    [anon_sym_DASH_DASH] = ACTIONS(1951),
    [anon_sym_PLUS_PLUS] = ACTIONS(1951),
    [anon_sym_DOT] = ACTIONS(1949),
    [anon_sym_DOT_STAR] = ACTIONS(1951),
    [anon_sym_DASH_GT] = ACTIONS(1951),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1949),
    [anon_sym_decltype] = ACTIONS(1949),
    [anon_sym_final] = ACTIONS(1949),
    [anon_sym_override] = ACTIONS(1949),
  },
  [2494] = {
    [sym_string_literal] = STATE(2344),
    [sym_template_argument_list] = STATE(2687),
    [sym_raw_string_literal] = STATE(2344),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(5885),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5622),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_SEMI] = ACTIONS(3824),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5885),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_RBRACE] = ACTIONS(3824),
    [anon_sym_LBRACK] = ACTIONS(5887),
    [anon_sym_EQ] = ACTIONS(3832),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3824),
    [anon_sym_SLASH_EQ] = ACTIONS(3824),
    [anon_sym_PERCENT_EQ] = ACTIONS(3824),
    [anon_sym_PLUS_EQ] = ACTIONS(3824),
    [anon_sym_DASH_EQ] = ACTIONS(3824),
    [anon_sym_LT_LT_EQ] = ACTIONS(3824),
    [anon_sym_GT_GT_EQ] = ACTIONS(3824),
    [anon_sym_AMP_EQ] = ACTIONS(3824),
    [anon_sym_CARET_EQ] = ACTIONS(3824),
    [anon_sym_PIPE_EQ] = ACTIONS(3824),
    [anon_sym_and_eq] = ACTIONS(3824),
    [anon_sym_or_eq] = ACTIONS(3824),
    [anon_sym_xor_eq] = ACTIONS(3824),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
  },
  [2495] = {
    [sym_identifier] = ACTIONS(1953),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1955),
    [anon_sym_COMMA] = ACTIONS(1955),
    [anon_sym_RPAREN] = ACTIONS(1955),
    [aux_sym_preproc_if_token2] = ACTIONS(1955),
    [aux_sym_preproc_else_token1] = ACTIONS(1955),
    [aux_sym_preproc_elif_token1] = ACTIONS(1953),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1955),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1955),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_DASH] = ACTIONS(1953),
    [anon_sym_PLUS] = ACTIONS(1953),
    [anon_sym_STAR] = ACTIONS(1953),
    [anon_sym_SLASH] = ACTIONS(1953),
    [anon_sym_PERCENT] = ACTIONS(1953),
    [anon_sym_PIPE_PIPE] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_PIPE] = ACTIONS(1953),
    [anon_sym_CARET] = ACTIONS(1953),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym_EQ_EQ] = ACTIONS(1955),
    [anon_sym_BANG_EQ] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1953),
    [anon_sym_GT_EQ] = ACTIONS(1955),
    [anon_sym_LT_EQ] = ACTIONS(1953),
    [anon_sym_LT] = ACTIONS(1953),
    [anon_sym_LT_LT] = ACTIONS(1953),
    [anon_sym_GT_GT] = ACTIONS(1953),
    [anon_sym_COLON] = ACTIONS(1953),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_RBRACE] = ACTIONS(1955),
    [anon_sym_LBRACK] = ACTIONS(1955),
    [anon_sym_RBRACK] = ACTIONS(1955),
    [anon_sym_EQ] = ACTIONS(1953),
    [anon_sym_QMARK] = ACTIONS(1955),
    [anon_sym_STAR_EQ] = ACTIONS(1955),
    [anon_sym_SLASH_EQ] = ACTIONS(1955),
    [anon_sym_PERCENT_EQ] = ACTIONS(1955),
    [anon_sym_PLUS_EQ] = ACTIONS(1955),
    [anon_sym_DASH_EQ] = ACTIONS(1955),
    [anon_sym_LT_LT_EQ] = ACTIONS(1955),
    [anon_sym_GT_GT_EQ] = ACTIONS(1955),
    [anon_sym_AMP_EQ] = ACTIONS(1955),
    [anon_sym_CARET_EQ] = ACTIONS(1955),
    [anon_sym_PIPE_EQ] = ACTIONS(1955),
    [anon_sym_and_eq] = ACTIONS(1953),
    [anon_sym_or_eq] = ACTIONS(1953),
    [anon_sym_xor_eq] = ACTIONS(1953),
    [anon_sym_LT_EQ_GT] = ACTIONS(1955),
    [anon_sym_or] = ACTIONS(1953),
    [anon_sym_and] = ACTIONS(1953),
    [anon_sym_bitor] = ACTIONS(1953),
    [anon_sym_xor] = ACTIONS(1953),
    [anon_sym_bitand] = ACTIONS(1953),
    [anon_sym_not_eq] = ACTIONS(1953),
    [anon_sym_DASH_DASH] = ACTIONS(1955),
    [anon_sym_PLUS_PLUS] = ACTIONS(1955),
    [anon_sym_DOT] = ACTIONS(1953),
    [anon_sym_DOT_STAR] = ACTIONS(1955),
    [anon_sym_DASH_GT] = ACTIONS(1955),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
  },
  [2496] = {
    [sym_identifier] = ACTIONS(1953),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1955),
    [anon_sym_COMMA] = ACTIONS(1955),
    [anon_sym_RPAREN] = ACTIONS(1955),
    [aux_sym_preproc_if_token2] = ACTIONS(1955),
    [aux_sym_preproc_else_token1] = ACTIONS(1955),
    [aux_sym_preproc_elif_token1] = ACTIONS(1953),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1955),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1955),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_DASH] = ACTIONS(1953),
    [anon_sym_PLUS] = ACTIONS(1953),
    [anon_sym_STAR] = ACTIONS(1953),
    [anon_sym_SLASH] = ACTIONS(1953),
    [anon_sym_PERCENT] = ACTIONS(1953),
    [anon_sym_PIPE_PIPE] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_PIPE] = ACTIONS(1953),
    [anon_sym_CARET] = ACTIONS(1953),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym_EQ_EQ] = ACTIONS(1955),
    [anon_sym_BANG_EQ] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1953),
    [anon_sym_GT_EQ] = ACTIONS(1955),
    [anon_sym_LT_EQ] = ACTIONS(1953),
    [anon_sym_LT] = ACTIONS(1953),
    [anon_sym_LT_LT] = ACTIONS(1953),
    [anon_sym_GT_GT] = ACTIONS(1953),
    [anon_sym_COLON] = ACTIONS(1953),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_RBRACE] = ACTIONS(1955),
    [anon_sym_LBRACK] = ACTIONS(1955),
    [anon_sym_RBRACK] = ACTIONS(1955),
    [anon_sym_EQ] = ACTIONS(1953),
    [anon_sym_QMARK] = ACTIONS(1955),
    [anon_sym_STAR_EQ] = ACTIONS(1955),
    [anon_sym_SLASH_EQ] = ACTIONS(1955),
    [anon_sym_PERCENT_EQ] = ACTIONS(1955),
    [anon_sym_PLUS_EQ] = ACTIONS(1955),
    [anon_sym_DASH_EQ] = ACTIONS(1955),
    [anon_sym_LT_LT_EQ] = ACTIONS(1955),
    [anon_sym_GT_GT_EQ] = ACTIONS(1955),
    [anon_sym_AMP_EQ] = ACTIONS(1955),
    [anon_sym_CARET_EQ] = ACTIONS(1955),
    [anon_sym_PIPE_EQ] = ACTIONS(1955),
    [anon_sym_and_eq] = ACTIONS(1953),
    [anon_sym_or_eq] = ACTIONS(1953),
    [anon_sym_xor_eq] = ACTIONS(1953),
    [anon_sym_LT_EQ_GT] = ACTIONS(1955),
    [anon_sym_or] = ACTIONS(1953),
    [anon_sym_and] = ACTIONS(1953),
    [anon_sym_bitor] = ACTIONS(1953),
    [anon_sym_xor] = ACTIONS(1953),
    [anon_sym_bitand] = ACTIONS(1953),
    [anon_sym_not_eq] = ACTIONS(1953),
    [anon_sym_DASH_DASH] = ACTIONS(1955),
    [anon_sym_PLUS_PLUS] = ACTIONS(1955),
    [anon_sym_DOT] = ACTIONS(1953),
    [anon_sym_DOT_STAR] = ACTIONS(1955),
    [anon_sym_DASH_GT] = ACTIONS(1955),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
  },
  [2497] = {
    [sym_string_literal] = STATE(2344),
    [sym_raw_string_literal] = STATE(2344),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5840),
    [anon_sym_COMMA] = ACTIONS(5840),
    [anon_sym_RPAREN] = ACTIONS(5840),
    [anon_sym_LPAREN2] = ACTIONS(5840),
    [anon_sym_DASH] = ACTIONS(5838),
    [anon_sym_PLUS] = ACTIONS(5838),
    [anon_sym_STAR] = ACTIONS(5838),
    [anon_sym_SLASH] = ACTIONS(5838),
    [anon_sym_PERCENT] = ACTIONS(5838),
    [anon_sym_PIPE_PIPE] = ACTIONS(5840),
    [anon_sym_AMP_AMP] = ACTIONS(5840),
    [anon_sym_PIPE] = ACTIONS(5838),
    [anon_sym_CARET] = ACTIONS(5838),
    [anon_sym_AMP] = ACTIONS(5838),
    [anon_sym_EQ_EQ] = ACTIONS(5840),
    [anon_sym_BANG_EQ] = ACTIONS(5840),
    [anon_sym_GT] = ACTIONS(5838),
    [anon_sym_GT_EQ] = ACTIONS(5840),
    [anon_sym_LT_EQ] = ACTIONS(5838),
    [anon_sym_LT] = ACTIONS(5838),
    [anon_sym_LT_LT] = ACTIONS(5838),
    [anon_sym_GT_GT] = ACTIONS(5838),
    [anon_sym_COLON] = ACTIONS(5840),
    [anon_sym_SEMI] = ACTIONS(5840),
    [anon_sym_RBRACE] = ACTIONS(5840),
    [anon_sym_LBRACK] = ACTIONS(5840),
    [anon_sym_RBRACK] = ACTIONS(5840),
    [anon_sym_EQ] = ACTIONS(5838),
    [anon_sym_QMARK] = ACTIONS(5840),
    [anon_sym_STAR_EQ] = ACTIONS(5840),
    [anon_sym_SLASH_EQ] = ACTIONS(5840),
    [anon_sym_PERCENT_EQ] = ACTIONS(5840),
    [anon_sym_PLUS_EQ] = ACTIONS(5840),
    [anon_sym_DASH_EQ] = ACTIONS(5840),
    [anon_sym_LT_LT_EQ] = ACTIONS(5840),
    [anon_sym_GT_GT_EQ] = ACTIONS(5840),
    [anon_sym_AMP_EQ] = ACTIONS(5840),
    [anon_sym_CARET_EQ] = ACTIONS(5840),
    [anon_sym_PIPE_EQ] = ACTIONS(5840),
    [anon_sym_and_eq] = ACTIONS(5838),
    [anon_sym_or_eq] = ACTIONS(5838),
    [anon_sym_xor_eq] = ACTIONS(5838),
    [anon_sym_LT_EQ_GT] = ACTIONS(5840),
    [anon_sym_or] = ACTIONS(5838),
    [anon_sym_and] = ACTIONS(5838),
    [anon_sym_bitor] = ACTIONS(5838),
    [anon_sym_xor] = ACTIONS(5838),
    [anon_sym_bitand] = ACTIONS(5838),
    [anon_sym_not_eq] = ACTIONS(5838),
    [anon_sym_DASH_DASH] = ACTIONS(5840),
    [anon_sym_PLUS_PLUS] = ACTIONS(5840),
    [anon_sym_DOT] = ACTIONS(5838),
    [anon_sym_DOT_STAR] = ACTIONS(5840),
    [anon_sym_DASH_GT] = ACTIONS(5840),
    [anon_sym_L_DQUOTE] = ACTIONS(3541),
    [anon_sym_u_DQUOTE] = ACTIONS(3541),
    [anon_sym_U_DQUOTE] = ACTIONS(3541),
    [anon_sym_u8_DQUOTE] = ACTIONS(3541),
    [anon_sym_DQUOTE] = ACTIONS(3541),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3549),
    [anon_sym_LR_DQUOTE] = ACTIONS(3549),
    [anon_sym_uR_DQUOTE] = ACTIONS(3549),
    [anon_sym_UR_DQUOTE] = ACTIONS(3549),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3549),
    [sym_literal_suffix] = ACTIONS(5836),
  },
  [2498] = {
    [sym_identifier] = ACTIONS(1969),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1971),
    [anon_sym_COMMA] = ACTIONS(1971),
    [anon_sym_RPAREN] = ACTIONS(1971),
    [aux_sym_preproc_if_token2] = ACTIONS(1971),
    [aux_sym_preproc_else_token1] = ACTIONS(1971),
    [aux_sym_preproc_elif_token1] = ACTIONS(1969),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1971),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1971),
    [anon_sym_LPAREN2] = ACTIONS(1971),
    [anon_sym_DASH] = ACTIONS(1969),
    [anon_sym_PLUS] = ACTIONS(1969),
    [anon_sym_STAR] = ACTIONS(1969),
    [anon_sym_SLASH] = ACTIONS(1969),
    [anon_sym_PERCENT] = ACTIONS(1969),
    [anon_sym_PIPE_PIPE] = ACTIONS(1971),
    [anon_sym_AMP_AMP] = ACTIONS(1971),
    [anon_sym_PIPE] = ACTIONS(1969),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_EQ_EQ] = ACTIONS(1971),
    [anon_sym_BANG_EQ] = ACTIONS(1971),
    [anon_sym_GT] = ACTIONS(1969),
    [anon_sym_GT_EQ] = ACTIONS(1971),
    [anon_sym_LT_EQ] = ACTIONS(1969),
    [anon_sym_LT] = ACTIONS(1969),
    [anon_sym_LT_LT] = ACTIONS(1969),
    [anon_sym_GT_GT] = ACTIONS(1969),
    [anon_sym_COLON] = ACTIONS(1969),
    [anon_sym_SEMI] = ACTIONS(1971),
    [anon_sym___attribute__] = ACTIONS(1969),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACE] = ACTIONS(1971),
    [anon_sym_RBRACE] = ACTIONS(1971),
    [anon_sym_LBRACK] = ACTIONS(1971),
    [anon_sym_RBRACK] = ACTIONS(1971),
    [anon_sym_EQ] = ACTIONS(1969),
    [anon_sym_QMARK] = ACTIONS(1971),
    [anon_sym_STAR_EQ] = ACTIONS(1971),
    [anon_sym_SLASH_EQ] = ACTIONS(1971),
    [anon_sym_PERCENT_EQ] = ACTIONS(1971),
    [anon_sym_PLUS_EQ] = ACTIONS(1971),
    [anon_sym_DASH_EQ] = ACTIONS(1971),
    [anon_sym_LT_LT_EQ] = ACTIONS(1971),
    [anon_sym_GT_GT_EQ] = ACTIONS(1971),
    [anon_sym_AMP_EQ] = ACTIONS(1971),
    [anon_sym_CARET_EQ] = ACTIONS(1971),
    [anon_sym_PIPE_EQ] = ACTIONS(1971),
    [anon_sym_and_eq] = ACTIONS(1969),
    [anon_sym_or_eq] = ACTIONS(1969),
    [anon_sym_xor_eq] = ACTIONS(1969),
    [anon_sym_LT_EQ_GT] = ACTIONS(1971),
    [anon_sym_or] = ACTIONS(1969),
    [anon_sym_and] = ACTIONS(1969),
    [anon_sym_bitor] = ACTIONS(1969),
    [anon_sym_xor] = ACTIONS(1969),
    [anon_sym_bitand] = ACTIONS(1969),
    [anon_sym_not_eq] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1971),
    [anon_sym_PLUS_PLUS] = ACTIONS(1971),
    [anon_sym_DOT] = ACTIONS(1969),
    [anon_sym_DOT_STAR] = ACTIONS(1971),
    [anon_sym_DASH_GT] = ACTIONS(1971),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1969),
    [anon_sym_decltype] = ACTIONS(1969),
    [anon_sym_final] = ACTIONS(1969),
    [anon_sym_override] = ACTIONS(1969),
  },
  [2499] = {
    [sym_ms_based_modifier] = STATE(8703),
    [sym_ms_unaligned_ptr_modifier] = STATE(4205),
    [sym_ms_pointer_modifier] = STATE(2503),
    [sym__declarator] = STATE(5944),
    [sym__abstract_declarator] = STATE(6443),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_abstract_parenthesized_declarator] = STATE(6033),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_abstract_pointer_declarator] = STATE(6033),
    [sym_function_declarator] = STATE(6270),
    [sym_abstract_function_declarator] = STATE(6033),
    [sym_array_declarator] = STATE(6270),
    [sym_abstract_array_declarator] = STATE(6033),
    [sym_type_qualifier] = STATE(2913),
    [sym_alignas_qualifier] = STATE(4472),
    [sym_parameter_list] = STATE(3363),
    [sym_decltype] = STATE(8571),
    [sym_reference_declarator] = STATE(6270),
    [sym_abstract_reference_declarator] = STATE(6033),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym__function_declarator_seq] = STATE(6076),
    [sym_template_type] = STATE(8571),
    [sym_template_function] = STATE(6270),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5644),
    [sym_qualified_identifier] = STATE(6270),
    [sym_operator_name] = STATE(6270),
    [aux_sym__type_definition_type_repeat1] = STATE(2913),
    [aux_sym_pointer_declarator_repeat1] = STATE(2503),
    [sym_identifier] = ACTIONS(5889),
    [anon_sym_COMMA] = ACTIONS(5891),
    [anon_sym_RPAREN] = ACTIONS(5891),
    [anon_sym_LPAREN2] = ACTIONS(3934),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(5893),
    [anon_sym_AMP_AMP] = ACTIONS(5895),
    [anon_sym_AMP] = ACTIONS(5897),
    [anon_sym_COLON] = ACTIONS(5899),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(5901),
    [anon_sym___based] = ACTIONS(49),
    [sym_ms_restrict_modifier] = ACTIONS(3906),
    [sym_ms_unsigned_ptr_modifier] = ACTIONS(3906),
    [sym_ms_signed_ptr_modifier] = ACTIONS(3906),
    [anon_sym__unaligned] = ACTIONS(3908),
    [anon_sym___unaligned] = ACTIONS(3908),
    [anon_sym_LBRACK] = ACTIONS(5903),
    [anon_sym_EQ] = ACTIONS(5891),
    [anon_sym_const] = ACTIONS(3904),
    [anon_sym_constexpr] = ACTIONS(3904),
    [anon_sym_volatile] = ACTIONS(3904),
    [anon_sym_restrict] = ACTIONS(3904),
    [anon_sym___restrict__] = ACTIONS(3904),
    [anon_sym__Atomic] = ACTIONS(3904),
    [anon_sym__Noreturn] = ACTIONS(3904),
    [anon_sym_noreturn] = ACTIONS(3904),
    [anon_sym_mutable] = ACTIONS(3904),
    [anon_sym_constinit] = ACTIONS(3904),
    [anon_sym_consteval] = ACTIONS(3904),
    [anon_sym_alignas] = ACTIONS(3910),
    [anon_sym__Alignas] = ACTIONS(3910),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(5891),
    [anon_sym_operator] = ACTIONS(2078),
  },
  [2500] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(3821),
    [sym_raw_string_literal] = STATE(2868),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_RPAREN] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3824),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5243),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_SEMI] = ACTIONS(3824),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_RBRACE] = ACTIONS(3824),
    [anon_sym_LBRACK] = ACTIONS(3824),
    [anon_sym_EQ] = ACTIONS(3854),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3856),
    [anon_sym_SLASH_EQ] = ACTIONS(3856),
    [anon_sym_PERCENT_EQ] = ACTIONS(3856),
    [anon_sym_PLUS_EQ] = ACTIONS(3856),
    [anon_sym_DASH_EQ] = ACTIONS(3856),
    [anon_sym_LT_LT_EQ] = ACTIONS(3856),
    [anon_sym_GT_GT_EQ] = ACTIONS(3856),
    [anon_sym_AMP_EQ] = ACTIONS(3856),
    [anon_sym_CARET_EQ] = ACTIONS(3856),
    [anon_sym_PIPE_EQ] = ACTIONS(3856),
    [anon_sym_and_eq] = ACTIONS(3856),
    [anon_sym_or_eq] = ACTIONS(3856),
    [anon_sym_xor_eq] = ACTIONS(3856),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
  },
  [2501] = {
    [sym_identifier] = ACTIONS(5133),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5135),
    [anon_sym_COMMA] = ACTIONS(5135),
    [anon_sym_RPAREN] = ACTIONS(5135),
    [aux_sym_preproc_if_token2] = ACTIONS(5135),
    [aux_sym_preproc_else_token1] = ACTIONS(5135),
    [aux_sym_preproc_elif_token1] = ACTIONS(5133),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5135),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5135),
    [anon_sym_LPAREN2] = ACTIONS(5135),
    [anon_sym_DASH] = ACTIONS(5133),
    [anon_sym_PLUS] = ACTIONS(5133),
    [anon_sym_STAR] = ACTIONS(5135),
    [anon_sym_SLASH] = ACTIONS(5133),
    [anon_sym_PERCENT] = ACTIONS(5135),
    [anon_sym_PIPE_PIPE] = ACTIONS(5135),
    [anon_sym_AMP_AMP] = ACTIONS(5135),
    [anon_sym_PIPE] = ACTIONS(5133),
    [anon_sym_CARET] = ACTIONS(5135),
    [anon_sym_AMP] = ACTIONS(5133),
    [anon_sym_EQ_EQ] = ACTIONS(5135),
    [anon_sym_BANG_EQ] = ACTIONS(5135),
    [anon_sym_GT] = ACTIONS(5133),
    [anon_sym_GT_EQ] = ACTIONS(5135),
    [anon_sym_LT_EQ] = ACTIONS(5133),
    [anon_sym_LT] = ACTIONS(5133),
    [anon_sym_LT_LT] = ACTIONS(5135),
    [anon_sym_GT_GT] = ACTIONS(5135),
    [anon_sym_COLON] = ACTIONS(5135),
    [anon_sym_SEMI] = ACTIONS(5135),
    [anon_sym___extension__] = ACTIONS(5133),
    [anon_sym___attribute__] = ACTIONS(5133),
    [anon_sym_LBRACE] = ACTIONS(5135),
    [anon_sym_RBRACE] = ACTIONS(5135),
    [anon_sym_LBRACK] = ACTIONS(5135),
    [anon_sym_RBRACK] = ACTIONS(5135),
    [anon_sym_const] = ACTIONS(5133),
    [anon_sym_constexpr] = ACTIONS(5133),
    [anon_sym_volatile] = ACTIONS(5133),
    [anon_sym_restrict] = ACTIONS(5133),
    [anon_sym___restrict__] = ACTIONS(5133),
    [anon_sym__Atomic] = ACTIONS(5133),
    [anon_sym__Noreturn] = ACTIONS(5133),
    [anon_sym_noreturn] = ACTIONS(5133),
    [anon_sym_mutable] = ACTIONS(5133),
    [anon_sym_constinit] = ACTIONS(5133),
    [anon_sym_consteval] = ACTIONS(5133),
    [anon_sym_alignas] = ACTIONS(5133),
    [anon_sym__Alignas] = ACTIONS(5133),
    [anon_sym_QMARK] = ACTIONS(5135),
    [anon_sym_LT_EQ_GT] = ACTIONS(5135),
    [anon_sym_or] = ACTIONS(5133),
    [anon_sym_and] = ACTIONS(5133),
    [anon_sym_bitor] = ACTIONS(5133),
    [anon_sym_xor] = ACTIONS(5133),
    [anon_sym_bitand] = ACTIONS(5133),
    [anon_sym_not_eq] = ACTIONS(5133),
    [anon_sym_DASH_DASH] = ACTIONS(5135),
    [anon_sym_PLUS_PLUS] = ACTIONS(5135),
    [anon_sym_DOT] = ACTIONS(5133),
    [anon_sym_DOT_STAR] = ACTIONS(5135),
    [anon_sym_DASH_GT] = ACTIONS(5135),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5133),
    [anon_sym_decltype] = ACTIONS(5133),
    [anon_sym_final] = ACTIONS(5133),
    [anon_sym_override] = ACTIONS(5133),
    [anon_sym_requires] = ACTIONS(5133),
  },
  [2502] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4058),
    [anon_sym_RPAREN] = ACTIONS(4060),
    [anon_sym_LPAREN2] = ACTIONS(4060),
    [anon_sym_DASH] = ACTIONS(4063),
    [anon_sym_PLUS] = ACTIONS(4063),
    [anon_sym_STAR] = ACTIONS(4065),
    [anon_sym_SLASH] = ACTIONS(4063),
    [anon_sym_PERCENT] = ACTIONS(4063),
    [anon_sym_PIPE_PIPE] = ACTIONS(4058),
    [anon_sym_AMP_AMP] = ACTIONS(4060),
    [anon_sym_PIPE] = ACTIONS(4063),
    [anon_sym_CARET] = ACTIONS(4063),
    [anon_sym_AMP] = ACTIONS(4065),
    [anon_sym_EQ_EQ] = ACTIONS(4058),
    [anon_sym_BANG_EQ] = ACTIONS(4058),
    [anon_sym_GT] = ACTIONS(4063),
    [anon_sym_GT_EQ] = ACTIONS(4058),
    [anon_sym_LT_EQ] = ACTIONS(4063),
    [anon_sym_LT] = ACTIONS(4063),
    [anon_sym_LT_LT] = ACTIONS(4063),
    [anon_sym_GT_GT] = ACTIONS(4063),
    [anon_sym___extension__] = ACTIONS(1961),
    [anon_sym_COLON_COLON] = ACTIONS(1961),
    [anon_sym_LBRACE] = ACTIONS(1961),
    [anon_sym_LBRACK] = ACTIONS(4060),
    [anon_sym_EQ] = ACTIONS(4063),
    [anon_sym_const] = ACTIONS(1959),
    [anon_sym_constexpr] = ACTIONS(1961),
    [anon_sym_volatile] = ACTIONS(1961),
    [anon_sym_restrict] = ACTIONS(1961),
    [anon_sym___restrict__] = ACTIONS(1961),
    [anon_sym__Atomic] = ACTIONS(1961),
    [anon_sym__Noreturn] = ACTIONS(1961),
    [anon_sym_noreturn] = ACTIONS(1961),
    [anon_sym_mutable] = ACTIONS(1961),
    [anon_sym_constinit] = ACTIONS(1961),
    [anon_sym_consteval] = ACTIONS(1961),
    [anon_sym_alignas] = ACTIONS(1961),
    [anon_sym__Alignas] = ACTIONS(1961),
    [anon_sym_QMARK] = ACTIONS(4058),
    [anon_sym_STAR_EQ] = ACTIONS(4058),
    [anon_sym_SLASH_EQ] = ACTIONS(4058),
    [anon_sym_PERCENT_EQ] = ACTIONS(4058),
    [anon_sym_PLUS_EQ] = ACTIONS(4058),
    [anon_sym_DASH_EQ] = ACTIONS(4058),
    [anon_sym_LT_LT_EQ] = ACTIONS(4058),
    [anon_sym_GT_GT_EQ] = ACTIONS(4058),
    [anon_sym_AMP_EQ] = ACTIONS(4058),
    [anon_sym_CARET_EQ] = ACTIONS(4058),
    [anon_sym_PIPE_EQ] = ACTIONS(4058),
    [anon_sym_and_eq] = ACTIONS(4058),
    [anon_sym_or_eq] = ACTIONS(4058),
    [anon_sym_xor_eq] = ACTIONS(4058),
    [anon_sym_LT_EQ_GT] = ACTIONS(4058),
    [anon_sym_or] = ACTIONS(4063),
    [anon_sym_and] = ACTIONS(4063),
    [anon_sym_bitor] = ACTIONS(4058),
    [anon_sym_xor] = ACTIONS(4063),
    [anon_sym_bitand] = ACTIONS(4058),
    [anon_sym_not_eq] = ACTIONS(4058),
    [anon_sym_DASH_DASH] = ACTIONS(4058),
    [anon_sym_PLUS_PLUS] = ACTIONS(4058),
    [anon_sym_DOT] = ACTIONS(4063),
    [anon_sym_DOT_STAR] = ACTIONS(4058),
    [anon_sym_DASH_GT] = ACTIONS(4058),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1961),
    [anon_sym_decltype] = ACTIONS(1961),
  },
  [2503] = {
    [sym_ms_based_modifier] = STATE(8703),
    [sym_ms_unaligned_ptr_modifier] = STATE(4205),
    [sym_ms_pointer_modifier] = STATE(4067),
    [sym__declarator] = STATE(5886),
    [sym__abstract_declarator] = STATE(6445),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_abstract_parenthesized_declarator] = STATE(6033),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_abstract_pointer_declarator] = STATE(6033),
    [sym_function_declarator] = STATE(6270),
    [sym_abstract_function_declarator] = STATE(6033),
    [sym_array_declarator] = STATE(6270),
    [sym_abstract_array_declarator] = STATE(6033),
    [sym_type_qualifier] = STATE(2910),
    [sym_alignas_qualifier] = STATE(4472),
    [sym_parameter_list] = STATE(3363),
    [sym_decltype] = STATE(8571),
    [sym_reference_declarator] = STATE(6270),
    [sym_abstract_reference_declarator] = STATE(6033),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym__function_declarator_seq] = STATE(6076),
    [sym_template_type] = STATE(8571),
    [sym_template_function] = STATE(6270),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5644),
    [sym_qualified_identifier] = STATE(6270),
    [sym_operator_name] = STATE(6270),
    [aux_sym__type_definition_type_repeat1] = STATE(2910),
    [aux_sym_pointer_declarator_repeat1] = STATE(4067),
    [sym_identifier] = ACTIONS(5889),
    [anon_sym_COMMA] = ACTIONS(5905),
    [anon_sym_RPAREN] = ACTIONS(5905),
    [anon_sym_LPAREN2] = ACTIONS(3934),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(5893),
    [anon_sym_AMP_AMP] = ACTIONS(5895),
    [anon_sym_AMP] = ACTIONS(5897),
    [anon_sym_COLON] = ACTIONS(5907),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(5901),
    [anon_sym___based] = ACTIONS(49),
    [sym_ms_restrict_modifier] = ACTIONS(3906),
    [sym_ms_unsigned_ptr_modifier] = ACTIONS(3906),
    [sym_ms_signed_ptr_modifier] = ACTIONS(3906),
    [anon_sym__unaligned] = ACTIONS(3908),
    [anon_sym___unaligned] = ACTIONS(3908),
    [anon_sym_LBRACK] = ACTIONS(5903),
    [anon_sym_EQ] = ACTIONS(5905),
    [anon_sym_const] = ACTIONS(3904),
    [anon_sym_constexpr] = ACTIONS(3904),
    [anon_sym_volatile] = ACTIONS(3904),
    [anon_sym_restrict] = ACTIONS(3904),
    [anon_sym___restrict__] = ACTIONS(3904),
    [anon_sym__Atomic] = ACTIONS(3904),
    [anon_sym__Noreturn] = ACTIONS(3904),
    [anon_sym_noreturn] = ACTIONS(3904),
    [anon_sym_mutable] = ACTIONS(3904),
    [anon_sym_constinit] = ACTIONS(3904),
    [anon_sym_consteval] = ACTIONS(3904),
    [anon_sym_alignas] = ACTIONS(3910),
    [anon_sym__Alignas] = ACTIONS(3910),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(5905),
    [anon_sym_operator] = ACTIONS(2078),
  },
  [2504] = {
    [sym_string_literal] = STATE(2509),
    [sym_template_argument_list] = STATE(3230),
    [sym_raw_string_literal] = STATE(2509),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_RPAREN] = ACTIONS(5876),
    [anon_sym_LPAREN2] = ACTIONS(5876),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5185),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5188),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_LBRACK] = ACTIONS(5882),
    [anon_sym_EQ] = ACTIONS(3832),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3824),
    [anon_sym_SLASH_EQ] = ACTIONS(3824),
    [anon_sym_PERCENT_EQ] = ACTIONS(3824),
    [anon_sym_PLUS_EQ] = ACTIONS(3824),
    [anon_sym_DASH_EQ] = ACTIONS(3824),
    [anon_sym_LT_LT_EQ] = ACTIONS(3824),
    [anon_sym_GT_GT_EQ] = ACTIONS(3824),
    [anon_sym_AMP_EQ] = ACTIONS(3824),
    [anon_sym_CARET_EQ] = ACTIONS(3824),
    [anon_sym_PIPE_EQ] = ACTIONS(3824),
    [anon_sym_and_eq] = ACTIONS(3824),
    [anon_sym_or_eq] = ACTIONS(3824),
    [anon_sym_xor_eq] = ACTIONS(3824),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3832),
    [anon_sym_L_DQUOTE] = ACTIONS(5192),
    [anon_sym_u_DQUOTE] = ACTIONS(5192),
    [anon_sym_U_DQUOTE] = ACTIONS(5192),
    [anon_sym_u8_DQUOTE] = ACTIONS(5192),
    [anon_sym_DQUOTE] = ACTIONS(5192),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5194),
    [anon_sym_LR_DQUOTE] = ACTIONS(5194),
    [anon_sym_uR_DQUOTE] = ACTIONS(5194),
    [anon_sym_UR_DQUOTE] = ACTIONS(5194),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5194),
    [anon_sym_DASH_GT_STAR] = ACTIONS(3824),
  },
  [2505] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(3821),
    [sym_raw_string_literal] = STATE(2868),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3824),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5243),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON] = ACTIONS(5909),
    [anon_sym_SEMI] = ACTIONS(3824),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_RBRACE] = ACTIONS(3824),
    [anon_sym_LBRACK] = ACTIONS(3824),
    [anon_sym_EQ] = ACTIONS(3854),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3856),
    [anon_sym_SLASH_EQ] = ACTIONS(3856),
    [anon_sym_PERCENT_EQ] = ACTIONS(3856),
    [anon_sym_PLUS_EQ] = ACTIONS(3856),
    [anon_sym_DASH_EQ] = ACTIONS(3856),
    [anon_sym_LT_LT_EQ] = ACTIONS(3856),
    [anon_sym_GT_GT_EQ] = ACTIONS(3856),
    [anon_sym_AMP_EQ] = ACTIONS(3856),
    [anon_sym_CARET_EQ] = ACTIONS(3856),
    [anon_sym_PIPE_EQ] = ACTIONS(3856),
    [anon_sym_and_eq] = ACTIONS(3856),
    [anon_sym_or_eq] = ACTIONS(3856),
    [anon_sym_xor_eq] = ACTIONS(3856),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
  },
  [2506] = {
    [sym_string_literal] = STATE(2509),
    [sym_template_argument_list] = STATE(3348),
    [sym_raw_string_literal] = STATE(2509),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_RPAREN] = ACTIONS(5885),
    [anon_sym_LPAREN2] = ACTIONS(5885),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5198),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5885),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_LBRACK] = ACTIONS(5887),
    [anon_sym_EQ] = ACTIONS(3832),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3824),
    [anon_sym_SLASH_EQ] = ACTIONS(3824),
    [anon_sym_PERCENT_EQ] = ACTIONS(3824),
    [anon_sym_PLUS_EQ] = ACTIONS(3824),
    [anon_sym_DASH_EQ] = ACTIONS(3824),
    [anon_sym_LT_LT_EQ] = ACTIONS(3824),
    [anon_sym_GT_GT_EQ] = ACTIONS(3824),
    [anon_sym_AMP_EQ] = ACTIONS(3824),
    [anon_sym_CARET_EQ] = ACTIONS(3824),
    [anon_sym_PIPE_EQ] = ACTIONS(3824),
    [anon_sym_and_eq] = ACTIONS(3824),
    [anon_sym_or_eq] = ACTIONS(3824),
    [anon_sym_xor_eq] = ACTIONS(3824),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3832),
    [anon_sym_L_DQUOTE] = ACTIONS(5192),
    [anon_sym_u_DQUOTE] = ACTIONS(5192),
    [anon_sym_U_DQUOTE] = ACTIONS(5192),
    [anon_sym_u8_DQUOTE] = ACTIONS(5192),
    [anon_sym_DQUOTE] = ACTIONS(5192),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5194),
    [anon_sym_LR_DQUOTE] = ACTIONS(5194),
    [anon_sym_uR_DQUOTE] = ACTIONS(5194),
    [anon_sym_UR_DQUOTE] = ACTIONS(5194),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5194),
    [anon_sym_DASH_GT_STAR] = ACTIONS(3824),
  },
  [2507] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(3821),
    [sym_raw_string_literal] = STATE(2868),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(5885),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5243),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_SEMI] = ACTIONS(3824),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5885),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_RBRACE] = ACTIONS(3824),
    [anon_sym_LBRACK] = ACTIONS(5887),
    [anon_sym_EQ] = ACTIONS(3854),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3856),
    [anon_sym_SLASH_EQ] = ACTIONS(3856),
    [anon_sym_PERCENT_EQ] = ACTIONS(3856),
    [anon_sym_PLUS_EQ] = ACTIONS(3856),
    [anon_sym_DASH_EQ] = ACTIONS(3856),
    [anon_sym_LT_LT_EQ] = ACTIONS(3856),
    [anon_sym_GT_GT_EQ] = ACTIONS(3856),
    [anon_sym_AMP_EQ] = ACTIONS(3856),
    [anon_sym_CARET_EQ] = ACTIONS(3856),
    [anon_sym_PIPE_EQ] = ACTIONS(3856),
    [anon_sym_and_eq] = ACTIONS(3856),
    [anon_sym_or_eq] = ACTIONS(3856),
    [anon_sym_xor_eq] = ACTIONS(3856),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
  },
  [2508] = {
    [sym_attribute_specifier] = STATE(2617),
    [sym_enumerator_list] = STATE(2578),
    [sym_identifier] = ACTIONS(5519),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5521),
    [anon_sym_COMMA] = ACTIONS(5521),
    [anon_sym_RPAREN] = ACTIONS(5521),
    [aux_sym_preproc_if_token2] = ACTIONS(5521),
    [aux_sym_preproc_else_token1] = ACTIONS(5521),
    [aux_sym_preproc_elif_token1] = ACTIONS(5519),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5521),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5521),
    [anon_sym_LPAREN2] = ACTIONS(5521),
    [anon_sym_DASH] = ACTIONS(5519),
    [anon_sym_PLUS] = ACTIONS(5519),
    [anon_sym_STAR] = ACTIONS(5519),
    [anon_sym_SLASH] = ACTIONS(5519),
    [anon_sym_PERCENT] = ACTIONS(5519),
    [anon_sym_PIPE_PIPE] = ACTIONS(5521),
    [anon_sym_AMP_AMP] = ACTIONS(5521),
    [anon_sym_PIPE] = ACTIONS(5519),
    [anon_sym_CARET] = ACTIONS(5519),
    [anon_sym_AMP] = ACTIONS(5519),
    [anon_sym_EQ_EQ] = ACTIONS(5521),
    [anon_sym_BANG_EQ] = ACTIONS(5521),
    [anon_sym_GT] = ACTIONS(5519),
    [anon_sym_GT_EQ] = ACTIONS(5521),
    [anon_sym_LT_EQ] = ACTIONS(5519),
    [anon_sym_LT] = ACTIONS(5519),
    [anon_sym_LT_LT] = ACTIONS(5519),
    [anon_sym_GT_GT] = ACTIONS(5519),
    [anon_sym_COLON] = ACTIONS(5521),
    [anon_sym_SEMI] = ACTIONS(5521),
    [anon_sym___attribute__] = ACTIONS(5815),
    [anon_sym_LBRACE] = ACTIONS(5911),
    [anon_sym_RBRACE] = ACTIONS(5521),
    [anon_sym_LBRACK] = ACTIONS(5521),
    [anon_sym_RBRACK] = ACTIONS(5521),
    [anon_sym_EQ] = ACTIONS(5519),
    [anon_sym_QMARK] = ACTIONS(5521),
    [anon_sym_STAR_EQ] = ACTIONS(5521),
    [anon_sym_SLASH_EQ] = ACTIONS(5521),
    [anon_sym_PERCENT_EQ] = ACTIONS(5521),
    [anon_sym_PLUS_EQ] = ACTIONS(5521),
    [anon_sym_DASH_EQ] = ACTIONS(5521),
    [anon_sym_LT_LT_EQ] = ACTIONS(5521),
    [anon_sym_GT_GT_EQ] = ACTIONS(5521),
    [anon_sym_AMP_EQ] = ACTIONS(5521),
    [anon_sym_CARET_EQ] = ACTIONS(5521),
    [anon_sym_PIPE_EQ] = ACTIONS(5521),
    [anon_sym_and_eq] = ACTIONS(5519),
    [anon_sym_or_eq] = ACTIONS(5519),
    [anon_sym_xor_eq] = ACTIONS(5519),
    [anon_sym_LT_EQ_GT] = ACTIONS(5521),
    [anon_sym_or] = ACTIONS(5519),
    [anon_sym_and] = ACTIONS(5519),
    [anon_sym_bitor] = ACTIONS(5519),
    [anon_sym_xor] = ACTIONS(5519),
    [anon_sym_bitand] = ACTIONS(5519),
    [anon_sym_not_eq] = ACTIONS(5519),
    [anon_sym_DASH_DASH] = ACTIONS(5521),
    [anon_sym_PLUS_PLUS] = ACTIONS(5521),
    [anon_sym_DOT] = ACTIONS(5519),
    [anon_sym_DOT_STAR] = ACTIONS(5521),
    [anon_sym_DASH_GT] = ACTIONS(5521),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5519),
    [anon_sym_decltype] = ACTIONS(5519),
  },
  [2509] = {
    [sym_string_literal] = STATE(2511),
    [sym_raw_string_literal] = STATE(2511),
    [aux_sym_concatenated_string_repeat1] = STATE(2511),
    [sym_identifier] = ACTIONS(5913),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5661),
    [anon_sym_COMMA] = ACTIONS(5661),
    [anon_sym_RPAREN] = ACTIONS(5661),
    [anon_sym_LPAREN2] = ACTIONS(5661),
    [anon_sym_DASH] = ACTIONS(5663),
    [anon_sym_PLUS] = ACTIONS(5663),
    [anon_sym_STAR] = ACTIONS(5663),
    [anon_sym_SLASH] = ACTIONS(5663),
    [anon_sym_PERCENT] = ACTIONS(5663),
    [anon_sym_PIPE_PIPE] = ACTIONS(5661),
    [anon_sym_AMP_AMP] = ACTIONS(5661),
    [anon_sym_PIPE] = ACTIONS(5663),
    [anon_sym_CARET] = ACTIONS(5663),
    [anon_sym_AMP] = ACTIONS(5663),
    [anon_sym_EQ_EQ] = ACTIONS(5661),
    [anon_sym_BANG_EQ] = ACTIONS(5661),
    [anon_sym_GT] = ACTIONS(5663),
    [anon_sym_GT_EQ] = ACTIONS(5661),
    [anon_sym_LT_EQ] = ACTIONS(5663),
    [anon_sym_LT] = ACTIONS(5663),
    [anon_sym_LT_LT] = ACTIONS(5663),
    [anon_sym_GT_GT] = ACTIONS(5663),
    [anon_sym_LBRACK] = ACTIONS(5661),
    [anon_sym_EQ] = ACTIONS(5663),
    [anon_sym_QMARK] = ACTIONS(5661),
    [anon_sym_STAR_EQ] = ACTIONS(5661),
    [anon_sym_SLASH_EQ] = ACTIONS(5661),
    [anon_sym_PERCENT_EQ] = ACTIONS(5661),
    [anon_sym_PLUS_EQ] = ACTIONS(5661),
    [anon_sym_DASH_EQ] = ACTIONS(5661),
    [anon_sym_LT_LT_EQ] = ACTIONS(5661),
    [anon_sym_GT_GT_EQ] = ACTIONS(5661),
    [anon_sym_AMP_EQ] = ACTIONS(5661),
    [anon_sym_CARET_EQ] = ACTIONS(5661),
    [anon_sym_PIPE_EQ] = ACTIONS(5661),
    [anon_sym_and_eq] = ACTIONS(5663),
    [anon_sym_or_eq] = ACTIONS(5663),
    [anon_sym_xor_eq] = ACTIONS(5663),
    [anon_sym_LT_EQ_GT] = ACTIONS(5661),
    [anon_sym_or] = ACTIONS(5663),
    [anon_sym_and] = ACTIONS(5663),
    [anon_sym_bitor] = ACTIONS(5663),
    [anon_sym_xor] = ACTIONS(5663),
    [anon_sym_bitand] = ACTIONS(5663),
    [anon_sym_not_eq] = ACTIONS(5663),
    [anon_sym_DASH_DASH] = ACTIONS(5661),
    [anon_sym_PLUS_PLUS] = ACTIONS(5661),
    [anon_sym_DOT] = ACTIONS(5663),
    [anon_sym_DOT_STAR] = ACTIONS(5661),
    [anon_sym_DASH_GT] = ACTIONS(5663),
    [anon_sym_L_DQUOTE] = ACTIONS(5192),
    [anon_sym_u_DQUOTE] = ACTIONS(5192),
    [anon_sym_U_DQUOTE] = ACTIONS(5192),
    [anon_sym_u8_DQUOTE] = ACTIONS(5192),
    [anon_sym_DQUOTE] = ACTIONS(5192),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5194),
    [anon_sym_LR_DQUOTE] = ACTIONS(5194),
    [anon_sym_uR_DQUOTE] = ACTIONS(5194),
    [anon_sym_UR_DQUOTE] = ACTIONS(5194),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5194),
    [anon_sym_DASH_GT_STAR] = ACTIONS(5661),
    [sym_literal_suffix] = ACTIONS(5663),
  },
  [2510] = {
    [sym_string_literal] = STATE(2510),
    [sym_raw_string_literal] = STATE(2510),
    [aux_sym_concatenated_string_repeat1] = STATE(2510),
    [sym_identifier] = ACTIONS(5915),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5649),
    [anon_sym_COMMA] = ACTIONS(5649),
    [anon_sym_LPAREN2] = ACTIONS(5649),
    [anon_sym_DASH] = ACTIONS(5651),
    [anon_sym_PLUS] = ACTIONS(5651),
    [anon_sym_STAR] = ACTIONS(5651),
    [anon_sym_SLASH] = ACTIONS(5651),
    [anon_sym_PERCENT] = ACTIONS(5651),
    [anon_sym_PIPE_PIPE] = ACTIONS(5649),
    [anon_sym_AMP_AMP] = ACTIONS(5649),
    [anon_sym_PIPE] = ACTIONS(5651),
    [anon_sym_CARET] = ACTIONS(5651),
    [anon_sym_AMP] = ACTIONS(5651),
    [anon_sym_EQ_EQ] = ACTIONS(5649),
    [anon_sym_BANG_EQ] = ACTIONS(5649),
    [anon_sym_GT] = ACTIONS(5651),
    [anon_sym_GT_EQ] = ACTIONS(5649),
    [anon_sym_LT_EQ] = ACTIONS(5651),
    [anon_sym_LT] = ACTIONS(5651),
    [anon_sym_LT_LT] = ACTIONS(5651),
    [anon_sym_GT_GT] = ACTIONS(5651),
    [anon_sym_SEMI] = ACTIONS(5649),
    [anon_sym___attribute__] = ACTIONS(5651),
    [anon_sym_LBRACK] = ACTIONS(5649),
    [anon_sym_EQ] = ACTIONS(5651),
    [anon_sym_QMARK] = ACTIONS(5649),
    [anon_sym_STAR_EQ] = ACTIONS(5649),
    [anon_sym_SLASH_EQ] = ACTIONS(5649),
    [anon_sym_PERCENT_EQ] = ACTIONS(5649),
    [anon_sym_PLUS_EQ] = ACTIONS(5649),
    [anon_sym_DASH_EQ] = ACTIONS(5649),
    [anon_sym_LT_LT_EQ] = ACTIONS(5649),
    [anon_sym_GT_GT_EQ] = ACTIONS(5649),
    [anon_sym_AMP_EQ] = ACTIONS(5649),
    [anon_sym_CARET_EQ] = ACTIONS(5649),
    [anon_sym_PIPE_EQ] = ACTIONS(5649),
    [anon_sym_and_eq] = ACTIONS(5651),
    [anon_sym_or_eq] = ACTIONS(5651),
    [anon_sym_xor_eq] = ACTIONS(5651),
    [anon_sym_LT_EQ_GT] = ACTIONS(5649),
    [anon_sym_or] = ACTIONS(5651),
    [anon_sym_and] = ACTIONS(5651),
    [anon_sym_bitor] = ACTIONS(5651),
    [anon_sym_xor] = ACTIONS(5651),
    [anon_sym_bitand] = ACTIONS(5651),
    [anon_sym_not_eq] = ACTIONS(5651),
    [anon_sym_DASH_DASH] = ACTIONS(5649),
    [anon_sym_PLUS_PLUS] = ACTIONS(5649),
    [anon_sym_DOT] = ACTIONS(5651),
    [anon_sym_DOT_STAR] = ACTIONS(5649),
    [anon_sym_DASH_GT] = ACTIONS(5649),
    [anon_sym_L_DQUOTE] = ACTIONS(5918),
    [anon_sym_u_DQUOTE] = ACTIONS(5918),
    [anon_sym_U_DQUOTE] = ACTIONS(5918),
    [anon_sym_u8_DQUOTE] = ACTIONS(5918),
    [anon_sym_DQUOTE] = ACTIONS(5918),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5921),
    [anon_sym_LR_DQUOTE] = ACTIONS(5921),
    [anon_sym_uR_DQUOTE] = ACTIONS(5921),
    [anon_sym_UR_DQUOTE] = ACTIONS(5921),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5921),
    [sym_literal_suffix] = ACTIONS(5651),
  },
  [2511] = {
    [sym_string_literal] = STATE(2514),
    [sym_raw_string_literal] = STATE(2514),
    [aux_sym_concatenated_string_repeat1] = STATE(2514),
    [sym_identifier] = ACTIONS(5924),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5667),
    [anon_sym_COMMA] = ACTIONS(5667),
    [anon_sym_RPAREN] = ACTIONS(5667),
    [anon_sym_LPAREN2] = ACTIONS(5667),
    [anon_sym_DASH] = ACTIONS(5669),
    [anon_sym_PLUS] = ACTIONS(5669),
    [anon_sym_STAR] = ACTIONS(5669),
    [anon_sym_SLASH] = ACTIONS(5669),
    [anon_sym_PERCENT] = ACTIONS(5669),
    [anon_sym_PIPE_PIPE] = ACTIONS(5667),
    [anon_sym_AMP_AMP] = ACTIONS(5667),
    [anon_sym_PIPE] = ACTIONS(5669),
    [anon_sym_CARET] = ACTIONS(5669),
    [anon_sym_AMP] = ACTIONS(5669),
    [anon_sym_EQ_EQ] = ACTIONS(5667),
    [anon_sym_BANG_EQ] = ACTIONS(5667),
    [anon_sym_GT] = ACTIONS(5669),
    [anon_sym_GT_EQ] = ACTIONS(5667),
    [anon_sym_LT_EQ] = ACTIONS(5669),
    [anon_sym_LT] = ACTIONS(5669),
    [anon_sym_LT_LT] = ACTIONS(5669),
    [anon_sym_GT_GT] = ACTIONS(5669),
    [anon_sym_LBRACK] = ACTIONS(5667),
    [anon_sym_EQ] = ACTIONS(5669),
    [anon_sym_QMARK] = ACTIONS(5667),
    [anon_sym_STAR_EQ] = ACTIONS(5667),
    [anon_sym_SLASH_EQ] = ACTIONS(5667),
    [anon_sym_PERCENT_EQ] = ACTIONS(5667),
    [anon_sym_PLUS_EQ] = ACTIONS(5667),
    [anon_sym_DASH_EQ] = ACTIONS(5667),
    [anon_sym_LT_LT_EQ] = ACTIONS(5667),
    [anon_sym_GT_GT_EQ] = ACTIONS(5667),
    [anon_sym_AMP_EQ] = ACTIONS(5667),
    [anon_sym_CARET_EQ] = ACTIONS(5667),
    [anon_sym_PIPE_EQ] = ACTIONS(5667),
    [anon_sym_and_eq] = ACTIONS(5669),
    [anon_sym_or_eq] = ACTIONS(5669),
    [anon_sym_xor_eq] = ACTIONS(5669),
    [anon_sym_LT_EQ_GT] = ACTIONS(5667),
    [anon_sym_or] = ACTIONS(5669),
    [anon_sym_and] = ACTIONS(5669),
    [anon_sym_bitor] = ACTIONS(5669),
    [anon_sym_xor] = ACTIONS(5669),
    [anon_sym_bitand] = ACTIONS(5669),
    [anon_sym_not_eq] = ACTIONS(5669),
    [anon_sym_DASH_DASH] = ACTIONS(5667),
    [anon_sym_PLUS_PLUS] = ACTIONS(5667),
    [anon_sym_DOT] = ACTIONS(5669),
    [anon_sym_DOT_STAR] = ACTIONS(5667),
    [anon_sym_DASH_GT] = ACTIONS(5669),
    [anon_sym_L_DQUOTE] = ACTIONS(5192),
    [anon_sym_u_DQUOTE] = ACTIONS(5192),
    [anon_sym_U_DQUOTE] = ACTIONS(5192),
    [anon_sym_u8_DQUOTE] = ACTIONS(5192),
    [anon_sym_DQUOTE] = ACTIONS(5192),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5194),
    [anon_sym_LR_DQUOTE] = ACTIONS(5194),
    [anon_sym_uR_DQUOTE] = ACTIONS(5194),
    [anon_sym_UR_DQUOTE] = ACTIONS(5194),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5194),
    [anon_sym_DASH_GT_STAR] = ACTIONS(5667),
    [sym_literal_suffix] = ACTIONS(5669),
  },
  [2512] = {
    [sym_string_literal] = STATE(2674),
    [sym_template_argument_list] = STATE(3725),
    [sym_raw_string_literal] = STATE(2674),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_RPAREN] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3824),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5926),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_LBRACK] = ACTIONS(3824),
    [anon_sym_EQ] = ACTIONS(3832),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3824),
    [anon_sym_SLASH_EQ] = ACTIONS(3824),
    [anon_sym_PERCENT_EQ] = ACTIONS(3824),
    [anon_sym_PLUS_EQ] = ACTIONS(3824),
    [anon_sym_DASH_EQ] = ACTIONS(3824),
    [anon_sym_LT_LT_EQ] = ACTIONS(3824),
    [anon_sym_GT_GT_EQ] = ACTIONS(3824),
    [anon_sym_AMP_EQ] = ACTIONS(3824),
    [anon_sym_CARET_EQ] = ACTIONS(3824),
    [anon_sym_PIPE_EQ] = ACTIONS(3824),
    [anon_sym_and_eq] = ACTIONS(5929),
    [anon_sym_or_eq] = ACTIONS(5929),
    [anon_sym_xor_eq] = ACTIONS(5929),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3832),
    [anon_sym_L_DQUOTE] = ACTIONS(3973),
    [anon_sym_u_DQUOTE] = ACTIONS(3973),
    [anon_sym_U_DQUOTE] = ACTIONS(3973),
    [anon_sym_u8_DQUOTE] = ACTIONS(3973),
    [anon_sym_DQUOTE] = ACTIONS(3973),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3975),
    [anon_sym_LR_DQUOTE] = ACTIONS(3975),
    [anon_sym_uR_DQUOTE] = ACTIONS(3975),
    [anon_sym_UR_DQUOTE] = ACTIONS(3975),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3975),
    [anon_sym_DASH_GT_STAR] = ACTIONS(3824),
  },
  [2513] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2516),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5369),
    [anon_sym_COMMA] = ACTIONS(5369),
    [anon_sym_RPAREN] = ACTIONS(5369),
    [anon_sym_LPAREN2] = ACTIONS(5369),
    [anon_sym_DASH] = ACTIONS(5367),
    [anon_sym_PLUS] = ACTIONS(5367),
    [anon_sym_STAR] = ACTIONS(5369),
    [anon_sym_SLASH] = ACTIONS(5367),
    [anon_sym_PERCENT] = ACTIONS(5369),
    [anon_sym_PIPE_PIPE] = ACTIONS(5369),
    [anon_sym_AMP_AMP] = ACTIONS(5369),
    [anon_sym_PIPE] = ACTIONS(5367),
    [anon_sym_CARET] = ACTIONS(5369),
    [anon_sym_AMP] = ACTIONS(5367),
    [anon_sym_EQ_EQ] = ACTIONS(5369),
    [anon_sym_BANG_EQ] = ACTIONS(5369),
    [anon_sym_GT] = ACTIONS(5367),
    [anon_sym_GT_EQ] = ACTIONS(5369),
    [anon_sym_LT_EQ] = ACTIONS(5367),
    [anon_sym_LT] = ACTIONS(5367),
    [anon_sym_LT_LT] = ACTIONS(5369),
    [anon_sym_GT_GT] = ACTIONS(5369),
    [anon_sym_COLON] = ACTIONS(5369),
    [anon_sym_SEMI] = ACTIONS(5369),
    [anon_sym___extension__] = ACTIONS(5369),
    [anon_sym___attribute__] = ACTIONS(5369),
    [anon_sym_LBRACE] = ACTIONS(5369),
    [anon_sym_RBRACE] = ACTIONS(5369),
    [anon_sym_signed] = ACTIONS(5931),
    [anon_sym_unsigned] = ACTIONS(5931),
    [anon_sym_long] = ACTIONS(5931),
    [anon_sym_short] = ACTIONS(5931),
    [anon_sym_LBRACK] = ACTIONS(5369),
    [anon_sym_RBRACK] = ACTIONS(5369),
    [anon_sym_const] = ACTIONS(5367),
    [anon_sym_constexpr] = ACTIONS(5369),
    [anon_sym_volatile] = ACTIONS(5369),
    [anon_sym_restrict] = ACTIONS(5369),
    [anon_sym___restrict__] = ACTIONS(5369),
    [anon_sym__Atomic] = ACTIONS(5369),
    [anon_sym__Noreturn] = ACTIONS(5369),
    [anon_sym_noreturn] = ACTIONS(5369),
    [anon_sym_mutable] = ACTIONS(5369),
    [anon_sym_constinit] = ACTIONS(5369),
    [anon_sym_consteval] = ACTIONS(5369),
    [anon_sym_alignas] = ACTIONS(5369),
    [anon_sym__Alignas] = ACTIONS(5369),
    [anon_sym_QMARK] = ACTIONS(5369),
    [anon_sym_LT_EQ_GT] = ACTIONS(5369),
    [anon_sym_or] = ACTIONS(5369),
    [anon_sym_and] = ACTIONS(5369),
    [anon_sym_bitor] = ACTIONS(5369),
    [anon_sym_xor] = ACTIONS(5369),
    [anon_sym_bitand] = ACTIONS(5369),
    [anon_sym_not_eq] = ACTIONS(5369),
    [anon_sym_DASH_DASH] = ACTIONS(5369),
    [anon_sym_PLUS_PLUS] = ACTIONS(5369),
    [anon_sym_DOT] = ACTIONS(5367),
    [anon_sym_DOT_STAR] = ACTIONS(5369),
    [anon_sym_DASH_GT] = ACTIONS(5369),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5369),
    [anon_sym_decltype] = ACTIONS(5369),
    [anon_sym_final] = ACTIONS(5369),
    [anon_sym_override] = ACTIONS(5369),
    [anon_sym_requires] = ACTIONS(5369),
  },
  [2514] = {
    [sym_string_literal] = STATE(2514),
    [sym_raw_string_literal] = STATE(2514),
    [aux_sym_concatenated_string_repeat1] = STATE(2514),
    [sym_identifier] = ACTIONS(5933),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5649),
    [anon_sym_COMMA] = ACTIONS(5649),
    [anon_sym_RPAREN] = ACTIONS(5649),
    [anon_sym_LPAREN2] = ACTIONS(5649),
    [anon_sym_DASH] = ACTIONS(5651),
    [anon_sym_PLUS] = ACTIONS(5651),
    [anon_sym_STAR] = ACTIONS(5651),
    [anon_sym_SLASH] = ACTIONS(5651),
    [anon_sym_PERCENT] = ACTIONS(5651),
    [anon_sym_PIPE_PIPE] = ACTIONS(5649),
    [anon_sym_AMP_AMP] = ACTIONS(5649),
    [anon_sym_PIPE] = ACTIONS(5651),
    [anon_sym_CARET] = ACTIONS(5651),
    [anon_sym_AMP] = ACTIONS(5651),
    [anon_sym_EQ_EQ] = ACTIONS(5649),
    [anon_sym_BANG_EQ] = ACTIONS(5649),
    [anon_sym_GT] = ACTIONS(5651),
    [anon_sym_GT_EQ] = ACTIONS(5649),
    [anon_sym_LT_EQ] = ACTIONS(5651),
    [anon_sym_LT] = ACTIONS(5651),
    [anon_sym_LT_LT] = ACTIONS(5651),
    [anon_sym_GT_GT] = ACTIONS(5651),
    [anon_sym_LBRACK] = ACTIONS(5649),
    [anon_sym_EQ] = ACTIONS(5651),
    [anon_sym_QMARK] = ACTIONS(5649),
    [anon_sym_STAR_EQ] = ACTIONS(5649),
    [anon_sym_SLASH_EQ] = ACTIONS(5649),
    [anon_sym_PERCENT_EQ] = ACTIONS(5649),
    [anon_sym_PLUS_EQ] = ACTIONS(5649),
    [anon_sym_DASH_EQ] = ACTIONS(5649),
    [anon_sym_LT_LT_EQ] = ACTIONS(5649),
    [anon_sym_GT_GT_EQ] = ACTIONS(5649),
    [anon_sym_AMP_EQ] = ACTIONS(5649),
    [anon_sym_CARET_EQ] = ACTIONS(5649),
    [anon_sym_PIPE_EQ] = ACTIONS(5649),
    [anon_sym_and_eq] = ACTIONS(5651),
    [anon_sym_or_eq] = ACTIONS(5651),
    [anon_sym_xor_eq] = ACTIONS(5651),
    [anon_sym_LT_EQ_GT] = ACTIONS(5649),
    [anon_sym_or] = ACTIONS(5651),
    [anon_sym_and] = ACTIONS(5651),
    [anon_sym_bitor] = ACTIONS(5651),
    [anon_sym_xor] = ACTIONS(5651),
    [anon_sym_bitand] = ACTIONS(5651),
    [anon_sym_not_eq] = ACTIONS(5651),
    [anon_sym_DASH_DASH] = ACTIONS(5649),
    [anon_sym_PLUS_PLUS] = ACTIONS(5649),
    [anon_sym_DOT] = ACTIONS(5651),
    [anon_sym_DOT_STAR] = ACTIONS(5649),
    [anon_sym_DASH_GT] = ACTIONS(5651),
    [anon_sym_L_DQUOTE] = ACTIONS(5936),
    [anon_sym_u_DQUOTE] = ACTIONS(5936),
    [anon_sym_U_DQUOTE] = ACTIONS(5936),
    [anon_sym_u8_DQUOTE] = ACTIONS(5936),
    [anon_sym_DQUOTE] = ACTIONS(5936),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5939),
    [anon_sym_LR_DQUOTE] = ACTIONS(5939),
    [anon_sym_uR_DQUOTE] = ACTIONS(5939),
    [anon_sym_UR_DQUOTE] = ACTIONS(5939),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5939),
    [anon_sym_DASH_GT_STAR] = ACTIONS(5649),
    [sym_literal_suffix] = ACTIONS(5651),
  },
  [2515] = {
    [sym_string_literal] = STATE(2509),
    [sym_template_argument_list] = STATE(3348),
    [sym_raw_string_literal] = STATE(2509),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_RPAREN] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3824),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5198),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_LBRACK] = ACTIONS(3824),
    [anon_sym_EQ] = ACTIONS(3832),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3824),
    [anon_sym_SLASH_EQ] = ACTIONS(3824),
    [anon_sym_PERCENT_EQ] = ACTIONS(3824),
    [anon_sym_PLUS_EQ] = ACTIONS(3824),
    [anon_sym_DASH_EQ] = ACTIONS(3824),
    [anon_sym_LT_LT_EQ] = ACTIONS(3824),
    [anon_sym_GT_GT_EQ] = ACTIONS(3824),
    [anon_sym_AMP_EQ] = ACTIONS(3824),
    [anon_sym_CARET_EQ] = ACTIONS(3824),
    [anon_sym_PIPE_EQ] = ACTIONS(3824),
    [anon_sym_and_eq] = ACTIONS(3824),
    [anon_sym_or_eq] = ACTIONS(3824),
    [anon_sym_xor_eq] = ACTIONS(3824),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3832),
    [anon_sym_L_DQUOTE] = ACTIONS(5192),
    [anon_sym_u_DQUOTE] = ACTIONS(5192),
    [anon_sym_U_DQUOTE] = ACTIONS(5192),
    [anon_sym_u8_DQUOTE] = ACTIONS(5192),
    [anon_sym_DQUOTE] = ACTIONS(5192),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5194),
    [anon_sym_LR_DQUOTE] = ACTIONS(5194),
    [anon_sym_uR_DQUOTE] = ACTIONS(5194),
    [anon_sym_UR_DQUOTE] = ACTIONS(5194),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5194),
    [anon_sym_DASH_GT_STAR] = ACTIONS(3824),
  },
  [2516] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2374),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5389),
    [anon_sym_COMMA] = ACTIONS(5389),
    [anon_sym_RPAREN] = ACTIONS(5389),
    [anon_sym_LPAREN2] = ACTIONS(5389),
    [anon_sym_DASH] = ACTIONS(5387),
    [anon_sym_PLUS] = ACTIONS(5387),
    [anon_sym_STAR] = ACTIONS(5389),
    [anon_sym_SLASH] = ACTIONS(5387),
    [anon_sym_PERCENT] = ACTIONS(5389),
    [anon_sym_PIPE_PIPE] = ACTIONS(5389),
    [anon_sym_AMP_AMP] = ACTIONS(5389),
    [anon_sym_PIPE] = ACTIONS(5387),
    [anon_sym_CARET] = ACTIONS(5389),
    [anon_sym_AMP] = ACTIONS(5387),
    [anon_sym_EQ_EQ] = ACTIONS(5389),
    [anon_sym_BANG_EQ] = ACTIONS(5389),
    [anon_sym_GT] = ACTIONS(5387),
    [anon_sym_GT_EQ] = ACTIONS(5389),
    [anon_sym_LT_EQ] = ACTIONS(5387),
    [anon_sym_LT] = ACTIONS(5387),
    [anon_sym_LT_LT] = ACTIONS(5389),
    [anon_sym_GT_GT] = ACTIONS(5389),
    [anon_sym_COLON] = ACTIONS(5389),
    [anon_sym_SEMI] = ACTIONS(5389),
    [anon_sym___extension__] = ACTIONS(5389),
    [anon_sym___attribute__] = ACTIONS(5389),
    [anon_sym_LBRACE] = ACTIONS(5389),
    [anon_sym_RBRACE] = ACTIONS(5389),
    [anon_sym_signed] = ACTIONS(5942),
    [anon_sym_unsigned] = ACTIONS(5942),
    [anon_sym_long] = ACTIONS(5942),
    [anon_sym_short] = ACTIONS(5942),
    [anon_sym_LBRACK] = ACTIONS(5389),
    [anon_sym_RBRACK] = ACTIONS(5389),
    [anon_sym_const] = ACTIONS(5387),
    [anon_sym_constexpr] = ACTIONS(5389),
    [anon_sym_volatile] = ACTIONS(5389),
    [anon_sym_restrict] = ACTIONS(5389),
    [anon_sym___restrict__] = ACTIONS(5389),
    [anon_sym__Atomic] = ACTIONS(5389),
    [anon_sym__Noreturn] = ACTIONS(5389),
    [anon_sym_noreturn] = ACTIONS(5389),
    [anon_sym_mutable] = ACTIONS(5389),
    [anon_sym_constinit] = ACTIONS(5389),
    [anon_sym_consteval] = ACTIONS(5389),
    [anon_sym_alignas] = ACTIONS(5389),
    [anon_sym__Alignas] = ACTIONS(5389),
    [anon_sym_QMARK] = ACTIONS(5389),
    [anon_sym_LT_EQ_GT] = ACTIONS(5389),
    [anon_sym_or] = ACTIONS(5389),
    [anon_sym_and] = ACTIONS(5389),
    [anon_sym_bitor] = ACTIONS(5389),
    [anon_sym_xor] = ACTIONS(5389),
    [anon_sym_bitand] = ACTIONS(5389),
    [anon_sym_not_eq] = ACTIONS(5389),
    [anon_sym_DASH_DASH] = ACTIONS(5389),
    [anon_sym_PLUS_PLUS] = ACTIONS(5389),
    [anon_sym_DOT] = ACTIONS(5387),
    [anon_sym_DOT_STAR] = ACTIONS(5389),
    [anon_sym_DASH_GT] = ACTIONS(5389),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5389),
    [anon_sym_decltype] = ACTIONS(5389),
    [anon_sym_final] = ACTIONS(5389),
    [anon_sym_override] = ACTIONS(5389),
    [anon_sym_requires] = ACTIONS(5389),
  },
  [2517] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(3821),
    [sym_raw_string_literal] = STATE(2868),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3824),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5243),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON] = ACTIONS(3926),
    [anon_sym_SEMI] = ACTIONS(3824),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_LBRACK] = ACTIONS(3824),
    [anon_sym_EQ] = ACTIONS(3854),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3856),
    [anon_sym_SLASH_EQ] = ACTIONS(3856),
    [anon_sym_PERCENT_EQ] = ACTIONS(3856),
    [anon_sym_PLUS_EQ] = ACTIONS(3856),
    [anon_sym_DASH_EQ] = ACTIONS(3856),
    [anon_sym_LT_LT_EQ] = ACTIONS(3856),
    [anon_sym_GT_GT_EQ] = ACTIONS(3856),
    [anon_sym_AMP_EQ] = ACTIONS(3856),
    [anon_sym_CARET_EQ] = ACTIONS(3856),
    [anon_sym_PIPE_EQ] = ACTIONS(3856),
    [anon_sym_and_eq] = ACTIONS(3856),
    [anon_sym_or_eq] = ACTIONS(3856),
    [anon_sym_xor_eq] = ACTIONS(3856),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
  },
  [2518] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(3821),
    [sym_raw_string_literal] = STATE(2868),
    [aux_sym_structured_binding_declarator_repeat1] = STATE(7032),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(5944),
    [anon_sym_LPAREN2] = ACTIONS(3824),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5243),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_LBRACK] = ACTIONS(3824),
    [anon_sym_RBRACK] = ACTIONS(5946),
    [anon_sym_EQ] = ACTIONS(5949),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(5951),
    [anon_sym_SLASH_EQ] = ACTIONS(5951),
    [anon_sym_PERCENT_EQ] = ACTIONS(5951),
    [anon_sym_PLUS_EQ] = ACTIONS(5951),
    [anon_sym_DASH_EQ] = ACTIONS(5951),
    [anon_sym_LT_LT_EQ] = ACTIONS(5951),
    [anon_sym_GT_GT_EQ] = ACTIONS(5951),
    [anon_sym_AMP_EQ] = ACTIONS(5951),
    [anon_sym_CARET_EQ] = ACTIONS(5951),
    [anon_sym_PIPE_EQ] = ACTIONS(5951),
    [anon_sym_and_eq] = ACTIONS(5951),
    [anon_sym_or_eq] = ACTIONS(5951),
    [anon_sym_xor_eq] = ACTIONS(5951),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
  },
  [2519] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2533),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5355),
    [anon_sym_COMMA] = ACTIONS(5355),
    [anon_sym_RPAREN] = ACTIONS(5355),
    [anon_sym_LPAREN2] = ACTIONS(5355),
    [anon_sym_DASH] = ACTIONS(5353),
    [anon_sym_PLUS] = ACTIONS(5353),
    [anon_sym_STAR] = ACTIONS(5355),
    [anon_sym_SLASH] = ACTIONS(5353),
    [anon_sym_PERCENT] = ACTIONS(5355),
    [anon_sym_PIPE_PIPE] = ACTIONS(5355),
    [anon_sym_AMP_AMP] = ACTIONS(5355),
    [anon_sym_PIPE] = ACTIONS(5353),
    [anon_sym_CARET] = ACTIONS(5355),
    [anon_sym_AMP] = ACTIONS(5353),
    [anon_sym_EQ_EQ] = ACTIONS(5355),
    [anon_sym_BANG_EQ] = ACTIONS(5355),
    [anon_sym_GT] = ACTIONS(5353),
    [anon_sym_GT_EQ] = ACTIONS(5355),
    [anon_sym_LT_EQ] = ACTIONS(5353),
    [anon_sym_LT] = ACTIONS(5353),
    [anon_sym_LT_LT] = ACTIONS(5355),
    [anon_sym_GT_GT] = ACTIONS(5355),
    [anon_sym_COLON] = ACTIONS(5355),
    [anon_sym_SEMI] = ACTIONS(5355),
    [anon_sym___extension__] = ACTIONS(5355),
    [anon_sym___attribute__] = ACTIONS(5355),
    [anon_sym_LBRACE] = ACTIONS(5355),
    [anon_sym_RBRACE] = ACTIONS(5355),
    [anon_sym_signed] = ACTIONS(5953),
    [anon_sym_unsigned] = ACTIONS(5953),
    [anon_sym_long] = ACTIONS(5953),
    [anon_sym_short] = ACTIONS(5953),
    [anon_sym_LBRACK] = ACTIONS(5355),
    [anon_sym_RBRACK] = ACTIONS(5355),
    [anon_sym_const] = ACTIONS(5353),
    [anon_sym_constexpr] = ACTIONS(5355),
    [anon_sym_volatile] = ACTIONS(5355),
    [anon_sym_restrict] = ACTIONS(5355),
    [anon_sym___restrict__] = ACTIONS(5355),
    [anon_sym__Atomic] = ACTIONS(5355),
    [anon_sym__Noreturn] = ACTIONS(5355),
    [anon_sym_noreturn] = ACTIONS(5355),
    [anon_sym_mutable] = ACTIONS(5355),
    [anon_sym_constinit] = ACTIONS(5355),
    [anon_sym_consteval] = ACTIONS(5355),
    [anon_sym_alignas] = ACTIONS(5355),
    [anon_sym__Alignas] = ACTIONS(5355),
    [anon_sym_QMARK] = ACTIONS(5355),
    [anon_sym_LT_EQ_GT] = ACTIONS(5355),
    [anon_sym_or] = ACTIONS(5355),
    [anon_sym_and] = ACTIONS(5355),
    [anon_sym_bitor] = ACTIONS(5355),
    [anon_sym_xor] = ACTIONS(5355),
    [anon_sym_bitand] = ACTIONS(5355),
    [anon_sym_not_eq] = ACTIONS(5355),
    [anon_sym_DASH_DASH] = ACTIONS(5355),
    [anon_sym_PLUS_PLUS] = ACTIONS(5355),
    [anon_sym_DOT] = ACTIONS(5353),
    [anon_sym_DOT_STAR] = ACTIONS(5355),
    [anon_sym_DASH_GT] = ACTIONS(5355),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5355),
    [anon_sym_decltype] = ACTIONS(5355),
    [anon_sym_final] = ACTIONS(5355),
    [anon_sym_override] = ACTIONS(5355),
    [anon_sym_requires] = ACTIONS(5355),
  },
  [2520] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2374),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5349),
    [anon_sym_COMMA] = ACTIONS(5349),
    [anon_sym_RPAREN] = ACTIONS(5349),
    [anon_sym_LPAREN2] = ACTIONS(5349),
    [anon_sym_DASH] = ACTIONS(5347),
    [anon_sym_PLUS] = ACTIONS(5347),
    [anon_sym_STAR] = ACTIONS(5349),
    [anon_sym_SLASH] = ACTIONS(5347),
    [anon_sym_PERCENT] = ACTIONS(5349),
    [anon_sym_PIPE_PIPE] = ACTIONS(5349),
    [anon_sym_AMP_AMP] = ACTIONS(5349),
    [anon_sym_PIPE] = ACTIONS(5347),
    [anon_sym_CARET] = ACTIONS(5349),
    [anon_sym_AMP] = ACTIONS(5347),
    [anon_sym_EQ_EQ] = ACTIONS(5349),
    [anon_sym_BANG_EQ] = ACTIONS(5349),
    [anon_sym_GT] = ACTIONS(5347),
    [anon_sym_GT_EQ] = ACTIONS(5349),
    [anon_sym_LT_EQ] = ACTIONS(5347),
    [anon_sym_LT] = ACTIONS(5347),
    [anon_sym_LT_LT] = ACTIONS(5349),
    [anon_sym_GT_GT] = ACTIONS(5349),
    [anon_sym_COLON] = ACTIONS(5349),
    [anon_sym_SEMI] = ACTIONS(5349),
    [anon_sym___extension__] = ACTIONS(5349),
    [anon_sym___attribute__] = ACTIONS(5349),
    [anon_sym_LBRACE] = ACTIONS(5349),
    [anon_sym_RBRACE] = ACTIONS(5349),
    [anon_sym_signed] = ACTIONS(5942),
    [anon_sym_unsigned] = ACTIONS(5942),
    [anon_sym_long] = ACTIONS(5942),
    [anon_sym_short] = ACTIONS(5942),
    [anon_sym_LBRACK] = ACTIONS(5349),
    [anon_sym_RBRACK] = ACTIONS(5349),
    [anon_sym_const] = ACTIONS(5347),
    [anon_sym_constexpr] = ACTIONS(5349),
    [anon_sym_volatile] = ACTIONS(5349),
    [anon_sym_restrict] = ACTIONS(5349),
    [anon_sym___restrict__] = ACTIONS(5349),
    [anon_sym__Atomic] = ACTIONS(5349),
    [anon_sym__Noreturn] = ACTIONS(5349),
    [anon_sym_noreturn] = ACTIONS(5349),
    [anon_sym_mutable] = ACTIONS(5349),
    [anon_sym_constinit] = ACTIONS(5349),
    [anon_sym_consteval] = ACTIONS(5349),
    [anon_sym_alignas] = ACTIONS(5349),
    [anon_sym__Alignas] = ACTIONS(5349),
    [anon_sym_QMARK] = ACTIONS(5349),
    [anon_sym_LT_EQ_GT] = ACTIONS(5349),
    [anon_sym_or] = ACTIONS(5349),
    [anon_sym_and] = ACTIONS(5349),
    [anon_sym_bitor] = ACTIONS(5349),
    [anon_sym_xor] = ACTIONS(5349),
    [anon_sym_bitand] = ACTIONS(5349),
    [anon_sym_not_eq] = ACTIONS(5349),
    [anon_sym_DASH_DASH] = ACTIONS(5349),
    [anon_sym_PLUS_PLUS] = ACTIONS(5349),
    [anon_sym_DOT] = ACTIONS(5347),
    [anon_sym_DOT_STAR] = ACTIONS(5349),
    [anon_sym_DASH_GT] = ACTIONS(5349),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5349),
    [anon_sym_decltype] = ACTIONS(5349),
    [anon_sym_final] = ACTIONS(5349),
    [anon_sym_override] = ACTIONS(5349),
    [anon_sym_requires] = ACTIONS(5349),
  },
  [2521] = {
    [sym_string_literal] = STATE(2510),
    [sym_raw_string_literal] = STATE(2510),
    [aux_sym_concatenated_string_repeat1] = STATE(2510),
    [sym_identifier] = ACTIONS(5955),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5667),
    [anon_sym_COMMA] = ACTIONS(5667),
    [anon_sym_LPAREN2] = ACTIONS(5667),
    [anon_sym_DASH] = ACTIONS(5669),
    [anon_sym_PLUS] = ACTIONS(5669),
    [anon_sym_STAR] = ACTIONS(5669),
    [anon_sym_SLASH] = ACTIONS(5669),
    [anon_sym_PERCENT] = ACTIONS(5669),
    [anon_sym_PIPE_PIPE] = ACTIONS(5667),
    [anon_sym_AMP_AMP] = ACTIONS(5667),
    [anon_sym_PIPE] = ACTIONS(5669),
    [anon_sym_CARET] = ACTIONS(5669),
    [anon_sym_AMP] = ACTIONS(5669),
    [anon_sym_EQ_EQ] = ACTIONS(5667),
    [anon_sym_BANG_EQ] = ACTIONS(5667),
    [anon_sym_GT] = ACTIONS(5669),
    [anon_sym_GT_EQ] = ACTIONS(5667),
    [anon_sym_LT_EQ] = ACTIONS(5669),
    [anon_sym_LT] = ACTIONS(5669),
    [anon_sym_LT_LT] = ACTIONS(5669),
    [anon_sym_GT_GT] = ACTIONS(5669),
    [anon_sym_SEMI] = ACTIONS(5667),
    [anon_sym___attribute__] = ACTIONS(5669),
    [anon_sym_LBRACK] = ACTIONS(5667),
    [anon_sym_EQ] = ACTIONS(5669),
    [anon_sym_QMARK] = ACTIONS(5667),
    [anon_sym_STAR_EQ] = ACTIONS(5667),
    [anon_sym_SLASH_EQ] = ACTIONS(5667),
    [anon_sym_PERCENT_EQ] = ACTIONS(5667),
    [anon_sym_PLUS_EQ] = ACTIONS(5667),
    [anon_sym_DASH_EQ] = ACTIONS(5667),
    [anon_sym_LT_LT_EQ] = ACTIONS(5667),
    [anon_sym_GT_GT_EQ] = ACTIONS(5667),
    [anon_sym_AMP_EQ] = ACTIONS(5667),
    [anon_sym_CARET_EQ] = ACTIONS(5667),
    [anon_sym_PIPE_EQ] = ACTIONS(5667),
    [anon_sym_and_eq] = ACTIONS(5669),
    [anon_sym_or_eq] = ACTIONS(5669),
    [anon_sym_xor_eq] = ACTIONS(5669),
    [anon_sym_LT_EQ_GT] = ACTIONS(5667),
    [anon_sym_or] = ACTIONS(5669),
    [anon_sym_and] = ACTIONS(5669),
    [anon_sym_bitor] = ACTIONS(5669),
    [anon_sym_xor] = ACTIONS(5669),
    [anon_sym_bitand] = ACTIONS(5669),
    [anon_sym_not_eq] = ACTIONS(5669),
    [anon_sym_DASH_DASH] = ACTIONS(5667),
    [anon_sym_PLUS_PLUS] = ACTIONS(5667),
    [anon_sym_DOT] = ACTIONS(5669),
    [anon_sym_DOT_STAR] = ACTIONS(5667),
    [anon_sym_DASH_GT] = ACTIONS(5667),
    [anon_sym_L_DQUOTE] = ACTIONS(5957),
    [anon_sym_u_DQUOTE] = ACTIONS(5957),
    [anon_sym_U_DQUOTE] = ACTIONS(5957),
    [anon_sym_u8_DQUOTE] = ACTIONS(5957),
    [anon_sym_DQUOTE] = ACTIONS(5957),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5959),
    [anon_sym_LR_DQUOTE] = ACTIONS(5959),
    [anon_sym_uR_DQUOTE] = ACTIONS(5959),
    [anon_sym_UR_DQUOTE] = ACTIONS(5959),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5959),
    [sym_literal_suffix] = ACTIONS(5669),
  },
  [2522] = {
    [sym_string_literal] = STATE(2527),
    [sym_template_argument_list] = STATE(2687),
    [sym_raw_string_literal] = STATE(2527),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3824),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5622),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_SEMI] = ACTIONS(3824),
    [anon_sym___attribute__] = ACTIONS(3824),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_LBRACK] = ACTIONS(3824),
    [anon_sym_EQ] = ACTIONS(3832),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3824),
    [anon_sym_SLASH_EQ] = ACTIONS(3824),
    [anon_sym_PERCENT_EQ] = ACTIONS(3824),
    [anon_sym_PLUS_EQ] = ACTIONS(3824),
    [anon_sym_DASH_EQ] = ACTIONS(3824),
    [anon_sym_LT_LT_EQ] = ACTIONS(3824),
    [anon_sym_GT_GT_EQ] = ACTIONS(3824),
    [anon_sym_AMP_EQ] = ACTIONS(3824),
    [anon_sym_CARET_EQ] = ACTIONS(3824),
    [anon_sym_PIPE_EQ] = ACTIONS(3824),
    [anon_sym_and_eq] = ACTIONS(3824),
    [anon_sym_or_eq] = ACTIONS(3824),
    [anon_sym_xor_eq] = ACTIONS(3824),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(5957),
    [anon_sym_u_DQUOTE] = ACTIONS(5957),
    [anon_sym_U_DQUOTE] = ACTIONS(5957),
    [anon_sym_u8_DQUOTE] = ACTIONS(5957),
    [anon_sym_DQUOTE] = ACTIONS(5957),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5959),
    [anon_sym_LR_DQUOTE] = ACTIONS(5959),
    [anon_sym_uR_DQUOTE] = ACTIONS(5959),
    [anon_sym_UR_DQUOTE] = ACTIONS(5959),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5959),
  },
  [2523] = {
    [sym_template_argument_list] = STATE(2390),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2649),
    [sym_identifier] = ACTIONS(5294),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5296),
    [anon_sym_COMMA] = ACTIONS(5296),
    [aux_sym_preproc_if_token2] = ACTIONS(5296),
    [aux_sym_preproc_else_token1] = ACTIONS(5296),
    [aux_sym_preproc_elif_token1] = ACTIONS(5294),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5296),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5296),
    [anon_sym_LPAREN2] = ACTIONS(5296),
    [anon_sym_DASH] = ACTIONS(5294),
    [anon_sym_PLUS] = ACTIONS(5294),
    [anon_sym_STAR] = ACTIONS(5294),
    [anon_sym_SLASH] = ACTIONS(5294),
    [anon_sym_PERCENT] = ACTIONS(5294),
    [anon_sym_PIPE_PIPE] = ACTIONS(5296),
    [anon_sym_AMP_AMP] = ACTIONS(5296),
    [anon_sym_PIPE] = ACTIONS(5294),
    [anon_sym_CARET] = ACTIONS(5294),
    [anon_sym_AMP] = ACTIONS(5294),
    [anon_sym_EQ_EQ] = ACTIONS(5296),
    [anon_sym_BANG_EQ] = ACTIONS(5296),
    [anon_sym_GT] = ACTIONS(5294),
    [anon_sym_GT_EQ] = ACTIONS(5296),
    [anon_sym_LT_EQ] = ACTIONS(5294),
    [anon_sym_LT] = ACTIONS(5294),
    [anon_sym_LT_LT] = ACTIONS(5294),
    [anon_sym_GT_GT] = ACTIONS(5294),
    [anon_sym___attribute__] = ACTIONS(5294),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(5296),
    [anon_sym_signed] = ACTIONS(5961),
    [anon_sym_unsigned] = ACTIONS(5961),
    [anon_sym_long] = ACTIONS(5961),
    [anon_sym_short] = ACTIONS(5961),
    [anon_sym_LBRACK] = ACTIONS(5296),
    [anon_sym_EQ] = ACTIONS(5294),
    [anon_sym_QMARK] = ACTIONS(5296),
    [anon_sym_STAR_EQ] = ACTIONS(5296),
    [anon_sym_SLASH_EQ] = ACTIONS(5296),
    [anon_sym_PERCENT_EQ] = ACTIONS(5296),
    [anon_sym_PLUS_EQ] = ACTIONS(5296),
    [anon_sym_DASH_EQ] = ACTIONS(5296),
    [anon_sym_LT_LT_EQ] = ACTIONS(5296),
    [anon_sym_GT_GT_EQ] = ACTIONS(5296),
    [anon_sym_AMP_EQ] = ACTIONS(5296),
    [anon_sym_CARET_EQ] = ACTIONS(5296),
    [anon_sym_PIPE_EQ] = ACTIONS(5296),
    [anon_sym_and_eq] = ACTIONS(5294),
    [anon_sym_or_eq] = ACTIONS(5294),
    [anon_sym_xor_eq] = ACTIONS(5294),
    [anon_sym_LT_EQ_GT] = ACTIONS(5296),
    [anon_sym_or] = ACTIONS(5294),
    [anon_sym_and] = ACTIONS(5294),
    [anon_sym_bitor] = ACTIONS(5294),
    [anon_sym_xor] = ACTIONS(5294),
    [anon_sym_bitand] = ACTIONS(5294),
    [anon_sym_not_eq] = ACTIONS(5294),
    [anon_sym_DASH_DASH] = ACTIONS(5296),
    [anon_sym_PLUS_PLUS] = ACTIONS(5296),
    [anon_sym_DOT] = ACTIONS(5294),
    [anon_sym_DOT_STAR] = ACTIONS(5296),
    [anon_sym_DASH_GT] = ACTIONS(5296),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5294),
    [anon_sym_decltype] = ACTIONS(5294),
  },
  [2524] = {
    [sym_attribute_specifier] = STATE(2603),
    [sym_enumerator_list] = STATE(2572),
    [sym_identifier] = ACTIONS(5529),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5531),
    [anon_sym_COMMA] = ACTIONS(5531),
    [anon_sym_RPAREN] = ACTIONS(5531),
    [aux_sym_preproc_if_token2] = ACTIONS(5531),
    [aux_sym_preproc_else_token1] = ACTIONS(5531),
    [aux_sym_preproc_elif_token1] = ACTIONS(5529),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5531),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5531),
    [anon_sym_LPAREN2] = ACTIONS(5531),
    [anon_sym_DASH] = ACTIONS(5529),
    [anon_sym_PLUS] = ACTIONS(5529),
    [anon_sym_STAR] = ACTIONS(5529),
    [anon_sym_SLASH] = ACTIONS(5529),
    [anon_sym_PERCENT] = ACTIONS(5529),
    [anon_sym_PIPE_PIPE] = ACTIONS(5531),
    [anon_sym_AMP_AMP] = ACTIONS(5531),
    [anon_sym_PIPE] = ACTIONS(5529),
    [anon_sym_CARET] = ACTIONS(5529),
    [anon_sym_AMP] = ACTIONS(5529),
    [anon_sym_EQ_EQ] = ACTIONS(5531),
    [anon_sym_BANG_EQ] = ACTIONS(5531),
    [anon_sym_GT] = ACTIONS(5529),
    [anon_sym_GT_EQ] = ACTIONS(5531),
    [anon_sym_LT_EQ] = ACTIONS(5529),
    [anon_sym_LT] = ACTIONS(5529),
    [anon_sym_LT_LT] = ACTIONS(5529),
    [anon_sym_GT_GT] = ACTIONS(5529),
    [anon_sym_COLON] = ACTIONS(5531),
    [anon_sym_SEMI] = ACTIONS(5531),
    [anon_sym___attribute__] = ACTIONS(5815),
    [anon_sym_LBRACE] = ACTIONS(5911),
    [anon_sym_RBRACE] = ACTIONS(5531),
    [anon_sym_LBRACK] = ACTIONS(5531),
    [anon_sym_RBRACK] = ACTIONS(5531),
    [anon_sym_EQ] = ACTIONS(5529),
    [anon_sym_QMARK] = ACTIONS(5531),
    [anon_sym_STAR_EQ] = ACTIONS(5531),
    [anon_sym_SLASH_EQ] = ACTIONS(5531),
    [anon_sym_PERCENT_EQ] = ACTIONS(5531),
    [anon_sym_PLUS_EQ] = ACTIONS(5531),
    [anon_sym_DASH_EQ] = ACTIONS(5531),
    [anon_sym_LT_LT_EQ] = ACTIONS(5531),
    [anon_sym_GT_GT_EQ] = ACTIONS(5531),
    [anon_sym_AMP_EQ] = ACTIONS(5531),
    [anon_sym_CARET_EQ] = ACTIONS(5531),
    [anon_sym_PIPE_EQ] = ACTIONS(5531),
    [anon_sym_and_eq] = ACTIONS(5529),
    [anon_sym_or_eq] = ACTIONS(5529),
    [anon_sym_xor_eq] = ACTIONS(5529),
    [anon_sym_LT_EQ_GT] = ACTIONS(5531),
    [anon_sym_or] = ACTIONS(5529),
    [anon_sym_and] = ACTIONS(5529),
    [anon_sym_bitor] = ACTIONS(5529),
    [anon_sym_xor] = ACTIONS(5529),
    [anon_sym_bitand] = ACTIONS(5529),
    [anon_sym_not_eq] = ACTIONS(5529),
    [anon_sym_DASH_DASH] = ACTIONS(5531),
    [anon_sym_PLUS_PLUS] = ACTIONS(5531),
    [anon_sym_DOT] = ACTIONS(5529),
    [anon_sym_DOT_STAR] = ACTIONS(5531),
    [anon_sym_DASH_GT] = ACTIONS(5531),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5529),
    [anon_sym_decltype] = ACTIONS(5529),
  },
  [2525] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(3821),
    [sym_raw_string_literal] = STATE(2868),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3824),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5243),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON] = ACTIONS(3977),
    [anon_sym_SEMI] = ACTIONS(3824),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_LBRACK] = ACTIONS(3824),
    [anon_sym_EQ] = ACTIONS(3854),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3856),
    [anon_sym_SLASH_EQ] = ACTIONS(3856),
    [anon_sym_PERCENT_EQ] = ACTIONS(3856),
    [anon_sym_PLUS_EQ] = ACTIONS(3856),
    [anon_sym_DASH_EQ] = ACTIONS(3856),
    [anon_sym_LT_LT_EQ] = ACTIONS(3856),
    [anon_sym_GT_GT_EQ] = ACTIONS(3856),
    [anon_sym_AMP_EQ] = ACTIONS(3856),
    [anon_sym_CARET_EQ] = ACTIONS(3856),
    [anon_sym_PIPE_EQ] = ACTIONS(3856),
    [anon_sym_and_eq] = ACTIONS(3856),
    [anon_sym_or_eq] = ACTIONS(3856),
    [anon_sym_xor_eq] = ACTIONS(3856),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
  },
  [2526] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(3821),
    [sym_raw_string_literal] = STATE(2868),
    [aux_sym_structured_binding_declarator_repeat1] = STATE(7032),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(5963),
    [anon_sym_LPAREN2] = ACTIONS(3824),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5243),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_LBRACK] = ACTIONS(3824),
    [anon_sym_RBRACK] = ACTIONS(5946),
    [anon_sym_EQ] = ACTIONS(5949),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(5951),
    [anon_sym_SLASH_EQ] = ACTIONS(5951),
    [anon_sym_PERCENT_EQ] = ACTIONS(5951),
    [anon_sym_PLUS_EQ] = ACTIONS(5951),
    [anon_sym_DASH_EQ] = ACTIONS(5951),
    [anon_sym_LT_LT_EQ] = ACTIONS(5951),
    [anon_sym_GT_GT_EQ] = ACTIONS(5951),
    [anon_sym_AMP_EQ] = ACTIONS(5951),
    [anon_sym_CARET_EQ] = ACTIONS(5951),
    [anon_sym_PIPE_EQ] = ACTIONS(5951),
    [anon_sym_and_eq] = ACTIONS(5951),
    [anon_sym_or_eq] = ACTIONS(5951),
    [anon_sym_xor_eq] = ACTIONS(5951),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
  },
  [2527] = {
    [sym_string_literal] = STATE(2521),
    [sym_raw_string_literal] = STATE(2521),
    [aux_sym_concatenated_string_repeat1] = STATE(2521),
    [sym_identifier] = ACTIONS(5966),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5661),
    [anon_sym_COMMA] = ACTIONS(5661),
    [anon_sym_LPAREN2] = ACTIONS(5661),
    [anon_sym_DASH] = ACTIONS(5663),
    [anon_sym_PLUS] = ACTIONS(5663),
    [anon_sym_STAR] = ACTIONS(5663),
    [anon_sym_SLASH] = ACTIONS(5663),
    [anon_sym_PERCENT] = ACTIONS(5663),
    [anon_sym_PIPE_PIPE] = ACTIONS(5661),
    [anon_sym_AMP_AMP] = ACTIONS(5661),
    [anon_sym_PIPE] = ACTIONS(5663),
    [anon_sym_CARET] = ACTIONS(5663),
    [anon_sym_AMP] = ACTIONS(5663),
    [anon_sym_EQ_EQ] = ACTIONS(5661),
    [anon_sym_BANG_EQ] = ACTIONS(5661),
    [anon_sym_GT] = ACTIONS(5663),
    [anon_sym_GT_EQ] = ACTIONS(5661),
    [anon_sym_LT_EQ] = ACTIONS(5663),
    [anon_sym_LT] = ACTIONS(5663),
    [anon_sym_LT_LT] = ACTIONS(5663),
    [anon_sym_GT_GT] = ACTIONS(5663),
    [anon_sym_SEMI] = ACTIONS(5661),
    [anon_sym___attribute__] = ACTIONS(5663),
    [anon_sym_LBRACK] = ACTIONS(5661),
    [anon_sym_EQ] = ACTIONS(5663),
    [anon_sym_QMARK] = ACTIONS(5661),
    [anon_sym_STAR_EQ] = ACTIONS(5661),
    [anon_sym_SLASH_EQ] = ACTIONS(5661),
    [anon_sym_PERCENT_EQ] = ACTIONS(5661),
    [anon_sym_PLUS_EQ] = ACTIONS(5661),
    [anon_sym_DASH_EQ] = ACTIONS(5661),
    [anon_sym_LT_LT_EQ] = ACTIONS(5661),
    [anon_sym_GT_GT_EQ] = ACTIONS(5661),
    [anon_sym_AMP_EQ] = ACTIONS(5661),
    [anon_sym_CARET_EQ] = ACTIONS(5661),
    [anon_sym_PIPE_EQ] = ACTIONS(5661),
    [anon_sym_and_eq] = ACTIONS(5663),
    [anon_sym_or_eq] = ACTIONS(5663),
    [anon_sym_xor_eq] = ACTIONS(5663),
    [anon_sym_LT_EQ_GT] = ACTIONS(5661),
    [anon_sym_or] = ACTIONS(5663),
    [anon_sym_and] = ACTIONS(5663),
    [anon_sym_bitor] = ACTIONS(5663),
    [anon_sym_xor] = ACTIONS(5663),
    [anon_sym_bitand] = ACTIONS(5663),
    [anon_sym_not_eq] = ACTIONS(5663),
    [anon_sym_DASH_DASH] = ACTIONS(5661),
    [anon_sym_PLUS_PLUS] = ACTIONS(5661),
    [anon_sym_DOT] = ACTIONS(5663),
    [anon_sym_DOT_STAR] = ACTIONS(5661),
    [anon_sym_DASH_GT] = ACTIONS(5661),
    [anon_sym_L_DQUOTE] = ACTIONS(5957),
    [anon_sym_u_DQUOTE] = ACTIONS(5957),
    [anon_sym_U_DQUOTE] = ACTIONS(5957),
    [anon_sym_u8_DQUOTE] = ACTIONS(5957),
    [anon_sym_DQUOTE] = ACTIONS(5957),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5959),
    [anon_sym_LR_DQUOTE] = ACTIONS(5959),
    [anon_sym_uR_DQUOTE] = ACTIONS(5959),
    [anon_sym_UR_DQUOTE] = ACTIONS(5959),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5959),
    [sym_literal_suffix] = ACTIONS(5663),
  },
  [2528] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2533),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5320),
    [anon_sym_COMMA] = ACTIONS(5320),
    [anon_sym_RPAREN] = ACTIONS(5320),
    [anon_sym_LPAREN2] = ACTIONS(5320),
    [anon_sym_DASH] = ACTIONS(5318),
    [anon_sym_PLUS] = ACTIONS(5318),
    [anon_sym_STAR] = ACTIONS(5320),
    [anon_sym_SLASH] = ACTIONS(5318),
    [anon_sym_PERCENT] = ACTIONS(5320),
    [anon_sym_PIPE_PIPE] = ACTIONS(5320),
    [anon_sym_AMP_AMP] = ACTIONS(5320),
    [anon_sym_PIPE] = ACTIONS(5318),
    [anon_sym_CARET] = ACTIONS(5320),
    [anon_sym_AMP] = ACTIONS(5318),
    [anon_sym_EQ_EQ] = ACTIONS(5320),
    [anon_sym_BANG_EQ] = ACTIONS(5320),
    [anon_sym_GT] = ACTIONS(5318),
    [anon_sym_GT_EQ] = ACTIONS(5320),
    [anon_sym_LT_EQ] = ACTIONS(5318),
    [anon_sym_LT] = ACTIONS(5318),
    [anon_sym_LT_LT] = ACTIONS(5320),
    [anon_sym_GT_GT] = ACTIONS(5320),
    [anon_sym_COLON] = ACTIONS(5320),
    [anon_sym_SEMI] = ACTIONS(5320),
    [anon_sym___extension__] = ACTIONS(5320),
    [anon_sym___attribute__] = ACTIONS(5320),
    [anon_sym_LBRACE] = ACTIONS(5320),
    [anon_sym_RBRACE] = ACTIONS(5320),
    [anon_sym_signed] = ACTIONS(5953),
    [anon_sym_unsigned] = ACTIONS(5953),
    [anon_sym_long] = ACTIONS(5953),
    [anon_sym_short] = ACTIONS(5953),
    [anon_sym_LBRACK] = ACTIONS(5320),
    [anon_sym_RBRACK] = ACTIONS(5320),
    [anon_sym_const] = ACTIONS(5318),
    [anon_sym_constexpr] = ACTIONS(5320),
    [anon_sym_volatile] = ACTIONS(5320),
    [anon_sym_restrict] = ACTIONS(5320),
    [anon_sym___restrict__] = ACTIONS(5320),
    [anon_sym__Atomic] = ACTIONS(5320),
    [anon_sym__Noreturn] = ACTIONS(5320),
    [anon_sym_noreturn] = ACTIONS(5320),
    [anon_sym_mutable] = ACTIONS(5320),
    [anon_sym_constinit] = ACTIONS(5320),
    [anon_sym_consteval] = ACTIONS(5320),
    [anon_sym_alignas] = ACTIONS(5320),
    [anon_sym__Alignas] = ACTIONS(5320),
    [anon_sym_QMARK] = ACTIONS(5320),
    [anon_sym_LT_EQ_GT] = ACTIONS(5320),
    [anon_sym_or] = ACTIONS(5320),
    [anon_sym_and] = ACTIONS(5320),
    [anon_sym_bitor] = ACTIONS(5320),
    [anon_sym_xor] = ACTIONS(5320),
    [anon_sym_bitand] = ACTIONS(5320),
    [anon_sym_not_eq] = ACTIONS(5320),
    [anon_sym_DASH_DASH] = ACTIONS(5320),
    [anon_sym_PLUS_PLUS] = ACTIONS(5320),
    [anon_sym_DOT] = ACTIONS(5318),
    [anon_sym_DOT_STAR] = ACTIONS(5320),
    [anon_sym_DASH_GT] = ACTIONS(5320),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5320),
    [anon_sym_decltype] = ACTIONS(5320),
    [anon_sym_final] = ACTIONS(5320),
    [anon_sym_override] = ACTIONS(5320),
    [anon_sym_requires] = ACTIONS(5320),
  },
  [2529] = {
    [sym_identifier] = ACTIONS(1953),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1955),
    [anon_sym_COMMA] = ACTIONS(1955),
    [anon_sym_RPAREN] = ACTIONS(1955),
    [aux_sym_preproc_if_token2] = ACTIONS(1955),
    [aux_sym_preproc_else_token1] = ACTIONS(1955),
    [aux_sym_preproc_elif_token1] = ACTIONS(1953),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(1955),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(1955),
    [anon_sym_LPAREN2] = ACTIONS(1955),
    [anon_sym_DASH] = ACTIONS(1953),
    [anon_sym_PLUS] = ACTIONS(1953),
    [anon_sym_STAR] = ACTIONS(1953),
    [anon_sym_SLASH] = ACTIONS(1953),
    [anon_sym_PERCENT] = ACTIONS(1953),
    [anon_sym_PIPE_PIPE] = ACTIONS(1955),
    [anon_sym_AMP_AMP] = ACTIONS(1955),
    [anon_sym_PIPE] = ACTIONS(1953),
    [anon_sym_CARET] = ACTIONS(1953),
    [anon_sym_AMP] = ACTIONS(1953),
    [anon_sym_EQ_EQ] = ACTIONS(1955),
    [anon_sym_BANG_EQ] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1953),
    [anon_sym_GT_EQ] = ACTIONS(1955),
    [anon_sym_LT_EQ] = ACTIONS(1953),
    [anon_sym_LT] = ACTIONS(1953),
    [anon_sym_LT_LT] = ACTIONS(1953),
    [anon_sym_GT_GT] = ACTIONS(1953),
    [anon_sym_COLON] = ACTIONS(1955),
    [anon_sym_SEMI] = ACTIONS(1955),
    [anon_sym___attribute__] = ACTIONS(1953),
    [anon_sym_LBRACE] = ACTIONS(1955),
    [anon_sym_RBRACE] = ACTIONS(1955),
    [anon_sym_LBRACK] = ACTIONS(1955),
    [anon_sym_RBRACK] = ACTIONS(1955),
    [anon_sym_EQ] = ACTIONS(1953),
    [anon_sym_QMARK] = ACTIONS(1955),
    [anon_sym_STAR_EQ] = ACTIONS(1955),
    [anon_sym_SLASH_EQ] = ACTIONS(1955),
    [anon_sym_PERCENT_EQ] = ACTIONS(1955),
    [anon_sym_PLUS_EQ] = ACTIONS(1955),
    [anon_sym_DASH_EQ] = ACTIONS(1955),
    [anon_sym_LT_LT_EQ] = ACTIONS(1955),
    [anon_sym_GT_GT_EQ] = ACTIONS(1955),
    [anon_sym_AMP_EQ] = ACTIONS(1955),
    [anon_sym_CARET_EQ] = ACTIONS(1955),
    [anon_sym_PIPE_EQ] = ACTIONS(1955),
    [anon_sym_and_eq] = ACTIONS(1953),
    [anon_sym_or_eq] = ACTIONS(1953),
    [anon_sym_xor_eq] = ACTIONS(1953),
    [anon_sym_LT_EQ_GT] = ACTIONS(1955),
    [anon_sym_or] = ACTIONS(1953),
    [anon_sym_and] = ACTIONS(1953),
    [anon_sym_bitor] = ACTIONS(1953),
    [anon_sym_xor] = ACTIONS(1953),
    [anon_sym_bitand] = ACTIONS(1953),
    [anon_sym_not_eq] = ACTIONS(1953),
    [anon_sym_DASH_DASH] = ACTIONS(1955),
    [anon_sym_PLUS_PLUS] = ACTIONS(1955),
    [anon_sym_DOT] = ACTIONS(1953),
    [anon_sym_DOT_STAR] = ACTIONS(1955),
    [anon_sym_DASH_GT] = ACTIONS(1955),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1953),
    [anon_sym_decltype] = ACTIONS(1953),
    [anon_sym_final] = ACTIONS(1953),
    [anon_sym_override] = ACTIONS(1953),
  },
  [2530] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(3821),
    [sym_raw_string_literal] = STATE(2868),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3824),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5243),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON] = ACTIONS(3920),
    [anon_sym_SEMI] = ACTIONS(3824),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_LBRACK] = ACTIONS(3824),
    [anon_sym_EQ] = ACTIONS(3854),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3856),
    [anon_sym_SLASH_EQ] = ACTIONS(3856),
    [anon_sym_PERCENT_EQ] = ACTIONS(3856),
    [anon_sym_PLUS_EQ] = ACTIONS(3856),
    [anon_sym_DASH_EQ] = ACTIONS(3856),
    [anon_sym_LT_LT_EQ] = ACTIONS(3856),
    [anon_sym_GT_GT_EQ] = ACTIONS(3856),
    [anon_sym_AMP_EQ] = ACTIONS(3856),
    [anon_sym_CARET_EQ] = ACTIONS(3856),
    [anon_sym_PIPE_EQ] = ACTIONS(3856),
    [anon_sym_and_eq] = ACTIONS(3856),
    [anon_sym_or_eq] = ACTIONS(3856),
    [anon_sym_xor_eq] = ACTIONS(3856),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
  },
  [2531] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(3821),
    [sym_raw_string_literal] = STATE(2868),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3824),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5243),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON] = ACTIONS(5968),
    [anon_sym_SEMI] = ACTIONS(3824),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_LBRACK] = ACTIONS(3824),
    [anon_sym_EQ] = ACTIONS(3854),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3856),
    [anon_sym_SLASH_EQ] = ACTIONS(3856),
    [anon_sym_PERCENT_EQ] = ACTIONS(3856),
    [anon_sym_PLUS_EQ] = ACTIONS(3856),
    [anon_sym_DASH_EQ] = ACTIONS(3856),
    [anon_sym_LT_LT_EQ] = ACTIONS(3856),
    [anon_sym_GT_GT_EQ] = ACTIONS(3856),
    [anon_sym_AMP_EQ] = ACTIONS(3856),
    [anon_sym_CARET_EQ] = ACTIONS(3856),
    [anon_sym_PIPE_EQ] = ACTIONS(3856),
    [anon_sym_and_eq] = ACTIONS(3856),
    [anon_sym_or_eq] = ACTIONS(3856),
    [anon_sym_xor_eq] = ACTIONS(3856),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
  },
  [2532] = {
    [sym_string_literal] = STATE(3361),
    [sym_template_argument_list] = STATE(3821),
    [sym_raw_string_literal] = STATE(3361),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3824),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5243),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_SEMI] = ACTIONS(3824),
    [anon_sym___attribute__] = ACTIONS(3824),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_LBRACK] = ACTIONS(3824),
    [anon_sym_EQ] = ACTIONS(5970),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(5972),
    [anon_sym_SLASH_EQ] = ACTIONS(5972),
    [anon_sym_PERCENT_EQ] = ACTIONS(5972),
    [anon_sym_PLUS_EQ] = ACTIONS(5972),
    [anon_sym_DASH_EQ] = ACTIONS(5972),
    [anon_sym_LT_LT_EQ] = ACTIONS(5972),
    [anon_sym_GT_GT_EQ] = ACTIONS(5972),
    [anon_sym_AMP_EQ] = ACTIONS(5972),
    [anon_sym_CARET_EQ] = ACTIONS(5972),
    [anon_sym_PIPE_EQ] = ACTIONS(5972),
    [anon_sym_and_eq] = ACTIONS(5972),
    [anon_sym_or_eq] = ACTIONS(5972),
    [anon_sym_xor_eq] = ACTIONS(5972),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(5974),
    [anon_sym_u_DQUOTE] = ACTIONS(5974),
    [anon_sym_U_DQUOTE] = ACTIONS(5974),
    [anon_sym_u8_DQUOTE] = ACTIONS(5974),
    [anon_sym_DQUOTE] = ACTIONS(5974),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5976),
    [anon_sym_LR_DQUOTE] = ACTIONS(5976),
    [anon_sym_uR_DQUOTE] = ACTIONS(5976),
    [anon_sym_UR_DQUOTE] = ACTIONS(5976),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5976),
  },
  [2533] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2374),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5375),
    [anon_sym_COMMA] = ACTIONS(5375),
    [anon_sym_RPAREN] = ACTIONS(5375),
    [anon_sym_LPAREN2] = ACTIONS(5375),
    [anon_sym_DASH] = ACTIONS(5373),
    [anon_sym_PLUS] = ACTIONS(5373),
    [anon_sym_STAR] = ACTIONS(5375),
    [anon_sym_SLASH] = ACTIONS(5373),
    [anon_sym_PERCENT] = ACTIONS(5375),
    [anon_sym_PIPE_PIPE] = ACTIONS(5375),
    [anon_sym_AMP_AMP] = ACTIONS(5375),
    [anon_sym_PIPE] = ACTIONS(5373),
    [anon_sym_CARET] = ACTIONS(5375),
    [anon_sym_AMP] = ACTIONS(5373),
    [anon_sym_EQ_EQ] = ACTIONS(5375),
    [anon_sym_BANG_EQ] = ACTIONS(5375),
    [anon_sym_GT] = ACTIONS(5373),
    [anon_sym_GT_EQ] = ACTIONS(5375),
    [anon_sym_LT_EQ] = ACTIONS(5373),
    [anon_sym_LT] = ACTIONS(5373),
    [anon_sym_LT_LT] = ACTIONS(5375),
    [anon_sym_GT_GT] = ACTIONS(5375),
    [anon_sym_COLON] = ACTIONS(5375),
    [anon_sym_SEMI] = ACTIONS(5375),
    [anon_sym___extension__] = ACTIONS(5375),
    [anon_sym___attribute__] = ACTIONS(5375),
    [anon_sym_LBRACE] = ACTIONS(5375),
    [anon_sym_RBRACE] = ACTIONS(5375),
    [anon_sym_signed] = ACTIONS(5942),
    [anon_sym_unsigned] = ACTIONS(5942),
    [anon_sym_long] = ACTIONS(5942),
    [anon_sym_short] = ACTIONS(5942),
    [anon_sym_LBRACK] = ACTIONS(5375),
    [anon_sym_RBRACK] = ACTIONS(5375),
    [anon_sym_const] = ACTIONS(5373),
    [anon_sym_constexpr] = ACTIONS(5375),
    [anon_sym_volatile] = ACTIONS(5375),
    [anon_sym_restrict] = ACTIONS(5375),
    [anon_sym___restrict__] = ACTIONS(5375),
    [anon_sym__Atomic] = ACTIONS(5375),
    [anon_sym__Noreturn] = ACTIONS(5375),
    [anon_sym_noreturn] = ACTIONS(5375),
    [anon_sym_mutable] = ACTIONS(5375),
    [anon_sym_constinit] = ACTIONS(5375),
    [anon_sym_consteval] = ACTIONS(5375),
    [anon_sym_alignas] = ACTIONS(5375),
    [anon_sym__Alignas] = ACTIONS(5375),
    [anon_sym_QMARK] = ACTIONS(5375),
    [anon_sym_LT_EQ_GT] = ACTIONS(5375),
    [anon_sym_or] = ACTIONS(5375),
    [anon_sym_and] = ACTIONS(5375),
    [anon_sym_bitor] = ACTIONS(5375),
    [anon_sym_xor] = ACTIONS(5375),
    [anon_sym_bitand] = ACTIONS(5375),
    [anon_sym_not_eq] = ACTIONS(5375),
    [anon_sym_DASH_DASH] = ACTIONS(5375),
    [anon_sym_PLUS_PLUS] = ACTIONS(5375),
    [anon_sym_DOT] = ACTIONS(5373),
    [anon_sym_DOT_STAR] = ACTIONS(5375),
    [anon_sym_DASH_GT] = ACTIONS(5375),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5375),
    [anon_sym_decltype] = ACTIONS(5375),
    [anon_sym_final] = ACTIONS(5375),
    [anon_sym_override] = ACTIONS(5375),
    [anon_sym_requires] = ACTIONS(5375),
  },
  [2534] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(3821),
    [sym_raw_string_literal] = STATE(2868),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3824),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5243),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON] = ACTIONS(3916),
    [anon_sym_SEMI] = ACTIONS(3824),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_LBRACK] = ACTIONS(3824),
    [anon_sym_EQ] = ACTIONS(3854),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3856),
    [anon_sym_SLASH_EQ] = ACTIONS(3856),
    [anon_sym_PERCENT_EQ] = ACTIONS(3856),
    [anon_sym_PLUS_EQ] = ACTIONS(3856),
    [anon_sym_DASH_EQ] = ACTIONS(3856),
    [anon_sym_LT_LT_EQ] = ACTIONS(3856),
    [anon_sym_GT_GT_EQ] = ACTIONS(3856),
    [anon_sym_AMP_EQ] = ACTIONS(3856),
    [anon_sym_CARET_EQ] = ACTIONS(3856),
    [anon_sym_PIPE_EQ] = ACTIONS(3856),
    [anon_sym_and_eq] = ACTIONS(3856),
    [anon_sym_or_eq] = ACTIONS(3856),
    [anon_sym_xor_eq] = ACTIONS(3856),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
  },
  [2535] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2374),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5379),
    [anon_sym_COMMA] = ACTIONS(5379),
    [anon_sym_RPAREN] = ACTIONS(5379),
    [anon_sym_LPAREN2] = ACTIONS(5379),
    [anon_sym_DASH] = ACTIONS(5377),
    [anon_sym_PLUS] = ACTIONS(5377),
    [anon_sym_STAR] = ACTIONS(5379),
    [anon_sym_SLASH] = ACTIONS(5377),
    [anon_sym_PERCENT] = ACTIONS(5379),
    [anon_sym_PIPE_PIPE] = ACTIONS(5379),
    [anon_sym_AMP_AMP] = ACTIONS(5379),
    [anon_sym_PIPE] = ACTIONS(5377),
    [anon_sym_CARET] = ACTIONS(5379),
    [anon_sym_AMP] = ACTIONS(5377),
    [anon_sym_EQ_EQ] = ACTIONS(5379),
    [anon_sym_BANG_EQ] = ACTIONS(5379),
    [anon_sym_GT] = ACTIONS(5377),
    [anon_sym_GT_EQ] = ACTIONS(5379),
    [anon_sym_LT_EQ] = ACTIONS(5377),
    [anon_sym_LT] = ACTIONS(5377),
    [anon_sym_LT_LT] = ACTIONS(5379),
    [anon_sym_GT_GT] = ACTIONS(5379),
    [anon_sym_COLON] = ACTIONS(5379),
    [anon_sym_SEMI] = ACTIONS(5379),
    [anon_sym___extension__] = ACTIONS(5379),
    [anon_sym___attribute__] = ACTIONS(5379),
    [anon_sym_LBRACE] = ACTIONS(5379),
    [anon_sym_RBRACE] = ACTIONS(5379),
    [anon_sym_signed] = ACTIONS(5942),
    [anon_sym_unsigned] = ACTIONS(5942),
    [anon_sym_long] = ACTIONS(5942),
    [anon_sym_short] = ACTIONS(5942),
    [anon_sym_LBRACK] = ACTIONS(5379),
    [anon_sym_RBRACK] = ACTIONS(5379),
    [anon_sym_const] = ACTIONS(5377),
    [anon_sym_constexpr] = ACTIONS(5379),
    [anon_sym_volatile] = ACTIONS(5379),
    [anon_sym_restrict] = ACTIONS(5379),
    [anon_sym___restrict__] = ACTIONS(5379),
    [anon_sym__Atomic] = ACTIONS(5379),
    [anon_sym__Noreturn] = ACTIONS(5379),
    [anon_sym_noreturn] = ACTIONS(5379),
    [anon_sym_mutable] = ACTIONS(5379),
    [anon_sym_constinit] = ACTIONS(5379),
    [anon_sym_consteval] = ACTIONS(5379),
    [anon_sym_alignas] = ACTIONS(5379),
    [anon_sym__Alignas] = ACTIONS(5379),
    [anon_sym_QMARK] = ACTIONS(5379),
    [anon_sym_LT_EQ_GT] = ACTIONS(5379),
    [anon_sym_or] = ACTIONS(5379),
    [anon_sym_and] = ACTIONS(5379),
    [anon_sym_bitor] = ACTIONS(5379),
    [anon_sym_xor] = ACTIONS(5379),
    [anon_sym_bitand] = ACTIONS(5379),
    [anon_sym_not_eq] = ACTIONS(5379),
    [anon_sym_DASH_DASH] = ACTIONS(5379),
    [anon_sym_PLUS_PLUS] = ACTIONS(5379),
    [anon_sym_DOT] = ACTIONS(5377),
    [anon_sym_DOT_STAR] = ACTIONS(5379),
    [anon_sym_DASH_GT] = ACTIONS(5379),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5379),
    [anon_sym_decltype] = ACTIONS(5379),
    [anon_sym_final] = ACTIONS(5379),
    [anon_sym_override] = ACTIONS(5379),
    [anon_sym_requires] = ACTIONS(5379),
  },
  [2536] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2535),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5383),
    [anon_sym_COMMA] = ACTIONS(5383),
    [anon_sym_RPAREN] = ACTIONS(5383),
    [anon_sym_LPAREN2] = ACTIONS(5383),
    [anon_sym_DASH] = ACTIONS(5381),
    [anon_sym_PLUS] = ACTIONS(5381),
    [anon_sym_STAR] = ACTIONS(5383),
    [anon_sym_SLASH] = ACTIONS(5381),
    [anon_sym_PERCENT] = ACTIONS(5383),
    [anon_sym_PIPE_PIPE] = ACTIONS(5383),
    [anon_sym_AMP_AMP] = ACTIONS(5383),
    [anon_sym_PIPE] = ACTIONS(5381),
    [anon_sym_CARET] = ACTIONS(5383),
    [anon_sym_AMP] = ACTIONS(5381),
    [anon_sym_EQ_EQ] = ACTIONS(5383),
    [anon_sym_BANG_EQ] = ACTIONS(5383),
    [anon_sym_GT] = ACTIONS(5381),
    [anon_sym_GT_EQ] = ACTIONS(5383),
    [anon_sym_LT_EQ] = ACTIONS(5381),
    [anon_sym_LT] = ACTIONS(5381),
    [anon_sym_LT_LT] = ACTIONS(5383),
    [anon_sym_GT_GT] = ACTIONS(5383),
    [anon_sym_COLON] = ACTIONS(5383),
    [anon_sym_SEMI] = ACTIONS(5383),
    [anon_sym___extension__] = ACTIONS(5383),
    [anon_sym___attribute__] = ACTIONS(5383),
    [anon_sym_LBRACE] = ACTIONS(5383),
    [anon_sym_RBRACE] = ACTIONS(5383),
    [anon_sym_signed] = ACTIONS(5978),
    [anon_sym_unsigned] = ACTIONS(5978),
    [anon_sym_long] = ACTIONS(5978),
    [anon_sym_short] = ACTIONS(5978),
    [anon_sym_LBRACK] = ACTIONS(5383),
    [anon_sym_RBRACK] = ACTIONS(5383),
    [anon_sym_const] = ACTIONS(5381),
    [anon_sym_constexpr] = ACTIONS(5383),
    [anon_sym_volatile] = ACTIONS(5383),
    [anon_sym_restrict] = ACTIONS(5383),
    [anon_sym___restrict__] = ACTIONS(5383),
    [anon_sym__Atomic] = ACTIONS(5383),
    [anon_sym__Noreturn] = ACTIONS(5383),
    [anon_sym_noreturn] = ACTIONS(5383),
    [anon_sym_mutable] = ACTIONS(5383),
    [anon_sym_constinit] = ACTIONS(5383),
    [anon_sym_consteval] = ACTIONS(5383),
    [anon_sym_alignas] = ACTIONS(5383),
    [anon_sym__Alignas] = ACTIONS(5383),
    [anon_sym_QMARK] = ACTIONS(5383),
    [anon_sym_LT_EQ_GT] = ACTIONS(5383),
    [anon_sym_or] = ACTIONS(5383),
    [anon_sym_and] = ACTIONS(5383),
    [anon_sym_bitor] = ACTIONS(5383),
    [anon_sym_xor] = ACTIONS(5383),
    [anon_sym_bitand] = ACTIONS(5383),
    [anon_sym_not_eq] = ACTIONS(5383),
    [anon_sym_DASH_DASH] = ACTIONS(5383),
    [anon_sym_PLUS_PLUS] = ACTIONS(5383),
    [anon_sym_DOT] = ACTIONS(5381),
    [anon_sym_DOT_STAR] = ACTIONS(5383),
    [anon_sym_DASH_GT] = ACTIONS(5383),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5383),
    [anon_sym_decltype] = ACTIONS(5383),
    [anon_sym_final] = ACTIONS(5383),
    [anon_sym_override] = ACTIONS(5383),
    [anon_sym_requires] = ACTIONS(5383),
  },
  [2537] = {
    [sym_attribute_declaration] = STATE(2642),
    [sym_parameter_list] = STATE(2652),
    [aux_sym_attributed_declarator_repeat1] = STATE(2642),
    [sym_identifier] = ACTIONS(5980),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5982),
    [anon_sym_COMMA] = ACTIONS(5982),
    [anon_sym_RPAREN] = ACTIONS(5982),
    [aux_sym_preproc_if_token2] = ACTIONS(5982),
    [aux_sym_preproc_else_token1] = ACTIONS(5982),
    [aux_sym_preproc_elif_token1] = ACTIONS(5980),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5982),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5982),
    [anon_sym_LPAREN2] = ACTIONS(5984),
    [anon_sym_DASH] = ACTIONS(5980),
    [anon_sym_PLUS] = ACTIONS(5980),
    [anon_sym_STAR] = ACTIONS(5980),
    [anon_sym_SLASH] = ACTIONS(5980),
    [anon_sym_PERCENT] = ACTIONS(5980),
    [anon_sym_PIPE_PIPE] = ACTIONS(5982),
    [anon_sym_AMP_AMP] = ACTIONS(5982),
    [anon_sym_PIPE] = ACTIONS(5980),
    [anon_sym_CARET] = ACTIONS(5980),
    [anon_sym_AMP] = ACTIONS(5980),
    [anon_sym_EQ_EQ] = ACTIONS(5982),
    [anon_sym_BANG_EQ] = ACTIONS(5982),
    [anon_sym_GT] = ACTIONS(5980),
    [anon_sym_GT_EQ] = ACTIONS(5982),
    [anon_sym_LT_EQ] = ACTIONS(5980),
    [anon_sym_LT] = ACTIONS(5980),
    [anon_sym_LT_LT] = ACTIONS(5980),
    [anon_sym_GT_GT] = ACTIONS(5980),
    [anon_sym_COLON] = ACTIONS(5982),
    [anon_sym_SEMI] = ACTIONS(5982),
    [anon_sym___attribute__] = ACTIONS(5980),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5986),
    [anon_sym_RBRACE] = ACTIONS(5982),
    [anon_sym_LBRACK] = ACTIONS(5988),
    [anon_sym_RBRACK] = ACTIONS(5982),
    [anon_sym_EQ] = ACTIONS(5980),
    [anon_sym_QMARK] = ACTIONS(5982),
    [anon_sym_STAR_EQ] = ACTIONS(5982),
    [anon_sym_SLASH_EQ] = ACTIONS(5982),
    [anon_sym_PERCENT_EQ] = ACTIONS(5982),
    [anon_sym_PLUS_EQ] = ACTIONS(5982),
    [anon_sym_DASH_EQ] = ACTIONS(5982),
    [anon_sym_LT_LT_EQ] = ACTIONS(5982),
    [anon_sym_GT_GT_EQ] = ACTIONS(5982),
    [anon_sym_AMP_EQ] = ACTIONS(5982),
    [anon_sym_CARET_EQ] = ACTIONS(5982),
    [anon_sym_PIPE_EQ] = ACTIONS(5982),
    [anon_sym_and_eq] = ACTIONS(5980),
    [anon_sym_or_eq] = ACTIONS(5980),
    [anon_sym_xor_eq] = ACTIONS(5980),
    [anon_sym_LT_EQ_GT] = ACTIONS(5982),
    [anon_sym_or] = ACTIONS(5980),
    [anon_sym_and] = ACTIONS(5980),
    [anon_sym_bitor] = ACTIONS(5980),
    [anon_sym_xor] = ACTIONS(5980),
    [anon_sym_bitand] = ACTIONS(5980),
    [anon_sym_not_eq] = ACTIONS(5980),
    [anon_sym_DASH_DASH] = ACTIONS(5982),
    [anon_sym_PLUS_PLUS] = ACTIONS(5982),
    [anon_sym_DOT] = ACTIONS(5980),
    [anon_sym_DOT_STAR] = ACTIONS(5982),
    [anon_sym_DASH_GT] = ACTIONS(5982),
    [sym_comment] = ACTIONS(3),
  },
  [2538] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5781),
    [anon_sym_COMMA] = ACTIONS(5781),
    [anon_sym_RPAREN] = ACTIONS(5781),
    [anon_sym_LPAREN2] = ACTIONS(5781),
    [anon_sym_DASH] = ACTIONS(5779),
    [anon_sym_PLUS] = ACTIONS(5779),
    [anon_sym_STAR] = ACTIONS(5779),
    [anon_sym_SLASH] = ACTIONS(5779),
    [anon_sym_PERCENT] = ACTIONS(5779),
    [anon_sym_PIPE_PIPE] = ACTIONS(5781),
    [anon_sym_AMP_AMP] = ACTIONS(5781),
    [anon_sym_PIPE] = ACTIONS(5779),
    [anon_sym_CARET] = ACTIONS(5779),
    [anon_sym_AMP] = ACTIONS(5779),
    [anon_sym_EQ_EQ] = ACTIONS(5781),
    [anon_sym_BANG_EQ] = ACTIONS(5781),
    [anon_sym_GT] = ACTIONS(5779),
    [anon_sym_GT_EQ] = ACTIONS(5781),
    [anon_sym_LT_EQ] = ACTIONS(5779),
    [anon_sym_LT] = ACTIONS(5779),
    [anon_sym_LT_LT] = ACTIONS(5779),
    [anon_sym_GT_GT] = ACTIONS(5779),
    [anon_sym_COLON] = ACTIONS(5781),
    [anon_sym_SEMI] = ACTIONS(5781),
    [anon_sym_RBRACE] = ACTIONS(5781),
    [anon_sym_LBRACK] = ACTIONS(5781),
    [anon_sym_RBRACK] = ACTIONS(5781),
    [anon_sym_EQ] = ACTIONS(5779),
    [anon_sym_QMARK] = ACTIONS(5781),
    [anon_sym_STAR_EQ] = ACTIONS(5781),
    [anon_sym_SLASH_EQ] = ACTIONS(5781),
    [anon_sym_PERCENT_EQ] = ACTIONS(5781),
    [anon_sym_PLUS_EQ] = ACTIONS(5781),
    [anon_sym_DASH_EQ] = ACTIONS(5781),
    [anon_sym_LT_LT_EQ] = ACTIONS(5781),
    [anon_sym_GT_GT_EQ] = ACTIONS(5781),
    [anon_sym_AMP_EQ] = ACTIONS(5781),
    [anon_sym_CARET_EQ] = ACTIONS(5781),
    [anon_sym_PIPE_EQ] = ACTIONS(5781),
    [anon_sym_and_eq] = ACTIONS(5779),
    [anon_sym_or_eq] = ACTIONS(5779),
    [anon_sym_xor_eq] = ACTIONS(5779),
    [anon_sym_LT_EQ_GT] = ACTIONS(5781),
    [anon_sym_or] = ACTIONS(5779),
    [anon_sym_and] = ACTIONS(5779),
    [anon_sym_bitor] = ACTIONS(5779),
    [anon_sym_xor] = ACTIONS(5779),
    [anon_sym_bitand] = ACTIONS(5779),
    [anon_sym_not_eq] = ACTIONS(5779),
    [anon_sym_DASH_DASH] = ACTIONS(5781),
    [anon_sym_PLUS_PLUS] = ACTIONS(5781),
    [anon_sym_DOT] = ACTIONS(5779),
    [anon_sym_DOT_STAR] = ACTIONS(5781),
    [anon_sym_DASH_GT] = ACTIONS(5781),
    [anon_sym_L_DQUOTE] = ACTIONS(5781),
    [anon_sym_u_DQUOTE] = ACTIONS(5781),
    [anon_sym_U_DQUOTE] = ACTIONS(5781),
    [anon_sym_u8_DQUOTE] = ACTIONS(5781),
    [anon_sym_DQUOTE] = ACTIONS(5781),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5781),
    [anon_sym_LR_DQUOTE] = ACTIONS(5781),
    [anon_sym_uR_DQUOTE] = ACTIONS(5781),
    [anon_sym_UR_DQUOTE] = ACTIONS(5781),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5781),
    [sym_literal_suffix] = ACTIONS(5779),
  },
  [2539] = {
    [sym_string_literal] = STATE(2560),
    [sym_raw_string_literal] = STATE(2560),
    [aux_sym_concatenated_string_repeat1] = STATE(2560),
    [sym_identifier] = ACTIONS(5990),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5661),
    [anon_sym_COMMA] = ACTIONS(5661),
    [anon_sym_LPAREN2] = ACTIONS(5661),
    [anon_sym_DASH] = ACTIONS(5663),
    [anon_sym_PLUS] = ACTIONS(5663),
    [anon_sym_STAR] = ACTIONS(5663),
    [anon_sym_SLASH] = ACTIONS(5663),
    [anon_sym_PERCENT] = ACTIONS(5663),
    [anon_sym_PIPE_PIPE] = ACTIONS(5661),
    [anon_sym_AMP_AMP] = ACTIONS(5661),
    [anon_sym_PIPE] = ACTIONS(5663),
    [anon_sym_CARET] = ACTIONS(5663),
    [anon_sym_AMP] = ACTIONS(5663),
    [anon_sym_EQ_EQ] = ACTIONS(5661),
    [anon_sym_BANG_EQ] = ACTIONS(5661),
    [anon_sym_GT] = ACTIONS(5663),
    [anon_sym_GT_EQ] = ACTIONS(5663),
    [anon_sym_LT_EQ] = ACTIONS(5663),
    [anon_sym_LT] = ACTIONS(5663),
    [anon_sym_LT_LT] = ACTIONS(5663),
    [anon_sym_GT_GT] = ACTIONS(5663),
    [anon_sym_LBRACK] = ACTIONS(5661),
    [anon_sym_EQ] = ACTIONS(5663),
    [anon_sym_QMARK] = ACTIONS(5661),
    [anon_sym_STAR_EQ] = ACTIONS(5661),
    [anon_sym_SLASH_EQ] = ACTIONS(5661),
    [anon_sym_PERCENT_EQ] = ACTIONS(5661),
    [anon_sym_PLUS_EQ] = ACTIONS(5661),
    [anon_sym_DASH_EQ] = ACTIONS(5661),
    [anon_sym_LT_LT_EQ] = ACTIONS(5661),
    [anon_sym_GT_GT_EQ] = ACTIONS(5663),
    [anon_sym_AMP_EQ] = ACTIONS(5661),
    [anon_sym_CARET_EQ] = ACTIONS(5661),
    [anon_sym_PIPE_EQ] = ACTIONS(5661),
    [anon_sym_and_eq] = ACTIONS(5663),
    [anon_sym_or_eq] = ACTIONS(5663),
    [anon_sym_xor_eq] = ACTIONS(5663),
    [anon_sym_LT_EQ_GT] = ACTIONS(5661),
    [anon_sym_or] = ACTIONS(5663),
    [anon_sym_and] = ACTIONS(5663),
    [anon_sym_bitor] = ACTIONS(5663),
    [anon_sym_xor] = ACTIONS(5663),
    [anon_sym_bitand] = ACTIONS(5663),
    [anon_sym_not_eq] = ACTIONS(5663),
    [anon_sym_DASH_DASH] = ACTIONS(5661),
    [anon_sym_PLUS_PLUS] = ACTIONS(5661),
    [anon_sym_DOT] = ACTIONS(5663),
    [anon_sym_DOT_STAR] = ACTIONS(5661),
    [anon_sym_DASH_GT] = ACTIONS(5661),
    [anon_sym_L_DQUOTE] = ACTIONS(5992),
    [anon_sym_u_DQUOTE] = ACTIONS(5992),
    [anon_sym_U_DQUOTE] = ACTIONS(5992),
    [anon_sym_u8_DQUOTE] = ACTIONS(5992),
    [anon_sym_DQUOTE] = ACTIONS(5992),
    [sym_comment] = ACTIONS(3),
    [anon_sym_GT2] = ACTIONS(5661),
    [anon_sym_R_DQUOTE] = ACTIONS(5994),
    [anon_sym_LR_DQUOTE] = ACTIONS(5994),
    [anon_sym_uR_DQUOTE] = ACTIONS(5994),
    [anon_sym_UR_DQUOTE] = ACTIONS(5994),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5994),
    [sym_literal_suffix] = ACTIONS(5663),
  },
  [2540] = {
    [sym_attribute_declaration] = STATE(2642),
    [sym_parameter_list] = STATE(2652),
    [aux_sym_attributed_declarator_repeat1] = STATE(2642),
    [sym_identifier] = ACTIONS(5996),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5998),
    [anon_sym_COMMA] = ACTIONS(5998),
    [anon_sym_RPAREN] = ACTIONS(5998),
    [aux_sym_preproc_if_token2] = ACTIONS(5998),
    [aux_sym_preproc_else_token1] = ACTIONS(5998),
    [aux_sym_preproc_elif_token1] = ACTIONS(5996),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5998),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5998),
    [anon_sym_LPAREN2] = ACTIONS(5984),
    [anon_sym_DASH] = ACTIONS(5996),
    [anon_sym_PLUS] = ACTIONS(5996),
    [anon_sym_STAR] = ACTIONS(5996),
    [anon_sym_SLASH] = ACTIONS(5996),
    [anon_sym_PERCENT] = ACTIONS(5996),
    [anon_sym_PIPE_PIPE] = ACTIONS(5998),
    [anon_sym_AMP_AMP] = ACTIONS(5998),
    [anon_sym_PIPE] = ACTIONS(5996),
    [anon_sym_CARET] = ACTIONS(5996),
    [anon_sym_AMP] = ACTIONS(5996),
    [anon_sym_EQ_EQ] = ACTIONS(5998),
    [anon_sym_BANG_EQ] = ACTIONS(5998),
    [anon_sym_GT] = ACTIONS(5996),
    [anon_sym_GT_EQ] = ACTIONS(5998),
    [anon_sym_LT_EQ] = ACTIONS(5996),
    [anon_sym_LT] = ACTIONS(5996),
    [anon_sym_LT_LT] = ACTIONS(5996),
    [anon_sym_GT_GT] = ACTIONS(5996),
    [anon_sym_COLON] = ACTIONS(5998),
    [anon_sym_SEMI] = ACTIONS(5998),
    [anon_sym___attribute__] = ACTIONS(5996),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5986),
    [anon_sym_RBRACE] = ACTIONS(5998),
    [anon_sym_LBRACK] = ACTIONS(5988),
    [anon_sym_RBRACK] = ACTIONS(5998),
    [anon_sym_EQ] = ACTIONS(5996),
    [anon_sym_QMARK] = ACTIONS(5998),
    [anon_sym_STAR_EQ] = ACTIONS(5998),
    [anon_sym_SLASH_EQ] = ACTIONS(5998),
    [anon_sym_PERCENT_EQ] = ACTIONS(5998),
    [anon_sym_PLUS_EQ] = ACTIONS(5998),
    [anon_sym_DASH_EQ] = ACTIONS(5998),
    [anon_sym_LT_LT_EQ] = ACTIONS(5998),
    [anon_sym_GT_GT_EQ] = ACTIONS(5998),
    [anon_sym_AMP_EQ] = ACTIONS(5998),
    [anon_sym_CARET_EQ] = ACTIONS(5998),
    [anon_sym_PIPE_EQ] = ACTIONS(5998),
    [anon_sym_and_eq] = ACTIONS(5996),
    [anon_sym_or_eq] = ACTIONS(5996),
    [anon_sym_xor_eq] = ACTIONS(5996),
    [anon_sym_LT_EQ_GT] = ACTIONS(5998),
    [anon_sym_or] = ACTIONS(5996),
    [anon_sym_and] = ACTIONS(5996),
    [anon_sym_bitor] = ACTIONS(5996),
    [anon_sym_xor] = ACTIONS(5996),
    [anon_sym_bitand] = ACTIONS(5996),
    [anon_sym_not_eq] = ACTIONS(5996),
    [anon_sym_DASH_DASH] = ACTIONS(5998),
    [anon_sym_PLUS_PLUS] = ACTIONS(5998),
    [anon_sym_DOT] = ACTIONS(5996),
    [anon_sym_DOT_STAR] = ACTIONS(5998),
    [anon_sym_DASH_GT] = ACTIONS(5998),
    [sym_comment] = ACTIONS(3),
  },
  [2541] = {
    [sym_attribute_declaration] = STATE(2642),
    [sym_parameter_list] = STATE(2652),
    [aux_sym_attributed_declarator_repeat1] = STATE(2642),
    [sym_identifier] = ACTIONS(6000),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6002),
    [anon_sym_COMMA] = ACTIONS(6002),
    [anon_sym_RPAREN] = ACTIONS(6002),
    [aux_sym_preproc_if_token2] = ACTIONS(6002),
    [aux_sym_preproc_else_token1] = ACTIONS(6002),
    [aux_sym_preproc_elif_token1] = ACTIONS(6000),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6002),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6002),
    [anon_sym_LPAREN2] = ACTIONS(5984),
    [anon_sym_DASH] = ACTIONS(6000),
    [anon_sym_PLUS] = ACTIONS(6000),
    [anon_sym_STAR] = ACTIONS(6000),
    [anon_sym_SLASH] = ACTIONS(6000),
    [anon_sym_PERCENT] = ACTIONS(6000),
    [anon_sym_PIPE_PIPE] = ACTIONS(6002),
    [anon_sym_AMP_AMP] = ACTIONS(6002),
    [anon_sym_PIPE] = ACTIONS(6000),
    [anon_sym_CARET] = ACTIONS(6000),
    [anon_sym_AMP] = ACTIONS(6000),
    [anon_sym_EQ_EQ] = ACTIONS(6002),
    [anon_sym_BANG_EQ] = ACTIONS(6002),
    [anon_sym_GT] = ACTIONS(6000),
    [anon_sym_GT_EQ] = ACTIONS(6002),
    [anon_sym_LT_EQ] = ACTIONS(6000),
    [anon_sym_LT] = ACTIONS(6000),
    [anon_sym_LT_LT] = ACTIONS(6000),
    [anon_sym_GT_GT] = ACTIONS(6000),
    [anon_sym_COLON] = ACTIONS(6002),
    [anon_sym_SEMI] = ACTIONS(6002),
    [anon_sym___attribute__] = ACTIONS(6000),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5986),
    [anon_sym_RBRACE] = ACTIONS(6002),
    [anon_sym_LBRACK] = ACTIONS(5988),
    [anon_sym_RBRACK] = ACTIONS(6002),
    [anon_sym_EQ] = ACTIONS(6000),
    [anon_sym_QMARK] = ACTIONS(6002),
    [anon_sym_STAR_EQ] = ACTIONS(6002),
    [anon_sym_SLASH_EQ] = ACTIONS(6002),
    [anon_sym_PERCENT_EQ] = ACTIONS(6002),
    [anon_sym_PLUS_EQ] = ACTIONS(6002),
    [anon_sym_DASH_EQ] = ACTIONS(6002),
    [anon_sym_LT_LT_EQ] = ACTIONS(6002),
    [anon_sym_GT_GT_EQ] = ACTIONS(6002),
    [anon_sym_AMP_EQ] = ACTIONS(6002),
    [anon_sym_CARET_EQ] = ACTIONS(6002),
    [anon_sym_PIPE_EQ] = ACTIONS(6002),
    [anon_sym_and_eq] = ACTIONS(6000),
    [anon_sym_or_eq] = ACTIONS(6000),
    [anon_sym_xor_eq] = ACTIONS(6000),
    [anon_sym_LT_EQ_GT] = ACTIONS(6002),
    [anon_sym_or] = ACTIONS(6000),
    [anon_sym_and] = ACTIONS(6000),
    [anon_sym_bitor] = ACTIONS(6000),
    [anon_sym_xor] = ACTIONS(6000),
    [anon_sym_bitand] = ACTIONS(6000),
    [anon_sym_not_eq] = ACTIONS(6000),
    [anon_sym_DASH_DASH] = ACTIONS(6002),
    [anon_sym_PLUS_PLUS] = ACTIONS(6002),
    [anon_sym_DOT] = ACTIONS(6000),
    [anon_sym_DOT_STAR] = ACTIONS(6002),
    [anon_sym_DASH_GT] = ACTIONS(6002),
    [sym_comment] = ACTIONS(3),
  },
  [2542] = {
    [sym_identifier] = ACTIONS(2849),
    [anon_sym___extension__] = ACTIONS(2849),
    [anon_sym_typedef] = ACTIONS(6004),
    [anon_sym_in] = ACTIONS(2849),
    [anon_sym_out] = ACTIONS(2849),
    [anon_sym_inout] = ACTIONS(2849),
    [anon_sym_extern] = ACTIONS(2849),
    [anon_sym___attribute__] = ACTIONS(2849),
    [anon_sym_COLON_COLON] = ACTIONS(2851),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2851),
    [anon_sym___declspec] = ACTIONS(2849),
    [anon_sym_signed] = ACTIONS(2849),
    [anon_sym_unsigned] = ACTIONS(2849),
    [anon_sym_long] = ACTIONS(2849),
    [anon_sym_short] = ACTIONS(2849),
    [anon_sym_static] = ACTIONS(2849),
    [anon_sym_register] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2849),
    [anon_sym___inline] = ACTIONS(2849),
    [anon_sym___inline__] = ACTIONS(2849),
    [anon_sym___forceinline] = ACTIONS(2849),
    [anon_sym_thread_local] = ACTIONS(2849),
    [anon_sym___thread] = ACTIONS(2849),
    [anon_sym_const] = ACTIONS(2849),
    [anon_sym_constexpr] = ACTIONS(2849),
    [anon_sym_volatile] = ACTIONS(2849),
    [anon_sym_restrict] = ACTIONS(2849),
    [anon_sym___restrict__] = ACTIONS(2849),
    [anon_sym__Atomic] = ACTIONS(2849),
    [anon_sym__Noreturn] = ACTIONS(2849),
    [anon_sym_noreturn] = ACTIONS(2849),
    [anon_sym_mutable] = ACTIONS(2849),
    [anon_sym_constinit] = ACTIONS(2849),
    [anon_sym_consteval] = ACTIONS(2849),
    [anon_sym_alignas] = ACTIONS(2849),
    [anon_sym__Alignas] = ACTIONS(2849),
    [sym_primitive_type] = ACTIONS(2849),
    [anon_sym_enum] = ACTIONS(2849),
    [anon_sym_class] = ACTIONS(2849),
    [anon_sym_struct] = ACTIONS(2849),
    [anon_sym_union] = ACTIONS(2849),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2849),
    [anon_sym_decltype] = ACTIONS(2849),
    [sym_virtual] = ACTIONS(2849),
    [anon_sym_typename] = ACTIONS(2849),
    [anon_sym_template] = ACTIONS(2849),
    [anon_sym_precise] = ACTIONS(2849),
    [anon_sym_shared] = ACTIONS(2849),
    [anon_sym_groupshared] = ACTIONS(2849),
    [anon_sym_uniform] = ACTIONS(2849),
    [anon_sym_row_major] = ACTIONS(2849),
    [anon_sym_column_major] = ACTIONS(2849),
    [anon_sym_globallycoherent] = ACTIONS(2849),
    [anon_sym_centroid] = ACTIONS(2849),
    [anon_sym_noperspective] = ACTIONS(2849),
    [anon_sym_nointerpolation] = ACTIONS(2849),
    [anon_sym_sample] = ACTIONS(2849),
    [anon_sym_linear] = ACTIONS(2849),
    [anon_sym_snorm] = ACTIONS(2849),
    [anon_sym_unorm] = ACTIONS(2849),
    [anon_sym_point] = ACTIONS(2849),
    [anon_sym_line] = ACTIONS(2849),
    [anon_sym_triangleadj] = ACTIONS(2849),
    [anon_sym_lineadj] = ACTIONS(2849),
    [anon_sym_triangle] = ACTIONS(2849),
  },
  [2543] = {
    [sym_ms_based_modifier] = STATE(8703),
    [sym_ms_unaligned_ptr_modifier] = STATE(4205),
    [sym_ms_pointer_modifier] = STATE(4067),
    [sym__declarator] = STATE(5886),
    [sym__abstract_declarator] = STATE(6594),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_abstract_parenthesized_declarator] = STATE(6033),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_abstract_pointer_declarator] = STATE(6033),
    [sym_function_declarator] = STATE(6270),
    [sym_abstract_function_declarator] = STATE(6033),
    [sym_array_declarator] = STATE(6270),
    [sym_abstract_array_declarator] = STATE(6033),
    [sym_type_qualifier] = STATE(2952),
    [sym_alignas_qualifier] = STATE(4472),
    [sym_parameter_list] = STATE(3679),
    [sym_decltype] = STATE(8571),
    [sym_reference_declarator] = STATE(6270),
    [sym_abstract_reference_declarator] = STATE(6033),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym__function_declarator_seq] = STATE(6076),
    [sym_template_type] = STATE(8571),
    [sym_template_function] = STATE(6270),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5644),
    [sym_qualified_identifier] = STATE(6270),
    [sym_operator_name] = STATE(6270),
    [aux_sym__type_definition_type_repeat1] = STATE(2952),
    [aux_sym_pointer_declarator_repeat1] = STATE(4067),
    [sym_identifier] = ACTIONS(5889),
    [anon_sym_COMMA] = ACTIONS(5905),
    [anon_sym_RPAREN] = ACTIONS(5905),
    [anon_sym_LPAREN2] = ACTIONS(3934),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(6006),
    [anon_sym_AMP_AMP] = ACTIONS(6008),
    [anon_sym_AMP] = ACTIONS(6010),
    [anon_sym_COLON] = ACTIONS(5907),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(5901),
    [anon_sym___based] = ACTIONS(49),
    [sym_ms_restrict_modifier] = ACTIONS(3906),
    [sym_ms_unsigned_ptr_modifier] = ACTIONS(3906),
    [sym_ms_signed_ptr_modifier] = ACTIONS(3906),
    [anon_sym__unaligned] = ACTIONS(3908),
    [anon_sym___unaligned] = ACTIONS(3908),
    [anon_sym_LBRACK] = ACTIONS(5903),
    [anon_sym_const] = ACTIONS(3904),
    [anon_sym_constexpr] = ACTIONS(3904),
    [anon_sym_volatile] = ACTIONS(3904),
    [anon_sym_restrict] = ACTIONS(3904),
    [anon_sym___restrict__] = ACTIONS(3904),
    [anon_sym__Atomic] = ACTIONS(3904),
    [anon_sym__Noreturn] = ACTIONS(3904),
    [anon_sym_noreturn] = ACTIONS(3904),
    [anon_sym_mutable] = ACTIONS(3904),
    [anon_sym_constinit] = ACTIONS(3904),
    [anon_sym_consteval] = ACTIONS(3904),
    [anon_sym_alignas] = ACTIONS(3910),
    [anon_sym__Alignas] = ACTIONS(3910),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(2078),
  },
  [2544] = {
    [sym_template_argument_list] = STATE(2489),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2649),
    [sym_identifier] = ACTIONS(3822),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3830),
    [anon_sym_COMMA] = ACTIONS(3830),
    [aux_sym_preproc_if_token2] = ACTIONS(3830),
    [aux_sym_preproc_else_token1] = ACTIONS(3830),
    [aux_sym_preproc_elif_token1] = ACTIONS(3822),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(3830),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(3830),
    [anon_sym_LPAREN2] = ACTIONS(3830),
    [anon_sym_DASH] = ACTIONS(3822),
    [anon_sym_PLUS] = ACTIONS(3822),
    [anon_sym_STAR] = ACTIONS(3822),
    [anon_sym_SLASH] = ACTIONS(3822),
    [anon_sym_PERCENT] = ACTIONS(3822),
    [anon_sym_PIPE_PIPE] = ACTIONS(3830),
    [anon_sym_AMP_AMP] = ACTIONS(3830),
    [anon_sym_PIPE] = ACTIONS(3822),
    [anon_sym_CARET] = ACTIONS(3822),
    [anon_sym_AMP] = ACTIONS(3822),
    [anon_sym_EQ_EQ] = ACTIONS(3830),
    [anon_sym_BANG_EQ] = ACTIONS(3830),
    [anon_sym_GT] = ACTIONS(3822),
    [anon_sym_GT_EQ] = ACTIONS(3830),
    [anon_sym_LT_EQ] = ACTIONS(3822),
    [anon_sym_LT] = ACTIONS(5866),
    [anon_sym_LT_LT] = ACTIONS(3822),
    [anon_sym_GT_GT] = ACTIONS(3822),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(3830),
    [anon_sym_signed] = ACTIONS(5961),
    [anon_sym_unsigned] = ACTIONS(5961),
    [anon_sym_long] = ACTIONS(5961),
    [anon_sym_short] = ACTIONS(5961),
    [anon_sym_LBRACK] = ACTIONS(3830),
    [anon_sym_EQ] = ACTIONS(3822),
    [anon_sym_QMARK] = ACTIONS(3830),
    [anon_sym_STAR_EQ] = ACTIONS(3830),
    [anon_sym_SLASH_EQ] = ACTIONS(3830),
    [anon_sym_PERCENT_EQ] = ACTIONS(3830),
    [anon_sym_PLUS_EQ] = ACTIONS(3830),
    [anon_sym_DASH_EQ] = ACTIONS(3830),
    [anon_sym_LT_LT_EQ] = ACTIONS(3830),
    [anon_sym_GT_GT_EQ] = ACTIONS(3830),
    [anon_sym_AMP_EQ] = ACTIONS(3830),
    [anon_sym_CARET_EQ] = ACTIONS(3830),
    [anon_sym_PIPE_EQ] = ACTIONS(3830),
    [anon_sym_and_eq] = ACTIONS(3822),
    [anon_sym_or_eq] = ACTIONS(3822),
    [anon_sym_xor_eq] = ACTIONS(3822),
    [anon_sym_LT_EQ_GT] = ACTIONS(3830),
    [anon_sym_or] = ACTIONS(3822),
    [anon_sym_and] = ACTIONS(3822),
    [anon_sym_bitor] = ACTIONS(3822),
    [anon_sym_xor] = ACTIONS(3822),
    [anon_sym_bitand] = ACTIONS(3822),
    [anon_sym_not_eq] = ACTIONS(3822),
    [anon_sym_DASH_DASH] = ACTIONS(3830),
    [anon_sym_PLUS_PLUS] = ACTIONS(3830),
    [anon_sym_DOT] = ACTIONS(3822),
    [anon_sym_DOT_STAR] = ACTIONS(3830),
    [anon_sym_DASH_GT] = ACTIONS(3830),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3822),
    [anon_sym_decltype] = ACTIONS(3822),
  },
  [2545] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2554),
    [sym_identifier] = ACTIONS(6012),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5336),
    [anon_sym_COMMA] = ACTIONS(5336),
    [aux_sym_preproc_if_token2] = ACTIONS(5336),
    [aux_sym_preproc_else_token1] = ACTIONS(5336),
    [aux_sym_preproc_elif_token1] = ACTIONS(5338),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5336),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5336),
    [anon_sym_LPAREN2] = ACTIONS(5336),
    [anon_sym_DASH] = ACTIONS(5338),
    [anon_sym_PLUS] = ACTIONS(5338),
    [anon_sym_STAR] = ACTIONS(5338),
    [anon_sym_SLASH] = ACTIONS(5338),
    [anon_sym_PERCENT] = ACTIONS(5338),
    [anon_sym_PIPE_PIPE] = ACTIONS(5336),
    [anon_sym_AMP_AMP] = ACTIONS(5336),
    [anon_sym_PIPE] = ACTIONS(5338),
    [anon_sym_CARET] = ACTIONS(5338),
    [anon_sym_AMP] = ACTIONS(5338),
    [anon_sym_EQ_EQ] = ACTIONS(5336),
    [anon_sym_BANG_EQ] = ACTIONS(5336),
    [anon_sym_GT] = ACTIONS(5338),
    [anon_sym_GT_EQ] = ACTIONS(5336),
    [anon_sym_LT_EQ] = ACTIONS(5338),
    [anon_sym_LT] = ACTIONS(5338),
    [anon_sym_LT_LT] = ACTIONS(5338),
    [anon_sym_GT_GT] = ACTIONS(5338),
    [anon_sym___attribute__] = ACTIONS(5338),
    [anon_sym_LBRACE] = ACTIONS(5336),
    [anon_sym_signed] = ACTIONS(6015),
    [anon_sym_unsigned] = ACTIONS(6015),
    [anon_sym_long] = ACTIONS(6015),
    [anon_sym_short] = ACTIONS(6015),
    [anon_sym_LBRACK] = ACTIONS(5336),
    [anon_sym_EQ] = ACTIONS(5338),
    [sym_primitive_type] = ACTIONS(6017),
    [anon_sym_QMARK] = ACTIONS(5336),
    [anon_sym_STAR_EQ] = ACTIONS(5336),
    [anon_sym_SLASH_EQ] = ACTIONS(5336),
    [anon_sym_PERCENT_EQ] = ACTIONS(5336),
    [anon_sym_PLUS_EQ] = ACTIONS(5336),
    [anon_sym_DASH_EQ] = ACTIONS(5336),
    [anon_sym_LT_LT_EQ] = ACTIONS(5336),
    [anon_sym_GT_GT_EQ] = ACTIONS(5336),
    [anon_sym_AMP_EQ] = ACTIONS(5336),
    [anon_sym_CARET_EQ] = ACTIONS(5336),
    [anon_sym_PIPE_EQ] = ACTIONS(5336),
    [anon_sym_and_eq] = ACTIONS(5338),
    [anon_sym_or_eq] = ACTIONS(5338),
    [anon_sym_xor_eq] = ACTIONS(5338),
    [anon_sym_LT_EQ_GT] = ACTIONS(5336),
    [anon_sym_or] = ACTIONS(5338),
    [anon_sym_and] = ACTIONS(5338),
    [anon_sym_bitor] = ACTIONS(5338),
    [anon_sym_xor] = ACTIONS(5338),
    [anon_sym_bitand] = ACTIONS(5338),
    [anon_sym_not_eq] = ACTIONS(5338),
    [anon_sym_DASH_DASH] = ACTIONS(5336),
    [anon_sym_PLUS_PLUS] = ACTIONS(5336),
    [anon_sym_DOT] = ACTIONS(5338),
    [anon_sym_DOT_STAR] = ACTIONS(5336),
    [anon_sym_DASH_GT] = ACTIONS(5336),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5338),
    [anon_sym_decltype] = ACTIONS(5338),
  },
  [2546] = {
    [sym_template_argument_list] = STATE(2390),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2689),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5296),
    [anon_sym_COMMA] = ACTIONS(5296),
    [anon_sym_RPAREN] = ACTIONS(5296),
    [anon_sym_LPAREN2] = ACTIONS(5296),
    [anon_sym_DASH] = ACTIONS(5294),
    [anon_sym_PLUS] = ACTIONS(5294),
    [anon_sym_STAR] = ACTIONS(5294),
    [anon_sym_SLASH] = ACTIONS(5294),
    [anon_sym_PERCENT] = ACTIONS(5294),
    [anon_sym_PIPE_PIPE] = ACTIONS(5296),
    [anon_sym_AMP_AMP] = ACTIONS(5296),
    [anon_sym_PIPE] = ACTIONS(5294),
    [anon_sym_CARET] = ACTIONS(5294),
    [anon_sym_AMP] = ACTIONS(5294),
    [anon_sym_EQ_EQ] = ACTIONS(5296),
    [anon_sym_BANG_EQ] = ACTIONS(5296),
    [anon_sym_GT] = ACTIONS(5294),
    [anon_sym_GT_EQ] = ACTIONS(5296),
    [anon_sym_LT_EQ] = ACTIONS(5294),
    [anon_sym_LT] = ACTIONS(5294),
    [anon_sym_LT_LT] = ACTIONS(5294),
    [anon_sym_GT_GT] = ACTIONS(5294),
    [anon_sym_COLON] = ACTIONS(5294),
    [anon_sym_SEMI] = ACTIONS(5296),
    [anon_sym___attribute__] = ACTIONS(5296),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(5296),
    [anon_sym_RBRACE] = ACTIONS(5296),
    [anon_sym_signed] = ACTIONS(6019),
    [anon_sym_unsigned] = ACTIONS(6019),
    [anon_sym_long] = ACTIONS(6019),
    [anon_sym_short] = ACTIONS(6019),
    [anon_sym_LBRACK] = ACTIONS(5296),
    [anon_sym_RBRACK] = ACTIONS(5296),
    [anon_sym_EQ] = ACTIONS(5294),
    [anon_sym_QMARK] = ACTIONS(5296),
    [anon_sym_STAR_EQ] = ACTIONS(5296),
    [anon_sym_SLASH_EQ] = ACTIONS(5296),
    [anon_sym_PERCENT_EQ] = ACTIONS(5296),
    [anon_sym_PLUS_EQ] = ACTIONS(5296),
    [anon_sym_DASH_EQ] = ACTIONS(5296),
    [anon_sym_LT_LT_EQ] = ACTIONS(5296),
    [anon_sym_GT_GT_EQ] = ACTIONS(5296),
    [anon_sym_AMP_EQ] = ACTIONS(5296),
    [anon_sym_CARET_EQ] = ACTIONS(5296),
    [anon_sym_PIPE_EQ] = ACTIONS(5296),
    [anon_sym_and_eq] = ACTIONS(5296),
    [anon_sym_or_eq] = ACTIONS(5296),
    [anon_sym_xor_eq] = ACTIONS(5296),
    [anon_sym_LT_EQ_GT] = ACTIONS(5296),
    [anon_sym_or] = ACTIONS(5294),
    [anon_sym_and] = ACTIONS(5294),
    [anon_sym_bitor] = ACTIONS(5296),
    [anon_sym_xor] = ACTIONS(5294),
    [anon_sym_bitand] = ACTIONS(5296),
    [anon_sym_not_eq] = ACTIONS(5296),
    [anon_sym_DASH_DASH] = ACTIONS(5296),
    [anon_sym_PLUS_PLUS] = ACTIONS(5296),
    [anon_sym_DOT] = ACTIONS(5294),
    [anon_sym_DOT_STAR] = ACTIONS(5296),
    [anon_sym_DASH_GT] = ACTIONS(5296),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5296),
    [anon_sym_decltype] = ACTIONS(5296),
  },
  [2547] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2581),
    [sym_identifier] = ACTIONS(5224),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5315),
    [anon_sym_COMMA] = ACTIONS(5315),
    [anon_sym_LPAREN2] = ACTIONS(5315),
    [anon_sym_DASH] = ACTIONS(5312),
    [anon_sym_PLUS] = ACTIONS(5312),
    [anon_sym_STAR] = ACTIONS(5315),
    [anon_sym_SLASH] = ACTIONS(5312),
    [anon_sym_PERCENT] = ACTIONS(5315),
    [anon_sym_PIPE_PIPE] = ACTIONS(5315),
    [anon_sym_AMP_AMP] = ACTIONS(5315),
    [anon_sym_PIPE] = ACTIONS(5312),
    [anon_sym_CARET] = ACTIONS(5315),
    [anon_sym_AMP] = ACTIONS(5312),
    [anon_sym_EQ_EQ] = ACTIONS(5315),
    [anon_sym_BANG_EQ] = ACTIONS(5315),
    [anon_sym_GT] = ACTIONS(5312),
    [anon_sym_GT_EQ] = ACTIONS(5312),
    [anon_sym_LT_EQ] = ACTIONS(5312),
    [anon_sym_LT] = ACTIONS(5312),
    [anon_sym_LT_LT] = ACTIONS(5315),
    [anon_sym_GT_GT] = ACTIONS(5312),
    [anon_sym_COLON] = ACTIONS(5315),
    [anon_sym___extension__] = ACTIONS(5312),
    [anon_sym___attribute__] = ACTIONS(5312),
    [anon_sym_LBRACE] = ACTIONS(5315),
    [anon_sym_signed] = ACTIONS(6021),
    [anon_sym_unsigned] = ACTIONS(6021),
    [anon_sym_long] = ACTIONS(6021),
    [anon_sym_short] = ACTIONS(6021),
    [anon_sym_LBRACK] = ACTIONS(5315),
    [anon_sym_const] = ACTIONS(5312),
    [anon_sym_constexpr] = ACTIONS(5312),
    [anon_sym_volatile] = ACTIONS(5312),
    [anon_sym_restrict] = ACTIONS(5312),
    [anon_sym___restrict__] = ACTIONS(5312),
    [anon_sym__Atomic] = ACTIONS(5312),
    [anon_sym__Noreturn] = ACTIONS(5312),
    [anon_sym_noreturn] = ACTIONS(5312),
    [anon_sym_mutable] = ACTIONS(5312),
    [anon_sym_constinit] = ACTIONS(5312),
    [anon_sym_consteval] = ACTIONS(5312),
    [anon_sym_alignas] = ACTIONS(5312),
    [anon_sym__Alignas] = ACTIONS(5312),
    [sym_primitive_type] = ACTIONS(5224),
    [anon_sym_QMARK] = ACTIONS(5315),
    [anon_sym_LT_EQ_GT] = ACTIONS(5315),
    [anon_sym_or] = ACTIONS(5312),
    [anon_sym_and] = ACTIONS(5312),
    [anon_sym_bitor] = ACTIONS(5312),
    [anon_sym_xor] = ACTIONS(5312),
    [anon_sym_bitand] = ACTIONS(5312),
    [anon_sym_not_eq] = ACTIONS(5312),
    [anon_sym_DASH_DASH] = ACTIONS(5315),
    [anon_sym_PLUS_PLUS] = ACTIONS(5315),
    [anon_sym_DOT] = ACTIONS(5312),
    [anon_sym_DOT_STAR] = ACTIONS(5315),
    [anon_sym_DASH_GT] = ACTIONS(5315),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5312),
    [anon_sym_decltype] = ACTIONS(5312),
    [anon_sym_final] = ACTIONS(5312),
    [anon_sym_override] = ACTIONS(5312),
    [anon_sym_GT2] = ACTIONS(5315),
    [anon_sym_requires] = ACTIONS(5312),
  },
  [2548] = {
    [sym_identifier] = ACTIONS(5391),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5393),
    [anon_sym_COMMA] = ACTIONS(5393),
    [anon_sym_RPAREN] = ACTIONS(5393),
    [aux_sym_preproc_if_token2] = ACTIONS(5393),
    [aux_sym_preproc_else_token1] = ACTIONS(5393),
    [aux_sym_preproc_elif_token1] = ACTIONS(5391),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5393),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5393),
    [anon_sym_LPAREN2] = ACTIONS(5393),
    [anon_sym_DASH] = ACTIONS(5391),
    [anon_sym_PLUS] = ACTIONS(5391),
    [anon_sym_STAR] = ACTIONS(5391),
    [anon_sym_SLASH] = ACTIONS(5391),
    [anon_sym_PERCENT] = ACTIONS(5391),
    [anon_sym_PIPE_PIPE] = ACTIONS(5393),
    [anon_sym_AMP_AMP] = ACTIONS(5393),
    [anon_sym_PIPE] = ACTIONS(5391),
    [anon_sym_CARET] = ACTIONS(5391),
    [anon_sym_AMP] = ACTIONS(5391),
    [anon_sym_EQ_EQ] = ACTIONS(5393),
    [anon_sym_BANG_EQ] = ACTIONS(5393),
    [anon_sym_GT] = ACTIONS(5391),
    [anon_sym_GT_EQ] = ACTIONS(5393),
    [anon_sym_LT_EQ] = ACTIONS(5391),
    [anon_sym_LT] = ACTIONS(5391),
    [anon_sym_LT_LT] = ACTIONS(5391),
    [anon_sym_GT_GT] = ACTIONS(5391),
    [anon_sym_COLON] = ACTIONS(5391),
    [anon_sym_SEMI] = ACTIONS(5393),
    [anon_sym___attribute__] = ACTIONS(5391),
    [anon_sym_COLON_COLON] = ACTIONS(5393),
    [anon_sym_LBRACE] = ACTIONS(5393),
    [anon_sym_RBRACE] = ACTIONS(5393),
    [anon_sym_LBRACK] = ACTIONS(5393),
    [anon_sym_RBRACK] = ACTIONS(5393),
    [anon_sym_EQ] = ACTIONS(5391),
    [anon_sym_QMARK] = ACTIONS(5393),
    [anon_sym_STAR_EQ] = ACTIONS(5393),
    [anon_sym_SLASH_EQ] = ACTIONS(5393),
    [anon_sym_PERCENT_EQ] = ACTIONS(5393),
    [anon_sym_PLUS_EQ] = ACTIONS(5393),
    [anon_sym_DASH_EQ] = ACTIONS(5393),
    [anon_sym_LT_LT_EQ] = ACTIONS(5393),
    [anon_sym_GT_GT_EQ] = ACTIONS(5393),
    [anon_sym_AMP_EQ] = ACTIONS(5393),
    [anon_sym_CARET_EQ] = ACTIONS(5393),
    [anon_sym_PIPE_EQ] = ACTIONS(5393),
    [anon_sym_and_eq] = ACTIONS(5391),
    [anon_sym_or_eq] = ACTIONS(5391),
    [anon_sym_xor_eq] = ACTIONS(5391),
    [anon_sym_LT_EQ_GT] = ACTIONS(5393),
    [anon_sym_or] = ACTIONS(5391),
    [anon_sym_and] = ACTIONS(5391),
    [anon_sym_bitor] = ACTIONS(5391),
    [anon_sym_xor] = ACTIONS(5391),
    [anon_sym_bitand] = ACTIONS(5391),
    [anon_sym_not_eq] = ACTIONS(5391),
    [anon_sym_DASH_DASH] = ACTIONS(5393),
    [anon_sym_PLUS_PLUS] = ACTIONS(5393),
    [anon_sym_DOT] = ACTIONS(5391),
    [anon_sym_DOT_STAR] = ACTIONS(5393),
    [anon_sym_DASH_GT] = ACTIONS(5393),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5391),
    [anon_sym_decltype] = ACTIONS(5391),
  },
  [2549] = {
    [sym_identifier] = ACTIONS(5318),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5320),
    [anon_sym_COMMA] = ACTIONS(5320),
    [anon_sym_RPAREN] = ACTIONS(5320),
    [aux_sym_preproc_if_token2] = ACTIONS(5320),
    [aux_sym_preproc_else_token1] = ACTIONS(5320),
    [aux_sym_preproc_elif_token1] = ACTIONS(5318),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5320),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5320),
    [anon_sym_LPAREN2] = ACTIONS(5320),
    [anon_sym_DASH] = ACTIONS(5318),
    [anon_sym_PLUS] = ACTIONS(5318),
    [anon_sym_STAR] = ACTIONS(5318),
    [anon_sym_SLASH] = ACTIONS(5318),
    [anon_sym_PERCENT] = ACTIONS(5318),
    [anon_sym_PIPE_PIPE] = ACTIONS(5320),
    [anon_sym_AMP_AMP] = ACTIONS(5320),
    [anon_sym_PIPE] = ACTIONS(5318),
    [anon_sym_CARET] = ACTIONS(5318),
    [anon_sym_AMP] = ACTIONS(5318),
    [anon_sym_EQ_EQ] = ACTIONS(5320),
    [anon_sym_BANG_EQ] = ACTIONS(5320),
    [anon_sym_GT] = ACTIONS(5318),
    [anon_sym_GT_EQ] = ACTIONS(5320),
    [anon_sym_LT_EQ] = ACTIONS(5318),
    [anon_sym_LT] = ACTIONS(5318),
    [anon_sym_LT_LT] = ACTIONS(5318),
    [anon_sym_GT_GT] = ACTIONS(5318),
    [anon_sym_COLON] = ACTIONS(5318),
    [anon_sym_SEMI] = ACTIONS(5320),
    [anon_sym___attribute__] = ACTIONS(5318),
    [anon_sym_COLON_COLON] = ACTIONS(1957),
    [anon_sym_LBRACE] = ACTIONS(5320),
    [anon_sym_RBRACE] = ACTIONS(5320),
    [anon_sym_LBRACK] = ACTIONS(5320),
    [anon_sym_RBRACK] = ACTIONS(5320),
    [anon_sym_EQ] = ACTIONS(5318),
    [anon_sym_QMARK] = ACTIONS(5320),
    [anon_sym_STAR_EQ] = ACTIONS(5320),
    [anon_sym_SLASH_EQ] = ACTIONS(5320),
    [anon_sym_PERCENT_EQ] = ACTIONS(5320),
    [anon_sym_PLUS_EQ] = ACTIONS(5320),
    [anon_sym_DASH_EQ] = ACTIONS(5320),
    [anon_sym_LT_LT_EQ] = ACTIONS(5320),
    [anon_sym_GT_GT_EQ] = ACTIONS(5320),
    [anon_sym_AMP_EQ] = ACTIONS(5320),
    [anon_sym_CARET_EQ] = ACTIONS(5320),
    [anon_sym_PIPE_EQ] = ACTIONS(5320),
    [anon_sym_and_eq] = ACTIONS(5318),
    [anon_sym_or_eq] = ACTIONS(5318),
    [anon_sym_xor_eq] = ACTIONS(5318),
    [anon_sym_LT_EQ_GT] = ACTIONS(5320),
    [anon_sym_or] = ACTIONS(5318),
    [anon_sym_and] = ACTIONS(5318),
    [anon_sym_bitor] = ACTIONS(5318),
    [anon_sym_xor] = ACTIONS(5318),
    [anon_sym_bitand] = ACTIONS(5318),
    [anon_sym_not_eq] = ACTIONS(5318),
    [anon_sym_DASH_DASH] = ACTIONS(5320),
    [anon_sym_PLUS_PLUS] = ACTIONS(5320),
    [anon_sym_DOT] = ACTIONS(5318),
    [anon_sym_DOT_STAR] = ACTIONS(5320),
    [anon_sym_DASH_GT] = ACTIONS(5320),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5318),
    [anon_sym_decltype] = ACTIONS(5318),
  },
  [2550] = {
    [sym_string_literal] = STATE(3630),
    [sym_template_argument_list] = STATE(4467),
    [sym_raw_string_literal] = STATE(3630),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3824),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3832),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5201),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_LBRACK] = ACTIONS(3824),
    [anon_sym_EQ] = ACTIONS(5206),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(5208),
    [anon_sym_SLASH_EQ] = ACTIONS(5208),
    [anon_sym_PERCENT_EQ] = ACTIONS(5208),
    [anon_sym_PLUS_EQ] = ACTIONS(5208),
    [anon_sym_DASH_EQ] = ACTIONS(5208),
    [anon_sym_LT_LT_EQ] = ACTIONS(5208),
    [anon_sym_GT_GT_EQ] = ACTIONS(5206),
    [anon_sym_AMP_EQ] = ACTIONS(5208),
    [anon_sym_CARET_EQ] = ACTIONS(5208),
    [anon_sym_PIPE_EQ] = ACTIONS(5208),
    [anon_sym_and_eq] = ACTIONS(5208),
    [anon_sym_or_eq] = ACTIONS(5208),
    [anon_sym_xor_eq] = ACTIONS(5208),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(5210),
    [anon_sym_u_DQUOTE] = ACTIONS(5210),
    [anon_sym_U_DQUOTE] = ACTIONS(5210),
    [anon_sym_u8_DQUOTE] = ACTIONS(5210),
    [anon_sym_DQUOTE] = ACTIONS(5210),
    [sym_comment] = ACTIONS(3),
    [anon_sym_GT2] = ACTIONS(3824),
    [anon_sym_R_DQUOTE] = ACTIONS(5212),
    [anon_sym_LR_DQUOTE] = ACTIONS(5212),
    [anon_sym_uR_DQUOTE] = ACTIONS(5212),
    [anon_sym_UR_DQUOTE] = ACTIONS(5212),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5212),
  },
  [2551] = {
    [sym_attribute_declaration] = STATE(2642),
    [sym_parameter_list] = STATE(2652),
    [aux_sym_attributed_declarator_repeat1] = STATE(2642),
    [sym_identifier] = ACTIONS(6024),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6026),
    [anon_sym_COMMA] = ACTIONS(6026),
    [anon_sym_RPAREN] = ACTIONS(6026),
    [aux_sym_preproc_if_token2] = ACTIONS(6026),
    [aux_sym_preproc_else_token1] = ACTIONS(6026),
    [aux_sym_preproc_elif_token1] = ACTIONS(6024),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6026),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6026),
    [anon_sym_LPAREN2] = ACTIONS(5984),
    [anon_sym_DASH] = ACTIONS(6024),
    [anon_sym_PLUS] = ACTIONS(6024),
    [anon_sym_STAR] = ACTIONS(6024),
    [anon_sym_SLASH] = ACTIONS(6024),
    [anon_sym_PERCENT] = ACTIONS(6024),
    [anon_sym_PIPE_PIPE] = ACTIONS(6026),
    [anon_sym_AMP_AMP] = ACTIONS(6026),
    [anon_sym_PIPE] = ACTIONS(6024),
    [anon_sym_CARET] = ACTIONS(6024),
    [anon_sym_AMP] = ACTIONS(6024),
    [anon_sym_EQ_EQ] = ACTIONS(6026),
    [anon_sym_BANG_EQ] = ACTIONS(6026),
    [anon_sym_GT] = ACTIONS(6024),
    [anon_sym_GT_EQ] = ACTIONS(6026),
    [anon_sym_LT_EQ] = ACTIONS(6024),
    [anon_sym_LT] = ACTIONS(6024),
    [anon_sym_LT_LT] = ACTIONS(6024),
    [anon_sym_GT_GT] = ACTIONS(6024),
    [anon_sym_COLON] = ACTIONS(6026),
    [anon_sym_SEMI] = ACTIONS(6026),
    [anon_sym___attribute__] = ACTIONS(6024),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5986),
    [anon_sym_RBRACE] = ACTIONS(6026),
    [anon_sym_LBRACK] = ACTIONS(5988),
    [anon_sym_RBRACK] = ACTIONS(6026),
    [anon_sym_EQ] = ACTIONS(6024),
    [anon_sym_QMARK] = ACTIONS(6026),
    [anon_sym_STAR_EQ] = ACTIONS(6026),
    [anon_sym_SLASH_EQ] = ACTIONS(6026),
    [anon_sym_PERCENT_EQ] = ACTIONS(6026),
    [anon_sym_PLUS_EQ] = ACTIONS(6026),
    [anon_sym_DASH_EQ] = ACTIONS(6026),
    [anon_sym_LT_LT_EQ] = ACTIONS(6026),
    [anon_sym_GT_GT_EQ] = ACTIONS(6026),
    [anon_sym_AMP_EQ] = ACTIONS(6026),
    [anon_sym_CARET_EQ] = ACTIONS(6026),
    [anon_sym_PIPE_EQ] = ACTIONS(6026),
    [anon_sym_and_eq] = ACTIONS(6024),
    [anon_sym_or_eq] = ACTIONS(6024),
    [anon_sym_xor_eq] = ACTIONS(6024),
    [anon_sym_LT_EQ_GT] = ACTIONS(6026),
    [anon_sym_or] = ACTIONS(6024),
    [anon_sym_and] = ACTIONS(6024),
    [anon_sym_bitor] = ACTIONS(6024),
    [anon_sym_xor] = ACTIONS(6024),
    [anon_sym_bitand] = ACTIONS(6024),
    [anon_sym_not_eq] = ACTIONS(6024),
    [anon_sym_DASH_DASH] = ACTIONS(6026),
    [anon_sym_PLUS_PLUS] = ACTIONS(6026),
    [anon_sym_DOT] = ACTIONS(6024),
    [anon_sym_DOT_STAR] = ACTIONS(6026),
    [anon_sym_DASH_GT] = ACTIONS(6026),
    [sym_comment] = ACTIONS(3),
  },
  [2552] = {
    [sym_attribute_specifier] = STATE(2608),
    [sym_identifier] = ACTIONS(5614),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5616),
    [anon_sym_COMMA] = ACTIONS(5616),
    [anon_sym_RPAREN] = ACTIONS(5616),
    [aux_sym_preproc_if_token2] = ACTIONS(5616),
    [aux_sym_preproc_else_token1] = ACTIONS(5616),
    [aux_sym_preproc_elif_token1] = ACTIONS(5614),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5616),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5616),
    [anon_sym_LPAREN2] = ACTIONS(5616),
    [anon_sym_DASH] = ACTIONS(5614),
    [anon_sym_PLUS] = ACTIONS(5614),
    [anon_sym_STAR] = ACTIONS(5614),
    [anon_sym_SLASH] = ACTIONS(5614),
    [anon_sym_PERCENT] = ACTIONS(5614),
    [anon_sym_PIPE_PIPE] = ACTIONS(5616),
    [anon_sym_AMP_AMP] = ACTIONS(5616),
    [anon_sym_PIPE] = ACTIONS(5614),
    [anon_sym_CARET] = ACTIONS(5614),
    [anon_sym_AMP] = ACTIONS(5614),
    [anon_sym_EQ_EQ] = ACTIONS(5616),
    [anon_sym_BANG_EQ] = ACTIONS(5616),
    [anon_sym_GT] = ACTIONS(5614),
    [anon_sym_GT_EQ] = ACTIONS(5616),
    [anon_sym_LT_EQ] = ACTIONS(5614),
    [anon_sym_LT] = ACTIONS(5614),
    [anon_sym_LT_LT] = ACTIONS(5614),
    [anon_sym_GT_GT] = ACTIONS(5614),
    [anon_sym_COLON] = ACTIONS(5616),
    [anon_sym_SEMI] = ACTIONS(5616),
    [anon_sym___attribute__] = ACTIONS(5815),
    [anon_sym_LBRACE] = ACTIONS(5616),
    [anon_sym_RBRACE] = ACTIONS(5616),
    [anon_sym_LBRACK] = ACTIONS(5616),
    [anon_sym_RBRACK] = ACTIONS(5616),
    [anon_sym_EQ] = ACTIONS(5614),
    [anon_sym_QMARK] = ACTIONS(5616),
    [anon_sym_STAR_EQ] = ACTIONS(5616),
    [anon_sym_SLASH_EQ] = ACTIONS(5616),
    [anon_sym_PERCENT_EQ] = ACTIONS(5616),
    [anon_sym_PLUS_EQ] = ACTIONS(5616),
    [anon_sym_DASH_EQ] = ACTIONS(5616),
    [anon_sym_LT_LT_EQ] = ACTIONS(5616),
    [anon_sym_GT_GT_EQ] = ACTIONS(5616),
    [anon_sym_AMP_EQ] = ACTIONS(5616),
    [anon_sym_CARET_EQ] = ACTIONS(5616),
    [anon_sym_PIPE_EQ] = ACTIONS(5616),
    [anon_sym_and_eq] = ACTIONS(5614),
    [anon_sym_or_eq] = ACTIONS(5614),
    [anon_sym_xor_eq] = ACTIONS(5614),
    [anon_sym_LT_EQ_GT] = ACTIONS(5616),
    [anon_sym_or] = ACTIONS(5614),
    [anon_sym_and] = ACTIONS(5614),
    [anon_sym_bitor] = ACTIONS(5614),
    [anon_sym_xor] = ACTIONS(5614),
    [anon_sym_bitand] = ACTIONS(5614),
    [anon_sym_not_eq] = ACTIONS(5614),
    [anon_sym_DASH_DASH] = ACTIONS(5616),
    [anon_sym_PLUS_PLUS] = ACTIONS(5616),
    [anon_sym_DOT] = ACTIONS(5614),
    [anon_sym_DOT_STAR] = ACTIONS(5616),
    [anon_sym_DASH_GT] = ACTIONS(5616),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5614),
    [anon_sym_decltype] = ACTIONS(5614),
  },
  [2553] = {
    [sym_attribute_specifier] = STATE(2590),
    [sym_identifier] = ACTIONS(5599),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5601),
    [anon_sym_COMMA] = ACTIONS(5601),
    [anon_sym_RPAREN] = ACTIONS(5601),
    [aux_sym_preproc_if_token2] = ACTIONS(5601),
    [aux_sym_preproc_else_token1] = ACTIONS(5601),
    [aux_sym_preproc_elif_token1] = ACTIONS(5599),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5601),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5601),
    [anon_sym_LPAREN2] = ACTIONS(5601),
    [anon_sym_DASH] = ACTIONS(5599),
    [anon_sym_PLUS] = ACTIONS(5599),
    [anon_sym_STAR] = ACTIONS(5599),
    [anon_sym_SLASH] = ACTIONS(5599),
    [anon_sym_PERCENT] = ACTIONS(5599),
    [anon_sym_PIPE_PIPE] = ACTIONS(5601),
    [anon_sym_AMP_AMP] = ACTIONS(5601),
    [anon_sym_PIPE] = ACTIONS(5599),
    [anon_sym_CARET] = ACTIONS(5599),
    [anon_sym_AMP] = ACTIONS(5599),
    [anon_sym_EQ_EQ] = ACTIONS(5601),
    [anon_sym_BANG_EQ] = ACTIONS(5601),
    [anon_sym_GT] = ACTIONS(5599),
    [anon_sym_GT_EQ] = ACTIONS(5601),
    [anon_sym_LT_EQ] = ACTIONS(5599),
    [anon_sym_LT] = ACTIONS(5599),
    [anon_sym_LT_LT] = ACTIONS(5599),
    [anon_sym_GT_GT] = ACTIONS(5599),
    [anon_sym_COLON] = ACTIONS(5601),
    [anon_sym_SEMI] = ACTIONS(5601),
    [anon_sym___attribute__] = ACTIONS(5815),
    [anon_sym_LBRACE] = ACTIONS(5601),
    [anon_sym_RBRACE] = ACTIONS(5601),
    [anon_sym_LBRACK] = ACTIONS(5601),
    [anon_sym_RBRACK] = ACTIONS(5601),
    [anon_sym_EQ] = ACTIONS(5599),
    [anon_sym_QMARK] = ACTIONS(5601),
    [anon_sym_STAR_EQ] = ACTIONS(5601),
    [anon_sym_SLASH_EQ] = ACTIONS(5601),
    [anon_sym_PERCENT_EQ] = ACTIONS(5601),
    [anon_sym_PLUS_EQ] = ACTIONS(5601),
    [anon_sym_DASH_EQ] = ACTIONS(5601),
    [anon_sym_LT_LT_EQ] = ACTIONS(5601),
    [anon_sym_GT_GT_EQ] = ACTIONS(5601),
    [anon_sym_AMP_EQ] = ACTIONS(5601),
    [anon_sym_CARET_EQ] = ACTIONS(5601),
    [anon_sym_PIPE_EQ] = ACTIONS(5601),
    [anon_sym_and_eq] = ACTIONS(5599),
    [anon_sym_or_eq] = ACTIONS(5599),
    [anon_sym_xor_eq] = ACTIONS(5599),
    [anon_sym_LT_EQ_GT] = ACTIONS(5601),
    [anon_sym_or] = ACTIONS(5599),
    [anon_sym_and] = ACTIONS(5599),
    [anon_sym_bitor] = ACTIONS(5599),
    [anon_sym_xor] = ACTIONS(5599),
    [anon_sym_bitand] = ACTIONS(5599),
    [anon_sym_not_eq] = ACTIONS(5599),
    [anon_sym_DASH_DASH] = ACTIONS(5601),
    [anon_sym_PLUS_PLUS] = ACTIONS(5601),
    [anon_sym_DOT] = ACTIONS(5599),
    [anon_sym_DOT_STAR] = ACTIONS(5601),
    [anon_sym_DASH_GT] = ACTIONS(5601),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5599),
    [anon_sym_decltype] = ACTIONS(5599),
  },
  [2554] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2408),
    [sym_identifier] = ACTIONS(5312),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5315),
    [anon_sym_COMMA] = ACTIONS(5315),
    [aux_sym_preproc_if_token2] = ACTIONS(5315),
    [aux_sym_preproc_else_token1] = ACTIONS(5315),
    [aux_sym_preproc_elif_token1] = ACTIONS(5312),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5315),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5315),
    [anon_sym_LPAREN2] = ACTIONS(5315),
    [anon_sym_DASH] = ACTIONS(5312),
    [anon_sym_PLUS] = ACTIONS(5312),
    [anon_sym_STAR] = ACTIONS(5312),
    [anon_sym_SLASH] = ACTIONS(5312),
    [anon_sym_PERCENT] = ACTIONS(5312),
    [anon_sym_PIPE_PIPE] = ACTIONS(5315),
    [anon_sym_AMP_AMP] = ACTIONS(5315),
    [anon_sym_PIPE] = ACTIONS(5312),
    [anon_sym_CARET] = ACTIONS(5312),
    [anon_sym_AMP] = ACTIONS(5312),
    [anon_sym_EQ_EQ] = ACTIONS(5315),
    [anon_sym_BANG_EQ] = ACTIONS(5315),
    [anon_sym_GT] = ACTIONS(5312),
    [anon_sym_GT_EQ] = ACTIONS(5315),
    [anon_sym_LT_EQ] = ACTIONS(5312),
    [anon_sym_LT] = ACTIONS(5312),
    [anon_sym_LT_LT] = ACTIONS(5312),
    [anon_sym_GT_GT] = ACTIONS(5312),
    [anon_sym___attribute__] = ACTIONS(5312),
    [anon_sym_LBRACE] = ACTIONS(5315),
    [anon_sym_signed] = ACTIONS(5807),
    [anon_sym_unsigned] = ACTIONS(5807),
    [anon_sym_long] = ACTIONS(5807),
    [anon_sym_short] = ACTIONS(5807),
    [anon_sym_LBRACK] = ACTIONS(5315),
    [anon_sym_EQ] = ACTIONS(5312),
    [sym_primitive_type] = ACTIONS(5224),
    [anon_sym_QMARK] = ACTIONS(5315),
    [anon_sym_STAR_EQ] = ACTIONS(5315),
    [anon_sym_SLASH_EQ] = ACTIONS(5315),
    [anon_sym_PERCENT_EQ] = ACTIONS(5315),
    [anon_sym_PLUS_EQ] = ACTIONS(5315),
    [anon_sym_DASH_EQ] = ACTIONS(5315),
    [anon_sym_LT_LT_EQ] = ACTIONS(5315),
    [anon_sym_GT_GT_EQ] = ACTIONS(5315),
    [anon_sym_AMP_EQ] = ACTIONS(5315),
    [anon_sym_CARET_EQ] = ACTIONS(5315),
    [anon_sym_PIPE_EQ] = ACTIONS(5315),
    [anon_sym_and_eq] = ACTIONS(5312),
    [anon_sym_or_eq] = ACTIONS(5312),
    [anon_sym_xor_eq] = ACTIONS(5312),
    [anon_sym_LT_EQ_GT] = ACTIONS(5315),
    [anon_sym_or] = ACTIONS(5312),
    [anon_sym_and] = ACTIONS(5312),
    [anon_sym_bitor] = ACTIONS(5312),
    [anon_sym_xor] = ACTIONS(5312),
    [anon_sym_bitand] = ACTIONS(5312),
    [anon_sym_not_eq] = ACTIONS(5312),
    [anon_sym_DASH_DASH] = ACTIONS(5315),
    [anon_sym_PLUS_PLUS] = ACTIONS(5315),
    [anon_sym_DOT] = ACTIONS(5312),
    [anon_sym_DOT_STAR] = ACTIONS(5315),
    [anon_sym_DASH_GT] = ACTIONS(5315),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5312),
    [anon_sym_decltype] = ACTIONS(5312),
  },
  [2555] = {
    [sym_string_literal] = STATE(2539),
    [sym_template_argument_list] = STATE(3358),
    [sym_raw_string_literal] = STATE(2539),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3824),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3832),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(6028),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_LBRACK] = ACTIONS(3824),
    [anon_sym_EQ] = ACTIONS(3832),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3824),
    [anon_sym_SLASH_EQ] = ACTIONS(3824),
    [anon_sym_PERCENT_EQ] = ACTIONS(3824),
    [anon_sym_PLUS_EQ] = ACTIONS(3824),
    [anon_sym_DASH_EQ] = ACTIONS(3824),
    [anon_sym_LT_LT_EQ] = ACTIONS(3824),
    [anon_sym_GT_GT_EQ] = ACTIONS(3832),
    [anon_sym_AMP_EQ] = ACTIONS(3824),
    [anon_sym_CARET_EQ] = ACTIONS(3824),
    [anon_sym_PIPE_EQ] = ACTIONS(3824),
    [anon_sym_and_eq] = ACTIONS(3824),
    [anon_sym_or_eq] = ACTIONS(3824),
    [anon_sym_xor_eq] = ACTIONS(3824),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(5992),
    [anon_sym_u_DQUOTE] = ACTIONS(5992),
    [anon_sym_U_DQUOTE] = ACTIONS(5992),
    [anon_sym_u8_DQUOTE] = ACTIONS(5992),
    [anon_sym_DQUOTE] = ACTIONS(5992),
    [sym_comment] = ACTIONS(3),
    [anon_sym_GT2] = ACTIONS(3824),
    [anon_sym_R_DQUOTE] = ACTIONS(5994),
    [anon_sym_LR_DQUOTE] = ACTIONS(5994),
    [anon_sym_uR_DQUOTE] = ACTIONS(5994),
    [anon_sym_UR_DQUOTE] = ACTIONS(5994),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5994),
  },
  [2556] = {
    [sym_ms_based_modifier] = STATE(8703),
    [sym_ms_unaligned_ptr_modifier] = STATE(4205),
    [sym_ms_pointer_modifier] = STATE(2574),
    [sym__declarator] = STATE(5944),
    [sym__abstract_declarator] = STATE(6600),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_abstract_parenthesized_declarator] = STATE(6033),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_abstract_pointer_declarator] = STATE(6033),
    [sym_function_declarator] = STATE(6270),
    [sym_abstract_function_declarator] = STATE(6033),
    [sym_array_declarator] = STATE(6270),
    [sym_abstract_array_declarator] = STATE(6033),
    [sym_type_qualifier] = STATE(2985),
    [sym_alignas_qualifier] = STATE(4472),
    [sym_parameter_list] = STATE(3745),
    [sym_decltype] = STATE(8571),
    [sym_reference_declarator] = STATE(6270),
    [sym_abstract_reference_declarator] = STATE(6033),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym__function_declarator_seq] = STATE(6076),
    [sym_template_type] = STATE(8571),
    [sym_template_function] = STATE(6270),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5644),
    [sym_qualified_identifier] = STATE(6270),
    [sym_operator_name] = STATE(6270),
    [aux_sym__type_definition_type_repeat1] = STATE(2985),
    [aux_sym_pointer_declarator_repeat1] = STATE(2574),
    [sym_identifier] = ACTIONS(5889),
    [anon_sym_COMMA] = ACTIONS(5891),
    [anon_sym_LPAREN2] = ACTIONS(3934),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(6031),
    [anon_sym_AMP_AMP] = ACTIONS(6033),
    [anon_sym_AMP] = ACTIONS(6035),
    [anon_sym_COLON] = ACTIONS(5899),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(5901),
    [anon_sym___based] = ACTIONS(49),
    [sym_ms_restrict_modifier] = ACTIONS(3906),
    [sym_ms_unsigned_ptr_modifier] = ACTIONS(3906),
    [sym_ms_signed_ptr_modifier] = ACTIONS(3906),
    [anon_sym__unaligned] = ACTIONS(3908),
    [anon_sym___unaligned] = ACTIONS(3908),
    [anon_sym_LBRACK] = ACTIONS(5903),
    [anon_sym_const] = ACTIONS(3904),
    [anon_sym_constexpr] = ACTIONS(3904),
    [anon_sym_volatile] = ACTIONS(3904),
    [anon_sym_restrict] = ACTIONS(3904),
    [anon_sym___restrict__] = ACTIONS(3904),
    [anon_sym__Atomic] = ACTIONS(3904),
    [anon_sym__Noreturn] = ACTIONS(3904),
    [anon_sym_noreturn] = ACTIONS(3904),
    [anon_sym_mutable] = ACTIONS(3904),
    [anon_sym_constinit] = ACTIONS(3904),
    [anon_sym_consteval] = ACTIONS(3904),
    [anon_sym_alignas] = ACTIONS(3910),
    [anon_sym__Alignas] = ACTIONS(3910),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(5891),
    [anon_sym_operator] = ACTIONS(2078),
  },
  [2557] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2582),
    [sym_identifier] = ACTIONS(6037),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5336),
    [anon_sym_COMMA] = ACTIONS(5336),
    [anon_sym_RPAREN] = ACTIONS(5336),
    [anon_sym_LPAREN2] = ACTIONS(5336),
    [anon_sym_DASH] = ACTIONS(5338),
    [anon_sym_PLUS] = ACTIONS(5338),
    [anon_sym_STAR] = ACTIONS(5338),
    [anon_sym_SLASH] = ACTIONS(5338),
    [anon_sym_PERCENT] = ACTIONS(5338),
    [anon_sym_PIPE_PIPE] = ACTIONS(5336),
    [anon_sym_AMP_AMP] = ACTIONS(5336),
    [anon_sym_PIPE] = ACTIONS(5338),
    [anon_sym_CARET] = ACTIONS(5338),
    [anon_sym_AMP] = ACTIONS(5338),
    [anon_sym_EQ_EQ] = ACTIONS(5336),
    [anon_sym_BANG_EQ] = ACTIONS(5336),
    [anon_sym_GT] = ACTIONS(5338),
    [anon_sym_GT_EQ] = ACTIONS(5336),
    [anon_sym_LT_EQ] = ACTIONS(5338),
    [anon_sym_LT] = ACTIONS(5338),
    [anon_sym_LT_LT] = ACTIONS(5338),
    [anon_sym_GT_GT] = ACTIONS(5338),
    [anon_sym_COLON] = ACTIONS(5336),
    [anon_sym_SEMI] = ACTIONS(5336),
    [anon_sym___attribute__] = ACTIONS(5338),
    [anon_sym_LBRACE] = ACTIONS(5336),
    [anon_sym_RBRACE] = ACTIONS(5336),
    [anon_sym_signed] = ACTIONS(6039),
    [anon_sym_unsigned] = ACTIONS(6039),
    [anon_sym_long] = ACTIONS(6039),
    [anon_sym_short] = ACTIONS(6039),
    [anon_sym_LBRACK] = ACTIONS(5336),
    [anon_sym_RBRACK] = ACTIONS(5336),
    [anon_sym_EQ] = ACTIONS(5338),
    [sym_primitive_type] = ACTIONS(6041),
    [anon_sym_QMARK] = ACTIONS(5336),
    [anon_sym_STAR_EQ] = ACTIONS(5336),
    [anon_sym_SLASH_EQ] = ACTIONS(5336),
    [anon_sym_PERCENT_EQ] = ACTIONS(5336),
    [anon_sym_PLUS_EQ] = ACTIONS(5336),
    [anon_sym_DASH_EQ] = ACTIONS(5336),
    [anon_sym_LT_LT_EQ] = ACTIONS(5336),
    [anon_sym_GT_GT_EQ] = ACTIONS(5336),
    [anon_sym_AMP_EQ] = ACTIONS(5336),
    [anon_sym_CARET_EQ] = ACTIONS(5336),
    [anon_sym_PIPE_EQ] = ACTIONS(5336),
    [anon_sym_and_eq] = ACTIONS(5338),
    [anon_sym_or_eq] = ACTIONS(5338),
    [anon_sym_xor_eq] = ACTIONS(5338),
    [anon_sym_LT_EQ_GT] = ACTIONS(5336),
    [anon_sym_or] = ACTIONS(5338),
    [anon_sym_and] = ACTIONS(5338),
    [anon_sym_bitor] = ACTIONS(5338),
    [anon_sym_xor] = ACTIONS(5338),
    [anon_sym_bitand] = ACTIONS(5338),
    [anon_sym_not_eq] = ACTIONS(5338),
    [anon_sym_DASH_DASH] = ACTIONS(5336),
    [anon_sym_PLUS_PLUS] = ACTIONS(5336),
    [anon_sym_DOT] = ACTIONS(5338),
    [anon_sym_DOT_STAR] = ACTIONS(5336),
    [anon_sym_DASH_GT] = ACTIONS(5336),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5338),
    [anon_sym_decltype] = ACTIONS(5338),
  },
  [2558] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5773),
    [anon_sym_COMMA] = ACTIONS(5773),
    [anon_sym_RPAREN] = ACTIONS(5773),
    [anon_sym_LPAREN2] = ACTIONS(5773),
    [anon_sym_DASH] = ACTIONS(5771),
    [anon_sym_PLUS] = ACTIONS(5771),
    [anon_sym_STAR] = ACTIONS(5771),
    [anon_sym_SLASH] = ACTIONS(5771),
    [anon_sym_PERCENT] = ACTIONS(5771),
    [anon_sym_PIPE_PIPE] = ACTIONS(5773),
    [anon_sym_AMP_AMP] = ACTIONS(5773),
    [anon_sym_PIPE] = ACTIONS(5771),
    [anon_sym_CARET] = ACTIONS(5771),
    [anon_sym_AMP] = ACTIONS(5771),
    [anon_sym_EQ_EQ] = ACTIONS(5773),
    [anon_sym_BANG_EQ] = ACTIONS(5773),
    [anon_sym_GT] = ACTIONS(5771),
    [anon_sym_GT_EQ] = ACTIONS(5773),
    [anon_sym_LT_EQ] = ACTIONS(5771),
    [anon_sym_LT] = ACTIONS(5771),
    [anon_sym_LT_LT] = ACTIONS(5771),
    [anon_sym_GT_GT] = ACTIONS(5771),
    [anon_sym_COLON] = ACTIONS(5773),
    [anon_sym_SEMI] = ACTIONS(5773),
    [anon_sym_RBRACE] = ACTIONS(5773),
    [anon_sym_LBRACK] = ACTIONS(5773),
    [anon_sym_RBRACK] = ACTIONS(5773),
    [anon_sym_EQ] = ACTIONS(5771),
    [anon_sym_QMARK] = ACTIONS(5773),
    [anon_sym_STAR_EQ] = ACTIONS(5773),
    [anon_sym_SLASH_EQ] = ACTIONS(5773),
    [anon_sym_PERCENT_EQ] = ACTIONS(5773),
    [anon_sym_PLUS_EQ] = ACTIONS(5773),
    [anon_sym_DASH_EQ] = ACTIONS(5773),
    [anon_sym_LT_LT_EQ] = ACTIONS(5773),
    [anon_sym_GT_GT_EQ] = ACTIONS(5773),
    [anon_sym_AMP_EQ] = ACTIONS(5773),
    [anon_sym_CARET_EQ] = ACTIONS(5773),
    [anon_sym_PIPE_EQ] = ACTIONS(5773),
    [anon_sym_and_eq] = ACTIONS(5771),
    [anon_sym_or_eq] = ACTIONS(5771),
    [anon_sym_xor_eq] = ACTIONS(5771),
    [anon_sym_LT_EQ_GT] = ACTIONS(5773),
    [anon_sym_or] = ACTIONS(5771),
    [anon_sym_and] = ACTIONS(5771),
    [anon_sym_bitor] = ACTIONS(5771),
    [anon_sym_xor] = ACTIONS(5771),
    [anon_sym_bitand] = ACTIONS(5771),
    [anon_sym_not_eq] = ACTIONS(5771),
    [anon_sym_DASH_DASH] = ACTIONS(5773),
    [anon_sym_PLUS_PLUS] = ACTIONS(5773),
    [anon_sym_DOT] = ACTIONS(5771),
    [anon_sym_DOT_STAR] = ACTIONS(5773),
    [anon_sym_DASH_GT] = ACTIONS(5773),
    [anon_sym_L_DQUOTE] = ACTIONS(5773),
    [anon_sym_u_DQUOTE] = ACTIONS(5773),
    [anon_sym_U_DQUOTE] = ACTIONS(5773),
    [anon_sym_u8_DQUOTE] = ACTIONS(5773),
    [anon_sym_DQUOTE] = ACTIONS(5773),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5773),
    [anon_sym_LR_DQUOTE] = ACTIONS(5773),
    [anon_sym_uR_DQUOTE] = ACTIONS(5773),
    [anon_sym_UR_DQUOTE] = ACTIONS(5773),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5773),
    [sym_literal_suffix] = ACTIONS(5771),
  },
  [2559] = {
    [sym_decltype_auto] = STATE(2607),
    [sym_identifier] = ACTIONS(5413),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5415),
    [anon_sym_COMMA] = ACTIONS(5415),
    [anon_sym_RPAREN] = ACTIONS(5415),
    [aux_sym_preproc_if_token2] = ACTIONS(5415),
    [aux_sym_preproc_else_token1] = ACTIONS(5415),
    [aux_sym_preproc_elif_token1] = ACTIONS(5413),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5415),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5415),
    [anon_sym_LPAREN2] = ACTIONS(5415),
    [anon_sym_DASH] = ACTIONS(5413),
    [anon_sym_PLUS] = ACTIONS(5413),
    [anon_sym_STAR] = ACTIONS(5413),
    [anon_sym_SLASH] = ACTIONS(5413),
    [anon_sym_PERCENT] = ACTIONS(5413),
    [anon_sym_PIPE_PIPE] = ACTIONS(5415),
    [anon_sym_AMP_AMP] = ACTIONS(5415),
    [anon_sym_PIPE] = ACTIONS(5413),
    [anon_sym_CARET] = ACTIONS(5413),
    [anon_sym_AMP] = ACTIONS(5413),
    [anon_sym_EQ_EQ] = ACTIONS(5415),
    [anon_sym_BANG_EQ] = ACTIONS(5415),
    [anon_sym_GT] = ACTIONS(5413),
    [anon_sym_GT_EQ] = ACTIONS(5415),
    [anon_sym_LT_EQ] = ACTIONS(5413),
    [anon_sym_LT] = ACTIONS(5413),
    [anon_sym_LT_LT] = ACTIONS(5413),
    [anon_sym_GT_GT] = ACTIONS(5413),
    [anon_sym_COLON] = ACTIONS(5415),
    [anon_sym_SEMI] = ACTIONS(5415),
    [anon_sym___attribute__] = ACTIONS(5413),
    [anon_sym_LBRACE] = ACTIONS(5415),
    [anon_sym_RBRACE] = ACTIONS(5415),
    [anon_sym_LBRACK] = ACTIONS(5415),
    [anon_sym_RBRACK] = ACTIONS(5415),
    [anon_sym_EQ] = ACTIONS(5413),
    [anon_sym_QMARK] = ACTIONS(5415),
    [anon_sym_STAR_EQ] = ACTIONS(5415),
    [anon_sym_SLASH_EQ] = ACTIONS(5415),
    [anon_sym_PERCENT_EQ] = ACTIONS(5415),
    [anon_sym_PLUS_EQ] = ACTIONS(5415),
    [anon_sym_DASH_EQ] = ACTIONS(5415),
    [anon_sym_LT_LT_EQ] = ACTIONS(5415),
    [anon_sym_GT_GT_EQ] = ACTIONS(5415),
    [anon_sym_AMP_EQ] = ACTIONS(5415),
    [anon_sym_CARET_EQ] = ACTIONS(5415),
    [anon_sym_PIPE_EQ] = ACTIONS(5415),
    [anon_sym_and_eq] = ACTIONS(5413),
    [anon_sym_or_eq] = ACTIONS(5413),
    [anon_sym_xor_eq] = ACTIONS(5413),
    [anon_sym_LT_EQ_GT] = ACTIONS(5415),
    [anon_sym_or] = ACTIONS(5413),
    [anon_sym_and] = ACTIONS(5413),
    [anon_sym_bitor] = ACTIONS(5413),
    [anon_sym_xor] = ACTIONS(5413),
    [anon_sym_bitand] = ACTIONS(5413),
    [anon_sym_not_eq] = ACTIONS(5413),
    [anon_sym_DASH_DASH] = ACTIONS(5415),
    [anon_sym_PLUS_PLUS] = ACTIONS(5415),
    [anon_sym_DOT] = ACTIONS(5413),
    [anon_sym_DOT_STAR] = ACTIONS(5415),
    [anon_sym_DASH_GT] = ACTIONS(5415),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5858),
    [anon_sym_decltype] = ACTIONS(5860),
  },
  [2560] = {
    [sym_string_literal] = STATE(2561),
    [sym_raw_string_literal] = STATE(2561),
    [aux_sym_concatenated_string_repeat1] = STATE(2561),
    [sym_identifier] = ACTIONS(6043),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5667),
    [anon_sym_COMMA] = ACTIONS(5667),
    [anon_sym_LPAREN2] = ACTIONS(5667),
    [anon_sym_DASH] = ACTIONS(5669),
    [anon_sym_PLUS] = ACTIONS(5669),
    [anon_sym_STAR] = ACTIONS(5669),
    [anon_sym_SLASH] = ACTIONS(5669),
    [anon_sym_PERCENT] = ACTIONS(5669),
    [anon_sym_PIPE_PIPE] = ACTIONS(5667),
    [anon_sym_AMP_AMP] = ACTIONS(5667),
    [anon_sym_PIPE] = ACTIONS(5669),
    [anon_sym_CARET] = ACTIONS(5669),
    [anon_sym_AMP] = ACTIONS(5669),
    [anon_sym_EQ_EQ] = ACTIONS(5667),
    [anon_sym_BANG_EQ] = ACTIONS(5667),
    [anon_sym_GT] = ACTIONS(5669),
    [anon_sym_GT_EQ] = ACTIONS(5669),
    [anon_sym_LT_EQ] = ACTIONS(5669),
    [anon_sym_LT] = ACTIONS(5669),
    [anon_sym_LT_LT] = ACTIONS(5669),
    [anon_sym_GT_GT] = ACTIONS(5669),
    [anon_sym_LBRACK] = ACTIONS(5667),
    [anon_sym_EQ] = ACTIONS(5669),
    [anon_sym_QMARK] = ACTIONS(5667),
    [anon_sym_STAR_EQ] = ACTIONS(5667),
    [anon_sym_SLASH_EQ] = ACTIONS(5667),
    [anon_sym_PERCENT_EQ] = ACTIONS(5667),
    [anon_sym_PLUS_EQ] = ACTIONS(5667),
    [anon_sym_DASH_EQ] = ACTIONS(5667),
    [anon_sym_LT_LT_EQ] = ACTIONS(5667),
    [anon_sym_GT_GT_EQ] = ACTIONS(5669),
    [anon_sym_AMP_EQ] = ACTIONS(5667),
    [anon_sym_CARET_EQ] = ACTIONS(5667),
    [anon_sym_PIPE_EQ] = ACTIONS(5667),
    [anon_sym_and_eq] = ACTIONS(5669),
    [anon_sym_or_eq] = ACTIONS(5669),
    [anon_sym_xor_eq] = ACTIONS(5669),
    [anon_sym_LT_EQ_GT] = ACTIONS(5667),
    [anon_sym_or] = ACTIONS(5669),
    [anon_sym_and] = ACTIONS(5669),
    [anon_sym_bitor] = ACTIONS(5669),
    [anon_sym_xor] = ACTIONS(5669),
    [anon_sym_bitand] = ACTIONS(5669),
    [anon_sym_not_eq] = ACTIONS(5669),
    [anon_sym_DASH_DASH] = ACTIONS(5667),
    [anon_sym_PLUS_PLUS] = ACTIONS(5667),
    [anon_sym_DOT] = ACTIONS(5669),
    [anon_sym_DOT_STAR] = ACTIONS(5667),
    [anon_sym_DASH_GT] = ACTIONS(5667),
    [anon_sym_L_DQUOTE] = ACTIONS(5992),
    [anon_sym_u_DQUOTE] = ACTIONS(5992),
    [anon_sym_U_DQUOTE] = ACTIONS(5992),
    [anon_sym_u8_DQUOTE] = ACTIONS(5992),
    [anon_sym_DQUOTE] = ACTIONS(5992),
    [sym_comment] = ACTIONS(3),
    [anon_sym_GT2] = ACTIONS(5667),
    [anon_sym_R_DQUOTE] = ACTIONS(5994),
    [anon_sym_LR_DQUOTE] = ACTIONS(5994),
    [anon_sym_uR_DQUOTE] = ACTIONS(5994),
    [anon_sym_UR_DQUOTE] = ACTIONS(5994),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5994),
    [sym_literal_suffix] = ACTIONS(5669),
  },
  [2561] = {
    [sym_string_literal] = STATE(2561),
    [sym_raw_string_literal] = STATE(2561),
    [aux_sym_concatenated_string_repeat1] = STATE(2561),
    [sym_identifier] = ACTIONS(6045),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5649),
    [anon_sym_COMMA] = ACTIONS(5649),
    [anon_sym_LPAREN2] = ACTIONS(5649),
    [anon_sym_DASH] = ACTIONS(5651),
    [anon_sym_PLUS] = ACTIONS(5651),
    [anon_sym_STAR] = ACTIONS(5651),
    [anon_sym_SLASH] = ACTIONS(5651),
    [anon_sym_PERCENT] = ACTIONS(5651),
    [anon_sym_PIPE_PIPE] = ACTIONS(5649),
    [anon_sym_AMP_AMP] = ACTIONS(5649),
    [anon_sym_PIPE] = ACTIONS(5651),
    [anon_sym_CARET] = ACTIONS(5651),
    [anon_sym_AMP] = ACTIONS(5651),
    [anon_sym_EQ_EQ] = ACTIONS(5649),
    [anon_sym_BANG_EQ] = ACTIONS(5649),
    [anon_sym_GT] = ACTIONS(5651),
    [anon_sym_GT_EQ] = ACTIONS(5651),
    [anon_sym_LT_EQ] = ACTIONS(5651),
    [anon_sym_LT] = ACTIONS(5651),
    [anon_sym_LT_LT] = ACTIONS(5651),
    [anon_sym_GT_GT] = ACTIONS(5651),
    [anon_sym_LBRACK] = ACTIONS(5649),
    [anon_sym_EQ] = ACTIONS(5651),
    [anon_sym_QMARK] = ACTIONS(5649),
    [anon_sym_STAR_EQ] = ACTIONS(5649),
    [anon_sym_SLASH_EQ] = ACTIONS(5649),
    [anon_sym_PERCENT_EQ] = ACTIONS(5649),
    [anon_sym_PLUS_EQ] = ACTIONS(5649),
    [anon_sym_DASH_EQ] = ACTIONS(5649),
    [anon_sym_LT_LT_EQ] = ACTIONS(5649),
    [anon_sym_GT_GT_EQ] = ACTIONS(5651),
    [anon_sym_AMP_EQ] = ACTIONS(5649),
    [anon_sym_CARET_EQ] = ACTIONS(5649),
    [anon_sym_PIPE_EQ] = ACTIONS(5649),
    [anon_sym_and_eq] = ACTIONS(5651),
    [anon_sym_or_eq] = ACTIONS(5651),
    [anon_sym_xor_eq] = ACTIONS(5651),
    [anon_sym_LT_EQ_GT] = ACTIONS(5649),
    [anon_sym_or] = ACTIONS(5651),
    [anon_sym_and] = ACTIONS(5651),
    [anon_sym_bitor] = ACTIONS(5651),
    [anon_sym_xor] = ACTIONS(5651),
    [anon_sym_bitand] = ACTIONS(5651),
    [anon_sym_not_eq] = ACTIONS(5651),
    [anon_sym_DASH_DASH] = ACTIONS(5649),
    [anon_sym_PLUS_PLUS] = ACTIONS(5649),
    [anon_sym_DOT] = ACTIONS(5651),
    [anon_sym_DOT_STAR] = ACTIONS(5649),
    [anon_sym_DASH_GT] = ACTIONS(5649),
    [anon_sym_L_DQUOTE] = ACTIONS(6048),
    [anon_sym_u_DQUOTE] = ACTIONS(6048),
    [anon_sym_U_DQUOTE] = ACTIONS(6048),
    [anon_sym_u8_DQUOTE] = ACTIONS(6048),
    [anon_sym_DQUOTE] = ACTIONS(6048),
    [sym_comment] = ACTIONS(3),
    [anon_sym_GT2] = ACTIONS(5649),
    [anon_sym_R_DQUOTE] = ACTIONS(6051),
    [anon_sym_LR_DQUOTE] = ACTIONS(6051),
    [anon_sym_uR_DQUOTE] = ACTIONS(6051),
    [anon_sym_UR_DQUOTE] = ACTIONS(6051),
    [anon_sym_u8R_DQUOTE] = ACTIONS(6051),
    [sym_literal_suffix] = ACTIONS(5651),
  },
  [2562] = {
    [sym_attribute_specifier] = STATE(2635),
    [sym_identifier] = ACTIONS(5567),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5569),
    [anon_sym_COMMA] = ACTIONS(5569),
    [anon_sym_RPAREN] = ACTIONS(5569),
    [aux_sym_preproc_if_token2] = ACTIONS(5569),
    [aux_sym_preproc_else_token1] = ACTIONS(5569),
    [aux_sym_preproc_elif_token1] = ACTIONS(5567),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5569),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5569),
    [anon_sym_LPAREN2] = ACTIONS(5569),
    [anon_sym_DASH] = ACTIONS(5567),
    [anon_sym_PLUS] = ACTIONS(5567),
    [anon_sym_STAR] = ACTIONS(5567),
    [anon_sym_SLASH] = ACTIONS(5567),
    [anon_sym_PERCENT] = ACTIONS(5567),
    [anon_sym_PIPE_PIPE] = ACTIONS(5569),
    [anon_sym_AMP_AMP] = ACTIONS(5569),
    [anon_sym_PIPE] = ACTIONS(5567),
    [anon_sym_CARET] = ACTIONS(5567),
    [anon_sym_AMP] = ACTIONS(5567),
    [anon_sym_EQ_EQ] = ACTIONS(5569),
    [anon_sym_BANG_EQ] = ACTIONS(5569),
    [anon_sym_GT] = ACTIONS(5567),
    [anon_sym_GT_EQ] = ACTIONS(5569),
    [anon_sym_LT_EQ] = ACTIONS(5567),
    [anon_sym_LT] = ACTIONS(5567),
    [anon_sym_LT_LT] = ACTIONS(5567),
    [anon_sym_GT_GT] = ACTIONS(5567),
    [anon_sym_COLON] = ACTIONS(5569),
    [anon_sym_SEMI] = ACTIONS(5569),
    [anon_sym___attribute__] = ACTIONS(5815),
    [anon_sym_LBRACE] = ACTIONS(5569),
    [anon_sym_RBRACE] = ACTIONS(5569),
    [anon_sym_LBRACK] = ACTIONS(5569),
    [anon_sym_RBRACK] = ACTIONS(5569),
    [anon_sym_EQ] = ACTIONS(5567),
    [anon_sym_QMARK] = ACTIONS(5569),
    [anon_sym_STAR_EQ] = ACTIONS(5569),
    [anon_sym_SLASH_EQ] = ACTIONS(5569),
    [anon_sym_PERCENT_EQ] = ACTIONS(5569),
    [anon_sym_PLUS_EQ] = ACTIONS(5569),
    [anon_sym_DASH_EQ] = ACTIONS(5569),
    [anon_sym_LT_LT_EQ] = ACTIONS(5569),
    [anon_sym_GT_GT_EQ] = ACTIONS(5569),
    [anon_sym_AMP_EQ] = ACTIONS(5569),
    [anon_sym_CARET_EQ] = ACTIONS(5569),
    [anon_sym_PIPE_EQ] = ACTIONS(5569),
    [anon_sym_and_eq] = ACTIONS(5567),
    [anon_sym_or_eq] = ACTIONS(5567),
    [anon_sym_xor_eq] = ACTIONS(5567),
    [anon_sym_LT_EQ_GT] = ACTIONS(5569),
    [anon_sym_or] = ACTIONS(5567),
    [anon_sym_and] = ACTIONS(5567),
    [anon_sym_bitor] = ACTIONS(5567),
    [anon_sym_xor] = ACTIONS(5567),
    [anon_sym_bitand] = ACTIONS(5567),
    [anon_sym_not_eq] = ACTIONS(5567),
    [anon_sym_DASH_DASH] = ACTIONS(5569),
    [anon_sym_PLUS_PLUS] = ACTIONS(5569),
    [anon_sym_DOT] = ACTIONS(5567),
    [anon_sym_DOT_STAR] = ACTIONS(5569),
    [anon_sym_DASH_GT] = ACTIONS(5569),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5567),
    [anon_sym_decltype] = ACTIONS(5567),
  },
  [2563] = {
    [sym_attribute_specifier] = STATE(2611),
    [sym_identifier] = ACTIONS(5575),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5577),
    [anon_sym_COMMA] = ACTIONS(5577),
    [anon_sym_RPAREN] = ACTIONS(5577),
    [aux_sym_preproc_if_token2] = ACTIONS(5577),
    [aux_sym_preproc_else_token1] = ACTIONS(5577),
    [aux_sym_preproc_elif_token1] = ACTIONS(5575),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5577),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5577),
    [anon_sym_LPAREN2] = ACTIONS(5577),
    [anon_sym_DASH] = ACTIONS(5575),
    [anon_sym_PLUS] = ACTIONS(5575),
    [anon_sym_STAR] = ACTIONS(5575),
    [anon_sym_SLASH] = ACTIONS(5575),
    [anon_sym_PERCENT] = ACTIONS(5575),
    [anon_sym_PIPE_PIPE] = ACTIONS(5577),
    [anon_sym_AMP_AMP] = ACTIONS(5577),
    [anon_sym_PIPE] = ACTIONS(5575),
    [anon_sym_CARET] = ACTIONS(5575),
    [anon_sym_AMP] = ACTIONS(5575),
    [anon_sym_EQ_EQ] = ACTIONS(5577),
    [anon_sym_BANG_EQ] = ACTIONS(5577),
    [anon_sym_GT] = ACTIONS(5575),
    [anon_sym_GT_EQ] = ACTIONS(5577),
    [anon_sym_LT_EQ] = ACTIONS(5575),
    [anon_sym_LT] = ACTIONS(5575),
    [anon_sym_LT_LT] = ACTIONS(5575),
    [anon_sym_GT_GT] = ACTIONS(5575),
    [anon_sym_COLON] = ACTIONS(5577),
    [anon_sym_SEMI] = ACTIONS(5577),
    [anon_sym___attribute__] = ACTIONS(5815),
    [anon_sym_LBRACE] = ACTIONS(5577),
    [anon_sym_RBRACE] = ACTIONS(5577),
    [anon_sym_LBRACK] = ACTIONS(5577),
    [anon_sym_RBRACK] = ACTIONS(5577),
    [anon_sym_EQ] = ACTIONS(5575),
    [anon_sym_QMARK] = ACTIONS(5577),
    [anon_sym_STAR_EQ] = ACTIONS(5577),
    [anon_sym_SLASH_EQ] = ACTIONS(5577),
    [anon_sym_PERCENT_EQ] = ACTIONS(5577),
    [anon_sym_PLUS_EQ] = ACTIONS(5577),
    [anon_sym_DASH_EQ] = ACTIONS(5577),
    [anon_sym_LT_LT_EQ] = ACTIONS(5577),
    [anon_sym_GT_GT_EQ] = ACTIONS(5577),
    [anon_sym_AMP_EQ] = ACTIONS(5577),
    [anon_sym_CARET_EQ] = ACTIONS(5577),
    [anon_sym_PIPE_EQ] = ACTIONS(5577),
    [anon_sym_and_eq] = ACTIONS(5575),
    [anon_sym_or_eq] = ACTIONS(5575),
    [anon_sym_xor_eq] = ACTIONS(5575),
    [anon_sym_LT_EQ_GT] = ACTIONS(5577),
    [anon_sym_or] = ACTIONS(5575),
    [anon_sym_and] = ACTIONS(5575),
    [anon_sym_bitor] = ACTIONS(5575),
    [anon_sym_xor] = ACTIONS(5575),
    [anon_sym_bitand] = ACTIONS(5575),
    [anon_sym_not_eq] = ACTIONS(5575),
    [anon_sym_DASH_DASH] = ACTIONS(5577),
    [anon_sym_PLUS_PLUS] = ACTIONS(5577),
    [anon_sym_DOT] = ACTIONS(5575),
    [anon_sym_DOT_STAR] = ACTIONS(5577),
    [anon_sym_DASH_GT] = ACTIONS(5577),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5575),
    [anon_sym_decltype] = ACTIONS(5575),
  },
  [2564] = {
    [sym_attribute_specifier] = STATE(2598),
    [sym_identifier] = ACTIONS(5595),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5597),
    [anon_sym_COMMA] = ACTIONS(5597),
    [anon_sym_RPAREN] = ACTIONS(5597),
    [aux_sym_preproc_if_token2] = ACTIONS(5597),
    [aux_sym_preproc_else_token1] = ACTIONS(5597),
    [aux_sym_preproc_elif_token1] = ACTIONS(5595),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5597),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5597),
    [anon_sym_LPAREN2] = ACTIONS(5597),
    [anon_sym_DASH] = ACTIONS(5595),
    [anon_sym_PLUS] = ACTIONS(5595),
    [anon_sym_STAR] = ACTIONS(5595),
    [anon_sym_SLASH] = ACTIONS(5595),
    [anon_sym_PERCENT] = ACTIONS(5595),
    [anon_sym_PIPE_PIPE] = ACTIONS(5597),
    [anon_sym_AMP_AMP] = ACTIONS(5597),
    [anon_sym_PIPE] = ACTIONS(5595),
    [anon_sym_CARET] = ACTIONS(5595),
    [anon_sym_AMP] = ACTIONS(5595),
    [anon_sym_EQ_EQ] = ACTIONS(5597),
    [anon_sym_BANG_EQ] = ACTIONS(5597),
    [anon_sym_GT] = ACTIONS(5595),
    [anon_sym_GT_EQ] = ACTIONS(5597),
    [anon_sym_LT_EQ] = ACTIONS(5595),
    [anon_sym_LT] = ACTIONS(5595),
    [anon_sym_LT_LT] = ACTIONS(5595),
    [anon_sym_GT_GT] = ACTIONS(5595),
    [anon_sym_COLON] = ACTIONS(5597),
    [anon_sym_SEMI] = ACTIONS(5597),
    [anon_sym___attribute__] = ACTIONS(5815),
    [anon_sym_LBRACE] = ACTIONS(5597),
    [anon_sym_RBRACE] = ACTIONS(5597),
    [anon_sym_LBRACK] = ACTIONS(5597),
    [anon_sym_RBRACK] = ACTIONS(5597),
    [anon_sym_EQ] = ACTIONS(5595),
    [anon_sym_QMARK] = ACTIONS(5597),
    [anon_sym_STAR_EQ] = ACTIONS(5597),
    [anon_sym_SLASH_EQ] = ACTIONS(5597),
    [anon_sym_PERCENT_EQ] = ACTIONS(5597),
    [anon_sym_PLUS_EQ] = ACTIONS(5597),
    [anon_sym_DASH_EQ] = ACTIONS(5597),
    [anon_sym_LT_LT_EQ] = ACTIONS(5597),
    [anon_sym_GT_GT_EQ] = ACTIONS(5597),
    [anon_sym_AMP_EQ] = ACTIONS(5597),
    [anon_sym_CARET_EQ] = ACTIONS(5597),
    [anon_sym_PIPE_EQ] = ACTIONS(5597),
    [anon_sym_and_eq] = ACTIONS(5595),
    [anon_sym_or_eq] = ACTIONS(5595),
    [anon_sym_xor_eq] = ACTIONS(5595),
    [anon_sym_LT_EQ_GT] = ACTIONS(5597),
    [anon_sym_or] = ACTIONS(5595),
    [anon_sym_and] = ACTIONS(5595),
    [anon_sym_bitor] = ACTIONS(5595),
    [anon_sym_xor] = ACTIONS(5595),
    [anon_sym_bitand] = ACTIONS(5595),
    [anon_sym_not_eq] = ACTIONS(5595),
    [anon_sym_DASH_DASH] = ACTIONS(5597),
    [anon_sym_PLUS_PLUS] = ACTIONS(5597),
    [anon_sym_DOT] = ACTIONS(5595),
    [anon_sym_DOT_STAR] = ACTIONS(5597),
    [anon_sym_DASH_GT] = ACTIONS(5597),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5595),
    [anon_sym_decltype] = ACTIONS(5595),
  },
  [2565] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5777),
    [anon_sym_COMMA] = ACTIONS(5777),
    [anon_sym_RPAREN] = ACTIONS(5777),
    [anon_sym_LPAREN2] = ACTIONS(5777),
    [anon_sym_DASH] = ACTIONS(5775),
    [anon_sym_PLUS] = ACTIONS(5775),
    [anon_sym_STAR] = ACTIONS(5775),
    [anon_sym_SLASH] = ACTIONS(5775),
    [anon_sym_PERCENT] = ACTIONS(5775),
    [anon_sym_PIPE_PIPE] = ACTIONS(5777),
    [anon_sym_AMP_AMP] = ACTIONS(5777),
    [anon_sym_PIPE] = ACTIONS(5775),
    [anon_sym_CARET] = ACTIONS(5775),
    [anon_sym_AMP] = ACTIONS(5775),
    [anon_sym_EQ_EQ] = ACTIONS(5777),
    [anon_sym_BANG_EQ] = ACTIONS(5777),
    [anon_sym_GT] = ACTIONS(5775),
    [anon_sym_GT_EQ] = ACTIONS(5777),
    [anon_sym_LT_EQ] = ACTIONS(5775),
    [anon_sym_LT] = ACTIONS(5775),
    [anon_sym_LT_LT] = ACTIONS(5775),
    [anon_sym_GT_GT] = ACTIONS(5775),
    [anon_sym_COLON] = ACTIONS(5777),
    [anon_sym_SEMI] = ACTIONS(5777),
    [anon_sym_RBRACE] = ACTIONS(5777),
    [anon_sym_LBRACK] = ACTIONS(5777),
    [anon_sym_RBRACK] = ACTIONS(5777),
    [anon_sym_EQ] = ACTIONS(5775),
    [anon_sym_QMARK] = ACTIONS(5777),
    [anon_sym_STAR_EQ] = ACTIONS(5777),
    [anon_sym_SLASH_EQ] = ACTIONS(5777),
    [anon_sym_PERCENT_EQ] = ACTIONS(5777),
    [anon_sym_PLUS_EQ] = ACTIONS(5777),
    [anon_sym_DASH_EQ] = ACTIONS(5777),
    [anon_sym_LT_LT_EQ] = ACTIONS(5777),
    [anon_sym_GT_GT_EQ] = ACTIONS(5777),
    [anon_sym_AMP_EQ] = ACTIONS(5777),
    [anon_sym_CARET_EQ] = ACTIONS(5777),
    [anon_sym_PIPE_EQ] = ACTIONS(5777),
    [anon_sym_and_eq] = ACTIONS(5775),
    [anon_sym_or_eq] = ACTIONS(5775),
    [anon_sym_xor_eq] = ACTIONS(5775),
    [anon_sym_LT_EQ_GT] = ACTIONS(5777),
    [anon_sym_or] = ACTIONS(5775),
    [anon_sym_and] = ACTIONS(5775),
    [anon_sym_bitor] = ACTIONS(5775),
    [anon_sym_xor] = ACTIONS(5775),
    [anon_sym_bitand] = ACTIONS(5775),
    [anon_sym_not_eq] = ACTIONS(5775),
    [anon_sym_DASH_DASH] = ACTIONS(5777),
    [anon_sym_PLUS_PLUS] = ACTIONS(5777),
    [anon_sym_DOT] = ACTIONS(5775),
    [anon_sym_DOT_STAR] = ACTIONS(5777),
    [anon_sym_DASH_GT] = ACTIONS(5777),
    [anon_sym_L_DQUOTE] = ACTIONS(5777),
    [anon_sym_u_DQUOTE] = ACTIONS(5777),
    [anon_sym_U_DQUOTE] = ACTIONS(5777),
    [anon_sym_u8_DQUOTE] = ACTIONS(5777),
    [anon_sym_DQUOTE] = ACTIONS(5777),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5777),
    [anon_sym_LR_DQUOTE] = ACTIONS(5777),
    [anon_sym_uR_DQUOTE] = ACTIONS(5777),
    [anon_sym_UR_DQUOTE] = ACTIONS(5777),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5777),
    [sym_literal_suffix] = ACTIONS(5775),
  },
  [2566] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(3821),
    [sym_raw_string_literal] = STATE(2868),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3824),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5243),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON] = ACTIONS(3832),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_LBRACK] = ACTIONS(3824),
    [anon_sym_EQ] = ACTIONS(6054),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(6056),
    [anon_sym_SLASH_EQ] = ACTIONS(6056),
    [anon_sym_PERCENT_EQ] = ACTIONS(6056),
    [anon_sym_PLUS_EQ] = ACTIONS(6056),
    [anon_sym_DASH_EQ] = ACTIONS(6056),
    [anon_sym_LT_LT_EQ] = ACTIONS(6056),
    [anon_sym_GT_GT_EQ] = ACTIONS(6056),
    [anon_sym_AMP_EQ] = ACTIONS(6056),
    [anon_sym_CARET_EQ] = ACTIONS(6056),
    [anon_sym_PIPE_EQ] = ACTIONS(6056),
    [anon_sym_and_eq] = ACTIONS(6056),
    [anon_sym_or_eq] = ACTIONS(6056),
    [anon_sym_xor_eq] = ACTIONS(6056),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
  },
  [2567] = {
    [sym_string_literal] = STATE(2868),
    [sym_template_argument_list] = STATE(3821),
    [sym_raw_string_literal] = STATE(2868),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3824),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(5243),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_LBRACK] = ACTIONS(3824),
    [anon_sym_RBRACK] = ACTIONS(3824),
    [anon_sym_EQ] = ACTIONS(5949),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(5951),
    [anon_sym_SLASH_EQ] = ACTIONS(5951),
    [anon_sym_PERCENT_EQ] = ACTIONS(5951),
    [anon_sym_PLUS_EQ] = ACTIONS(5951),
    [anon_sym_DASH_EQ] = ACTIONS(5951),
    [anon_sym_LT_LT_EQ] = ACTIONS(5951),
    [anon_sym_GT_GT_EQ] = ACTIONS(5951),
    [anon_sym_AMP_EQ] = ACTIONS(5951),
    [anon_sym_CARET_EQ] = ACTIONS(5951),
    [anon_sym_PIPE_EQ] = ACTIONS(5951),
    [anon_sym_and_eq] = ACTIONS(5951),
    [anon_sym_or_eq] = ACTIONS(5951),
    [anon_sym_xor_eq] = ACTIONS(5951),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3824),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3824),
    [anon_sym_not_eq] = ACTIONS(3824),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(3858),
    [anon_sym_u_DQUOTE] = ACTIONS(3858),
    [anon_sym_U_DQUOTE] = ACTIONS(3858),
    [anon_sym_u8_DQUOTE] = ACTIONS(3858),
    [anon_sym_DQUOTE] = ACTIONS(3858),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(3860),
    [anon_sym_LR_DQUOTE] = ACTIONS(3860),
    [anon_sym_uR_DQUOTE] = ACTIONS(3860),
    [anon_sym_UR_DQUOTE] = ACTIONS(3860),
    [anon_sym_u8R_DQUOTE] = ACTIONS(3860),
  },
  [2568] = {
    [sym_attribute_specifier] = STATE(2610),
    [sym_identifier] = ACTIONS(5571),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5573),
    [anon_sym_COMMA] = ACTIONS(5573),
    [anon_sym_RPAREN] = ACTIONS(5573),
    [aux_sym_preproc_if_token2] = ACTIONS(5573),
    [aux_sym_preproc_else_token1] = ACTIONS(5573),
    [aux_sym_preproc_elif_token1] = ACTIONS(5571),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5573),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5573),
    [anon_sym_LPAREN2] = ACTIONS(5573),
    [anon_sym_DASH] = ACTIONS(5571),
    [anon_sym_PLUS] = ACTIONS(5571),
    [anon_sym_STAR] = ACTIONS(5571),
    [anon_sym_SLASH] = ACTIONS(5571),
    [anon_sym_PERCENT] = ACTIONS(5571),
    [anon_sym_PIPE_PIPE] = ACTIONS(5573),
    [anon_sym_AMP_AMP] = ACTIONS(5573),
    [anon_sym_PIPE] = ACTIONS(5571),
    [anon_sym_CARET] = ACTIONS(5571),
    [anon_sym_AMP] = ACTIONS(5571),
    [anon_sym_EQ_EQ] = ACTIONS(5573),
    [anon_sym_BANG_EQ] = ACTIONS(5573),
    [anon_sym_GT] = ACTIONS(5571),
    [anon_sym_GT_EQ] = ACTIONS(5573),
    [anon_sym_LT_EQ] = ACTIONS(5571),
    [anon_sym_LT] = ACTIONS(5571),
    [anon_sym_LT_LT] = ACTIONS(5571),
    [anon_sym_GT_GT] = ACTIONS(5571),
    [anon_sym_COLON] = ACTIONS(5573),
    [anon_sym_SEMI] = ACTIONS(5573),
    [anon_sym___attribute__] = ACTIONS(5815),
    [anon_sym_LBRACE] = ACTIONS(5573),
    [anon_sym_RBRACE] = ACTIONS(5573),
    [anon_sym_LBRACK] = ACTIONS(5573),
    [anon_sym_RBRACK] = ACTIONS(5573),
    [anon_sym_EQ] = ACTIONS(5571),
    [anon_sym_QMARK] = ACTIONS(5573),
    [anon_sym_STAR_EQ] = ACTIONS(5573),
    [anon_sym_SLASH_EQ] = ACTIONS(5573),
    [anon_sym_PERCENT_EQ] = ACTIONS(5573),
    [anon_sym_PLUS_EQ] = ACTIONS(5573),
    [anon_sym_DASH_EQ] = ACTIONS(5573),
    [anon_sym_LT_LT_EQ] = ACTIONS(5573),
    [anon_sym_GT_GT_EQ] = ACTIONS(5573),
    [anon_sym_AMP_EQ] = ACTIONS(5573),
    [anon_sym_CARET_EQ] = ACTIONS(5573),
    [anon_sym_PIPE_EQ] = ACTIONS(5573),
    [anon_sym_and_eq] = ACTIONS(5571),
    [anon_sym_or_eq] = ACTIONS(5571),
    [anon_sym_xor_eq] = ACTIONS(5571),
    [anon_sym_LT_EQ_GT] = ACTIONS(5573),
    [anon_sym_or] = ACTIONS(5571),
    [anon_sym_and] = ACTIONS(5571),
    [anon_sym_bitor] = ACTIONS(5571),
    [anon_sym_xor] = ACTIONS(5571),
    [anon_sym_bitand] = ACTIONS(5571),
    [anon_sym_not_eq] = ACTIONS(5571),
    [anon_sym_DASH_DASH] = ACTIONS(5573),
    [anon_sym_PLUS_PLUS] = ACTIONS(5573),
    [anon_sym_DOT] = ACTIONS(5571),
    [anon_sym_DOT_STAR] = ACTIONS(5573),
    [anon_sym_DASH_GT] = ACTIONS(5573),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5571),
    [anon_sym_decltype] = ACTIONS(5571),
  },
  [2569] = {
    [sym_attribute_specifier] = STATE(2615),
    [sym_identifier] = ACTIONS(5610),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5612),
    [anon_sym_COMMA] = ACTIONS(5612),
    [anon_sym_RPAREN] = ACTIONS(5612),
    [aux_sym_preproc_if_token2] = ACTIONS(5612),
    [aux_sym_preproc_else_token1] = ACTIONS(5612),
    [aux_sym_preproc_elif_token1] = ACTIONS(5610),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5612),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5612),
    [anon_sym_LPAREN2] = ACTIONS(5612),
    [anon_sym_DASH] = ACTIONS(5610),
    [anon_sym_PLUS] = ACTIONS(5610),
    [anon_sym_STAR] = ACTIONS(5610),
    [anon_sym_SLASH] = ACTIONS(5610),
    [anon_sym_PERCENT] = ACTIONS(5610),
    [anon_sym_PIPE_PIPE] = ACTIONS(5612),
    [anon_sym_AMP_AMP] = ACTIONS(5612),
    [anon_sym_PIPE] = ACTIONS(5610),
    [anon_sym_CARET] = ACTIONS(5610),
    [anon_sym_AMP] = ACTIONS(5610),
    [anon_sym_EQ_EQ] = ACTIONS(5612),
    [anon_sym_BANG_EQ] = ACTIONS(5612),
    [anon_sym_GT] = ACTIONS(5610),
    [anon_sym_GT_EQ] = ACTIONS(5612),
    [anon_sym_LT_EQ] = ACTIONS(5610),
    [anon_sym_LT] = ACTIONS(5610),
    [anon_sym_LT_LT] = ACTIONS(5610),
    [anon_sym_GT_GT] = ACTIONS(5610),
    [anon_sym_COLON] = ACTIONS(5612),
    [anon_sym_SEMI] = ACTIONS(5612),
    [anon_sym___attribute__] = ACTIONS(5815),
    [anon_sym_LBRACE] = ACTIONS(5612),
    [anon_sym_RBRACE] = ACTIONS(5612),
    [anon_sym_LBRACK] = ACTIONS(5612),
    [anon_sym_RBRACK] = ACTIONS(5612),
    [anon_sym_EQ] = ACTIONS(5610),
    [anon_sym_QMARK] = ACTIONS(5612),
    [anon_sym_STAR_EQ] = ACTIONS(5612),
    [anon_sym_SLASH_EQ] = ACTIONS(5612),
    [anon_sym_PERCENT_EQ] = ACTIONS(5612),
    [anon_sym_PLUS_EQ] = ACTIONS(5612),
    [anon_sym_DASH_EQ] = ACTIONS(5612),
    [anon_sym_LT_LT_EQ] = ACTIONS(5612),
    [anon_sym_GT_GT_EQ] = ACTIONS(5612),
    [anon_sym_AMP_EQ] = ACTIONS(5612),
    [anon_sym_CARET_EQ] = ACTIONS(5612),
    [anon_sym_PIPE_EQ] = ACTIONS(5612),
    [anon_sym_and_eq] = ACTIONS(5610),
    [anon_sym_or_eq] = ACTIONS(5610),
    [anon_sym_xor_eq] = ACTIONS(5610),
    [anon_sym_LT_EQ_GT] = ACTIONS(5612),
    [anon_sym_or] = ACTIONS(5610),
    [anon_sym_and] = ACTIONS(5610),
    [anon_sym_bitor] = ACTIONS(5610),
    [anon_sym_xor] = ACTIONS(5610),
    [anon_sym_bitand] = ACTIONS(5610),
    [anon_sym_not_eq] = ACTIONS(5610),
    [anon_sym_DASH_DASH] = ACTIONS(5612),
    [anon_sym_PLUS_PLUS] = ACTIONS(5612),
    [anon_sym_DOT] = ACTIONS(5610),
    [anon_sym_DOT_STAR] = ACTIONS(5612),
    [anon_sym_DASH_GT] = ACTIONS(5612),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5610),
    [anon_sym_decltype] = ACTIONS(5610),
  },
  [2570] = {
    [sym_ms_based_modifier] = STATE(8703),
    [sym_ms_unaligned_ptr_modifier] = STATE(4205),
    [sym_ms_pointer_modifier] = STATE(2543),
    [sym__declarator] = STATE(5944),
    [sym__abstract_declarator] = STATE(6574),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_abstract_parenthesized_declarator] = STATE(6033),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_abstract_pointer_declarator] = STATE(6033),
    [sym_function_declarator] = STATE(6270),
    [sym_abstract_function_declarator] = STATE(6033),
    [sym_array_declarator] = STATE(6270),
    [sym_abstract_array_declarator] = STATE(6033),
    [sym_type_qualifier] = STATE(2970),
    [sym_alignas_qualifier] = STATE(4472),
    [sym_parameter_list] = STATE(3679),
    [sym_decltype] = STATE(8571),
    [sym_reference_declarator] = STATE(6270),
    [sym_abstract_reference_declarator] = STATE(6033),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym__function_declarator_seq] = STATE(6076),
    [sym_template_type] = STATE(8571),
    [sym_template_function] = STATE(6270),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5644),
    [sym_qualified_identifier] = STATE(6270),
    [sym_operator_name] = STATE(6270),
    [aux_sym__type_definition_type_repeat1] = STATE(2970),
    [aux_sym_pointer_declarator_repeat1] = STATE(2543),
    [sym_identifier] = ACTIONS(5889),
    [anon_sym_COMMA] = ACTIONS(5891),
    [anon_sym_RPAREN] = ACTIONS(5891),
    [anon_sym_LPAREN2] = ACTIONS(3934),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(6006),
    [anon_sym_AMP_AMP] = ACTIONS(6008),
    [anon_sym_AMP] = ACTIONS(6010),
    [anon_sym_COLON] = ACTIONS(5899),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(5901),
    [anon_sym___based] = ACTIONS(49),
    [sym_ms_restrict_modifier] = ACTIONS(3906),
    [sym_ms_unsigned_ptr_modifier] = ACTIONS(3906),
    [sym_ms_signed_ptr_modifier] = ACTIONS(3906),
    [anon_sym__unaligned] = ACTIONS(3908),
    [anon_sym___unaligned] = ACTIONS(3908),
    [anon_sym_LBRACK] = ACTIONS(5903),
    [anon_sym_const] = ACTIONS(3904),
    [anon_sym_constexpr] = ACTIONS(3904),
    [anon_sym_volatile] = ACTIONS(3904),
    [anon_sym_restrict] = ACTIONS(3904),
    [anon_sym___restrict__] = ACTIONS(3904),
    [anon_sym__Atomic] = ACTIONS(3904),
    [anon_sym__Noreturn] = ACTIONS(3904),
    [anon_sym_noreturn] = ACTIONS(3904),
    [anon_sym_mutable] = ACTIONS(3904),
    [anon_sym_constinit] = ACTIONS(3904),
    [anon_sym_consteval] = ACTIONS(3904),
    [anon_sym_alignas] = ACTIONS(3910),
    [anon_sym__Alignas] = ACTIONS(3910),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_operator] = ACTIONS(2078),
  },
  [2571] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2547),
    [sym_identifier] = ACTIONS(6058),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5336),
    [anon_sym_COMMA] = ACTIONS(5336),
    [anon_sym_LPAREN2] = ACTIONS(5336),
    [anon_sym_DASH] = ACTIONS(5338),
    [anon_sym_PLUS] = ACTIONS(5338),
    [anon_sym_STAR] = ACTIONS(5336),
    [anon_sym_SLASH] = ACTIONS(5338),
    [anon_sym_PERCENT] = ACTIONS(5336),
    [anon_sym_PIPE_PIPE] = ACTIONS(5336),
    [anon_sym_AMP_AMP] = ACTIONS(5336),
    [anon_sym_PIPE] = ACTIONS(5338),
    [anon_sym_CARET] = ACTIONS(5336),
    [anon_sym_AMP] = ACTIONS(5338),
    [anon_sym_EQ_EQ] = ACTIONS(5336),
    [anon_sym_BANG_EQ] = ACTIONS(5336),
    [anon_sym_GT] = ACTIONS(5338),
    [anon_sym_GT_EQ] = ACTIONS(5338),
    [anon_sym_LT_EQ] = ACTIONS(5338),
    [anon_sym_LT] = ACTIONS(5338),
    [anon_sym_LT_LT] = ACTIONS(5336),
    [anon_sym_GT_GT] = ACTIONS(5338),
    [anon_sym_COLON] = ACTIONS(5336),
    [anon_sym___extension__] = ACTIONS(5338),
    [anon_sym___attribute__] = ACTIONS(5338),
    [anon_sym_LBRACE] = ACTIONS(5336),
    [anon_sym_signed] = ACTIONS(6060),
    [anon_sym_unsigned] = ACTIONS(6060),
    [anon_sym_long] = ACTIONS(6060),
    [anon_sym_short] = ACTIONS(6060),
    [anon_sym_LBRACK] = ACTIONS(5336),
    [anon_sym_const] = ACTIONS(5338),
    [anon_sym_constexpr] = ACTIONS(5338),
    [anon_sym_volatile] = ACTIONS(5338),
    [anon_sym_restrict] = ACTIONS(5338),
    [anon_sym___restrict__] = ACTIONS(5338),
    [anon_sym__Atomic] = ACTIONS(5338),
    [anon_sym__Noreturn] = ACTIONS(5338),
    [anon_sym_noreturn] = ACTIONS(5338),
    [anon_sym_mutable] = ACTIONS(5338),
    [anon_sym_constinit] = ACTIONS(5338),
    [anon_sym_consteval] = ACTIONS(5338),
    [anon_sym_alignas] = ACTIONS(5338),
    [anon_sym__Alignas] = ACTIONS(5338),
    [sym_primitive_type] = ACTIONS(6062),
    [anon_sym_QMARK] = ACTIONS(5336),
    [anon_sym_LT_EQ_GT] = ACTIONS(5336),
    [anon_sym_or] = ACTIONS(5338),
    [anon_sym_and] = ACTIONS(5338),
    [anon_sym_bitor] = ACTIONS(5338),
    [anon_sym_xor] = ACTIONS(5338),
    [anon_sym_bitand] = ACTIONS(5338),
    [anon_sym_not_eq] = ACTIONS(5338),
    [anon_sym_DASH_DASH] = ACTIONS(5336),
    [anon_sym_PLUS_PLUS] = ACTIONS(5336),
    [anon_sym_DOT] = ACTIONS(5338),
    [anon_sym_DOT_STAR] = ACTIONS(5336),
    [anon_sym_DASH_GT] = ACTIONS(5336),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5338),
    [anon_sym_decltype] = ACTIONS(5338),
    [anon_sym_final] = ACTIONS(5338),
    [anon_sym_override] = ACTIONS(5338),
    [anon_sym_GT2] = ACTIONS(5336),
    [anon_sym_requires] = ACTIONS(5338),
  },
  [2572] = {
    [sym_attribute_specifier] = STATE(2638),
    [sym_identifier] = ACTIONS(5587),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5589),
    [anon_sym_COMMA] = ACTIONS(5589),
    [anon_sym_RPAREN] = ACTIONS(5589),
    [aux_sym_preproc_if_token2] = ACTIONS(5589),
    [aux_sym_preproc_else_token1] = ACTIONS(5589),
    [aux_sym_preproc_elif_token1] = ACTIONS(5587),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5589),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5589),
    [anon_sym_LPAREN2] = ACTIONS(5589),
    [anon_sym_DASH] = ACTIONS(5587),
    [anon_sym_PLUS] = ACTIONS(5587),
    [anon_sym_STAR] = ACTIONS(5587),
    [anon_sym_SLASH] = ACTIONS(5587),
    [anon_sym_PERCENT] = ACTIONS(5587),
    [anon_sym_PIPE_PIPE] = ACTIONS(5589),
    [anon_sym_AMP_AMP] = ACTIONS(5589),
    [anon_sym_PIPE] = ACTIONS(5587),
    [anon_sym_CARET] = ACTIONS(5587),
    [anon_sym_AMP] = ACTIONS(5587),
    [anon_sym_EQ_EQ] = ACTIONS(5589),
    [anon_sym_BANG_EQ] = ACTIONS(5589),
    [anon_sym_GT] = ACTIONS(5587),
    [anon_sym_GT_EQ] = ACTIONS(5589),
    [anon_sym_LT_EQ] = ACTIONS(5587),
    [anon_sym_LT] = ACTIONS(5587),
    [anon_sym_LT_LT] = ACTIONS(5587),
    [anon_sym_GT_GT] = ACTIONS(5587),
    [anon_sym_COLON] = ACTIONS(5589),
    [anon_sym_SEMI] = ACTIONS(5589),
    [anon_sym___attribute__] = ACTIONS(5815),
    [anon_sym_LBRACE] = ACTIONS(5589),
    [anon_sym_RBRACE] = ACTIONS(5589),
    [anon_sym_LBRACK] = ACTIONS(5589),
    [anon_sym_RBRACK] = ACTIONS(5589),
    [anon_sym_EQ] = ACTIONS(5587),
    [anon_sym_QMARK] = ACTIONS(5589),
    [anon_sym_STAR_EQ] = ACTIONS(5589),
    [anon_sym_SLASH_EQ] = ACTIONS(5589),
    [anon_sym_PERCENT_EQ] = ACTIONS(5589),
    [anon_sym_PLUS_EQ] = ACTIONS(5589),
    [anon_sym_DASH_EQ] = ACTIONS(5589),
    [anon_sym_LT_LT_EQ] = ACTIONS(5589),
    [anon_sym_GT_GT_EQ] = ACTIONS(5589),
    [anon_sym_AMP_EQ] = ACTIONS(5589),
    [anon_sym_CARET_EQ] = ACTIONS(5589),
    [anon_sym_PIPE_EQ] = ACTIONS(5589),
    [anon_sym_and_eq] = ACTIONS(5587),
    [anon_sym_or_eq] = ACTIONS(5587),
    [anon_sym_xor_eq] = ACTIONS(5587),
    [anon_sym_LT_EQ_GT] = ACTIONS(5589),
    [anon_sym_or] = ACTIONS(5587),
    [anon_sym_and] = ACTIONS(5587),
    [anon_sym_bitor] = ACTIONS(5587),
    [anon_sym_xor] = ACTIONS(5587),
    [anon_sym_bitand] = ACTIONS(5587),
    [anon_sym_not_eq] = ACTIONS(5587),
    [anon_sym_DASH_DASH] = ACTIONS(5589),
    [anon_sym_PLUS_PLUS] = ACTIONS(5589),
    [anon_sym_DOT] = ACTIONS(5587),
    [anon_sym_DOT_STAR] = ACTIONS(5589),
    [anon_sym_DASH_GT] = ACTIONS(5589),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5587),
    [anon_sym_decltype] = ACTIONS(5587),
  },
  [2573] = {
    [sym_template_argument_list] = STATE(2489),
    [aux_sym_sized_type_specifier_repeat1] = STATE(2689),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3830),
    [anon_sym_COMMA] = ACTIONS(3830),
    [anon_sym_RPAREN] = ACTIONS(3830),
    [anon_sym_LPAREN2] = ACTIONS(3830),
    [anon_sym_DASH] = ACTIONS(3822),
    [anon_sym_PLUS] = ACTIONS(3822),
    [anon_sym_STAR] = ACTIONS(3822),
    [anon_sym_SLASH] = ACTIONS(3822),
    [anon_sym_PERCENT] = ACTIONS(3822),
    [anon_sym_PIPE_PIPE] = ACTIONS(3830),
    [anon_sym_AMP_AMP] = ACTIONS(3830),
    [anon_sym_PIPE] = ACTIONS(3822),
    [anon_sym_CARET] = ACTIONS(3822),
    [anon_sym_AMP] = ACTIONS(3822),
    [anon_sym_EQ_EQ] = ACTIONS(3830),
    [anon_sym_BANG_EQ] = ACTIONS(3830),
    [anon_sym_GT] = ACTIONS(3822),
    [anon_sym_GT_EQ] = ACTIONS(3830),
    [anon_sym_LT_EQ] = ACTIONS(3822),
    [anon_sym_LT] = ACTIONS(5866),
    [anon_sym_LT_LT] = ACTIONS(3822),
    [anon_sym_GT_GT] = ACTIONS(3822),
    [anon_sym_COLON] = ACTIONS(3822),
    [anon_sym_SEMI] = ACTIONS(3830),
    [anon_sym___attribute__] = ACTIONS(3830),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(3830),
    [anon_sym_RBRACE] = ACTIONS(3830),
    [anon_sym_signed] = ACTIONS(6019),
    [anon_sym_unsigned] = ACTIONS(6019),
    [anon_sym_long] = ACTIONS(6019),
    [anon_sym_short] = ACTIONS(6019),
    [anon_sym_LBRACK] = ACTIONS(3830),
    [anon_sym_RBRACK] = ACTIONS(3830),
    [anon_sym_EQ] = ACTIONS(3822),
    [anon_sym_QMARK] = ACTIONS(3830),
    [anon_sym_STAR_EQ] = ACTIONS(3830),
    [anon_sym_SLASH_EQ] = ACTIONS(3830),
    [anon_sym_PERCENT_EQ] = ACTIONS(3830),
    [anon_sym_PLUS_EQ] = ACTIONS(3830),
    [anon_sym_DASH_EQ] = ACTIONS(3830),
    [anon_sym_LT_LT_EQ] = ACTIONS(3830),
    [anon_sym_GT_GT_EQ] = ACTIONS(3830),
    [anon_sym_AMP_EQ] = ACTIONS(3830),
    [anon_sym_CARET_EQ] = ACTIONS(3830),
    [anon_sym_PIPE_EQ] = ACTIONS(3830),
    [anon_sym_and_eq] = ACTIONS(3830),
    [anon_sym_or_eq] = ACTIONS(3830),
    [anon_sym_xor_eq] = ACTIONS(3830),
    [anon_sym_LT_EQ_GT] = ACTIONS(3830),
    [anon_sym_or] = ACTIONS(3822),
    [anon_sym_and] = ACTIONS(3822),
    [anon_sym_bitor] = ACTIONS(3830),
    [anon_sym_xor] = ACTIONS(3822),
    [anon_sym_bitand] = ACTIONS(3830),
    [anon_sym_not_eq] = ACTIONS(3830),
    [anon_sym_DASH_DASH] = ACTIONS(3830),
    [anon_sym_PLUS_PLUS] = ACTIONS(3830),
    [anon_sym_DOT] = ACTIONS(3822),
    [anon_sym_DOT_STAR] = ACTIONS(3830),
    [anon_sym_DASH_GT] = ACTIONS(3830),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(3830),
    [anon_sym_decltype] = ACTIONS(3830),
  },
  [2574] = {
    [sym_ms_based_modifier] = STATE(8703),
    [sym_ms_unaligned_ptr_modifier] = STATE(4205),
    [sym_ms_pointer_modifier] = STATE(4067),
    [sym__declarator] = STATE(5886),
    [sym__abstract_declarator] = STATE(6598),
    [sym_parenthesized_declarator] = STATE(6270),
    [sym_abstract_parenthesized_declarator] = STATE(6033),
    [sym_attributed_declarator] = STATE(6270),
    [sym_pointer_declarator] = STATE(6270),
    [sym_abstract_pointer_declarator] = STATE(6033),
    [sym_function_declarator] = STATE(6270),
    [sym_abstract_function_declarator] = STATE(6033),
    [sym_array_declarator] = STATE(6270),
    [sym_abstract_array_declarator] = STATE(6033),
    [sym_type_qualifier] = STATE(2978),
    [sym_alignas_qualifier] = STATE(4472),
    [sym_parameter_list] = STATE(3745),
    [sym_decltype] = STATE(8571),
    [sym_reference_declarator] = STATE(6270),
    [sym_abstract_reference_declarator] = STATE(6033),
    [sym_structured_binding_declarator] = STATE(6270),
    [sym__function_declarator_seq] = STATE(6076),
    [sym_template_type] = STATE(8571),
    [sym_template_function] = STATE(6270),
    [sym_destructor_name] = STATE(6270),
    [sym_dependent_type_identifier] = STATE(8571),
    [sym__scope_resolution] = STATE(5644),
    [sym_qualified_identifier] = STATE(6270),
    [sym_operator_name] = STATE(6270),
    [aux_sym__type_definition_type_repeat1] = STATE(2978),
    [aux_sym_pointer_declarator_repeat1] = STATE(4067),
    [sym_identifier] = ACTIONS(5889),
    [anon_sym_COMMA] = ACTIONS(5905),
    [anon_sym_LPAREN2] = ACTIONS(3934),
    [anon_sym_TILDE] = ACTIONS(2603),
    [anon_sym_STAR] = ACTIONS(6031),
    [anon_sym_AMP_AMP] = ACTIONS(6033),
    [anon_sym_AMP] = ACTIONS(6035),
    [anon_sym_COLON] = ACTIONS(5907),
    [anon_sym___extension__] = ACTIONS(3904),
    [anon_sym_COLON_COLON] = ACTIONS(5901),
    [anon_sym___based] = ACTIONS(49),
    [sym_ms_restrict_modifier] = ACTIONS(3906),
    [sym_ms_unsigned_ptr_modifier] = ACTIONS(3906),
    [sym_ms_signed_ptr_modifier] = ACTIONS(3906),
    [anon_sym__unaligned] = ACTIONS(3908),
    [anon_sym___unaligned] = ACTIONS(3908),
    [anon_sym_LBRACK] = ACTIONS(5903),
    [anon_sym_const] = ACTIONS(3904),
    [anon_sym_constexpr] = ACTIONS(3904),
    [anon_sym_volatile] = ACTIONS(3904),
    [anon_sym_restrict] = ACTIONS(3904),
    [anon_sym___restrict__] = ACTIONS(3904),
    [anon_sym__Atomic] = ACTIONS(3904),
    [anon_sym__Noreturn] = ACTIONS(3904),
    [anon_sym_noreturn] = ACTIONS(3904),
    [anon_sym_mutable] = ACTIONS(3904),
    [anon_sym_constinit] = ACTIONS(3904),
    [anon_sym_consteval] = ACTIONS(3904),
    [anon_sym_alignas] = ACTIONS(3910),
    [anon_sym__Alignas] = ACTIONS(3910),
    [sym_comment] = ACTIONS(3),
    [anon_sym_decltype] = ACTIONS(2855),
    [anon_sym_template] = ACTIONS(1266),
    [anon_sym_GT2] = ACTIONS(5905),
    [anon_sym_operator] = ACTIONS(2078),
  },
  [2575] = {
    [sym_attribute_declaration] = STATE(2642),
    [sym_parameter_list] = STATE(2652),
    [aux_sym_attributed_declarator_repeat1] = STATE(2642),
    [sym_identifier] = ACTIONS(6064),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6066),
    [anon_sym_COMMA] = ACTIONS(6066),
    [anon_sym_RPAREN] = ACTIONS(6066),
    [aux_sym_preproc_if_token2] = ACTIONS(6066),
    [aux_sym_preproc_else_token1] = ACTIONS(6066),
    [aux_sym_preproc_elif_token1] = ACTIONS(6064),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6066),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6066),
    [anon_sym_LPAREN2] = ACTIONS(5984),
    [anon_sym_DASH] = ACTIONS(6064),
    [anon_sym_PLUS] = ACTIONS(6064),
    [anon_sym_STAR] = ACTIONS(6064),
    [anon_sym_SLASH] = ACTIONS(6064),
    [anon_sym_PERCENT] = ACTIONS(6064),
    [anon_sym_PIPE_PIPE] = ACTIONS(6066),
    [anon_sym_AMP_AMP] = ACTIONS(6066),
    [anon_sym_PIPE] = ACTIONS(6064),
    [anon_sym_CARET] = ACTIONS(6064),
    [anon_sym_AMP] = ACTIONS(6064),
    [anon_sym_EQ_EQ] = ACTIONS(6066),
    [anon_sym_BANG_EQ] = ACTIONS(6066),
    [anon_sym_GT] = ACTIONS(6064),
    [anon_sym_GT_EQ] = ACTIONS(6066),
    [anon_sym_LT_EQ] = ACTIONS(6064),
    [anon_sym_LT] = ACTIONS(6064),
    [anon_sym_LT_LT] = ACTIONS(6064),
    [anon_sym_GT_GT] = ACTIONS(6064),
    [anon_sym_COLON] = ACTIONS(6066),
    [anon_sym_SEMI] = ACTIONS(6066),
    [anon_sym___attribute__] = ACTIONS(6064),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5986),
    [anon_sym_RBRACE] = ACTIONS(6066),
    [anon_sym_LBRACK] = ACTIONS(5988),
    [anon_sym_RBRACK] = ACTIONS(6066),
    [anon_sym_EQ] = ACTIONS(6064),
    [anon_sym_QMARK] = ACTIONS(6066),
    [anon_sym_STAR_EQ] = ACTIONS(6066),
    [anon_sym_SLASH_EQ] = ACTIONS(6066),
    [anon_sym_PERCENT_EQ] = ACTIONS(6066),
    [anon_sym_PLUS_EQ] = ACTIONS(6066),
    [anon_sym_DASH_EQ] = ACTIONS(6066),
    [anon_sym_LT_LT_EQ] = ACTIONS(6066),
    [anon_sym_GT_GT_EQ] = ACTIONS(6066),
    [anon_sym_AMP_EQ] = ACTIONS(6066),
    [anon_sym_CARET_EQ] = ACTIONS(6066),
    [anon_sym_PIPE_EQ] = ACTIONS(6066),
    [anon_sym_and_eq] = ACTIONS(6064),
    [anon_sym_or_eq] = ACTIONS(6064),
    [anon_sym_xor_eq] = ACTIONS(6064),
    [anon_sym_LT_EQ_GT] = ACTIONS(6066),
    [anon_sym_or] = ACTIONS(6064),
    [anon_sym_and] = ACTIONS(6064),
    [anon_sym_bitor] = ACTIONS(6064),
    [anon_sym_xor] = ACTIONS(6064),
    [anon_sym_bitand] = ACTIONS(6064),
    [anon_sym_not_eq] = ACTIONS(6064),
    [anon_sym_DASH_DASH] = ACTIONS(6066),
    [anon_sym_PLUS_PLUS] = ACTIONS(6066),
    [anon_sym_DOT] = ACTIONS(6064),
    [anon_sym_DOT_STAR] = ACTIONS(6066),
    [anon_sym_DASH_GT] = ACTIONS(6066),
    [sym_comment] = ACTIONS(3),
  },
  [2576] = {
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5798),
    [anon_sym_COMMA] = ACTIONS(5798),
    [anon_sym_RPAREN] = ACTIONS(5798),
    [anon_sym_LPAREN2] = ACTIONS(5798),
    [anon_sym_DASH] = ACTIONS(5796),
    [anon_sym_PLUS] = ACTIONS(5796),
    [anon_sym_STAR] = ACTIONS(5796),
    [anon_sym_SLASH] = ACTIONS(5796),
    [anon_sym_PERCENT] = ACTIONS(5796),
    [anon_sym_PIPE_PIPE] = ACTIONS(5798),
    [anon_sym_AMP_AMP] = ACTIONS(5798),
    [anon_sym_PIPE] = ACTIONS(5796),
    [anon_sym_CARET] = ACTIONS(5796),
    [anon_sym_AMP] = ACTIONS(5796),
    [anon_sym_EQ_EQ] = ACTIONS(5798),
    [anon_sym_BANG_EQ] = ACTIONS(5798),
    [anon_sym_GT] = ACTIONS(5796),
    [anon_sym_GT_EQ] = ACTIONS(5798),
    [anon_sym_LT_EQ] = ACTIONS(5796),
    [anon_sym_LT] = ACTIONS(5796),
    [anon_sym_LT_LT] = ACTIONS(5796),
    [anon_sym_GT_GT] = ACTIONS(5796),
    [anon_sym_COLON] = ACTIONS(5798),
    [anon_sym_SEMI] = ACTIONS(5798),
    [anon_sym_RBRACE] = ACTIONS(5798),
    [anon_sym_LBRACK] = ACTIONS(5798),
    [anon_sym_RBRACK] = ACTIONS(5798),
    [anon_sym_EQ] = ACTIONS(5796),
    [anon_sym_QMARK] = ACTIONS(5798),
    [anon_sym_STAR_EQ] = ACTIONS(5798),
    [anon_sym_SLASH_EQ] = ACTIONS(5798),
    [anon_sym_PERCENT_EQ] = ACTIONS(5798),
    [anon_sym_PLUS_EQ] = ACTIONS(5798),
    [anon_sym_DASH_EQ] = ACTIONS(5798),
    [anon_sym_LT_LT_EQ] = ACTIONS(5798),
    [anon_sym_GT_GT_EQ] = ACTIONS(5798),
    [anon_sym_AMP_EQ] = ACTIONS(5798),
    [anon_sym_CARET_EQ] = ACTIONS(5798),
    [anon_sym_PIPE_EQ] = ACTIONS(5798),
    [anon_sym_and_eq] = ACTIONS(5796),
    [anon_sym_or_eq] = ACTIONS(5796),
    [anon_sym_xor_eq] = ACTIONS(5796),
    [anon_sym_LT_EQ_GT] = ACTIONS(5798),
    [anon_sym_or] = ACTIONS(5796),
    [anon_sym_and] = ACTIONS(5796),
    [anon_sym_bitor] = ACTIONS(5796),
    [anon_sym_xor] = ACTIONS(5796),
    [anon_sym_bitand] = ACTIONS(5796),
    [anon_sym_not_eq] = ACTIONS(5796),
    [anon_sym_DASH_DASH] = ACTIONS(5798),
    [anon_sym_PLUS_PLUS] = ACTIONS(5798),
    [anon_sym_DOT] = ACTIONS(5796),
    [anon_sym_DOT_STAR] = ACTIONS(5798),
    [anon_sym_DASH_GT] = ACTIONS(5798),
    [anon_sym_L_DQUOTE] = ACTIONS(5798),
    [anon_sym_u_DQUOTE] = ACTIONS(5798),
    [anon_sym_U_DQUOTE] = ACTIONS(5798),
    [anon_sym_u8_DQUOTE] = ACTIONS(5798),
    [anon_sym_DQUOTE] = ACTIONS(5798),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5798),
    [anon_sym_LR_DQUOTE] = ACTIONS(5798),
    [anon_sym_uR_DQUOTE] = ACTIONS(5798),
    [anon_sym_UR_DQUOTE] = ACTIONS(5798),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5798),
    [sym_literal_suffix] = ACTIONS(5796),
  },
  [2577] = {
    [sym_template_argument_list] = STATE(2441),
    [sym_identifier] = ACTIONS(1933),
    [anon_sym_LPAREN2] = ACTIONS(4047),
    [anon_sym_TILDE] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1935),
    [anon_sym_AMP_AMP] = ACTIONS(1935),
    [anon_sym_AMP] = ACTIONS(1933),
    [anon_sym_LT] = ACTIONS(5298),
    [anon_sym_SEMI] = ACTIONS(4045),
    [anon_sym___extension__] = ACTIONS(1933),
    [anon_sym_in] = ACTIONS(1933),
    [anon_sym_out] = ACTIONS(1933),
    [anon_sym_inout] = ACTIONS(1933),
    [anon_sym_extern] = ACTIONS(1933),
    [anon_sym___attribute__] = ACTIONS(1933),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(4047),
    [anon_sym___declspec] = ACTIONS(1933),
    [anon_sym___based] = ACTIONS(1933),
    [anon_sym_LBRACK] = ACTIONS(4052),
    [anon_sym_static] = ACTIONS(1933),
    [anon_sym_register] = ACTIONS(1933),
    [anon_sym_inline] = ACTIONS(1933),
    [anon_sym___inline] = ACTIONS(1933),
    [anon_sym___inline__] = ACTIONS(1933),
    [anon_sym___forceinline] = ACTIONS(1933),
    [anon_sym_thread_local] = ACTIONS(1933),
    [anon_sym___thread] = ACTIONS(1933),
    [anon_sym_const] = ACTIONS(1933),
    [anon_sym_constexpr] = ACTIONS(1933),
    [anon_sym_volatile] = ACTIONS(1933),
    [anon_sym_restrict] = ACTIONS(1933),
    [anon_sym___restrict__] = ACTIONS(1933),
    [anon_sym__Atomic] = ACTIONS(1933),
    [anon_sym__Noreturn] = ACTIONS(1933),
    [anon_sym_noreturn] = ACTIONS(1933),
    [anon_sym_mutable] = ACTIONS(1933),
    [anon_sym_constinit] = ACTIONS(1933),
    [anon_sym_consteval] = ACTIONS(1933),
    [anon_sym_alignas] = ACTIONS(1933),
    [anon_sym__Alignas] = ACTIONS(1933),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(1933),
    [anon_sym_decltype] = ACTIONS(1933),
    [sym_virtual] = ACTIONS(1933),
    [anon_sym_template] = ACTIONS(1933),
    [anon_sym_operator] = ACTIONS(1933),
    [anon_sym_precise] = ACTIONS(1933),
    [anon_sym_shared] = ACTIONS(1933),
    [anon_sym_groupshared] = ACTIONS(1933),
    [anon_sym_uniform] = ACTIONS(1933),
    [anon_sym_row_major] = ACTIONS(1933),
    [anon_sym_column_major] = ACTIONS(1933),
    [anon_sym_globallycoherent] = ACTIONS(1933),
    [anon_sym_centroid] = ACTIONS(1933),
    [anon_sym_noperspective] = ACTIONS(1933),
    [anon_sym_nointerpolation] = ACTIONS(1933),
    [anon_sym_sample] = ACTIONS(1933),
    [anon_sym_linear] = ACTIONS(1933),
    [anon_sym_snorm] = ACTIONS(1933),
    [anon_sym_unorm] = ACTIONS(1933),
    [anon_sym_point] = ACTIONS(1933),
    [anon_sym_line] = ACTIONS(1933),
    [anon_sym_triangleadj] = ACTIONS(1933),
    [anon_sym_lineadj] = ACTIONS(1933),
    [anon_sym_triangle] = ACTIONS(1933),
  },
  [2578] = {
    [sym_attribute_specifier] = STATE(2604),
    [sym_identifier] = ACTIONS(5579),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5581),
    [anon_sym_COMMA] = ACTIONS(5581),
    [anon_sym_RPAREN] = ACTIONS(5581),
    [aux_sym_preproc_if_token2] = ACTIONS(5581),
    [aux_sym_preproc_else_token1] = ACTIONS(5581),
    [aux_sym_preproc_elif_token1] = ACTIONS(5579),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5581),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5581),
    [anon_sym_LPAREN2] = ACTIONS(5581),
    [anon_sym_DASH] = ACTIONS(5579),
    [anon_sym_PLUS] = ACTIONS(5579),
    [anon_sym_STAR] = ACTIONS(5579),
    [anon_sym_SLASH] = ACTIONS(5579),
    [anon_sym_PERCENT] = ACTIONS(5579),
    [anon_sym_PIPE_PIPE] = ACTIONS(5581),
    [anon_sym_AMP_AMP] = ACTIONS(5581),
    [anon_sym_PIPE] = ACTIONS(5579),
    [anon_sym_CARET] = ACTIONS(5579),
    [anon_sym_AMP] = ACTIONS(5579),
    [anon_sym_EQ_EQ] = ACTIONS(5581),
    [anon_sym_BANG_EQ] = ACTIONS(5581),
    [anon_sym_GT] = ACTIONS(5579),
    [anon_sym_GT_EQ] = ACTIONS(5581),
    [anon_sym_LT_EQ] = ACTIONS(5579),
    [anon_sym_LT] = ACTIONS(5579),
    [anon_sym_LT_LT] = ACTIONS(5579),
    [anon_sym_GT_GT] = ACTIONS(5579),
    [anon_sym_COLON] = ACTIONS(5581),
    [anon_sym_SEMI] = ACTIONS(5581),
    [anon_sym___attribute__] = ACTIONS(5815),
    [anon_sym_LBRACE] = ACTIONS(5581),
    [anon_sym_RBRACE] = ACTIONS(5581),
    [anon_sym_LBRACK] = ACTIONS(5581),
    [anon_sym_RBRACK] = ACTIONS(5581),
    [anon_sym_EQ] = ACTIONS(5579),
    [anon_sym_QMARK] = ACTIONS(5581),
    [anon_sym_STAR_EQ] = ACTIONS(5581),
    [anon_sym_SLASH_EQ] = ACTIONS(5581),
    [anon_sym_PERCENT_EQ] = ACTIONS(5581),
    [anon_sym_PLUS_EQ] = ACTIONS(5581),
    [anon_sym_DASH_EQ] = ACTIONS(5581),
    [anon_sym_LT_LT_EQ] = ACTIONS(5581),
    [anon_sym_GT_GT_EQ] = ACTIONS(5581),
    [anon_sym_AMP_EQ] = ACTIONS(5581),
    [anon_sym_CARET_EQ] = ACTIONS(5581),
    [anon_sym_PIPE_EQ] = ACTIONS(5581),
    [anon_sym_and_eq] = ACTIONS(5579),
    [anon_sym_or_eq] = ACTIONS(5579),
    [anon_sym_xor_eq] = ACTIONS(5579),
    [anon_sym_LT_EQ_GT] = ACTIONS(5581),
    [anon_sym_or] = ACTIONS(5579),
    [anon_sym_and] = ACTIONS(5579),
    [anon_sym_bitor] = ACTIONS(5579),
    [anon_sym_xor] = ACTIONS(5579),
    [anon_sym_bitand] = ACTIONS(5579),
    [anon_sym_not_eq] = ACTIONS(5579),
    [anon_sym_DASH_DASH] = ACTIONS(5581),
    [anon_sym_PLUS_PLUS] = ACTIONS(5581),
    [anon_sym_DOT] = ACTIONS(5579),
    [anon_sym_DOT_STAR] = ACTIONS(5581),
    [anon_sym_DASH_GT] = ACTIONS(5581),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5579),
    [anon_sym_decltype] = ACTIONS(5579),
  },
  [2579] = {
    [sym_attribute_specifier] = STATE(2633),
    [sym_identifier] = ACTIONS(5583),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5585),
    [anon_sym_COMMA] = ACTIONS(5585),
    [anon_sym_RPAREN] = ACTIONS(5585),
    [aux_sym_preproc_if_token2] = ACTIONS(5585),
    [aux_sym_preproc_else_token1] = ACTIONS(5585),
    [aux_sym_preproc_elif_token1] = ACTIONS(5583),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5585),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5585),
    [anon_sym_LPAREN2] = ACTIONS(5585),
    [anon_sym_DASH] = ACTIONS(5583),
    [anon_sym_PLUS] = ACTIONS(5583),
    [anon_sym_STAR] = ACTIONS(5583),
    [anon_sym_SLASH] = ACTIONS(5583),
    [anon_sym_PERCENT] = ACTIONS(5583),
    [anon_sym_PIPE_PIPE] = ACTIONS(5585),
    [anon_sym_AMP_AMP] = ACTIONS(5585),
    [anon_sym_PIPE] = ACTIONS(5583),
    [anon_sym_CARET] = ACTIONS(5583),
    [anon_sym_AMP] = ACTIONS(5583),
    [anon_sym_EQ_EQ] = ACTIONS(5585),
    [anon_sym_BANG_EQ] = ACTIONS(5585),
    [anon_sym_GT] = ACTIONS(5583),
    [anon_sym_GT_EQ] = ACTIONS(5585),
    [anon_sym_LT_EQ] = ACTIONS(5583),
    [anon_sym_LT] = ACTIONS(5583),
    [anon_sym_LT_LT] = ACTIONS(5583),
    [anon_sym_GT_GT] = ACTIONS(5583),
    [anon_sym_COLON] = ACTIONS(5585),
    [anon_sym_SEMI] = ACTIONS(5585),
    [anon_sym___attribute__] = ACTIONS(5815),
    [anon_sym_LBRACE] = ACTIONS(5585),
    [anon_sym_RBRACE] = ACTIONS(5585),
    [anon_sym_LBRACK] = ACTIONS(5585),
    [anon_sym_RBRACK] = ACTIONS(5585),
    [anon_sym_EQ] = ACTIONS(5583),
    [anon_sym_QMARK] = ACTIONS(5585),
    [anon_sym_STAR_EQ] = ACTIONS(5585),
    [anon_sym_SLASH_EQ] = ACTIONS(5585),
    [anon_sym_PERCENT_EQ] = ACTIONS(5585),
    [anon_sym_PLUS_EQ] = ACTIONS(5585),
    [anon_sym_DASH_EQ] = ACTIONS(5585),
    [anon_sym_LT_LT_EQ] = ACTIONS(5585),
    [anon_sym_GT_GT_EQ] = ACTIONS(5585),
    [anon_sym_AMP_EQ] = ACTIONS(5585),
    [anon_sym_CARET_EQ] = ACTIONS(5585),
    [anon_sym_PIPE_EQ] = ACTIONS(5585),
    [anon_sym_and_eq] = ACTIONS(5583),
    [anon_sym_or_eq] = ACTIONS(5583),
    [anon_sym_xor_eq] = ACTIONS(5583),
    [anon_sym_LT_EQ_GT] = ACTIONS(5585),
    [anon_sym_or] = ACTIONS(5583),
    [anon_sym_and] = ACTIONS(5583),
    [anon_sym_bitor] = ACTIONS(5583),
    [anon_sym_xor] = ACTIONS(5583),
    [anon_sym_bitand] = ACTIONS(5583),
    [anon_sym_not_eq] = ACTIONS(5583),
    [anon_sym_DASH_DASH] = ACTIONS(5585),
    [anon_sym_PLUS_PLUS] = ACTIONS(5585),
    [anon_sym_DOT] = ACTIONS(5583),
    [anon_sym_DOT_STAR] = ACTIONS(5585),
    [anon_sym_DASH_GT] = ACTIONS(5585),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5583),
    [anon_sym_decltype] = ACTIONS(5583),
  },
  [2580] = {
    [sym_attribute_specifier] = STATE(2641),
    [sym_identifier] = ACTIONS(5606),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5608),
    [anon_sym_COMMA] = ACTIONS(5608),
    [anon_sym_RPAREN] = ACTIONS(5608),
    [aux_sym_preproc_if_token2] = ACTIONS(5608),
    [aux_sym_preproc_else_token1] = ACTIONS(5608),
    [aux_sym_preproc_elif_token1] = ACTIONS(5606),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5608),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5608),
    [anon_sym_LPAREN2] = ACTIONS(5608),
    [anon_sym_DASH] = ACTIONS(5606),
    [anon_sym_PLUS] = ACTIONS(5606),
    [anon_sym_STAR] = ACTIONS(5606),
    [anon_sym_SLASH] = ACTIONS(5606),
    [anon_sym_PERCENT] = ACTIONS(5606),
    [anon_sym_PIPE_PIPE] = ACTIONS(5608),
    [anon_sym_AMP_AMP] = ACTIONS(5608),
    [anon_sym_PIPE] = ACTIONS(5606),
    [anon_sym_CARET] = ACTIONS(5606),
    [anon_sym_AMP] = ACTIONS(5606),
    [anon_sym_EQ_EQ] = ACTIONS(5608),
    [anon_sym_BANG_EQ] = ACTIONS(5608),
    [anon_sym_GT] = ACTIONS(5606),
    [anon_sym_GT_EQ] = ACTIONS(5608),
    [anon_sym_LT_EQ] = ACTIONS(5606),
    [anon_sym_LT] = ACTIONS(5606),
    [anon_sym_LT_LT] = ACTIONS(5606),
    [anon_sym_GT_GT] = ACTIONS(5606),
    [anon_sym_COLON] = ACTIONS(5608),
    [anon_sym_SEMI] = ACTIONS(5608),
    [anon_sym___attribute__] = ACTIONS(5815),
    [anon_sym_LBRACE] = ACTIONS(5608),
    [anon_sym_RBRACE] = ACTIONS(5608),
    [anon_sym_LBRACK] = ACTIONS(5608),
    [anon_sym_RBRACK] = ACTIONS(5608),
    [anon_sym_EQ] = ACTIONS(5606),
    [anon_sym_QMARK] = ACTIONS(5608),
    [anon_sym_STAR_EQ] = ACTIONS(5608),
    [anon_sym_SLASH_EQ] = ACTIONS(5608),
    [anon_sym_PERCENT_EQ] = ACTIONS(5608),
    [anon_sym_PLUS_EQ] = ACTIONS(5608),
    [anon_sym_DASH_EQ] = ACTIONS(5608),
    [anon_sym_LT_LT_EQ] = ACTIONS(5608),
    [anon_sym_GT_GT_EQ] = ACTIONS(5608),
    [anon_sym_AMP_EQ] = ACTIONS(5608),
    [anon_sym_CARET_EQ] = ACTIONS(5608),
    [anon_sym_PIPE_EQ] = ACTIONS(5608),
    [anon_sym_and_eq] = ACTIONS(5606),
    [anon_sym_or_eq] = ACTIONS(5606),
    [anon_sym_xor_eq] = ACTIONS(5606),
    [anon_sym_LT_EQ_GT] = ACTIONS(5608),
    [anon_sym_or] = ACTIONS(5606),
    [anon_sym_and] = ACTIONS(5606),
    [anon_sym_bitor] = ACTIONS(5606),
    [anon_sym_xor] = ACTIONS(5606),
    [anon_sym_bitand] = ACTIONS(5606),
    [anon_sym_not_eq] = ACTIONS(5606),
    [anon_sym_DASH_DASH] = ACTIONS(5608),
    [anon_sym_PLUS_PLUS] = ACTIONS(5608),
    [anon_sym_DOT] = ACTIONS(5606),
    [anon_sym_DOT_STAR] = ACTIONS(5608),
    [anon_sym_DASH_GT] = ACTIONS(5608),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5606),
    [anon_sym_decltype] = ACTIONS(5606),
  },
  [2581] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2581),
    [sym_identifier] = ACTIONS(5224),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5226),
    [anon_sym_COMMA] = ACTIONS(5226),
    [anon_sym_LPAREN2] = ACTIONS(5226),
    [anon_sym_DASH] = ACTIONS(5224),
    [anon_sym_PLUS] = ACTIONS(5224),
    [anon_sym_STAR] = ACTIONS(5226),
    [anon_sym_SLASH] = ACTIONS(5224),
    [anon_sym_PERCENT] = ACTIONS(5226),
    [anon_sym_PIPE_PIPE] = ACTIONS(5226),
    [anon_sym_AMP_AMP] = ACTIONS(5226),
    [anon_sym_PIPE] = ACTIONS(5224),
    [anon_sym_CARET] = ACTIONS(5226),
    [anon_sym_AMP] = ACTIONS(5224),
    [anon_sym_EQ_EQ] = ACTIONS(5226),
    [anon_sym_BANG_EQ] = ACTIONS(5226),
    [anon_sym_GT] = ACTIONS(5224),
    [anon_sym_GT_EQ] = ACTIONS(5224),
    [anon_sym_LT_EQ] = ACTIONS(5224),
    [anon_sym_LT] = ACTIONS(5224),
    [anon_sym_LT_LT] = ACTIONS(5226),
    [anon_sym_GT_GT] = ACTIONS(5224),
    [anon_sym_COLON] = ACTIONS(5226),
    [anon_sym___extension__] = ACTIONS(5224),
    [anon_sym___attribute__] = ACTIONS(5224),
    [anon_sym_LBRACE] = ACTIONS(5226),
    [anon_sym_signed] = ACTIONS(6021),
    [anon_sym_unsigned] = ACTIONS(6021),
    [anon_sym_long] = ACTIONS(6021),
    [anon_sym_short] = ACTIONS(6021),
    [anon_sym_LBRACK] = ACTIONS(5226),
    [anon_sym_const] = ACTIONS(5224),
    [anon_sym_constexpr] = ACTIONS(5224),
    [anon_sym_volatile] = ACTIONS(5224),
    [anon_sym_restrict] = ACTIONS(5224),
    [anon_sym___restrict__] = ACTIONS(5224),
    [anon_sym__Atomic] = ACTIONS(5224),
    [anon_sym__Noreturn] = ACTIONS(5224),
    [anon_sym_noreturn] = ACTIONS(5224),
    [anon_sym_mutable] = ACTIONS(5224),
    [anon_sym_constinit] = ACTIONS(5224),
    [anon_sym_consteval] = ACTIONS(5224),
    [anon_sym_alignas] = ACTIONS(5224),
    [anon_sym__Alignas] = ACTIONS(5224),
    [sym_primitive_type] = ACTIONS(5224),
    [anon_sym_QMARK] = ACTIONS(5226),
    [anon_sym_LT_EQ_GT] = ACTIONS(5226),
    [anon_sym_or] = ACTIONS(5224),
    [anon_sym_and] = ACTIONS(5224),
    [anon_sym_bitor] = ACTIONS(5224),
    [anon_sym_xor] = ACTIONS(5224),
    [anon_sym_bitand] = ACTIONS(5224),
    [anon_sym_not_eq] = ACTIONS(5224),
    [anon_sym_DASH_DASH] = ACTIONS(5226),
    [anon_sym_PLUS_PLUS] = ACTIONS(5226),
    [anon_sym_DOT] = ACTIONS(5224),
    [anon_sym_DOT_STAR] = ACTIONS(5226),
    [anon_sym_DASH_GT] = ACTIONS(5226),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5224),
    [anon_sym_decltype] = ACTIONS(5224),
    [anon_sym_final] = ACTIONS(5224),
    [anon_sym_override] = ACTIONS(5224),
    [anon_sym_GT2] = ACTIONS(5226),
    [anon_sym_requires] = ACTIONS(5224),
  },
  [2582] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2408),
    [sym_identifier] = ACTIONS(5224),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5315),
    [anon_sym_COMMA] = ACTIONS(5315),
    [anon_sym_RPAREN] = ACTIONS(5315),
    [anon_sym_LPAREN2] = ACTIONS(5315),
    [anon_sym_DASH] = ACTIONS(5312),
    [anon_sym_PLUS] = ACTIONS(5312),
    [anon_sym_STAR] = ACTIONS(5312),
    [anon_sym_SLASH] = ACTIONS(5312),
    [anon_sym_PERCENT] = ACTIONS(5312),
    [anon_sym_PIPE_PIPE] = ACTIONS(5315),
    [anon_sym_AMP_AMP] = ACTIONS(5315),
    [anon_sym_PIPE] = ACTIONS(5312),
    [anon_sym_CARET] = ACTIONS(5312),
    [anon_sym_AMP] = ACTIONS(5312),
    [anon_sym_EQ_EQ] = ACTIONS(5315),
    [anon_sym_BANG_EQ] = ACTIONS(5315),
    [anon_sym_GT] = ACTIONS(5312),
    [anon_sym_GT_EQ] = ACTIONS(5315),
    [anon_sym_LT_EQ] = ACTIONS(5312),
    [anon_sym_LT] = ACTIONS(5312),
    [anon_sym_LT_LT] = ACTIONS(5312),
    [anon_sym_GT_GT] = ACTIONS(5312),
    [anon_sym_COLON] = ACTIONS(5315),
    [anon_sym_SEMI] = ACTIONS(5315),
    [anon_sym___attribute__] = ACTIONS(5312),
    [anon_sym_LBRACE] = ACTIONS(5315),
    [anon_sym_RBRACE] = ACTIONS(5315),
    [anon_sym_signed] = ACTIONS(5807),
    [anon_sym_unsigned] = ACTIONS(5807),
    [anon_sym_long] = ACTIONS(5807),
    [anon_sym_short] = ACTIONS(5807),
    [anon_sym_LBRACK] = ACTIONS(5315),
    [anon_sym_RBRACK] = ACTIONS(5315),
    [anon_sym_EQ] = ACTIONS(5312),
    [sym_primitive_type] = ACTIONS(5224),
    [anon_sym_QMARK] = ACTIONS(5315),
    [anon_sym_STAR_EQ] = ACTIONS(5315),
    [anon_sym_SLASH_EQ] = ACTIONS(5315),
    [anon_sym_PERCENT_EQ] = ACTIONS(5315),
    [anon_sym_PLUS_EQ] = ACTIONS(5315),
    [anon_sym_DASH_EQ] = ACTIONS(5315),
    [anon_sym_LT_LT_EQ] = ACTIONS(5315),
    [anon_sym_GT_GT_EQ] = ACTIONS(5315),
    [anon_sym_AMP_EQ] = ACTIONS(5315),
    [anon_sym_CARET_EQ] = ACTIONS(5315),
    [anon_sym_PIPE_EQ] = ACTIONS(5315),
    [anon_sym_and_eq] = ACTIONS(5312),
    [anon_sym_or_eq] = ACTIONS(5312),
    [anon_sym_xor_eq] = ACTIONS(5312),
    [anon_sym_LT_EQ_GT] = ACTIONS(5315),
    [anon_sym_or] = ACTIONS(5312),
    [anon_sym_and] = ACTIONS(5312),
    [anon_sym_bitor] = ACTIONS(5312),
    [anon_sym_xor] = ACTIONS(5312),
    [anon_sym_bitand] = ACTIONS(5312),
    [anon_sym_not_eq] = ACTIONS(5312),
    [anon_sym_DASH_DASH] = ACTIONS(5315),
    [anon_sym_PLUS_PLUS] = ACTIONS(5315),
    [anon_sym_DOT] = ACTIONS(5312),
    [anon_sym_DOT_STAR] = ACTIONS(5315),
    [anon_sym_DASH_GT] = ACTIONS(5315),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5312),
    [anon_sym_decltype] = ACTIONS(5312),
  },
  [2583] = {
    [sym_attribute_specifier] = STATE(2602),
    [sym_identifier] = ACTIONS(5591),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5593),
    [anon_sym_COMMA] = ACTIONS(5593),
    [anon_sym_RPAREN] = ACTIONS(5593),
    [aux_sym_preproc_if_token2] = ACTIONS(5593),
    [aux_sym_preproc_else_token1] = ACTIONS(5593),
    [aux_sym_preproc_elif_token1] = ACTIONS(5591),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5593),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5593),
    [anon_sym_LPAREN2] = ACTIONS(5593),
    [anon_sym_DASH] = ACTIONS(5591),
    [anon_sym_PLUS] = ACTIONS(5591),
    [anon_sym_STAR] = ACTIONS(5591),
    [anon_sym_SLASH] = ACTIONS(5591),
    [anon_sym_PERCENT] = ACTIONS(5591),
    [anon_sym_PIPE_PIPE] = ACTIONS(5593),
    [anon_sym_AMP_AMP] = ACTIONS(5593),
    [anon_sym_PIPE] = ACTIONS(5591),
    [anon_sym_CARET] = ACTIONS(5591),
    [anon_sym_AMP] = ACTIONS(5591),
    [anon_sym_EQ_EQ] = ACTIONS(5593),
    [anon_sym_BANG_EQ] = ACTIONS(5593),
    [anon_sym_GT] = ACTIONS(5591),
    [anon_sym_GT_EQ] = ACTIONS(5593),
    [anon_sym_LT_EQ] = ACTIONS(5591),
    [anon_sym_LT] = ACTIONS(5591),
    [anon_sym_LT_LT] = ACTIONS(5591),
    [anon_sym_GT_GT] = ACTIONS(5591),
    [anon_sym_COLON] = ACTIONS(5593),
    [anon_sym_SEMI] = ACTIONS(5593),
    [anon_sym___attribute__] = ACTIONS(5815),
    [anon_sym_LBRACE] = ACTIONS(5593),
    [anon_sym_RBRACE] = ACTIONS(5593),
    [anon_sym_LBRACK] = ACTIONS(5593),
    [anon_sym_RBRACK] = ACTIONS(5593),
    [anon_sym_EQ] = ACTIONS(5591),
    [anon_sym_QMARK] = ACTIONS(5593),
    [anon_sym_STAR_EQ] = ACTIONS(5593),
    [anon_sym_SLASH_EQ] = ACTIONS(5593),
    [anon_sym_PERCENT_EQ] = ACTIONS(5593),
    [anon_sym_PLUS_EQ] = ACTIONS(5593),
    [anon_sym_DASH_EQ] = ACTIONS(5593),
    [anon_sym_LT_LT_EQ] = ACTIONS(5593),
    [anon_sym_GT_GT_EQ] = ACTIONS(5593),
    [anon_sym_AMP_EQ] = ACTIONS(5593),
    [anon_sym_CARET_EQ] = ACTIONS(5593),
    [anon_sym_PIPE_EQ] = ACTIONS(5593),
    [anon_sym_and_eq] = ACTIONS(5591),
    [anon_sym_or_eq] = ACTIONS(5591),
    [anon_sym_xor_eq] = ACTIONS(5591),
    [anon_sym_LT_EQ_GT] = ACTIONS(5593),
    [anon_sym_or] = ACTIONS(5591),
    [anon_sym_and] = ACTIONS(5591),
    [anon_sym_bitor] = ACTIONS(5591),
    [anon_sym_xor] = ACTIONS(5591),
    [anon_sym_bitand] = ACTIONS(5591),
    [anon_sym_not_eq] = ACTIONS(5591),
    [anon_sym_DASH_DASH] = ACTIONS(5593),
    [anon_sym_PLUS_PLUS] = ACTIONS(5593),
    [anon_sym_DOT] = ACTIONS(5591),
    [anon_sym_DOT_STAR] = ACTIONS(5593),
    [anon_sym_DASH_GT] = ACTIONS(5593),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5591),
    [anon_sym_decltype] = ACTIONS(5591),
  },
  [2584] = {
    [sym_identifier] = ACTIONS(2849),
    [anon_sym___extension__] = ACTIONS(2849),
    [anon_sym_typedef] = ACTIONS(6068),
    [anon_sym_in] = ACTIONS(2849),
    [anon_sym_out] = ACTIONS(2849),
    [anon_sym_inout] = ACTIONS(2849),
    [anon_sym_extern] = ACTIONS(2849),
    [anon_sym___attribute__] = ACTIONS(2849),
    [anon_sym_COLON_COLON] = ACTIONS(2851),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2851),
    [anon_sym___declspec] = ACTIONS(2849),
    [anon_sym_signed] = ACTIONS(2849),
    [anon_sym_unsigned] = ACTIONS(2849),
    [anon_sym_long] = ACTIONS(2849),
    [anon_sym_short] = ACTIONS(2849),
    [anon_sym_static] = ACTIONS(2849),
    [anon_sym_register] = ACTIONS(2849),
    [anon_sym_inline] = ACTIONS(2849),
    [anon_sym___inline] = ACTIONS(2849),
    [anon_sym___inline__] = ACTIONS(2849),
    [anon_sym___forceinline] = ACTIONS(2849),
    [anon_sym_thread_local] = ACTIONS(2849),
    [anon_sym___thread] = ACTIONS(2849),
    [anon_sym_const] = ACTIONS(2849),
    [anon_sym_constexpr] = ACTIONS(2849),
    [anon_sym_volatile] = ACTIONS(2849),
    [anon_sym_restrict] = ACTIONS(2849),
    [anon_sym___restrict__] = ACTIONS(2849),
    [anon_sym__Atomic] = ACTIONS(2849),
    [anon_sym__Noreturn] = ACTIONS(2849),
    [anon_sym_noreturn] = ACTIONS(2849),
    [anon_sym_mutable] = ACTIONS(2849),
    [anon_sym_constinit] = ACTIONS(2849),
    [anon_sym_consteval] = ACTIONS(2849),
    [anon_sym_alignas] = ACTIONS(2849),
    [anon_sym__Alignas] = ACTIONS(2849),
    [sym_primitive_type] = ACTIONS(2849),
    [anon_sym_enum] = ACTIONS(2849),
    [anon_sym_class] = ACTIONS(2849),
    [anon_sym_struct] = ACTIONS(2849),
    [anon_sym_union] = ACTIONS(2849),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2849),
    [anon_sym_decltype] = ACTIONS(2849),
    [sym_virtual] = ACTIONS(2849),
    [anon_sym_typename] = ACTIONS(2849),
    [anon_sym_template] = ACTIONS(2849),
    [anon_sym_precise] = ACTIONS(2849),
    [anon_sym_shared] = ACTIONS(2849),
    [anon_sym_groupshared] = ACTIONS(2849),
    [anon_sym_uniform] = ACTIONS(2849),
    [anon_sym_row_major] = ACTIONS(2849),
    [anon_sym_column_major] = ACTIONS(2849),
    [anon_sym_globallycoherent] = ACTIONS(2849),
    [anon_sym_centroid] = ACTIONS(2849),
    [anon_sym_noperspective] = ACTIONS(2849),
    [anon_sym_nointerpolation] = ACTIONS(2849),
    [anon_sym_sample] = ACTIONS(2849),
    [anon_sym_linear] = ACTIONS(2849),
    [anon_sym_snorm] = ACTIONS(2849),
    [anon_sym_unorm] = ACTIONS(2849),
    [anon_sym_point] = ACTIONS(2849),
    [anon_sym_line] = ACTIONS(2849),
    [anon_sym_triangleadj] = ACTIONS(2849),
    [anon_sym_lineadj] = ACTIONS(2849),
    [anon_sym_triangle] = ACTIONS(2849),
  },
  [2585] = {
    [sym_attribute_specifier] = STATE(2482),
    [sym_field_declaration_list] = STATE(2720),
    [sym_virtual_specifier] = STATE(6756),
    [sym_base_class_clause] = STATE(7544),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5329),
    [anon_sym_COMMA] = ACTIONS(5329),
    [anon_sym_RPAREN] = ACTIONS(5329),
    [anon_sym_LPAREN2] = ACTIONS(5329),
    [anon_sym_DASH] = ACTIONS(5327),
    [anon_sym_PLUS] = ACTIONS(5327),
    [anon_sym_STAR] = ACTIONS(5329),
    [anon_sym_SLASH] = ACTIONS(5327),
    [anon_sym_PERCENT] = ACTIONS(5329),
    [anon_sym_PIPE_PIPE] = ACTIONS(5329),
    [anon_sym_AMP_AMP] = ACTIONS(5329),
    [anon_sym_PIPE] = ACTIONS(5327),
    [anon_sym_CARET] = ACTIONS(5329),
    [anon_sym_AMP] = ACTIONS(5327),
    [anon_sym_EQ_EQ] = ACTIONS(5329),
    [anon_sym_BANG_EQ] = ACTIONS(5329),
    [anon_sym_GT] = ACTIONS(5327),
    [anon_sym_GT_EQ] = ACTIONS(5329),
    [anon_sym_LT_EQ] = ACTIONS(5327),
    [anon_sym_LT] = ACTIONS(5327),
    [anon_sym_LT_LT] = ACTIONS(5329),
    [anon_sym_GT_GT] = ACTIONS(5329),
    [anon_sym_COLON] = ACTIONS(5813),
    [anon_sym_SEMI] = ACTIONS(5329),
    [anon_sym___extension__] = ACTIONS(5329),
    [anon_sym___attribute__] = ACTIONS(6070),
    [anon_sym_LBRACE] = ACTIONS(6072),
    [anon_sym_RBRACE] = ACTIONS(5329),
    [anon_sym_LBRACK] = ACTIONS(5329),
    [anon_sym_RBRACK] = ACTIONS(5329),
    [anon_sym_const] = ACTIONS(5327),
    [anon_sym_constexpr] = ACTIONS(5329),
    [anon_sym_volatile] = ACTIONS(5329),
    [anon_sym_restrict] = ACTIONS(5329),
    [anon_sym___restrict__] = ACTIONS(5329),
    [anon_sym__Atomic] = ACTIONS(5329),
    [anon_sym__Noreturn] = ACTIONS(5329),
    [anon_sym_noreturn] = ACTIONS(5329),
    [anon_sym_mutable] = ACTIONS(5329),
    [anon_sym_constinit] = ACTIONS(5329),
    [anon_sym_consteval] = ACTIONS(5329),
    [anon_sym_alignas] = ACTIONS(5329),
    [anon_sym__Alignas] = ACTIONS(5329),
    [anon_sym_QMARK] = ACTIONS(5329),
    [anon_sym_LT_EQ_GT] = ACTIONS(5329),
    [anon_sym_or] = ACTIONS(5329),
    [anon_sym_and] = ACTIONS(5329),
    [anon_sym_bitor] = ACTIONS(5329),
    [anon_sym_xor] = ACTIONS(5329),
    [anon_sym_bitand] = ACTIONS(5329),
    [anon_sym_not_eq] = ACTIONS(5329),
    [anon_sym_DASH_DASH] = ACTIONS(5329),
    [anon_sym_PLUS_PLUS] = ACTIONS(5329),
    [anon_sym_DOT] = ACTIONS(5327),
    [anon_sym_DOT_STAR] = ACTIONS(5329),
    [anon_sym_DASH_GT] = ACTIONS(5329),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5329),
    [anon_sym_decltype] = ACTIONS(5329),
    [anon_sym_final] = ACTIONS(6074),
    [anon_sym_override] = ACTIONS(6074),
    [anon_sym_requires] = ACTIONS(5329),
  },
  [2586] = {
    [sym_identifier] = ACTIONS(5133),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5135),
    [anon_sym_COMMA] = ACTIONS(5135),
    [anon_sym_RPAREN] = ACTIONS(5135),
    [aux_sym_preproc_if_token2] = ACTIONS(5135),
    [aux_sym_preproc_else_token1] = ACTIONS(5135),
    [aux_sym_preproc_elif_token1] = ACTIONS(5133),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5135),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5135),
    [anon_sym_LPAREN2] = ACTIONS(5135),
    [anon_sym_DASH] = ACTIONS(5133),
    [anon_sym_PLUS] = ACTIONS(5133),
    [anon_sym_STAR] = ACTIONS(5133),
    [anon_sym_SLASH] = ACTIONS(5133),
    [anon_sym_PERCENT] = ACTIONS(5133),
    [anon_sym_PIPE_PIPE] = ACTIONS(5135),
    [anon_sym_AMP_AMP] = ACTIONS(5135),
    [anon_sym_PIPE] = ACTIONS(5133),
    [anon_sym_CARET] = ACTIONS(5133),
    [anon_sym_AMP] = ACTIONS(5133),
    [anon_sym_EQ_EQ] = ACTIONS(5135),
    [anon_sym_BANG_EQ] = ACTIONS(5135),
    [anon_sym_GT] = ACTIONS(5133),
    [anon_sym_GT_EQ] = ACTIONS(5135),
    [anon_sym_LT_EQ] = ACTIONS(5133),
    [anon_sym_LT] = ACTIONS(5133),
    [anon_sym_LT_LT] = ACTIONS(5133),
    [anon_sym_GT_GT] = ACTIONS(5133),
    [anon_sym_COLON] = ACTIONS(5135),
    [anon_sym_SEMI] = ACTIONS(5135),
    [anon_sym___attribute__] = ACTIONS(5133),
    [anon_sym_LBRACE] = ACTIONS(5135),
    [anon_sym_RBRACE] = ACTIONS(5135),
    [anon_sym_LBRACK] = ACTIONS(5135),
    [anon_sym_RBRACK] = ACTIONS(5135),
    [anon_sym_EQ] = ACTIONS(5133),
    [anon_sym_QMARK] = ACTIONS(5135),
    [anon_sym_STAR_EQ] = ACTIONS(5135),
    [anon_sym_SLASH_EQ] = ACTIONS(5135),
    [anon_sym_PERCENT_EQ] = ACTIONS(5135),
    [anon_sym_PLUS_EQ] = ACTIONS(5135),
    [anon_sym_DASH_EQ] = ACTIONS(5135),
    [anon_sym_LT_LT_EQ] = ACTIONS(5135),
    [anon_sym_GT_GT_EQ] = ACTIONS(5135),
    [anon_sym_AMP_EQ] = ACTIONS(5135),
    [anon_sym_CARET_EQ] = ACTIONS(5135),
    [anon_sym_PIPE_EQ] = ACTIONS(5135),
    [anon_sym_and_eq] = ACTIONS(5133),
    [anon_sym_or_eq] = ACTIONS(5133),
    [anon_sym_xor_eq] = ACTIONS(5133),
    [anon_sym_LT_EQ_GT] = ACTIONS(5135),
    [anon_sym_or] = ACTIONS(5133),
    [anon_sym_and] = ACTIONS(5133),
    [anon_sym_bitor] = ACTIONS(5133),
    [anon_sym_xor] = ACTIONS(5133),
    [anon_sym_bitand] = ACTIONS(5133),
    [anon_sym_not_eq] = ACTIONS(5133),
    [anon_sym_DASH_DASH] = ACTIONS(5135),
    [anon_sym_PLUS_PLUS] = ACTIONS(5135),
    [anon_sym_DOT] = ACTIONS(5133),
    [anon_sym_DOT_STAR] = ACTIONS(5135),
    [anon_sym_DASH_GT] = ACTIONS(5135),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5133),
    [anon_sym_decltype] = ACTIONS(5133),
  },
  [2587] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2630),
    [sym_identifier] = ACTIONS(5367),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5369),
    [anon_sym_COMMA] = ACTIONS(5369),
    [aux_sym_preproc_if_token2] = ACTIONS(5369),
    [aux_sym_preproc_else_token1] = ACTIONS(5369),
    [aux_sym_preproc_elif_token1] = ACTIONS(5367),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5369),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5369),
    [anon_sym_LPAREN2] = ACTIONS(5369),
    [anon_sym_DASH] = ACTIONS(5367),
    [anon_sym_PLUS] = ACTIONS(5367),
    [anon_sym_STAR] = ACTIONS(5367),
    [anon_sym_SLASH] = ACTIONS(5367),
    [anon_sym_PERCENT] = ACTIONS(5367),
    [anon_sym_PIPE_PIPE] = ACTIONS(5369),
    [anon_sym_AMP_AMP] = ACTIONS(5369),
    [anon_sym_PIPE] = ACTIONS(5367),
    [anon_sym_CARET] = ACTIONS(5367),
    [anon_sym_AMP] = ACTIONS(5367),
    [anon_sym_EQ_EQ] = ACTIONS(5369),
    [anon_sym_BANG_EQ] = ACTIONS(5369),
    [anon_sym_GT] = ACTIONS(5367),
    [anon_sym_GT_EQ] = ACTIONS(5369),
    [anon_sym_LT_EQ] = ACTIONS(5367),
    [anon_sym_LT] = ACTIONS(5367),
    [anon_sym_LT_LT] = ACTIONS(5367),
    [anon_sym_GT_GT] = ACTIONS(5367),
    [anon_sym___attribute__] = ACTIONS(5367),
    [anon_sym_LBRACE] = ACTIONS(5369),
    [anon_sym_signed] = ACTIONS(6076),
    [anon_sym_unsigned] = ACTIONS(6076),
    [anon_sym_long] = ACTIONS(6076),
    [anon_sym_short] = ACTIONS(6076),
    [anon_sym_LBRACK] = ACTIONS(5369),
    [anon_sym_EQ] = ACTIONS(5367),
    [anon_sym_QMARK] = ACTIONS(5369),
    [anon_sym_STAR_EQ] = ACTIONS(5369),
    [anon_sym_SLASH_EQ] = ACTIONS(5369),
    [anon_sym_PERCENT_EQ] = ACTIONS(5369),
    [anon_sym_PLUS_EQ] = ACTIONS(5369),
    [anon_sym_DASH_EQ] = ACTIONS(5369),
    [anon_sym_LT_LT_EQ] = ACTIONS(5369),
    [anon_sym_GT_GT_EQ] = ACTIONS(5369),
    [anon_sym_AMP_EQ] = ACTIONS(5369),
    [anon_sym_CARET_EQ] = ACTIONS(5369),
    [anon_sym_PIPE_EQ] = ACTIONS(5369),
    [anon_sym_and_eq] = ACTIONS(5367),
    [anon_sym_or_eq] = ACTIONS(5367),
    [anon_sym_xor_eq] = ACTIONS(5367),
    [anon_sym_LT_EQ_GT] = ACTIONS(5369),
    [anon_sym_or] = ACTIONS(5367),
    [anon_sym_and] = ACTIONS(5367),
    [anon_sym_bitor] = ACTIONS(5367),
    [anon_sym_xor] = ACTIONS(5367),
    [anon_sym_bitand] = ACTIONS(5367),
    [anon_sym_not_eq] = ACTIONS(5367),
    [anon_sym_DASH_DASH] = ACTIONS(5369),
    [anon_sym_PLUS_PLUS] = ACTIONS(5369),
    [anon_sym_DOT] = ACTIONS(5367),
    [anon_sym_DOT_STAR] = ACTIONS(5369),
    [anon_sym_DASH_GT] = ACTIONS(5369),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5367),
    [anon_sym_decltype] = ACTIONS(5367),
  },
  [2588] = {
    [sym_attribute_declaration] = STATE(2588),
    [aux_sym_attributed_declarator_repeat1] = STATE(2588),
    [sym_identifier] = ACTIONS(6078),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6080),
    [anon_sym_COMMA] = ACTIONS(6080),
    [anon_sym_RPAREN] = ACTIONS(6080),
    [aux_sym_preproc_if_token2] = ACTIONS(6080),
    [aux_sym_preproc_else_token1] = ACTIONS(6080),
    [aux_sym_preproc_elif_token1] = ACTIONS(6078),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6080),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6080),
    [anon_sym_LPAREN2] = ACTIONS(6080),
    [anon_sym_DASH] = ACTIONS(6078),
    [anon_sym_PLUS] = ACTIONS(6078),
    [anon_sym_STAR] = ACTIONS(6078),
    [anon_sym_SLASH] = ACTIONS(6078),
    [anon_sym_PERCENT] = ACTIONS(6078),
    [anon_sym_PIPE_PIPE] = ACTIONS(6080),
    [anon_sym_AMP_AMP] = ACTIONS(6080),
    [anon_sym_PIPE] = ACTIONS(6078),
    [anon_sym_CARET] = ACTIONS(6078),
    [anon_sym_AMP] = ACTIONS(6078),
    [anon_sym_EQ_EQ] = ACTIONS(6080),
    [anon_sym_BANG_EQ] = ACTIONS(6080),
    [anon_sym_GT] = ACTIONS(6078),
    [anon_sym_GT_EQ] = ACTIONS(6080),
    [anon_sym_LT_EQ] = ACTIONS(6078),
    [anon_sym_LT] = ACTIONS(6078),
    [anon_sym_LT_LT] = ACTIONS(6078),
    [anon_sym_GT_GT] = ACTIONS(6078),
    [anon_sym_COLON] = ACTIONS(6080),
    [anon_sym_SEMI] = ACTIONS(6080),
    [anon_sym___attribute__] = ACTIONS(6078),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6082),
    [anon_sym_RBRACE] = ACTIONS(6080),
    [anon_sym_LBRACK] = ACTIONS(6078),
    [anon_sym_RBRACK] = ACTIONS(6080),
    [anon_sym_EQ] = ACTIONS(6078),
    [anon_sym_QMARK] = ACTIONS(6080),
    [anon_sym_STAR_EQ] = ACTIONS(6080),
    [anon_sym_SLASH_EQ] = ACTIONS(6080),
    [anon_sym_PERCENT_EQ] = ACTIONS(6080),
    [anon_sym_PLUS_EQ] = ACTIONS(6080),
    [anon_sym_DASH_EQ] = ACTIONS(6080),
    [anon_sym_LT_LT_EQ] = ACTIONS(6080),
    [anon_sym_GT_GT_EQ] = ACTIONS(6080),
    [anon_sym_AMP_EQ] = ACTIONS(6080),
    [anon_sym_CARET_EQ] = ACTIONS(6080),
    [anon_sym_PIPE_EQ] = ACTIONS(6080),
    [anon_sym_and_eq] = ACTIONS(6078),
    [anon_sym_or_eq] = ACTIONS(6078),
    [anon_sym_xor_eq] = ACTIONS(6078),
    [anon_sym_LT_EQ_GT] = ACTIONS(6080),
    [anon_sym_or] = ACTIONS(6078),
    [anon_sym_and] = ACTIONS(6078),
    [anon_sym_bitor] = ACTIONS(6078),
    [anon_sym_xor] = ACTIONS(6078),
    [anon_sym_bitand] = ACTIONS(6078),
    [anon_sym_not_eq] = ACTIONS(6078),
    [anon_sym_DASH_DASH] = ACTIONS(6080),
    [anon_sym_PLUS_PLUS] = ACTIONS(6080),
    [anon_sym_DOT] = ACTIONS(6078),
    [anon_sym_DOT_STAR] = ACTIONS(6080),
    [anon_sym_DASH_GT] = ACTIONS(6080),
    [sym_comment] = ACTIONS(3),
  },
  [2589] = {
    [sym_identifier] = ACTIONS(5467),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5469),
    [anon_sym_COMMA] = ACTIONS(5469),
    [anon_sym_RPAREN] = ACTIONS(5469),
    [aux_sym_preproc_if_token2] = ACTIONS(5469),
    [aux_sym_preproc_else_token1] = ACTIONS(5469),
    [aux_sym_preproc_elif_token1] = ACTIONS(5467),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5469),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5469),
    [anon_sym_LPAREN2] = ACTIONS(5469),
    [anon_sym_DASH] = ACTIONS(5467),
    [anon_sym_PLUS] = ACTIONS(5467),
    [anon_sym_STAR] = ACTIONS(5467),
    [anon_sym_SLASH] = ACTIONS(5467),
    [anon_sym_PERCENT] = ACTIONS(5467),
    [anon_sym_PIPE_PIPE] = ACTIONS(5469),
    [anon_sym_AMP_AMP] = ACTIONS(5469),
    [anon_sym_PIPE] = ACTIONS(5467),
    [anon_sym_CARET] = ACTIONS(5467),
    [anon_sym_AMP] = ACTIONS(5467),
    [anon_sym_EQ_EQ] = ACTIONS(5469),
    [anon_sym_BANG_EQ] = ACTIONS(5469),
    [anon_sym_GT] = ACTIONS(5467),
    [anon_sym_GT_EQ] = ACTIONS(5469),
    [anon_sym_LT_EQ] = ACTIONS(5467),
    [anon_sym_LT] = ACTIONS(5467),
    [anon_sym_LT_LT] = ACTIONS(5467),
    [anon_sym_GT_GT] = ACTIONS(5467),
    [anon_sym_COLON] = ACTIONS(5469),
    [anon_sym_SEMI] = ACTIONS(5469),
    [anon_sym___attribute__] = ACTIONS(5467),
    [anon_sym_LBRACE] = ACTIONS(5469),
    [anon_sym_RBRACE] = ACTIONS(5469),
    [anon_sym_LBRACK] = ACTIONS(5469),
    [anon_sym_RBRACK] = ACTIONS(5469),
    [anon_sym_EQ] = ACTIONS(5467),
    [anon_sym_QMARK] = ACTIONS(5469),
    [anon_sym_STAR_EQ] = ACTIONS(5469),
    [anon_sym_SLASH_EQ] = ACTIONS(5469),
    [anon_sym_PERCENT_EQ] = ACTIONS(5469),
    [anon_sym_PLUS_EQ] = ACTIONS(5469),
    [anon_sym_DASH_EQ] = ACTIONS(5469),
    [anon_sym_LT_LT_EQ] = ACTIONS(5469),
    [anon_sym_GT_GT_EQ] = ACTIONS(5469),
    [anon_sym_AMP_EQ] = ACTIONS(5469),
    [anon_sym_CARET_EQ] = ACTIONS(5469),
    [anon_sym_PIPE_EQ] = ACTIONS(5469),
    [anon_sym_and_eq] = ACTIONS(5467),
    [anon_sym_or_eq] = ACTIONS(5467),
    [anon_sym_xor_eq] = ACTIONS(5467),
    [anon_sym_LT_EQ_GT] = ACTIONS(5469),
    [anon_sym_or] = ACTIONS(5467),
    [anon_sym_and] = ACTIONS(5467),
    [anon_sym_bitor] = ACTIONS(5467),
    [anon_sym_xor] = ACTIONS(5467),
    [anon_sym_bitand] = ACTIONS(5467),
    [anon_sym_not_eq] = ACTIONS(5467),
    [anon_sym_DASH_DASH] = ACTIONS(5469),
    [anon_sym_PLUS_PLUS] = ACTIONS(5469),
    [anon_sym_DOT] = ACTIONS(5467),
    [anon_sym_DOT_STAR] = ACTIONS(5469),
    [anon_sym_DASH_GT] = ACTIONS(5469),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5467),
    [anon_sym_decltype] = ACTIONS(5467),
  },
  [2590] = {
    [sym_identifier] = ACTIONS(5483),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5485),
    [anon_sym_COMMA] = ACTIONS(5485),
    [anon_sym_RPAREN] = ACTIONS(5485),
    [aux_sym_preproc_if_token2] = ACTIONS(5485),
    [aux_sym_preproc_else_token1] = ACTIONS(5485),
    [aux_sym_preproc_elif_token1] = ACTIONS(5483),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5485),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5485),
    [anon_sym_LPAREN2] = ACTIONS(5485),
    [anon_sym_DASH] = ACTIONS(5483),
    [anon_sym_PLUS] = ACTIONS(5483),
    [anon_sym_STAR] = ACTIONS(5483),
    [anon_sym_SLASH] = ACTIONS(5483),
    [anon_sym_PERCENT] = ACTIONS(5483),
    [anon_sym_PIPE_PIPE] = ACTIONS(5485),
    [anon_sym_AMP_AMP] = ACTIONS(5485),
    [anon_sym_PIPE] = ACTIONS(5483),
    [anon_sym_CARET] = ACTIONS(5483),
    [anon_sym_AMP] = ACTIONS(5483),
    [anon_sym_EQ_EQ] = ACTIONS(5485),
    [anon_sym_BANG_EQ] = ACTIONS(5485),
    [anon_sym_GT] = ACTIONS(5483),
    [anon_sym_GT_EQ] = ACTIONS(5485),
    [anon_sym_LT_EQ] = ACTIONS(5483),
    [anon_sym_LT] = ACTIONS(5483),
    [anon_sym_LT_LT] = ACTIONS(5483),
    [anon_sym_GT_GT] = ACTIONS(5483),
    [anon_sym_COLON] = ACTIONS(5485),
    [anon_sym_SEMI] = ACTIONS(5485),
    [anon_sym___attribute__] = ACTIONS(5483),
    [anon_sym_LBRACE] = ACTIONS(5485),
    [anon_sym_RBRACE] = ACTIONS(5485),
    [anon_sym_LBRACK] = ACTIONS(5485),
    [anon_sym_RBRACK] = ACTIONS(5485),
    [anon_sym_EQ] = ACTIONS(5483),
    [anon_sym_QMARK] = ACTIONS(5485),
    [anon_sym_STAR_EQ] = ACTIONS(5485),
    [anon_sym_SLASH_EQ] = ACTIONS(5485),
    [anon_sym_PERCENT_EQ] = ACTIONS(5485),
    [anon_sym_PLUS_EQ] = ACTIONS(5485),
    [anon_sym_DASH_EQ] = ACTIONS(5485),
    [anon_sym_LT_LT_EQ] = ACTIONS(5485),
    [anon_sym_GT_GT_EQ] = ACTIONS(5485),
    [anon_sym_AMP_EQ] = ACTIONS(5485),
    [anon_sym_CARET_EQ] = ACTIONS(5485),
    [anon_sym_PIPE_EQ] = ACTIONS(5485),
    [anon_sym_and_eq] = ACTIONS(5483),
    [anon_sym_or_eq] = ACTIONS(5483),
    [anon_sym_xor_eq] = ACTIONS(5483),
    [anon_sym_LT_EQ_GT] = ACTIONS(5485),
    [anon_sym_or] = ACTIONS(5483),
    [anon_sym_and] = ACTIONS(5483),
    [anon_sym_bitor] = ACTIONS(5483),
    [anon_sym_xor] = ACTIONS(5483),
    [anon_sym_bitand] = ACTIONS(5483),
    [anon_sym_not_eq] = ACTIONS(5483),
    [anon_sym_DASH_DASH] = ACTIONS(5485),
    [anon_sym_PLUS_PLUS] = ACTIONS(5485),
    [anon_sym_DOT] = ACTIONS(5483),
    [anon_sym_DOT_STAR] = ACTIONS(5485),
    [anon_sym_DASH_GT] = ACTIONS(5485),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5483),
    [anon_sym_decltype] = ACTIONS(5483),
  },
  [2591] = {
    [sym_identifier] = ACTIONS(5467),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5469),
    [anon_sym_COMMA] = ACTIONS(5469),
    [anon_sym_RPAREN] = ACTIONS(5469),
    [aux_sym_preproc_if_token2] = ACTIONS(5469),
    [aux_sym_preproc_else_token1] = ACTIONS(5469),
    [aux_sym_preproc_elif_token1] = ACTIONS(5467),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5469),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5469),
    [anon_sym_LPAREN2] = ACTIONS(5469),
    [anon_sym_DASH] = ACTIONS(5467),
    [anon_sym_PLUS] = ACTIONS(5467),
    [anon_sym_STAR] = ACTIONS(5467),
    [anon_sym_SLASH] = ACTIONS(5467),
    [anon_sym_PERCENT] = ACTIONS(5467),
    [anon_sym_PIPE_PIPE] = ACTIONS(5469),
    [anon_sym_AMP_AMP] = ACTIONS(5469),
    [anon_sym_PIPE] = ACTIONS(5467),
    [anon_sym_CARET] = ACTIONS(5467),
    [anon_sym_AMP] = ACTIONS(5467),
    [anon_sym_EQ_EQ] = ACTIONS(5469),
    [anon_sym_BANG_EQ] = ACTIONS(5469),
    [anon_sym_GT] = ACTIONS(5467),
    [anon_sym_GT_EQ] = ACTIONS(5469),
    [anon_sym_LT_EQ] = ACTIONS(5467),
    [anon_sym_LT] = ACTIONS(5467),
    [anon_sym_LT_LT] = ACTIONS(5467),
    [anon_sym_GT_GT] = ACTIONS(5467),
    [anon_sym_COLON] = ACTIONS(5469),
    [anon_sym_SEMI] = ACTIONS(5469),
    [anon_sym___attribute__] = ACTIONS(5467),
    [anon_sym_LBRACE] = ACTIONS(5469),
    [anon_sym_RBRACE] = ACTIONS(5469),
    [anon_sym_LBRACK] = ACTIONS(5469),
    [anon_sym_RBRACK] = ACTIONS(5469),
    [anon_sym_EQ] = ACTIONS(5467),
    [anon_sym_QMARK] = ACTIONS(5469),
    [anon_sym_STAR_EQ] = ACTIONS(5469),
    [anon_sym_SLASH_EQ] = ACTIONS(5469),
    [anon_sym_PERCENT_EQ] = ACTIONS(5469),
    [anon_sym_PLUS_EQ] = ACTIONS(5469),
    [anon_sym_DASH_EQ] = ACTIONS(5469),
    [anon_sym_LT_LT_EQ] = ACTIONS(5469),
    [anon_sym_GT_GT_EQ] = ACTIONS(5469),
    [anon_sym_AMP_EQ] = ACTIONS(5469),
    [anon_sym_CARET_EQ] = ACTIONS(5469),
    [anon_sym_PIPE_EQ] = ACTIONS(5469),
    [anon_sym_and_eq] = ACTIONS(5467),
    [anon_sym_or_eq] = ACTIONS(5467),
    [anon_sym_xor_eq] = ACTIONS(5467),
    [anon_sym_LT_EQ_GT] = ACTIONS(5469),
    [anon_sym_or] = ACTIONS(5467),
    [anon_sym_and] = ACTIONS(5467),
    [anon_sym_bitor] = ACTIONS(5467),
    [anon_sym_xor] = ACTIONS(5467),
    [anon_sym_bitand] = ACTIONS(5467),
    [anon_sym_not_eq] = ACTIONS(5467),
    [anon_sym_DASH_DASH] = ACTIONS(5469),
    [anon_sym_PLUS_PLUS] = ACTIONS(5469),
    [anon_sym_DOT] = ACTIONS(5467),
    [anon_sym_DOT_STAR] = ACTIONS(5469),
    [anon_sym_DASH_GT] = ACTIONS(5469),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5467),
    [anon_sym_decltype] = ACTIONS(5467),
  },
  [2592] = {
    [sym_identifier] = ACTIONS(2260),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2262),
    [anon_sym_COMMA] = ACTIONS(2262),
    [anon_sym_RPAREN] = ACTIONS(2262),
    [aux_sym_preproc_if_token2] = ACTIONS(2262),
    [aux_sym_preproc_else_token1] = ACTIONS(2262),
    [aux_sym_preproc_elif_token1] = ACTIONS(2260),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2262),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2262),
    [anon_sym_LPAREN2] = ACTIONS(2262),
    [anon_sym_DASH] = ACTIONS(2260),
    [anon_sym_PLUS] = ACTIONS(2260),
    [anon_sym_STAR] = ACTIONS(2260),
    [anon_sym_SLASH] = ACTIONS(2260),
    [anon_sym_PERCENT] = ACTIONS(2260),
    [anon_sym_PIPE_PIPE] = ACTIONS(2262),
    [anon_sym_AMP_AMP] = ACTIONS(2262),
    [anon_sym_PIPE] = ACTIONS(2260),
    [anon_sym_CARET] = ACTIONS(2260),
    [anon_sym_AMP] = ACTIONS(2260),
    [anon_sym_EQ_EQ] = ACTIONS(2262),
    [anon_sym_BANG_EQ] = ACTIONS(2262),
    [anon_sym_GT] = ACTIONS(2260),
    [anon_sym_GT_EQ] = ACTIONS(2262),
    [anon_sym_LT_EQ] = ACTIONS(2260),
    [anon_sym_LT] = ACTIONS(2260),
    [anon_sym_LT_LT] = ACTIONS(2260),
    [anon_sym_GT_GT] = ACTIONS(2260),
    [anon_sym_COLON] = ACTIONS(2262),
    [anon_sym_SEMI] = ACTIONS(2262),
    [anon_sym___attribute__] = ACTIONS(2260),
    [anon_sym_LBRACE] = ACTIONS(2262),
    [anon_sym_RBRACE] = ACTIONS(2262),
    [anon_sym_LBRACK] = ACTIONS(2262),
    [anon_sym_RBRACK] = ACTIONS(2262),
    [anon_sym_EQ] = ACTIONS(2260),
    [anon_sym_QMARK] = ACTIONS(2262),
    [anon_sym_STAR_EQ] = ACTIONS(2262),
    [anon_sym_SLASH_EQ] = ACTIONS(2262),
    [anon_sym_PERCENT_EQ] = ACTIONS(2262),
    [anon_sym_PLUS_EQ] = ACTIONS(2262),
    [anon_sym_DASH_EQ] = ACTIONS(2262),
    [anon_sym_LT_LT_EQ] = ACTIONS(2262),
    [anon_sym_GT_GT_EQ] = ACTIONS(2262),
    [anon_sym_AMP_EQ] = ACTIONS(2262),
    [anon_sym_CARET_EQ] = ACTIONS(2262),
    [anon_sym_PIPE_EQ] = ACTIONS(2262),
    [anon_sym_and_eq] = ACTIONS(2260),
    [anon_sym_or_eq] = ACTIONS(2260),
    [anon_sym_xor_eq] = ACTIONS(2260),
    [anon_sym_LT_EQ_GT] = ACTIONS(2262),
    [anon_sym_or] = ACTIONS(2260),
    [anon_sym_and] = ACTIONS(2260),
    [anon_sym_bitor] = ACTIONS(2260),
    [anon_sym_xor] = ACTIONS(2260),
    [anon_sym_bitand] = ACTIONS(2260),
    [anon_sym_not_eq] = ACTIONS(2260),
    [anon_sym_DASH_DASH] = ACTIONS(2262),
    [anon_sym_PLUS_PLUS] = ACTIONS(2262),
    [anon_sym_DOT] = ACTIONS(2260),
    [anon_sym_DOT_STAR] = ACTIONS(2262),
    [anon_sym_DASH_GT] = ACTIONS(2262),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2260),
    [anon_sym_decltype] = ACTIONS(2260),
  },
  [2593] = {
    [sym_identifier] = ACTIONS(2142),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(2144),
    [anon_sym_COMMA] = ACTIONS(2144),
    [anon_sym_RPAREN] = ACTIONS(2144),
    [aux_sym_preproc_if_token2] = ACTIONS(2144),
    [aux_sym_preproc_else_token1] = ACTIONS(2144),
    [aux_sym_preproc_elif_token1] = ACTIONS(2142),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(2144),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(2144),
    [anon_sym_LPAREN2] = ACTIONS(2144),
    [anon_sym_DASH] = ACTIONS(2142),
    [anon_sym_PLUS] = ACTIONS(2142),
    [anon_sym_STAR] = ACTIONS(2142),
    [anon_sym_SLASH] = ACTIONS(2142),
    [anon_sym_PERCENT] = ACTIONS(2142),
    [anon_sym_PIPE_PIPE] = ACTIONS(2144),
    [anon_sym_AMP_AMP] = ACTIONS(2144),
    [anon_sym_PIPE] = ACTIONS(2142),
    [anon_sym_CARET] = ACTIONS(2142),
    [anon_sym_AMP] = ACTIONS(2142),
    [anon_sym_EQ_EQ] = ACTIONS(2144),
    [anon_sym_BANG_EQ] = ACTIONS(2144),
    [anon_sym_GT] = ACTIONS(2142),
    [anon_sym_GT_EQ] = ACTIONS(2144),
    [anon_sym_LT_EQ] = ACTIONS(2142),
    [anon_sym_LT] = ACTIONS(2142),
    [anon_sym_LT_LT] = ACTIONS(2142),
    [anon_sym_GT_GT] = ACTIONS(2142),
    [anon_sym_COLON] = ACTIONS(2144),
    [anon_sym_SEMI] = ACTIONS(2144),
    [anon_sym___attribute__] = ACTIONS(2142),
    [anon_sym_LBRACE] = ACTIONS(2144),
    [anon_sym_RBRACE] = ACTIONS(2144),
    [anon_sym_LBRACK] = ACTIONS(2144),
    [anon_sym_RBRACK] = ACTIONS(2144),
    [anon_sym_EQ] = ACTIONS(2142),
    [anon_sym_QMARK] = ACTIONS(2144),
    [anon_sym_STAR_EQ] = ACTIONS(2144),
    [anon_sym_SLASH_EQ] = ACTIONS(2144),
    [anon_sym_PERCENT_EQ] = ACTIONS(2144),
    [anon_sym_PLUS_EQ] = ACTIONS(2144),
    [anon_sym_DASH_EQ] = ACTIONS(2144),
    [anon_sym_LT_LT_EQ] = ACTIONS(2144),
    [anon_sym_GT_GT_EQ] = ACTIONS(2144),
    [anon_sym_AMP_EQ] = ACTIONS(2144),
    [anon_sym_CARET_EQ] = ACTIONS(2144),
    [anon_sym_PIPE_EQ] = ACTIONS(2144),
    [anon_sym_and_eq] = ACTIONS(2142),
    [anon_sym_or_eq] = ACTIONS(2142),
    [anon_sym_xor_eq] = ACTIONS(2142),
    [anon_sym_LT_EQ_GT] = ACTIONS(2144),
    [anon_sym_or] = ACTIONS(2142),
    [anon_sym_and] = ACTIONS(2142),
    [anon_sym_bitor] = ACTIONS(2142),
    [anon_sym_xor] = ACTIONS(2142),
    [anon_sym_bitand] = ACTIONS(2142),
    [anon_sym_not_eq] = ACTIONS(2142),
    [anon_sym_DASH_DASH] = ACTIONS(2144),
    [anon_sym_PLUS_PLUS] = ACTIONS(2144),
    [anon_sym_DOT] = ACTIONS(2142),
    [anon_sym_DOT_STAR] = ACTIONS(2144),
    [anon_sym_DASH_GT] = ACTIONS(2144),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2142),
    [anon_sym_decltype] = ACTIONS(2142),
  },
  [2594] = {
    [sym_identifier] = ACTIONS(5479),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5481),
    [anon_sym_COMMA] = ACTIONS(5481),
    [anon_sym_RPAREN] = ACTIONS(5481),
    [aux_sym_preproc_if_token2] = ACTIONS(5481),
    [aux_sym_preproc_else_token1] = ACTIONS(5481),
    [aux_sym_preproc_elif_token1] = ACTIONS(5479),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5481),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5481),
    [anon_sym_LPAREN2] = ACTIONS(5481),
    [anon_sym_DASH] = ACTIONS(5479),
    [anon_sym_PLUS] = ACTIONS(5479),
    [anon_sym_STAR] = ACTIONS(5479),
    [anon_sym_SLASH] = ACTIONS(5479),
    [anon_sym_PERCENT] = ACTIONS(5479),
    [anon_sym_PIPE_PIPE] = ACTIONS(5481),
    [anon_sym_AMP_AMP] = ACTIONS(5481),
    [anon_sym_PIPE] = ACTIONS(5479),
    [anon_sym_CARET] = ACTIONS(5479),
    [anon_sym_AMP] = ACTIONS(5479),
    [anon_sym_EQ_EQ] = ACTIONS(5481),
    [anon_sym_BANG_EQ] = ACTIONS(5481),
    [anon_sym_GT] = ACTIONS(5479),
    [anon_sym_GT_EQ] = ACTIONS(5481),
    [anon_sym_LT_EQ] = ACTIONS(5479),
    [anon_sym_LT] = ACTIONS(5479),
    [anon_sym_LT_LT] = ACTIONS(5479),
    [anon_sym_GT_GT] = ACTIONS(5479),
    [anon_sym_COLON] = ACTIONS(5481),
    [anon_sym_SEMI] = ACTIONS(5481),
    [anon_sym___attribute__] = ACTIONS(5479),
    [anon_sym_LBRACE] = ACTIONS(5481),
    [anon_sym_RBRACE] = ACTIONS(5481),
    [anon_sym_LBRACK] = ACTIONS(5481),
    [anon_sym_RBRACK] = ACTIONS(5481),
    [anon_sym_EQ] = ACTIONS(5479),
    [anon_sym_QMARK] = ACTIONS(5481),
    [anon_sym_STAR_EQ] = ACTIONS(5481),
    [anon_sym_SLASH_EQ] = ACTIONS(5481),
    [anon_sym_PERCENT_EQ] = ACTIONS(5481),
    [anon_sym_PLUS_EQ] = ACTIONS(5481),
    [anon_sym_DASH_EQ] = ACTIONS(5481),
    [anon_sym_LT_LT_EQ] = ACTIONS(5481),
    [anon_sym_GT_GT_EQ] = ACTIONS(5481),
    [anon_sym_AMP_EQ] = ACTIONS(5481),
    [anon_sym_CARET_EQ] = ACTIONS(5481),
    [anon_sym_PIPE_EQ] = ACTIONS(5481),
    [anon_sym_and_eq] = ACTIONS(5479),
    [anon_sym_or_eq] = ACTIONS(5479),
    [anon_sym_xor_eq] = ACTIONS(5479),
    [anon_sym_LT_EQ_GT] = ACTIONS(5481),
    [anon_sym_or] = ACTIONS(5479),
    [anon_sym_and] = ACTIONS(5479),
    [anon_sym_bitor] = ACTIONS(5479),
    [anon_sym_xor] = ACTIONS(5479),
    [anon_sym_bitand] = ACTIONS(5479),
    [anon_sym_not_eq] = ACTIONS(5479),
    [anon_sym_DASH_DASH] = ACTIONS(5481),
    [anon_sym_PLUS_PLUS] = ACTIONS(5481),
    [anon_sym_DOT] = ACTIONS(5479),
    [anon_sym_DOT_STAR] = ACTIONS(5481),
    [anon_sym_DASH_GT] = ACTIONS(5481),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5479),
    [anon_sym_decltype] = ACTIONS(5479),
  },
  [2595] = {
    [sym_identifier] = ACTIONS(5467),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5469),
    [anon_sym_COMMA] = ACTIONS(5469),
    [anon_sym_RPAREN] = ACTIONS(5469),
    [aux_sym_preproc_if_token2] = ACTIONS(5469),
    [aux_sym_preproc_else_token1] = ACTIONS(5469),
    [aux_sym_preproc_elif_token1] = ACTIONS(5467),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5469),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5469),
    [anon_sym_LPAREN2] = ACTIONS(5469),
    [anon_sym_DASH] = ACTIONS(5467),
    [anon_sym_PLUS] = ACTIONS(5467),
    [anon_sym_STAR] = ACTIONS(5467),
    [anon_sym_SLASH] = ACTIONS(5467),
    [anon_sym_PERCENT] = ACTIONS(5467),
    [anon_sym_PIPE_PIPE] = ACTIONS(5469),
    [anon_sym_AMP_AMP] = ACTIONS(5469),
    [anon_sym_PIPE] = ACTIONS(5467),
    [anon_sym_CARET] = ACTIONS(5467),
    [anon_sym_AMP] = ACTIONS(5467),
    [anon_sym_EQ_EQ] = ACTIONS(5469),
    [anon_sym_BANG_EQ] = ACTIONS(5469),
    [anon_sym_GT] = ACTIONS(5467),
    [anon_sym_GT_EQ] = ACTIONS(5469),
    [anon_sym_LT_EQ] = ACTIONS(5467),
    [anon_sym_LT] = ACTIONS(5467),
    [anon_sym_LT_LT] = ACTIONS(5467),
    [anon_sym_GT_GT] = ACTIONS(5467),
    [anon_sym_COLON] = ACTIONS(5469),
    [anon_sym_SEMI] = ACTIONS(5469),
    [anon_sym___attribute__] = ACTIONS(5467),
    [anon_sym_LBRACE] = ACTIONS(5469),
    [anon_sym_RBRACE] = ACTIONS(5469),
    [anon_sym_LBRACK] = ACTIONS(5469),
    [anon_sym_RBRACK] = ACTIONS(5469),
    [anon_sym_EQ] = ACTIONS(5467),
    [anon_sym_QMARK] = ACTIONS(5469),
    [anon_sym_STAR_EQ] = ACTIONS(5469),
    [anon_sym_SLASH_EQ] = ACTIONS(5469),
    [anon_sym_PERCENT_EQ] = ACTIONS(5469),
    [anon_sym_PLUS_EQ] = ACTIONS(5469),
    [anon_sym_DASH_EQ] = ACTIONS(5469),
    [anon_sym_LT_LT_EQ] = ACTIONS(5469),
    [anon_sym_GT_GT_EQ] = ACTIONS(5469),
    [anon_sym_AMP_EQ] = ACTIONS(5469),
    [anon_sym_CARET_EQ] = ACTIONS(5469),
    [anon_sym_PIPE_EQ] = ACTIONS(5469),
    [anon_sym_and_eq] = ACTIONS(5467),
    [anon_sym_or_eq] = ACTIONS(5467),
    [anon_sym_xor_eq] = ACTIONS(5467),
    [anon_sym_LT_EQ_GT] = ACTIONS(5469),
    [anon_sym_or] = ACTIONS(5467),
    [anon_sym_and] = ACTIONS(5467),
    [anon_sym_bitor] = ACTIONS(5467),
    [anon_sym_xor] = ACTIONS(5467),
    [anon_sym_bitand] = ACTIONS(5467),
    [anon_sym_not_eq] = ACTIONS(5467),
    [anon_sym_DASH_DASH] = ACTIONS(5469),
    [anon_sym_PLUS_PLUS] = ACTIONS(5469),
    [anon_sym_DOT] = ACTIONS(5467),
    [anon_sym_DOT_STAR] = ACTIONS(5469),
    [anon_sym_DASH_GT] = ACTIONS(5469),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5467),
    [anon_sym_decltype] = ACTIONS(5467),
  },
  [2596] = {
    [sym_identifier] = ACTIONS(5451),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5453),
    [anon_sym_COMMA] = ACTIONS(5453),
    [anon_sym_RPAREN] = ACTIONS(5453),
    [aux_sym_preproc_if_token2] = ACTIONS(5453),
    [aux_sym_preproc_else_token1] = ACTIONS(5453),
    [aux_sym_preproc_elif_token1] = ACTIONS(5451),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5453),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5453),
    [anon_sym_LPAREN2] = ACTIONS(5453),
    [anon_sym_DASH] = ACTIONS(5451),
    [anon_sym_PLUS] = ACTIONS(5451),
    [anon_sym_STAR] = ACTIONS(5451),
    [anon_sym_SLASH] = ACTIONS(5451),
    [anon_sym_PERCENT] = ACTIONS(5451),
    [anon_sym_PIPE_PIPE] = ACTIONS(5453),
    [anon_sym_AMP_AMP] = ACTIONS(5453),
    [anon_sym_PIPE] = ACTIONS(5451),
    [anon_sym_CARET] = ACTIONS(5451),
    [anon_sym_AMP] = ACTIONS(5451),
    [anon_sym_EQ_EQ] = ACTIONS(5453),
    [anon_sym_BANG_EQ] = ACTIONS(5453),
    [anon_sym_GT] = ACTIONS(5451),
    [anon_sym_GT_EQ] = ACTIONS(5453),
    [anon_sym_LT_EQ] = ACTIONS(5451),
    [anon_sym_LT] = ACTIONS(5451),
    [anon_sym_LT_LT] = ACTIONS(5451),
    [anon_sym_GT_GT] = ACTIONS(5451),
    [anon_sym_COLON] = ACTIONS(5453),
    [anon_sym_SEMI] = ACTIONS(5453),
    [anon_sym___attribute__] = ACTIONS(5451),
    [anon_sym_LBRACE] = ACTIONS(5453),
    [anon_sym_RBRACE] = ACTIONS(5453),
    [anon_sym_LBRACK] = ACTIONS(5453),
    [anon_sym_RBRACK] = ACTIONS(5453),
    [anon_sym_EQ] = ACTIONS(5451),
    [anon_sym_QMARK] = ACTIONS(5453),
    [anon_sym_STAR_EQ] = ACTIONS(5453),
    [anon_sym_SLASH_EQ] = ACTIONS(5453),
    [anon_sym_PERCENT_EQ] = ACTIONS(5453),
    [anon_sym_PLUS_EQ] = ACTIONS(5453),
    [anon_sym_DASH_EQ] = ACTIONS(5453),
    [anon_sym_LT_LT_EQ] = ACTIONS(5453),
    [anon_sym_GT_GT_EQ] = ACTIONS(5453),
    [anon_sym_AMP_EQ] = ACTIONS(5453),
    [anon_sym_CARET_EQ] = ACTIONS(5453),
    [anon_sym_PIPE_EQ] = ACTIONS(5453),
    [anon_sym_and_eq] = ACTIONS(5451),
    [anon_sym_or_eq] = ACTIONS(5451),
    [anon_sym_xor_eq] = ACTIONS(5451),
    [anon_sym_LT_EQ_GT] = ACTIONS(5453),
    [anon_sym_or] = ACTIONS(5451),
    [anon_sym_and] = ACTIONS(5451),
    [anon_sym_bitor] = ACTIONS(5451),
    [anon_sym_xor] = ACTIONS(5451),
    [anon_sym_bitand] = ACTIONS(5451),
    [anon_sym_not_eq] = ACTIONS(5451),
    [anon_sym_DASH_DASH] = ACTIONS(5453),
    [anon_sym_PLUS_PLUS] = ACTIONS(5453),
    [anon_sym_DOT] = ACTIONS(5451),
    [anon_sym_DOT_STAR] = ACTIONS(5453),
    [anon_sym_DASH_GT] = ACTIONS(5453),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5451),
    [anon_sym_decltype] = ACTIONS(5451),
  },
  [2597] = {
    [sym_attribute_specifier] = STATE(2269),
    [sym_enumerator_list] = STATE(2322),
    [sym__enum_base_clause] = STATE(2301),
    [sym_identifier] = ACTIONS(5689),
    [anon_sym_LPAREN2] = ACTIONS(5691),
    [anon_sym_STAR] = ACTIONS(5691),
    [anon_sym_AMP_AMP] = ACTIONS(5691),
    [anon_sym_AMP] = ACTIONS(5689),
    [anon_sym_COLON] = ACTIONS(6085),
    [anon_sym_SEMI] = ACTIONS(5691),
    [anon_sym___extension__] = ACTIONS(5689),
    [anon_sym_in] = ACTIONS(5689),
    [anon_sym_out] = ACTIONS(5689),
    [anon_sym_inout] = ACTIONS(5689),
    [anon_sym_extern] = ACTIONS(5689),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5691),
    [anon_sym___declspec] = ACTIONS(5689),
    [anon_sym___based] = ACTIONS(5689),
    [anon_sym_LBRACE] = ACTIONS(5523),
    [anon_sym_static] = ACTIONS(5689),
    [anon_sym_register] = ACTIONS(5689),
    [anon_sym_inline] = ACTIONS(5689),
    [anon_sym___inline] = ACTIONS(5689),
    [anon_sym___inline__] = ACTIONS(5689),
    [anon_sym___forceinline] = ACTIONS(5689),
    [anon_sym_thread_local] = ACTIONS(5689),
    [anon_sym___thread] = ACTIONS(5689),
    [anon_sym_const] = ACTIONS(5689),
    [anon_sym_constexpr] = ACTIONS(5689),
    [anon_sym_volatile] = ACTIONS(5689),
    [anon_sym_restrict] = ACTIONS(5689),
    [anon_sym___restrict__] = ACTIONS(5689),
    [anon_sym__Atomic] = ACTIONS(5689),
    [anon_sym__Noreturn] = ACTIONS(5689),
    [anon_sym_noreturn] = ACTIONS(5689),
    [anon_sym_mutable] = ACTIONS(5689),
    [anon_sym_constinit] = ACTIONS(5689),
    [anon_sym_consteval] = ACTIONS(5689),
    [anon_sym_alignas] = ACTIONS(5689),
    [anon_sym__Alignas] = ACTIONS(5689),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5689),
    [anon_sym_decltype] = ACTIONS(5689),
    [sym_virtual] = ACTIONS(5689),
    [anon_sym_operator] = ACTIONS(5689),
    [anon_sym_precise] = ACTIONS(5689),
    [anon_sym_shared] = ACTIONS(5689),
    [anon_sym_groupshared] = ACTIONS(5689),
    [anon_sym_uniform] = ACTIONS(5689),
    [anon_sym_row_major] = ACTIONS(5689),
    [anon_sym_column_major] = ACTIONS(5689),
    [anon_sym_globallycoherent] = ACTIONS(5689),
    [anon_sym_centroid] = ACTIONS(5689),
    [anon_sym_noperspective] = ACTIONS(5689),
    [anon_sym_nointerpolation] = ACTIONS(5689),
    [anon_sym_sample] = ACTIONS(5689),
    [anon_sym_linear] = ACTIONS(5689),
    [anon_sym_snorm] = ACTIONS(5689),
    [anon_sym_unorm] = ACTIONS(5689),
    [anon_sym_point] = ACTIONS(5689),
    [anon_sym_line] = ACTIONS(5689),
    [anon_sym_triangleadj] = ACTIONS(5689),
    [anon_sym_lineadj] = ACTIONS(5689),
    [anon_sym_triangle] = ACTIONS(5689),
  },
  [2598] = {
    [sym_identifier] = ACTIONS(5463),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5465),
    [anon_sym_COMMA] = ACTIONS(5465),
    [anon_sym_RPAREN] = ACTIONS(5465),
    [aux_sym_preproc_if_token2] = ACTIONS(5465),
    [aux_sym_preproc_else_token1] = ACTIONS(5465),
    [aux_sym_preproc_elif_token1] = ACTIONS(5463),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5465),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5465),
    [anon_sym_LPAREN2] = ACTIONS(5465),
    [anon_sym_DASH] = ACTIONS(5463),
    [anon_sym_PLUS] = ACTIONS(5463),
    [anon_sym_STAR] = ACTIONS(5463),
    [anon_sym_SLASH] = ACTIONS(5463),
    [anon_sym_PERCENT] = ACTIONS(5463),
    [anon_sym_PIPE_PIPE] = ACTIONS(5465),
    [anon_sym_AMP_AMP] = ACTIONS(5465),
    [anon_sym_PIPE] = ACTIONS(5463),
    [anon_sym_CARET] = ACTIONS(5463),
    [anon_sym_AMP] = ACTIONS(5463),
    [anon_sym_EQ_EQ] = ACTIONS(5465),
    [anon_sym_BANG_EQ] = ACTIONS(5465),
    [anon_sym_GT] = ACTIONS(5463),
    [anon_sym_GT_EQ] = ACTIONS(5465),
    [anon_sym_LT_EQ] = ACTIONS(5463),
    [anon_sym_LT] = ACTIONS(5463),
    [anon_sym_LT_LT] = ACTIONS(5463),
    [anon_sym_GT_GT] = ACTIONS(5463),
    [anon_sym_COLON] = ACTIONS(5465),
    [anon_sym_SEMI] = ACTIONS(5465),
    [anon_sym___attribute__] = ACTIONS(5463),
    [anon_sym_LBRACE] = ACTIONS(5465),
    [anon_sym_RBRACE] = ACTIONS(5465),
    [anon_sym_LBRACK] = ACTIONS(5465),
    [anon_sym_RBRACK] = ACTIONS(5465),
    [anon_sym_EQ] = ACTIONS(5463),
    [anon_sym_QMARK] = ACTIONS(5465),
    [anon_sym_STAR_EQ] = ACTIONS(5465),
    [anon_sym_SLASH_EQ] = ACTIONS(5465),
    [anon_sym_PERCENT_EQ] = ACTIONS(5465),
    [anon_sym_PLUS_EQ] = ACTIONS(5465),
    [anon_sym_DASH_EQ] = ACTIONS(5465),
    [anon_sym_LT_LT_EQ] = ACTIONS(5465),
    [anon_sym_GT_GT_EQ] = ACTIONS(5465),
    [anon_sym_AMP_EQ] = ACTIONS(5465),
    [anon_sym_CARET_EQ] = ACTIONS(5465),
    [anon_sym_PIPE_EQ] = ACTIONS(5465),
    [anon_sym_and_eq] = ACTIONS(5463),
    [anon_sym_or_eq] = ACTIONS(5463),
    [anon_sym_xor_eq] = ACTIONS(5463),
    [anon_sym_LT_EQ_GT] = ACTIONS(5465),
    [anon_sym_or] = ACTIONS(5463),
    [anon_sym_and] = ACTIONS(5463),
    [anon_sym_bitor] = ACTIONS(5463),
    [anon_sym_xor] = ACTIONS(5463),
    [anon_sym_bitand] = ACTIONS(5463),
    [anon_sym_not_eq] = ACTIONS(5463),
    [anon_sym_DASH_DASH] = ACTIONS(5465),
    [anon_sym_PLUS_PLUS] = ACTIONS(5465),
    [anon_sym_DOT] = ACTIONS(5463),
    [anon_sym_DOT_STAR] = ACTIONS(5465),
    [anon_sym_DASH_GT] = ACTIONS(5465),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5463),
    [anon_sym_decltype] = ACTIONS(5463),
  },
  [2599] = {
    [sym_attribute_specifier] = STATE(2293),
    [sym_enumerator_list] = STATE(2328),
    [sym__enum_base_clause] = STATE(2299),
    [sym_identifier] = ACTIONS(5636),
    [anon_sym_LPAREN2] = ACTIONS(5638),
    [anon_sym_STAR] = ACTIONS(5638),
    [anon_sym_AMP_AMP] = ACTIONS(5638),
    [anon_sym_AMP] = ACTIONS(5636),
    [anon_sym_COLON] = ACTIONS(6085),
    [anon_sym_SEMI] = ACTIONS(5638),
    [anon_sym___extension__] = ACTIONS(5636),
    [anon_sym_in] = ACTIONS(5636),
    [anon_sym_out] = ACTIONS(5636),
    [anon_sym_inout] = ACTIONS(5636),
    [anon_sym_extern] = ACTIONS(5636),
    [anon_sym___attribute__] = ACTIONS(4987),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5638),
    [anon_sym___declspec] = ACTIONS(5636),
    [anon_sym___based] = ACTIONS(5636),
    [anon_sym_LBRACE] = ACTIONS(5523),
    [anon_sym_static] = ACTIONS(5636),
    [anon_sym_register] = ACTIONS(5636),
    [anon_sym_inline] = ACTIONS(5636),
    [anon_sym___inline] = ACTIONS(5636),
    [anon_sym___inline__] = ACTIONS(5636),
    [anon_sym___forceinline] = ACTIONS(5636),
    [anon_sym_thread_local] = ACTIONS(5636),
    [anon_sym___thread] = ACTIONS(5636),
    [anon_sym_const] = ACTIONS(5636),
    [anon_sym_constexpr] = ACTIONS(5636),
    [anon_sym_volatile] = ACTIONS(5636),
    [anon_sym_restrict] = ACTIONS(5636),
    [anon_sym___restrict__] = ACTIONS(5636),
    [anon_sym__Atomic] = ACTIONS(5636),
    [anon_sym__Noreturn] = ACTIONS(5636),
    [anon_sym_noreturn] = ACTIONS(5636),
    [anon_sym_mutable] = ACTIONS(5636),
    [anon_sym_constinit] = ACTIONS(5636),
    [anon_sym_consteval] = ACTIONS(5636),
    [anon_sym_alignas] = ACTIONS(5636),
    [anon_sym__Alignas] = ACTIONS(5636),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5636),
    [anon_sym_decltype] = ACTIONS(5636),
    [sym_virtual] = ACTIONS(5636),
    [anon_sym_operator] = ACTIONS(5636),
    [anon_sym_precise] = ACTIONS(5636),
    [anon_sym_shared] = ACTIONS(5636),
    [anon_sym_groupshared] = ACTIONS(5636),
    [anon_sym_uniform] = ACTIONS(5636),
    [anon_sym_row_major] = ACTIONS(5636),
    [anon_sym_column_major] = ACTIONS(5636),
    [anon_sym_globallycoherent] = ACTIONS(5636),
    [anon_sym_centroid] = ACTIONS(5636),
    [anon_sym_noperspective] = ACTIONS(5636),
    [anon_sym_nointerpolation] = ACTIONS(5636),
    [anon_sym_sample] = ACTIONS(5636),
    [anon_sym_linear] = ACTIONS(5636),
    [anon_sym_snorm] = ACTIONS(5636),
    [anon_sym_unorm] = ACTIONS(5636),
    [anon_sym_point] = ACTIONS(5636),
    [anon_sym_line] = ACTIONS(5636),
    [anon_sym_triangleadj] = ACTIONS(5636),
    [anon_sym_lineadj] = ACTIONS(5636),
    [anon_sym_triangle] = ACTIONS(5636),
  },
  [2600] = {
    [sym_identifier] = ACTIONS(5419),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5421),
    [anon_sym_COMMA] = ACTIONS(5421),
    [anon_sym_RPAREN] = ACTIONS(5421),
    [aux_sym_preproc_if_token2] = ACTIONS(5421),
    [aux_sym_preproc_else_token1] = ACTIONS(5421),
    [aux_sym_preproc_elif_token1] = ACTIONS(5419),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5421),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5421),
    [anon_sym_LPAREN2] = ACTIONS(5421),
    [anon_sym_DASH] = ACTIONS(5419),
    [anon_sym_PLUS] = ACTIONS(5419),
    [anon_sym_STAR] = ACTIONS(5419),
    [anon_sym_SLASH] = ACTIONS(5419),
    [anon_sym_PERCENT] = ACTIONS(5419),
    [anon_sym_PIPE_PIPE] = ACTIONS(5421),
    [anon_sym_AMP_AMP] = ACTIONS(5421),
    [anon_sym_PIPE] = ACTIONS(5419),
    [anon_sym_CARET] = ACTIONS(5419),
    [anon_sym_AMP] = ACTIONS(5419),
    [anon_sym_EQ_EQ] = ACTIONS(5421),
    [anon_sym_BANG_EQ] = ACTIONS(5421),
    [anon_sym_GT] = ACTIONS(5419),
    [anon_sym_GT_EQ] = ACTIONS(5421),
    [anon_sym_LT_EQ] = ACTIONS(5419),
    [anon_sym_LT] = ACTIONS(5419),
    [anon_sym_LT_LT] = ACTIONS(5419),
    [anon_sym_GT_GT] = ACTIONS(5419),
    [anon_sym_COLON] = ACTIONS(5421),
    [anon_sym_SEMI] = ACTIONS(5421),
    [anon_sym___attribute__] = ACTIONS(5419),
    [anon_sym_LBRACE] = ACTIONS(5421),
    [anon_sym_RBRACE] = ACTIONS(5421),
    [anon_sym_LBRACK] = ACTIONS(5421),
    [anon_sym_RBRACK] = ACTIONS(5421),
    [anon_sym_EQ] = ACTIONS(5419),
    [anon_sym_QMARK] = ACTIONS(5421),
    [anon_sym_STAR_EQ] = ACTIONS(5421),
    [anon_sym_SLASH_EQ] = ACTIONS(5421),
    [anon_sym_PERCENT_EQ] = ACTIONS(5421),
    [anon_sym_PLUS_EQ] = ACTIONS(5421),
    [anon_sym_DASH_EQ] = ACTIONS(5421),
    [anon_sym_LT_LT_EQ] = ACTIONS(5421),
    [anon_sym_GT_GT_EQ] = ACTIONS(5421),
    [anon_sym_AMP_EQ] = ACTIONS(5421),
    [anon_sym_CARET_EQ] = ACTIONS(5421),
    [anon_sym_PIPE_EQ] = ACTIONS(5421),
    [anon_sym_and_eq] = ACTIONS(5419),
    [anon_sym_or_eq] = ACTIONS(5419),
    [anon_sym_xor_eq] = ACTIONS(5419),
    [anon_sym_LT_EQ_GT] = ACTIONS(5421),
    [anon_sym_or] = ACTIONS(5419),
    [anon_sym_and] = ACTIONS(5419),
    [anon_sym_bitor] = ACTIONS(5419),
    [anon_sym_xor] = ACTIONS(5419),
    [anon_sym_bitand] = ACTIONS(5419),
    [anon_sym_not_eq] = ACTIONS(5419),
    [anon_sym_DASH_DASH] = ACTIONS(5421),
    [anon_sym_PLUS_PLUS] = ACTIONS(5421),
    [anon_sym_DOT] = ACTIONS(5419),
    [anon_sym_DOT_STAR] = ACTIONS(5421),
    [anon_sym_DASH_GT] = ACTIONS(5421),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5419),
    [anon_sym_decltype] = ACTIONS(5419),
  },
  [2601] = {
    [sym_identifier] = ACTIONS(5495),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5497),
    [anon_sym_COMMA] = ACTIONS(5497),
    [anon_sym_RPAREN] = ACTIONS(5497),
    [aux_sym_preproc_if_token2] = ACTIONS(5497),
    [aux_sym_preproc_else_token1] = ACTIONS(5497),
    [aux_sym_preproc_elif_token1] = ACTIONS(5495),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5497),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5497),
    [anon_sym_LPAREN2] = ACTIONS(5497),
    [anon_sym_DASH] = ACTIONS(5495),
    [anon_sym_PLUS] = ACTIONS(5495),
    [anon_sym_STAR] = ACTIONS(5495),
    [anon_sym_SLASH] = ACTIONS(5495),
    [anon_sym_PERCENT] = ACTIONS(5495),
    [anon_sym_PIPE_PIPE] = ACTIONS(5497),
    [anon_sym_AMP_AMP] = ACTIONS(5497),
    [anon_sym_PIPE] = ACTIONS(5495),
    [anon_sym_CARET] = ACTIONS(5495),
    [anon_sym_AMP] = ACTIONS(5495),
    [anon_sym_EQ_EQ] = ACTIONS(5497),
    [anon_sym_BANG_EQ] = ACTIONS(5497),
    [anon_sym_GT] = ACTIONS(5495),
    [anon_sym_GT_EQ] = ACTIONS(5497),
    [anon_sym_LT_EQ] = ACTIONS(5495),
    [anon_sym_LT] = ACTIONS(5495),
    [anon_sym_LT_LT] = ACTIONS(5495),
    [anon_sym_GT_GT] = ACTIONS(5495),
    [anon_sym_COLON] = ACTIONS(5497),
    [anon_sym_SEMI] = ACTIONS(5497),
    [anon_sym___attribute__] = ACTIONS(5495),
    [anon_sym_LBRACE] = ACTIONS(5497),
    [anon_sym_RBRACE] = ACTIONS(5497),
    [anon_sym_LBRACK] = ACTIONS(5497),
    [anon_sym_RBRACK] = ACTIONS(5497),
    [anon_sym_EQ] = ACTIONS(5495),
    [anon_sym_QMARK] = ACTIONS(5497),
    [anon_sym_STAR_EQ] = ACTIONS(5497),
    [anon_sym_SLASH_EQ] = ACTIONS(5497),
    [anon_sym_PERCENT_EQ] = ACTIONS(5497),
    [anon_sym_PLUS_EQ] = ACTIONS(5497),
    [anon_sym_DASH_EQ] = ACTIONS(5497),
    [anon_sym_LT_LT_EQ] = ACTIONS(5497),
    [anon_sym_GT_GT_EQ] = ACTIONS(5497),
    [anon_sym_AMP_EQ] = ACTIONS(5497),
    [anon_sym_CARET_EQ] = ACTIONS(5497),
    [anon_sym_PIPE_EQ] = ACTIONS(5497),
    [anon_sym_and_eq] = ACTIONS(5495),
    [anon_sym_or_eq] = ACTIONS(5495),
    [anon_sym_xor_eq] = ACTIONS(5495),
    [anon_sym_LT_EQ_GT] = ACTIONS(5497),
    [anon_sym_or] = ACTIONS(5495),
    [anon_sym_and] = ACTIONS(5495),
    [anon_sym_bitor] = ACTIONS(5495),
    [anon_sym_xor] = ACTIONS(5495),
    [anon_sym_bitand] = ACTIONS(5495),
    [anon_sym_not_eq] = ACTIONS(5495),
    [anon_sym_DASH_DASH] = ACTIONS(5497),
    [anon_sym_PLUS_PLUS] = ACTIONS(5497),
    [anon_sym_DOT] = ACTIONS(5495),
    [anon_sym_DOT_STAR] = ACTIONS(5497),
    [anon_sym_DASH_GT] = ACTIONS(5497),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5495),
    [anon_sym_decltype] = ACTIONS(5495),
  },
  [2602] = {
    [sym_identifier] = ACTIONS(5503),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5505),
    [anon_sym_COMMA] = ACTIONS(5505),
    [anon_sym_RPAREN] = ACTIONS(5505),
    [aux_sym_preproc_if_token2] = ACTIONS(5505),
    [aux_sym_preproc_else_token1] = ACTIONS(5505),
    [aux_sym_preproc_elif_token1] = ACTIONS(5503),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5505),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5505),
    [anon_sym_LPAREN2] = ACTIONS(5505),
    [anon_sym_DASH] = ACTIONS(5503),
    [anon_sym_PLUS] = ACTIONS(5503),
    [anon_sym_STAR] = ACTIONS(5503),
    [anon_sym_SLASH] = ACTIONS(5503),
    [anon_sym_PERCENT] = ACTIONS(5503),
    [anon_sym_PIPE_PIPE] = ACTIONS(5505),
    [anon_sym_AMP_AMP] = ACTIONS(5505),
    [anon_sym_PIPE] = ACTIONS(5503),
    [anon_sym_CARET] = ACTIONS(5503),
    [anon_sym_AMP] = ACTIONS(5503),
    [anon_sym_EQ_EQ] = ACTIONS(5505),
    [anon_sym_BANG_EQ] = ACTIONS(5505),
    [anon_sym_GT] = ACTIONS(5503),
    [anon_sym_GT_EQ] = ACTIONS(5505),
    [anon_sym_LT_EQ] = ACTIONS(5503),
    [anon_sym_LT] = ACTIONS(5503),
    [anon_sym_LT_LT] = ACTIONS(5503),
    [anon_sym_GT_GT] = ACTIONS(5503),
    [anon_sym_COLON] = ACTIONS(5505),
    [anon_sym_SEMI] = ACTIONS(5505),
    [anon_sym___attribute__] = ACTIONS(5503),
    [anon_sym_LBRACE] = ACTIONS(5505),
    [anon_sym_RBRACE] = ACTIONS(5505),
    [anon_sym_LBRACK] = ACTIONS(5505),
    [anon_sym_RBRACK] = ACTIONS(5505),
    [anon_sym_EQ] = ACTIONS(5503),
    [anon_sym_QMARK] = ACTIONS(5505),
    [anon_sym_STAR_EQ] = ACTIONS(5505),
    [anon_sym_SLASH_EQ] = ACTIONS(5505),
    [anon_sym_PERCENT_EQ] = ACTIONS(5505),
    [anon_sym_PLUS_EQ] = ACTIONS(5505),
    [anon_sym_DASH_EQ] = ACTIONS(5505),
    [anon_sym_LT_LT_EQ] = ACTIONS(5505),
    [anon_sym_GT_GT_EQ] = ACTIONS(5505),
    [anon_sym_AMP_EQ] = ACTIONS(5505),
    [anon_sym_CARET_EQ] = ACTIONS(5505),
    [anon_sym_PIPE_EQ] = ACTIONS(5505),
    [anon_sym_and_eq] = ACTIONS(5503),
    [anon_sym_or_eq] = ACTIONS(5503),
    [anon_sym_xor_eq] = ACTIONS(5503),
    [anon_sym_LT_EQ_GT] = ACTIONS(5505),
    [anon_sym_or] = ACTIONS(5503),
    [anon_sym_and] = ACTIONS(5503),
    [anon_sym_bitor] = ACTIONS(5503),
    [anon_sym_xor] = ACTIONS(5503),
    [anon_sym_bitand] = ACTIONS(5503),
    [anon_sym_not_eq] = ACTIONS(5503),
    [anon_sym_DASH_DASH] = ACTIONS(5505),
    [anon_sym_PLUS_PLUS] = ACTIONS(5505),
    [anon_sym_DOT] = ACTIONS(5503),
    [anon_sym_DOT_STAR] = ACTIONS(5505),
    [anon_sym_DASH_GT] = ACTIONS(5505),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5503),
    [anon_sym_decltype] = ACTIONS(5503),
  },
  [2603] = {
    [sym_identifier] = ACTIONS(5511),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5513),
    [anon_sym_COMMA] = ACTIONS(5513),
    [anon_sym_RPAREN] = ACTIONS(5513),
    [aux_sym_preproc_if_token2] = ACTIONS(5513),
    [aux_sym_preproc_else_token1] = ACTIONS(5513),
    [aux_sym_preproc_elif_token1] = ACTIONS(5511),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5513),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5513),
    [anon_sym_LPAREN2] = ACTIONS(5513),
    [anon_sym_DASH] = ACTIONS(5511),
    [anon_sym_PLUS] = ACTIONS(5511),
    [anon_sym_STAR] = ACTIONS(5511),
    [anon_sym_SLASH] = ACTIONS(5511),
    [anon_sym_PERCENT] = ACTIONS(5511),
    [anon_sym_PIPE_PIPE] = ACTIONS(5513),
    [anon_sym_AMP_AMP] = ACTIONS(5513),
    [anon_sym_PIPE] = ACTIONS(5511),
    [anon_sym_CARET] = ACTIONS(5511),
    [anon_sym_AMP] = ACTIONS(5511),
    [anon_sym_EQ_EQ] = ACTIONS(5513),
    [anon_sym_BANG_EQ] = ACTIONS(5513),
    [anon_sym_GT] = ACTIONS(5511),
    [anon_sym_GT_EQ] = ACTIONS(5513),
    [anon_sym_LT_EQ] = ACTIONS(5511),
    [anon_sym_LT] = ACTIONS(5511),
    [anon_sym_LT_LT] = ACTIONS(5511),
    [anon_sym_GT_GT] = ACTIONS(5511),
    [anon_sym_COLON] = ACTIONS(5513),
    [anon_sym_SEMI] = ACTIONS(5513),
    [anon_sym___attribute__] = ACTIONS(5511),
    [anon_sym_LBRACE] = ACTIONS(5513),
    [anon_sym_RBRACE] = ACTIONS(5513),
    [anon_sym_LBRACK] = ACTIONS(5513),
    [anon_sym_RBRACK] = ACTIONS(5513),
    [anon_sym_EQ] = ACTIONS(5511),
    [anon_sym_QMARK] = ACTIONS(5513),
    [anon_sym_STAR_EQ] = ACTIONS(5513),
    [anon_sym_SLASH_EQ] = ACTIONS(5513),
    [anon_sym_PERCENT_EQ] = ACTIONS(5513),
    [anon_sym_PLUS_EQ] = ACTIONS(5513),
    [anon_sym_DASH_EQ] = ACTIONS(5513),
    [anon_sym_LT_LT_EQ] = ACTIONS(5513),
    [anon_sym_GT_GT_EQ] = ACTIONS(5513),
    [anon_sym_AMP_EQ] = ACTIONS(5513),
    [anon_sym_CARET_EQ] = ACTIONS(5513),
    [anon_sym_PIPE_EQ] = ACTIONS(5513),
    [anon_sym_and_eq] = ACTIONS(5511),
    [anon_sym_or_eq] = ACTIONS(5511),
    [anon_sym_xor_eq] = ACTIONS(5511),
    [anon_sym_LT_EQ_GT] = ACTIONS(5513),
    [anon_sym_or] = ACTIONS(5511),
    [anon_sym_and] = ACTIONS(5511),
    [anon_sym_bitor] = ACTIONS(5511),
    [anon_sym_xor] = ACTIONS(5511),
    [anon_sym_bitand] = ACTIONS(5511),
    [anon_sym_not_eq] = ACTIONS(5511),
    [anon_sym_DASH_DASH] = ACTIONS(5513),
    [anon_sym_PLUS_PLUS] = ACTIONS(5513),
    [anon_sym_DOT] = ACTIONS(5511),
    [anon_sym_DOT_STAR] = ACTIONS(5513),
    [anon_sym_DASH_GT] = ACTIONS(5513),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5511),
    [anon_sym_decltype] = ACTIONS(5511),
  },
  [2604] = {
    [sym_identifier] = ACTIONS(5537),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5539),
    [anon_sym_COMMA] = ACTIONS(5539),
    [anon_sym_RPAREN] = ACTIONS(5539),
    [aux_sym_preproc_if_token2] = ACTIONS(5539),
    [aux_sym_preproc_else_token1] = ACTIONS(5539),
    [aux_sym_preproc_elif_token1] = ACTIONS(5537),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5539),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5539),
    [anon_sym_LPAREN2] = ACTIONS(5539),
    [anon_sym_DASH] = ACTIONS(5537),
    [anon_sym_PLUS] = ACTIONS(5537),
    [anon_sym_STAR] = ACTIONS(5537),
    [anon_sym_SLASH] = ACTIONS(5537),
    [anon_sym_PERCENT] = ACTIONS(5537),
    [anon_sym_PIPE_PIPE] = ACTIONS(5539),
    [anon_sym_AMP_AMP] = ACTIONS(5539),
    [anon_sym_PIPE] = ACTIONS(5537),
    [anon_sym_CARET] = ACTIONS(5537),
    [anon_sym_AMP] = ACTIONS(5537),
    [anon_sym_EQ_EQ] = ACTIONS(5539),
    [anon_sym_BANG_EQ] = ACTIONS(5539),
    [anon_sym_GT] = ACTIONS(5537),
    [anon_sym_GT_EQ] = ACTIONS(5539),
    [anon_sym_LT_EQ] = ACTIONS(5537),
    [anon_sym_LT] = ACTIONS(5537),
    [anon_sym_LT_LT] = ACTIONS(5537),
    [anon_sym_GT_GT] = ACTIONS(5537),
    [anon_sym_COLON] = ACTIONS(5539),
    [anon_sym_SEMI] = ACTIONS(5539),
    [anon_sym___attribute__] = ACTIONS(5537),
    [anon_sym_LBRACE] = ACTIONS(5539),
    [anon_sym_RBRACE] = ACTIONS(5539),
    [anon_sym_LBRACK] = ACTIONS(5539),
    [anon_sym_RBRACK] = ACTIONS(5539),
    [anon_sym_EQ] = ACTIONS(5537),
    [anon_sym_QMARK] = ACTIONS(5539),
    [anon_sym_STAR_EQ] = ACTIONS(5539),
    [anon_sym_SLASH_EQ] = ACTIONS(5539),
    [anon_sym_PERCENT_EQ] = ACTIONS(5539),
    [anon_sym_PLUS_EQ] = ACTIONS(5539),
    [anon_sym_DASH_EQ] = ACTIONS(5539),
    [anon_sym_LT_LT_EQ] = ACTIONS(5539),
    [anon_sym_GT_GT_EQ] = ACTIONS(5539),
    [anon_sym_AMP_EQ] = ACTIONS(5539),
    [anon_sym_CARET_EQ] = ACTIONS(5539),
    [anon_sym_PIPE_EQ] = ACTIONS(5539),
    [anon_sym_and_eq] = ACTIONS(5537),
    [anon_sym_or_eq] = ACTIONS(5537),
    [anon_sym_xor_eq] = ACTIONS(5537),
    [anon_sym_LT_EQ_GT] = ACTIONS(5539),
    [anon_sym_or] = ACTIONS(5537),
    [anon_sym_and] = ACTIONS(5537),
    [anon_sym_bitor] = ACTIONS(5537),
    [anon_sym_xor] = ACTIONS(5537),
    [anon_sym_bitand] = ACTIONS(5537),
    [anon_sym_not_eq] = ACTIONS(5537),
    [anon_sym_DASH_DASH] = ACTIONS(5539),
    [anon_sym_PLUS_PLUS] = ACTIONS(5539),
    [anon_sym_DOT] = ACTIONS(5537),
    [anon_sym_DOT_STAR] = ACTIONS(5539),
    [anon_sym_DASH_GT] = ACTIONS(5539),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5537),
    [anon_sym_decltype] = ACTIONS(5537),
  },
  [2605] = {
    [sym_identifier] = ACTIONS(5499),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5501),
    [anon_sym_COMMA] = ACTIONS(5501),
    [anon_sym_RPAREN] = ACTIONS(5501),
    [aux_sym_preproc_if_token2] = ACTIONS(5501),
    [aux_sym_preproc_else_token1] = ACTIONS(5501),
    [aux_sym_preproc_elif_token1] = ACTIONS(5499),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5501),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5501),
    [anon_sym_LPAREN2] = ACTIONS(5501),
    [anon_sym_DASH] = ACTIONS(5499),
    [anon_sym_PLUS] = ACTIONS(5499),
    [anon_sym_STAR] = ACTIONS(5499),
    [anon_sym_SLASH] = ACTIONS(5499),
    [anon_sym_PERCENT] = ACTIONS(5499),
    [anon_sym_PIPE_PIPE] = ACTIONS(5501),
    [anon_sym_AMP_AMP] = ACTIONS(5501),
    [anon_sym_PIPE] = ACTIONS(5499),
    [anon_sym_CARET] = ACTIONS(5499),
    [anon_sym_AMP] = ACTIONS(5499),
    [anon_sym_EQ_EQ] = ACTIONS(5501),
    [anon_sym_BANG_EQ] = ACTIONS(5501),
    [anon_sym_GT] = ACTIONS(5499),
    [anon_sym_GT_EQ] = ACTIONS(5501),
    [anon_sym_LT_EQ] = ACTIONS(5499),
    [anon_sym_LT] = ACTIONS(5499),
    [anon_sym_LT_LT] = ACTIONS(5499),
    [anon_sym_GT_GT] = ACTIONS(5499),
    [anon_sym_COLON] = ACTIONS(5501),
    [anon_sym_SEMI] = ACTIONS(5501),
    [anon_sym___attribute__] = ACTIONS(5499),
    [anon_sym_LBRACE] = ACTIONS(5501),
    [anon_sym_RBRACE] = ACTIONS(5501),
    [anon_sym_LBRACK] = ACTIONS(5501),
    [anon_sym_RBRACK] = ACTIONS(5501),
    [anon_sym_EQ] = ACTIONS(5499),
    [anon_sym_QMARK] = ACTIONS(5501),
    [anon_sym_STAR_EQ] = ACTIONS(5501),
    [anon_sym_SLASH_EQ] = ACTIONS(5501),
    [anon_sym_PERCENT_EQ] = ACTIONS(5501),
    [anon_sym_PLUS_EQ] = ACTIONS(5501),
    [anon_sym_DASH_EQ] = ACTIONS(5501),
    [anon_sym_LT_LT_EQ] = ACTIONS(5501),
    [anon_sym_GT_GT_EQ] = ACTIONS(5501),
    [anon_sym_AMP_EQ] = ACTIONS(5501),
    [anon_sym_CARET_EQ] = ACTIONS(5501),
    [anon_sym_PIPE_EQ] = ACTIONS(5501),
    [anon_sym_and_eq] = ACTIONS(5499),
    [anon_sym_or_eq] = ACTIONS(5499),
    [anon_sym_xor_eq] = ACTIONS(5499),
    [anon_sym_LT_EQ_GT] = ACTIONS(5501),
    [anon_sym_or] = ACTIONS(5499),
    [anon_sym_and] = ACTIONS(5499),
    [anon_sym_bitor] = ACTIONS(5499),
    [anon_sym_xor] = ACTIONS(5499),
    [anon_sym_bitand] = ACTIONS(5499),
    [anon_sym_not_eq] = ACTIONS(5499),
    [anon_sym_DASH_DASH] = ACTIONS(5501),
    [anon_sym_PLUS_PLUS] = ACTIONS(5501),
    [anon_sym_DOT] = ACTIONS(5499),
    [anon_sym_DOT_STAR] = ACTIONS(5501),
    [anon_sym_DASH_GT] = ACTIONS(5501),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5499),
    [anon_sym_decltype] = ACTIONS(5499),
  },
  [2606] = {
    [sym_identifier] = ACTIONS(2502),
    [anon_sym___extension__] = ACTIONS(2502),
    [anon_sym_in] = ACTIONS(2502),
    [anon_sym_out] = ACTIONS(2502),
    [anon_sym_inout] = ACTIONS(2502),
    [anon_sym_extern] = ACTIONS(2502),
    [anon_sym___attribute__] = ACTIONS(2502),
    [anon_sym_COLON_COLON] = ACTIONS(2504),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2504),
    [anon_sym___declspec] = ACTIONS(2502),
    [anon_sym_signed] = ACTIONS(2502),
    [anon_sym_unsigned] = ACTIONS(2502),
    [anon_sym_long] = ACTIONS(2502),
    [anon_sym_short] = ACTIONS(2502),
    [anon_sym_static] = ACTIONS(2502),
    [anon_sym_register] = ACTIONS(2502),
    [anon_sym_inline] = ACTIONS(2502),
    [anon_sym___inline] = ACTIONS(2502),
    [anon_sym___inline__] = ACTIONS(2502),
    [anon_sym___forceinline] = ACTIONS(2502),
    [anon_sym_thread_local] = ACTIONS(2502),
    [anon_sym___thread] = ACTIONS(2502),
    [anon_sym_const] = ACTIONS(2502),
    [anon_sym_constexpr] = ACTIONS(2502),
    [anon_sym_volatile] = ACTIONS(2502),
    [anon_sym_restrict] = ACTIONS(2502),
    [anon_sym___restrict__] = ACTIONS(2502),
    [anon_sym__Atomic] = ACTIONS(2502),
    [anon_sym__Noreturn] = ACTIONS(2502),
    [anon_sym_noreturn] = ACTIONS(2502),
    [anon_sym_mutable] = ACTIONS(2502),
    [anon_sym_constinit] = ACTIONS(2502),
    [anon_sym_consteval] = ACTIONS(2502),
    [anon_sym_alignas] = ACTIONS(2502),
    [anon_sym__Alignas] = ACTIONS(2502),
    [sym_primitive_type] = ACTIONS(2502),
    [anon_sym_enum] = ACTIONS(2502),
    [anon_sym_class] = ACTIONS(2502),
    [anon_sym_struct] = ACTIONS(2502),
    [anon_sym_union] = ACTIONS(2502),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2502),
    [anon_sym_decltype] = ACTIONS(2502),
    [sym_virtual] = ACTIONS(2502),
    [anon_sym_typename] = ACTIONS(2502),
    [anon_sym_template] = ACTIONS(2502),
    [anon_sym_precise] = ACTIONS(2502),
    [anon_sym_shared] = ACTIONS(2502),
    [anon_sym_groupshared] = ACTIONS(2502),
    [anon_sym_uniform] = ACTIONS(2502),
    [anon_sym_row_major] = ACTIONS(2502),
    [anon_sym_column_major] = ACTIONS(2502),
    [anon_sym_globallycoherent] = ACTIONS(2502),
    [anon_sym_centroid] = ACTIONS(2502),
    [anon_sym_noperspective] = ACTIONS(2502),
    [anon_sym_nointerpolation] = ACTIONS(2502),
    [anon_sym_sample] = ACTIONS(2502),
    [anon_sym_linear] = ACTIONS(2502),
    [anon_sym_snorm] = ACTIONS(2502),
    [anon_sym_unorm] = ACTIONS(2502),
    [anon_sym_point] = ACTIONS(2502),
    [anon_sym_line] = ACTIONS(2502),
    [anon_sym_triangleadj] = ACTIONS(2502),
    [anon_sym_lineadj] = ACTIONS(2502),
    [anon_sym_triangle] = ACTIONS(2502),
  },
  [2607] = {
    [sym_identifier] = ACTIONS(5439),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5441),
    [anon_sym_COMMA] = ACTIONS(5441),
    [anon_sym_RPAREN] = ACTIONS(5441),
    [aux_sym_preproc_if_token2] = ACTIONS(5441),
    [aux_sym_preproc_else_token1] = ACTIONS(5441),
    [aux_sym_preproc_elif_token1] = ACTIONS(5439),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5441),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5441),
    [anon_sym_LPAREN2] = ACTIONS(5441),
    [anon_sym_DASH] = ACTIONS(5439),
    [anon_sym_PLUS] = ACTIONS(5439),
    [anon_sym_STAR] = ACTIONS(5439),
    [anon_sym_SLASH] = ACTIONS(5439),
    [anon_sym_PERCENT] = ACTIONS(5439),
    [anon_sym_PIPE_PIPE] = ACTIONS(5441),
    [anon_sym_AMP_AMP] = ACTIONS(5441),
    [anon_sym_PIPE] = ACTIONS(5439),
    [anon_sym_CARET] = ACTIONS(5439),
    [anon_sym_AMP] = ACTIONS(5439),
    [anon_sym_EQ_EQ] = ACTIONS(5441),
    [anon_sym_BANG_EQ] = ACTIONS(5441),
    [anon_sym_GT] = ACTIONS(5439),
    [anon_sym_GT_EQ] = ACTIONS(5441),
    [anon_sym_LT_EQ] = ACTIONS(5439),
    [anon_sym_LT] = ACTIONS(5439),
    [anon_sym_LT_LT] = ACTIONS(5439),
    [anon_sym_GT_GT] = ACTIONS(5439),
    [anon_sym_COLON] = ACTIONS(5441),
    [anon_sym_SEMI] = ACTIONS(5441),
    [anon_sym___attribute__] = ACTIONS(5439),
    [anon_sym_LBRACE] = ACTIONS(5441),
    [anon_sym_RBRACE] = ACTIONS(5441),
    [anon_sym_LBRACK] = ACTIONS(5441),
    [anon_sym_RBRACK] = ACTIONS(5441),
    [anon_sym_EQ] = ACTIONS(5439),
    [anon_sym_QMARK] = ACTIONS(5441),
    [anon_sym_STAR_EQ] = ACTIONS(5441),
    [anon_sym_SLASH_EQ] = ACTIONS(5441),
    [anon_sym_PERCENT_EQ] = ACTIONS(5441),
    [anon_sym_PLUS_EQ] = ACTIONS(5441),
    [anon_sym_DASH_EQ] = ACTIONS(5441),
    [anon_sym_LT_LT_EQ] = ACTIONS(5441),
    [anon_sym_GT_GT_EQ] = ACTIONS(5441),
    [anon_sym_AMP_EQ] = ACTIONS(5441),
    [anon_sym_CARET_EQ] = ACTIONS(5441),
    [anon_sym_PIPE_EQ] = ACTIONS(5441),
    [anon_sym_and_eq] = ACTIONS(5439),
    [anon_sym_or_eq] = ACTIONS(5439),
    [anon_sym_xor_eq] = ACTIONS(5439),
    [anon_sym_LT_EQ_GT] = ACTIONS(5441),
    [anon_sym_or] = ACTIONS(5439),
    [anon_sym_and] = ACTIONS(5439),
    [anon_sym_bitor] = ACTIONS(5439),
    [anon_sym_xor] = ACTIONS(5439),
    [anon_sym_bitand] = ACTIONS(5439),
    [anon_sym_not_eq] = ACTIONS(5439),
    [anon_sym_DASH_DASH] = ACTIONS(5441),
    [anon_sym_PLUS_PLUS] = ACTIONS(5441),
    [anon_sym_DOT] = ACTIONS(5439),
    [anon_sym_DOT_STAR] = ACTIONS(5441),
    [anon_sym_DASH_GT] = ACTIONS(5441),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5439),
    [anon_sym_decltype] = ACTIONS(5439),
  },
  [2608] = {
    [sym_identifier] = ACTIONS(5491),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5493),
    [anon_sym_COMMA] = ACTIONS(5493),
    [anon_sym_RPAREN] = ACTIONS(5493),
    [aux_sym_preproc_if_token2] = ACTIONS(5493),
    [aux_sym_preproc_else_token1] = ACTIONS(5493),
    [aux_sym_preproc_elif_token1] = ACTIONS(5491),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5493),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5493),
    [anon_sym_LPAREN2] = ACTIONS(5493),
    [anon_sym_DASH] = ACTIONS(5491),
    [anon_sym_PLUS] = ACTIONS(5491),
    [anon_sym_STAR] = ACTIONS(5491),
    [anon_sym_SLASH] = ACTIONS(5491),
    [anon_sym_PERCENT] = ACTIONS(5491),
    [anon_sym_PIPE_PIPE] = ACTIONS(5493),
    [anon_sym_AMP_AMP] = ACTIONS(5493),
    [anon_sym_PIPE] = ACTIONS(5491),
    [anon_sym_CARET] = ACTIONS(5491),
    [anon_sym_AMP] = ACTIONS(5491),
    [anon_sym_EQ_EQ] = ACTIONS(5493),
    [anon_sym_BANG_EQ] = ACTIONS(5493),
    [anon_sym_GT] = ACTIONS(5491),
    [anon_sym_GT_EQ] = ACTIONS(5493),
    [anon_sym_LT_EQ] = ACTIONS(5491),
    [anon_sym_LT] = ACTIONS(5491),
    [anon_sym_LT_LT] = ACTIONS(5491),
    [anon_sym_GT_GT] = ACTIONS(5491),
    [anon_sym_COLON] = ACTIONS(5493),
    [anon_sym_SEMI] = ACTIONS(5493),
    [anon_sym___attribute__] = ACTIONS(5491),
    [anon_sym_LBRACE] = ACTIONS(5493),
    [anon_sym_RBRACE] = ACTIONS(5493),
    [anon_sym_LBRACK] = ACTIONS(5493),
    [anon_sym_RBRACK] = ACTIONS(5493),
    [anon_sym_EQ] = ACTIONS(5491),
    [anon_sym_QMARK] = ACTIONS(5493),
    [anon_sym_STAR_EQ] = ACTIONS(5493),
    [anon_sym_SLASH_EQ] = ACTIONS(5493),
    [anon_sym_PERCENT_EQ] = ACTIONS(5493),
    [anon_sym_PLUS_EQ] = ACTIONS(5493),
    [anon_sym_DASH_EQ] = ACTIONS(5493),
    [anon_sym_LT_LT_EQ] = ACTIONS(5493),
    [anon_sym_GT_GT_EQ] = ACTIONS(5493),
    [anon_sym_AMP_EQ] = ACTIONS(5493),
    [anon_sym_CARET_EQ] = ACTIONS(5493),
    [anon_sym_PIPE_EQ] = ACTIONS(5493),
    [anon_sym_and_eq] = ACTIONS(5491),
    [anon_sym_or_eq] = ACTIONS(5491),
    [anon_sym_xor_eq] = ACTIONS(5491),
    [anon_sym_LT_EQ_GT] = ACTIONS(5493),
    [anon_sym_or] = ACTIONS(5491),
    [anon_sym_and] = ACTIONS(5491),
    [anon_sym_bitor] = ACTIONS(5491),
    [anon_sym_xor] = ACTIONS(5491),
    [anon_sym_bitand] = ACTIONS(5491),
    [anon_sym_not_eq] = ACTIONS(5491),
    [anon_sym_DASH_DASH] = ACTIONS(5493),
    [anon_sym_PLUS_PLUS] = ACTIONS(5493),
    [anon_sym_DOT] = ACTIONS(5491),
    [anon_sym_DOT_STAR] = ACTIONS(5493),
    [anon_sym_DASH_GT] = ACTIONS(5493),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5491),
    [anon_sym_decltype] = ACTIONS(5491),
  },
  [2609] = {
    [sym_identifier] = ACTIONS(2118),
    [anon_sym___extension__] = ACTIONS(2118),
    [anon_sym_in] = ACTIONS(2118),
    [anon_sym_out] = ACTIONS(2118),
    [anon_sym_inout] = ACTIONS(2118),
    [anon_sym_extern] = ACTIONS(2118),
    [anon_sym___attribute__] = ACTIONS(2118),
    [anon_sym_COLON_COLON] = ACTIONS(2120),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2120),
    [anon_sym___declspec] = ACTIONS(2118),
    [anon_sym_signed] = ACTIONS(2118),
    [anon_sym_unsigned] = ACTIONS(2118),
    [anon_sym_long] = ACTIONS(2118),
    [anon_sym_short] = ACTIONS(2118),
    [anon_sym_static] = ACTIONS(2118),
    [anon_sym_register] = ACTIONS(2118),
    [anon_sym_inline] = ACTIONS(2118),
    [anon_sym___inline] = ACTIONS(2118),
    [anon_sym___inline__] = ACTIONS(2118),
    [anon_sym___forceinline] = ACTIONS(2118),
    [anon_sym_thread_local] = ACTIONS(2118),
    [anon_sym___thread] = ACTIONS(2118),
    [anon_sym_const] = ACTIONS(2118),
    [anon_sym_constexpr] = ACTIONS(2118),
    [anon_sym_volatile] = ACTIONS(2118),
    [anon_sym_restrict] = ACTIONS(2118),
    [anon_sym___restrict__] = ACTIONS(2118),
    [anon_sym__Atomic] = ACTIONS(2118),
    [anon_sym__Noreturn] = ACTIONS(2118),
    [anon_sym_noreturn] = ACTIONS(2118),
    [anon_sym_mutable] = ACTIONS(2118),
    [anon_sym_constinit] = ACTIONS(2118),
    [anon_sym_consteval] = ACTIONS(2118),
    [anon_sym_alignas] = ACTIONS(2118),
    [anon_sym__Alignas] = ACTIONS(2118),
    [sym_primitive_type] = ACTIONS(2118),
    [anon_sym_enum] = ACTIONS(2118),
    [anon_sym_class] = ACTIONS(2118),
    [anon_sym_struct] = ACTIONS(2118),
    [anon_sym_union] = ACTIONS(2118),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2118),
    [anon_sym_decltype] = ACTIONS(2118),
    [sym_virtual] = ACTIONS(2118),
    [anon_sym_typename] = ACTIONS(2118),
    [anon_sym_template] = ACTIONS(2118),
    [anon_sym_precise] = ACTIONS(2118),
    [anon_sym_shared] = ACTIONS(2118),
    [anon_sym_groupshared] = ACTIONS(2118),
    [anon_sym_uniform] = ACTIONS(2118),
    [anon_sym_row_major] = ACTIONS(2118),
    [anon_sym_column_major] = ACTIONS(2118),
    [anon_sym_globallycoherent] = ACTIONS(2118),
    [anon_sym_centroid] = ACTIONS(2118),
    [anon_sym_noperspective] = ACTIONS(2118),
    [anon_sym_nointerpolation] = ACTIONS(2118),
    [anon_sym_sample] = ACTIONS(2118),
    [anon_sym_linear] = ACTIONS(2118),
    [anon_sym_snorm] = ACTIONS(2118),
    [anon_sym_unorm] = ACTIONS(2118),
    [anon_sym_point] = ACTIONS(2118),
    [anon_sym_line] = ACTIONS(2118),
    [anon_sym_triangleadj] = ACTIONS(2118),
    [anon_sym_lineadj] = ACTIONS(2118),
    [anon_sym_triangle] = ACTIONS(2118),
  },
  [2610] = {
    [sym_identifier] = ACTIONS(5487),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5489),
    [anon_sym_COMMA] = ACTIONS(5489),
    [anon_sym_RPAREN] = ACTIONS(5489),
    [aux_sym_preproc_if_token2] = ACTIONS(5489),
    [aux_sym_preproc_else_token1] = ACTIONS(5489),
    [aux_sym_preproc_elif_token1] = ACTIONS(5487),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5489),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5489),
    [anon_sym_LPAREN2] = ACTIONS(5489),
    [anon_sym_DASH] = ACTIONS(5487),
    [anon_sym_PLUS] = ACTIONS(5487),
    [anon_sym_STAR] = ACTIONS(5487),
    [anon_sym_SLASH] = ACTIONS(5487),
    [anon_sym_PERCENT] = ACTIONS(5487),
    [anon_sym_PIPE_PIPE] = ACTIONS(5489),
    [anon_sym_AMP_AMP] = ACTIONS(5489),
    [anon_sym_PIPE] = ACTIONS(5487),
    [anon_sym_CARET] = ACTIONS(5487),
    [anon_sym_AMP] = ACTIONS(5487),
    [anon_sym_EQ_EQ] = ACTIONS(5489),
    [anon_sym_BANG_EQ] = ACTIONS(5489),
    [anon_sym_GT] = ACTIONS(5487),
    [anon_sym_GT_EQ] = ACTIONS(5489),
    [anon_sym_LT_EQ] = ACTIONS(5487),
    [anon_sym_LT] = ACTIONS(5487),
    [anon_sym_LT_LT] = ACTIONS(5487),
    [anon_sym_GT_GT] = ACTIONS(5487),
    [anon_sym_COLON] = ACTIONS(5489),
    [anon_sym_SEMI] = ACTIONS(5489),
    [anon_sym___attribute__] = ACTIONS(5487),
    [anon_sym_LBRACE] = ACTIONS(5489),
    [anon_sym_RBRACE] = ACTIONS(5489),
    [anon_sym_LBRACK] = ACTIONS(5489),
    [anon_sym_RBRACK] = ACTIONS(5489),
    [anon_sym_EQ] = ACTIONS(5487),
    [anon_sym_QMARK] = ACTIONS(5489),
    [anon_sym_STAR_EQ] = ACTIONS(5489),
    [anon_sym_SLASH_EQ] = ACTIONS(5489),
    [anon_sym_PERCENT_EQ] = ACTIONS(5489),
    [anon_sym_PLUS_EQ] = ACTIONS(5489),
    [anon_sym_DASH_EQ] = ACTIONS(5489),
    [anon_sym_LT_LT_EQ] = ACTIONS(5489),
    [anon_sym_GT_GT_EQ] = ACTIONS(5489),
    [anon_sym_AMP_EQ] = ACTIONS(5489),
    [anon_sym_CARET_EQ] = ACTIONS(5489),
    [anon_sym_PIPE_EQ] = ACTIONS(5489),
    [anon_sym_and_eq] = ACTIONS(5487),
    [anon_sym_or_eq] = ACTIONS(5487),
    [anon_sym_xor_eq] = ACTIONS(5487),
    [anon_sym_LT_EQ_GT] = ACTIONS(5489),
    [anon_sym_or] = ACTIONS(5487),
    [anon_sym_and] = ACTIONS(5487),
    [anon_sym_bitor] = ACTIONS(5487),
    [anon_sym_xor] = ACTIONS(5487),
    [anon_sym_bitand] = ACTIONS(5487),
    [anon_sym_not_eq] = ACTIONS(5487),
    [anon_sym_DASH_DASH] = ACTIONS(5489),
    [anon_sym_PLUS_PLUS] = ACTIONS(5489),
    [anon_sym_DOT] = ACTIONS(5487),
    [anon_sym_DOT_STAR] = ACTIONS(5489),
    [anon_sym_DASH_GT] = ACTIONS(5489),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5487),
    [anon_sym_decltype] = ACTIONS(5487),
  },
  [2611] = {
    [sym_identifier] = ACTIONS(5545),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5547),
    [anon_sym_COMMA] = ACTIONS(5547),
    [anon_sym_RPAREN] = ACTIONS(5547),
    [aux_sym_preproc_if_token2] = ACTIONS(5547),
    [aux_sym_preproc_else_token1] = ACTIONS(5547),
    [aux_sym_preproc_elif_token1] = ACTIONS(5545),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5547),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5547),
    [anon_sym_LPAREN2] = ACTIONS(5547),
    [anon_sym_DASH] = ACTIONS(5545),
    [anon_sym_PLUS] = ACTIONS(5545),
    [anon_sym_STAR] = ACTIONS(5545),
    [anon_sym_SLASH] = ACTIONS(5545),
    [anon_sym_PERCENT] = ACTIONS(5545),
    [anon_sym_PIPE_PIPE] = ACTIONS(5547),
    [anon_sym_AMP_AMP] = ACTIONS(5547),
    [anon_sym_PIPE] = ACTIONS(5545),
    [anon_sym_CARET] = ACTIONS(5545),
    [anon_sym_AMP] = ACTIONS(5545),
    [anon_sym_EQ_EQ] = ACTIONS(5547),
    [anon_sym_BANG_EQ] = ACTIONS(5547),
    [anon_sym_GT] = ACTIONS(5545),
    [anon_sym_GT_EQ] = ACTIONS(5547),
    [anon_sym_LT_EQ] = ACTIONS(5545),
    [anon_sym_LT] = ACTIONS(5545),
    [anon_sym_LT_LT] = ACTIONS(5545),
    [anon_sym_GT_GT] = ACTIONS(5545),
    [anon_sym_COLON] = ACTIONS(5547),
    [anon_sym_SEMI] = ACTIONS(5547),
    [anon_sym___attribute__] = ACTIONS(5545),
    [anon_sym_LBRACE] = ACTIONS(5547),
    [anon_sym_RBRACE] = ACTIONS(5547),
    [anon_sym_LBRACK] = ACTIONS(5547),
    [anon_sym_RBRACK] = ACTIONS(5547),
    [anon_sym_EQ] = ACTIONS(5545),
    [anon_sym_QMARK] = ACTIONS(5547),
    [anon_sym_STAR_EQ] = ACTIONS(5547),
    [anon_sym_SLASH_EQ] = ACTIONS(5547),
    [anon_sym_PERCENT_EQ] = ACTIONS(5547),
    [anon_sym_PLUS_EQ] = ACTIONS(5547),
    [anon_sym_DASH_EQ] = ACTIONS(5547),
    [anon_sym_LT_LT_EQ] = ACTIONS(5547),
    [anon_sym_GT_GT_EQ] = ACTIONS(5547),
    [anon_sym_AMP_EQ] = ACTIONS(5547),
    [anon_sym_CARET_EQ] = ACTIONS(5547),
    [anon_sym_PIPE_EQ] = ACTIONS(5547),
    [anon_sym_and_eq] = ACTIONS(5545),
    [anon_sym_or_eq] = ACTIONS(5545),
    [anon_sym_xor_eq] = ACTIONS(5545),
    [anon_sym_LT_EQ_GT] = ACTIONS(5547),
    [anon_sym_or] = ACTIONS(5545),
    [anon_sym_and] = ACTIONS(5545),
    [anon_sym_bitor] = ACTIONS(5545),
    [anon_sym_xor] = ACTIONS(5545),
    [anon_sym_bitand] = ACTIONS(5545),
    [anon_sym_not_eq] = ACTIONS(5545),
    [anon_sym_DASH_DASH] = ACTIONS(5547),
    [anon_sym_PLUS_PLUS] = ACTIONS(5547),
    [anon_sym_DOT] = ACTIONS(5545),
    [anon_sym_DOT_STAR] = ACTIONS(5547),
    [anon_sym_DASH_GT] = ACTIONS(5547),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5545),
    [anon_sym_decltype] = ACTIONS(5545),
  },
  [2612] = {
    [sym_identifier] = ACTIONS(5353),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5355),
    [anon_sym_COMMA] = ACTIONS(5355),
    [anon_sym_RPAREN] = ACTIONS(5355),
    [aux_sym_preproc_if_token2] = ACTIONS(5355),
    [aux_sym_preproc_else_token1] = ACTIONS(5355),
    [aux_sym_preproc_elif_token1] = ACTIONS(5353),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5355),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5355),
    [anon_sym_LPAREN2] = ACTIONS(5355),
    [anon_sym_DASH] = ACTIONS(5353),
    [anon_sym_PLUS] = ACTIONS(5353),
    [anon_sym_STAR] = ACTIONS(5353),
    [anon_sym_SLASH] = ACTIONS(5353),
    [anon_sym_PERCENT] = ACTIONS(5353),
    [anon_sym_PIPE_PIPE] = ACTIONS(5355),
    [anon_sym_AMP_AMP] = ACTIONS(5355),
    [anon_sym_PIPE] = ACTIONS(5353),
    [anon_sym_CARET] = ACTIONS(5353),
    [anon_sym_AMP] = ACTIONS(5353),
    [anon_sym_EQ_EQ] = ACTIONS(5355),
    [anon_sym_BANG_EQ] = ACTIONS(5355),
    [anon_sym_GT] = ACTIONS(5353),
    [anon_sym_GT_EQ] = ACTIONS(5355),
    [anon_sym_LT_EQ] = ACTIONS(5353),
    [anon_sym_LT] = ACTIONS(5353),
    [anon_sym_LT_LT] = ACTIONS(5353),
    [anon_sym_GT_GT] = ACTIONS(5353),
    [anon_sym_COLON] = ACTIONS(5355),
    [anon_sym_SEMI] = ACTIONS(5355),
    [anon_sym___attribute__] = ACTIONS(5353),
    [anon_sym_LBRACE] = ACTIONS(5355),
    [anon_sym_RBRACE] = ACTIONS(5355),
    [anon_sym_LBRACK] = ACTIONS(5355),
    [anon_sym_RBRACK] = ACTIONS(5355),
    [anon_sym_EQ] = ACTIONS(5353),
    [anon_sym_QMARK] = ACTIONS(5355),
    [anon_sym_STAR_EQ] = ACTIONS(5355),
    [anon_sym_SLASH_EQ] = ACTIONS(5355),
    [anon_sym_PERCENT_EQ] = ACTIONS(5355),
    [anon_sym_PLUS_EQ] = ACTIONS(5355),
    [anon_sym_DASH_EQ] = ACTIONS(5355),
    [anon_sym_LT_LT_EQ] = ACTIONS(5355),
    [anon_sym_GT_GT_EQ] = ACTIONS(5355),
    [anon_sym_AMP_EQ] = ACTIONS(5355),
    [anon_sym_CARET_EQ] = ACTIONS(5355),
    [anon_sym_PIPE_EQ] = ACTIONS(5355),
    [anon_sym_and_eq] = ACTIONS(5353),
    [anon_sym_or_eq] = ACTIONS(5353),
    [anon_sym_xor_eq] = ACTIONS(5353),
    [anon_sym_LT_EQ_GT] = ACTIONS(5355),
    [anon_sym_or] = ACTIONS(5353),
    [anon_sym_and] = ACTIONS(5353),
    [anon_sym_bitor] = ACTIONS(5353),
    [anon_sym_xor] = ACTIONS(5353),
    [anon_sym_bitand] = ACTIONS(5353),
    [anon_sym_not_eq] = ACTIONS(5353),
    [anon_sym_DASH_DASH] = ACTIONS(5355),
    [anon_sym_PLUS_PLUS] = ACTIONS(5355),
    [anon_sym_DOT] = ACTIONS(5353),
    [anon_sym_DOT_STAR] = ACTIONS(5355),
    [anon_sym_DASH_GT] = ACTIONS(5355),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5353),
    [anon_sym_decltype] = ACTIONS(5353),
  },
  [2613] = {
    [sym_identifier] = ACTIONS(5427),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5429),
    [anon_sym_COMMA] = ACTIONS(5429),
    [anon_sym_RPAREN] = ACTIONS(5429),
    [aux_sym_preproc_if_token2] = ACTIONS(5429),
    [aux_sym_preproc_else_token1] = ACTIONS(5429),
    [aux_sym_preproc_elif_token1] = ACTIONS(5427),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5429),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5429),
    [anon_sym_LPAREN2] = ACTIONS(5429),
    [anon_sym_DASH] = ACTIONS(5427),
    [anon_sym_PLUS] = ACTIONS(5427),
    [anon_sym_STAR] = ACTIONS(5427),
    [anon_sym_SLASH] = ACTIONS(5427),
    [anon_sym_PERCENT] = ACTIONS(5427),
    [anon_sym_PIPE_PIPE] = ACTIONS(5429),
    [anon_sym_AMP_AMP] = ACTIONS(5429),
    [anon_sym_PIPE] = ACTIONS(5427),
    [anon_sym_CARET] = ACTIONS(5427),
    [anon_sym_AMP] = ACTIONS(5427),
    [anon_sym_EQ_EQ] = ACTIONS(5429),
    [anon_sym_BANG_EQ] = ACTIONS(5429),
    [anon_sym_GT] = ACTIONS(5427),
    [anon_sym_GT_EQ] = ACTIONS(5429),
    [anon_sym_LT_EQ] = ACTIONS(5427),
    [anon_sym_LT] = ACTIONS(5427),
    [anon_sym_LT_LT] = ACTIONS(5427),
    [anon_sym_GT_GT] = ACTIONS(5427),
    [anon_sym_COLON] = ACTIONS(5429),
    [anon_sym_SEMI] = ACTIONS(5429),
    [anon_sym___attribute__] = ACTIONS(5427),
    [anon_sym_LBRACE] = ACTIONS(5429),
    [anon_sym_RBRACE] = ACTIONS(5429),
    [anon_sym_LBRACK] = ACTIONS(5429),
    [anon_sym_RBRACK] = ACTIONS(5429),
    [anon_sym_EQ] = ACTIONS(5427),
    [anon_sym_QMARK] = ACTIONS(5429),
    [anon_sym_STAR_EQ] = ACTIONS(5429),
    [anon_sym_SLASH_EQ] = ACTIONS(5429),
    [anon_sym_PERCENT_EQ] = ACTIONS(5429),
    [anon_sym_PLUS_EQ] = ACTIONS(5429),
    [anon_sym_DASH_EQ] = ACTIONS(5429),
    [anon_sym_LT_LT_EQ] = ACTIONS(5429),
    [anon_sym_GT_GT_EQ] = ACTIONS(5429),
    [anon_sym_AMP_EQ] = ACTIONS(5429),
    [anon_sym_CARET_EQ] = ACTIONS(5429),
    [anon_sym_PIPE_EQ] = ACTIONS(5429),
    [anon_sym_and_eq] = ACTIONS(5427),
    [anon_sym_or_eq] = ACTIONS(5427),
    [anon_sym_xor_eq] = ACTIONS(5427),
    [anon_sym_LT_EQ_GT] = ACTIONS(5429),
    [anon_sym_or] = ACTIONS(5427),
    [anon_sym_and] = ACTIONS(5427),
    [anon_sym_bitor] = ACTIONS(5427),
    [anon_sym_xor] = ACTIONS(5427),
    [anon_sym_bitand] = ACTIONS(5427),
    [anon_sym_not_eq] = ACTIONS(5427),
    [anon_sym_DASH_DASH] = ACTIONS(5429),
    [anon_sym_PLUS_PLUS] = ACTIONS(5429),
    [anon_sym_DOT] = ACTIONS(5427),
    [anon_sym_DOT_STAR] = ACTIONS(5429),
    [anon_sym_DASH_GT] = ACTIONS(5429),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5427),
    [anon_sym_decltype] = ACTIONS(5427),
  },
  [2614] = {
    [sym_string_literal] = STATE(2509),
    [sym_raw_string_literal] = STATE(2509),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5840),
    [anon_sym_COMMA] = ACTIONS(5840),
    [anon_sym_RPAREN] = ACTIONS(5840),
    [anon_sym_LPAREN2] = ACTIONS(5840),
    [anon_sym_DASH] = ACTIONS(5838),
    [anon_sym_PLUS] = ACTIONS(5838),
    [anon_sym_STAR] = ACTIONS(5838),
    [anon_sym_SLASH] = ACTIONS(5838),
    [anon_sym_PERCENT] = ACTIONS(5838),
    [anon_sym_PIPE_PIPE] = ACTIONS(5840),
    [anon_sym_AMP_AMP] = ACTIONS(5840),
    [anon_sym_PIPE] = ACTIONS(5838),
    [anon_sym_CARET] = ACTIONS(5838),
    [anon_sym_AMP] = ACTIONS(5838),
    [anon_sym_EQ_EQ] = ACTIONS(5840),
    [anon_sym_BANG_EQ] = ACTIONS(5840),
    [anon_sym_GT] = ACTIONS(5838),
    [anon_sym_GT_EQ] = ACTIONS(5840),
    [anon_sym_LT_EQ] = ACTIONS(5838),
    [anon_sym_LT] = ACTIONS(5838),
    [anon_sym_LT_LT] = ACTIONS(5838),
    [anon_sym_GT_GT] = ACTIONS(5838),
    [anon_sym_LBRACK] = ACTIONS(5840),
    [anon_sym_EQ] = ACTIONS(5838),
    [anon_sym_QMARK] = ACTIONS(5840),
    [anon_sym_STAR_EQ] = ACTIONS(5840),
    [anon_sym_SLASH_EQ] = ACTIONS(5840),
    [anon_sym_PERCENT_EQ] = ACTIONS(5840),
    [anon_sym_PLUS_EQ] = ACTIONS(5840),
    [anon_sym_DASH_EQ] = ACTIONS(5840),
    [anon_sym_LT_LT_EQ] = ACTIONS(5840),
    [anon_sym_GT_GT_EQ] = ACTIONS(5840),
    [anon_sym_AMP_EQ] = ACTIONS(5840),
    [anon_sym_CARET_EQ] = ACTIONS(5840),
    [anon_sym_PIPE_EQ] = ACTIONS(5840),
    [anon_sym_and_eq] = ACTIONS(5838),
    [anon_sym_or_eq] = ACTIONS(5838),
    [anon_sym_xor_eq] = ACTIONS(5838),
    [anon_sym_LT_EQ_GT] = ACTIONS(5840),
    [anon_sym_or] = ACTIONS(5838),
    [anon_sym_and] = ACTIONS(5838),
    [anon_sym_bitor] = ACTIONS(5838),
    [anon_sym_xor] = ACTIONS(5838),
    [anon_sym_bitand] = ACTIONS(5838),
    [anon_sym_not_eq] = ACTIONS(5838),
    [anon_sym_DASH_DASH] = ACTIONS(5840),
    [anon_sym_PLUS_PLUS] = ACTIONS(5840),
    [anon_sym_DOT] = ACTIONS(5838),
    [anon_sym_DOT_STAR] = ACTIONS(5840),
    [anon_sym_DASH_GT] = ACTIONS(5838),
    [anon_sym_L_DQUOTE] = ACTIONS(5192),
    [anon_sym_u_DQUOTE] = ACTIONS(5192),
    [anon_sym_U_DQUOTE] = ACTIONS(5192),
    [anon_sym_u8_DQUOTE] = ACTIONS(5192),
    [anon_sym_DQUOTE] = ACTIONS(5192),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5194),
    [anon_sym_LR_DQUOTE] = ACTIONS(5194),
    [anon_sym_uR_DQUOTE] = ACTIONS(5194),
    [anon_sym_UR_DQUOTE] = ACTIONS(5194),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5194),
    [anon_sym_DASH_GT_STAR] = ACTIONS(5840),
    [sym_literal_suffix] = ACTIONS(6087),
  },
  [2615] = {
    [sym_identifier] = ACTIONS(5443),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5445),
    [anon_sym_COMMA] = ACTIONS(5445),
    [anon_sym_RPAREN] = ACTIONS(5445),
    [aux_sym_preproc_if_token2] = ACTIONS(5445),
    [aux_sym_preproc_else_token1] = ACTIONS(5445),
    [aux_sym_preproc_elif_token1] = ACTIONS(5443),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5445),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5445),
    [anon_sym_LPAREN2] = ACTIONS(5445),
    [anon_sym_DASH] = ACTIONS(5443),
    [anon_sym_PLUS] = ACTIONS(5443),
    [anon_sym_STAR] = ACTIONS(5443),
    [anon_sym_SLASH] = ACTIONS(5443),
    [anon_sym_PERCENT] = ACTIONS(5443),
    [anon_sym_PIPE_PIPE] = ACTIONS(5445),
    [anon_sym_AMP_AMP] = ACTIONS(5445),
    [anon_sym_PIPE] = ACTIONS(5443),
    [anon_sym_CARET] = ACTIONS(5443),
    [anon_sym_AMP] = ACTIONS(5443),
    [anon_sym_EQ_EQ] = ACTIONS(5445),
    [anon_sym_BANG_EQ] = ACTIONS(5445),
    [anon_sym_GT] = ACTIONS(5443),
    [anon_sym_GT_EQ] = ACTIONS(5445),
    [anon_sym_LT_EQ] = ACTIONS(5443),
    [anon_sym_LT] = ACTIONS(5443),
    [anon_sym_LT_LT] = ACTIONS(5443),
    [anon_sym_GT_GT] = ACTIONS(5443),
    [anon_sym_COLON] = ACTIONS(5445),
    [anon_sym_SEMI] = ACTIONS(5445),
    [anon_sym___attribute__] = ACTIONS(5443),
    [anon_sym_LBRACE] = ACTIONS(5445),
    [anon_sym_RBRACE] = ACTIONS(5445),
    [anon_sym_LBRACK] = ACTIONS(5445),
    [anon_sym_RBRACK] = ACTIONS(5445),
    [anon_sym_EQ] = ACTIONS(5443),
    [anon_sym_QMARK] = ACTIONS(5445),
    [anon_sym_STAR_EQ] = ACTIONS(5445),
    [anon_sym_SLASH_EQ] = ACTIONS(5445),
    [anon_sym_PERCENT_EQ] = ACTIONS(5445),
    [anon_sym_PLUS_EQ] = ACTIONS(5445),
    [anon_sym_DASH_EQ] = ACTIONS(5445),
    [anon_sym_LT_LT_EQ] = ACTIONS(5445),
    [anon_sym_GT_GT_EQ] = ACTIONS(5445),
    [anon_sym_AMP_EQ] = ACTIONS(5445),
    [anon_sym_CARET_EQ] = ACTIONS(5445),
    [anon_sym_PIPE_EQ] = ACTIONS(5445),
    [anon_sym_and_eq] = ACTIONS(5443),
    [anon_sym_or_eq] = ACTIONS(5443),
    [anon_sym_xor_eq] = ACTIONS(5443),
    [anon_sym_LT_EQ_GT] = ACTIONS(5445),
    [anon_sym_or] = ACTIONS(5443),
    [anon_sym_and] = ACTIONS(5443),
    [anon_sym_bitor] = ACTIONS(5443),
    [anon_sym_xor] = ACTIONS(5443),
    [anon_sym_bitand] = ACTIONS(5443),
    [anon_sym_not_eq] = ACTIONS(5443),
    [anon_sym_DASH_DASH] = ACTIONS(5445),
    [anon_sym_PLUS_PLUS] = ACTIONS(5445),
    [anon_sym_DOT] = ACTIONS(5443),
    [anon_sym_DOT_STAR] = ACTIONS(5445),
    [anon_sym_DASH_GT] = ACTIONS(5445),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5443),
    [anon_sym_decltype] = ACTIONS(5443),
  },
  [2616] = {
    [sym_identifier] = ACTIONS(5475),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5477),
    [anon_sym_COMMA] = ACTIONS(5477),
    [anon_sym_RPAREN] = ACTIONS(5477),
    [aux_sym_preproc_if_token2] = ACTIONS(5477),
    [aux_sym_preproc_else_token1] = ACTIONS(5477),
    [aux_sym_preproc_elif_token1] = ACTIONS(5475),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5477),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5477),
    [anon_sym_LPAREN2] = ACTIONS(5477),
    [anon_sym_DASH] = ACTIONS(5475),
    [anon_sym_PLUS] = ACTIONS(5475),
    [anon_sym_STAR] = ACTIONS(5475),
    [anon_sym_SLASH] = ACTIONS(5475),
    [anon_sym_PERCENT] = ACTIONS(5475),
    [anon_sym_PIPE_PIPE] = ACTIONS(5477),
    [anon_sym_AMP_AMP] = ACTIONS(5477),
    [anon_sym_PIPE] = ACTIONS(5475),
    [anon_sym_CARET] = ACTIONS(5475),
    [anon_sym_AMP] = ACTIONS(5475),
    [anon_sym_EQ_EQ] = ACTIONS(5477),
    [anon_sym_BANG_EQ] = ACTIONS(5477),
    [anon_sym_GT] = ACTIONS(5475),
    [anon_sym_GT_EQ] = ACTIONS(5477),
    [anon_sym_LT_EQ] = ACTIONS(5475),
    [anon_sym_LT] = ACTIONS(5475),
    [anon_sym_LT_LT] = ACTIONS(5475),
    [anon_sym_GT_GT] = ACTIONS(5475),
    [anon_sym_COLON] = ACTIONS(5477),
    [anon_sym_SEMI] = ACTIONS(5477),
    [anon_sym___attribute__] = ACTIONS(5475),
    [anon_sym_LBRACE] = ACTIONS(5477),
    [anon_sym_RBRACE] = ACTIONS(5477),
    [anon_sym_LBRACK] = ACTIONS(5477),
    [anon_sym_RBRACK] = ACTIONS(5477),
    [anon_sym_EQ] = ACTIONS(5475),
    [anon_sym_QMARK] = ACTIONS(5477),
    [anon_sym_STAR_EQ] = ACTIONS(5477),
    [anon_sym_SLASH_EQ] = ACTIONS(5477),
    [anon_sym_PERCENT_EQ] = ACTIONS(5477),
    [anon_sym_PLUS_EQ] = ACTIONS(5477),
    [anon_sym_DASH_EQ] = ACTIONS(5477),
    [anon_sym_LT_LT_EQ] = ACTIONS(5477),
    [anon_sym_GT_GT_EQ] = ACTIONS(5477),
    [anon_sym_AMP_EQ] = ACTIONS(5477),
    [anon_sym_CARET_EQ] = ACTIONS(5477),
    [anon_sym_PIPE_EQ] = ACTIONS(5477),
    [anon_sym_and_eq] = ACTIONS(5475),
    [anon_sym_or_eq] = ACTIONS(5475),
    [anon_sym_xor_eq] = ACTIONS(5475),
    [anon_sym_LT_EQ_GT] = ACTIONS(5477),
    [anon_sym_or] = ACTIONS(5475),
    [anon_sym_and] = ACTIONS(5475),
    [anon_sym_bitor] = ACTIONS(5475),
    [anon_sym_xor] = ACTIONS(5475),
    [anon_sym_bitand] = ACTIONS(5475),
    [anon_sym_not_eq] = ACTIONS(5475),
    [anon_sym_DASH_DASH] = ACTIONS(5477),
    [anon_sym_PLUS_PLUS] = ACTIONS(5477),
    [anon_sym_DOT] = ACTIONS(5475),
    [anon_sym_DOT_STAR] = ACTIONS(5477),
    [anon_sym_DASH_GT] = ACTIONS(5477),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5475),
    [anon_sym_decltype] = ACTIONS(5475),
  },
  [2617] = {
    [sym_identifier] = ACTIONS(5447),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5449),
    [anon_sym_COMMA] = ACTIONS(5449),
    [anon_sym_RPAREN] = ACTIONS(5449),
    [aux_sym_preproc_if_token2] = ACTIONS(5449),
    [aux_sym_preproc_else_token1] = ACTIONS(5449),
    [aux_sym_preproc_elif_token1] = ACTIONS(5447),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5449),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5449),
    [anon_sym_LPAREN2] = ACTIONS(5449),
    [anon_sym_DASH] = ACTIONS(5447),
    [anon_sym_PLUS] = ACTIONS(5447),
    [anon_sym_STAR] = ACTIONS(5447),
    [anon_sym_SLASH] = ACTIONS(5447),
    [anon_sym_PERCENT] = ACTIONS(5447),
    [anon_sym_PIPE_PIPE] = ACTIONS(5449),
    [anon_sym_AMP_AMP] = ACTIONS(5449),
    [anon_sym_PIPE] = ACTIONS(5447),
    [anon_sym_CARET] = ACTIONS(5447),
    [anon_sym_AMP] = ACTIONS(5447),
    [anon_sym_EQ_EQ] = ACTIONS(5449),
    [anon_sym_BANG_EQ] = ACTIONS(5449),
    [anon_sym_GT] = ACTIONS(5447),
    [anon_sym_GT_EQ] = ACTIONS(5449),
    [anon_sym_LT_EQ] = ACTIONS(5447),
    [anon_sym_LT] = ACTIONS(5447),
    [anon_sym_LT_LT] = ACTIONS(5447),
    [anon_sym_GT_GT] = ACTIONS(5447),
    [anon_sym_COLON] = ACTIONS(5449),
    [anon_sym_SEMI] = ACTIONS(5449),
    [anon_sym___attribute__] = ACTIONS(5447),
    [anon_sym_LBRACE] = ACTIONS(5449),
    [anon_sym_RBRACE] = ACTIONS(5449),
    [anon_sym_LBRACK] = ACTIONS(5449),
    [anon_sym_RBRACK] = ACTIONS(5449),
    [anon_sym_EQ] = ACTIONS(5447),
    [anon_sym_QMARK] = ACTIONS(5449),
    [anon_sym_STAR_EQ] = ACTIONS(5449),
    [anon_sym_SLASH_EQ] = ACTIONS(5449),
    [anon_sym_PERCENT_EQ] = ACTIONS(5449),
    [anon_sym_PLUS_EQ] = ACTIONS(5449),
    [anon_sym_DASH_EQ] = ACTIONS(5449),
    [anon_sym_LT_LT_EQ] = ACTIONS(5449),
    [anon_sym_GT_GT_EQ] = ACTIONS(5449),
    [anon_sym_AMP_EQ] = ACTIONS(5449),
    [anon_sym_CARET_EQ] = ACTIONS(5449),
    [anon_sym_PIPE_EQ] = ACTIONS(5449),
    [anon_sym_and_eq] = ACTIONS(5447),
    [anon_sym_or_eq] = ACTIONS(5447),
    [anon_sym_xor_eq] = ACTIONS(5447),
    [anon_sym_LT_EQ_GT] = ACTIONS(5449),
    [anon_sym_or] = ACTIONS(5447),
    [anon_sym_and] = ACTIONS(5447),
    [anon_sym_bitor] = ACTIONS(5447),
    [anon_sym_xor] = ACTIONS(5447),
    [anon_sym_bitand] = ACTIONS(5447),
    [anon_sym_not_eq] = ACTIONS(5447),
    [anon_sym_DASH_DASH] = ACTIONS(5449),
    [anon_sym_PLUS_PLUS] = ACTIONS(5449),
    [anon_sym_DOT] = ACTIONS(5447),
    [anon_sym_DOT_STAR] = ACTIONS(5449),
    [anon_sym_DASH_GT] = ACTIONS(5449),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5447),
    [anon_sym_decltype] = ACTIONS(5447),
  },
  [2618] = {
    [sym_identifier] = ACTIONS(2308),
    [anon_sym___extension__] = ACTIONS(2308),
    [anon_sym_in] = ACTIONS(2308),
    [anon_sym_out] = ACTIONS(2308),
    [anon_sym_inout] = ACTIONS(2308),
    [anon_sym_extern] = ACTIONS(2308),
    [anon_sym___attribute__] = ACTIONS(2308),
    [anon_sym_COLON_COLON] = ACTIONS(2310),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2310),
    [anon_sym___declspec] = ACTIONS(2308),
    [anon_sym_signed] = ACTIONS(2308),
    [anon_sym_unsigned] = ACTIONS(2308),
    [anon_sym_long] = ACTIONS(2308),
    [anon_sym_short] = ACTIONS(2308),
    [anon_sym_static] = ACTIONS(2308),
    [anon_sym_register] = ACTIONS(2308),
    [anon_sym_inline] = ACTIONS(2308),
    [anon_sym___inline] = ACTIONS(2308),
    [anon_sym___inline__] = ACTIONS(2308),
    [anon_sym___forceinline] = ACTIONS(2308),
    [anon_sym_thread_local] = ACTIONS(2308),
    [anon_sym___thread] = ACTIONS(2308),
    [anon_sym_const] = ACTIONS(2308),
    [anon_sym_constexpr] = ACTIONS(2308),
    [anon_sym_volatile] = ACTIONS(2308),
    [anon_sym_restrict] = ACTIONS(2308),
    [anon_sym___restrict__] = ACTIONS(2308),
    [anon_sym__Atomic] = ACTIONS(2308),
    [anon_sym__Noreturn] = ACTIONS(2308),
    [anon_sym_noreturn] = ACTIONS(2308),
    [anon_sym_mutable] = ACTIONS(2308),
    [anon_sym_constinit] = ACTIONS(2308),
    [anon_sym_consteval] = ACTIONS(2308),
    [anon_sym_alignas] = ACTIONS(2308),
    [anon_sym__Alignas] = ACTIONS(2308),
    [sym_primitive_type] = ACTIONS(2308),
    [anon_sym_enum] = ACTIONS(2308),
    [anon_sym_class] = ACTIONS(2308),
    [anon_sym_struct] = ACTIONS(2308),
    [anon_sym_union] = ACTIONS(2308),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2308),
    [anon_sym_decltype] = ACTIONS(2308),
    [sym_virtual] = ACTIONS(2308),
    [anon_sym_typename] = ACTIONS(2308),
    [anon_sym_template] = ACTIONS(2308),
    [anon_sym_precise] = ACTIONS(2308),
    [anon_sym_shared] = ACTIONS(2308),
    [anon_sym_groupshared] = ACTIONS(2308),
    [anon_sym_uniform] = ACTIONS(2308),
    [anon_sym_row_major] = ACTIONS(2308),
    [anon_sym_column_major] = ACTIONS(2308),
    [anon_sym_globallycoherent] = ACTIONS(2308),
    [anon_sym_centroid] = ACTIONS(2308),
    [anon_sym_noperspective] = ACTIONS(2308),
    [anon_sym_nointerpolation] = ACTIONS(2308),
    [anon_sym_sample] = ACTIONS(2308),
    [anon_sym_linear] = ACTIONS(2308),
    [anon_sym_snorm] = ACTIONS(2308),
    [anon_sym_unorm] = ACTIONS(2308),
    [anon_sym_point] = ACTIONS(2308),
    [anon_sym_line] = ACTIONS(2308),
    [anon_sym_triangleadj] = ACTIONS(2308),
    [anon_sym_lineadj] = ACTIONS(2308),
    [anon_sym_triangle] = ACTIONS(2308),
  },
  [2619] = {
    [sym_argument_list] = STATE(2818),
    [sym_initializer_list] = STATE(2818),
    [sym_identifier] = ACTIONS(6089),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6091),
    [anon_sym_COMMA] = ACTIONS(6091),
    [anon_sym_RPAREN] = ACTIONS(6091),
    [aux_sym_preproc_if_token2] = ACTIONS(6091),
    [aux_sym_preproc_else_token1] = ACTIONS(6091),
    [aux_sym_preproc_elif_token1] = ACTIONS(6089),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6091),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6091),
    [anon_sym_LPAREN2] = ACTIONS(5854),
    [anon_sym_DASH] = ACTIONS(6089),
    [anon_sym_PLUS] = ACTIONS(6089),
    [anon_sym_STAR] = ACTIONS(6089),
    [anon_sym_SLASH] = ACTIONS(6089),
    [anon_sym_PERCENT] = ACTIONS(6089),
    [anon_sym_PIPE_PIPE] = ACTIONS(6091),
    [anon_sym_AMP_AMP] = ACTIONS(6091),
    [anon_sym_PIPE] = ACTIONS(6089),
    [anon_sym_CARET] = ACTIONS(6089),
    [anon_sym_AMP] = ACTIONS(6089),
    [anon_sym_EQ_EQ] = ACTIONS(6091),
    [anon_sym_BANG_EQ] = ACTIONS(6091),
    [anon_sym_GT] = ACTIONS(6089),
    [anon_sym_GT_EQ] = ACTIONS(6091),
    [anon_sym_LT_EQ] = ACTIONS(6089),
    [anon_sym_LT] = ACTIONS(6089),
    [anon_sym_LT_LT] = ACTIONS(6089),
    [anon_sym_GT_GT] = ACTIONS(6089),
    [anon_sym_COLON] = ACTIONS(6091),
    [anon_sym_SEMI] = ACTIONS(6091),
    [anon_sym___attribute__] = ACTIONS(6089),
    [anon_sym_LBRACE] = ACTIONS(3523),
    [anon_sym_RBRACE] = ACTIONS(6091),
    [anon_sym_LBRACK] = ACTIONS(6091),
    [anon_sym_RBRACK] = ACTIONS(6091),
    [anon_sym_EQ] = ACTIONS(6089),
    [anon_sym_QMARK] = ACTIONS(6091),
    [anon_sym_STAR_EQ] = ACTIONS(6091),
    [anon_sym_SLASH_EQ] = ACTIONS(6091),
    [anon_sym_PERCENT_EQ] = ACTIONS(6091),
    [anon_sym_PLUS_EQ] = ACTIONS(6091),
    [anon_sym_DASH_EQ] = ACTIONS(6091),
    [anon_sym_LT_LT_EQ] = ACTIONS(6091),
    [anon_sym_GT_GT_EQ] = ACTIONS(6091),
    [anon_sym_AMP_EQ] = ACTIONS(6091),
    [anon_sym_CARET_EQ] = ACTIONS(6091),
    [anon_sym_PIPE_EQ] = ACTIONS(6091),
    [anon_sym_and_eq] = ACTIONS(6089),
    [anon_sym_or_eq] = ACTIONS(6089),
    [anon_sym_xor_eq] = ACTIONS(6089),
    [anon_sym_LT_EQ_GT] = ACTIONS(6091),
    [anon_sym_or] = ACTIONS(6089),
    [anon_sym_and] = ACTIONS(6089),
    [anon_sym_bitor] = ACTIONS(6089),
    [anon_sym_xor] = ACTIONS(6089),
    [anon_sym_bitand] = ACTIONS(6089),
    [anon_sym_not_eq] = ACTIONS(6089),
    [anon_sym_DASH_DASH] = ACTIONS(6091),
    [anon_sym_PLUS_PLUS] = ACTIONS(6091),
    [anon_sym_DOT] = ACTIONS(6089),
    [anon_sym_DOT_STAR] = ACTIONS(6091),
    [anon_sym_DASH_GT] = ACTIONS(6091),
    [sym_comment] = ACTIONS(3),
  },
  [2620] = {
    [sym_identifier] = ACTIONS(6093),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6095),
    [anon_sym_COMMA] = ACTIONS(6095),
    [anon_sym_RPAREN] = ACTIONS(6095),
    [aux_sym_preproc_if_token2] = ACTIONS(6095),
    [aux_sym_preproc_else_token1] = ACTIONS(6095),
    [aux_sym_preproc_elif_token1] = ACTIONS(6093),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6095),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6095),
    [anon_sym_LPAREN2] = ACTIONS(6095),
    [anon_sym_DASH] = ACTIONS(6093),
    [anon_sym_PLUS] = ACTIONS(6093),
    [anon_sym_STAR] = ACTIONS(6093),
    [anon_sym_SLASH] = ACTIONS(6093),
    [anon_sym_PERCENT] = ACTIONS(6093),
    [anon_sym_PIPE_PIPE] = ACTIONS(6095),
    [anon_sym_AMP_AMP] = ACTIONS(6095),
    [anon_sym_PIPE] = ACTIONS(6093),
    [anon_sym_CARET] = ACTIONS(6093),
    [anon_sym_AMP] = ACTIONS(6093),
    [anon_sym_EQ_EQ] = ACTIONS(6095),
    [anon_sym_BANG_EQ] = ACTIONS(6095),
    [anon_sym_GT] = ACTIONS(6093),
    [anon_sym_GT_EQ] = ACTIONS(6095),
    [anon_sym_LT_EQ] = ACTIONS(6093),
    [anon_sym_LT] = ACTIONS(6093),
    [anon_sym_LT_LT] = ACTIONS(6093),
    [anon_sym_GT_GT] = ACTIONS(6093),
    [anon_sym_COLON] = ACTIONS(6095),
    [anon_sym_SEMI] = ACTIONS(6095),
    [anon_sym___attribute__] = ACTIONS(6093),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6095),
    [anon_sym_LBRACE] = ACTIONS(6095),
    [anon_sym_RBRACE] = ACTIONS(6095),
    [anon_sym_LBRACK] = ACTIONS(6093),
    [anon_sym_RBRACK] = ACTIONS(6095),
    [anon_sym_EQ] = ACTIONS(6093),
    [anon_sym_QMARK] = ACTIONS(6095),
    [anon_sym_STAR_EQ] = ACTIONS(6095),
    [anon_sym_SLASH_EQ] = ACTIONS(6095),
    [anon_sym_PERCENT_EQ] = ACTIONS(6095),
    [anon_sym_PLUS_EQ] = ACTIONS(6095),
    [anon_sym_DASH_EQ] = ACTIONS(6095),
    [anon_sym_LT_LT_EQ] = ACTIONS(6095),
    [anon_sym_GT_GT_EQ] = ACTIONS(6095),
    [anon_sym_AMP_EQ] = ACTIONS(6095),
    [anon_sym_CARET_EQ] = ACTIONS(6095),
    [anon_sym_PIPE_EQ] = ACTIONS(6095),
    [anon_sym_and_eq] = ACTIONS(6093),
    [anon_sym_or_eq] = ACTIONS(6093),
    [anon_sym_xor_eq] = ACTIONS(6093),
    [anon_sym_LT_EQ_GT] = ACTIONS(6095),
    [anon_sym_or] = ACTIONS(6093),
    [anon_sym_and] = ACTIONS(6093),
    [anon_sym_bitor] = ACTIONS(6093),
    [anon_sym_xor] = ACTIONS(6093),
    [anon_sym_bitand] = ACTIONS(6093),
    [anon_sym_not_eq] = ACTIONS(6093),
    [anon_sym_DASH_DASH] = ACTIONS(6095),
    [anon_sym_PLUS_PLUS] = ACTIONS(6095),
    [anon_sym_DOT] = ACTIONS(6093),
    [anon_sym_DOT_STAR] = ACTIONS(6095),
    [anon_sym_DASH_GT] = ACTIONS(6095),
    [sym_comment] = ACTIONS(3),
    [anon_sym_try] = ACTIONS(6093),
  },
  [2621] = {
    [sym_identifier] = ACTIONS(6097),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6099),
    [anon_sym_COMMA] = ACTIONS(6099),
    [anon_sym_RPAREN] = ACTIONS(6099),
    [aux_sym_preproc_if_token2] = ACTIONS(6099),
    [aux_sym_preproc_else_token1] = ACTIONS(6099),
    [aux_sym_preproc_elif_token1] = ACTIONS(6097),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6099),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6099),
    [anon_sym_LPAREN2] = ACTIONS(6099),
    [anon_sym_DASH] = ACTIONS(6097),
    [anon_sym_PLUS] = ACTIONS(6097),
    [anon_sym_STAR] = ACTIONS(6097),
    [anon_sym_SLASH] = ACTIONS(6097),
    [anon_sym_PERCENT] = ACTIONS(6097),
    [anon_sym_PIPE_PIPE] = ACTIONS(6099),
    [anon_sym_AMP_AMP] = ACTIONS(6099),
    [anon_sym_PIPE] = ACTIONS(6097),
    [anon_sym_CARET] = ACTIONS(6097),
    [anon_sym_AMP] = ACTIONS(6097),
    [anon_sym_EQ_EQ] = ACTIONS(6099),
    [anon_sym_BANG_EQ] = ACTIONS(6099),
    [anon_sym_GT] = ACTIONS(6097),
    [anon_sym_GT_EQ] = ACTIONS(6099),
    [anon_sym_LT_EQ] = ACTIONS(6097),
    [anon_sym_LT] = ACTIONS(6097),
    [anon_sym_LT_LT] = ACTIONS(6097),
    [anon_sym_GT_GT] = ACTIONS(6097),
    [anon_sym_COLON] = ACTIONS(6099),
    [anon_sym_SEMI] = ACTIONS(6099),
    [anon_sym___attribute__] = ACTIONS(6097),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6099),
    [anon_sym_LBRACE] = ACTIONS(6099),
    [anon_sym_RBRACE] = ACTIONS(6099),
    [anon_sym_LBRACK] = ACTIONS(6097),
    [anon_sym_RBRACK] = ACTIONS(6099),
    [anon_sym_EQ] = ACTIONS(6097),
    [anon_sym_QMARK] = ACTIONS(6099),
    [anon_sym_STAR_EQ] = ACTIONS(6099),
    [anon_sym_SLASH_EQ] = ACTIONS(6099),
    [anon_sym_PERCENT_EQ] = ACTIONS(6099),
    [anon_sym_PLUS_EQ] = ACTIONS(6099),
    [anon_sym_DASH_EQ] = ACTIONS(6099),
    [anon_sym_LT_LT_EQ] = ACTIONS(6099),
    [anon_sym_GT_GT_EQ] = ACTIONS(6099),
    [anon_sym_AMP_EQ] = ACTIONS(6099),
    [anon_sym_CARET_EQ] = ACTIONS(6099),
    [anon_sym_PIPE_EQ] = ACTIONS(6099),
    [anon_sym_and_eq] = ACTIONS(6097),
    [anon_sym_or_eq] = ACTIONS(6097),
    [anon_sym_xor_eq] = ACTIONS(6097),
    [anon_sym_LT_EQ_GT] = ACTIONS(6099),
    [anon_sym_or] = ACTIONS(6097),
    [anon_sym_and] = ACTIONS(6097),
    [anon_sym_bitor] = ACTIONS(6097),
    [anon_sym_xor] = ACTIONS(6097),
    [anon_sym_bitand] = ACTIONS(6097),
    [anon_sym_not_eq] = ACTIONS(6097),
    [anon_sym_DASH_DASH] = ACTIONS(6099),
    [anon_sym_PLUS_PLUS] = ACTIONS(6099),
    [anon_sym_DOT] = ACTIONS(6097),
    [anon_sym_DOT_STAR] = ACTIONS(6099),
    [anon_sym_DASH_GT] = ACTIONS(6099),
    [sym_comment] = ACTIONS(3),
    [anon_sym_try] = ACTIONS(6097),
  },
  [2622] = {
    [sym_identifier] = ACTIONS(6101),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6103),
    [anon_sym_COMMA] = ACTIONS(6103),
    [anon_sym_RPAREN] = ACTIONS(6103),
    [aux_sym_preproc_if_token2] = ACTIONS(6103),
    [aux_sym_preproc_else_token1] = ACTIONS(6103),
    [aux_sym_preproc_elif_token1] = ACTIONS(6101),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6103),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6103),
    [anon_sym_LPAREN2] = ACTIONS(6103),
    [anon_sym_DASH] = ACTIONS(6101),
    [anon_sym_PLUS] = ACTIONS(6101),
    [anon_sym_STAR] = ACTIONS(6101),
    [anon_sym_SLASH] = ACTIONS(6101),
    [anon_sym_PERCENT] = ACTIONS(6101),
    [anon_sym_PIPE_PIPE] = ACTIONS(6103),
    [anon_sym_AMP_AMP] = ACTIONS(6103),
    [anon_sym_PIPE] = ACTIONS(6101),
    [anon_sym_CARET] = ACTIONS(6101),
    [anon_sym_AMP] = ACTIONS(6101),
    [anon_sym_EQ_EQ] = ACTIONS(6103),
    [anon_sym_BANG_EQ] = ACTIONS(6103),
    [anon_sym_GT] = ACTIONS(6101),
    [anon_sym_GT_EQ] = ACTIONS(6103),
    [anon_sym_LT_EQ] = ACTIONS(6101),
    [anon_sym_LT] = ACTIONS(6101),
    [anon_sym_LT_LT] = ACTIONS(6101),
    [anon_sym_GT_GT] = ACTIONS(6101),
    [anon_sym_COLON] = ACTIONS(6103),
    [anon_sym_SEMI] = ACTIONS(6103),
    [anon_sym___attribute__] = ACTIONS(6101),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6103),
    [anon_sym_LBRACE] = ACTIONS(6103),
    [anon_sym_RBRACE] = ACTIONS(6103),
    [anon_sym_LBRACK] = ACTIONS(6101),
    [anon_sym_RBRACK] = ACTIONS(6103),
    [anon_sym_EQ] = ACTIONS(6101),
    [anon_sym_QMARK] = ACTIONS(6103),
    [anon_sym_STAR_EQ] = ACTIONS(6103),
    [anon_sym_SLASH_EQ] = ACTIONS(6103),
    [anon_sym_PERCENT_EQ] = ACTIONS(6103),
    [anon_sym_PLUS_EQ] = ACTIONS(6103),
    [anon_sym_DASH_EQ] = ACTIONS(6103),
    [anon_sym_LT_LT_EQ] = ACTIONS(6103),
    [anon_sym_GT_GT_EQ] = ACTIONS(6103),
    [anon_sym_AMP_EQ] = ACTIONS(6103),
    [anon_sym_CARET_EQ] = ACTIONS(6103),
    [anon_sym_PIPE_EQ] = ACTIONS(6103),
    [anon_sym_and_eq] = ACTIONS(6101),
    [anon_sym_or_eq] = ACTIONS(6101),
    [anon_sym_xor_eq] = ACTIONS(6101),
    [anon_sym_LT_EQ_GT] = ACTIONS(6103),
    [anon_sym_or] = ACTIONS(6101),
    [anon_sym_and] = ACTIONS(6101),
    [anon_sym_bitor] = ACTIONS(6101),
    [anon_sym_xor] = ACTIONS(6101),
    [anon_sym_bitand] = ACTIONS(6101),
    [anon_sym_not_eq] = ACTIONS(6101),
    [anon_sym_DASH_DASH] = ACTIONS(6103),
    [anon_sym_PLUS_PLUS] = ACTIONS(6103),
    [anon_sym_DOT] = ACTIONS(6101),
    [anon_sym_DOT_STAR] = ACTIONS(6103),
    [anon_sym_DASH_GT] = ACTIONS(6103),
    [sym_comment] = ACTIONS(3),
    [anon_sym_try] = ACTIONS(6101),
  },
  [2623] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2653),
    [sym_identifier] = ACTIONS(5353),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5355),
    [anon_sym_COMMA] = ACTIONS(5355),
    [aux_sym_preproc_if_token2] = ACTIONS(5355),
    [aux_sym_preproc_else_token1] = ACTIONS(5355),
    [aux_sym_preproc_elif_token1] = ACTIONS(5353),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5355),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5355),
    [anon_sym_LPAREN2] = ACTIONS(5355),
    [anon_sym_DASH] = ACTIONS(5353),
    [anon_sym_PLUS] = ACTIONS(5353),
    [anon_sym_STAR] = ACTIONS(5353),
    [anon_sym_SLASH] = ACTIONS(5353),
    [anon_sym_PERCENT] = ACTIONS(5353),
    [anon_sym_PIPE_PIPE] = ACTIONS(5355),
    [anon_sym_AMP_AMP] = ACTIONS(5355),
    [anon_sym_PIPE] = ACTIONS(5353),
    [anon_sym_CARET] = ACTIONS(5353),
    [anon_sym_AMP] = ACTIONS(5353),
    [anon_sym_EQ_EQ] = ACTIONS(5355),
    [anon_sym_BANG_EQ] = ACTIONS(5355),
    [anon_sym_GT] = ACTIONS(5353),
    [anon_sym_GT_EQ] = ACTIONS(5355),
    [anon_sym_LT_EQ] = ACTIONS(5353),
    [anon_sym_LT] = ACTIONS(5353),
    [anon_sym_LT_LT] = ACTIONS(5353),
    [anon_sym_GT_GT] = ACTIONS(5353),
    [anon_sym___attribute__] = ACTIONS(5353),
    [anon_sym_LBRACE] = ACTIONS(5355),
    [anon_sym_signed] = ACTIONS(6105),
    [anon_sym_unsigned] = ACTIONS(6105),
    [anon_sym_long] = ACTIONS(6105),
    [anon_sym_short] = ACTIONS(6105),
    [anon_sym_LBRACK] = ACTIONS(5355),
    [anon_sym_EQ] = ACTIONS(5353),
    [anon_sym_QMARK] = ACTIONS(5355),
    [anon_sym_STAR_EQ] = ACTIONS(5355),
    [anon_sym_SLASH_EQ] = ACTIONS(5355),
    [anon_sym_PERCENT_EQ] = ACTIONS(5355),
    [anon_sym_PLUS_EQ] = ACTIONS(5355),
    [anon_sym_DASH_EQ] = ACTIONS(5355),
    [anon_sym_LT_LT_EQ] = ACTIONS(5355),
    [anon_sym_GT_GT_EQ] = ACTIONS(5355),
    [anon_sym_AMP_EQ] = ACTIONS(5355),
    [anon_sym_CARET_EQ] = ACTIONS(5355),
    [anon_sym_PIPE_EQ] = ACTIONS(5355),
    [anon_sym_and_eq] = ACTIONS(5353),
    [anon_sym_or_eq] = ACTIONS(5353),
    [anon_sym_xor_eq] = ACTIONS(5353),
    [anon_sym_LT_EQ_GT] = ACTIONS(5355),
    [anon_sym_or] = ACTIONS(5353),
    [anon_sym_and] = ACTIONS(5353),
    [anon_sym_bitor] = ACTIONS(5353),
    [anon_sym_xor] = ACTIONS(5353),
    [anon_sym_bitand] = ACTIONS(5353),
    [anon_sym_not_eq] = ACTIONS(5353),
    [anon_sym_DASH_DASH] = ACTIONS(5355),
    [anon_sym_PLUS_PLUS] = ACTIONS(5355),
    [anon_sym_DOT] = ACTIONS(5353),
    [anon_sym_DOT_STAR] = ACTIONS(5355),
    [anon_sym_DASH_GT] = ACTIONS(5355),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5353),
    [anon_sym_decltype] = ACTIONS(5353),
  },
  [2624] = {
    [sym_identifier] = ACTIONS(6107),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6109),
    [anon_sym_COMMA] = ACTIONS(6109),
    [anon_sym_RPAREN] = ACTIONS(6109),
    [aux_sym_preproc_if_token2] = ACTIONS(6109),
    [aux_sym_preproc_else_token1] = ACTIONS(6109),
    [aux_sym_preproc_elif_token1] = ACTIONS(6107),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6109),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6109),
    [anon_sym_LPAREN2] = ACTIONS(6109),
    [anon_sym_DASH] = ACTIONS(6107),
    [anon_sym_PLUS] = ACTIONS(6107),
    [anon_sym_STAR] = ACTIONS(6107),
    [anon_sym_SLASH] = ACTIONS(6107),
    [anon_sym_PERCENT] = ACTIONS(6107),
    [anon_sym_PIPE_PIPE] = ACTIONS(6109),
    [anon_sym_AMP_AMP] = ACTIONS(6109),
    [anon_sym_PIPE] = ACTIONS(6107),
    [anon_sym_CARET] = ACTIONS(6107),
    [anon_sym_AMP] = ACTIONS(6107),
    [anon_sym_EQ_EQ] = ACTIONS(6109),
    [anon_sym_BANG_EQ] = ACTIONS(6109),
    [anon_sym_GT] = ACTIONS(6107),
    [anon_sym_GT_EQ] = ACTIONS(6109),
    [anon_sym_LT_EQ] = ACTIONS(6107),
    [anon_sym_LT] = ACTIONS(6107),
    [anon_sym_LT_LT] = ACTIONS(6107),
    [anon_sym_GT_GT] = ACTIONS(6107),
    [anon_sym_COLON] = ACTIONS(6109),
    [anon_sym_SEMI] = ACTIONS(6109),
    [anon_sym___attribute__] = ACTIONS(6107),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6109),
    [anon_sym_LBRACE] = ACTIONS(6109),
    [anon_sym_RBRACE] = ACTIONS(6109),
    [anon_sym_LBRACK] = ACTIONS(6107),
    [anon_sym_RBRACK] = ACTIONS(6109),
    [anon_sym_EQ] = ACTIONS(6107),
    [anon_sym_QMARK] = ACTIONS(6109),
    [anon_sym_STAR_EQ] = ACTIONS(6109),
    [anon_sym_SLASH_EQ] = ACTIONS(6109),
    [anon_sym_PERCENT_EQ] = ACTIONS(6109),
    [anon_sym_PLUS_EQ] = ACTIONS(6109),
    [anon_sym_DASH_EQ] = ACTIONS(6109),
    [anon_sym_LT_LT_EQ] = ACTIONS(6109),
    [anon_sym_GT_GT_EQ] = ACTIONS(6109),
    [anon_sym_AMP_EQ] = ACTIONS(6109),
    [anon_sym_CARET_EQ] = ACTIONS(6109),
    [anon_sym_PIPE_EQ] = ACTIONS(6109),
    [anon_sym_and_eq] = ACTIONS(6107),
    [anon_sym_or_eq] = ACTIONS(6107),
    [anon_sym_xor_eq] = ACTIONS(6107),
    [anon_sym_LT_EQ_GT] = ACTIONS(6109),
    [anon_sym_or] = ACTIONS(6107),
    [anon_sym_and] = ACTIONS(6107),
    [anon_sym_bitor] = ACTIONS(6107),
    [anon_sym_xor] = ACTIONS(6107),
    [anon_sym_bitand] = ACTIONS(6107),
    [anon_sym_not_eq] = ACTIONS(6107),
    [anon_sym_DASH_DASH] = ACTIONS(6109),
    [anon_sym_PLUS_PLUS] = ACTIONS(6109),
    [anon_sym_DOT] = ACTIONS(6107),
    [anon_sym_DOT_STAR] = ACTIONS(6109),
    [anon_sym_DASH_GT] = ACTIONS(6109),
    [sym_comment] = ACTIONS(3),
    [anon_sym_try] = ACTIONS(6107),
  },
  [2625] = {
    [sym_string_literal] = STATE(2527),
    [sym_raw_string_literal] = STATE(2527),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3824),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(3832),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_SEMI] = ACTIONS(3824),
    [anon_sym___attribute__] = ACTIONS(3832),
    [anon_sym_LBRACK] = ACTIONS(3824),
    [anon_sym_EQ] = ACTIONS(3832),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3824),
    [anon_sym_SLASH_EQ] = ACTIONS(3824),
    [anon_sym_PERCENT_EQ] = ACTIONS(3824),
    [anon_sym_PLUS_EQ] = ACTIONS(3824),
    [anon_sym_DASH_EQ] = ACTIONS(3824),
    [anon_sym_LT_LT_EQ] = ACTIONS(3824),
    [anon_sym_GT_GT_EQ] = ACTIONS(3824),
    [anon_sym_AMP_EQ] = ACTIONS(3824),
    [anon_sym_CARET_EQ] = ACTIONS(3824),
    [anon_sym_PIPE_EQ] = ACTIONS(3824),
    [anon_sym_and_eq] = ACTIONS(3832),
    [anon_sym_or_eq] = ACTIONS(3832),
    [anon_sym_xor_eq] = ACTIONS(3832),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3832),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3832),
    [anon_sym_not_eq] = ACTIONS(3832),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3824),
    [anon_sym_L_DQUOTE] = ACTIONS(5957),
    [anon_sym_u_DQUOTE] = ACTIONS(5957),
    [anon_sym_U_DQUOTE] = ACTIONS(5957),
    [anon_sym_u8_DQUOTE] = ACTIONS(5957),
    [anon_sym_DQUOTE] = ACTIONS(5957),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5959),
    [anon_sym_LR_DQUOTE] = ACTIONS(5959),
    [anon_sym_uR_DQUOTE] = ACTIONS(5959),
    [anon_sym_UR_DQUOTE] = ACTIONS(5959),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5959),
    [sym_literal_suffix] = ACTIONS(5836),
  },
  [2626] = {
    [sym_identifier] = ACTIONS(5525),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5527),
    [anon_sym_COMMA] = ACTIONS(5527),
    [anon_sym_RPAREN] = ACTIONS(5527),
    [aux_sym_preproc_if_token2] = ACTIONS(5527),
    [aux_sym_preproc_else_token1] = ACTIONS(5527),
    [aux_sym_preproc_elif_token1] = ACTIONS(5525),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5527),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5527),
    [anon_sym_LPAREN2] = ACTIONS(5527),
    [anon_sym_DASH] = ACTIONS(5525),
    [anon_sym_PLUS] = ACTIONS(5525),
    [anon_sym_STAR] = ACTIONS(5525),
    [anon_sym_SLASH] = ACTIONS(5525),
    [anon_sym_PERCENT] = ACTIONS(5525),
    [anon_sym_PIPE_PIPE] = ACTIONS(5527),
    [anon_sym_AMP_AMP] = ACTIONS(5527),
    [anon_sym_PIPE] = ACTIONS(5525),
    [anon_sym_CARET] = ACTIONS(5525),
    [anon_sym_AMP] = ACTIONS(5525),
    [anon_sym_EQ_EQ] = ACTIONS(5527),
    [anon_sym_BANG_EQ] = ACTIONS(5527),
    [anon_sym_GT] = ACTIONS(5525),
    [anon_sym_GT_EQ] = ACTIONS(5527),
    [anon_sym_LT_EQ] = ACTIONS(5525),
    [anon_sym_LT] = ACTIONS(5525),
    [anon_sym_LT_LT] = ACTIONS(5525),
    [anon_sym_GT_GT] = ACTIONS(5525),
    [anon_sym_COLON] = ACTIONS(5527),
    [anon_sym_SEMI] = ACTIONS(5527),
    [anon_sym___attribute__] = ACTIONS(5525),
    [anon_sym_LBRACE] = ACTIONS(5527),
    [anon_sym_RBRACE] = ACTIONS(5527),
    [anon_sym_LBRACK] = ACTIONS(5527),
    [anon_sym_RBRACK] = ACTIONS(5527),
    [anon_sym_EQ] = ACTIONS(5525),
    [anon_sym_QMARK] = ACTIONS(5527),
    [anon_sym_STAR_EQ] = ACTIONS(5527),
    [anon_sym_SLASH_EQ] = ACTIONS(5527),
    [anon_sym_PERCENT_EQ] = ACTIONS(5527),
    [anon_sym_PLUS_EQ] = ACTIONS(5527),
    [anon_sym_DASH_EQ] = ACTIONS(5527),
    [anon_sym_LT_LT_EQ] = ACTIONS(5527),
    [anon_sym_GT_GT_EQ] = ACTIONS(5527),
    [anon_sym_AMP_EQ] = ACTIONS(5527),
    [anon_sym_CARET_EQ] = ACTIONS(5527),
    [anon_sym_PIPE_EQ] = ACTIONS(5527),
    [anon_sym_and_eq] = ACTIONS(5525),
    [anon_sym_or_eq] = ACTIONS(5525),
    [anon_sym_xor_eq] = ACTIONS(5525),
    [anon_sym_LT_EQ_GT] = ACTIONS(5527),
    [anon_sym_or] = ACTIONS(5525),
    [anon_sym_and] = ACTIONS(5525),
    [anon_sym_bitor] = ACTIONS(5525),
    [anon_sym_xor] = ACTIONS(5525),
    [anon_sym_bitand] = ACTIONS(5525),
    [anon_sym_not_eq] = ACTIONS(5525),
    [anon_sym_DASH_DASH] = ACTIONS(5527),
    [anon_sym_PLUS_PLUS] = ACTIONS(5527),
    [anon_sym_DOT] = ACTIONS(5525),
    [anon_sym_DOT_STAR] = ACTIONS(5527),
    [anon_sym_DASH_GT] = ACTIONS(5527),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5525),
    [anon_sym_decltype] = ACTIONS(5525),
  },
  [2627] = {
    [sym_identifier] = ACTIONS(6111),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6113),
    [anon_sym_COMMA] = ACTIONS(6113),
    [anon_sym_RPAREN] = ACTIONS(6113),
    [aux_sym_preproc_if_token2] = ACTIONS(6113),
    [aux_sym_preproc_else_token1] = ACTIONS(6113),
    [aux_sym_preproc_elif_token1] = ACTIONS(6111),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6113),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6113),
    [anon_sym_LPAREN2] = ACTIONS(6113),
    [anon_sym_DASH] = ACTIONS(6111),
    [anon_sym_PLUS] = ACTIONS(6111),
    [anon_sym_STAR] = ACTIONS(6111),
    [anon_sym_SLASH] = ACTIONS(6111),
    [anon_sym_PERCENT] = ACTIONS(6111),
    [anon_sym_PIPE_PIPE] = ACTIONS(6113),
    [anon_sym_AMP_AMP] = ACTIONS(6113),
    [anon_sym_PIPE] = ACTIONS(6111),
    [anon_sym_CARET] = ACTIONS(6111),
    [anon_sym_AMP] = ACTIONS(6111),
    [anon_sym_EQ_EQ] = ACTIONS(6113),
    [anon_sym_BANG_EQ] = ACTIONS(6113),
    [anon_sym_GT] = ACTIONS(6111),
    [anon_sym_GT_EQ] = ACTIONS(6113),
    [anon_sym_LT_EQ] = ACTIONS(6111),
    [anon_sym_LT] = ACTIONS(6111),
    [anon_sym_LT_LT] = ACTIONS(6111),
    [anon_sym_GT_GT] = ACTIONS(6111),
    [anon_sym_COLON] = ACTIONS(6113),
    [anon_sym_SEMI] = ACTIONS(6113),
    [anon_sym___attribute__] = ACTIONS(6111),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6113),
    [anon_sym_LBRACE] = ACTIONS(6113),
    [anon_sym_RBRACE] = ACTIONS(6113),
    [anon_sym_LBRACK] = ACTIONS(6111),
    [anon_sym_RBRACK] = ACTIONS(6113),
    [anon_sym_EQ] = ACTIONS(6111),
    [anon_sym_QMARK] = ACTIONS(6113),
    [anon_sym_STAR_EQ] = ACTIONS(6113),
    [anon_sym_SLASH_EQ] = ACTIONS(6113),
    [anon_sym_PERCENT_EQ] = ACTIONS(6113),
    [anon_sym_PLUS_EQ] = ACTIONS(6113),
    [anon_sym_DASH_EQ] = ACTIONS(6113),
    [anon_sym_LT_LT_EQ] = ACTIONS(6113),
    [anon_sym_GT_GT_EQ] = ACTIONS(6113),
    [anon_sym_AMP_EQ] = ACTIONS(6113),
    [anon_sym_CARET_EQ] = ACTIONS(6113),
    [anon_sym_PIPE_EQ] = ACTIONS(6113),
    [anon_sym_and_eq] = ACTIONS(6111),
    [anon_sym_or_eq] = ACTIONS(6111),
    [anon_sym_xor_eq] = ACTIONS(6111),
    [anon_sym_LT_EQ_GT] = ACTIONS(6113),
    [anon_sym_or] = ACTIONS(6111),
    [anon_sym_and] = ACTIONS(6111),
    [anon_sym_bitor] = ACTIONS(6111),
    [anon_sym_xor] = ACTIONS(6111),
    [anon_sym_bitand] = ACTIONS(6111),
    [anon_sym_not_eq] = ACTIONS(6111),
    [anon_sym_DASH_DASH] = ACTIONS(6113),
    [anon_sym_PLUS_PLUS] = ACTIONS(6113),
    [anon_sym_DOT] = ACTIONS(6111),
    [anon_sym_DOT_STAR] = ACTIONS(6113),
    [anon_sym_DASH_GT] = ACTIONS(6113),
    [sym_comment] = ACTIONS(3),
    [anon_sym_try] = ACTIONS(6111),
  },
  [2628] = {
    [sym_identifier] = ACTIONS(2138),
    [anon_sym___extension__] = ACTIONS(2138),
    [anon_sym_in] = ACTIONS(2138),
    [anon_sym_out] = ACTIONS(2138),
    [anon_sym_inout] = ACTIONS(2138),
    [anon_sym_extern] = ACTIONS(2138),
    [anon_sym___attribute__] = ACTIONS(2138),
    [anon_sym_COLON_COLON] = ACTIONS(2140),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2140),
    [anon_sym___declspec] = ACTIONS(2138),
    [anon_sym_signed] = ACTIONS(2138),
    [anon_sym_unsigned] = ACTIONS(2138),
    [anon_sym_long] = ACTIONS(2138),
    [anon_sym_short] = ACTIONS(2138),
    [anon_sym_static] = ACTIONS(2138),
    [anon_sym_register] = ACTIONS(2138),
    [anon_sym_inline] = ACTIONS(2138),
    [anon_sym___inline] = ACTIONS(2138),
    [anon_sym___inline__] = ACTIONS(2138),
    [anon_sym___forceinline] = ACTIONS(2138),
    [anon_sym_thread_local] = ACTIONS(2138),
    [anon_sym___thread] = ACTIONS(2138),
    [anon_sym_const] = ACTIONS(2138),
    [anon_sym_constexpr] = ACTIONS(2138),
    [anon_sym_volatile] = ACTIONS(2138),
    [anon_sym_restrict] = ACTIONS(2138),
    [anon_sym___restrict__] = ACTIONS(2138),
    [anon_sym__Atomic] = ACTIONS(2138),
    [anon_sym__Noreturn] = ACTIONS(2138),
    [anon_sym_noreturn] = ACTIONS(2138),
    [anon_sym_mutable] = ACTIONS(2138),
    [anon_sym_constinit] = ACTIONS(2138),
    [anon_sym_consteval] = ACTIONS(2138),
    [anon_sym_alignas] = ACTIONS(2138),
    [anon_sym__Alignas] = ACTIONS(2138),
    [sym_primitive_type] = ACTIONS(2138),
    [anon_sym_enum] = ACTIONS(2138),
    [anon_sym_class] = ACTIONS(2138),
    [anon_sym_struct] = ACTIONS(2138),
    [anon_sym_union] = ACTIONS(2138),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2138),
    [anon_sym_decltype] = ACTIONS(2138),
    [sym_virtual] = ACTIONS(2138),
    [anon_sym_typename] = ACTIONS(2138),
    [anon_sym_template] = ACTIONS(2138),
    [anon_sym_precise] = ACTIONS(2138),
    [anon_sym_shared] = ACTIONS(2138),
    [anon_sym_groupshared] = ACTIONS(2138),
    [anon_sym_uniform] = ACTIONS(2138),
    [anon_sym_row_major] = ACTIONS(2138),
    [anon_sym_column_major] = ACTIONS(2138),
    [anon_sym_globallycoherent] = ACTIONS(2138),
    [anon_sym_centroid] = ACTIONS(2138),
    [anon_sym_noperspective] = ACTIONS(2138),
    [anon_sym_nointerpolation] = ACTIONS(2138),
    [anon_sym_sample] = ACTIONS(2138),
    [anon_sym_linear] = ACTIONS(2138),
    [anon_sym_snorm] = ACTIONS(2138),
    [anon_sym_unorm] = ACTIONS(2138),
    [anon_sym_point] = ACTIONS(2138),
    [anon_sym_line] = ACTIONS(2138),
    [anon_sym_triangleadj] = ACTIONS(2138),
    [anon_sym_lineadj] = ACTIONS(2138),
    [anon_sym_triangle] = ACTIONS(2138),
  },
  [2629] = {
    [sym_identifier] = ACTIONS(2134),
    [anon_sym___extension__] = ACTIONS(2134),
    [anon_sym_in] = ACTIONS(2134),
    [anon_sym_out] = ACTIONS(2134),
    [anon_sym_inout] = ACTIONS(2134),
    [anon_sym_extern] = ACTIONS(2134),
    [anon_sym___attribute__] = ACTIONS(2134),
    [anon_sym_COLON_COLON] = ACTIONS(2136),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2136),
    [anon_sym___declspec] = ACTIONS(2134),
    [anon_sym_signed] = ACTIONS(2134),
    [anon_sym_unsigned] = ACTIONS(2134),
    [anon_sym_long] = ACTIONS(2134),
    [anon_sym_short] = ACTIONS(2134),
    [anon_sym_static] = ACTIONS(2134),
    [anon_sym_register] = ACTIONS(2134),
    [anon_sym_inline] = ACTIONS(2134),
    [anon_sym___inline] = ACTIONS(2134),
    [anon_sym___inline__] = ACTIONS(2134),
    [anon_sym___forceinline] = ACTIONS(2134),
    [anon_sym_thread_local] = ACTIONS(2134),
    [anon_sym___thread] = ACTIONS(2134),
    [anon_sym_const] = ACTIONS(2134),
    [anon_sym_constexpr] = ACTIONS(2134),
    [anon_sym_volatile] = ACTIONS(2134),
    [anon_sym_restrict] = ACTIONS(2134),
    [anon_sym___restrict__] = ACTIONS(2134),
    [anon_sym__Atomic] = ACTIONS(2134),
    [anon_sym__Noreturn] = ACTIONS(2134),
    [anon_sym_noreturn] = ACTIONS(2134),
    [anon_sym_mutable] = ACTIONS(2134),
    [anon_sym_constinit] = ACTIONS(2134),
    [anon_sym_consteval] = ACTIONS(2134),
    [anon_sym_alignas] = ACTIONS(2134),
    [anon_sym__Alignas] = ACTIONS(2134),
    [sym_primitive_type] = ACTIONS(2134),
    [anon_sym_enum] = ACTIONS(2134),
    [anon_sym_class] = ACTIONS(2134),
    [anon_sym_struct] = ACTIONS(2134),
    [anon_sym_union] = ACTIONS(2134),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2134),
    [anon_sym_decltype] = ACTIONS(2134),
    [sym_virtual] = ACTIONS(2134),
    [anon_sym_typename] = ACTIONS(2134),
    [anon_sym_template] = ACTIONS(2134),
    [anon_sym_precise] = ACTIONS(2134),
    [anon_sym_shared] = ACTIONS(2134),
    [anon_sym_groupshared] = ACTIONS(2134),
    [anon_sym_uniform] = ACTIONS(2134),
    [anon_sym_row_major] = ACTIONS(2134),
    [anon_sym_column_major] = ACTIONS(2134),
    [anon_sym_globallycoherent] = ACTIONS(2134),
    [anon_sym_centroid] = ACTIONS(2134),
    [anon_sym_noperspective] = ACTIONS(2134),
    [anon_sym_nointerpolation] = ACTIONS(2134),
    [anon_sym_sample] = ACTIONS(2134),
    [anon_sym_linear] = ACTIONS(2134),
    [anon_sym_snorm] = ACTIONS(2134),
    [anon_sym_unorm] = ACTIONS(2134),
    [anon_sym_point] = ACTIONS(2134),
    [anon_sym_line] = ACTIONS(2134),
    [anon_sym_triangleadj] = ACTIONS(2134),
    [anon_sym_lineadj] = ACTIONS(2134),
    [anon_sym_triangle] = ACTIONS(2134),
  },
  [2630] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2640),
    [sym_identifier] = ACTIONS(5387),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5389),
    [anon_sym_COMMA] = ACTIONS(5389),
    [aux_sym_preproc_if_token2] = ACTIONS(5389),
    [aux_sym_preproc_else_token1] = ACTIONS(5389),
    [aux_sym_preproc_elif_token1] = ACTIONS(5387),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5389),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5389),
    [anon_sym_LPAREN2] = ACTIONS(5389),
    [anon_sym_DASH] = ACTIONS(5387),
    [anon_sym_PLUS] = ACTIONS(5387),
    [anon_sym_STAR] = ACTIONS(5387),
    [anon_sym_SLASH] = ACTIONS(5387),
    [anon_sym_PERCENT] = ACTIONS(5387),
    [anon_sym_PIPE_PIPE] = ACTIONS(5389),
    [anon_sym_AMP_AMP] = ACTIONS(5389),
    [anon_sym_PIPE] = ACTIONS(5387),
    [anon_sym_CARET] = ACTIONS(5387),
    [anon_sym_AMP] = ACTIONS(5387),
    [anon_sym_EQ_EQ] = ACTIONS(5389),
    [anon_sym_BANG_EQ] = ACTIONS(5389),
    [anon_sym_GT] = ACTIONS(5387),
    [anon_sym_GT_EQ] = ACTIONS(5389),
    [anon_sym_LT_EQ] = ACTIONS(5387),
    [anon_sym_LT] = ACTIONS(5387),
    [anon_sym_LT_LT] = ACTIONS(5387),
    [anon_sym_GT_GT] = ACTIONS(5387),
    [anon_sym___attribute__] = ACTIONS(5387),
    [anon_sym_LBRACE] = ACTIONS(5389),
    [anon_sym_signed] = ACTIONS(6115),
    [anon_sym_unsigned] = ACTIONS(6115),
    [anon_sym_long] = ACTIONS(6115),
    [anon_sym_short] = ACTIONS(6115),
    [anon_sym_LBRACK] = ACTIONS(5389),
    [anon_sym_EQ] = ACTIONS(5387),
    [anon_sym_QMARK] = ACTIONS(5389),
    [anon_sym_STAR_EQ] = ACTIONS(5389),
    [anon_sym_SLASH_EQ] = ACTIONS(5389),
    [anon_sym_PERCENT_EQ] = ACTIONS(5389),
    [anon_sym_PLUS_EQ] = ACTIONS(5389),
    [anon_sym_DASH_EQ] = ACTIONS(5389),
    [anon_sym_LT_LT_EQ] = ACTIONS(5389),
    [anon_sym_GT_GT_EQ] = ACTIONS(5389),
    [anon_sym_AMP_EQ] = ACTIONS(5389),
    [anon_sym_CARET_EQ] = ACTIONS(5389),
    [anon_sym_PIPE_EQ] = ACTIONS(5389),
    [anon_sym_and_eq] = ACTIONS(5387),
    [anon_sym_or_eq] = ACTIONS(5387),
    [anon_sym_xor_eq] = ACTIONS(5387),
    [anon_sym_LT_EQ_GT] = ACTIONS(5389),
    [anon_sym_or] = ACTIONS(5387),
    [anon_sym_and] = ACTIONS(5387),
    [anon_sym_bitor] = ACTIONS(5387),
    [anon_sym_xor] = ACTIONS(5387),
    [anon_sym_bitand] = ACTIONS(5387),
    [anon_sym_not_eq] = ACTIONS(5387),
    [anon_sym_DASH_DASH] = ACTIONS(5389),
    [anon_sym_PLUS_PLUS] = ACTIONS(5389),
    [anon_sym_DOT] = ACTIONS(5387),
    [anon_sym_DOT_STAR] = ACTIONS(5389),
    [anon_sym_DASH_GT] = ACTIONS(5389),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5387),
    [anon_sym_decltype] = ACTIONS(5387),
  },
  [2631] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2640),
    [sym_identifier] = ACTIONS(5377),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5379),
    [anon_sym_COMMA] = ACTIONS(5379),
    [aux_sym_preproc_if_token2] = ACTIONS(5379),
    [aux_sym_preproc_else_token1] = ACTIONS(5379),
    [aux_sym_preproc_elif_token1] = ACTIONS(5377),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5379),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5379),
    [anon_sym_LPAREN2] = ACTIONS(5379),
    [anon_sym_DASH] = ACTIONS(5377),
    [anon_sym_PLUS] = ACTIONS(5377),
    [anon_sym_STAR] = ACTIONS(5377),
    [anon_sym_SLASH] = ACTIONS(5377),
    [anon_sym_PERCENT] = ACTIONS(5377),
    [anon_sym_PIPE_PIPE] = ACTIONS(5379),
    [anon_sym_AMP_AMP] = ACTIONS(5379),
    [anon_sym_PIPE] = ACTIONS(5377),
    [anon_sym_CARET] = ACTIONS(5377),
    [anon_sym_AMP] = ACTIONS(5377),
    [anon_sym_EQ_EQ] = ACTIONS(5379),
    [anon_sym_BANG_EQ] = ACTIONS(5379),
    [anon_sym_GT] = ACTIONS(5377),
    [anon_sym_GT_EQ] = ACTIONS(5379),
    [anon_sym_LT_EQ] = ACTIONS(5377),
    [anon_sym_LT] = ACTIONS(5377),
    [anon_sym_LT_LT] = ACTIONS(5377),
    [anon_sym_GT_GT] = ACTIONS(5377),
    [anon_sym___attribute__] = ACTIONS(5377),
    [anon_sym_LBRACE] = ACTIONS(5379),
    [anon_sym_signed] = ACTIONS(6115),
    [anon_sym_unsigned] = ACTIONS(6115),
    [anon_sym_long] = ACTIONS(6115),
    [anon_sym_short] = ACTIONS(6115),
    [anon_sym_LBRACK] = ACTIONS(5379),
    [anon_sym_EQ] = ACTIONS(5377),
    [anon_sym_QMARK] = ACTIONS(5379),
    [anon_sym_STAR_EQ] = ACTIONS(5379),
    [anon_sym_SLASH_EQ] = ACTIONS(5379),
    [anon_sym_PERCENT_EQ] = ACTIONS(5379),
    [anon_sym_PLUS_EQ] = ACTIONS(5379),
    [anon_sym_DASH_EQ] = ACTIONS(5379),
    [anon_sym_LT_LT_EQ] = ACTIONS(5379),
    [anon_sym_GT_GT_EQ] = ACTIONS(5379),
    [anon_sym_AMP_EQ] = ACTIONS(5379),
    [anon_sym_CARET_EQ] = ACTIONS(5379),
    [anon_sym_PIPE_EQ] = ACTIONS(5379),
    [anon_sym_and_eq] = ACTIONS(5377),
    [anon_sym_or_eq] = ACTIONS(5377),
    [anon_sym_xor_eq] = ACTIONS(5377),
    [anon_sym_LT_EQ_GT] = ACTIONS(5379),
    [anon_sym_or] = ACTIONS(5377),
    [anon_sym_and] = ACTIONS(5377),
    [anon_sym_bitor] = ACTIONS(5377),
    [anon_sym_xor] = ACTIONS(5377),
    [anon_sym_bitand] = ACTIONS(5377),
    [anon_sym_not_eq] = ACTIONS(5377),
    [anon_sym_DASH_DASH] = ACTIONS(5379),
    [anon_sym_PLUS_PLUS] = ACTIONS(5379),
    [anon_sym_DOT] = ACTIONS(5377),
    [anon_sym_DOT_STAR] = ACTIONS(5379),
    [anon_sym_DASH_GT] = ACTIONS(5379),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5377),
    [anon_sym_decltype] = ACTIONS(5377),
  },
  [2632] = {
    [sym_identifier] = ACTIONS(2712),
    [anon_sym___extension__] = ACTIONS(2712),
    [anon_sym_in] = ACTIONS(2712),
    [anon_sym_out] = ACTIONS(2712),
    [anon_sym_inout] = ACTIONS(2712),
    [anon_sym_extern] = ACTIONS(2712),
    [anon_sym___attribute__] = ACTIONS(2712),
    [anon_sym_COLON_COLON] = ACTIONS(2717),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2717),
    [anon_sym___declspec] = ACTIONS(2712),
    [anon_sym_signed] = ACTIONS(2712),
    [anon_sym_unsigned] = ACTIONS(2712),
    [anon_sym_long] = ACTIONS(2712),
    [anon_sym_short] = ACTIONS(2712),
    [anon_sym_static] = ACTIONS(2712),
    [anon_sym_register] = ACTIONS(2712),
    [anon_sym_inline] = ACTIONS(2712),
    [anon_sym___inline] = ACTIONS(2712),
    [anon_sym___inline__] = ACTIONS(2712),
    [anon_sym___forceinline] = ACTIONS(2712),
    [anon_sym_thread_local] = ACTIONS(2712),
    [anon_sym___thread] = ACTIONS(2712),
    [anon_sym_const] = ACTIONS(2712),
    [anon_sym_constexpr] = ACTIONS(2712),
    [anon_sym_volatile] = ACTIONS(2712),
    [anon_sym_restrict] = ACTIONS(2712),
    [anon_sym___restrict__] = ACTIONS(2712),
    [anon_sym__Atomic] = ACTIONS(2712),
    [anon_sym__Noreturn] = ACTIONS(2712),
    [anon_sym_noreturn] = ACTIONS(2712),
    [anon_sym_mutable] = ACTIONS(2712),
    [anon_sym_constinit] = ACTIONS(2712),
    [anon_sym_consteval] = ACTIONS(2712),
    [anon_sym_alignas] = ACTIONS(2712),
    [anon_sym__Alignas] = ACTIONS(2712),
    [sym_primitive_type] = ACTIONS(2712),
    [anon_sym_enum] = ACTIONS(2712),
    [anon_sym_class] = ACTIONS(2712),
    [anon_sym_struct] = ACTIONS(2712),
    [anon_sym_union] = ACTIONS(2712),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2712),
    [anon_sym_decltype] = ACTIONS(2712),
    [sym_virtual] = ACTIONS(2712),
    [anon_sym_typename] = ACTIONS(2712),
    [anon_sym_template] = ACTIONS(2712),
    [anon_sym_precise] = ACTIONS(2712),
    [anon_sym_shared] = ACTIONS(2712),
    [anon_sym_groupshared] = ACTIONS(2712),
    [anon_sym_uniform] = ACTIONS(2712),
    [anon_sym_row_major] = ACTIONS(2712),
    [anon_sym_column_major] = ACTIONS(2712),
    [anon_sym_globallycoherent] = ACTIONS(2712),
    [anon_sym_centroid] = ACTIONS(2712),
    [anon_sym_noperspective] = ACTIONS(2712),
    [anon_sym_nointerpolation] = ACTIONS(2712),
    [anon_sym_sample] = ACTIONS(2712),
    [anon_sym_linear] = ACTIONS(2712),
    [anon_sym_snorm] = ACTIONS(2712),
    [anon_sym_unorm] = ACTIONS(2712),
    [anon_sym_point] = ACTIONS(2712),
    [anon_sym_line] = ACTIONS(2712),
    [anon_sym_triangleadj] = ACTIONS(2712),
    [anon_sym_lineadj] = ACTIONS(2712),
    [anon_sym_triangle] = ACTIONS(2712),
  },
  [2633] = {
    [sym_identifier] = ACTIONS(5533),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5535),
    [anon_sym_COMMA] = ACTIONS(5535),
    [anon_sym_RPAREN] = ACTIONS(5535),
    [aux_sym_preproc_if_token2] = ACTIONS(5535),
    [aux_sym_preproc_else_token1] = ACTIONS(5535),
    [aux_sym_preproc_elif_token1] = ACTIONS(5533),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5535),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5535),
    [anon_sym_LPAREN2] = ACTIONS(5535),
    [anon_sym_DASH] = ACTIONS(5533),
    [anon_sym_PLUS] = ACTIONS(5533),
    [anon_sym_STAR] = ACTIONS(5533),
    [anon_sym_SLASH] = ACTIONS(5533),
    [anon_sym_PERCENT] = ACTIONS(5533),
    [anon_sym_PIPE_PIPE] = ACTIONS(5535),
    [anon_sym_AMP_AMP] = ACTIONS(5535),
    [anon_sym_PIPE] = ACTIONS(5533),
    [anon_sym_CARET] = ACTIONS(5533),
    [anon_sym_AMP] = ACTIONS(5533),
    [anon_sym_EQ_EQ] = ACTIONS(5535),
    [anon_sym_BANG_EQ] = ACTIONS(5535),
    [anon_sym_GT] = ACTIONS(5533),
    [anon_sym_GT_EQ] = ACTIONS(5535),
    [anon_sym_LT_EQ] = ACTIONS(5533),
    [anon_sym_LT] = ACTIONS(5533),
    [anon_sym_LT_LT] = ACTIONS(5533),
    [anon_sym_GT_GT] = ACTIONS(5533),
    [anon_sym_COLON] = ACTIONS(5535),
    [anon_sym_SEMI] = ACTIONS(5535),
    [anon_sym___attribute__] = ACTIONS(5533),
    [anon_sym_LBRACE] = ACTIONS(5535),
    [anon_sym_RBRACE] = ACTIONS(5535),
    [anon_sym_LBRACK] = ACTIONS(5535),
    [anon_sym_RBRACK] = ACTIONS(5535),
    [anon_sym_EQ] = ACTIONS(5533),
    [anon_sym_QMARK] = ACTIONS(5535),
    [anon_sym_STAR_EQ] = ACTIONS(5535),
    [anon_sym_SLASH_EQ] = ACTIONS(5535),
    [anon_sym_PERCENT_EQ] = ACTIONS(5535),
    [anon_sym_PLUS_EQ] = ACTIONS(5535),
    [anon_sym_DASH_EQ] = ACTIONS(5535),
    [anon_sym_LT_LT_EQ] = ACTIONS(5535),
    [anon_sym_GT_GT_EQ] = ACTIONS(5535),
    [anon_sym_AMP_EQ] = ACTIONS(5535),
    [anon_sym_CARET_EQ] = ACTIONS(5535),
    [anon_sym_PIPE_EQ] = ACTIONS(5535),
    [anon_sym_and_eq] = ACTIONS(5533),
    [anon_sym_or_eq] = ACTIONS(5533),
    [anon_sym_xor_eq] = ACTIONS(5533),
    [anon_sym_LT_EQ_GT] = ACTIONS(5535),
    [anon_sym_or] = ACTIONS(5533),
    [anon_sym_and] = ACTIONS(5533),
    [anon_sym_bitor] = ACTIONS(5533),
    [anon_sym_xor] = ACTIONS(5533),
    [anon_sym_bitand] = ACTIONS(5533),
    [anon_sym_not_eq] = ACTIONS(5533),
    [anon_sym_DASH_DASH] = ACTIONS(5535),
    [anon_sym_PLUS_PLUS] = ACTIONS(5535),
    [anon_sym_DOT] = ACTIONS(5533),
    [anon_sym_DOT_STAR] = ACTIONS(5535),
    [anon_sym_DASH_GT] = ACTIONS(5535),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5533),
    [anon_sym_decltype] = ACTIONS(5533),
  },
  [2634] = {
    [sym_string_literal] = STATE(2527),
    [sym_raw_string_literal] = STATE(2527),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5840),
    [anon_sym_COMMA] = ACTIONS(5840),
    [anon_sym_LPAREN2] = ACTIONS(5840),
    [anon_sym_DASH] = ACTIONS(5838),
    [anon_sym_PLUS] = ACTIONS(5838),
    [anon_sym_STAR] = ACTIONS(5838),
    [anon_sym_SLASH] = ACTIONS(5838),
    [anon_sym_PERCENT] = ACTIONS(5838),
    [anon_sym_PIPE_PIPE] = ACTIONS(5840),
    [anon_sym_AMP_AMP] = ACTIONS(5840),
    [anon_sym_PIPE] = ACTIONS(5838),
    [anon_sym_CARET] = ACTIONS(5838),
    [anon_sym_AMP] = ACTIONS(5838),
    [anon_sym_EQ_EQ] = ACTIONS(5840),
    [anon_sym_BANG_EQ] = ACTIONS(5840),
    [anon_sym_GT] = ACTIONS(5838),
    [anon_sym_GT_EQ] = ACTIONS(5840),
    [anon_sym_LT_EQ] = ACTIONS(5838),
    [anon_sym_LT] = ACTIONS(5838),
    [anon_sym_LT_LT] = ACTIONS(5838),
    [anon_sym_GT_GT] = ACTIONS(5838),
    [anon_sym_SEMI] = ACTIONS(5840),
    [anon_sym___attribute__] = ACTIONS(5838),
    [anon_sym_LBRACK] = ACTIONS(5840),
    [anon_sym_EQ] = ACTIONS(5838),
    [anon_sym_QMARK] = ACTIONS(5840),
    [anon_sym_STAR_EQ] = ACTIONS(5840),
    [anon_sym_SLASH_EQ] = ACTIONS(5840),
    [anon_sym_PERCENT_EQ] = ACTIONS(5840),
    [anon_sym_PLUS_EQ] = ACTIONS(5840),
    [anon_sym_DASH_EQ] = ACTIONS(5840),
    [anon_sym_LT_LT_EQ] = ACTIONS(5840),
    [anon_sym_GT_GT_EQ] = ACTIONS(5840),
    [anon_sym_AMP_EQ] = ACTIONS(5840),
    [anon_sym_CARET_EQ] = ACTIONS(5840),
    [anon_sym_PIPE_EQ] = ACTIONS(5840),
    [anon_sym_and_eq] = ACTIONS(5838),
    [anon_sym_or_eq] = ACTIONS(5838),
    [anon_sym_xor_eq] = ACTIONS(5838),
    [anon_sym_LT_EQ_GT] = ACTIONS(5840),
    [anon_sym_or] = ACTIONS(5838),
    [anon_sym_and] = ACTIONS(5838),
    [anon_sym_bitor] = ACTIONS(5838),
    [anon_sym_xor] = ACTIONS(5838),
    [anon_sym_bitand] = ACTIONS(5838),
    [anon_sym_not_eq] = ACTIONS(5838),
    [anon_sym_DASH_DASH] = ACTIONS(5840),
    [anon_sym_PLUS_PLUS] = ACTIONS(5840),
    [anon_sym_DOT] = ACTIONS(5838),
    [anon_sym_DOT_STAR] = ACTIONS(5840),
    [anon_sym_DASH_GT] = ACTIONS(5840),
    [anon_sym_L_DQUOTE] = ACTIONS(5957),
    [anon_sym_u_DQUOTE] = ACTIONS(5957),
    [anon_sym_U_DQUOTE] = ACTIONS(5957),
    [anon_sym_u8_DQUOTE] = ACTIONS(5957),
    [anon_sym_DQUOTE] = ACTIONS(5957),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5959),
    [anon_sym_LR_DQUOTE] = ACTIONS(5959),
    [anon_sym_uR_DQUOTE] = ACTIONS(5959),
    [anon_sym_UR_DQUOTE] = ACTIONS(5959),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5959),
    [sym_literal_suffix] = ACTIONS(5836),
  },
  [2635] = {
    [sym_identifier] = ACTIONS(5431),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5433),
    [anon_sym_COMMA] = ACTIONS(5433),
    [anon_sym_RPAREN] = ACTIONS(5433),
    [aux_sym_preproc_if_token2] = ACTIONS(5433),
    [aux_sym_preproc_else_token1] = ACTIONS(5433),
    [aux_sym_preproc_elif_token1] = ACTIONS(5431),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5433),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5433),
    [anon_sym_LPAREN2] = ACTIONS(5433),
    [anon_sym_DASH] = ACTIONS(5431),
    [anon_sym_PLUS] = ACTIONS(5431),
    [anon_sym_STAR] = ACTIONS(5431),
    [anon_sym_SLASH] = ACTIONS(5431),
    [anon_sym_PERCENT] = ACTIONS(5431),
    [anon_sym_PIPE_PIPE] = ACTIONS(5433),
    [anon_sym_AMP_AMP] = ACTIONS(5433),
    [anon_sym_PIPE] = ACTIONS(5431),
    [anon_sym_CARET] = ACTIONS(5431),
    [anon_sym_AMP] = ACTIONS(5431),
    [anon_sym_EQ_EQ] = ACTIONS(5433),
    [anon_sym_BANG_EQ] = ACTIONS(5433),
    [anon_sym_GT] = ACTIONS(5431),
    [anon_sym_GT_EQ] = ACTIONS(5433),
    [anon_sym_LT_EQ] = ACTIONS(5431),
    [anon_sym_LT] = ACTIONS(5431),
    [anon_sym_LT_LT] = ACTIONS(5431),
    [anon_sym_GT_GT] = ACTIONS(5431),
    [anon_sym_COLON] = ACTIONS(5433),
    [anon_sym_SEMI] = ACTIONS(5433),
    [anon_sym___attribute__] = ACTIONS(5431),
    [anon_sym_LBRACE] = ACTIONS(5433),
    [anon_sym_RBRACE] = ACTIONS(5433),
    [anon_sym_LBRACK] = ACTIONS(5433),
    [anon_sym_RBRACK] = ACTIONS(5433),
    [anon_sym_EQ] = ACTIONS(5431),
    [anon_sym_QMARK] = ACTIONS(5433),
    [anon_sym_STAR_EQ] = ACTIONS(5433),
    [anon_sym_SLASH_EQ] = ACTIONS(5433),
    [anon_sym_PERCENT_EQ] = ACTIONS(5433),
    [anon_sym_PLUS_EQ] = ACTIONS(5433),
    [anon_sym_DASH_EQ] = ACTIONS(5433),
    [anon_sym_LT_LT_EQ] = ACTIONS(5433),
    [anon_sym_GT_GT_EQ] = ACTIONS(5433),
    [anon_sym_AMP_EQ] = ACTIONS(5433),
    [anon_sym_CARET_EQ] = ACTIONS(5433),
    [anon_sym_PIPE_EQ] = ACTIONS(5433),
    [anon_sym_and_eq] = ACTIONS(5431),
    [anon_sym_or_eq] = ACTIONS(5431),
    [anon_sym_xor_eq] = ACTIONS(5431),
    [anon_sym_LT_EQ_GT] = ACTIONS(5433),
    [anon_sym_or] = ACTIONS(5431),
    [anon_sym_and] = ACTIONS(5431),
    [anon_sym_bitor] = ACTIONS(5431),
    [anon_sym_xor] = ACTIONS(5431),
    [anon_sym_bitand] = ACTIONS(5431),
    [anon_sym_not_eq] = ACTIONS(5431),
    [anon_sym_DASH_DASH] = ACTIONS(5433),
    [anon_sym_PLUS_PLUS] = ACTIONS(5433),
    [anon_sym_DOT] = ACTIONS(5431),
    [anon_sym_DOT_STAR] = ACTIONS(5433),
    [anon_sym_DASH_GT] = ACTIONS(5433),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5431),
    [anon_sym_decltype] = ACTIONS(5431),
  },
  [2636] = {
    [sym_argument_list] = STATE(2773),
    [sym_initializer_list] = STATE(2773),
    [sym_identifier] = ACTIONS(6117),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6119),
    [anon_sym_COMMA] = ACTIONS(6119),
    [anon_sym_RPAREN] = ACTIONS(6119),
    [aux_sym_preproc_if_token2] = ACTIONS(6119),
    [aux_sym_preproc_else_token1] = ACTIONS(6119),
    [aux_sym_preproc_elif_token1] = ACTIONS(6117),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6119),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6119),
    [anon_sym_LPAREN2] = ACTIONS(5854),
    [anon_sym_DASH] = ACTIONS(6117),
    [anon_sym_PLUS] = ACTIONS(6117),
    [anon_sym_STAR] = ACTIONS(6117),
    [anon_sym_SLASH] = ACTIONS(6117),
    [anon_sym_PERCENT] = ACTIONS(6117),
    [anon_sym_PIPE_PIPE] = ACTIONS(6119),
    [anon_sym_AMP_AMP] = ACTIONS(6119),
    [anon_sym_PIPE] = ACTIONS(6117),
    [anon_sym_CARET] = ACTIONS(6117),
    [anon_sym_AMP] = ACTIONS(6117),
    [anon_sym_EQ_EQ] = ACTIONS(6119),
    [anon_sym_BANG_EQ] = ACTIONS(6119),
    [anon_sym_GT] = ACTIONS(6117),
    [anon_sym_GT_EQ] = ACTIONS(6119),
    [anon_sym_LT_EQ] = ACTIONS(6117),
    [anon_sym_LT] = ACTIONS(6117),
    [anon_sym_LT_LT] = ACTIONS(6117),
    [anon_sym_GT_GT] = ACTIONS(6117),
    [anon_sym_COLON] = ACTIONS(6119),
    [anon_sym_SEMI] = ACTIONS(6119),
    [anon_sym___attribute__] = ACTIONS(6117),
    [anon_sym_LBRACE] = ACTIONS(3523),
    [anon_sym_RBRACE] = ACTIONS(6119),
    [anon_sym_LBRACK] = ACTIONS(6119),
    [anon_sym_RBRACK] = ACTIONS(6119),
    [anon_sym_EQ] = ACTIONS(6117),
    [anon_sym_QMARK] = ACTIONS(6119),
    [anon_sym_STAR_EQ] = ACTIONS(6119),
    [anon_sym_SLASH_EQ] = ACTIONS(6119),
    [anon_sym_PERCENT_EQ] = ACTIONS(6119),
    [anon_sym_PLUS_EQ] = ACTIONS(6119),
    [anon_sym_DASH_EQ] = ACTIONS(6119),
    [anon_sym_LT_LT_EQ] = ACTIONS(6119),
    [anon_sym_GT_GT_EQ] = ACTIONS(6119),
    [anon_sym_AMP_EQ] = ACTIONS(6119),
    [anon_sym_CARET_EQ] = ACTIONS(6119),
    [anon_sym_PIPE_EQ] = ACTIONS(6119),
    [anon_sym_and_eq] = ACTIONS(6117),
    [anon_sym_or_eq] = ACTIONS(6117),
    [anon_sym_xor_eq] = ACTIONS(6117),
    [anon_sym_LT_EQ_GT] = ACTIONS(6119),
    [anon_sym_or] = ACTIONS(6117),
    [anon_sym_and] = ACTIONS(6117),
    [anon_sym_bitor] = ACTIONS(6117),
    [anon_sym_xor] = ACTIONS(6117),
    [anon_sym_bitand] = ACTIONS(6117),
    [anon_sym_not_eq] = ACTIONS(6117),
    [anon_sym_DASH_DASH] = ACTIONS(6119),
    [anon_sym_PLUS_PLUS] = ACTIONS(6119),
    [anon_sym_DOT] = ACTIONS(6117),
    [anon_sym_DOT_STAR] = ACTIONS(6119),
    [anon_sym_DASH_GT] = ACTIONS(6119),
    [sym_comment] = ACTIONS(3),
  },
  [2637] = {
    [sym_identifier] = ACTIONS(6121),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6123),
    [anon_sym_COMMA] = ACTIONS(6123),
    [anon_sym_RPAREN] = ACTIONS(6123),
    [aux_sym_preproc_if_token2] = ACTIONS(6123),
    [aux_sym_preproc_else_token1] = ACTIONS(6123),
    [aux_sym_preproc_elif_token1] = ACTIONS(6121),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6123),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6123),
    [anon_sym_LPAREN2] = ACTIONS(6123),
    [anon_sym_DASH] = ACTIONS(6121),
    [anon_sym_PLUS] = ACTIONS(6121),
    [anon_sym_STAR] = ACTIONS(6121),
    [anon_sym_SLASH] = ACTIONS(6121),
    [anon_sym_PERCENT] = ACTIONS(6121),
    [anon_sym_PIPE_PIPE] = ACTIONS(6123),
    [anon_sym_AMP_AMP] = ACTIONS(6123),
    [anon_sym_PIPE] = ACTIONS(6121),
    [anon_sym_CARET] = ACTIONS(6121),
    [anon_sym_AMP] = ACTIONS(6121),
    [anon_sym_EQ_EQ] = ACTIONS(6123),
    [anon_sym_BANG_EQ] = ACTIONS(6123),
    [anon_sym_GT] = ACTIONS(6121),
    [anon_sym_GT_EQ] = ACTIONS(6123),
    [anon_sym_LT_EQ] = ACTIONS(6121),
    [anon_sym_LT] = ACTIONS(6121),
    [anon_sym_LT_LT] = ACTIONS(6121),
    [anon_sym_GT_GT] = ACTIONS(6121),
    [anon_sym_COLON] = ACTIONS(6123),
    [anon_sym_SEMI] = ACTIONS(6123),
    [anon_sym___attribute__] = ACTIONS(6121),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6123),
    [anon_sym_LBRACE] = ACTIONS(6123),
    [anon_sym_RBRACE] = ACTIONS(6123),
    [anon_sym_LBRACK] = ACTIONS(6121),
    [anon_sym_RBRACK] = ACTIONS(6123),
    [anon_sym_EQ] = ACTIONS(6121),
    [anon_sym_QMARK] = ACTIONS(6123),
    [anon_sym_STAR_EQ] = ACTIONS(6123),
    [anon_sym_SLASH_EQ] = ACTIONS(6123),
    [anon_sym_PERCENT_EQ] = ACTIONS(6123),
    [anon_sym_PLUS_EQ] = ACTIONS(6123),
    [anon_sym_DASH_EQ] = ACTIONS(6123),
    [anon_sym_LT_LT_EQ] = ACTIONS(6123),
    [anon_sym_GT_GT_EQ] = ACTIONS(6123),
    [anon_sym_AMP_EQ] = ACTIONS(6123),
    [anon_sym_CARET_EQ] = ACTIONS(6123),
    [anon_sym_PIPE_EQ] = ACTIONS(6123),
    [anon_sym_and_eq] = ACTIONS(6121),
    [anon_sym_or_eq] = ACTIONS(6121),
    [anon_sym_xor_eq] = ACTIONS(6121),
    [anon_sym_LT_EQ_GT] = ACTIONS(6123),
    [anon_sym_or] = ACTIONS(6121),
    [anon_sym_and] = ACTIONS(6121),
    [anon_sym_bitor] = ACTIONS(6121),
    [anon_sym_xor] = ACTIONS(6121),
    [anon_sym_bitand] = ACTIONS(6121),
    [anon_sym_not_eq] = ACTIONS(6121),
    [anon_sym_DASH_DASH] = ACTIONS(6123),
    [anon_sym_PLUS_PLUS] = ACTIONS(6123),
    [anon_sym_DOT] = ACTIONS(6121),
    [anon_sym_DOT_STAR] = ACTIONS(6123),
    [anon_sym_DASH_GT] = ACTIONS(6123),
    [sym_comment] = ACTIONS(3),
    [anon_sym_try] = ACTIONS(6121),
  },
  [2638] = {
    [sym_identifier] = ACTIONS(5507),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5509),
    [anon_sym_COMMA] = ACTIONS(5509),
    [anon_sym_RPAREN] = ACTIONS(5509),
    [aux_sym_preproc_if_token2] = ACTIONS(5509),
    [aux_sym_preproc_else_token1] = ACTIONS(5509),
    [aux_sym_preproc_elif_token1] = ACTIONS(5507),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5509),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5509),
    [anon_sym_LPAREN2] = ACTIONS(5509),
    [anon_sym_DASH] = ACTIONS(5507),
    [anon_sym_PLUS] = ACTIONS(5507),
    [anon_sym_STAR] = ACTIONS(5507),
    [anon_sym_SLASH] = ACTIONS(5507),
    [anon_sym_PERCENT] = ACTIONS(5507),
    [anon_sym_PIPE_PIPE] = ACTIONS(5509),
    [anon_sym_AMP_AMP] = ACTIONS(5509),
    [anon_sym_PIPE] = ACTIONS(5507),
    [anon_sym_CARET] = ACTIONS(5507),
    [anon_sym_AMP] = ACTIONS(5507),
    [anon_sym_EQ_EQ] = ACTIONS(5509),
    [anon_sym_BANG_EQ] = ACTIONS(5509),
    [anon_sym_GT] = ACTIONS(5507),
    [anon_sym_GT_EQ] = ACTIONS(5509),
    [anon_sym_LT_EQ] = ACTIONS(5507),
    [anon_sym_LT] = ACTIONS(5507),
    [anon_sym_LT_LT] = ACTIONS(5507),
    [anon_sym_GT_GT] = ACTIONS(5507),
    [anon_sym_COLON] = ACTIONS(5509),
    [anon_sym_SEMI] = ACTIONS(5509),
    [anon_sym___attribute__] = ACTIONS(5507),
    [anon_sym_LBRACE] = ACTIONS(5509),
    [anon_sym_RBRACE] = ACTIONS(5509),
    [anon_sym_LBRACK] = ACTIONS(5509),
    [anon_sym_RBRACK] = ACTIONS(5509),
    [anon_sym_EQ] = ACTIONS(5507),
    [anon_sym_QMARK] = ACTIONS(5509),
    [anon_sym_STAR_EQ] = ACTIONS(5509),
    [anon_sym_SLASH_EQ] = ACTIONS(5509),
    [anon_sym_PERCENT_EQ] = ACTIONS(5509),
    [anon_sym_PLUS_EQ] = ACTIONS(5509),
    [anon_sym_DASH_EQ] = ACTIONS(5509),
    [anon_sym_LT_LT_EQ] = ACTIONS(5509),
    [anon_sym_GT_GT_EQ] = ACTIONS(5509),
    [anon_sym_AMP_EQ] = ACTIONS(5509),
    [anon_sym_CARET_EQ] = ACTIONS(5509),
    [anon_sym_PIPE_EQ] = ACTIONS(5509),
    [anon_sym_and_eq] = ACTIONS(5507),
    [anon_sym_or_eq] = ACTIONS(5507),
    [anon_sym_xor_eq] = ACTIONS(5507),
    [anon_sym_LT_EQ_GT] = ACTIONS(5509),
    [anon_sym_or] = ACTIONS(5507),
    [anon_sym_and] = ACTIONS(5507),
    [anon_sym_bitor] = ACTIONS(5507),
    [anon_sym_xor] = ACTIONS(5507),
    [anon_sym_bitand] = ACTIONS(5507),
    [anon_sym_not_eq] = ACTIONS(5507),
    [anon_sym_DASH_DASH] = ACTIONS(5509),
    [anon_sym_PLUS_PLUS] = ACTIONS(5509),
    [anon_sym_DOT] = ACTIONS(5507),
    [anon_sym_DOT_STAR] = ACTIONS(5509),
    [anon_sym_DASH_GT] = ACTIONS(5509),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5507),
    [anon_sym_decltype] = ACTIONS(5507),
  },
  [2639] = {
    [sym_identifier] = ACTIONS(6125),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6127),
    [anon_sym_COMMA] = ACTIONS(6127),
    [anon_sym_RPAREN] = ACTIONS(6127),
    [aux_sym_preproc_if_token2] = ACTIONS(6127),
    [aux_sym_preproc_else_token1] = ACTIONS(6127),
    [aux_sym_preproc_elif_token1] = ACTIONS(6125),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6127),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6127),
    [anon_sym_LPAREN2] = ACTIONS(6127),
    [anon_sym_DASH] = ACTIONS(6125),
    [anon_sym_PLUS] = ACTIONS(6125),
    [anon_sym_STAR] = ACTIONS(6125),
    [anon_sym_SLASH] = ACTIONS(6125),
    [anon_sym_PERCENT] = ACTIONS(6125),
    [anon_sym_PIPE_PIPE] = ACTIONS(6127),
    [anon_sym_AMP_AMP] = ACTIONS(6127),
    [anon_sym_PIPE] = ACTIONS(6125),
    [anon_sym_CARET] = ACTIONS(6125),
    [anon_sym_AMP] = ACTIONS(6125),
    [anon_sym_EQ_EQ] = ACTIONS(6127),
    [anon_sym_BANG_EQ] = ACTIONS(6127),
    [anon_sym_GT] = ACTIONS(6125),
    [anon_sym_GT_EQ] = ACTIONS(6127),
    [anon_sym_LT_EQ] = ACTIONS(6125),
    [anon_sym_LT] = ACTIONS(6125),
    [anon_sym_LT_LT] = ACTIONS(6125),
    [anon_sym_GT_GT] = ACTIONS(6125),
    [anon_sym_COLON] = ACTIONS(6127),
    [anon_sym_SEMI] = ACTIONS(6127),
    [anon_sym___attribute__] = ACTIONS(6125),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6127),
    [anon_sym_LBRACE] = ACTIONS(6127),
    [anon_sym_RBRACE] = ACTIONS(6127),
    [anon_sym_LBRACK] = ACTIONS(6125),
    [anon_sym_RBRACK] = ACTIONS(6127),
    [anon_sym_EQ] = ACTIONS(6125),
    [anon_sym_QMARK] = ACTIONS(6127),
    [anon_sym_STAR_EQ] = ACTIONS(6127),
    [anon_sym_SLASH_EQ] = ACTIONS(6127),
    [anon_sym_PERCENT_EQ] = ACTIONS(6127),
    [anon_sym_PLUS_EQ] = ACTIONS(6127),
    [anon_sym_DASH_EQ] = ACTIONS(6127),
    [anon_sym_LT_LT_EQ] = ACTIONS(6127),
    [anon_sym_GT_GT_EQ] = ACTIONS(6127),
    [anon_sym_AMP_EQ] = ACTIONS(6127),
    [anon_sym_CARET_EQ] = ACTIONS(6127),
    [anon_sym_PIPE_EQ] = ACTIONS(6127),
    [anon_sym_and_eq] = ACTIONS(6125),
    [anon_sym_or_eq] = ACTIONS(6125),
    [anon_sym_xor_eq] = ACTIONS(6125),
    [anon_sym_LT_EQ_GT] = ACTIONS(6127),
    [anon_sym_or] = ACTIONS(6125),
    [anon_sym_and] = ACTIONS(6125),
    [anon_sym_bitor] = ACTIONS(6125),
    [anon_sym_xor] = ACTIONS(6125),
    [anon_sym_bitand] = ACTIONS(6125),
    [anon_sym_not_eq] = ACTIONS(6125),
    [anon_sym_DASH_DASH] = ACTIONS(6127),
    [anon_sym_PLUS_PLUS] = ACTIONS(6127),
    [anon_sym_DOT] = ACTIONS(6125),
    [anon_sym_DOT_STAR] = ACTIONS(6127),
    [anon_sym_DASH_GT] = ACTIONS(6127),
    [sym_comment] = ACTIONS(3),
    [anon_sym_try] = ACTIONS(6125),
  },
  [2640] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2640),
    [sym_identifier] = ACTIONS(5224),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5226),
    [anon_sym_COMMA] = ACTIONS(5226),
    [aux_sym_preproc_if_token2] = ACTIONS(5226),
    [aux_sym_preproc_else_token1] = ACTIONS(5226),
    [aux_sym_preproc_elif_token1] = ACTIONS(5224),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5226),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5226),
    [anon_sym_LPAREN2] = ACTIONS(5226),
    [anon_sym_DASH] = ACTIONS(5224),
    [anon_sym_PLUS] = ACTIONS(5224),
    [anon_sym_STAR] = ACTIONS(5224),
    [anon_sym_SLASH] = ACTIONS(5224),
    [anon_sym_PERCENT] = ACTIONS(5224),
    [anon_sym_PIPE_PIPE] = ACTIONS(5226),
    [anon_sym_AMP_AMP] = ACTIONS(5226),
    [anon_sym_PIPE] = ACTIONS(5224),
    [anon_sym_CARET] = ACTIONS(5224),
    [anon_sym_AMP] = ACTIONS(5224),
    [anon_sym_EQ_EQ] = ACTIONS(5226),
    [anon_sym_BANG_EQ] = ACTIONS(5226),
    [anon_sym_GT] = ACTIONS(5224),
    [anon_sym_GT_EQ] = ACTIONS(5226),
    [anon_sym_LT_EQ] = ACTIONS(5224),
    [anon_sym_LT] = ACTIONS(5224),
    [anon_sym_LT_LT] = ACTIONS(5224),
    [anon_sym_GT_GT] = ACTIONS(5224),
    [anon_sym___attribute__] = ACTIONS(5224),
    [anon_sym_LBRACE] = ACTIONS(5226),
    [anon_sym_signed] = ACTIONS(6129),
    [anon_sym_unsigned] = ACTIONS(6129),
    [anon_sym_long] = ACTIONS(6129),
    [anon_sym_short] = ACTIONS(6129),
    [anon_sym_LBRACK] = ACTIONS(5226),
    [anon_sym_EQ] = ACTIONS(5224),
    [anon_sym_QMARK] = ACTIONS(5226),
    [anon_sym_STAR_EQ] = ACTIONS(5226),
    [anon_sym_SLASH_EQ] = ACTIONS(5226),
    [anon_sym_PERCENT_EQ] = ACTIONS(5226),
    [anon_sym_PLUS_EQ] = ACTIONS(5226),
    [anon_sym_DASH_EQ] = ACTIONS(5226),
    [anon_sym_LT_LT_EQ] = ACTIONS(5226),
    [anon_sym_GT_GT_EQ] = ACTIONS(5226),
    [anon_sym_AMP_EQ] = ACTIONS(5226),
    [anon_sym_CARET_EQ] = ACTIONS(5226),
    [anon_sym_PIPE_EQ] = ACTIONS(5226),
    [anon_sym_and_eq] = ACTIONS(5224),
    [anon_sym_or_eq] = ACTIONS(5224),
    [anon_sym_xor_eq] = ACTIONS(5224),
    [anon_sym_LT_EQ_GT] = ACTIONS(5226),
    [anon_sym_or] = ACTIONS(5224),
    [anon_sym_and] = ACTIONS(5224),
    [anon_sym_bitor] = ACTIONS(5224),
    [anon_sym_xor] = ACTIONS(5224),
    [anon_sym_bitand] = ACTIONS(5224),
    [anon_sym_not_eq] = ACTIONS(5224),
    [anon_sym_DASH_DASH] = ACTIONS(5226),
    [anon_sym_PLUS_PLUS] = ACTIONS(5226),
    [anon_sym_DOT] = ACTIONS(5224),
    [anon_sym_DOT_STAR] = ACTIONS(5226),
    [anon_sym_DASH_GT] = ACTIONS(5226),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5224),
    [anon_sym_decltype] = ACTIONS(5224),
  },
  [2641] = {
    [sym_identifier] = ACTIONS(5549),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5551),
    [anon_sym_COMMA] = ACTIONS(5551),
    [anon_sym_RPAREN] = ACTIONS(5551),
    [aux_sym_preproc_if_token2] = ACTIONS(5551),
    [aux_sym_preproc_else_token1] = ACTIONS(5551),
    [aux_sym_preproc_elif_token1] = ACTIONS(5549),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5551),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5551),
    [anon_sym_LPAREN2] = ACTIONS(5551),
    [anon_sym_DASH] = ACTIONS(5549),
    [anon_sym_PLUS] = ACTIONS(5549),
    [anon_sym_STAR] = ACTIONS(5549),
    [anon_sym_SLASH] = ACTIONS(5549),
    [anon_sym_PERCENT] = ACTIONS(5549),
    [anon_sym_PIPE_PIPE] = ACTIONS(5551),
    [anon_sym_AMP_AMP] = ACTIONS(5551),
    [anon_sym_PIPE] = ACTIONS(5549),
    [anon_sym_CARET] = ACTIONS(5549),
    [anon_sym_AMP] = ACTIONS(5549),
    [anon_sym_EQ_EQ] = ACTIONS(5551),
    [anon_sym_BANG_EQ] = ACTIONS(5551),
    [anon_sym_GT] = ACTIONS(5549),
    [anon_sym_GT_EQ] = ACTIONS(5551),
    [anon_sym_LT_EQ] = ACTIONS(5549),
    [anon_sym_LT] = ACTIONS(5549),
    [anon_sym_LT_LT] = ACTIONS(5549),
    [anon_sym_GT_GT] = ACTIONS(5549),
    [anon_sym_COLON] = ACTIONS(5551),
    [anon_sym_SEMI] = ACTIONS(5551),
    [anon_sym___attribute__] = ACTIONS(5549),
    [anon_sym_LBRACE] = ACTIONS(5551),
    [anon_sym_RBRACE] = ACTIONS(5551),
    [anon_sym_LBRACK] = ACTIONS(5551),
    [anon_sym_RBRACK] = ACTIONS(5551),
    [anon_sym_EQ] = ACTIONS(5549),
    [anon_sym_QMARK] = ACTIONS(5551),
    [anon_sym_STAR_EQ] = ACTIONS(5551),
    [anon_sym_SLASH_EQ] = ACTIONS(5551),
    [anon_sym_PERCENT_EQ] = ACTIONS(5551),
    [anon_sym_PLUS_EQ] = ACTIONS(5551),
    [anon_sym_DASH_EQ] = ACTIONS(5551),
    [anon_sym_LT_LT_EQ] = ACTIONS(5551),
    [anon_sym_GT_GT_EQ] = ACTIONS(5551),
    [anon_sym_AMP_EQ] = ACTIONS(5551),
    [anon_sym_CARET_EQ] = ACTIONS(5551),
    [anon_sym_PIPE_EQ] = ACTIONS(5551),
    [anon_sym_and_eq] = ACTIONS(5549),
    [anon_sym_or_eq] = ACTIONS(5549),
    [anon_sym_xor_eq] = ACTIONS(5549),
    [anon_sym_LT_EQ_GT] = ACTIONS(5551),
    [anon_sym_or] = ACTIONS(5549),
    [anon_sym_and] = ACTIONS(5549),
    [anon_sym_bitor] = ACTIONS(5549),
    [anon_sym_xor] = ACTIONS(5549),
    [anon_sym_bitand] = ACTIONS(5549),
    [anon_sym_not_eq] = ACTIONS(5549),
    [anon_sym_DASH_DASH] = ACTIONS(5551),
    [anon_sym_PLUS_PLUS] = ACTIONS(5551),
    [anon_sym_DOT] = ACTIONS(5549),
    [anon_sym_DOT_STAR] = ACTIONS(5551),
    [anon_sym_DASH_GT] = ACTIONS(5551),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5549),
    [anon_sym_decltype] = ACTIONS(5549),
  },
  [2642] = {
    [sym_attribute_declaration] = STATE(2588),
    [aux_sym_attributed_declarator_repeat1] = STATE(2588),
    [sym_identifier] = ACTIONS(6132),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6134),
    [anon_sym_COMMA] = ACTIONS(6134),
    [anon_sym_RPAREN] = ACTIONS(6134),
    [aux_sym_preproc_if_token2] = ACTIONS(6134),
    [aux_sym_preproc_else_token1] = ACTIONS(6134),
    [aux_sym_preproc_elif_token1] = ACTIONS(6132),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6134),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6134),
    [anon_sym_LPAREN2] = ACTIONS(6134),
    [anon_sym_DASH] = ACTIONS(6132),
    [anon_sym_PLUS] = ACTIONS(6132),
    [anon_sym_STAR] = ACTIONS(6132),
    [anon_sym_SLASH] = ACTIONS(6132),
    [anon_sym_PERCENT] = ACTIONS(6132),
    [anon_sym_PIPE_PIPE] = ACTIONS(6134),
    [anon_sym_AMP_AMP] = ACTIONS(6134),
    [anon_sym_PIPE] = ACTIONS(6132),
    [anon_sym_CARET] = ACTIONS(6132),
    [anon_sym_AMP] = ACTIONS(6132),
    [anon_sym_EQ_EQ] = ACTIONS(6134),
    [anon_sym_BANG_EQ] = ACTIONS(6134),
    [anon_sym_GT] = ACTIONS(6132),
    [anon_sym_GT_EQ] = ACTIONS(6134),
    [anon_sym_LT_EQ] = ACTIONS(6132),
    [anon_sym_LT] = ACTIONS(6132),
    [anon_sym_LT_LT] = ACTIONS(6132),
    [anon_sym_GT_GT] = ACTIONS(6132),
    [anon_sym_COLON] = ACTIONS(6134),
    [anon_sym_SEMI] = ACTIONS(6134),
    [anon_sym___attribute__] = ACTIONS(6132),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5986),
    [anon_sym_RBRACE] = ACTIONS(6134),
    [anon_sym_LBRACK] = ACTIONS(6132),
    [anon_sym_RBRACK] = ACTIONS(6134),
    [anon_sym_EQ] = ACTIONS(6132),
    [anon_sym_QMARK] = ACTIONS(6134),
    [anon_sym_STAR_EQ] = ACTIONS(6134),
    [anon_sym_SLASH_EQ] = ACTIONS(6134),
    [anon_sym_PERCENT_EQ] = ACTIONS(6134),
    [anon_sym_PLUS_EQ] = ACTIONS(6134),
    [anon_sym_DASH_EQ] = ACTIONS(6134),
    [anon_sym_LT_LT_EQ] = ACTIONS(6134),
    [anon_sym_GT_GT_EQ] = ACTIONS(6134),
    [anon_sym_AMP_EQ] = ACTIONS(6134),
    [anon_sym_CARET_EQ] = ACTIONS(6134),
    [anon_sym_PIPE_EQ] = ACTIONS(6134),
    [anon_sym_and_eq] = ACTIONS(6132),
    [anon_sym_or_eq] = ACTIONS(6132),
    [anon_sym_xor_eq] = ACTIONS(6132),
    [anon_sym_LT_EQ_GT] = ACTIONS(6134),
    [anon_sym_or] = ACTIONS(6132),
    [anon_sym_and] = ACTIONS(6132),
    [anon_sym_bitor] = ACTIONS(6132),
    [anon_sym_xor] = ACTIONS(6132),
    [anon_sym_bitand] = ACTIONS(6132),
    [anon_sym_not_eq] = ACTIONS(6132),
    [anon_sym_DASH_DASH] = ACTIONS(6134),
    [anon_sym_PLUS_PLUS] = ACTIONS(6134),
    [anon_sym_DOT] = ACTIONS(6132),
    [anon_sym_DOT_STAR] = ACTIONS(6134),
    [anon_sym_DASH_GT] = ACTIONS(6134),
    [sym_comment] = ACTIONS(3),
  },
  [2643] = {
    [sym_argument_list] = STATE(2793),
    [sym_initializer_list] = STATE(2793),
    [sym_identifier] = ACTIONS(6136),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6138),
    [anon_sym_COMMA] = ACTIONS(6138),
    [anon_sym_RPAREN] = ACTIONS(6138),
    [aux_sym_preproc_if_token2] = ACTIONS(6138),
    [aux_sym_preproc_else_token1] = ACTIONS(6138),
    [aux_sym_preproc_elif_token1] = ACTIONS(6136),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6138),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6138),
    [anon_sym_LPAREN2] = ACTIONS(5854),
    [anon_sym_DASH] = ACTIONS(6136),
    [anon_sym_PLUS] = ACTIONS(6136),
    [anon_sym_STAR] = ACTIONS(6136),
    [anon_sym_SLASH] = ACTIONS(6136),
    [anon_sym_PERCENT] = ACTIONS(6136),
    [anon_sym_PIPE_PIPE] = ACTIONS(6138),
    [anon_sym_AMP_AMP] = ACTIONS(6138),
    [anon_sym_PIPE] = ACTIONS(6136),
    [anon_sym_CARET] = ACTIONS(6136),
    [anon_sym_AMP] = ACTIONS(6136),
    [anon_sym_EQ_EQ] = ACTIONS(6138),
    [anon_sym_BANG_EQ] = ACTIONS(6138),
    [anon_sym_GT] = ACTIONS(6136),
    [anon_sym_GT_EQ] = ACTIONS(6138),
    [anon_sym_LT_EQ] = ACTIONS(6136),
    [anon_sym_LT] = ACTIONS(6136),
    [anon_sym_LT_LT] = ACTIONS(6136),
    [anon_sym_GT_GT] = ACTIONS(6136),
    [anon_sym_COLON] = ACTIONS(6138),
    [anon_sym_SEMI] = ACTIONS(6138),
    [anon_sym___attribute__] = ACTIONS(6136),
    [anon_sym_LBRACE] = ACTIONS(3523),
    [anon_sym_RBRACE] = ACTIONS(6138),
    [anon_sym_LBRACK] = ACTIONS(6138),
    [anon_sym_RBRACK] = ACTIONS(6138),
    [anon_sym_EQ] = ACTIONS(6136),
    [anon_sym_QMARK] = ACTIONS(6138),
    [anon_sym_STAR_EQ] = ACTIONS(6138),
    [anon_sym_SLASH_EQ] = ACTIONS(6138),
    [anon_sym_PERCENT_EQ] = ACTIONS(6138),
    [anon_sym_PLUS_EQ] = ACTIONS(6138),
    [anon_sym_DASH_EQ] = ACTIONS(6138),
    [anon_sym_LT_LT_EQ] = ACTIONS(6138),
    [anon_sym_GT_GT_EQ] = ACTIONS(6138),
    [anon_sym_AMP_EQ] = ACTIONS(6138),
    [anon_sym_CARET_EQ] = ACTIONS(6138),
    [anon_sym_PIPE_EQ] = ACTIONS(6138),
    [anon_sym_and_eq] = ACTIONS(6136),
    [anon_sym_or_eq] = ACTIONS(6136),
    [anon_sym_xor_eq] = ACTIONS(6136),
    [anon_sym_LT_EQ_GT] = ACTIONS(6138),
    [anon_sym_or] = ACTIONS(6136),
    [anon_sym_and] = ACTIONS(6136),
    [anon_sym_bitor] = ACTIONS(6136),
    [anon_sym_xor] = ACTIONS(6136),
    [anon_sym_bitand] = ACTIONS(6136),
    [anon_sym_not_eq] = ACTIONS(6136),
    [anon_sym_DASH_DASH] = ACTIONS(6138),
    [anon_sym_PLUS_PLUS] = ACTIONS(6138),
    [anon_sym_DOT] = ACTIONS(6136),
    [anon_sym_DOT_STAR] = ACTIONS(6138),
    [anon_sym_DASH_GT] = ACTIONS(6138),
    [sym_comment] = ACTIONS(3),
  },
  [2644] = {
    [sym_identifier] = ACTIONS(5525),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5527),
    [anon_sym_COMMA] = ACTIONS(5527),
    [anon_sym_RPAREN] = ACTIONS(5527),
    [aux_sym_preproc_if_token2] = ACTIONS(5527),
    [aux_sym_preproc_else_token1] = ACTIONS(5527),
    [aux_sym_preproc_elif_token1] = ACTIONS(5525),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5527),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5527),
    [anon_sym_LPAREN2] = ACTIONS(5527),
    [anon_sym_DASH] = ACTIONS(5525),
    [anon_sym_PLUS] = ACTIONS(5525),
    [anon_sym_STAR] = ACTIONS(5525),
    [anon_sym_SLASH] = ACTIONS(5525),
    [anon_sym_PERCENT] = ACTIONS(5525),
    [anon_sym_PIPE_PIPE] = ACTIONS(5527),
    [anon_sym_AMP_AMP] = ACTIONS(5527),
    [anon_sym_PIPE] = ACTIONS(5525),
    [anon_sym_CARET] = ACTIONS(5525),
    [anon_sym_AMP] = ACTIONS(5525),
    [anon_sym_EQ_EQ] = ACTIONS(5527),
    [anon_sym_BANG_EQ] = ACTIONS(5527),
    [anon_sym_GT] = ACTIONS(5525),
    [anon_sym_GT_EQ] = ACTIONS(5527),
    [anon_sym_LT_EQ] = ACTIONS(5525),
    [anon_sym_LT] = ACTIONS(5525),
    [anon_sym_LT_LT] = ACTIONS(5525),
    [anon_sym_GT_GT] = ACTIONS(5525),
    [anon_sym_COLON] = ACTIONS(5527),
    [anon_sym_SEMI] = ACTIONS(5527),
    [anon_sym___attribute__] = ACTIONS(5525),
    [anon_sym_LBRACE] = ACTIONS(5527),
    [anon_sym_RBRACE] = ACTIONS(5527),
    [anon_sym_LBRACK] = ACTIONS(5527),
    [anon_sym_RBRACK] = ACTIONS(5527),
    [anon_sym_EQ] = ACTIONS(5525),
    [anon_sym_QMARK] = ACTIONS(5527),
    [anon_sym_STAR_EQ] = ACTIONS(5527),
    [anon_sym_SLASH_EQ] = ACTIONS(5527),
    [anon_sym_PERCENT_EQ] = ACTIONS(5527),
    [anon_sym_PLUS_EQ] = ACTIONS(5527),
    [anon_sym_DASH_EQ] = ACTIONS(5527),
    [anon_sym_LT_LT_EQ] = ACTIONS(5527),
    [anon_sym_GT_GT_EQ] = ACTIONS(5527),
    [anon_sym_AMP_EQ] = ACTIONS(5527),
    [anon_sym_CARET_EQ] = ACTIONS(5527),
    [anon_sym_PIPE_EQ] = ACTIONS(5527),
    [anon_sym_and_eq] = ACTIONS(5525),
    [anon_sym_or_eq] = ACTIONS(5525),
    [anon_sym_xor_eq] = ACTIONS(5525),
    [anon_sym_LT_EQ_GT] = ACTIONS(5527),
    [anon_sym_or] = ACTIONS(5525),
    [anon_sym_and] = ACTIONS(5525),
    [anon_sym_bitor] = ACTIONS(5525),
    [anon_sym_xor] = ACTIONS(5525),
    [anon_sym_bitand] = ACTIONS(5525),
    [anon_sym_not_eq] = ACTIONS(5525),
    [anon_sym_DASH_DASH] = ACTIONS(5527),
    [anon_sym_PLUS_PLUS] = ACTIONS(5527),
    [anon_sym_DOT] = ACTIONS(5525),
    [anon_sym_DOT_STAR] = ACTIONS(5527),
    [anon_sym_DASH_GT] = ACTIONS(5527),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5525),
    [anon_sym_decltype] = ACTIONS(5525),
  },
  [2645] = {
    [sym_template_argument_list] = STATE(2687),
    [sym_identifier] = ACTIONS(4050),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(4045),
    [anon_sym_COMMA] = ACTIONS(4045),
    [anon_sym_RPAREN] = ACTIONS(4045),
    [aux_sym_preproc_if_token2] = ACTIONS(4045),
    [aux_sym_preproc_else_token1] = ACTIONS(4045),
    [aux_sym_preproc_elif_token1] = ACTIONS(4050),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(4045),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(4045),
    [anon_sym_LPAREN2] = ACTIONS(4045),
    [anon_sym_DASH] = ACTIONS(4050),
    [anon_sym_PLUS] = ACTIONS(4050),
    [anon_sym_STAR] = ACTIONS(4050),
    [anon_sym_SLASH] = ACTIONS(4050),
    [anon_sym_PERCENT] = ACTIONS(4050),
    [anon_sym_PIPE_PIPE] = ACTIONS(4045),
    [anon_sym_AMP_AMP] = ACTIONS(4045),
    [anon_sym_PIPE] = ACTIONS(4050),
    [anon_sym_CARET] = ACTIONS(4050),
    [anon_sym_AMP] = ACTIONS(4050),
    [anon_sym_EQ_EQ] = ACTIONS(4045),
    [anon_sym_BANG_EQ] = ACTIONS(4045),
    [anon_sym_GT] = ACTIONS(4050),
    [anon_sym_GT_EQ] = ACTIONS(4045),
    [anon_sym_LT_EQ] = ACTIONS(4050),
    [anon_sym_LT] = ACTIONS(5844),
    [anon_sym_LT_LT] = ACTIONS(4050),
    [anon_sym_GT_GT] = ACTIONS(4050),
    [anon_sym_COLON] = ACTIONS(4050),
    [anon_sym_SEMI] = ACTIONS(4045),
    [anon_sym___attribute__] = ACTIONS(4050),
    [anon_sym_COLON_COLON] = ACTIONS(1939),
    [anon_sym_LBRACE] = ACTIONS(1935),
    [anon_sym_RBRACE] = ACTIONS(4045),
    [anon_sym_LBRACK] = ACTIONS(4045),
    [anon_sym_RBRACK] = ACTIONS(4045),
    [anon_sym_EQ] = ACTIONS(4050),
    [anon_sym_QMARK] = ACTIONS(4045),
    [anon_sym_STAR_EQ] = ACTIONS(4045),
    [anon_sym_SLASH_EQ] = ACTIONS(4045),
    [anon_sym_PERCENT_EQ] = ACTIONS(4045),
    [anon_sym_PLUS_EQ] = ACTIONS(4045),
    [anon_sym_DASH_EQ] = ACTIONS(4045),
    [anon_sym_LT_LT_EQ] = ACTIONS(4045),
    [anon_sym_GT_GT_EQ] = ACTIONS(4045),
    [anon_sym_AMP_EQ] = ACTIONS(4045),
    [anon_sym_CARET_EQ] = ACTIONS(4045),
    [anon_sym_PIPE_EQ] = ACTIONS(4045),
    [anon_sym_and_eq] = ACTIONS(4050),
    [anon_sym_or_eq] = ACTIONS(4050),
    [anon_sym_xor_eq] = ACTIONS(4050),
    [anon_sym_LT_EQ_GT] = ACTIONS(4045),
    [anon_sym_or] = ACTIONS(4050),
    [anon_sym_and] = ACTIONS(4050),
    [anon_sym_bitor] = ACTIONS(4050),
    [anon_sym_xor] = ACTIONS(4050),
    [anon_sym_bitand] = ACTIONS(4050),
    [anon_sym_not_eq] = ACTIONS(4050),
    [anon_sym_DASH_DASH] = ACTIONS(4045),
    [anon_sym_PLUS_PLUS] = ACTIONS(4045),
    [anon_sym_DOT] = ACTIONS(4050),
    [anon_sym_DOT_STAR] = ACTIONS(4045),
    [anon_sym_DASH_GT] = ACTIONS(4045),
    [sym_comment] = ACTIONS(3),
  },
  [2646] = {
    [sym_identifier] = ACTIONS(6140),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6142),
    [anon_sym_COMMA] = ACTIONS(6142),
    [anon_sym_RPAREN] = ACTIONS(6142),
    [aux_sym_preproc_if_token2] = ACTIONS(6142),
    [aux_sym_preproc_else_token1] = ACTIONS(6142),
    [aux_sym_preproc_elif_token1] = ACTIONS(6140),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6142),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6142),
    [anon_sym_LPAREN2] = ACTIONS(6142),
    [anon_sym_DASH] = ACTIONS(6140),
    [anon_sym_PLUS] = ACTIONS(6140),
    [anon_sym_STAR] = ACTIONS(6140),
    [anon_sym_SLASH] = ACTIONS(6140),
    [anon_sym_PERCENT] = ACTIONS(6140),
    [anon_sym_PIPE_PIPE] = ACTIONS(6142),
    [anon_sym_AMP_AMP] = ACTIONS(6142),
    [anon_sym_PIPE] = ACTIONS(6140),
    [anon_sym_CARET] = ACTIONS(6140),
    [anon_sym_AMP] = ACTIONS(6140),
    [anon_sym_EQ_EQ] = ACTIONS(6142),
    [anon_sym_BANG_EQ] = ACTIONS(6142),
    [anon_sym_GT] = ACTIONS(6140),
    [anon_sym_GT_EQ] = ACTIONS(6142),
    [anon_sym_LT_EQ] = ACTIONS(6140),
    [anon_sym_LT] = ACTIONS(6140),
    [anon_sym_LT_LT] = ACTIONS(6140),
    [anon_sym_GT_GT] = ACTIONS(6140),
    [anon_sym_COLON] = ACTIONS(6142),
    [anon_sym_SEMI] = ACTIONS(6142),
    [anon_sym___attribute__] = ACTIONS(6140),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6142),
    [anon_sym_LBRACE] = ACTIONS(6142),
    [anon_sym_RBRACE] = ACTIONS(6142),
    [anon_sym_LBRACK] = ACTIONS(6140),
    [anon_sym_RBRACK] = ACTIONS(6142),
    [anon_sym_EQ] = ACTIONS(6140),
    [anon_sym_QMARK] = ACTIONS(6142),
    [anon_sym_STAR_EQ] = ACTIONS(6142),
    [anon_sym_SLASH_EQ] = ACTIONS(6142),
    [anon_sym_PERCENT_EQ] = ACTIONS(6142),
    [anon_sym_PLUS_EQ] = ACTIONS(6142),
    [anon_sym_DASH_EQ] = ACTIONS(6142),
    [anon_sym_LT_LT_EQ] = ACTIONS(6142),
    [anon_sym_GT_GT_EQ] = ACTIONS(6142),
    [anon_sym_AMP_EQ] = ACTIONS(6142),
    [anon_sym_CARET_EQ] = ACTIONS(6142),
    [anon_sym_PIPE_EQ] = ACTIONS(6142),
    [anon_sym_and_eq] = ACTIONS(6140),
    [anon_sym_or_eq] = ACTIONS(6140),
    [anon_sym_xor_eq] = ACTIONS(6140),
    [anon_sym_LT_EQ_GT] = ACTIONS(6142),
    [anon_sym_or] = ACTIONS(6140),
    [anon_sym_and] = ACTIONS(6140),
    [anon_sym_bitor] = ACTIONS(6140),
    [anon_sym_xor] = ACTIONS(6140),
    [anon_sym_bitand] = ACTIONS(6140),
    [anon_sym_not_eq] = ACTIONS(6140),
    [anon_sym_DASH_DASH] = ACTIONS(6142),
    [anon_sym_PLUS_PLUS] = ACTIONS(6142),
    [anon_sym_DOT] = ACTIONS(6140),
    [anon_sym_DOT_STAR] = ACTIONS(6142),
    [anon_sym_DASH_GT] = ACTIONS(6142),
    [sym_comment] = ACTIONS(3),
    [anon_sym_try] = ACTIONS(6140),
  },
  [2647] = {
    [sym_identifier] = ACTIONS(6144),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6146),
    [anon_sym_COMMA] = ACTIONS(6146),
    [anon_sym_RPAREN] = ACTIONS(6146),
    [aux_sym_preproc_if_token2] = ACTIONS(6146),
    [aux_sym_preproc_else_token1] = ACTIONS(6146),
    [aux_sym_preproc_elif_token1] = ACTIONS(6144),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6146),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6146),
    [anon_sym_LPAREN2] = ACTIONS(6146),
    [anon_sym_DASH] = ACTIONS(6144),
    [anon_sym_PLUS] = ACTIONS(6144),
    [anon_sym_STAR] = ACTIONS(6144),
    [anon_sym_SLASH] = ACTIONS(6144),
    [anon_sym_PERCENT] = ACTIONS(6144),
    [anon_sym_PIPE_PIPE] = ACTIONS(6146),
    [anon_sym_AMP_AMP] = ACTIONS(6146),
    [anon_sym_PIPE] = ACTIONS(6144),
    [anon_sym_CARET] = ACTIONS(6144),
    [anon_sym_AMP] = ACTIONS(6144),
    [anon_sym_EQ_EQ] = ACTIONS(6146),
    [anon_sym_BANG_EQ] = ACTIONS(6146),
    [anon_sym_GT] = ACTIONS(6144),
    [anon_sym_GT_EQ] = ACTIONS(6146),
    [anon_sym_LT_EQ] = ACTIONS(6144),
    [anon_sym_LT] = ACTIONS(6144),
    [anon_sym_LT_LT] = ACTIONS(6144),
    [anon_sym_GT_GT] = ACTIONS(6144),
    [anon_sym_COLON] = ACTIONS(6146),
    [anon_sym_SEMI] = ACTIONS(6146),
    [anon_sym___attribute__] = ACTIONS(6144),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6146),
    [anon_sym_LBRACE] = ACTIONS(6146),
    [anon_sym_RBRACE] = ACTIONS(6146),
    [anon_sym_LBRACK] = ACTIONS(6144),
    [anon_sym_RBRACK] = ACTIONS(6146),
    [anon_sym_EQ] = ACTIONS(6144),
    [anon_sym_QMARK] = ACTIONS(6146),
    [anon_sym_STAR_EQ] = ACTIONS(6146),
    [anon_sym_SLASH_EQ] = ACTIONS(6146),
    [anon_sym_PERCENT_EQ] = ACTIONS(6146),
    [anon_sym_PLUS_EQ] = ACTIONS(6146),
    [anon_sym_DASH_EQ] = ACTIONS(6146),
    [anon_sym_LT_LT_EQ] = ACTIONS(6146),
    [anon_sym_GT_GT_EQ] = ACTIONS(6146),
    [anon_sym_AMP_EQ] = ACTIONS(6146),
    [anon_sym_CARET_EQ] = ACTIONS(6146),
    [anon_sym_PIPE_EQ] = ACTIONS(6146),
    [anon_sym_and_eq] = ACTIONS(6144),
    [anon_sym_or_eq] = ACTIONS(6144),
    [anon_sym_xor_eq] = ACTIONS(6144),
    [anon_sym_LT_EQ_GT] = ACTIONS(6146),
    [anon_sym_or] = ACTIONS(6144),
    [anon_sym_and] = ACTIONS(6144),
    [anon_sym_bitor] = ACTIONS(6144),
    [anon_sym_xor] = ACTIONS(6144),
    [anon_sym_bitand] = ACTIONS(6144),
    [anon_sym_not_eq] = ACTIONS(6144),
    [anon_sym_DASH_DASH] = ACTIONS(6146),
    [anon_sym_PLUS_PLUS] = ACTIONS(6146),
    [anon_sym_DOT] = ACTIONS(6144),
    [anon_sym_DOT_STAR] = ACTIONS(6146),
    [anon_sym_DASH_GT] = ACTIONS(6146),
    [sym_comment] = ACTIONS(3),
    [anon_sym_try] = ACTIONS(6144),
  },
  [2648] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2631),
    [sym_identifier] = ACTIONS(5381),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5383),
    [anon_sym_COMMA] = ACTIONS(5383),
    [aux_sym_preproc_if_token2] = ACTIONS(5383),
    [aux_sym_preproc_else_token1] = ACTIONS(5383),
    [aux_sym_preproc_elif_token1] = ACTIONS(5381),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5383),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5383),
    [anon_sym_LPAREN2] = ACTIONS(5383),
    [anon_sym_DASH] = ACTIONS(5381),
    [anon_sym_PLUS] = ACTIONS(5381),
    [anon_sym_STAR] = ACTIONS(5381),
    [anon_sym_SLASH] = ACTIONS(5381),
    [anon_sym_PERCENT] = ACTIONS(5381),
    [anon_sym_PIPE_PIPE] = ACTIONS(5383),
    [anon_sym_AMP_AMP] = ACTIONS(5383),
    [anon_sym_PIPE] = ACTIONS(5381),
    [anon_sym_CARET] = ACTIONS(5381),
    [anon_sym_AMP] = ACTIONS(5381),
    [anon_sym_EQ_EQ] = ACTIONS(5383),
    [anon_sym_BANG_EQ] = ACTIONS(5383),
    [anon_sym_GT] = ACTIONS(5381),
    [anon_sym_GT_EQ] = ACTIONS(5383),
    [anon_sym_LT_EQ] = ACTIONS(5381),
    [anon_sym_LT] = ACTIONS(5381),
    [anon_sym_LT_LT] = ACTIONS(5381),
    [anon_sym_GT_GT] = ACTIONS(5381),
    [anon_sym___attribute__] = ACTIONS(5381),
    [anon_sym_LBRACE] = ACTIONS(5383),
    [anon_sym_signed] = ACTIONS(6148),
    [anon_sym_unsigned] = ACTIONS(6148),
    [anon_sym_long] = ACTIONS(6148),
    [anon_sym_short] = ACTIONS(6148),
    [anon_sym_LBRACK] = ACTIONS(5383),
    [anon_sym_EQ] = ACTIONS(5381),
    [anon_sym_QMARK] = ACTIONS(5383),
    [anon_sym_STAR_EQ] = ACTIONS(5383),
    [anon_sym_SLASH_EQ] = ACTIONS(5383),
    [anon_sym_PERCENT_EQ] = ACTIONS(5383),
    [anon_sym_PLUS_EQ] = ACTIONS(5383),
    [anon_sym_DASH_EQ] = ACTIONS(5383),
    [anon_sym_LT_LT_EQ] = ACTIONS(5383),
    [anon_sym_GT_GT_EQ] = ACTIONS(5383),
    [anon_sym_AMP_EQ] = ACTIONS(5383),
    [anon_sym_CARET_EQ] = ACTIONS(5383),
    [anon_sym_PIPE_EQ] = ACTIONS(5383),
    [anon_sym_and_eq] = ACTIONS(5381),
    [anon_sym_or_eq] = ACTIONS(5381),
    [anon_sym_xor_eq] = ACTIONS(5381),
    [anon_sym_LT_EQ_GT] = ACTIONS(5383),
    [anon_sym_or] = ACTIONS(5381),
    [anon_sym_and] = ACTIONS(5381),
    [anon_sym_bitor] = ACTIONS(5381),
    [anon_sym_xor] = ACTIONS(5381),
    [anon_sym_bitand] = ACTIONS(5381),
    [anon_sym_not_eq] = ACTIONS(5381),
    [anon_sym_DASH_DASH] = ACTIONS(5383),
    [anon_sym_PLUS_PLUS] = ACTIONS(5383),
    [anon_sym_DOT] = ACTIONS(5381),
    [anon_sym_DOT_STAR] = ACTIONS(5383),
    [anon_sym_DASH_GT] = ACTIONS(5383),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5381),
    [anon_sym_decltype] = ACTIONS(5381),
  },
  [2649] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2640),
    [sym_identifier] = ACTIONS(5347),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5349),
    [anon_sym_COMMA] = ACTIONS(5349),
    [aux_sym_preproc_if_token2] = ACTIONS(5349),
    [aux_sym_preproc_else_token1] = ACTIONS(5349),
    [aux_sym_preproc_elif_token1] = ACTIONS(5347),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5349),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5349),
    [anon_sym_LPAREN2] = ACTIONS(5349),
    [anon_sym_DASH] = ACTIONS(5347),
    [anon_sym_PLUS] = ACTIONS(5347),
    [anon_sym_STAR] = ACTIONS(5347),
    [anon_sym_SLASH] = ACTIONS(5347),
    [anon_sym_PERCENT] = ACTIONS(5347),
    [anon_sym_PIPE_PIPE] = ACTIONS(5349),
    [anon_sym_AMP_AMP] = ACTIONS(5349),
    [anon_sym_PIPE] = ACTIONS(5347),
    [anon_sym_CARET] = ACTIONS(5347),
    [anon_sym_AMP] = ACTIONS(5347),
    [anon_sym_EQ_EQ] = ACTIONS(5349),
    [anon_sym_BANG_EQ] = ACTIONS(5349),
    [anon_sym_GT] = ACTIONS(5347),
    [anon_sym_GT_EQ] = ACTIONS(5349),
    [anon_sym_LT_EQ] = ACTIONS(5347),
    [anon_sym_LT] = ACTIONS(5347),
    [anon_sym_LT_LT] = ACTIONS(5347),
    [anon_sym_GT_GT] = ACTIONS(5347),
    [anon_sym___attribute__] = ACTIONS(5347),
    [anon_sym_LBRACE] = ACTIONS(5349),
    [anon_sym_signed] = ACTIONS(6115),
    [anon_sym_unsigned] = ACTIONS(6115),
    [anon_sym_long] = ACTIONS(6115),
    [anon_sym_short] = ACTIONS(6115),
    [anon_sym_LBRACK] = ACTIONS(5349),
    [anon_sym_EQ] = ACTIONS(5347),
    [anon_sym_QMARK] = ACTIONS(5349),
    [anon_sym_STAR_EQ] = ACTIONS(5349),
    [anon_sym_SLASH_EQ] = ACTIONS(5349),
    [anon_sym_PERCENT_EQ] = ACTIONS(5349),
    [anon_sym_PLUS_EQ] = ACTIONS(5349),
    [anon_sym_DASH_EQ] = ACTIONS(5349),
    [anon_sym_LT_LT_EQ] = ACTIONS(5349),
    [anon_sym_GT_GT_EQ] = ACTIONS(5349),
    [anon_sym_AMP_EQ] = ACTIONS(5349),
    [anon_sym_CARET_EQ] = ACTIONS(5349),
    [anon_sym_PIPE_EQ] = ACTIONS(5349),
    [anon_sym_and_eq] = ACTIONS(5347),
    [anon_sym_or_eq] = ACTIONS(5347),
    [anon_sym_xor_eq] = ACTIONS(5347),
    [anon_sym_LT_EQ_GT] = ACTIONS(5349),
    [anon_sym_or] = ACTIONS(5347),
    [anon_sym_and] = ACTIONS(5347),
    [anon_sym_bitor] = ACTIONS(5347),
    [anon_sym_xor] = ACTIONS(5347),
    [anon_sym_bitand] = ACTIONS(5347),
    [anon_sym_not_eq] = ACTIONS(5347),
    [anon_sym_DASH_DASH] = ACTIONS(5349),
    [anon_sym_PLUS_PLUS] = ACTIONS(5349),
    [anon_sym_DOT] = ACTIONS(5347),
    [anon_sym_DOT_STAR] = ACTIONS(5349),
    [anon_sym_DASH_GT] = ACTIONS(5349),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5347),
    [anon_sym_decltype] = ACTIONS(5347),
  },
  [2650] = {
    [sym_identifier] = ACTIONS(5515),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5517),
    [anon_sym_COMMA] = ACTIONS(5517),
    [anon_sym_RPAREN] = ACTIONS(5517),
    [aux_sym_preproc_if_token2] = ACTIONS(5517),
    [aux_sym_preproc_else_token1] = ACTIONS(5517),
    [aux_sym_preproc_elif_token1] = ACTIONS(5515),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5517),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5517),
    [anon_sym_LPAREN2] = ACTIONS(5517),
    [anon_sym_DASH] = ACTIONS(5515),
    [anon_sym_PLUS] = ACTIONS(5515),
    [anon_sym_STAR] = ACTIONS(5515),
    [anon_sym_SLASH] = ACTIONS(5515),
    [anon_sym_PERCENT] = ACTIONS(5515),
    [anon_sym_PIPE_PIPE] = ACTIONS(5517),
    [anon_sym_AMP_AMP] = ACTIONS(5517),
    [anon_sym_PIPE] = ACTIONS(5515),
    [anon_sym_CARET] = ACTIONS(5515),
    [anon_sym_AMP] = ACTIONS(5515),
    [anon_sym_EQ_EQ] = ACTIONS(5517),
    [anon_sym_BANG_EQ] = ACTIONS(5517),
    [anon_sym_GT] = ACTIONS(5515),
    [anon_sym_GT_EQ] = ACTIONS(5517),
    [anon_sym_LT_EQ] = ACTIONS(5515),
    [anon_sym_LT] = ACTIONS(5515),
    [anon_sym_LT_LT] = ACTIONS(5515),
    [anon_sym_GT_GT] = ACTIONS(5515),
    [anon_sym_COLON] = ACTIONS(5517),
    [anon_sym_SEMI] = ACTIONS(5517),
    [anon_sym___attribute__] = ACTIONS(5515),
    [anon_sym_LBRACE] = ACTIONS(5517),
    [anon_sym_RBRACE] = ACTIONS(5517),
    [anon_sym_LBRACK] = ACTIONS(5517),
    [anon_sym_RBRACK] = ACTIONS(5517),
    [anon_sym_EQ] = ACTIONS(5515),
    [anon_sym_QMARK] = ACTIONS(5517),
    [anon_sym_STAR_EQ] = ACTIONS(5517),
    [anon_sym_SLASH_EQ] = ACTIONS(5517),
    [anon_sym_PERCENT_EQ] = ACTIONS(5517),
    [anon_sym_PLUS_EQ] = ACTIONS(5517),
    [anon_sym_DASH_EQ] = ACTIONS(5517),
    [anon_sym_LT_LT_EQ] = ACTIONS(5517),
    [anon_sym_GT_GT_EQ] = ACTIONS(5517),
    [anon_sym_AMP_EQ] = ACTIONS(5517),
    [anon_sym_CARET_EQ] = ACTIONS(5517),
    [anon_sym_PIPE_EQ] = ACTIONS(5517),
    [anon_sym_and_eq] = ACTIONS(5515),
    [anon_sym_or_eq] = ACTIONS(5515),
    [anon_sym_xor_eq] = ACTIONS(5515),
    [anon_sym_LT_EQ_GT] = ACTIONS(5517),
    [anon_sym_or] = ACTIONS(5515),
    [anon_sym_and] = ACTIONS(5515),
    [anon_sym_bitor] = ACTIONS(5515),
    [anon_sym_xor] = ACTIONS(5515),
    [anon_sym_bitand] = ACTIONS(5515),
    [anon_sym_not_eq] = ACTIONS(5515),
    [anon_sym_DASH_DASH] = ACTIONS(5517),
    [anon_sym_PLUS_PLUS] = ACTIONS(5517),
    [anon_sym_DOT] = ACTIONS(5515),
    [anon_sym_DOT_STAR] = ACTIONS(5517),
    [anon_sym_DASH_GT] = ACTIONS(5517),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5515),
    [anon_sym_decltype] = ACTIONS(5515),
  },
  [2651] = {
    [sym_identifier] = ACTIONS(5455),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5457),
    [anon_sym_COMMA] = ACTIONS(5457),
    [anon_sym_RPAREN] = ACTIONS(5457),
    [aux_sym_preproc_if_token2] = ACTIONS(5457),
    [aux_sym_preproc_else_token1] = ACTIONS(5457),
    [aux_sym_preproc_elif_token1] = ACTIONS(5455),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5457),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5457),
    [anon_sym_LPAREN2] = ACTIONS(5457),
    [anon_sym_DASH] = ACTIONS(5455),
    [anon_sym_PLUS] = ACTIONS(5455),
    [anon_sym_STAR] = ACTIONS(5455),
    [anon_sym_SLASH] = ACTIONS(5455),
    [anon_sym_PERCENT] = ACTIONS(5455),
    [anon_sym_PIPE_PIPE] = ACTIONS(5457),
    [anon_sym_AMP_AMP] = ACTIONS(5457),
    [anon_sym_PIPE] = ACTIONS(5455),
    [anon_sym_CARET] = ACTIONS(5455),
    [anon_sym_AMP] = ACTIONS(5455),
    [anon_sym_EQ_EQ] = ACTIONS(5457),
    [anon_sym_BANG_EQ] = ACTIONS(5457),
    [anon_sym_GT] = ACTIONS(5455),
    [anon_sym_GT_EQ] = ACTIONS(5457),
    [anon_sym_LT_EQ] = ACTIONS(5455),
    [anon_sym_LT] = ACTIONS(5455),
    [anon_sym_LT_LT] = ACTIONS(5455),
    [anon_sym_GT_GT] = ACTIONS(5455),
    [anon_sym_COLON] = ACTIONS(5457),
    [anon_sym_SEMI] = ACTIONS(5457),
    [anon_sym___attribute__] = ACTIONS(5455),
    [anon_sym_LBRACE] = ACTIONS(5457),
    [anon_sym_RBRACE] = ACTIONS(5457),
    [anon_sym_LBRACK] = ACTIONS(5457),
    [anon_sym_RBRACK] = ACTIONS(5457),
    [anon_sym_EQ] = ACTIONS(5455),
    [anon_sym_QMARK] = ACTIONS(5457),
    [anon_sym_STAR_EQ] = ACTIONS(5457),
    [anon_sym_SLASH_EQ] = ACTIONS(5457),
    [anon_sym_PERCENT_EQ] = ACTIONS(5457),
    [anon_sym_PLUS_EQ] = ACTIONS(5457),
    [anon_sym_DASH_EQ] = ACTIONS(5457),
    [anon_sym_LT_LT_EQ] = ACTIONS(5457),
    [anon_sym_GT_GT_EQ] = ACTIONS(5457),
    [anon_sym_AMP_EQ] = ACTIONS(5457),
    [anon_sym_CARET_EQ] = ACTIONS(5457),
    [anon_sym_PIPE_EQ] = ACTIONS(5457),
    [anon_sym_and_eq] = ACTIONS(5455),
    [anon_sym_or_eq] = ACTIONS(5455),
    [anon_sym_xor_eq] = ACTIONS(5455),
    [anon_sym_LT_EQ_GT] = ACTIONS(5457),
    [anon_sym_or] = ACTIONS(5455),
    [anon_sym_and] = ACTIONS(5455),
    [anon_sym_bitor] = ACTIONS(5455),
    [anon_sym_xor] = ACTIONS(5455),
    [anon_sym_bitand] = ACTIONS(5455),
    [anon_sym_not_eq] = ACTIONS(5455),
    [anon_sym_DASH_DASH] = ACTIONS(5457),
    [anon_sym_PLUS_PLUS] = ACTIONS(5457),
    [anon_sym_DOT] = ACTIONS(5455),
    [anon_sym_DOT_STAR] = ACTIONS(5457),
    [anon_sym_DASH_GT] = ACTIONS(5457),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5455),
    [anon_sym_decltype] = ACTIONS(5455),
  },
  [2652] = {
    [sym_identifier] = ACTIONS(6150),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6152),
    [anon_sym_COMMA] = ACTIONS(6152),
    [anon_sym_RPAREN] = ACTIONS(6152),
    [aux_sym_preproc_if_token2] = ACTIONS(6152),
    [aux_sym_preproc_else_token1] = ACTIONS(6152),
    [aux_sym_preproc_elif_token1] = ACTIONS(6150),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6152),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6152),
    [anon_sym_LPAREN2] = ACTIONS(6152),
    [anon_sym_DASH] = ACTIONS(6150),
    [anon_sym_PLUS] = ACTIONS(6150),
    [anon_sym_STAR] = ACTIONS(6150),
    [anon_sym_SLASH] = ACTIONS(6150),
    [anon_sym_PERCENT] = ACTIONS(6150),
    [anon_sym_PIPE_PIPE] = ACTIONS(6152),
    [anon_sym_AMP_AMP] = ACTIONS(6152),
    [anon_sym_PIPE] = ACTIONS(6150),
    [anon_sym_CARET] = ACTIONS(6150),
    [anon_sym_AMP] = ACTIONS(6150),
    [anon_sym_EQ_EQ] = ACTIONS(6152),
    [anon_sym_BANG_EQ] = ACTIONS(6152),
    [anon_sym_GT] = ACTIONS(6150),
    [anon_sym_GT_EQ] = ACTIONS(6152),
    [anon_sym_LT_EQ] = ACTIONS(6150),
    [anon_sym_LT] = ACTIONS(6150),
    [anon_sym_LT_LT] = ACTIONS(6150),
    [anon_sym_GT_GT] = ACTIONS(6150),
    [anon_sym_COLON] = ACTIONS(6152),
    [anon_sym_SEMI] = ACTIONS(6152),
    [anon_sym___attribute__] = ACTIONS(6150),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6152),
    [anon_sym_LBRACE] = ACTIONS(6152),
    [anon_sym_RBRACE] = ACTIONS(6152),
    [anon_sym_LBRACK] = ACTIONS(6150),
    [anon_sym_RBRACK] = ACTIONS(6152),
    [anon_sym_EQ] = ACTIONS(6150),
    [anon_sym_QMARK] = ACTIONS(6152),
    [anon_sym_STAR_EQ] = ACTIONS(6152),
    [anon_sym_SLASH_EQ] = ACTIONS(6152),
    [anon_sym_PERCENT_EQ] = ACTIONS(6152),
    [anon_sym_PLUS_EQ] = ACTIONS(6152),
    [anon_sym_DASH_EQ] = ACTIONS(6152),
    [anon_sym_LT_LT_EQ] = ACTIONS(6152),
    [anon_sym_GT_GT_EQ] = ACTIONS(6152),
    [anon_sym_AMP_EQ] = ACTIONS(6152),
    [anon_sym_CARET_EQ] = ACTIONS(6152),
    [anon_sym_PIPE_EQ] = ACTIONS(6152),
    [anon_sym_and_eq] = ACTIONS(6150),
    [anon_sym_or_eq] = ACTIONS(6150),
    [anon_sym_xor_eq] = ACTIONS(6150),
    [anon_sym_LT_EQ_GT] = ACTIONS(6152),
    [anon_sym_or] = ACTIONS(6150),
    [anon_sym_and] = ACTIONS(6150),
    [anon_sym_bitor] = ACTIONS(6150),
    [anon_sym_xor] = ACTIONS(6150),
    [anon_sym_bitand] = ACTIONS(6150),
    [anon_sym_not_eq] = ACTIONS(6150),
    [anon_sym_DASH_DASH] = ACTIONS(6152),
    [anon_sym_PLUS_PLUS] = ACTIONS(6152),
    [anon_sym_DOT] = ACTIONS(6150),
    [anon_sym_DOT_STAR] = ACTIONS(6152),
    [anon_sym_DASH_GT] = ACTIONS(6152),
    [sym_comment] = ACTIONS(3),
    [anon_sym_try] = ACTIONS(6150),
  },
  [2653] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2640),
    [sym_identifier] = ACTIONS(5373),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5375),
    [anon_sym_COMMA] = ACTIONS(5375),
    [aux_sym_preproc_if_token2] = ACTIONS(5375),
    [aux_sym_preproc_else_token1] = ACTIONS(5375),
    [aux_sym_preproc_elif_token1] = ACTIONS(5373),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5375),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5375),
    [anon_sym_LPAREN2] = ACTIONS(5375),
    [anon_sym_DASH] = ACTIONS(5373),
    [anon_sym_PLUS] = ACTIONS(5373),
    [anon_sym_STAR] = ACTIONS(5373),
    [anon_sym_SLASH] = ACTIONS(5373),
    [anon_sym_PERCENT] = ACTIONS(5373),
    [anon_sym_PIPE_PIPE] = ACTIONS(5375),
    [anon_sym_AMP_AMP] = ACTIONS(5375),
    [anon_sym_PIPE] = ACTIONS(5373),
    [anon_sym_CARET] = ACTIONS(5373),
    [anon_sym_AMP] = ACTIONS(5373),
    [anon_sym_EQ_EQ] = ACTIONS(5375),
    [anon_sym_BANG_EQ] = ACTIONS(5375),
    [anon_sym_GT] = ACTIONS(5373),
    [anon_sym_GT_EQ] = ACTIONS(5375),
    [anon_sym_LT_EQ] = ACTIONS(5373),
    [anon_sym_LT] = ACTIONS(5373),
    [anon_sym_LT_LT] = ACTIONS(5373),
    [anon_sym_GT_GT] = ACTIONS(5373),
    [anon_sym___attribute__] = ACTIONS(5373),
    [anon_sym_LBRACE] = ACTIONS(5375),
    [anon_sym_signed] = ACTIONS(6115),
    [anon_sym_unsigned] = ACTIONS(6115),
    [anon_sym_long] = ACTIONS(6115),
    [anon_sym_short] = ACTIONS(6115),
    [anon_sym_LBRACK] = ACTIONS(5375),
    [anon_sym_EQ] = ACTIONS(5373),
    [anon_sym_QMARK] = ACTIONS(5375),
    [anon_sym_STAR_EQ] = ACTIONS(5375),
    [anon_sym_SLASH_EQ] = ACTIONS(5375),
    [anon_sym_PERCENT_EQ] = ACTIONS(5375),
    [anon_sym_PLUS_EQ] = ACTIONS(5375),
    [anon_sym_DASH_EQ] = ACTIONS(5375),
    [anon_sym_LT_LT_EQ] = ACTIONS(5375),
    [anon_sym_GT_GT_EQ] = ACTIONS(5375),
    [anon_sym_AMP_EQ] = ACTIONS(5375),
    [anon_sym_CARET_EQ] = ACTIONS(5375),
    [anon_sym_PIPE_EQ] = ACTIONS(5375),
    [anon_sym_and_eq] = ACTIONS(5373),
    [anon_sym_or_eq] = ACTIONS(5373),
    [anon_sym_xor_eq] = ACTIONS(5373),
    [anon_sym_LT_EQ_GT] = ACTIONS(5375),
    [anon_sym_or] = ACTIONS(5373),
    [anon_sym_and] = ACTIONS(5373),
    [anon_sym_bitor] = ACTIONS(5373),
    [anon_sym_xor] = ACTIONS(5373),
    [anon_sym_bitand] = ACTIONS(5373),
    [anon_sym_not_eq] = ACTIONS(5373),
    [anon_sym_DASH_DASH] = ACTIONS(5375),
    [anon_sym_PLUS_PLUS] = ACTIONS(5375),
    [anon_sym_DOT] = ACTIONS(5373),
    [anon_sym_DOT_STAR] = ACTIONS(5375),
    [anon_sym_DASH_GT] = ACTIONS(5375),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5373),
    [anon_sym_decltype] = ACTIONS(5373),
  },
  [2654] = {
    [sym_identifier] = ACTIONS(5471),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5473),
    [anon_sym_COMMA] = ACTIONS(5473),
    [anon_sym_RPAREN] = ACTIONS(5473),
    [aux_sym_preproc_if_token2] = ACTIONS(5473),
    [aux_sym_preproc_else_token1] = ACTIONS(5473),
    [aux_sym_preproc_elif_token1] = ACTIONS(5471),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5473),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5473),
    [anon_sym_LPAREN2] = ACTIONS(5473),
    [anon_sym_DASH] = ACTIONS(5471),
    [anon_sym_PLUS] = ACTIONS(5471),
    [anon_sym_STAR] = ACTIONS(5471),
    [anon_sym_SLASH] = ACTIONS(5471),
    [anon_sym_PERCENT] = ACTIONS(5471),
    [anon_sym_PIPE_PIPE] = ACTIONS(5473),
    [anon_sym_AMP_AMP] = ACTIONS(5473),
    [anon_sym_PIPE] = ACTIONS(5471),
    [anon_sym_CARET] = ACTIONS(5471),
    [anon_sym_AMP] = ACTIONS(5471),
    [anon_sym_EQ_EQ] = ACTIONS(5473),
    [anon_sym_BANG_EQ] = ACTIONS(5473),
    [anon_sym_GT] = ACTIONS(5471),
    [anon_sym_GT_EQ] = ACTIONS(5473),
    [anon_sym_LT_EQ] = ACTIONS(5471),
    [anon_sym_LT] = ACTIONS(5471),
    [anon_sym_LT_LT] = ACTIONS(5471),
    [anon_sym_GT_GT] = ACTIONS(5471),
    [anon_sym_COLON] = ACTIONS(5473),
    [anon_sym_SEMI] = ACTIONS(5473),
    [anon_sym___attribute__] = ACTIONS(5471),
    [anon_sym_LBRACE] = ACTIONS(5473),
    [anon_sym_RBRACE] = ACTIONS(5473),
    [anon_sym_LBRACK] = ACTIONS(5473),
    [anon_sym_RBRACK] = ACTIONS(5473),
    [anon_sym_EQ] = ACTIONS(5471),
    [anon_sym_QMARK] = ACTIONS(5473),
    [anon_sym_STAR_EQ] = ACTIONS(5473),
    [anon_sym_SLASH_EQ] = ACTIONS(5473),
    [anon_sym_PERCENT_EQ] = ACTIONS(5473),
    [anon_sym_PLUS_EQ] = ACTIONS(5473),
    [anon_sym_DASH_EQ] = ACTIONS(5473),
    [anon_sym_LT_LT_EQ] = ACTIONS(5473),
    [anon_sym_GT_GT_EQ] = ACTIONS(5473),
    [anon_sym_AMP_EQ] = ACTIONS(5473),
    [anon_sym_CARET_EQ] = ACTIONS(5473),
    [anon_sym_PIPE_EQ] = ACTIONS(5473),
    [anon_sym_and_eq] = ACTIONS(5471),
    [anon_sym_or_eq] = ACTIONS(5471),
    [anon_sym_xor_eq] = ACTIONS(5471),
    [anon_sym_LT_EQ_GT] = ACTIONS(5473),
    [anon_sym_or] = ACTIONS(5471),
    [anon_sym_and] = ACTIONS(5471),
    [anon_sym_bitor] = ACTIONS(5471),
    [anon_sym_xor] = ACTIONS(5471),
    [anon_sym_bitand] = ACTIONS(5471),
    [anon_sym_not_eq] = ACTIONS(5471),
    [anon_sym_DASH_DASH] = ACTIONS(5473),
    [anon_sym_PLUS_PLUS] = ACTIONS(5473),
    [anon_sym_DOT] = ACTIONS(5471),
    [anon_sym_DOT_STAR] = ACTIONS(5473),
    [anon_sym_DASH_GT] = ACTIONS(5473),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5471),
    [anon_sym_decltype] = ACTIONS(5471),
  },
  [2655] = {
    [sym_identifier] = ACTIONS(5318),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5320),
    [anon_sym_COMMA] = ACTIONS(5320),
    [anon_sym_RPAREN] = ACTIONS(5320),
    [aux_sym_preproc_if_token2] = ACTIONS(5320),
    [aux_sym_preproc_else_token1] = ACTIONS(5320),
    [aux_sym_preproc_elif_token1] = ACTIONS(5318),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5320),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5320),
    [anon_sym_LPAREN2] = ACTIONS(5320),
    [anon_sym_DASH] = ACTIONS(5318),
    [anon_sym_PLUS] = ACTIONS(5318),
    [anon_sym_STAR] = ACTIONS(5318),
    [anon_sym_SLASH] = ACTIONS(5318),
    [anon_sym_PERCENT] = ACTIONS(5318),
    [anon_sym_PIPE_PIPE] = ACTIONS(5320),
    [anon_sym_AMP_AMP] = ACTIONS(5320),
    [anon_sym_PIPE] = ACTIONS(5318),
    [anon_sym_CARET] = ACTIONS(5318),
    [anon_sym_AMP] = ACTIONS(5318),
    [anon_sym_EQ_EQ] = ACTIONS(5320),
    [anon_sym_BANG_EQ] = ACTIONS(5320),
    [anon_sym_GT] = ACTIONS(5318),
    [anon_sym_GT_EQ] = ACTIONS(5320),
    [anon_sym_LT_EQ] = ACTIONS(5318),
    [anon_sym_LT] = ACTIONS(5318),
    [anon_sym_LT_LT] = ACTIONS(5318),
    [anon_sym_GT_GT] = ACTIONS(5318),
    [anon_sym_COLON] = ACTIONS(5320),
    [anon_sym_SEMI] = ACTIONS(5320),
    [anon_sym___attribute__] = ACTIONS(5318),
    [anon_sym_LBRACE] = ACTIONS(5320),
    [anon_sym_RBRACE] = ACTIONS(5320),
    [anon_sym_LBRACK] = ACTIONS(5320),
    [anon_sym_RBRACK] = ACTIONS(5320),
    [anon_sym_EQ] = ACTIONS(5318),
    [anon_sym_QMARK] = ACTIONS(5320),
    [anon_sym_STAR_EQ] = ACTIONS(5320),
    [anon_sym_SLASH_EQ] = ACTIONS(5320),
    [anon_sym_PERCENT_EQ] = ACTIONS(5320),
    [anon_sym_PLUS_EQ] = ACTIONS(5320),
    [anon_sym_DASH_EQ] = ACTIONS(5320),
    [anon_sym_LT_LT_EQ] = ACTIONS(5320),
    [anon_sym_GT_GT_EQ] = ACTIONS(5320),
    [anon_sym_AMP_EQ] = ACTIONS(5320),
    [anon_sym_CARET_EQ] = ACTIONS(5320),
    [anon_sym_PIPE_EQ] = ACTIONS(5320),
    [anon_sym_and_eq] = ACTIONS(5318),
    [anon_sym_or_eq] = ACTIONS(5318),
    [anon_sym_xor_eq] = ACTIONS(5318),
    [anon_sym_LT_EQ_GT] = ACTIONS(5320),
    [anon_sym_or] = ACTIONS(5318),
    [anon_sym_and] = ACTIONS(5318),
    [anon_sym_bitor] = ACTIONS(5318),
    [anon_sym_xor] = ACTIONS(5318),
    [anon_sym_bitand] = ACTIONS(5318),
    [anon_sym_not_eq] = ACTIONS(5318),
    [anon_sym_DASH_DASH] = ACTIONS(5320),
    [anon_sym_PLUS_PLUS] = ACTIONS(5320),
    [anon_sym_DOT] = ACTIONS(5318),
    [anon_sym_DOT_STAR] = ACTIONS(5320),
    [anon_sym_DASH_GT] = ACTIONS(5320),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5318),
    [anon_sym_decltype] = ACTIONS(5318),
  },
  [2656] = {
    [sym_identifier] = ACTIONS(5459),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5461),
    [anon_sym_COMMA] = ACTIONS(5461),
    [anon_sym_RPAREN] = ACTIONS(5461),
    [aux_sym_preproc_if_token2] = ACTIONS(5461),
    [aux_sym_preproc_else_token1] = ACTIONS(5461),
    [aux_sym_preproc_elif_token1] = ACTIONS(5459),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5461),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5461),
    [anon_sym_LPAREN2] = ACTIONS(5461),
    [anon_sym_DASH] = ACTIONS(5459),
    [anon_sym_PLUS] = ACTIONS(5459),
    [anon_sym_STAR] = ACTIONS(5459),
    [anon_sym_SLASH] = ACTIONS(5459),
    [anon_sym_PERCENT] = ACTIONS(5459),
    [anon_sym_PIPE_PIPE] = ACTIONS(5461),
    [anon_sym_AMP_AMP] = ACTIONS(5461),
    [anon_sym_PIPE] = ACTIONS(5459),
    [anon_sym_CARET] = ACTIONS(5459),
    [anon_sym_AMP] = ACTIONS(5459),
    [anon_sym_EQ_EQ] = ACTIONS(5461),
    [anon_sym_BANG_EQ] = ACTIONS(5461),
    [anon_sym_GT] = ACTIONS(5459),
    [anon_sym_GT_EQ] = ACTIONS(5461),
    [anon_sym_LT_EQ] = ACTIONS(5459),
    [anon_sym_LT] = ACTIONS(5459),
    [anon_sym_LT_LT] = ACTIONS(5459),
    [anon_sym_GT_GT] = ACTIONS(5459),
    [anon_sym_COLON] = ACTIONS(5461),
    [anon_sym_SEMI] = ACTIONS(5461),
    [anon_sym___attribute__] = ACTIONS(5459),
    [anon_sym_LBRACE] = ACTIONS(5461),
    [anon_sym_RBRACE] = ACTIONS(5461),
    [anon_sym_LBRACK] = ACTIONS(5461),
    [anon_sym_RBRACK] = ACTIONS(5461),
    [anon_sym_EQ] = ACTIONS(5459),
    [anon_sym_QMARK] = ACTIONS(5461),
    [anon_sym_STAR_EQ] = ACTIONS(5461),
    [anon_sym_SLASH_EQ] = ACTIONS(5461),
    [anon_sym_PERCENT_EQ] = ACTIONS(5461),
    [anon_sym_PLUS_EQ] = ACTIONS(5461),
    [anon_sym_DASH_EQ] = ACTIONS(5461),
    [anon_sym_LT_LT_EQ] = ACTIONS(5461),
    [anon_sym_GT_GT_EQ] = ACTIONS(5461),
    [anon_sym_AMP_EQ] = ACTIONS(5461),
    [anon_sym_CARET_EQ] = ACTIONS(5461),
    [anon_sym_PIPE_EQ] = ACTIONS(5461),
    [anon_sym_and_eq] = ACTIONS(5459),
    [anon_sym_or_eq] = ACTIONS(5459),
    [anon_sym_xor_eq] = ACTIONS(5459),
    [anon_sym_LT_EQ_GT] = ACTIONS(5461),
    [anon_sym_or] = ACTIONS(5459),
    [anon_sym_and] = ACTIONS(5459),
    [anon_sym_bitor] = ACTIONS(5459),
    [anon_sym_xor] = ACTIONS(5459),
    [anon_sym_bitand] = ACTIONS(5459),
    [anon_sym_not_eq] = ACTIONS(5459),
    [anon_sym_DASH_DASH] = ACTIONS(5461),
    [anon_sym_PLUS_PLUS] = ACTIONS(5461),
    [anon_sym_DOT] = ACTIONS(5459),
    [anon_sym_DOT_STAR] = ACTIONS(5461),
    [anon_sym_DASH_GT] = ACTIONS(5461),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5459),
    [anon_sym_decltype] = ACTIONS(5459),
  },
  [2657] = {
    [sym_identifier] = ACTIONS(5541),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5543),
    [anon_sym_COMMA] = ACTIONS(5543),
    [anon_sym_RPAREN] = ACTIONS(5543),
    [aux_sym_preproc_if_token2] = ACTIONS(5543),
    [aux_sym_preproc_else_token1] = ACTIONS(5543),
    [aux_sym_preproc_elif_token1] = ACTIONS(5541),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5543),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5543),
    [anon_sym_LPAREN2] = ACTIONS(5543),
    [anon_sym_DASH] = ACTIONS(5541),
    [anon_sym_PLUS] = ACTIONS(5541),
    [anon_sym_STAR] = ACTIONS(5541),
    [anon_sym_SLASH] = ACTIONS(5541),
    [anon_sym_PERCENT] = ACTIONS(5541),
    [anon_sym_PIPE_PIPE] = ACTIONS(5543),
    [anon_sym_AMP_AMP] = ACTIONS(5543),
    [anon_sym_PIPE] = ACTIONS(5541),
    [anon_sym_CARET] = ACTIONS(5541),
    [anon_sym_AMP] = ACTIONS(5541),
    [anon_sym_EQ_EQ] = ACTIONS(5543),
    [anon_sym_BANG_EQ] = ACTIONS(5543),
    [anon_sym_GT] = ACTIONS(5541),
    [anon_sym_GT_EQ] = ACTIONS(5543),
    [anon_sym_LT_EQ] = ACTIONS(5541),
    [anon_sym_LT] = ACTIONS(5541),
    [anon_sym_LT_LT] = ACTIONS(5541),
    [anon_sym_GT_GT] = ACTIONS(5541),
    [anon_sym_COLON] = ACTIONS(5543),
    [anon_sym_SEMI] = ACTIONS(5543),
    [anon_sym___attribute__] = ACTIONS(5541),
    [anon_sym_LBRACE] = ACTIONS(5543),
    [anon_sym_RBRACE] = ACTIONS(5543),
    [anon_sym_LBRACK] = ACTIONS(5543),
    [anon_sym_RBRACK] = ACTIONS(5543),
    [anon_sym_EQ] = ACTIONS(5541),
    [anon_sym_QMARK] = ACTIONS(5543),
    [anon_sym_STAR_EQ] = ACTIONS(5543),
    [anon_sym_SLASH_EQ] = ACTIONS(5543),
    [anon_sym_PERCENT_EQ] = ACTIONS(5543),
    [anon_sym_PLUS_EQ] = ACTIONS(5543),
    [anon_sym_DASH_EQ] = ACTIONS(5543),
    [anon_sym_LT_LT_EQ] = ACTIONS(5543),
    [anon_sym_GT_GT_EQ] = ACTIONS(5543),
    [anon_sym_AMP_EQ] = ACTIONS(5543),
    [anon_sym_CARET_EQ] = ACTIONS(5543),
    [anon_sym_PIPE_EQ] = ACTIONS(5543),
    [anon_sym_and_eq] = ACTIONS(5541),
    [anon_sym_or_eq] = ACTIONS(5541),
    [anon_sym_xor_eq] = ACTIONS(5541),
    [anon_sym_LT_EQ_GT] = ACTIONS(5543),
    [anon_sym_or] = ACTIONS(5541),
    [anon_sym_and] = ACTIONS(5541),
    [anon_sym_bitor] = ACTIONS(5541),
    [anon_sym_xor] = ACTIONS(5541),
    [anon_sym_bitand] = ACTIONS(5541),
    [anon_sym_not_eq] = ACTIONS(5541),
    [anon_sym_DASH_DASH] = ACTIONS(5543),
    [anon_sym_PLUS_PLUS] = ACTIONS(5543),
    [anon_sym_DOT] = ACTIONS(5541),
    [anon_sym_DOT_STAR] = ACTIONS(5543),
    [anon_sym_DASH_GT] = ACTIONS(5543),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5541),
    [anon_sym_decltype] = ACTIONS(5541),
  },
  [2658] = {
    [sym_identifier] = ACTIONS(6154),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6156),
    [anon_sym_RPAREN] = ACTIONS(6156),
    [aux_sym_preproc_if_token2] = ACTIONS(6156),
    [aux_sym_preproc_else_token1] = ACTIONS(6156),
    [aux_sym_preproc_elif_token1] = ACTIONS(6154),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6156),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6156),
    [anon_sym_LPAREN2] = ACTIONS(6156),
    [anon_sym_DASH] = ACTIONS(6154),
    [anon_sym_PLUS] = ACTIONS(6154),
    [anon_sym_STAR] = ACTIONS(6154),
    [anon_sym_SLASH] = ACTIONS(6154),
    [anon_sym_PERCENT] = ACTIONS(6154),
    [anon_sym_PIPE_PIPE] = ACTIONS(6156),
    [anon_sym_AMP_AMP] = ACTIONS(6156),
    [anon_sym_PIPE] = ACTIONS(6154),
    [anon_sym_CARET] = ACTIONS(6154),
    [anon_sym_AMP] = ACTIONS(6154),
    [anon_sym_EQ_EQ] = ACTIONS(6156),
    [anon_sym_BANG_EQ] = ACTIONS(6156),
    [anon_sym_GT] = ACTIONS(6154),
    [anon_sym_GT_EQ] = ACTIONS(6156),
    [anon_sym_LT_EQ] = ACTIONS(6154),
    [anon_sym_LT] = ACTIONS(6154),
    [anon_sym_LT_LT] = ACTIONS(6154),
    [anon_sym_GT_GT] = ACTIONS(6154),
    [anon_sym_COLON] = ACTIONS(6156),
    [anon_sym_SEMI] = ACTIONS(6156),
    [anon_sym___attribute__] = ACTIONS(6154),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(6156),
    [anon_sym_LBRACE] = ACTIONS(6156),
    [anon_sym_RBRACE] = ACTIONS(6156),
    [anon_sym_LBRACK] = ACTIONS(6154),
    [anon_sym_RBRACK] = ACTIONS(6156),
    [anon_sym_EQ] = ACTIONS(6154),
    [anon_sym_QMARK] = ACTIONS(6156),
    [anon_sym_STAR_EQ] = ACTIONS(6156),
    [anon_sym_SLASH_EQ] = ACTIONS(6156),
    [anon_sym_PERCENT_EQ] = ACTIONS(6156),
    [anon_sym_PLUS_EQ] = ACTIONS(6156),
    [anon_sym_DASH_EQ] = ACTIONS(6156),
    [anon_sym_LT_LT_EQ] = ACTIONS(6156),
    [anon_sym_GT_GT_EQ] = ACTIONS(6156),
    [anon_sym_AMP_EQ] = ACTIONS(6156),
    [anon_sym_CARET_EQ] = ACTIONS(6156),
    [anon_sym_PIPE_EQ] = ACTIONS(6156),
    [anon_sym_and_eq] = ACTIONS(6154),
    [anon_sym_or_eq] = ACTIONS(6154),
    [anon_sym_xor_eq] = ACTIONS(6154),
    [anon_sym_LT_EQ_GT] = ACTIONS(6156),
    [anon_sym_or] = ACTIONS(6154),
    [anon_sym_and] = ACTIONS(6154),
    [anon_sym_bitor] = ACTIONS(6154),
    [anon_sym_xor] = ACTIONS(6154),
    [anon_sym_bitand] = ACTIONS(6154),
    [anon_sym_not_eq] = ACTIONS(6154),
    [anon_sym_DASH_DASH] = ACTIONS(6156),
    [anon_sym_PLUS_PLUS] = ACTIONS(6156),
    [anon_sym_DOT] = ACTIONS(6154),
    [anon_sym_DOT_STAR] = ACTIONS(6156),
    [anon_sym_DASH_GT] = ACTIONS(6156),
    [sym_comment] = ACTIONS(3),
    [anon_sym_try] = ACTIONS(6154),
  },
  [2659] = {
    [aux_sym_sized_type_specifier_repeat1] = STATE(2410),
    [sym_identifier] = ACTIONS(6158),
    [anon_sym_LPAREN2] = ACTIONS(5336),
    [anon_sym_STAR] = ACTIONS(5336),
    [anon_sym_AMP_AMP] = ACTIONS(5336),
    [anon_sym_AMP] = ACTIONS(5338),
    [anon_sym___extension__] = ACTIONS(5338),
    [anon_sym_in] = ACTIONS(5338),
    [anon_sym_out] = ACTIONS(5338),
    [anon_sym_inout] = ACTIONS(5338),
    [anon_sym_extern] = ACTIONS(5338),
    [anon_sym___attribute__] = ACTIONS(5338),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(5336),
    [anon_sym___declspec] = ACTIONS(5338),
    [anon_sym_LBRACE] = ACTIONS(5336),
    [anon_sym_signed] = ACTIONS(6160),
    [anon_sym_unsigned] = ACTIONS(6160),
    [anon_sym_long] = ACTIONS(6160),
    [anon_sym_short] = ACTIONS(6160),
    [anon_sym_LBRACK] = ACTIONS(5338),
    [anon_sym_static] = ACTIONS(5338),
    [anon_sym_register] = ACTIONS(5338),
    [anon_sym_inline] = ACTIONS(5338),
    [anon_sym___inline] = ACTIONS(5338),
    [anon_sym___inline__] = ACTIONS(5338),
    [anon_sym___forceinline] = ACTIONS(5338),
    [anon_sym_thread_local] = ACTIONS(5338),
    [anon_sym___thread] = ACTIONS(5338),
    [anon_sym_const] = ACTIONS(5338),
    [anon_sym_constexpr] = ACTIONS(5338),
    [anon_sym_volatile] = ACTIONS(5338),
    [anon_sym_restrict] = ACTIONS(5338),
    [anon_sym___restrict__] = ACTIONS(5338),
    [anon_sym__Atomic] = ACTIONS(5338),
    [anon_sym__Noreturn] = ACTIONS(5338),
    [anon_sym_noreturn] = ACTIONS(5338),
    [anon_sym_mutable] = ACTIONS(5338),
    [anon_sym_constinit] = ACTIONS(5338),
    [anon_sym_consteval] = ACTIONS(5338),
    [anon_sym_alignas] = ACTIONS(5338),
    [anon_sym__Alignas] = ACTIONS(5338),
    [sym_primitive_type] = ACTIONS(5342),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5338),
    [anon_sym_decltype] = ACTIONS(5338),
    [sym_virtual] = ACTIONS(5338),
    [anon_sym_precise] = ACTIONS(5338),
    [anon_sym_shared] = ACTIONS(5338),
    [anon_sym_groupshared] = ACTIONS(5338),
    [anon_sym_uniform] = ACTIONS(5338),
    [anon_sym_row_major] = ACTIONS(5338),
    [anon_sym_column_major] = ACTIONS(5338),
    [anon_sym_globallycoherent] = ACTIONS(5338),
    [anon_sym_centroid] = ACTIONS(5338),
    [anon_sym_noperspective] = ACTIONS(5338),
    [anon_sym_nointerpolation] = ACTIONS(5338),
    [anon_sym_sample] = ACTIONS(5338),
    [anon_sym_linear] = ACTIONS(5338),
    [anon_sym_snorm] = ACTIONS(5338),
    [anon_sym_unorm] = ACTIONS(5338),
    [anon_sym_point] = ACTIONS(5338),
    [anon_sym_line] = ACTIONS(5338),
    [anon_sym_triangleadj] = ACTIONS(5338),
    [anon_sym_lineadj] = ACTIONS(5338),
    [anon_sym_triangle] = ACTIONS(5338),
  },
  [2660] = {
    [sym_argument_list] = STATE(2842),
    [sym_initializer_list] = STATE(2842),
    [sym_identifier] = ACTIONS(6162),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(6164),
    [anon_sym_COMMA] = ACTIONS(6164),
    [anon_sym_RPAREN] = ACTIONS(6164),
    [aux_sym_preproc_if_token2] = ACTIONS(6164),
    [aux_sym_preproc_else_token1] = ACTIONS(6164),
    [aux_sym_preproc_elif_token1] = ACTIONS(6162),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(6164),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(6164),
    [anon_sym_LPAREN2] = ACTIONS(5854),
    [anon_sym_DASH] = ACTIONS(6162),
    [anon_sym_PLUS] = ACTIONS(6162),
    [anon_sym_STAR] = ACTIONS(6162),
    [anon_sym_SLASH] = ACTIONS(6162),
    [anon_sym_PERCENT] = ACTIONS(6162),
    [anon_sym_PIPE_PIPE] = ACTIONS(6164),
    [anon_sym_AMP_AMP] = ACTIONS(6164),
    [anon_sym_PIPE] = ACTIONS(6162),
    [anon_sym_CARET] = ACTIONS(6162),
    [anon_sym_AMP] = ACTIONS(6162),
    [anon_sym_EQ_EQ] = ACTIONS(6164),
    [anon_sym_BANG_EQ] = ACTIONS(6164),
    [anon_sym_GT] = ACTIONS(6162),
    [anon_sym_GT_EQ] = ACTIONS(6164),
    [anon_sym_LT_EQ] = ACTIONS(6162),
    [anon_sym_LT] = ACTIONS(6162),
    [anon_sym_LT_LT] = ACTIONS(6162),
    [anon_sym_GT_GT] = ACTIONS(6162),
    [anon_sym_COLON] = ACTIONS(6164),
    [anon_sym_SEMI] = ACTIONS(6164),
    [anon_sym___attribute__] = ACTIONS(6162),
    [anon_sym_LBRACE] = ACTIONS(3523),
    [anon_sym_RBRACE] = ACTIONS(6164),
    [anon_sym_LBRACK] = ACTIONS(6164),
    [anon_sym_RBRACK] = ACTIONS(6164),
    [anon_sym_EQ] = ACTIONS(6162),
    [anon_sym_QMARK] = ACTIONS(6164),
    [anon_sym_STAR_EQ] = ACTIONS(6164),
    [anon_sym_SLASH_EQ] = ACTIONS(6164),
    [anon_sym_PERCENT_EQ] = ACTIONS(6164),
    [anon_sym_PLUS_EQ] = ACTIONS(6164),
    [anon_sym_DASH_EQ] = ACTIONS(6164),
    [anon_sym_LT_LT_EQ] = ACTIONS(6164),
    [anon_sym_GT_GT_EQ] = ACTIONS(6164),
    [anon_sym_AMP_EQ] = ACTIONS(6164),
    [anon_sym_CARET_EQ] = ACTIONS(6164),
    [anon_sym_PIPE_EQ] = ACTIONS(6164),
    [anon_sym_and_eq] = ACTIONS(6162),
    [anon_sym_or_eq] = ACTIONS(6162),
    [anon_sym_xor_eq] = ACTIONS(6162),
    [anon_sym_LT_EQ_GT] = ACTIONS(6164),
    [anon_sym_or] = ACTIONS(6162),
    [anon_sym_and] = ACTIONS(6162),
    [anon_sym_bitor] = ACTIONS(6162),
    [anon_sym_xor] = ACTIONS(6162),
    [anon_sym_bitand] = ACTIONS(6162),
    [anon_sym_not_eq] = ACTIONS(6162),
    [anon_sym_DASH_DASH] = ACTIONS(6164),
    [anon_sym_PLUS_PLUS] = ACTIONS(6164),
    [anon_sym_DOT] = ACTIONS(6162),
    [anon_sym_DOT_STAR] = ACTIONS(6164),
    [anon_sym_DASH_GT] = ACTIONS(6164),
    [sym_comment] = ACTIONS(3),
  },
  [2661] = {
    [sym_identifier] = ACTIONS(5423),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5425),
    [anon_sym_COMMA] = ACTIONS(5425),
    [anon_sym_RPAREN] = ACTIONS(5425),
    [aux_sym_preproc_if_token2] = ACTIONS(5425),
    [aux_sym_preproc_else_token1] = ACTIONS(5425),
    [aux_sym_preproc_elif_token1] = ACTIONS(5423),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5425),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5425),
    [anon_sym_LPAREN2] = ACTIONS(5425),
    [anon_sym_DASH] = ACTIONS(5423),
    [anon_sym_PLUS] = ACTIONS(5423),
    [anon_sym_STAR] = ACTIONS(5423),
    [anon_sym_SLASH] = ACTIONS(5423),
    [anon_sym_PERCENT] = ACTIONS(5423),
    [anon_sym_PIPE_PIPE] = ACTIONS(5425),
    [anon_sym_AMP_AMP] = ACTIONS(5425),
    [anon_sym_PIPE] = ACTIONS(5423),
    [anon_sym_CARET] = ACTIONS(5423),
    [anon_sym_AMP] = ACTIONS(5423),
    [anon_sym_EQ_EQ] = ACTIONS(5425),
    [anon_sym_BANG_EQ] = ACTIONS(5425),
    [anon_sym_GT] = ACTIONS(5423),
    [anon_sym_GT_EQ] = ACTIONS(5425),
    [anon_sym_LT_EQ] = ACTIONS(5423),
    [anon_sym_LT] = ACTIONS(5423),
    [anon_sym_LT_LT] = ACTIONS(5423),
    [anon_sym_GT_GT] = ACTIONS(5423),
    [anon_sym_COLON] = ACTIONS(5425),
    [anon_sym_SEMI] = ACTIONS(5425),
    [anon_sym___attribute__] = ACTIONS(5423),
    [anon_sym_LBRACE] = ACTIONS(5425),
    [anon_sym_RBRACE] = ACTIONS(5425),
    [anon_sym_LBRACK] = ACTIONS(5425),
    [anon_sym_RBRACK] = ACTIONS(5425),
    [anon_sym_EQ] = ACTIONS(5423),
    [anon_sym_QMARK] = ACTIONS(5425),
    [anon_sym_STAR_EQ] = ACTIONS(5425),
    [anon_sym_SLASH_EQ] = ACTIONS(5425),
    [anon_sym_PERCENT_EQ] = ACTIONS(5425),
    [anon_sym_PLUS_EQ] = ACTIONS(5425),
    [anon_sym_DASH_EQ] = ACTIONS(5425),
    [anon_sym_LT_LT_EQ] = ACTIONS(5425),
    [anon_sym_GT_GT_EQ] = ACTIONS(5425),
    [anon_sym_AMP_EQ] = ACTIONS(5425),
    [anon_sym_CARET_EQ] = ACTIONS(5425),
    [anon_sym_PIPE_EQ] = ACTIONS(5425),
    [anon_sym_and_eq] = ACTIONS(5423),
    [anon_sym_or_eq] = ACTIONS(5423),
    [anon_sym_xor_eq] = ACTIONS(5423),
    [anon_sym_LT_EQ_GT] = ACTIONS(5425),
    [anon_sym_or] = ACTIONS(5423),
    [anon_sym_and] = ACTIONS(5423),
    [anon_sym_bitor] = ACTIONS(5423),
    [anon_sym_xor] = ACTIONS(5423),
    [anon_sym_bitand] = ACTIONS(5423),
    [anon_sym_not_eq] = ACTIONS(5423),
    [anon_sym_DASH_DASH] = ACTIONS(5425),
    [anon_sym_PLUS_PLUS] = ACTIONS(5425),
    [anon_sym_DOT] = ACTIONS(5423),
    [anon_sym_DOT_STAR] = ACTIONS(5425),
    [anon_sym_DASH_GT] = ACTIONS(5425),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5423),
    [anon_sym_decltype] = ACTIONS(5423),
  },
  [2662] = {
    [sym_identifier] = ACTIONS(2272),
    [anon_sym___extension__] = ACTIONS(2272),
    [anon_sym_in] = ACTIONS(2272),
    [anon_sym_out] = ACTIONS(2272),
    [anon_sym_inout] = ACTIONS(2272),
    [anon_sym_extern] = ACTIONS(2272),
    [anon_sym___attribute__] = ACTIONS(2272),
    [anon_sym_COLON_COLON] = ACTIONS(2274),
    [anon_sym_LBRACK_LBRACK] = ACTIONS(2274),
    [anon_sym___declspec] = ACTIONS(2272),
    [anon_sym_signed] = ACTIONS(2272),
    [anon_sym_unsigned] = ACTIONS(2272),
    [anon_sym_long] = ACTIONS(2272),
    [anon_sym_short] = ACTIONS(2272),
    [anon_sym_static] = ACTIONS(2272),
    [anon_sym_register] = ACTIONS(2272),
    [anon_sym_inline] = ACTIONS(2272),
    [anon_sym___inline] = ACTIONS(2272),
    [anon_sym___inline__] = ACTIONS(2272),
    [anon_sym___forceinline] = ACTIONS(2272),
    [anon_sym_thread_local] = ACTIONS(2272),
    [anon_sym___thread] = ACTIONS(2272),
    [anon_sym_const] = ACTIONS(2272),
    [anon_sym_constexpr] = ACTIONS(2272),
    [anon_sym_volatile] = ACTIONS(2272),
    [anon_sym_restrict] = ACTIONS(2272),
    [anon_sym___restrict__] = ACTIONS(2272),
    [anon_sym__Atomic] = ACTIONS(2272),
    [anon_sym__Noreturn] = ACTIONS(2272),
    [anon_sym_noreturn] = ACTIONS(2272),
    [anon_sym_mutable] = ACTIONS(2272),
    [anon_sym_constinit] = ACTIONS(2272),
    [anon_sym_consteval] = ACTIONS(2272),
    [anon_sym_alignas] = ACTIONS(2272),
    [anon_sym__Alignas] = ACTIONS(2272),
    [sym_primitive_type] = ACTIONS(2272),
    [anon_sym_enum] = ACTIONS(2272),
    [anon_sym_class] = ACTIONS(2272),
    [anon_sym_struct] = ACTIONS(2272),
    [anon_sym_union] = ACTIONS(2272),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(2272),
    [anon_sym_decltype] = ACTIONS(2272),
    [sym_virtual] = ACTIONS(2272),
    [anon_sym_typename] = ACTIONS(2272),
    [anon_sym_template] = ACTIONS(2272),
    [anon_sym_precise] = ACTIONS(2272),
    [anon_sym_shared] = ACTIONS(2272),
    [anon_sym_groupshared] = ACTIONS(2272),
    [anon_sym_uniform] = ACTIONS(2272),
    [anon_sym_row_major] = ACTIONS(2272),
    [anon_sym_column_major] = ACTIONS(2272),
    [anon_sym_globallycoherent] = ACTIONS(2272),
    [anon_sym_centroid] = ACTIONS(2272),
    [anon_sym_noperspective] = ACTIONS(2272),
    [anon_sym_nointerpolation] = ACTIONS(2272),
    [anon_sym_sample] = ACTIONS(2272),
    [anon_sym_linear] = ACTIONS(2272),
    [anon_sym_snorm] = ACTIONS(2272),
    [anon_sym_unorm] = ACTIONS(2272),
    [anon_sym_point] = ACTIONS(2272),
    [anon_sym_line] = ACTIONS(2272),
    [anon_sym_triangleadj] = ACTIONS(2272),
    [anon_sym_lineadj] = ACTIONS(2272),
    [anon_sym_triangle] = ACTIONS(2272),
  },
  [2663] = {
    [sym_identifier] = ACTIONS(5318),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(5320),
    [anon_sym_COMMA] = ACTIONS(5320),
    [anon_sym_RPAREN] = ACTIONS(5320),
    [aux_sym_preproc_if_token2] = ACTIONS(5320),
    [aux_sym_preproc_else_token1] = ACTIONS(5320),
    [aux_sym_preproc_elif_token1] = ACTIONS(5318),
    [aux_sym_preproc_elifdef_token1] = ACTIONS(5320),
    [aux_sym_preproc_elifdef_token2] = ACTIONS(5320),
    [anon_sym_LPAREN2] = ACTIONS(5320),
    [anon_sym_DASH] = ACTIONS(5318),
    [anon_sym_PLUS] = ACTIONS(5318),
    [anon_sym_STAR] = ACTIONS(5318),
    [anon_sym_SLASH] = ACTIONS(5318),
    [anon_sym_PERCENT] = ACTIONS(5318),
    [anon_sym_PIPE_PIPE] = ACTIONS(5320),
    [anon_sym_AMP_AMP] = ACTIONS(5320),
    [anon_sym_PIPE] = ACTIONS(5318),
    [anon_sym_CARET] = ACTIONS(5318),
    [anon_sym_AMP] = ACTIONS(5318),
    [anon_sym_EQ_EQ] = ACTIONS(5320),
    [anon_sym_BANG_EQ] = ACTIONS(5320),
    [anon_sym_GT] = ACTIONS(5318),
    [anon_sym_GT_EQ] = ACTIONS(5320),
    [anon_sym_LT_EQ] = ACTIONS(5318),
    [anon_sym_LT] = ACTIONS(5318),
    [anon_sym_LT_LT] = ACTIONS(5318),
    [anon_sym_GT_GT] = ACTIONS(5318),
    [anon_sym_COLON] = ACTIONS(5320),
    [anon_sym_SEMI] = ACTIONS(5320),
    [anon_sym___attribute__] = ACTIONS(5318),
    [anon_sym_LBRACE] = ACTIONS(5320),
    [anon_sym_RBRACE] = ACTIONS(5320),
    [anon_sym_LBRACK] = ACTIONS(5320),
    [anon_sym_RBRACK] = ACTIONS(5320),
    [anon_sym_EQ] = ACTIONS(5318),
    [anon_sym_QMARK] = ACTIONS(5320),
    [anon_sym_STAR_EQ] = ACTIONS(5320),
    [anon_sym_SLASH_EQ] = ACTIONS(5320),
    [anon_sym_PERCENT_EQ] = ACTIONS(5320),
    [anon_sym_PLUS_EQ] = ACTIONS(5320),
    [anon_sym_DASH_EQ] = ACTIONS(5320),
    [anon_sym_LT_LT_EQ] = ACTIONS(5320),
    [anon_sym_GT_GT_EQ] = ACTIONS(5320),
    [anon_sym_AMP_EQ] = ACTIONS(5320),
    [anon_sym_CARET_EQ] = ACTIONS(5320),
    [anon_sym_PIPE_EQ] = ACTIONS(5320),
    [anon_sym_and_eq] = ACTIONS(5318),
    [anon_sym_or_eq] = ACTIONS(5318),
    [anon_sym_xor_eq] = ACTIONS(5318),
    [anon_sym_LT_EQ_GT] = ACTIONS(5320),
    [anon_sym_or] = ACTIONS(5318),
    [anon_sym_and] = ACTIONS(5318),
    [anon_sym_bitor] = ACTIONS(5318),
    [anon_sym_xor] = ACTIONS(5318),
    [anon_sym_bitand] = ACTIONS(5318),
    [anon_sym_not_eq] = ACTIONS(5318),
    [anon_sym_DASH_DASH] = ACTIONS(5320),
    [anon_sym_PLUS_PLUS] = ACTIONS(5320),
    [anon_sym_DOT] = ACTIONS(5318),
    [anon_sym_DOT_STAR] = ACTIONS(5320),
    [anon_sym_DASH_GT] = ACTIONS(5320),
    [sym_comment] = ACTIONS(3),
    [sym_auto] = ACTIONS(5318),
    [anon_sym_decltype] = ACTIONS(5318),
  },
  [2664] = {
    [sym_string_literal] = STATE(2509),
    [sym_raw_string_literal] = STATE(2509),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(3824),
    [anon_sym_COMMA] = ACTIONS(3824),
    [anon_sym_RPAREN] = ACTIONS(3824),
    [anon_sym_LPAREN2] = ACTIONS(3824),
    [anon_sym_DASH] = ACTIONS(3832),
    [anon_sym_PLUS] = ACTIONS(3832),
    [anon_sym_STAR] = ACTIONS(3832),
    [anon_sym_SLASH] = ACTIONS(3832),
    [anon_sym_PERCENT] = ACTIONS(3832),
    [anon_sym_PIPE_PIPE] = ACTIONS(3824),
    [anon_sym_AMP_AMP] = ACTIONS(3824),
    [anon_sym_PIPE] = ACTIONS(3832),
    [anon_sym_CARET] = ACTIONS(3832),
    [anon_sym_AMP] = ACTIONS(3832),
    [anon_sym_EQ_EQ] = ACTIONS(3824),
    [anon_sym_BANG_EQ] = ACTIONS(3824),
    [anon_sym_GT] = ACTIONS(3832),
    [anon_sym_GT_EQ] = ACTIONS(3824),
    [anon_sym_LT_EQ] = ACTIONS(3832),
    [anon_sym_LT] = ACTIONS(3832),
    [anon_sym_LT_LT] = ACTIONS(3832),
    [anon_sym_GT_GT] = ACTIONS(3832),
    [anon_sym_LBRACK] = ACTIONS(3824),
    [anon_sym_EQ] = ACTIONS(3832),
    [anon_sym_QMARK] = ACTIONS(3824),
    [anon_sym_STAR_EQ] = ACTIONS(3824),
    [anon_sym_SLASH_EQ] = ACTIONS(3824),
    [anon_sym_PERCENT_EQ] = ACTIONS(3824),
    [anon_sym_PLUS_EQ] = ACTIONS(3824),
    [anon_sym_DASH_EQ] = ACTIONS(3824),
    [anon_sym_LT_LT_EQ] = ACTIONS(3824),
    [anon_sym_GT_GT_EQ] = ACTIONS(3824),
    [anon_sym_AMP_EQ] = ACTIONS(3824),
    [anon_sym_CARET_EQ] = ACTIONS(3824),
    [anon_sym_PIPE_EQ] = ACTIONS(3824),
    [anon_sym_and_eq] = ACTIONS(3832),
    [anon_sym_or_eq] = ACTIONS(3832),
    [anon_sym_xor_eq] = ACTIONS(3832),
    [anon_sym_LT_EQ_GT] = ACTIONS(3824),
    [anon_sym_or] = ACTIONS(3832),
    [anon_sym_and] = ACTIONS(3832),
    [anon_sym_bitor] = ACTIONS(3832),
    [anon_sym_xor] = ACTIONS(3832),
    [anon_sym_bitand] = ACTIONS(3832),
    [anon_sym_not_eq] = ACTIONS(3832),
    [anon_sym_DASH_DASH] = ACTIONS(3824),
    [anon_sym_PLUS_PLUS] = ACTIONS(3824),
    [anon_sym_DOT] = ACTIONS(3832),
    [anon_sym_DOT_STAR] = ACTIONS(3824),
    [anon_sym_DASH_GT] = ACTIONS(3832),
    [anon_sym_L_DQUOTE] = ACTIONS(5192),
    [anon_sym_u_DQUOTE] = ACTIONS(5192),
    [anon_sym_U_DQUOTE] = ACTIONS(5192),
    [anon_sym_u8_DQUOTE] = ACTIONS(5192),
    [anon_sym_DQUOTE] = ACTIONS(5192),
    [sym_comment] = ACTIONS(3),
    [anon_sym_R_DQUOTE] = ACTIONS(5194),
    [anon_sym_LR_DQUOTE] = ACTIONS(5194),
    [anon_sym_uR_DQUOTE] = ACTIONS(5194),
    [anon_sym_UR_DQUOTE] = ACTIONS(5194),
    [anon_sym_u8R_DQUOTE] = ACTIONS(5194),
    [anon_sym_DASH_GT_STAR] = ACTIONS(3824),
    [sym_literal_suffix] = ACTIONS(6087),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2408), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6166), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5373), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5375), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
  [75] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2581), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6168), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5347), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5349), 46,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [150] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2665), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6170), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5318), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5320), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
  [225] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6070), 1,
      anon_sym___attribute__,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    STATE(2462), 1,
      sym_attribute_specifier,
    STATE(2735), 1,
      sym_enumerator_list,
    ACTIONS(5529), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5531), 49,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [304] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2697), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6174), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5353), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5355), 46,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [379] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5796), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5798), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
  [450] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2408), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6166), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5377), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5379), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
  [525] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2408), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6166), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5387), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5389), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
  [600] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2581), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6168), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5387), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5389), 46,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [675] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6176), 1,
      sym_identifier,
    STATE(2682), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(3973), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(3975), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5663), 23,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_literal_suffix,
    ACTIONS(5661), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [754] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2672), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6178), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5367), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5369), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
  [829] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6180), 1,
      sym_identifier,
    STATE(2676), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(6183), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(6186), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5651), 23,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_literal_suffix,
    ACTIONS(5649), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [908] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2581), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6168), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5377), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5379), 46,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [983] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6193), 1,
      anon_sym_LT,
    STATE(2679), 1,
      sym_template_argument_list,
    ACTIONS(6189), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6191), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [1060] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6196), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6198), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [1133] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5775), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5777), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
  [1204] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5771), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5773), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [1275] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6200), 1,
      sym_identifier,
    STATE(2676), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(3973), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(3975), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5669), 23,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_literal_suffix,
    ACTIONS(5667), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [1354] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2653), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6105), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5318), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5320), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [1429] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5815), 1,
      anon_sym___attribute__,
    ACTIONS(5911), 1,
      anon_sym_LBRACE,
    ACTIONS(6202), 1,
      anon_sym_COLON,
    STATE(2524), 1,
      sym__enum_base_clause,
    STATE(2583), 1,
      sym_enumerator_list,
    STATE(2600), 1,
      sym_attribute_specifier,
    ACTIONS(5689), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5691), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [1512] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6070), 1,
      anon_sym___attribute__,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    STATE(2478), 1,
      sym_attribute_specifier,
    STATE(2737), 1,
      sym_enumerator_list,
    ACTIONS(5519), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5521), 49,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [1591] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2665), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6170), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5353), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5355), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
  [1666] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1961), 2,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
    ACTIONS(4063), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(4058), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [1739] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5775), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5777), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [1810] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2408), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6166), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5347), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5349), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
  [1885] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5771), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5773), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
  [1956] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6208), 1,
      anon_sym_LT,
    STATE(2679), 1,
      sym_template_argument_list,
    ACTIONS(6204), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6206), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [2033] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4050), 1,
      anon_sym_LBRACK,
    ACTIONS(5298), 1,
      anon_sym_LT,
    STATE(2851), 1,
      sym_template_argument_list,
    ACTIONS(4047), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(1935), 3,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
    ACTIONS(1933), 54,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym_in,
      anon_sym_out,
      anon_sym_inout,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      sym_virtual,
      anon_sym_operator,
      anon_sym_precise,
      anon_sym_shared,
      anon_sym_groupshared,
      anon_sym_uniform,
      anon_sym_row_major,
      anon_sym_column_major,
      anon_sym_globallycoherent,
      anon_sym_centroid,
      anon_sym_noperspective,
      anon_sym_nointerpolation,
      anon_sym_sample,
      anon_sym_linear,
      anon_sym_snorm,
      anon_sym_unorm,
      anon_sym_point,
      anon_sym_line,
      anon_sym_triangleadj,
      anon_sym_lineadj,
      anon_sym_triangle,
  [2114] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5779), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5781), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [2185] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5796), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5798), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [2256] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5779), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5781), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
  [2327] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5815), 1,
      anon_sym___attribute__,
    ACTIONS(5911), 1,
      anon_sym_LBRACE,
    ACTIONS(6202), 1,
      anon_sym_COLON,
    STATE(2508), 1,
      sym__enum_base_clause,
    STATE(2569), 1,
      sym_enumerator_list,
    STATE(2605), 1,
      sym_attribute_specifier,
    ACTIONS(5636), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5638), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [2410] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2581), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6168), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5373), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5375), 46,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [2485] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6211), 1,
      sym_literal_suffix,
    STATE(2539), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(5992), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(5994), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5840), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
    ACTIONS(5838), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
  [2564] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6211), 1,
      sym_literal_suffix,
    STATE(2539), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(5992), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(5994), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(3824), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
    ACTIONS(3832), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
  [2643] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3934), 1,
      anon_sym_LPAREN2,
    ACTIONS(3936), 1,
      anon_sym_STAR,
    ACTIONS(3938), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3940), 1,
      anon_sym_AMP,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(5903), 1,
      anon_sym_LBRACK,
    ACTIONS(5905), 1,
      anon_sym_RPAREN,
    ACTIONS(6213), 1,
      anon_sym_COLON_COLON,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5718), 1,
      sym__scope_resolution,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6310), 1,
      sym__declarator,
    STATE(6577), 1,
      sym__abstract_declarator,
    STATE(8582), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3100), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(4067), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [2770] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2673), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6215), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5367), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5369), 46,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [2845] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2677), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6217), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5381), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5383), 46,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [2920] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2671), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6219), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5381), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5383), 40,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
  [2995] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3934), 1,
      anon_sym_LPAREN2,
    ACTIONS(3936), 1,
      anon_sym_STAR,
    ACTIONS(3938), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3940), 1,
      anon_sym_AMP,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(5891), 1,
      anon_sym_RPAREN,
    ACTIONS(5903), 1,
      anon_sym_LBRACK,
    ACTIONS(6213), 1,
      anon_sym_COLON_COLON,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5718), 1,
      sym__scope_resolution,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6320), 1,
      sym__declarator,
    STATE(6565), 1,
      sym__abstract_declarator,
    STATE(8582), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2700), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(3101), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [3122] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5856), 1,
      anon_sym_LBRACK,
    STATE(2708), 1,
      sym_new_declarator,
    ACTIONS(6221), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6223), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [3197] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6225), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6227), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [3267] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5775), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5777), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [3337] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6229), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6231), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [3407] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6070), 1,
      anon_sym___attribute__,
    STATE(2450), 1,
      sym_attribute_specifier,
    ACTIONS(5599), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5601), 50,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [3481] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6233), 26,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6235), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
  [3565] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6245), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6247), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [3635] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6249), 26,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6251), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [3717] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6253), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6255), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [3787] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5775), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5777), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [3857] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5771), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5773), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [3927] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2716), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6257), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5226), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
    ACTIONS(5224), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      sym_primitive_type,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [4001] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    STATE(2390), 1,
      sym_template_argument_list,
    STATE(2871), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6260), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5294), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5296), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [4079] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6262), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6264), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [4149] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6070), 1,
      anon_sym___attribute__,
    STATE(2483), 1,
      sym_attribute_specifier,
    ACTIONS(5606), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5608), 50,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [4223] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6070), 1,
      anon_sym___attribute__,
    STATE(2484), 1,
      sym_attribute_specifier,
    ACTIONS(5583), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5585), 50,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [4297] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6266), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6268), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [4367] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5796), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_literal_suffix,
    ACTIONS(5798), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
  [4437] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6270), 26,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6272), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
  [4521] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6070), 1,
      anon_sym___attribute__,
    STATE(2477), 1,
      sym_attribute_specifier,
    ACTIONS(5610), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5612), 50,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [4595] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6070), 1,
      anon_sym___attribute__,
    STATE(2434), 1,
      sym_attribute_specifier,
    ACTIONS(5595), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5597), 50,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [4669] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5320), 5,
      anon_sym_LPAREN2,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5318), 56,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym_in,
      anon_sym_out,
      anon_sym_inout,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym_LBRACK,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      sym_virtual,
      anon_sym_template,
      anon_sym_operator,
      anon_sym_precise,
      anon_sym_shared,
      anon_sym_groupshared,
      anon_sym_uniform,
      anon_sym_row_major,
      anon_sym_column_major,
      anon_sym_globallycoherent,
      anon_sym_centroid,
      anon_sym_noperspective,
      anon_sym_nointerpolation,
      anon_sym_sample,
      anon_sym_linear,
      anon_sym_snorm,
      anon_sym_unorm,
      anon_sym_point,
      anon_sym_line,
      anon_sym_triangleadj,
      anon_sym_lineadj,
      anon_sym_triangle,
  [4741] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6070), 1,
      anon_sym___attribute__,
    STATE(2448), 1,
      sym_attribute_specifier,
    ACTIONS(5567), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5569), 50,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [4815] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5775), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_literal_suffix,
    ACTIONS(5777), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
  [4885] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6070), 1,
      anon_sym___attribute__,
    STATE(2451), 1,
      sym_attribute_specifier,
    ACTIONS(5575), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5577), 50,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [4959] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3631), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(3633), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [5029] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6070), 1,
      anon_sym___attribute__,
    STATE(2446), 1,
      sym_attribute_specifier,
    ACTIONS(5571), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5573), 50,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [5103] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6225), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6227), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [5173] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6276), 6,
      anon_sym_LPAREN2,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6274), 56,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym_in,
      anon_sym_out,
      anon_sym_inout,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym_LBRACK,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      anon_sym_decltype,
      sym_virtual,
      anon_sym_explicit,
      anon_sym_template,
      anon_sym_operator,
      anon_sym_precise,
      anon_sym_shared,
      anon_sym_groupshared,
      anon_sym_uniform,
      anon_sym_row_major,
      anon_sym_column_major,
      anon_sym_globallycoherent,
      anon_sym_centroid,
      anon_sym_noperspective,
      anon_sym_nointerpolation,
      anon_sym_sample,
      anon_sym_linear,
      anon_sym_snorm,
      anon_sym_unorm,
      anon_sym_point,
      anon_sym_line,
      anon_sym_triangleadj,
      anon_sym_lineadj,
      anon_sym_triangle,
  [5243] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5771), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5773), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [5313] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6070), 1,
      anon_sym___attribute__,
    STATE(2440), 1,
      sym_attribute_specifier,
    ACTIONS(5587), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5589), 50,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [5387] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6282), 1,
      anon_sym_LBRACK_RBRACK,
    ACTIONS(6278), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6280), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [5459] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6070), 1,
      anon_sym___attribute__,
    STATE(2442), 1,
      sym_attribute_specifier,
    ACTIONS(5579), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5581), 50,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [5533] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2697), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6174), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5318), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5320), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [5607] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2716), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5224), 2,
      sym_primitive_type,
      sym_identifier,
    ACTIONS(6257), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5315), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
    ACTIONS(5312), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
  [5683] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(6284), 1,
      anon_sym___attribute__,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    STATE(2880), 1,
      sym_field_declaration_list,
    STATE(3024), 1,
      sym_attribute_specifier,
    STATE(6862), 1,
      sym_virtual_specifier,
    STATE(7817), 1,
      sym_base_class_clause,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(5327), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5329), 41,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym___extension__,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      anon_sym_requires,
  [5769] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6070), 1,
      anon_sym___attribute__,
    STATE(2456), 1,
      sym_attribute_specifier,
    ACTIONS(5614), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5616), 50,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [5843] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6288), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6290), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [5913] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6292), 26,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6294), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
  [5997] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5779), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5781), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [6067] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5796), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5798), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [6137] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3657), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(3659), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [6207] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5771), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_literal_suffix,
    ACTIONS(5773), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
  [6277] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6296), 1,
      sym_identifier,
    ACTIONS(6300), 1,
      sym_primitive_type,
    STATE(2739), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6298), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5336), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
    ACTIONS(5338), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
  [6355] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6302), 26,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6304), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [6437] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6310), 1,
      anon_sym_LT,
    STATE(2687), 1,
      sym_template_argument_list,
    ACTIONS(6306), 26,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6308), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [6511] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6070), 1,
      anon_sym___attribute__,
    STATE(2465), 1,
      sym_attribute_specifier,
    ACTIONS(5591), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5593), 50,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [6585] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6315), 1,
      anon_sym_LPAREN2,
    ACTIONS(6317), 5,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6313), 56,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym_in,
      anon_sym_out,
      anon_sym_inout,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym_LBRACK,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      anon_sym_decltype,
      sym_virtual,
      anon_sym_explicit,
      anon_sym_template,
      anon_sym_operator,
      anon_sym_precise,
      anon_sym_shared,
      anon_sym_groupshared,
      anon_sym_uniform,
      anon_sym_row_major,
      anon_sym_column_major,
      anon_sym_globallycoherent,
      anon_sym_centroid,
      anon_sym_noperspective,
      anon_sym_nointerpolation,
      anon_sym_sample,
      anon_sym_linear,
      anon_sym_snorm,
      anon_sym_unorm,
      anon_sym_point,
      anon_sym_line,
      anon_sym_triangleadj,
      anon_sym_lineadj,
      anon_sym_triangle,
  [6657] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(6319), 1,
      anon_sym___attribute__,
    ACTIONS(6321), 1,
      anon_sym_LBRACE,
    STATE(3071), 1,
      sym_field_declaration_list,
    STATE(3210), 1,
      sym_attribute_specifier,
    STATE(6960), 1,
      sym_virtual_specifier,
    STATE(7631), 1,
      sym_base_class_clause,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(5327), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5329), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [6743] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6225), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6227), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [6813] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6323), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6325), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [6883] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6327), 26,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6329), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
  [6967] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5796), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5798), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [7037] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5779), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5781), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [7107] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5779), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_literal_suffix,
    ACTIONS(5781), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
  [7177] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6331), 26,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6333), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
  [7261] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6335), 28,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6337), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [7331] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5149), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5151), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [7400] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5164), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5166), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [7469] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6339), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6341), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [7538] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6343), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6345), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [7607] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6347), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6349), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [7676] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5771), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5773), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [7745] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5145), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5147), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [7814] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5113), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5115), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [7883] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6351), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6353), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [7952] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6355), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6357), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [8021] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6087), 1,
      sym_literal_suffix,
    STATE(2674), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(3973), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(3975), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(3832), 22,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3824), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [8098] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6359), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6361), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [8167] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6363), 1,
      anon_sym_LT,
    STATE(2871), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2884), 1,
      sym_template_argument_list,
    ACTIONS(6260), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(3822), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3830), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [8246] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6365), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6367), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [8315] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6369), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6371), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [8384] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5523), 1,
      anon_sym_LBRACE,
    ACTIONS(6373), 1,
      anon_sym_COLON,
    ACTIONS(6375), 1,
      anon_sym___attribute__,
    STATE(2293), 1,
      sym_attribute_specifier,
    STATE(2299), 1,
      sym__enum_base_clause,
    STATE(2328), 1,
      sym_enumerator_list,
    ACTIONS(5636), 7,
      anon_sym_AMP,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym___inline,
      anon_sym_const,
      anon_sym_line,
      anon_sym_triangle,
    ACTIONS(5638), 48,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_out,
      anon_sym_inout,
      anon_sym_extern,
      anon_sym_LBRACK_LBRACK,
      anon_sym___declspec,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      sym_virtual,
      anon_sym_precise,
      anon_sym_shared,
      anon_sym_groupshared,
      anon_sym_uniform,
      anon_sym_row_major,
      anon_sym_column_major,
      anon_sym_globallycoherent,
      anon_sym_centroid,
      anon_sym_noperspective,
      anon_sym_nointerpolation,
      anon_sym_sample,
      anon_sym_linear,
      anon_sym_snorm,
      anon_sym_unorm,
      anon_sym_point,
      anon_sym_triangleadj,
      anon_sym_lineadj,
  [8465] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5119), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5121), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [8534] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5119), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5121), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [8603] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5123), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5125), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [8672] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5157), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5159), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [8741] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5137), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5139), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [8810] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6377), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6379), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6381), 1,
      anon_sym_or,
    ACTIONS(6383), 1,
      anon_sym_and,
    ACTIONS(5231), 25,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5233), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [8887] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5911), 1,
      anon_sym_LBRACE,
    ACTIONS(6385), 1,
      anon_sym_COLON,
    ACTIONS(6387), 1,
      anon_sym___attribute__,
    STATE(2508), 1,
      sym__enum_base_clause,
    STATE(2569), 1,
      sym_enumerator_list,
    STATE(2605), 1,
      sym_attribute_specifier,
    ACTIONS(5636), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5638), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
  [8968] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6389), 1,
      sym_identifier,
    ACTIONS(6393), 1,
      sym_primitive_type,
    STATE(2819), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6391), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5336), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
    ACTIONS(5338), 29,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_auto,
      anon_sym_decltype,
  [9045] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4041), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(4037), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [9114] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6087), 1,
      sym_literal_suffix,
    STATE(2674), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(3973), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(3975), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5838), 22,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5840), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [9191] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5119), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5121), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [9260] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6395), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6397), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [9329] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3832), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(3824), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [9398] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6379), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6383), 1,
      anon_sym_and,
    ACTIONS(5252), 26,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5254), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [9471] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5141), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5143), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [9540] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6399), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6401), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [9609] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6403), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6405), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [9678] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5172), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5174), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [9747] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6407), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6409), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [9816] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6411), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6413), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [9885] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6415), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6417), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [9954] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6419), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6421), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [10023] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(6423), 1,
      anon_sym___attribute__,
    ACTIONS(6425), 1,
      anon_sym_LBRACE,
    STATE(3132), 1,
      sym_field_declaration_list,
    STATE(3323), 1,
      sym_attribute_specifier,
    STATE(6991), 1,
      sym_virtual_specifier,
    STATE(7607), 1,
      sym_base_class_clause,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(5327), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5329), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [10108] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6427), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6429), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [10177] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6431), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6433), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [10246] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6435), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6437), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [10315] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5775), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5777), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [10384] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6439), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6441), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [10453] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6443), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6445), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [10522] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    STATE(2390), 1,
      sym_template_argument_list,
    STATE(2924), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6447), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5294), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5296), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [10599] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6449), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6451), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [10668] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6453), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6455), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [10737] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5129), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5131), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [10806] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5176), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5178), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [10875] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6457), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6459), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [10944] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6461), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6463), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [11013] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5887), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5885), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [11082] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6465), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6467), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [11151] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6469), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6471), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [11220] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6473), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6475), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [11289] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6477), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6479), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [11358] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2825), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5224), 2,
      sym_primitive_type,
      sym_identifier,
    ACTIONS(6481), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5315), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
    ACTIONS(5312), 29,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_auto,
      anon_sym_decltype,
  [11433] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(4045), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [11502] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6484), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6486), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [11571] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6488), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6490), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [11640] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6492), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6494), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [11709] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5911), 1,
      anon_sym_LBRACE,
    ACTIONS(6385), 1,
      anon_sym_COLON,
    ACTIONS(6387), 1,
      anon_sym___attribute__,
    STATE(2524), 1,
      sym__enum_base_clause,
    STATE(2583), 1,
      sym_enumerator_list,
    STATE(2600), 1,
      sym_attribute_specifier,
    ACTIONS(5689), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5691), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
  [11790] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2825), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6481), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5226), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
    ACTIONS(5224), 31,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      sym_primitive_type,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [11863] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6496), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6498), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [11932] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6500), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6502), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [12001] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6504), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6506), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [12070] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6508), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6510), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [12139] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6512), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6514), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [12208] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1931), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(1929), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [12277] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6278), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6280), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [12346] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6516), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6518), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [12415] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6520), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6522), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [12484] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(4045), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [12553] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6524), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6526), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [12622] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(4045), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [12691] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5796), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5798), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [12760] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(4045), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [12829] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6528), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6530), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [12898] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(4045), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [12967] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6532), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6534), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [13036] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1947), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(1945), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [13105] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3832), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(3824), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [13174] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4999), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(2202), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [13243] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5779), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5781), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [13312] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(4045), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [13381] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6536), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6538), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [13450] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6540), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6542), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [13519] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5523), 1,
      anon_sym_LBRACE,
    ACTIONS(6373), 1,
      anon_sym_COLON,
    ACTIONS(6375), 1,
      anon_sym___attribute__,
    STATE(2269), 1,
      sym_attribute_specifier,
    STATE(2301), 1,
      sym__enum_base_clause,
    STATE(2322), 1,
      sym_enumerator_list,
    ACTIONS(5689), 7,
      anon_sym_AMP,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym___inline,
      anon_sym_const,
      anon_sym_line,
      anon_sym_triangle,
    ACTIONS(5691), 48,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_out,
      anon_sym_inout,
      anon_sym_extern,
      anon_sym_LBRACK_LBRACK,
      anon_sym___declspec,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      sym_virtual,
      anon_sym_precise,
      anon_sym_shared,
      anon_sym_groupshared,
      anon_sym_uniform,
      anon_sym_row_major,
      anon_sym_column_major,
      anon_sym_globallycoherent,
      anon_sym_centroid,
      anon_sym_noperspective,
      anon_sym_nointerpolation,
      anon_sym_sample,
      anon_sym_linear,
      anon_sym_snorm,
      anon_sym_unorm,
      anon_sym_point,
      anon_sym_triangleadj,
      anon_sym_lineadj,
  [13600] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4063), 1,
      anon_sym_LBRACK,
    ACTIONS(4060), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(1961), 4,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
    ACTIONS(1959), 54,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym_in,
      anon_sym_out,
      anon_sym_inout,
      anon_sym_extern,
      anon_sym___attribute__,
      anon_sym___declspec,
      anon_sym___based,
      anon_sym_static,
      anon_sym_register,
      anon_sym_inline,
      anon_sym___inline,
      anon_sym___inline__,
      anon_sym___forceinline,
      anon_sym_thread_local,
      anon_sym___thread,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      sym_virtual,
      anon_sym_operator,
      anon_sym_precise,
      anon_sym_shared,
      anon_sym_groupshared,
      anon_sym_uniform,
      anon_sym_row_major,
      anon_sym_column_major,
      anon_sym_globallycoherent,
      anon_sym_centroid,
      anon_sym_noperspective,
      anon_sym_nointerpolation,
      anon_sym_sample,
      anon_sym_linear,
      anon_sym_snorm,
      anon_sym_unorm,
      anon_sym_point,
      anon_sym_line,
      anon_sym_triangleadj,
      anon_sym_lineadj,
      anon_sym_triangle,
  [13673] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6544), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6546), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [13742] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5168), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5170), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [13811] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6439), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6441), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [13880] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5775), 24,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5777), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
  [13948] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6548), 1,
      sym_identifier,
    STATE(2856), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(6551), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(6554), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5651), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5649), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [14024] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6557), 1,
      anon_sym_LT,
    STATE(2884), 1,
      sym_template_argument_list,
    ACTIONS(1933), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1935), 38,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
  [14098] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6284), 1,
      anon_sym___attribute__,
    ACTIONS(6560), 1,
      anon_sym_LBRACE,
    STATE(2887), 1,
      sym_enumerator_list,
    STATE(3014), 1,
      sym_attribute_specifier,
    ACTIONS(5519), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5521), 44,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [14174] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5771), 24,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5773), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
  [14242] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2872), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6562), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5381), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5383), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [14314] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2873), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6564), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5367), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5369), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [14386] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2866), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6566), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5353), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5355), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [14458] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6568), 1,
      anon_sym_LT,
    STATE(2924), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2938), 1,
      sym_template_argument_list,
    ACTIONS(6447), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(3822), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(3830), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [14536] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6284), 1,
      anon_sym___attribute__,
    ACTIONS(6560), 1,
      anon_sym_LBRACE,
    STATE(2894), 1,
      sym_enumerator_list,
    STATE(2997), 1,
      sym_attribute_specifier,
    ACTIONS(5529), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5531), 44,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [14612] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5796), 24,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5798), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
  [14680] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2716), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6570), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5373), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5375), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [14752] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6363), 1,
      anon_sym_LT,
    STATE(2884), 1,
      sym_template_argument_list,
    ACTIONS(1941), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1943), 38,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
  [14826] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6572), 1,
      sym_identifier,
    STATE(2870), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(3858), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(3860), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5663), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5661), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [14902] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5779), 24,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5781), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
  [14970] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6574), 1,
      sym_identifier,
    STATE(2856), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(3858), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(3860), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5669), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5667), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [15046] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2716), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6570), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5347), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5349), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [15118] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2716), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6570), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5377), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5379), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [15190] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2716), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6570), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5387), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5389), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [15262] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1899), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(1901), 46,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [15329] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1887), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(1889), 46,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [15396] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6284), 1,
      anon_sym___attribute__,
    STATE(2999), 1,
      sym_attribute_specifier,
    ACTIONS(5599), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5601), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [15467] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1953), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(1955), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [15536] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1903), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(1905), 46,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [15603] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5775), 23,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_literal_suffix,
    ACTIONS(5777), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
  [15670] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6284), 1,
      anon_sym___attribute__,
    STATE(3003), 1,
      sym_attribute_specifier,
    ACTIONS(5583), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5585), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [15741] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1925), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(1927), 46,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [15808] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1953), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(1955), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [15877] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1969), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1971), 38,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
  [15946] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1959), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1961), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
  [16013] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2904), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5224), 2,
      sym_primitive_type,
      sym_identifier,
    ACTIONS(6576), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5312), 25,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5315), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [16086] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6284), 1,
      anon_sym___attribute__,
    STATE(2971), 1,
      sym_attribute_specifier,
    ACTIONS(5606), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5608), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [16157] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6284), 1,
      anon_sym___attribute__,
    STATE(3001), 1,
      sym_attribute_specifier,
    ACTIONS(5579), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5581), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [16228] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6568), 1,
      anon_sym_LT,
    STATE(2938), 1,
      sym_template_argument_list,
    ACTIONS(1941), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(1943), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
  [16301] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6284), 1,
      anon_sym___attribute__,
    STATE(2959), 1,
      sym_attribute_specifier,
    ACTIONS(5567), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5569), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [16372] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1895), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(1897), 46,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [16439] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1949), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1951), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
  [16506] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1969), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(1971), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [16575] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1949), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(1951), 46,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [16642] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6284), 1,
      anon_sym___attribute__,
    STATE(2972), 1,
      sym_attribute_specifier,
    ACTIONS(5587), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5589), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [16713] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1959), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(1961), 46,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [16780] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2825), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6579), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5377), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5379), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [16851] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6581), 1,
      sym_identifier,
    ACTIONS(6585), 1,
      sym_primitive_type,
    STATE(2885), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6583), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5338), 25,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5336), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [16926] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2900), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6587), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5367), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5369), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [16997] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6589), 1,
      anon_sym_LT,
    STATE(2938), 1,
      sym_template_argument_list,
    ACTIONS(1933), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(1935), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
  [17070] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2825), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6579), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5387), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5389), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [17141] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6284), 1,
      anon_sym___attribute__,
    STATE(2957), 1,
      sym_attribute_specifier,
    ACTIONS(5614), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5616), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [17212] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1953), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1955), 38,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
  [17281] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2825), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6579), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5373), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5375), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [17352] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2904), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6576), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5224), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      sym_primitive_type,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5226), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [17423] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6284), 1,
      anon_sym___attribute__,
    STATE(2965), 1,
      sym_attribute_specifier,
    ACTIONS(5595), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5597), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [17494] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5779), 23,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_literal_suffix,
    ACTIONS(5781), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
  [17561] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6284), 1,
      anon_sym___attribute__,
    STATE(2974), 1,
      sym_attribute_specifier,
    ACTIONS(5571), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5573), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [17632] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(6592), 1,
      anon_sym___attribute__,
    ACTIONS(6594), 1,
      anon_sym_LBRACE,
    STATE(3243), 1,
      sym_field_declaration_list,
    STATE(3623), 1,
      sym_attribute_specifier,
    STATE(6963), 1,
      sym_virtual_specifier,
    STATE(7716), 1,
      sym_base_class_clause,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(5327), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5329), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [17715] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1953), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1955), 38,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
  [17784] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3934), 1,
      anon_sym_LPAREN2,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5893), 1,
      anon_sym_STAR,
    ACTIONS(5895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5897), 1,
      anon_sym_AMP,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5903), 1,
      anon_sym_LBRACK,
    ACTIONS(6598), 1,
      anon_sym_COLON,
    STATE(3363), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5983), 1,
      sym__declarator,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6448), 1,
      sym__abstract_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(6596), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_EQ,
      anon_sym_GT2,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [17901] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6284), 1,
      anon_sym___attribute__,
    STATE(3010), 1,
      sym_attribute_specifier,
    ACTIONS(5575), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5577), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [17972] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6319), 1,
      anon_sym___attribute__,
    ACTIONS(6600), 1,
      anon_sym_COLON,
    ACTIONS(6602), 1,
      anon_sym_LBRACE,
    STATE(2988), 1,
      sym__enum_base_clause,
    STATE(3070), 1,
      sym_enumerator_list,
    STATE(3206), 1,
      sym_attribute_specifier,
    ACTIONS(5636), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5638), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [18051] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3934), 1,
      anon_sym_LPAREN2,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5893), 1,
      anon_sym_STAR,
    ACTIONS(5895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5897), 1,
      anon_sym_AMP,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5903), 1,
      anon_sym_LBRACK,
    ACTIONS(5907), 1,
      anon_sym_COLON,
    STATE(3363), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5886), 1,
      sym__declarator,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6445), 1,
      sym__abstract_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(5905), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_EQ,
      anon_sym_GT2,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [18168] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6284), 1,
      anon_sym___attribute__,
    STATE(2977), 1,
      sym_attribute_specifier,
    ACTIONS(5591), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5593), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [18239] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1917), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(1919), 46,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [18306] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6319), 1,
      anon_sym___attribute__,
    ACTIONS(6600), 1,
      anon_sym_COLON,
    ACTIONS(6602), 1,
      anon_sym_LBRACE,
    STATE(3020), 1,
      sym__enum_base_clause,
    STATE(3055), 1,
      sym_enumerator_list,
    STATE(3186), 1,
      sym_attribute_specifier,
    ACTIONS(5689), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5691), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [18385] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5796), 23,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_literal_suffix,
    ACTIONS(5798), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
  [18452] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5771), 23,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_literal_suffix,
    ACTIONS(5773), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
      anon_sym_DASH_GT_STAR,
  [18519] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2866), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6566), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5318), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5320), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [18590] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    STATE(2390), 1,
      sym_template_argument_list,
    STATE(2955), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6604), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5294), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5296), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [18665] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2903), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6606), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5353), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5355), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [18736] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2896), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6608), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5381), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5383), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [18807] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1891), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(1893), 46,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [18874] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2825), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6579), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5347), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5349), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [18945] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6284), 1,
      anon_sym___attribute__,
    STATE(2953), 1,
      sym_attribute_specifier,
    ACTIONS(5610), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5612), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [19016] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6610), 1,
      anon_sym_LT,
    STATE(2955), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3030), 1,
      sym_template_argument_list,
    ACTIONS(6604), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(3822), 15,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3830), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [19092] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6612), 1,
      anon_sym_LT,
    STATE(3029), 1,
      sym_template_argument_list,
    ACTIONS(1935), 27,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(1933), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [19164] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6423), 1,
      anon_sym___attribute__,
    ACTIONS(6614), 1,
      anon_sym_COLON,
    ACTIONS(6616), 1,
      anon_sym_LBRACE,
    STATE(3048), 1,
      sym__enum_base_clause,
    STATE(3149), 1,
      sym_enumerator_list,
    STATE(3342), 1,
      sym_attribute_specifier,
    ACTIONS(5636), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5638), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [19242] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5391), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5393), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym___extension__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [19308] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3627), 1,
      anon_sym_LBRACE,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6620), 1,
      anon_sym_LBRACK,
    ACTIONS(6622), 1,
      sym_auto,
    ACTIONS(6624), 1,
      anon_sym_decltype,
    STATE(3184), 1,
      sym_new_declarator,
    STATE(3198), 1,
      sym_decltype_auto,
    STATE(3562), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5868), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5870), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [19390] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1953), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(1955), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
  [19458] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1953), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1955), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
  [19524] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3627), 1,
      anon_sym_LBRACE,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6620), 1,
      anon_sym_LBRACK,
    ACTIONS(6622), 1,
      sym_auto,
    ACTIONS(6624), 1,
      anon_sym_decltype,
    STATE(3198), 1,
      sym_decltype_auto,
    STATE(3200), 1,
      sym_new_declarator,
    STATE(3639), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5872), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5874), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [19606] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2260), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(2262), 46,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [19672] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6626), 1,
      sym_auto,
    ACTIONS(6628), 1,
      anon_sym_decltype,
    STATE(2994), 1,
      sym_decltype_auto,
    ACTIONS(5413), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5415), 43,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [19744] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5475), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5477), 46,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [19810] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5318), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5320), 44,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [19878] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1959), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(1961), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
  [19944] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1949), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(1951), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
  [20010] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2903), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6606), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5318), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5320), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [20080] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1953), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(1955), 46,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [20146] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1969), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(1971), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
  [20214] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5353), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5355), 46,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [20280] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5451), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5453), 46,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [20346] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6612), 1,
      anon_sym_LT,
    STATE(3029), 1,
      sym_template_argument_list,
    ACTIONS(1943), 27,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(1941), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [20418] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2142), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(2144), 46,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [20484] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1953), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(1955), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
  [20552] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6423), 1,
      anon_sym___attribute__,
    ACTIONS(6614), 1,
      anon_sym_COLON,
    ACTIONS(6616), 1,
      anon_sym_LBRACE,
    STATE(3085), 1,
      sym__enum_base_clause,
    STATE(3090), 1,
      sym_enumerator_list,
    STATE(3239), 1,
      sym_attribute_specifier,
    ACTIONS(5689), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5691), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [20630] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3627), 1,
      anon_sym_LBRACE,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6620), 1,
      anon_sym_LBRACK,
    ACTIONS(6622), 1,
      sym_auto,
    ACTIONS(6624), 1,
      anon_sym_decltype,
    STATE(3198), 1,
      sym_decltype_auto,
    STATE(3218), 1,
      sym_new_declarator,
    STATE(3487), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5850), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5852), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [20712] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3627), 1,
      anon_sym_LBRACE,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6620), 1,
      anon_sym_LBRACK,
    ACTIONS(6622), 1,
      sym_auto,
    ACTIONS(6624), 1,
      anon_sym_decltype,
    STATE(3175), 1,
      sym_new_declarator,
    STATE(3198), 1,
      sym_decltype_auto,
    STATE(3603), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5862), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5864), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [20794] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5497), 46,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [20860] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3934), 1,
      anon_sym_LPAREN2,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5903), 1,
      anon_sym_LBRACK,
    ACTIONS(6006), 1,
      anon_sym_STAR,
    ACTIONS(6008), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6010), 1,
      anon_sym_AMP,
    ACTIONS(6598), 1,
      anon_sym_COLON,
    STATE(3679), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5983), 1,
      sym__declarator,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6571), 1,
      sym__abstract_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6596), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [20975] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5443), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5445), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [21040] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6632), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(6640), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6642), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6654), 1,
      anon_sym_GT_EQ,
    ACTIONS(6658), 1,
      anon_sym_QMARK,
    ACTIONS(6660), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6662), 1,
      anon_sym_or,
    ACTIONS(6664), 1,
      anon_sym_and,
    ACTIONS(6666), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6636), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6644), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(6646), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6648), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(6650), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6656), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6638), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6652), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6630), 6,
      aux_sym_preproc_elif_token1,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      sym_identifier,
    ACTIONS(6634), 15,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [21153] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2904), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6668), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5347), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5349), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [21222] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6632), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(6640), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6642), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6654), 1,
      anon_sym_GT_EQ,
    ACTIONS(6658), 1,
      anon_sym_QMARK,
    ACTIONS(6660), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6662), 1,
      anon_sym_or,
    ACTIONS(6664), 1,
      anon_sym_and,
    ACTIONS(6666), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6636), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6644), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(6646), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6648), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(6650), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6656), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6638), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6652), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6670), 6,
      aux_sym_preproc_elif_token1,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      sym_identifier,
    ACTIONS(6672), 15,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [21335] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5491), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5493), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [21400] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6636), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6656), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6638), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6294), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
  [21485] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5431), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5433), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [21550] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5525), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5527), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [21615] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1953), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(1955), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_COLON,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
  [21680] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5419), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5421), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [21745] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5467), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5469), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [21810] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2968), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6674), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5381), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5383), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [21879] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5463), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5465), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [21944] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6636), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6638), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6294), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
  [22027] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6638), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6294), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
  [22108] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2904), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6668), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5377), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5379), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [22177] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3019), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6676), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5367), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5369), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [22246] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3934), 1,
      anon_sym_LPAREN2,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5903), 1,
      anon_sym_LBRACK,
    ACTIONS(5907), 1,
      anon_sym_COLON,
    ACTIONS(6006), 1,
      anon_sym_STAR,
    ACTIONS(6008), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6010), 1,
      anon_sym_AMP,
    STATE(3679), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5886), 1,
      sym__declarator,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6594), 1,
      sym__abstract_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(5905), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [22361] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5549), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5551), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [22426] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5507), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5509), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [22491] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3675), 1,
      anon_sym_LBRACE,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(6680), 1,
      anon_sym_LBRACK,
    ACTIONS(6682), 1,
      sym_auto,
    ACTIONS(6684), 1,
      anon_sym_decltype,
    STATE(3292), 1,
      sym_decltype_auto,
    STATE(3321), 1,
      sym_new_declarator,
    STATE(3706), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5868), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5870), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [22572] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5487), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5489), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [22637] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2996), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6686), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5353), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5355), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [22706] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3675), 1,
      anon_sym_LBRACE,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(6680), 1,
      anon_sym_LBRACK,
    ACTIONS(6682), 1,
      sym_auto,
    ACTIONS(6684), 1,
      anon_sym_decltype,
    STATE(3292), 1,
      sym_decltype_auto,
    STATE(3304), 1,
      sym_new_declarator,
    STATE(3683), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5850), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5852), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [22787] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5503), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5505), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [22852] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3934), 1,
      anon_sym_LPAREN2,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5903), 1,
      anon_sym_LBRACK,
    ACTIONS(6031), 1,
      anon_sym_STAR,
    ACTIONS(6033), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6035), 1,
      anon_sym_AMP,
    ACTIONS(6598), 1,
      anon_sym_COLON,
    STATE(3745), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5983), 1,
      sym__declarator,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6576), 1,
      sym__abstract_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6596), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [22967] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5775), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5777), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [23032] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5515), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5517), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [23097] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5318), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5320), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [23162] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6610), 1,
      anon_sym_LT,
    STATE(3030), 1,
      sym_template_argument_list,
    ACTIONS(1941), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1943), 38,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
  [23233] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5499), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5501), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [23298] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5133), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5135), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [23363] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3934), 1,
      anon_sym_LPAREN2,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5903), 1,
      anon_sym_LBRACK,
    ACTIONS(5907), 1,
      anon_sym_COLON,
    ACTIONS(6031), 1,
      anon_sym_STAR,
    ACTIONS(6033), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6035), 1,
      anon_sym_AMP,
    STATE(3745), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5886), 1,
      sym__declarator,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6598), 1,
      sym__abstract_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(5905), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [23478] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6640), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6642), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6654), 1,
      anon_sym_GT_EQ,
    ACTIONS(6660), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6662), 1,
      anon_sym_or,
    ACTIONS(6664), 1,
      anon_sym_and,
    ACTIONS(6666), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6636), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6644), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(6646), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6648), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(6650), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6656), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6638), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6652), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6688), 6,
      aux_sym_preproc_elif_token1,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      sym_identifier,
    ACTIONS(6690), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [23587] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6632), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(6640), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6642), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6654), 1,
      anon_sym_GT_EQ,
    ACTIONS(6658), 1,
      anon_sym_QMARK,
    ACTIONS(6660), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6662), 1,
      anon_sym_or,
    ACTIONS(6664), 1,
      anon_sym_and,
    ACTIONS(6666), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6636), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6644), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(6646), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6648), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(6650), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6656), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6638), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6652), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6496), 6,
      aux_sym_preproc_elif_token1,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      sym_identifier,
    ACTIONS(6498), 15,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [23700] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6319), 1,
      anon_sym___attribute__,
    ACTIONS(6602), 1,
      anon_sym_LBRACE,
    STATE(3052), 1,
      sym_enumerator_list,
    STATE(3179), 1,
      sym_attribute_specifier,
    ACTIONS(5519), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5521), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [23773] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5423), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5425), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [23838] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5796), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5798), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [23903] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5459), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5461), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [23968] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5525), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5527), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [24033] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6692), 1,
      anon_sym_LT,
    STATE(3030), 1,
      sym_template_argument_list,
    ACTIONS(1933), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1935), 38,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
  [24104] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5439), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5441), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [24169] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5771), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5773), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [24234] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2904), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6668), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5373), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5375), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [24303] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5511), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5513), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [24368] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5471), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5473), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [24433] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5483), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5485), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [24498] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6640), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6642), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6654), 1,
      anon_sym_GT_EQ,
    ACTIONS(6660), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6662), 1,
      anon_sym_or,
    ACTIONS(6664), 1,
      anon_sym_and,
    ACTIONS(6666), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6636), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6644), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(6646), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6648), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(6650), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6656), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6638), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6652), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6695), 6,
      aux_sym_preproc_elif_token1,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      sym_identifier,
    ACTIONS(6697), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [24607] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5537), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5539), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [24672] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3675), 1,
      anon_sym_LBRACE,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(6680), 1,
      anon_sym_LBRACK,
    ACTIONS(6682), 1,
      sym_auto,
    ACTIONS(6684), 1,
      anon_sym_decltype,
    STATE(3292), 1,
      sym_decltype_auto,
    STATE(3332), 1,
      sym_new_declarator,
    STATE(3726), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5862), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5864), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [24753] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5533), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5535), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [24818] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5779), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5781), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [24883] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6640), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6642), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6654), 1,
      anon_sym_GT_EQ,
    ACTIONS(6660), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6662), 1,
      anon_sym_or,
    ACTIONS(6664), 1,
      anon_sym_and,
    ACTIONS(6666), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6636), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6644), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(6646), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6648), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(6650), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6656), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6638), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6652), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6699), 6,
      aux_sym_preproc_elif_token1,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      sym_identifier,
    ACTIONS(6701), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [24992] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5467), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5469), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [25057] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6660), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6636), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6656), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6638), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6294), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [25144] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5427), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5429), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [25209] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5467), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5469), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [25274] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5545), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5547), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [25339] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5318), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5320), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [25404] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5455), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5457), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [25469] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6654), 1,
      anon_sym_GT_EQ,
    ACTIONS(6660), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6636), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6656), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6638), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6652), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 15,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6294), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [25560] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5447), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5449), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [25625] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6654), 1,
      anon_sym_GT_EQ,
    ACTIONS(6660), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6666), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6636), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6650), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6656), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6638), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6652), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 14,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      sym_identifier,
    ACTIONS(6294), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [25720] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6654), 1,
      anon_sym_GT_EQ,
    ACTIONS(6660), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6666), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6636), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6648), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(6650), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6656), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6638), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6652), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 12,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      sym_identifier,
    ACTIONS(6294), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [25817] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6640), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6642), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6654), 1,
      anon_sym_GT_EQ,
    ACTIONS(6660), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6662), 1,
      anon_sym_or,
    ACTIONS(6664), 1,
      anon_sym_and,
    ACTIONS(6666), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6636), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6644), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(6646), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6648), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(6650), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6656), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6638), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6652), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6703), 6,
      aux_sym_preproc_elif_token1,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      sym_identifier,
    ACTIONS(6705), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [25926] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6642), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6654), 1,
      anon_sym_GT_EQ,
    ACTIONS(6660), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6664), 1,
      anon_sym_and,
    ACTIONS(6666), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6636), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6644), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(6646), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6648), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(6650), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6656), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6638), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6652), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 7,
      aux_sym_preproc_elif_token1,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      sym_identifier,
    ACTIONS(6294), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [26031] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2904), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6668), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5387), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5389), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [26100] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6319), 1,
      anon_sym___attribute__,
    ACTIONS(6602), 1,
      anon_sym_LBRACE,
    STATE(3079), 1,
      sym_enumerator_list,
    STATE(3225), 1,
      sym_attribute_specifier,
    ACTIONS(5529), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5531), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [26173] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6654), 1,
      anon_sym_GT_EQ,
    ACTIONS(6660), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6666), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6636), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6646), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6648), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(6650), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6656), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6638), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6652), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 10,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      sym_identifier,
    ACTIONS(6294), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [26272] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5541), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5543), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [26337] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3675), 1,
      anon_sym_LBRACE,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(6680), 1,
      anon_sym_LBRACK,
    ACTIONS(6682), 1,
      sym_auto,
    ACTIONS(6684), 1,
      anon_sym_decltype,
    STATE(3292), 1,
      sym_decltype_auto,
    STATE(3341), 1,
      sym_new_declarator,
    STATE(3705), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5872), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5874), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [26418] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5479), 12,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_const,
      anon_sym_DOT,
    ACTIONS(5481), 45,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [26483] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6654), 1,
      anon_sym_GT_EQ,
    ACTIONS(6660), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6666), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6636), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6644), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(6646), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6648), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(6650), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6656), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6638), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6652), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 8,
      aux_sym_preproc_elif_token1,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      sym_identifier,
    ACTIONS(6294), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
  [26584] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1969), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1971), 38,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
  [26650] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1887), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
    ACTIONS(1889), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [26714] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1895), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1897), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
  [26778] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1959), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
    ACTIONS(1961), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [26842] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1959), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1961), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
  [26906] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1949), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1951), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
  [26970] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1971), 27,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(1969), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [27036] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6707), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
    ACTIONS(6709), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [27100] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6592), 1,
      anon_sym___attribute__,
    ACTIONS(6711), 1,
      anon_sym_COLON,
    ACTIONS(6713), 1,
      anon_sym_LBRACE,
    STATE(3171), 1,
      sym__enum_base_clause,
    STATE(3336), 1,
      sym_enumerator_list,
    STATE(3567), 1,
      sym_attribute_specifier,
    ACTIONS(5689), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5691), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [27176] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1961), 2,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
    ACTIONS(4063), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4058), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [27242] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6319), 1,
      anon_sym___attribute__,
    STATE(3205), 1,
      sym_attribute_specifier,
    ACTIONS(5614), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5616), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [27310] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6715), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
    ACTIONS(6717), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [27374] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6319), 1,
      anon_sym___attribute__,
    STATE(3209), 1,
      sym_attribute_specifier,
    ACTIONS(5599), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5601), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [27442] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1903), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1905), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
  [27506] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6319), 1,
      anon_sym___attribute__,
    STATE(3197), 1,
      sym_attribute_specifier,
    ACTIONS(5567), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5569), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [27574] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1953), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
    ACTIONS(1955), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [27638] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6319), 1,
      anon_sym___attribute__,
    STATE(3232), 1,
      sym_attribute_specifier,
    ACTIONS(5575), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5577), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [27706] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1899), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1901), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
  [27770] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6319), 1,
      anon_sym___attribute__,
    STATE(3233), 1,
      sym_attribute_specifier,
    ACTIONS(5571), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5573), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [27838] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2288), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
    ACTIONS(2290), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [27902] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6367), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_RBRACK_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6365), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_primitive_type,
      anon_sym_enum,
      anon_sym_class,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
  [27966] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6719), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
    ACTIONS(6721), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [28030] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6423), 1,
      anon_sym___attribute__,
    ACTIONS(6616), 1,
      anon_sym_LBRACE,
    STATE(3103), 1,
      sym_enumerator_list,
    STATE(3258), 1,
      sym_attribute_specifier,
    ACTIONS(5519), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5521), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [28102] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1925), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1927), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
  [28166] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6486), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_RBRACK_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6484), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_primitive_type,
      anon_sym_enum,
      anon_sym_class,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
  [28230] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1891), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1893), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
  [28294] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6319), 1,
      anon_sym___attribute__,
    STATE(3226), 1,
      sym_attribute_specifier,
    ACTIONS(5579), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5581), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [28362] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1887), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1889), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
  [28426] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1917), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1919), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
  [28490] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6319), 1,
      anon_sym___attribute__,
    STATE(3224), 1,
      sym_attribute_specifier,
    ACTIONS(5591), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5593), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [28558] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6339), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6341), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_try,
  [28622] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6353), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_RBRACK_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6351), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_primitive_type,
      anon_sym_enum,
      anon_sym_class,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
  [28686] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6723), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
    ACTIONS(6725), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [28750] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5836), 1,
      sym_literal_suffix,
    ACTIONS(5838), 26,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5840), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [28816] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1917), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
    ACTIONS(1919), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [28880] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5836), 1,
      sym_literal_suffix,
    ACTIONS(3832), 26,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(3824), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [28946] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1891), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
    ACTIONS(1893), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [29010] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4045), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_try,
  [29074] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4045), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_try,
  [29138] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4045), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_try,
  [29202] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1953), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1955), 38,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
  [29268] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1953), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1955), 38,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
  [29334] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6319), 1,
      anon_sym___attribute__,
    STATE(3187), 1,
      sym_attribute_specifier,
    ACTIONS(5595), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5597), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [29402] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1925), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
    ACTIONS(1927), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [29466] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6319), 1,
      anon_sym___attribute__,
    STATE(3180), 1,
      sym_attribute_specifier,
    ACTIONS(5610), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5612), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [29534] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6319), 1,
      anon_sym___attribute__,
    STATE(3170), 1,
      sym_attribute_specifier,
    ACTIONS(5583), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5585), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [29602] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4045), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_try,
  [29666] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6319), 1,
      anon_sym___attribute__,
    STATE(3168), 1,
      sym_attribute_specifier,
    ACTIONS(5606), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5608), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [29734] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1955), 27,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(1953), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [29800] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1955), 27,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(1953), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [29866] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4045), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_try,
  [29930] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6727), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
    ACTIONS(6729), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [29994] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4045), 37,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_try,
  [30058] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6319), 1,
      anon_sym___attribute__,
    STATE(3199), 1,
      sym_attribute_specifier,
    ACTIONS(5587), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5589), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [30126] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6592), 1,
      anon_sym___attribute__,
    ACTIONS(6711), 1,
      anon_sym_COLON,
    ACTIONS(6713), 1,
      anon_sym_LBRACE,
    STATE(3229), 1,
      sym__enum_base_clause,
    STATE(3244), 1,
      sym_enumerator_list,
    STATE(3491), 1,
      sym_attribute_specifier,
    ACTIONS(5636), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5638), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [30202] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6731), 27,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6733), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [30266] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6490), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_RBRACK_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6488), 30,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_primitive_type,
      anon_sym_enum,
      anon_sym_class,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
  [30330] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2996), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6686), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5318), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5320), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [30398] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2182), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
    ACTIONS(2184), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [30462] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6423), 1,
      anon_sym___attribute__,
    ACTIONS(6616), 1,
      anon_sym_LBRACE,
    STATE(3134), 1,
      sym_enumerator_list,
    STATE(3298), 1,
      sym_attribute_specifier,
    ACTIONS(5529), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5531), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [30534] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1895), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
    ACTIONS(1897), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [30598] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1899), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
    ACTIONS(1901), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [30662] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1949), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
    ACTIONS(1951), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [30726] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1903), 28,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
    ACTIONS(1905), 28,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [30790] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6423), 1,
      anon_sym___attribute__,
    STATE(3297), 1,
      sym_attribute_specifier,
    ACTIONS(5591), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5593), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [30857] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6735), 1,
      anon_sym_LPAREN2,
    ACTIONS(6737), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6739), 1,
      anon_sym_LBRACK,
    STATE(3429), 1,
      sym_parameter_list,
    STATE(3201), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6000), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6002), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [30930] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6735), 1,
      anon_sym_LPAREN2,
    ACTIONS(6737), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6739), 1,
      anon_sym_LBRACK,
    STATE(3429), 1,
      sym_parameter_list,
    STATE(3201), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(5996), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5998), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [31003] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6731), 25,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6733), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [31066] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5803), 4,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
    ACTIONS(5805), 10,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
    ACTIONS(3824), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(3832), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
  [31133] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6423), 1,
      anon_sym___attribute__,
    STATE(3279), 1,
      sym_attribute_specifier,
    ACTIONS(5606), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5608), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [31200] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6423), 1,
      anon_sym___attribute__,
    STATE(3347), 1,
      sym_attribute_specifier,
    ACTIONS(5614), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5616), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [31267] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3741), 1,
      anon_sym_LBRACE,
    ACTIONS(6741), 1,
      anon_sym_LPAREN2,
    ACTIONS(6743), 1,
      anon_sym_LBRACK,
    ACTIONS(6745), 1,
      sym_auto,
    ACTIONS(6747), 1,
      anon_sym_decltype,
    STATE(3554), 1,
      sym_new_declarator,
    STATE(3619), 1,
      sym_decltype_auto,
    STATE(3976), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5862), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5864), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [31346] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6423), 1,
      anon_sym___attribute__,
    STATE(3324), 1,
      sym_attribute_specifier,
    ACTIONS(5599), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5601), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [31413] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6749), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [31492] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3934), 1,
      anon_sym_LPAREN2,
    ACTIONS(3936), 1,
      anon_sym_STAR,
    ACTIONS(3938), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3940), 1,
      anon_sym_AMP,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(5903), 1,
      anon_sym_LBRACK,
    ACTIONS(6213), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6596), 1,
      anon_sym_RPAREN,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5718), 1,
      sym__scope_resolution,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6345), 1,
      sym__declarator,
    STATE(6615), 1,
      sym__abstract_declarator,
    STATE(8582), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [31603] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3934), 1,
      anon_sym_LPAREN2,
    ACTIONS(3936), 1,
      anon_sym_STAR,
    ACTIONS(3938), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3940), 1,
      anon_sym_AMP,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(5903), 1,
      anon_sym_LBRACK,
    ACTIONS(5905), 1,
      anon_sym_RPAREN,
    ACTIONS(6213), 1,
      anon_sym_COLON_COLON,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5718), 1,
      sym__scope_resolution,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6310), 1,
      sym__declarator,
    STATE(6577), 1,
      sym__abstract_declarator,
    STATE(8582), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [31714] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1953), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1955), 39,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_DASH_GT_STAR,
  [31777] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6423), 1,
      anon_sym___attribute__,
    STATE(3301), 1,
      sym_attribute_specifier,
    ACTIONS(5579), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5581), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [31844] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3741), 1,
      anon_sym_LBRACE,
    ACTIONS(6741), 1,
      anon_sym_LPAREN2,
    ACTIONS(6743), 1,
      anon_sym_LBRACK,
    ACTIONS(6745), 1,
      sym_auto,
    ACTIONS(6747), 1,
      anon_sym_decltype,
    STATE(3604), 1,
      sym_new_declarator,
    STATE(3619), 1,
      sym_decltype_auto,
    STATE(3890), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5868), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5870), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [31923] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6423), 1,
      anon_sym___attribute__,
    STATE(3309), 1,
      sym_attribute_specifier,
    ACTIONS(5575), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5577), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [31990] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6496), 1,
      anon_sym_EQ,
    ACTIONS(6632), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(6753), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6755), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6757), 1,
      anon_sym_PIPE,
    ACTIONS(6761), 1,
      anon_sym_AMP,
    ACTIONS(6767), 1,
      anon_sym_GT_EQ,
    ACTIONS(6771), 1,
      anon_sym_QMARK,
    ACTIONS(6773), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6775), 1,
      anon_sym_or,
    ACTIONS(6777), 1,
      anon_sym_and,
    ACTIONS(6779), 1,
      anon_sym_bitor,
    ACTIONS(6781), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6751), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6759), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6769), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6749), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6763), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(6765), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6498), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [32103] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5497), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [32166] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5475), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5477), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [32229] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6757), 1,
      anon_sym_PIPE,
    ACTIONS(6761), 1,
      anon_sym_AMP,
    ACTIONS(6767), 1,
      anon_sym_GT_EQ,
    ACTIONS(6773), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6779), 1,
      anon_sym_bitor,
    ACTIONS(6781), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6751), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6759), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6769), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6292), 3,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
    ACTIONS(6749), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6763), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(6765), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [32330] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6761), 1,
      anon_sym_AMP,
    ACTIONS(6767), 1,
      anon_sym_GT_EQ,
    ACTIONS(6773), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6781), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6751), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6759), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6769), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6749), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6763), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(6765), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 4,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
    ACTIONS(6294), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
  [32427] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6761), 1,
      anon_sym_AMP,
    ACTIONS(6767), 1,
      anon_sym_GT_EQ,
    ACTIONS(6773), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6781), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6751), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6769), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6749), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6763), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(6765), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 6,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
  [32522] = 52,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6783), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(6785), 1,
      anon_sym_COMMA,
    ACTIONS(6787), 1,
      anon_sym_RPAREN,
    ACTIONS(6789), 1,
      anon_sym_DASH,
    ACTIONS(6791), 1,
      anon_sym_PLUS,
    ACTIONS(6793), 1,
      anon_sym_STAR,
    ACTIONS(6795), 1,
      anon_sym_SLASH,
    ACTIONS(6797), 1,
      anon_sym_PERCENT,
    ACTIONS(6799), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6801), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6803), 1,
      anon_sym_PIPE,
    ACTIONS(6805), 1,
      anon_sym_CARET,
    ACTIONS(6807), 1,
      anon_sym_AMP,
    ACTIONS(6809), 1,
      anon_sym_EQ_EQ,
    ACTIONS(6811), 1,
      anon_sym_BANG_EQ,
    ACTIONS(6813), 1,
      anon_sym_GT,
    ACTIONS(6815), 1,
      anon_sym_GT_EQ,
    ACTIONS(6817), 1,
      anon_sym_LT_EQ,
    ACTIONS(6819), 1,
      anon_sym_LT,
    ACTIONS(6821), 1,
      anon_sym_LT_LT,
    ACTIONS(6823), 1,
      anon_sym_GT_GT,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6827), 1,
      anon_sym_EQ,
    ACTIONS(6829), 1,
      anon_sym_QMARK,
    ACTIONS(6831), 1,
      anon_sym_STAR_EQ,
    ACTIONS(6833), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(6835), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(6837), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(6839), 1,
      anon_sym_DASH_EQ,
    ACTIONS(6841), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(6843), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(6845), 1,
      anon_sym_AMP_EQ,
    ACTIONS(6847), 1,
      anon_sym_CARET_EQ,
    ACTIONS(6849), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(6853), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6855), 1,
      anon_sym_or,
    ACTIONS(6857), 1,
      anon_sym_and,
    ACTIONS(6859), 1,
      anon_sym_bitor,
    ACTIONS(6861), 1,
      anon_sym_xor,
    ACTIONS(6863), 1,
      anon_sym_bitand,
    ACTIONS(6865), 1,
      anon_sym_not_eq,
    ACTIONS(6871), 1,
      anon_sym_DOT_STAR,
    ACTIONS(6873), 1,
      anon_sym_DASH_GT_STAR,
    STATE(1683), 1,
      sym__binary_fold_operator,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    STATE(8023), 1,
      sym__fold_operator,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6851), 3,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [32683] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6767), 1,
      anon_sym_GT_EQ,
    ACTIONS(6773), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6751), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6769), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6749), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6763), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(6765), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
  [32774] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6767), 1,
      anon_sym_GT_EQ,
    ACTIONS(6773), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6751), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6769), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6749), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6765), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [32863] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6773), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6751), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6769), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6749), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 10,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [32948] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6751), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6749), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 12,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [33029] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6688), 1,
      anon_sym_EQ,
    ACTIONS(6753), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6755), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6757), 1,
      anon_sym_PIPE,
    ACTIONS(6761), 1,
      anon_sym_AMP,
    ACTIONS(6767), 1,
      anon_sym_GT_EQ,
    ACTIONS(6773), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6775), 1,
      anon_sym_or,
    ACTIONS(6777), 1,
      anon_sym_and,
    ACTIONS(6779), 1,
      anon_sym_bitor,
    ACTIONS(6781), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6751), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6759), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6769), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6749), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6763), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(6765), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6690), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [33138] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6423), 1,
      anon_sym___attribute__,
    STATE(3303), 1,
      sym_attribute_specifier,
    ACTIONS(5571), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5573), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [33205] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6751), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6769), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6749), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 10,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [33288] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5836), 1,
      sym_literal_suffix,
    ACTIONS(3832), 24,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(3824), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [33353] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5391), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5393), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [33416] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6885), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(6896), 1,
      anon_sym_DASH_GT,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(6905), 1,
      anon_sym_requires,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(4703), 1,
      sym__function_attributes_start,
    STATE(4909), 1,
      sym_ref_qualifier,
    STATE(5575), 1,
      sym__function_attributes_end,
    STATE(5676), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(6898), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4195), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4344), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5900), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5274), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(6875), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [33529] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6630), 1,
      anon_sym_EQ,
    ACTIONS(6632), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(6753), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6755), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6757), 1,
      anon_sym_PIPE,
    ACTIONS(6761), 1,
      anon_sym_AMP,
    ACTIONS(6767), 1,
      anon_sym_GT_EQ,
    ACTIONS(6771), 1,
      anon_sym_QMARK,
    ACTIONS(6773), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6775), 1,
      anon_sym_or,
    ACTIONS(6777), 1,
      anon_sym_and,
    ACTIONS(6779), 1,
      anon_sym_bitor,
    ACTIONS(6781), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6751), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6759), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6769), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6749), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6763), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(6765), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6634), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [33642] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6885), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(6896), 1,
      anon_sym_DASH_GT,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(6908), 1,
      anon_sym_requires,
    STATE(4670), 1,
      sym__function_attributes_start,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(4922), 1,
      sym_ref_qualifier,
    STATE(5570), 1,
      sym__function_attributes_end,
    STATE(5739), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(4195), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4344), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5900), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5245), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(6875), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [33755] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3741), 1,
      anon_sym_LBRACE,
    ACTIONS(6741), 1,
      anon_sym_LPAREN2,
    ACTIONS(6743), 1,
      anon_sym_LBRACK,
    ACTIONS(6745), 1,
      sym_auto,
    ACTIONS(6747), 1,
      anon_sym_decltype,
    STATE(3508), 1,
      sym_new_declarator,
    STATE(3619), 1,
      sym_decltype_auto,
    STATE(3948), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5872), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5874), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [33834] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6695), 1,
      anon_sym_EQ,
    ACTIONS(6753), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6755), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6757), 1,
      anon_sym_PIPE,
    ACTIONS(6761), 1,
      anon_sym_AMP,
    ACTIONS(6767), 1,
      anon_sym_GT_EQ,
    ACTIONS(6773), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6775), 1,
      anon_sym_or,
    ACTIONS(6777), 1,
      anon_sym_and,
    ACTIONS(6779), 1,
      anon_sym_bitor,
    ACTIONS(6781), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6751), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6759), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6769), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6749), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6763), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(6765), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6697), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [33943] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6735), 1,
      anon_sym_LPAREN2,
    ACTIONS(6737), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6739), 1,
      anon_sym_LBRACK,
    STATE(3429), 1,
      sym_parameter_list,
    STATE(3201), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(5980), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5982), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [34016] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6735), 1,
      anon_sym_LPAREN2,
    ACTIONS(6737), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6739), 1,
      anon_sym_LBRACK,
    STATE(3429), 1,
      sym_parameter_list,
    STATE(3201), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6024), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6026), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [34089] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6755), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6757), 1,
      anon_sym_PIPE,
    ACTIONS(6761), 1,
      anon_sym_AMP,
    ACTIONS(6767), 1,
      anon_sym_GT_EQ,
    ACTIONS(6773), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6777), 1,
      anon_sym_and,
    ACTIONS(6779), 1,
      anon_sym_bitor,
    ACTIONS(6781), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6292), 2,
      anon_sym_EQ,
      anon_sym_or,
    ACTIONS(6751), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6759), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6769), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6749), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6763), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(6765), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [34194] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1935), 1,
      anon_sym_LBRACE,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4196), 1,
      anon_sym_LT,
    STATE(3230), 1,
      sym_template_argument_list,
    ACTIONS(4050), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4045), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [34265] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6632), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(6670), 1,
      anon_sym_EQ,
    ACTIONS(6753), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6755), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6757), 1,
      anon_sym_PIPE,
    ACTIONS(6761), 1,
      anon_sym_AMP,
    ACTIONS(6767), 1,
      anon_sym_GT_EQ,
    ACTIONS(6771), 1,
      anon_sym_QMARK,
    ACTIONS(6773), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6775), 1,
      anon_sym_or,
    ACTIONS(6777), 1,
      anon_sym_and,
    ACTIONS(6779), 1,
      anon_sym_bitor,
    ACTIONS(6781), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6751), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6759), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6769), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6749), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6763), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(6765), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6672), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [34378] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6423), 1,
      anon_sym___attribute__,
    STATE(3265), 1,
      sym_attribute_specifier,
    ACTIONS(5583), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5585), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [34445] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5451), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5453), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [34508] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6423), 1,
      anon_sym___attribute__,
    STATE(3329), 1,
      sym_attribute_specifier,
    ACTIONS(5587), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5589), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [34575] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6423), 1,
      anon_sym___attribute__,
    STATE(3330), 1,
      sym_attribute_specifier,
    ACTIONS(5567), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5569), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [34642] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5353), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5355), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [34705] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6735), 1,
      anon_sym_LPAREN2,
    ACTIONS(6737), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6739), 1,
      anon_sym_LBRACK,
    STATE(3429), 1,
      sym_parameter_list,
    STATE(3201), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6064), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6066), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [34778] = 52,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6783), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(6785), 1,
      anon_sym_COMMA,
    ACTIONS(6789), 1,
      anon_sym_DASH,
    ACTIONS(6791), 1,
      anon_sym_PLUS,
    ACTIONS(6793), 1,
      anon_sym_STAR,
    ACTIONS(6795), 1,
      anon_sym_SLASH,
    ACTIONS(6797), 1,
      anon_sym_PERCENT,
    ACTIONS(6799), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6801), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6803), 1,
      anon_sym_PIPE,
    ACTIONS(6805), 1,
      anon_sym_CARET,
    ACTIONS(6807), 1,
      anon_sym_AMP,
    ACTIONS(6809), 1,
      anon_sym_EQ_EQ,
    ACTIONS(6811), 1,
      anon_sym_BANG_EQ,
    ACTIONS(6813), 1,
      anon_sym_GT,
    ACTIONS(6815), 1,
      anon_sym_GT_EQ,
    ACTIONS(6817), 1,
      anon_sym_LT_EQ,
    ACTIONS(6819), 1,
      anon_sym_LT,
    ACTIONS(6821), 1,
      anon_sym_LT_LT,
    ACTIONS(6823), 1,
      anon_sym_GT_GT,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6827), 1,
      anon_sym_EQ,
    ACTIONS(6829), 1,
      anon_sym_QMARK,
    ACTIONS(6831), 1,
      anon_sym_STAR_EQ,
    ACTIONS(6833), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(6835), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(6837), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(6839), 1,
      anon_sym_DASH_EQ,
    ACTIONS(6841), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(6843), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(6845), 1,
      anon_sym_AMP_EQ,
    ACTIONS(6847), 1,
      anon_sym_CARET_EQ,
    ACTIONS(6849), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(6853), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6855), 1,
      anon_sym_or,
    ACTIONS(6857), 1,
      anon_sym_and,
    ACTIONS(6859), 1,
      anon_sym_bitor,
    ACTIONS(6861), 1,
      anon_sym_xor,
    ACTIONS(6863), 1,
      anon_sym_bitand,
    ACTIONS(6865), 1,
      anon_sym_not_eq,
    ACTIONS(6871), 1,
      anon_sym_DOT_STAR,
    ACTIONS(6873), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(6910), 1,
      anon_sym_RPAREN,
    STATE(1683), 1,
      sym__binary_fold_operator,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    STATE(8023), 1,
      sym__fold_operator,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6851), 3,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [34939] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6703), 1,
      anon_sym_EQ,
    ACTIONS(6753), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6755), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6757), 1,
      anon_sym_PIPE,
    ACTIONS(6761), 1,
      anon_sym_AMP,
    ACTIONS(6767), 1,
      anon_sym_GT_EQ,
    ACTIONS(6773), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6775), 1,
      anon_sym_or,
    ACTIONS(6777), 1,
      anon_sym_and,
    ACTIONS(6779), 1,
      anon_sym_bitor,
    ACTIONS(6781), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6751), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6759), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6769), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6749), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6763), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(6765), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6705), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [35048] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3741), 1,
      anon_sym_LBRACE,
    ACTIONS(6741), 1,
      anon_sym_LPAREN2,
    ACTIONS(6743), 1,
      anon_sym_LBRACK,
    ACTIONS(6745), 1,
      sym_auto,
    ACTIONS(6747), 1,
      anon_sym_decltype,
    STATE(3619), 1,
      sym_decltype_auto,
    STATE(3637), 1,
      sym_new_declarator,
    STATE(3843), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5850), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5852), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [35127] = 52,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6783), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(6785), 1,
      anon_sym_COMMA,
    ACTIONS(6789), 1,
      anon_sym_DASH,
    ACTIONS(6791), 1,
      anon_sym_PLUS,
    ACTIONS(6793), 1,
      anon_sym_STAR,
    ACTIONS(6795), 1,
      anon_sym_SLASH,
    ACTIONS(6797), 1,
      anon_sym_PERCENT,
    ACTIONS(6799), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6801), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6803), 1,
      anon_sym_PIPE,
    ACTIONS(6805), 1,
      anon_sym_CARET,
    ACTIONS(6807), 1,
      anon_sym_AMP,
    ACTIONS(6809), 1,
      anon_sym_EQ_EQ,
    ACTIONS(6811), 1,
      anon_sym_BANG_EQ,
    ACTIONS(6813), 1,
      anon_sym_GT,
    ACTIONS(6815), 1,
      anon_sym_GT_EQ,
    ACTIONS(6817), 1,
      anon_sym_LT_EQ,
    ACTIONS(6819), 1,
      anon_sym_LT,
    ACTIONS(6821), 1,
      anon_sym_LT_LT,
    ACTIONS(6823), 1,
      anon_sym_GT_GT,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6827), 1,
      anon_sym_EQ,
    ACTIONS(6829), 1,
      anon_sym_QMARK,
    ACTIONS(6831), 1,
      anon_sym_STAR_EQ,
    ACTIONS(6833), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(6835), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(6837), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(6839), 1,
      anon_sym_DASH_EQ,
    ACTIONS(6841), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(6843), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(6845), 1,
      anon_sym_AMP_EQ,
    ACTIONS(6847), 1,
      anon_sym_CARET_EQ,
    ACTIONS(6849), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(6853), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6855), 1,
      anon_sym_or,
    ACTIONS(6857), 1,
      anon_sym_and,
    ACTIONS(6859), 1,
      anon_sym_bitor,
    ACTIONS(6861), 1,
      anon_sym_xor,
    ACTIONS(6863), 1,
      anon_sym_bitand,
    ACTIONS(6865), 1,
      anon_sym_not_eq,
    ACTIONS(6871), 1,
      anon_sym_DOT_STAR,
    ACTIONS(6873), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(6912), 1,
      anon_sym_RPAREN,
    STATE(1683), 1,
      sym__binary_fold_operator,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    STATE(8023), 1,
      sym__fold_operator,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6851), 3,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [35288] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2260), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2262), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [35351] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6423), 1,
      anon_sym___attribute__,
    STATE(3294), 1,
      sym_attribute_specifier,
    ACTIONS(5595), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5597), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [35418] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6622), 1,
      sym_auto,
    ACTIONS(6624), 1,
      anon_sym_decltype,
    STATE(3198), 1,
      sym_decltype_auto,
    ACTIONS(5413), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5415), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [35487] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2142), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2144), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [35550] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5836), 1,
      sym_literal_suffix,
    ACTIONS(5838), 24,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(5840), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [35615] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5318), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5320), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [35680] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1935), 1,
      anon_sym_LBRACE,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4055), 1,
      anon_sym_LT,
    STATE(3035), 1,
      sym_template_argument_list,
    ACTIONS(4050), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4045), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [35751] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6423), 1,
      anon_sym___attribute__,
    STATE(3252), 1,
      sym_attribute_specifier,
    ACTIONS(5610), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5612), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [35818] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6699), 1,
      anon_sym_EQ,
    ACTIONS(6753), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6755), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6757), 1,
      anon_sym_PIPE,
    ACTIONS(6761), 1,
      anon_sym_AMP,
    ACTIONS(6767), 1,
      anon_sym_GT_EQ,
    ACTIONS(6773), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6775), 1,
      anon_sym_or,
    ACTIONS(6777), 1,
      anon_sym_and,
    ACTIONS(6779), 1,
      anon_sym_bitor,
    ACTIONS(6781), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6751), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6759), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6769), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6749), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6763), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(6765), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6701), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [35927] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5133), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5135), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [35989] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5459), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5461), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [36051] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5318), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5320), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [36113] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6920), 1,
      anon_sym_DQUOTE_DQUOTE,
    ACTIONS(6918), 2,
      anon_sym_delete,
      anon_sym_new,
    ACTIONS(6916), 20,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_not,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DASH_GT,
    ACTIONS(6914), 31,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_compl,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_co_await,
      anon_sym_DASH_GT_STAR,
      anon_sym_LPAREN_RPAREN,
      anon_sym_LBRACK_RBRACK,
  [36179] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5836), 1,
      sym_literal_suffix,
    STATE(2868), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(3858), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(3860), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(3832), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(3824), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [36249] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6922), 1,
      anon_sym_LPAREN2,
    ACTIONS(6924), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6926), 1,
      anon_sym_LBRACK,
    STATE(3592), 1,
      sym_parameter_list,
    STATE(3343), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(5980), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5982), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [36321] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6928), 1,
      anon_sym_STAR,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5983), 1,
      sym__declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4064), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(4067), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [36429] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5318), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5320), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [36491] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6922), 1,
      anon_sym_LPAREN2,
    ACTIONS(6924), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6926), 1,
      anon_sym_LBRACK,
    STATE(3592), 1,
      sym_parameter_list,
    STATE(3343), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6064), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6066), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [36563] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1935), 1,
      anon_sym_LBRACE,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5810), 1,
      anon_sym_LT,
    STATE(3348), 1,
      sym_template_argument_list,
    ACTIONS(4050), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4045), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [36633] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5423), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5425), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [36695] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5541), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5543), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [36757] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5525), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5527), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [36819] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6936), 1,
      anon_sym_STAR,
    ACTIONS(6938), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6940), 1,
      anon_sym_AMP,
    ACTIONS(6942), 1,
      anon_sym_COLON_COLON,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5732), 1,
      sym__scope_resolution,
    STATE(6550), 1,
      sym__declarator,
    STATE(7980), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3167), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4062), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [36927] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5836), 1,
      sym_literal_suffix,
    STATE(2868), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(3858), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(3860), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5838), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5840), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [36997] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6310), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3188), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4074), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [37105] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6936), 1,
      anon_sym_STAR,
    ACTIONS(6938), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6940), 1,
      anon_sym_AMP,
    ACTIONS(6942), 1,
      anon_sym_COLON_COLON,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5732), 1,
      sym__scope_resolution,
    STATE(6548), 1,
      sym__declarator,
    STATE(7980), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4054), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(4067), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [37213] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5549), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5551), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [37275] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6960), 1,
      anon_sym_DQUOTE_DQUOTE,
    ACTIONS(6958), 2,
      anon_sym_delete,
      anon_sym_new,
    ACTIONS(6956), 20,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_not,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DASH_GT,
    ACTIONS(6954), 31,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_compl,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_co_await,
      anon_sym_DASH_GT_STAR,
      anon_sym_LPAREN_RPAREN,
      anon_sym_LBRACK_RBRACK,
  [37341] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5533), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5535), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [37403] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6592), 1,
      anon_sym___attribute__,
    ACTIONS(6713), 1,
      anon_sym_LBRACE,
    STATE(3334), 1,
      sym_enumerator_list,
    STATE(3646), 1,
      sym_attribute_specifier,
    ACTIONS(5529), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5531), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [37473] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5471), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5473), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [37535] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5525), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5527), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [37597] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5475), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5477), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [37659] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3627), 1,
      anon_sym_LBRACE,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    STATE(3486), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6136), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6138), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [37727] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5455), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5457), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [37789] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5515), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5517), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [37851] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6310), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4067), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4074), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [37959] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5447), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5449), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [38021] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5443), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5445), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [38083] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6928), 1,
      anon_sym_STAR,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5886), 1,
      sym__declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3157), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4056), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [38191] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6962), 1,
      anon_sym_STAR,
    ACTIONS(6964), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6966), 1,
      anon_sym_AMP,
    ACTIONS(6968), 1,
      anon_sym_COLON_COLON,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5741), 1,
      sym__scope_resolution,
    STATE(6439), 1,
      sym__declarator,
    STATE(7905), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3193), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4046), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [38299] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6962), 1,
      anon_sym_STAR,
    ACTIONS(6964), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6966), 1,
      anon_sym_AMP,
    ACTIONS(6968), 1,
      anon_sym_COLON_COLON,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5741), 1,
      sym__scope_resolution,
    STATE(6483), 1,
      sym__declarator,
    STATE(7905), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4066), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(4067), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [38407] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3627), 1,
      anon_sym_LBRACE,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    STATE(3559), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6162), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6164), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [38475] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6922), 1,
      anon_sym_LPAREN2,
    ACTIONS(6924), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6926), 1,
      anon_sym_LBRACK,
    STATE(3592), 1,
      sym_parameter_list,
    STATE(3343), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6000), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6002), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [38547] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5419), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5421), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [38609] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5463), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5465), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [38671] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6345), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4055), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(4067), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [38779] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3511), 1,
      anon_sym_DQUOTE_DQUOTE,
    ACTIONS(6970), 2,
      anon_sym_delete,
      anon_sym_new,
    ACTIONS(3507), 20,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_not,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DASH_GT,
    ACTIONS(3505), 31,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_compl,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_co_await,
      anon_sym_DASH_GT_STAR,
      anon_sym_LPAREN_RPAREN,
      anon_sym_LBRACK_RBRACK,
  [38845] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6936), 1,
      anon_sym_STAR,
    ACTIONS(6938), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6940), 1,
      anon_sym_AMP,
    ACTIONS(6942), 1,
      anon_sym_COLON_COLON,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5732), 1,
      sym__scope_resolution,
    STATE(6533), 1,
      sym__declarator,
    STATE(7980), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3196), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4051), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [38953] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5391), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5393), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [39015] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6978), 1,
      anon_sym_DQUOTE_DQUOTE,
    ACTIONS(6976), 2,
      anon_sym_delete,
      anon_sym_new,
    ACTIONS(6974), 20,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_not,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DASH_GT,
    ACTIONS(6972), 31,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_compl,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_co_await,
      anon_sym_DASH_GT_STAR,
      anon_sym_LPAREN_RPAREN,
      anon_sym_LBRACK_RBRACK,
  [39081] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6962), 1,
      anon_sym_STAR,
    ACTIONS(6964), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6966), 1,
      anon_sym_AMP,
    ACTIONS(6968), 1,
      anon_sym_COLON_COLON,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5741), 1,
      sym__scope_resolution,
    STATE(6444), 1,
      sym__declarator,
    STATE(7905), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4063), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(4067), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [39189] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6922), 1,
      anon_sym_LPAREN2,
    ACTIONS(6924), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6926), 1,
      anon_sym_LBRACK,
    STATE(3592), 1,
      sym_parameter_list,
    STATE(3343), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6024), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6026), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [39261] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1959), 1,
      anon_sym_const,
    ACTIONS(4065), 1,
      anon_sym_AMP,
    ACTIONS(4060), 7,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACK,
      anon_sym_GT2,
    ACTIONS(4063), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1961), 17,
      anon_sym___extension__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(4058), 18,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [39331] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6936), 1,
      anon_sym_STAR,
    ACTIONS(6938), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6940), 1,
      anon_sym_AMP,
    ACTIONS(6942), 1,
      anon_sym_COLON_COLON,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5732), 1,
      sym__scope_resolution,
    STATE(6550), 1,
      sym__declarator,
    STATE(7980), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4062), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(4067), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [39439] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5431), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5433), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [39501] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5439), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5441), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [39563] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5507), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5509), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [39625] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3627), 1,
      anon_sym_LBRACE,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    STATE(3563), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6089), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6091), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [39693] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6737), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(3211), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6132), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6134), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [39759] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5497), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [39821] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2605), 1,
      anon_sym_STAR,
    ACTIONS(2607), 1,
      anon_sym_AMP,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(6213), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5718), 1,
      sym__scope_resolution,
    STATE(6310), 1,
      sym__declarator,
    STATE(8582), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4067), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4069), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [39929] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2605), 1,
      anon_sym_STAR,
    ACTIONS(2607), 1,
      anon_sym_AMP,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(6213), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5718), 1,
      sym__scope_resolution,
    STATE(6320), 1,
      sym__declarator,
    STATE(8582), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3203), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4050), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [40037] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5491), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5493), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [40099] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5499), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5501), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [40161] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2605), 1,
      anon_sym_STAR,
    ACTIONS(2607), 1,
      anon_sym_AMP,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(6213), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5718), 1,
      sym__scope_resolution,
    STATE(6310), 1,
      sym__declarator,
    STATE(8582), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3234), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4069), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [40269] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5467), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5469), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [40331] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5483), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5485), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [40393] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5479), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5481), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [40455] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6980), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(3211), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6078), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6080), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [40521] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5467), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5469), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [40583] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2142), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(2144), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [40645] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6682), 1,
      sym_auto,
    ACTIONS(6684), 1,
      anon_sym_decltype,
    STATE(3292), 1,
      sym_decltype_auto,
    ACTIONS(5413), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5415), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [40713] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6928), 1,
      anon_sym_STAR,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5944), 1,
      sym__declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3219), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4057), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [40821] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5467), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5469), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [40883] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2260), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(2262), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [40945] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3627), 1,
      anon_sym_LBRACE,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    STATE(3581), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6117), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6119), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [41013] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6928), 1,
      anon_sym_STAR,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5886), 1,
      sym__declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4056), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(4067), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [41121] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6962), 1,
      anon_sym_STAR,
    ACTIONS(6964), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6966), 1,
      anon_sym_AMP,
    ACTIONS(6968), 1,
      anon_sym_COLON_COLON,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5741), 1,
      sym__scope_resolution,
    STATE(6444), 1,
      sym__declarator,
    STATE(7905), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3183), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4063), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [41229] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6989), 1,
      anon_sym_DQUOTE_DQUOTE,
    ACTIONS(6987), 2,
      anon_sym_delete,
      anon_sym_new,
    ACTIONS(6985), 20,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_not,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DASH_GT,
    ACTIONS(6983), 31,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_compl,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_co_await,
      anon_sym_DASH_GT_STAR,
      anon_sym_LPAREN_RPAREN,
      anon_sym_LBRACK_RBRACK,
  [41295] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6320), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3178), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4047), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [41403] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5353), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5355), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [41465] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5503), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5505), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [41527] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5511), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5513), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [41589] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5537), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5539), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [41651] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5451), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5453), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [41713] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3503), 1,
      anon_sym_DQUOTE_DQUOTE,
    ACTIONS(6991), 2,
      anon_sym_delete,
      anon_sym_new,
    ACTIONS(3489), 20,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_not,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DASH_GT,
    ACTIONS(3487), 31,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_compl,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_co_await,
      anon_sym_DASH_GT_STAR,
      anon_sym_LPAREN_RPAREN,
      anon_sym_LBRACK_RBRACK,
  [41779] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6592), 1,
      anon_sym___attribute__,
    ACTIONS(6713), 1,
      anon_sym_LBRACE,
    STATE(3338), 1,
      sym_enumerator_list,
    STATE(3574), 1,
      sym_attribute_specifier,
    ACTIONS(5519), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5521), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [41849] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1961), 2,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
    ACTIONS(4063), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4058), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [41913] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5318), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5320), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [41977] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5545), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5547), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [42039] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5487), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5489), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [42101] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2605), 1,
      anon_sym_STAR,
    ACTIONS(2607), 1,
      anon_sym_AMP,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(6213), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5718), 1,
      sym__scope_resolution,
    STATE(6345), 1,
      sym__declarator,
    STATE(8582), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4041), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(4067), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [42209] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5427), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5429), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [42271] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6922), 1,
      anon_sym_LPAREN2,
    ACTIONS(6924), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6926), 1,
      anon_sym_LBRACK,
    STATE(3592), 1,
      sym_parameter_list,
    STATE(3343), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(5996), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5998), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [42343] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5836), 1,
      sym_literal_suffix,
    STATE(2868), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(3858), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(3860), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(3832), 15,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(3824), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [42412] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6688), 1,
      anon_sym_EQ,
    ACTIONS(6997), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6999), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7001), 1,
      anon_sym_PIPE,
    ACTIONS(7005), 1,
      anon_sym_AMP,
    ACTIONS(7011), 1,
      anon_sym_GT_EQ,
    ACTIONS(7015), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7017), 1,
      anon_sym_or,
    ACTIONS(7019), 1,
      anon_sym_and,
    ACTIONS(7021), 1,
      anon_sym_bitor,
    ACTIONS(7023), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6993), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7003), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7013), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6995), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7007), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7009), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6690), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [42519] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5419), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5421), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [42580] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7025), 1,
      anon_sym_LT,
    STATE(2404), 1,
      sym_template_argument_list,
    ACTIONS(6306), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6308), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [42645] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7028), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(3241), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6078), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6080), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [42710] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6592), 1,
      anon_sym___attribute__,
    STATE(3582), 1,
      sym_attribute_specifier,
    ACTIONS(5606), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5608), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [42775] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6592), 1,
      anon_sym___attribute__,
    STATE(3580), 1,
      sym_attribute_specifier,
    ACTIONS(5583), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5585), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [42840] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6592), 1,
      anon_sym___attribute__,
    STATE(3573), 1,
      sym_attribute_specifier,
    ACTIONS(5610), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5612), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [42905] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7025), 1,
      anon_sym_LT,
    STATE(3230), 1,
      sym_template_argument_list,
    ACTIONS(6306), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6308), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [42970] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6592), 1,
      anon_sym___attribute__,
    STATE(3566), 1,
      sym_attribute_specifier,
    ACTIONS(5595), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5597), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [43035] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5133), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5135), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [43096] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5318), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5320), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [43157] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6688), 1,
      anon_sym_EQ,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6853), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7035), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7037), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7039), 1,
      anon_sym_PIPE,
    ACTIONS(7043), 1,
      anon_sym_AMP,
    ACTIONS(7049), 1,
      anon_sym_GT_EQ,
    ACTIONS(7053), 1,
      anon_sym_or,
    ACTIONS(7055), 1,
      anon_sym_and,
    ACTIONS(7057), 1,
      anon_sym_bitor,
    ACTIONS(7059), 1,
      anon_sym_bitand,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7031), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7041), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7051), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7033), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7045), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7047), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6690), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_DASH_GT_STAR,
  [43264] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1959), 1,
      anon_sym_const,
    ACTIONS(4065), 1,
      anon_sym_AMP,
    ACTIONS(4060), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACK,
    ACTIONS(4063), 8,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_DOT,
    ACTIONS(1961), 17,
      anon_sym___extension__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(4058), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [43333] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6703), 1,
      anon_sym_EQ,
    ACTIONS(6997), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6999), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7001), 1,
      anon_sym_PIPE,
    ACTIONS(7005), 1,
      anon_sym_AMP,
    ACTIONS(7011), 1,
      anon_sym_GT_EQ,
    ACTIONS(7015), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7017), 1,
      anon_sym_or,
    ACTIONS(7019), 1,
      anon_sym_and,
    ACTIONS(7021), 1,
      anon_sym_bitor,
    ACTIONS(7023), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6993), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7003), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7013), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6995), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7007), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7009), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6705), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [43440] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5443), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5445), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [43501] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5515), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5517), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [43562] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6995), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [43639] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6993), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6995), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 12,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [43718] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6993), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7013), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6995), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 10,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [43799] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6703), 1,
      anon_sym_EQ,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6853), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7035), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7037), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7039), 1,
      anon_sym_PIPE,
    ACTIONS(7043), 1,
      anon_sym_AMP,
    ACTIONS(7049), 1,
      anon_sym_GT_EQ,
    ACTIONS(7053), 1,
      anon_sym_or,
    ACTIONS(7055), 1,
      anon_sym_and,
    ACTIONS(7057), 1,
      anon_sym_bitor,
    ACTIONS(7059), 1,
      anon_sym_bitand,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7031), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7041), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7051), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7033), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7045), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7047), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6705), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_DASH_GT_STAR,
  [43906] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5447), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5449), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [43967] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5318), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5320), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [44028] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6249), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6251), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_GT_STAR,
  [44101] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5541), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5543), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [44162] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7063), 1,
      anon_sym_LT,
    STATE(3449), 1,
      sym_template_argument_list,
    ACTIONS(6204), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6206), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [44229] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5525), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5527), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [44290] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5471), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5473), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [44351] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5533), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5535), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [44412] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5455), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5457), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [44473] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7015), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6993), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7013), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6995), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 10,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [44556] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7031), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7051), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7033), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 10,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
  [44637] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7011), 1,
      anon_sym_GT_EQ,
    ACTIONS(7015), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6993), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7013), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6995), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7009), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [44724] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6270), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6272), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
  [44799] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7011), 1,
      anon_sym_GT_EQ,
    ACTIONS(7015), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6993), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7013), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6995), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7007), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7009), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
  [44888] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7031), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7033), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 12,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
  [44967] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7005), 1,
      anon_sym_AMP,
    ACTIONS(7011), 1,
      anon_sym_GT_EQ,
    ACTIONS(7015), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7023), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6993), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7013), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6995), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7007), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7009), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 6,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
  [45060] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7005), 1,
      anon_sym_AMP,
    ACTIONS(7011), 1,
      anon_sym_GT_EQ,
    ACTIONS(7015), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7023), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6993), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7003), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7013), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6995), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7007), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7009), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 4,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
    ACTIONS(6294), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
  [45155] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6853), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7031), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7051), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7033), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 10,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
  [45238] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6853), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7049), 1,
      anon_sym_GT_EQ,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7031), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7051), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7033), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7047), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
  [45325] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6853), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7049), 1,
      anon_sym_GT_EQ,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7031), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7051), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7033), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7045), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7047), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_DASH_GT_STAR,
  [45414] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6853), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7043), 1,
      anon_sym_AMP,
    ACTIONS(7049), 1,
      anon_sym_GT_EQ,
    ACTIONS(7059), 1,
      anon_sym_bitand,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7031), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7051), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7033), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7045), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7047), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 6,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_DASH_GT_STAR,
  [45507] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5549), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5551), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [45568] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6853), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7043), 1,
      anon_sym_AMP,
    ACTIONS(7049), 1,
      anon_sym_GT_EQ,
    ACTIONS(7059), 1,
      anon_sym_bitand,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7031), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7041), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7051), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7033), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7045), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7047), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 4,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
    ACTIONS(6294), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_DASH_GT_STAR,
  [45663] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5525), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5527), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [45724] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6630), 1,
      anon_sym_EQ,
    ACTIONS(6783), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6829), 1,
      anon_sym_QMARK,
    ACTIONS(6853), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7035), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7037), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7039), 1,
      anon_sym_PIPE,
    ACTIONS(7043), 1,
      anon_sym_AMP,
    ACTIONS(7049), 1,
      anon_sym_GT_EQ,
    ACTIONS(7053), 1,
      anon_sym_or,
    ACTIONS(7055), 1,
      anon_sym_and,
    ACTIONS(7057), 1,
      anon_sym_bitor,
    ACTIONS(7059), 1,
      anon_sym_bitand,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7031), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7041), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7051), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7033), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7045), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7047), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6634), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_DASH_GT_STAR,
  [45835] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5459), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5461), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [45896] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6853), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7039), 1,
      anon_sym_PIPE,
    ACTIONS(7043), 1,
      anon_sym_AMP,
    ACTIONS(7049), 1,
      anon_sym_GT_EQ,
    ACTIONS(7057), 1,
      anon_sym_bitor,
    ACTIONS(7059), 1,
      anon_sym_bitand,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7031), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7041), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7051), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6292), 3,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
    ACTIONS(7033), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7045), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7047), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_DASH_GT_STAR,
  [45995] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6853), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7037), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7039), 1,
      anon_sym_PIPE,
    ACTIONS(7043), 1,
      anon_sym_AMP,
    ACTIONS(7049), 1,
      anon_sym_GT_EQ,
    ACTIONS(7055), 1,
      anon_sym_and,
    ACTIONS(7057), 1,
      anon_sym_bitor,
    ACTIONS(7059), 1,
      anon_sym_bitand,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6292), 2,
      anon_sym_EQ,
      anon_sym_or,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7031), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7041), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7051), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7033), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7045), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7047), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_DASH_GT_STAR,
  [46098] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6699), 1,
      anon_sym_EQ,
    ACTIONS(6997), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6999), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7001), 1,
      anon_sym_PIPE,
    ACTIONS(7005), 1,
      anon_sym_AMP,
    ACTIONS(7011), 1,
      anon_sym_GT_EQ,
    ACTIONS(7015), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7017), 1,
      anon_sym_or,
    ACTIONS(7019), 1,
      anon_sym_and,
    ACTIONS(7021), 1,
      anon_sym_bitor,
    ACTIONS(7023), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6993), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7003), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7013), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6995), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7007), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7009), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6701), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [46205] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2278), 26,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(2276), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [46266] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2278), 26,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(2276), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [46327] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7066), 1,
      anon_sym_LBRACK_RBRACK,
    ACTIONS(6278), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6280), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [46390] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6292), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
  [46465] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6632), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(6670), 1,
      anon_sym_EQ,
    ACTIONS(6997), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6999), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7001), 1,
      anon_sym_PIPE,
    ACTIONS(7005), 1,
      anon_sym_AMP,
    ACTIONS(7011), 1,
      anon_sym_GT_EQ,
    ACTIONS(7015), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7017), 1,
      anon_sym_or,
    ACTIONS(7019), 1,
      anon_sym_and,
    ACTIONS(7021), 1,
      anon_sym_bitor,
    ACTIONS(7023), 1,
      anon_sym_bitand,
    ACTIONS(7068), 1,
      anon_sym_QMARK,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6993), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7003), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7013), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6995), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7007), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7009), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6672), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [46576] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5439), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5441), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [46637] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7001), 1,
      anon_sym_PIPE,
    ACTIONS(7005), 1,
      anon_sym_AMP,
    ACTIONS(7011), 1,
      anon_sym_GT_EQ,
    ACTIONS(7015), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7021), 1,
      anon_sym_bitor,
    ACTIONS(7023), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6993), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7003), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7013), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6292), 3,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
    ACTIONS(6995), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7007), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7009), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [46736] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5463), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5465), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [46797] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6999), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7001), 1,
      anon_sym_PIPE,
    ACTIONS(7005), 1,
      anon_sym_AMP,
    ACTIONS(7011), 1,
      anon_sym_GT_EQ,
    ACTIONS(7015), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7019), 1,
      anon_sym_and,
    ACTIONS(7021), 1,
      anon_sym_bitor,
    ACTIONS(7023), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6292), 2,
      anon_sym_EQ,
      anon_sym_or,
    ACTIONS(6993), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7003), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7013), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6995), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7007), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7009), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [46900] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7033), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
  [46977] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5503), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5505), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [47038] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5511), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5513), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [47099] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6885), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(6905), 1,
      anon_sym_requires,
    ACTIONS(7070), 1,
      anon_sym___attribute__,
    ACTIONS(7073), 1,
      anon_sym_DASH_GT,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(4847), 1,
      sym__function_attributes_start,
    STATE(5001), 1,
      sym_ref_qualifier,
    STATE(5673), 1,
      sym__function_attributes_end,
    STATE(5676), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(6898), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4195), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4344), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5900), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5315), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(6875), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [47210] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6670), 1,
      anon_sym_EQ,
    ACTIONS(6783), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6829), 1,
      anon_sym_QMARK,
    ACTIONS(6853), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7035), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7037), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7039), 1,
      anon_sym_PIPE,
    ACTIONS(7043), 1,
      anon_sym_AMP,
    ACTIONS(7049), 1,
      anon_sym_GT_EQ,
    ACTIONS(7053), 1,
      anon_sym_or,
    ACTIONS(7055), 1,
      anon_sym_and,
    ACTIONS(7057), 1,
      anon_sym_bitor,
    ACTIONS(7059), 1,
      anon_sym_bitand,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7031), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7041), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7051), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7033), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7045), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7047), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6672), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_DASH_GT_STAR,
  [47321] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5537), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5539), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [47382] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6620), 1,
      anon_sym_LBRACK,
    STATE(3427), 1,
      sym_new_declarator,
    ACTIONS(6221), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6223), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [47447] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5487), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5489), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [47508] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3675), 1,
      anon_sym_LBRACE,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    STATE(3665), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6117), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6119), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [47575] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2250), 26,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(2248), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [47636] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6233), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6235), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
  [47711] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6592), 1,
      anon_sym___attribute__,
    STATE(3587), 1,
      sym_attribute_specifier,
    ACTIONS(5599), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5601), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [47776] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6496), 1,
      anon_sym_EQ,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6783), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6829), 1,
      anon_sym_QMARK,
    ACTIONS(6853), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7035), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7037), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7039), 1,
      anon_sym_PIPE,
    ACTIONS(7043), 1,
      anon_sym_AMP,
    ACTIONS(7049), 1,
      anon_sym_GT_EQ,
    ACTIONS(7053), 1,
      anon_sym_or,
    ACTIONS(7055), 1,
      anon_sym_and,
    ACTIONS(7057), 1,
      anon_sym_bitor,
    ACTIONS(7059), 1,
      anon_sym_bitand,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7031), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7041), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7051), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7033), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7045), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7047), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6498), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_DASH_GT_STAR,
  [47887] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5545), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5547), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [47948] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5427), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5429), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [48009] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2250), 26,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(2248), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [48070] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6496), 1,
      anon_sym_EQ,
    ACTIONS(6632), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(6997), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6999), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7001), 1,
      anon_sym_PIPE,
    ACTIONS(7005), 1,
      anon_sym_AMP,
    ACTIONS(7011), 1,
      anon_sym_GT_EQ,
    ACTIONS(7015), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7017), 1,
      anon_sym_or,
    ACTIONS(7019), 1,
      anon_sym_and,
    ACTIONS(7021), 1,
      anon_sym_bitor,
    ACTIONS(7023), 1,
      anon_sym_bitand,
    ACTIONS(7068), 1,
      anon_sym_QMARK,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6993), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7003), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7013), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6995), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7007), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7009), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6498), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [48181] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5467), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5469), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [48242] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5467), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5469), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [48303] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2266), 26,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(2264), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [48364] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6592), 1,
      anon_sym___attribute__,
    STATE(3493), 1,
      sym_attribute_specifier,
    ACTIONS(5614), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5616), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [48429] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1935), 1,
      anon_sym_LBRACE,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5827), 1,
      anon_sym_LT,
    STATE(3358), 1,
      sym_template_argument_list,
    ACTIONS(4050), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4045), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [48498] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6630), 1,
      anon_sym_EQ,
    ACTIONS(6632), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(6997), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6999), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7001), 1,
      anon_sym_PIPE,
    ACTIONS(7005), 1,
      anon_sym_AMP,
    ACTIONS(7011), 1,
      anon_sym_GT_EQ,
    ACTIONS(7015), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7017), 1,
      anon_sym_or,
    ACTIONS(7019), 1,
      anon_sym_and,
    ACTIONS(7021), 1,
      anon_sym_bitor,
    ACTIONS(7023), 1,
      anon_sym_bitand,
    ACTIONS(7068), 1,
      anon_sym_QMARK,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6993), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7003), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7013), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6995), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7007), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7009), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6634), 16,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [48609] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6695), 1,
      anon_sym_EQ,
    ACTIONS(6997), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6999), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7001), 1,
      anon_sym_PIPE,
    ACTIONS(7005), 1,
      anon_sym_AMP,
    ACTIONS(7011), 1,
      anon_sym_GT_EQ,
    ACTIONS(7015), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7017), 1,
      anon_sym_or,
    ACTIONS(7019), 1,
      anon_sym_and,
    ACTIONS(7021), 1,
      anon_sym_bitor,
    ACTIONS(7023), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6993), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7003), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7013), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6995), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7007), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7009), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6697), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [48716] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6695), 1,
      anon_sym_EQ,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6853), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7035), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7037), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7039), 1,
      anon_sym_PIPE,
    ACTIONS(7043), 1,
      anon_sym_AMP,
    ACTIONS(7049), 1,
      anon_sym_GT_EQ,
    ACTIONS(7053), 1,
      anon_sym_or,
    ACTIONS(7055), 1,
      anon_sym_and,
    ACTIONS(7057), 1,
      anon_sym_bitor,
    ACTIONS(7059), 1,
      anon_sym_bitand,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7031), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7041), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7051), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7033), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7045), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7047), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6697), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_DASH_GT_STAR,
  [48823] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3675), 1,
      anon_sym_LBRACE,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    STATE(3663), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6162), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6164), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [48890] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7075), 1,
      anon_sym_LT,
    STATE(1084), 1,
      sym_template_argument_list,
    ACTIONS(6306), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6308), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [48955] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5479), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5481), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [49016] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5483), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5485), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [49077] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5836), 1,
      sym_literal_suffix,
    STATE(2868), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(3858), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(3860), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5838), 15,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(5840), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [49146] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6592), 1,
      anon_sym___attribute__,
    STATE(3625), 1,
      sym_attribute_specifier,
    ACTIONS(5567), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5569), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [49211] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6302), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6304), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_GT_STAR,
  [49284] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5467), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5469), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [49345] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5507), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5509), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [49406] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5431), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5433), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [49467] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2206), 26,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(2204), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [49528] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3675), 1,
      anon_sym_LBRACE,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    STATE(3684), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6136), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6138), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [49595] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7078), 1,
      anon_sym_LT,
    STATE(3449), 1,
      sym_template_argument_list,
    ACTIONS(6189), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6191), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [49662] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6592), 1,
      anon_sym___attribute__,
    STATE(3627), 1,
      sym_attribute_specifier,
    ACTIONS(5587), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5589), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [49727] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6699), 1,
      anon_sym_EQ,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6853), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7035), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7037), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7039), 1,
      anon_sym_PIPE,
    ACTIONS(7043), 1,
      anon_sym_AMP,
    ACTIONS(7049), 1,
      anon_sym_GT_EQ,
    ACTIONS(7053), 1,
      anon_sym_or,
    ACTIONS(7055), 1,
      anon_sym_and,
    ACTIONS(7057), 1,
      anon_sym_bitor,
    ACTIONS(7059), 1,
      anon_sym_bitand,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7031), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7041), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7051), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7033), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7045), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7047), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6701), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_DASH_GT_STAR,
  [49834] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6592), 1,
      anon_sym___attribute__,
    STATE(3645), 1,
      sym_attribute_specifier,
    ACTIONS(5591), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5593), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [49899] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7075), 1,
      anon_sym_LT,
    STATE(3035), 1,
      sym_template_argument_list,
    ACTIONS(6306), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6308), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [49964] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6592), 1,
      anon_sym___attribute__,
    STATE(3648), 1,
      sym_attribute_specifier,
    ACTIONS(5579), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5581), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [50029] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5423), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5425), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [50090] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6592), 1,
      anon_sym___attribute__,
    STATE(3651), 1,
      sym_attribute_specifier,
    ACTIONS(5571), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5573), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [50155] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3675), 1,
      anon_sym_LBRACE,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    STATE(3724), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6089), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6091), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [50222] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5499), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5501), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [50283] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6924), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(3241), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6132), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6134), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [50348] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6592), 1,
      anon_sym___attribute__,
    STATE(3653), 1,
      sym_attribute_specifier,
    ACTIONS(5575), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5577), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [50413] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7081), 1,
      anon_sym_LBRACK_RBRACK,
    ACTIONS(6278), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6280), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [50476] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6885), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(7070), 1,
      anon_sym___attribute__,
    ACTIONS(7073), 1,
      anon_sym_DASH_GT,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(4845), 1,
      sym__function_attributes_start,
    STATE(5044), 1,
      sym_ref_qualifier,
    STATE(5723), 1,
      sym__function_attributes_end,
    STATE(5739), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(4195), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4344), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5900), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5318), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(6875), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [50587] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5491), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5493), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [50648] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1961), 2,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
    ACTIONS(4063), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4058), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [50711] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6327), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6329), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
  [50786] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6867), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6331), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6333), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
  [50861] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5318), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5320), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [50923] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6093), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6095), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [50983] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6343), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6345), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [51043] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6885), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7083), 1,
      anon_sym_DASH_GT,
    ACTIONS(7085), 1,
      anon_sym_requires,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(4917), 1,
      sym__function_attributes_start,
    STATE(5055), 1,
      sym_ref_qualifier,
    STATE(5827), 1,
      sym__function_attributes_end,
    STATE(5973), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(6898), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4195), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4344), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5900), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5338), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(6875), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [51153] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3854), 1,
      anon_sym_EQ,
    ACTIONS(5188), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5876), 1,
      anon_sym_LPAREN2,
    ACTIONS(5882), 1,
      anon_sym_LBRACK,
    ACTIONS(3856), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
    ACTIONS(3832), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(3824), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [51223] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7088), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7094), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7096), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7098), 1,
      anon_sym_PIPE,
    ACTIONS(7102), 1,
      anon_sym_AMP,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7112), 1,
      anon_sym_QMARK,
    ACTIONS(7114), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7116), 1,
      anon_sym_or,
    ACTIONS(7118), 1,
      anon_sym_and,
    ACTIONS(7120), 1,
      anon_sym_bitor,
    ACTIONS(7122), 1,
      anon_sym_bitand,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(6496), 2,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
    ACTIONS(7090), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7100), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7108), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7124), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7092), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7104), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7106), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6498), 14,
      anon_sym_COMMA,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_GT2,
  [51331] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7124), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6233), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6235), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
  [51405] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1961), 2,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
    ACTIONS(4063), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4058), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [51467] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5836), 1,
      sym_literal_suffix,
    ACTIONS(5838), 25,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(5840), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [51529] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5836), 1,
      sym_literal_suffix,
    ACTIONS(3832), 25,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(3824), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [51591] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7130), 1,
      sym_identifier,
    STATE(3456), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(5974), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(5976), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5663), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5661), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [51659] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(7132), 1,
      anon_sym___attribute__,
    ACTIONS(7134), 1,
      anon_sym_LBRACE,
    STATE(4042), 1,
      sym_field_declaration_list,
    STATE(4161), 1,
      sym_attribute_specifier,
    STATE(6880), 1,
      sym_virtual_specifier,
    STATE(7528), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(5327), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5329), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [51735] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7138), 1,
      anon_sym_DASH_GT,
    ACTIONS(7142), 1,
      anon_sym_requires,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(4930), 1,
      sym__function_attributes_start,
    STATE(5059), 1,
      sym_ref_qualifier,
    STATE(5797), 1,
      sym_trailing_return_type,
    STATE(5862), 1,
      sym__function_attributes_end,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4195), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4344), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6072), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5332), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(6875), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [51845] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7094), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7096), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7098), 1,
      anon_sym_PIPE,
    ACTIONS(7102), 1,
      anon_sym_AMP,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7114), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7116), 1,
      anon_sym_or,
    ACTIONS(7118), 1,
      anon_sym_and,
    ACTIONS(7120), 1,
      anon_sym_bitor,
    ACTIONS(7122), 1,
      anon_sym_bitand,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(6695), 2,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
    ACTIONS(7090), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7100), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7108), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7124), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7092), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7104), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7106), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6697), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_GT2,
  [51949] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5887), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5885), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [52009] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4045), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [52069] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6632), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(6753), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6755), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6757), 1,
      anon_sym_PIPE,
    ACTIONS(6761), 1,
      anon_sym_AMP,
    ACTIONS(6767), 1,
      anon_sym_GT_EQ,
    ACTIONS(6771), 1,
      anon_sym_QMARK,
    ACTIONS(6773), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(6775), 1,
      anon_sym_or,
    ACTIONS(6777), 1,
      anon_sym_and,
    ACTIONS(6779), 1,
      anon_sym_bitor,
    ACTIONS(6781), 1,
      anon_sym_bitand,
    ACTIONS(6910), 1,
      anon_sym_RPAREN,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7146), 1,
      anon_sym_EQ,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6751), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6759), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6769), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6749), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6763), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(6765), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6851), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [52183] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7124), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7092), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
  [52259] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7124), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6292), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
  [52333] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7096), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7098), 1,
      anon_sym_PIPE,
    ACTIONS(7102), 1,
      anon_sym_AMP,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7114), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7118), 1,
      anon_sym_and,
    ACTIONS(7120), 1,
      anon_sym_bitor,
    ACTIONS(7122), 1,
      anon_sym_bitand,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7090), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7100), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7108), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7124), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6292), 3,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
    ACTIONS(7092), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7104), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7106), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_GT2,
  [52433] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7098), 1,
      anon_sym_PIPE,
    ACTIONS(7102), 1,
      anon_sym_AMP,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7114), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7120), 1,
      anon_sym_bitor,
    ACTIONS(7122), 1,
      anon_sym_bitand,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7090), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7100), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7108), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7124), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7092), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7104), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(6292), 4,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
    ACTIONS(7106), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_GT2,
  [52529] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7102), 1,
      anon_sym_AMP,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7114), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7122), 1,
      anon_sym_bitand,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7090), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7100), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7108), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7124), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7092), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7104), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7106), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 5,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
    ACTIONS(6294), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_GT2,
  [52621] = 51,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6871), 1,
      anon_sym_DOT_STAR,
    ACTIONS(6873), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(7148), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7150), 1,
      anon_sym_COMMA,
    ACTIONS(7152), 1,
      anon_sym_RPAREN,
    ACTIONS(7154), 1,
      anon_sym_DASH,
    ACTIONS(7156), 1,
      anon_sym_PLUS,
    ACTIONS(7158), 1,
      anon_sym_STAR,
    ACTIONS(7160), 1,
      anon_sym_SLASH,
    ACTIONS(7162), 1,
      anon_sym_PERCENT,
    ACTIONS(7164), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7166), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7168), 1,
      anon_sym_PIPE,
    ACTIONS(7170), 1,
      anon_sym_CARET,
    ACTIONS(7172), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_EQ_EQ,
    ACTIONS(7176), 1,
      anon_sym_BANG_EQ,
    ACTIONS(7178), 1,
      anon_sym_GT,
    ACTIONS(7180), 1,
      anon_sym_GT_EQ,
    ACTIONS(7182), 1,
      anon_sym_LT_EQ,
    ACTIONS(7184), 1,
      anon_sym_LT,
    ACTIONS(7186), 1,
      anon_sym_LT_LT,
    ACTIONS(7188), 1,
      anon_sym_GT_GT,
    ACTIONS(7190), 1,
      anon_sym_EQ,
    ACTIONS(7192), 1,
      anon_sym_QMARK,
    ACTIONS(7194), 1,
      anon_sym_STAR_EQ,
    ACTIONS(7196), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(7198), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(7200), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(7202), 1,
      anon_sym_DASH_EQ,
    ACTIONS(7204), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(7206), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(7208), 1,
      anon_sym_AMP_EQ,
    ACTIONS(7210), 1,
      anon_sym_CARET_EQ,
    ACTIONS(7212), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(7214), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7216), 1,
      anon_sym_or,
    ACTIONS(7218), 1,
      anon_sym_and,
    ACTIONS(7220), 1,
      anon_sym_bitor,
    ACTIONS(7222), 1,
      anon_sym_xor,
    ACTIONS(7224), 1,
      anon_sym_bitand,
    ACTIONS(7226), 1,
      anon_sym_not_eq,
    STATE(1683), 1,
      sym__binary_fold_operator,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    STATE(8023), 1,
      sym__fold_operator,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [52777] = 51,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6871), 1,
      anon_sym_DOT_STAR,
    ACTIONS(6873), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(7148), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7150), 1,
      anon_sym_COMMA,
    ACTIONS(7154), 1,
      anon_sym_DASH,
    ACTIONS(7156), 1,
      anon_sym_PLUS,
    ACTIONS(7158), 1,
      anon_sym_STAR,
    ACTIONS(7160), 1,
      anon_sym_SLASH,
    ACTIONS(7162), 1,
      anon_sym_PERCENT,
    ACTIONS(7164), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7166), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7168), 1,
      anon_sym_PIPE,
    ACTIONS(7170), 1,
      anon_sym_CARET,
    ACTIONS(7172), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_EQ_EQ,
    ACTIONS(7176), 1,
      anon_sym_BANG_EQ,
    ACTIONS(7178), 1,
      anon_sym_GT,
    ACTIONS(7180), 1,
      anon_sym_GT_EQ,
    ACTIONS(7182), 1,
      anon_sym_LT_EQ,
    ACTIONS(7184), 1,
      anon_sym_LT,
    ACTIONS(7186), 1,
      anon_sym_LT_LT,
    ACTIONS(7188), 1,
      anon_sym_GT_GT,
    ACTIONS(7190), 1,
      anon_sym_EQ,
    ACTIONS(7192), 1,
      anon_sym_QMARK,
    ACTIONS(7194), 1,
      anon_sym_STAR_EQ,
    ACTIONS(7196), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(7198), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(7200), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(7202), 1,
      anon_sym_DASH_EQ,
    ACTIONS(7204), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(7206), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(7208), 1,
      anon_sym_AMP_EQ,
    ACTIONS(7210), 1,
      anon_sym_CARET_EQ,
    ACTIONS(7212), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(7214), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7216), 1,
      anon_sym_or,
    ACTIONS(7218), 1,
      anon_sym_and,
    ACTIONS(7220), 1,
      anon_sym_bitor,
    ACTIONS(7222), 1,
      anon_sym_xor,
    ACTIONS(7224), 1,
      anon_sym_bitand,
    ACTIONS(7226), 1,
      anon_sym_not_eq,
    ACTIONS(7230), 1,
      anon_sym_RPAREN,
    STATE(1683), 1,
      sym__binary_fold_operator,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    STATE(8023), 1,
      sym__fold_operator,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [52933] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7102), 1,
      anon_sym_AMP,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7114), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7122), 1,
      anon_sym_bitand,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7090), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7108), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7124), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7092), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7104), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7106), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_GT2,
  [53023] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7114), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7090), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7108), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7124), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7092), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7104), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7106), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 8,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_GT2,
  [53109] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7114), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7090), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7108), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7124), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7092), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7106), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 8,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
  [53193] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7114), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7090), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7108), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7124), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7092), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 12,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
  [53275] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7090), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7124), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7092), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 14,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
  [53353] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2142), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2144), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [53413] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6302), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6304), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_GT2,
  [53485] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7094), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7096), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7098), 1,
      anon_sym_PIPE,
    ACTIONS(7102), 1,
      anon_sym_AMP,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7114), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7116), 1,
      anon_sym_or,
    ACTIONS(7118), 1,
      anon_sym_and,
    ACTIONS(7120), 1,
      anon_sym_bitor,
    ACTIONS(7122), 1,
      anon_sym_bitand,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(6703), 2,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
    ACTIONS(7090), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7100), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7108), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7124), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7092), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7104), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7106), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6705), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_GT2,
  [53589] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6278), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6280), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [53649] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7124), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6331), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6333), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
  [53723] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7124), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6327), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6329), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
  [53797] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7090), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7108), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7124), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7092), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 12,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
  [53877] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2260), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2262), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [53937] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4045), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [53997] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4045), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [54057] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5188), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5876), 1,
      anon_sym_LPAREN2,
    ACTIONS(5882), 1,
      anon_sym_LBRACK,
    ACTIONS(3832), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(3824), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [54123] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5188), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5876), 1,
      anon_sym_LPAREN2,
    ACTIONS(5882), 1,
      anon_sym_LBRACK,
    ACTIONS(3832), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(3824), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [54189] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3854), 1,
      anon_sym_EQ,
    ACTIONS(3856), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
    ACTIONS(3832), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(3824), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [54253] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4045), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [54313] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6249), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6251), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_GT2,
  [54385] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4045), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [54445] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4045), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [54505] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7124), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6270), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6272), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
  [54579] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6087), 1,
      sym_literal_suffix,
    ACTIONS(5838), 25,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5840), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [54641] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7138), 1,
      anon_sym_DASH_GT,
    ACTIONS(7235), 1,
      anon_sym_requires,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(4906), 1,
      sym__function_attributes_start,
    STATE(5061), 1,
      sym_ref_qualifier,
    STATE(5799), 1,
      sym_trailing_return_type,
    STATE(5847), 1,
      sym__function_attributes_end,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7232), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4195), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4344), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6072), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5335), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(6875), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [54751] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7094), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7096), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7098), 1,
      anon_sym_PIPE,
    ACTIONS(7102), 1,
      anon_sym_AMP,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7114), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7116), 1,
      anon_sym_or,
    ACTIONS(7118), 1,
      anon_sym_and,
    ACTIONS(7120), 1,
      anon_sym_bitor,
    ACTIONS(7122), 1,
      anon_sym_bitand,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(6699), 2,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
    ACTIONS(7090), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7100), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7108), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7124), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7092), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7104), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7106), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6701), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_GT2,
  [54855] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6097), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6099), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [54915] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7238), 1,
      anon_sym_LBRACK_RBRACK,
    ACTIONS(6278), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6280), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [54977] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6121), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6123), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [55037] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6125), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6127), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [55097] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7088), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7094), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7096), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7098), 1,
      anon_sym_PIPE,
    ACTIONS(7102), 1,
      anon_sym_AMP,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7112), 1,
      anon_sym_QMARK,
    ACTIONS(7114), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7116), 1,
      anon_sym_or,
    ACTIONS(7118), 1,
      anon_sym_and,
    ACTIONS(7120), 1,
      anon_sym_bitor,
    ACTIONS(7122), 1,
      anon_sym_bitand,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(6670), 2,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
    ACTIONS(7090), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7100), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7108), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7124), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7092), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7104), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7106), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6672), 14,
      anon_sym_COMMA,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_GT2,
  [55205] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6087), 1,
      sym_literal_suffix,
    ACTIONS(3832), 25,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3824), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [55267] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6731), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym___attribute__,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6733), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [55327] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7094), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7096), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7098), 1,
      anon_sym_PIPE,
    ACTIONS(7102), 1,
      anon_sym_AMP,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7114), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7116), 1,
      anon_sym_or,
    ACTIONS(7118), 1,
      anon_sym_and,
    ACTIONS(7120), 1,
      anon_sym_bitor,
    ACTIONS(7122), 1,
      anon_sym_bitand,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(6688), 2,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
    ACTIONS(7090), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7100), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7108), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7124), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7092), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7104), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7106), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6690), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_GT2,
  [55431] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7240), 1,
      sym_identifier,
    STATE(3409), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(7243), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(7246), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5651), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5649), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [55499] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6745), 1,
      sym_auto,
    ACTIONS(6747), 1,
      anon_sym_decltype,
    STATE(3619), 1,
      sym_decltype_auto,
    ACTIONS(5413), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5415), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [55565] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6278), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6280), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [55625] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6680), 1,
      anon_sym_LBRACK,
    STATE(3643), 1,
      sym_new_declarator,
    ACTIONS(6221), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6223), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [55689] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7088), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7094), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7096), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7098), 1,
      anon_sym_PIPE,
    ACTIONS(7102), 1,
      anon_sym_AMP,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7112), 1,
      anon_sym_QMARK,
    ACTIONS(7114), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7116), 1,
      anon_sym_or,
    ACTIONS(7118), 1,
      anon_sym_and,
    ACTIONS(7120), 1,
      anon_sym_bitor,
    ACTIONS(7122), 1,
      anon_sym_bitand,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(6630), 2,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
    ACTIONS(7090), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7100), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7108), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7124), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7092), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7104), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7106), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6634), 14,
      anon_sym_COMMA,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_GT2,
  [55797] = 51,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6871), 1,
      anon_sym_DOT_STAR,
    ACTIONS(6873), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(7148), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7150), 1,
      anon_sym_COMMA,
    ACTIONS(7154), 1,
      anon_sym_DASH,
    ACTIONS(7156), 1,
      anon_sym_PLUS,
    ACTIONS(7158), 1,
      anon_sym_STAR,
    ACTIONS(7160), 1,
      anon_sym_SLASH,
    ACTIONS(7162), 1,
      anon_sym_PERCENT,
    ACTIONS(7164), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7166), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7168), 1,
      anon_sym_PIPE,
    ACTIONS(7170), 1,
      anon_sym_CARET,
    ACTIONS(7172), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_EQ_EQ,
    ACTIONS(7176), 1,
      anon_sym_BANG_EQ,
    ACTIONS(7178), 1,
      anon_sym_GT,
    ACTIONS(7180), 1,
      anon_sym_GT_EQ,
    ACTIONS(7182), 1,
      anon_sym_LT_EQ,
    ACTIONS(7184), 1,
      anon_sym_LT,
    ACTIONS(7186), 1,
      anon_sym_LT_LT,
    ACTIONS(7188), 1,
      anon_sym_GT_GT,
    ACTIONS(7190), 1,
      anon_sym_EQ,
    ACTIONS(7192), 1,
      anon_sym_QMARK,
    ACTIONS(7194), 1,
      anon_sym_STAR_EQ,
    ACTIONS(7196), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(7198), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(7200), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(7202), 1,
      anon_sym_DASH_EQ,
    ACTIONS(7204), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(7206), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(7208), 1,
      anon_sym_AMP_EQ,
    ACTIONS(7210), 1,
      anon_sym_CARET_EQ,
    ACTIONS(7212), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(7214), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7216), 1,
      anon_sym_or,
    ACTIONS(7218), 1,
      anon_sym_and,
    ACTIONS(7220), 1,
      anon_sym_bitor,
    ACTIONS(7222), 1,
      anon_sym_xor,
    ACTIONS(7224), 1,
      anon_sym_bitand,
    ACTIONS(7226), 1,
      anon_sym_not_eq,
    ACTIONS(7249), 1,
      anon_sym_RPAREN,
    STATE(1683), 1,
      sym__binary_fold_operator,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    STATE(8023), 1,
      sym__fold_operator,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [55953] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5188), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5882), 1,
      anon_sym_LBRACK,
    ACTIONS(5876), 2,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    ACTIONS(3832), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3824), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [56019] = 51,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6871), 1,
      anon_sym_DOT_STAR,
    ACTIONS(6873), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(7148), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7150), 1,
      anon_sym_COMMA,
    ACTIONS(7154), 1,
      anon_sym_DASH,
    ACTIONS(7156), 1,
      anon_sym_PLUS,
    ACTIONS(7158), 1,
      anon_sym_STAR,
    ACTIONS(7160), 1,
      anon_sym_SLASH,
    ACTIONS(7162), 1,
      anon_sym_PERCENT,
    ACTIONS(7164), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7166), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7168), 1,
      anon_sym_PIPE,
    ACTIONS(7170), 1,
      anon_sym_CARET,
    ACTIONS(7172), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_EQ_EQ,
    ACTIONS(7176), 1,
      anon_sym_BANG_EQ,
    ACTIONS(7178), 1,
      anon_sym_GT,
    ACTIONS(7180), 1,
      anon_sym_GT_EQ,
    ACTIONS(7182), 1,
      anon_sym_LT_EQ,
    ACTIONS(7184), 1,
      anon_sym_LT,
    ACTIONS(7186), 1,
      anon_sym_LT_LT,
    ACTIONS(7188), 1,
      anon_sym_GT_GT,
    ACTIONS(7190), 1,
      anon_sym_EQ,
    ACTIONS(7192), 1,
      anon_sym_QMARK,
    ACTIONS(7194), 1,
      anon_sym_STAR_EQ,
    ACTIONS(7196), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(7198), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(7200), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(7202), 1,
      anon_sym_DASH_EQ,
    ACTIONS(7204), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(7206), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(7208), 1,
      anon_sym_AMP_EQ,
    ACTIONS(7210), 1,
      anon_sym_CARET_EQ,
    ACTIONS(7212), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(7214), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7216), 1,
      anon_sym_or,
    ACTIONS(7218), 1,
      anon_sym_and,
    ACTIONS(7220), 1,
      anon_sym_bitor,
    ACTIONS(7222), 1,
      anon_sym_xor,
    ACTIONS(7224), 1,
      anon_sym_bitand,
    ACTIONS(7226), 1,
      anon_sym_not_eq,
    ACTIONS(7251), 1,
      anon_sym_RPAREN,
    STATE(1683), 1,
      sym__binary_fold_operator,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    STATE(8023), 1,
      sym__fold_operator,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [56175] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5497), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [56235] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6266), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6268), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [56295] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5188), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5882), 1,
      anon_sym_LBRACK,
    ACTIONS(5876), 2,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    ACTIONS(3832), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3824), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [56361] = 51,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6871), 1,
      anon_sym_DOT_STAR,
    ACTIONS(6873), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(7148), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7150), 1,
      anon_sym_COMMA,
    ACTIONS(7154), 1,
      anon_sym_DASH,
    ACTIONS(7156), 1,
      anon_sym_PLUS,
    ACTIONS(7158), 1,
      anon_sym_STAR,
    ACTIONS(7160), 1,
      anon_sym_SLASH,
    ACTIONS(7162), 1,
      anon_sym_PERCENT,
    ACTIONS(7164), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7166), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7168), 1,
      anon_sym_PIPE,
    ACTIONS(7170), 1,
      anon_sym_CARET,
    ACTIONS(7172), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_EQ_EQ,
    ACTIONS(7176), 1,
      anon_sym_BANG_EQ,
    ACTIONS(7178), 1,
      anon_sym_GT,
    ACTIONS(7180), 1,
      anon_sym_GT_EQ,
    ACTIONS(7182), 1,
      anon_sym_LT_EQ,
    ACTIONS(7184), 1,
      anon_sym_LT,
    ACTIONS(7186), 1,
      anon_sym_LT_LT,
    ACTIONS(7188), 1,
      anon_sym_GT_GT,
    ACTIONS(7190), 1,
      anon_sym_EQ,
    ACTIONS(7192), 1,
      anon_sym_QMARK,
    ACTIONS(7194), 1,
      anon_sym_STAR_EQ,
    ACTIONS(7196), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(7198), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(7200), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(7202), 1,
      anon_sym_DASH_EQ,
    ACTIONS(7204), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(7206), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(7208), 1,
      anon_sym_AMP_EQ,
    ACTIONS(7210), 1,
      anon_sym_CARET_EQ,
    ACTIONS(7212), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(7214), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7216), 1,
      anon_sym_or,
    ACTIONS(7218), 1,
      anon_sym_and,
    ACTIONS(7220), 1,
      anon_sym_bitor,
    ACTIONS(7222), 1,
      anon_sym_xor,
    ACTIONS(7224), 1,
      anon_sym_bitand,
    ACTIONS(7226), 1,
      anon_sym_not_eq,
    ACTIONS(7253), 1,
      anon_sym_RPAREN,
    STATE(1683), 1,
      sym__binary_fold_operator,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    STATE(8023), 1,
      sym__fold_operator,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [56517] = 51,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6871), 1,
      anon_sym_DOT_STAR,
    ACTIONS(6873), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(7148), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7150), 1,
      anon_sym_COMMA,
    ACTIONS(7154), 1,
      anon_sym_DASH,
    ACTIONS(7156), 1,
      anon_sym_PLUS,
    ACTIONS(7158), 1,
      anon_sym_STAR,
    ACTIONS(7160), 1,
      anon_sym_SLASH,
    ACTIONS(7162), 1,
      anon_sym_PERCENT,
    ACTIONS(7164), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7166), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7168), 1,
      anon_sym_PIPE,
    ACTIONS(7170), 1,
      anon_sym_CARET,
    ACTIONS(7172), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_EQ_EQ,
    ACTIONS(7176), 1,
      anon_sym_BANG_EQ,
    ACTIONS(7178), 1,
      anon_sym_GT,
    ACTIONS(7180), 1,
      anon_sym_GT_EQ,
    ACTIONS(7182), 1,
      anon_sym_LT_EQ,
    ACTIONS(7184), 1,
      anon_sym_LT,
    ACTIONS(7186), 1,
      anon_sym_LT_LT,
    ACTIONS(7188), 1,
      anon_sym_GT_GT,
    ACTIONS(7190), 1,
      anon_sym_EQ,
    ACTIONS(7192), 1,
      anon_sym_QMARK,
    ACTIONS(7194), 1,
      anon_sym_STAR_EQ,
    ACTIONS(7196), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(7198), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(7200), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(7202), 1,
      anon_sym_DASH_EQ,
    ACTIONS(7204), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(7206), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(7208), 1,
      anon_sym_AMP_EQ,
    ACTIONS(7210), 1,
      anon_sym_CARET_EQ,
    ACTIONS(7212), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(7214), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7216), 1,
      anon_sym_or,
    ACTIONS(7218), 1,
      anon_sym_and,
    ACTIONS(7220), 1,
      anon_sym_bitor,
    ACTIONS(7222), 1,
      anon_sym_xor,
    ACTIONS(7224), 1,
      anon_sym_bitand,
    ACTIONS(7226), 1,
      anon_sym_not_eq,
    ACTIONS(7255), 1,
      anon_sym_RPAREN,
    STATE(1683), 1,
      sym__binary_fold_operator,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    STATE(8023), 1,
      sym__fold_operator,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [56673] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6233), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6235), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [56747] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7261), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7265), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7263), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 10,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [56827] = 51,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6871), 1,
      anon_sym_DOT_STAR,
    ACTIONS(6873), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(7148), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7150), 1,
      anon_sym_COMMA,
    ACTIONS(7154), 1,
      anon_sym_DASH,
    ACTIONS(7156), 1,
      anon_sym_PLUS,
    ACTIONS(7158), 1,
      anon_sym_STAR,
    ACTIONS(7160), 1,
      anon_sym_SLASH,
    ACTIONS(7162), 1,
      anon_sym_PERCENT,
    ACTIONS(7164), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7166), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7168), 1,
      anon_sym_PIPE,
    ACTIONS(7170), 1,
      anon_sym_CARET,
    ACTIONS(7172), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_EQ_EQ,
    ACTIONS(7176), 1,
      anon_sym_BANG_EQ,
    ACTIONS(7178), 1,
      anon_sym_GT,
    ACTIONS(7180), 1,
      anon_sym_GT_EQ,
    ACTIONS(7182), 1,
      anon_sym_LT_EQ,
    ACTIONS(7184), 1,
      anon_sym_LT,
    ACTIONS(7186), 1,
      anon_sym_LT_LT,
    ACTIONS(7188), 1,
      anon_sym_GT_GT,
    ACTIONS(7190), 1,
      anon_sym_EQ,
    ACTIONS(7192), 1,
      anon_sym_QMARK,
    ACTIONS(7194), 1,
      anon_sym_STAR_EQ,
    ACTIONS(7196), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(7198), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(7200), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(7202), 1,
      anon_sym_DASH_EQ,
    ACTIONS(7204), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(7206), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(7208), 1,
      anon_sym_AMP_EQ,
    ACTIONS(7210), 1,
      anon_sym_CARET_EQ,
    ACTIONS(7212), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(7214), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7216), 1,
      anon_sym_or,
    ACTIONS(7218), 1,
      anon_sym_and,
    ACTIONS(7220), 1,
      anon_sym_bitor,
    ACTIONS(7222), 1,
      anon_sym_xor,
    ACTIONS(7224), 1,
      anon_sym_bitand,
    ACTIONS(7226), 1,
      anon_sym_not_eq,
    ACTIONS(7267), 1,
      anon_sym_RPAREN,
    STATE(1683), 1,
      sym__binary_fold_operator,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    STATE(8023), 1,
      sym__fold_operator,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [56983] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6339), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6341), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [57043] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6107), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6109), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [57103] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6229), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6231), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [57163] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6885), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7083), 1,
      anon_sym_DASH_GT,
    ACTIONS(7269), 1,
      anon_sym_requires,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(4897), 1,
      sym__function_attributes_start,
    STATE(5058), 1,
      sym_ref_qualifier,
    STATE(5803), 1,
      sym__function_attributes_end,
    STATE(5988), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(4195), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4344), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5900), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5336), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(6875), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [57273] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6150), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6152), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [57333] = 51,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6871), 1,
      anon_sym_DOT_STAR,
    ACTIONS(6873), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(7148), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7150), 1,
      anon_sym_COMMA,
    ACTIONS(7154), 1,
      anon_sym_DASH,
    ACTIONS(7156), 1,
      anon_sym_PLUS,
    ACTIONS(7158), 1,
      anon_sym_STAR,
    ACTIONS(7160), 1,
      anon_sym_SLASH,
    ACTIONS(7162), 1,
      anon_sym_PERCENT,
    ACTIONS(7164), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7166), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7168), 1,
      anon_sym_PIPE,
    ACTIONS(7170), 1,
      anon_sym_CARET,
    ACTIONS(7172), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_EQ_EQ,
    ACTIONS(7176), 1,
      anon_sym_BANG_EQ,
    ACTIONS(7178), 1,
      anon_sym_GT,
    ACTIONS(7180), 1,
      anon_sym_GT_EQ,
    ACTIONS(7182), 1,
      anon_sym_LT_EQ,
    ACTIONS(7184), 1,
      anon_sym_LT,
    ACTIONS(7186), 1,
      anon_sym_LT_LT,
    ACTIONS(7188), 1,
      anon_sym_GT_GT,
    ACTIONS(7190), 1,
      anon_sym_EQ,
    ACTIONS(7192), 1,
      anon_sym_QMARK,
    ACTIONS(7194), 1,
      anon_sym_STAR_EQ,
    ACTIONS(7196), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(7198), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(7200), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(7202), 1,
      anon_sym_DASH_EQ,
    ACTIONS(7204), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(7206), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(7208), 1,
      anon_sym_AMP_EQ,
    ACTIONS(7210), 1,
      anon_sym_CARET_EQ,
    ACTIONS(7212), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(7214), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7216), 1,
      anon_sym_or,
    ACTIONS(7218), 1,
      anon_sym_and,
    ACTIONS(7220), 1,
      anon_sym_bitor,
    ACTIONS(7222), 1,
      anon_sym_xor,
    ACTIONS(7224), 1,
      anon_sym_bitand,
    ACTIONS(7226), 1,
      anon_sym_not_eq,
    ACTIONS(7271), 1,
      anon_sym_RPAREN,
    STATE(1683), 1,
      sym__binary_fold_operator,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    STATE(8023), 1,
      sym__fold_operator,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [57489] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5391), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5393), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [57549] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6249), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6251), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [57621] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6327), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6329), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [57695] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6331), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6333), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [57769] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6703), 1,
      anon_sym_EQ,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7273), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7275), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7277), 1,
      anon_sym_PIPE,
    ACTIONS(7281), 1,
      anon_sym_AMP,
    ACTIONS(7287), 1,
      anon_sym_GT_EQ,
    ACTIONS(7289), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7291), 1,
      anon_sym_or,
    ACTIONS(7293), 1,
      anon_sym_and,
    ACTIONS(7295), 1,
      anon_sym_bitor,
    ACTIONS(7297), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7261), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7265), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7279), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7263), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7283), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7285), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6705), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [57875] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6302), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6304), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [57947] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3631), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3633), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [58007] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6695), 1,
      anon_sym_EQ,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7273), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7275), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7277), 1,
      anon_sym_PIPE,
    ACTIONS(7281), 1,
      anon_sym_AMP,
    ACTIONS(7287), 1,
      anon_sym_GT_EQ,
    ACTIONS(7289), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7291), 1,
      anon_sym_or,
    ACTIONS(7293), 1,
      anon_sym_and,
    ACTIONS(7295), 1,
      anon_sym_bitor,
    ACTIONS(7297), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7261), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7265), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7279), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7263), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7283), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7285), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6697), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [58113] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6496), 1,
      anon_sym_EQ,
    ACTIONS(6632), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7273), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7275), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7277), 1,
      anon_sym_PIPE,
    ACTIONS(7281), 1,
      anon_sym_AMP,
    ACTIONS(7287), 1,
      anon_sym_GT_EQ,
    ACTIONS(7289), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7291), 1,
      anon_sym_or,
    ACTIONS(7293), 1,
      anon_sym_and,
    ACTIONS(7295), 1,
      anon_sym_bitor,
    ACTIONS(7297), 1,
      anon_sym_bitand,
    ACTIONS(7299), 1,
      anon_sym_QMARK,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7261), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7265), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7279), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7263), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7283), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7285), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6498), 15,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [58223] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5353), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5355), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [58283] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6140), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6142), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [58343] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7301), 1,
      anon_sym_LT,
    STATE(2415), 1,
      sym_template_argument_list,
    ACTIONS(6306), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6308), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [58407] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6144), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6146), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [58467] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6253), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6255), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [58527] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5451), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5453), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [58587] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7263), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [58663] = 51,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(6871), 1,
      anon_sym_DOT_STAR,
    ACTIONS(6873), 1,
      anon_sym_DASH_GT_STAR,
    ACTIONS(7148), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7150), 1,
      anon_sym_COMMA,
    ACTIONS(7154), 1,
      anon_sym_DASH,
    ACTIONS(7156), 1,
      anon_sym_PLUS,
    ACTIONS(7158), 1,
      anon_sym_STAR,
    ACTIONS(7160), 1,
      anon_sym_SLASH,
    ACTIONS(7162), 1,
      anon_sym_PERCENT,
    ACTIONS(7164), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7166), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7168), 1,
      anon_sym_PIPE,
    ACTIONS(7170), 1,
      anon_sym_CARET,
    ACTIONS(7172), 1,
      anon_sym_AMP,
    ACTIONS(7174), 1,
      anon_sym_EQ_EQ,
    ACTIONS(7176), 1,
      anon_sym_BANG_EQ,
    ACTIONS(7178), 1,
      anon_sym_GT,
    ACTIONS(7180), 1,
      anon_sym_GT_EQ,
    ACTIONS(7182), 1,
      anon_sym_LT_EQ,
    ACTIONS(7184), 1,
      anon_sym_LT,
    ACTIONS(7186), 1,
      anon_sym_LT_LT,
    ACTIONS(7188), 1,
      anon_sym_GT_GT,
    ACTIONS(7190), 1,
      anon_sym_EQ,
    ACTIONS(7192), 1,
      anon_sym_QMARK,
    ACTIONS(7194), 1,
      anon_sym_STAR_EQ,
    ACTIONS(7196), 1,
      anon_sym_SLASH_EQ,
    ACTIONS(7198), 1,
      anon_sym_PERCENT_EQ,
    ACTIONS(7200), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(7202), 1,
      anon_sym_DASH_EQ,
    ACTIONS(7204), 1,
      anon_sym_LT_LT_EQ,
    ACTIONS(7206), 1,
      anon_sym_GT_GT_EQ,
    ACTIONS(7208), 1,
      anon_sym_AMP_EQ,
    ACTIONS(7210), 1,
      anon_sym_CARET_EQ,
    ACTIONS(7212), 1,
      anon_sym_PIPE_EQ,
    ACTIONS(7214), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7216), 1,
      anon_sym_or,
    ACTIONS(7218), 1,
      anon_sym_and,
    ACTIONS(7220), 1,
      anon_sym_bitor,
    ACTIONS(7222), 1,
      anon_sym_xor,
    ACTIONS(7224), 1,
      anon_sym_bitand,
    ACTIONS(7226), 1,
      anon_sym_not_eq,
    ACTIONS(7304), 1,
      anon_sym_RPAREN,
    STATE(1683), 1,
      sym__binary_fold_operator,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    STATE(8023), 1,
      sym__fold_operator,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [58819] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6154), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6156), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [58879] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6196), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6198), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [58941] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6292), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [59015] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7275), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7277), 1,
      anon_sym_PIPE,
    ACTIONS(7281), 1,
      anon_sym_AMP,
    ACTIONS(7287), 1,
      anon_sym_GT_EQ,
    ACTIONS(7289), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7293), 1,
      anon_sym_and,
    ACTIONS(7295), 1,
      anon_sym_bitor,
    ACTIONS(7297), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6292), 2,
      anon_sym_EQ,
      anon_sym_or,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7261), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7265), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7279), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7263), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7283), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7285), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [59117] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7277), 1,
      anon_sym_PIPE,
    ACTIONS(7281), 1,
      anon_sym_AMP,
    ACTIONS(7287), 1,
      anon_sym_GT_EQ,
    ACTIONS(7289), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7295), 1,
      anon_sym_bitor,
    ACTIONS(7297), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7261), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7265), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7279), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(6292), 3,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
    ACTIONS(7263), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7283), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7285), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [59215] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7281), 1,
      anon_sym_AMP,
    ACTIONS(7287), 1,
      anon_sym_GT_EQ,
    ACTIONS(7289), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7297), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7261), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7265), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7279), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7263), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7283), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7285), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 4,
      anon_sym_PIPE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
    ACTIONS(6294), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
  [59309] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5887), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5885), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [59369] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7281), 1,
      anon_sym_AMP,
    ACTIONS(7287), 1,
      anon_sym_GT_EQ,
    ACTIONS(7289), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7297), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7261), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7265), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7263), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7283), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7285), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 6,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
  [59461] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7306), 1,
      sym_identifier,
    STATE(3409), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(5974), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(5976), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5669), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5667), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [59529] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7301), 1,
      anon_sym_LT,
    STATE(3348), 1,
      sym_template_argument_list,
    ACTIONS(6306), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6308), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [59593] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7287), 1,
      anon_sym_GT_EQ,
    ACTIONS(7289), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7261), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7265), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7263), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7283), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7285), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
  [59681] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7287), 1,
      anon_sym_GT_EQ,
    ACTIONS(7289), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7261), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7265), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7263), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7285), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [59767] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7289), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7261), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7265), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7263), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 10,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [59849] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7261), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7263), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 12,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6294), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [59927] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6270), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
    ACTIONS(6272), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [60001] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7308), 1,
      anon_sym_LT,
    STATE(3571), 1,
      sym_template_argument_list,
    ACTIONS(6204), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6206), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [60067] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6699), 1,
      anon_sym_EQ,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7273), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7275), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7277), 1,
      anon_sym_PIPE,
    ACTIONS(7281), 1,
      anon_sym_AMP,
    ACTIONS(7287), 1,
      anon_sym_GT_EQ,
    ACTIONS(7289), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7291), 1,
      anon_sym_or,
    ACTIONS(7293), 1,
      anon_sym_and,
    ACTIONS(7295), 1,
      anon_sym_bitor,
    ACTIONS(7297), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7261), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7265), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7279), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7263), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7283), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7285), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6701), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [60173] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6632), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(6670), 1,
      anon_sym_EQ,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7273), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7275), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7277), 1,
      anon_sym_PIPE,
    ACTIONS(7281), 1,
      anon_sym_AMP,
    ACTIONS(7287), 1,
      anon_sym_GT_EQ,
    ACTIONS(7289), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7291), 1,
      anon_sym_or,
    ACTIONS(7293), 1,
      anon_sym_and,
    ACTIONS(7295), 1,
      anon_sym_bitor,
    ACTIONS(7297), 1,
      anon_sym_bitand,
    ACTIONS(7299), 1,
      anon_sym_QMARK,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7261), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7265), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7279), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7263), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7283), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7285), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6672), 15,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [60283] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6688), 1,
      anon_sym_EQ,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7273), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7275), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7277), 1,
      anon_sym_PIPE,
    ACTIONS(7281), 1,
      anon_sym_AMP,
    ACTIONS(7287), 1,
      anon_sym_GT_EQ,
    ACTIONS(7289), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7291), 1,
      anon_sym_or,
    ACTIONS(7293), 1,
      anon_sym_and,
    ACTIONS(7295), 1,
      anon_sym_bitor,
    ACTIONS(7297), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7261), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7265), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7279), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7263), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7283), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7285), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6690), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [60389] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6343), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6345), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [60449] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6731), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_literal_suffix,
    ACTIONS(6733), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [60509] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5475), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5477), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [60569] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6630), 1,
      anon_sym_EQ,
    ACTIONS(6632), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7273), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7275), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7277), 1,
      anon_sym_PIPE,
    ACTIONS(7281), 1,
      anon_sym_AMP,
    ACTIONS(7287), 1,
      anon_sym_GT_EQ,
    ACTIONS(7289), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7291), 1,
      anon_sym_or,
    ACTIONS(7293), 1,
      anon_sym_and,
    ACTIONS(7295), 1,
      anon_sym_bitor,
    ACTIONS(7297), 1,
      anon_sym_bitand,
    ACTIONS(7299), 1,
      anon_sym_QMARK,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6239), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7261), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7265), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7279), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7263), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7283), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7285), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6634), 15,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
  [60679] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3657), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3659), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [60739] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7313), 25,
      anon_sym_LPAREN2,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      sym_number_literal,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(7311), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      sym_primitive_type,
      anon_sym_not,
      anon_sym_compl,
      anon_sym_sizeof,
      anon_sym___alignof__,
      anon_sym___alignof,
      anon_sym__alignof,
      anon_sym_alignof,
      anon_sym__Alignof,
      anon_sym_offsetof,
      anon_sym__Generic,
      anon_sym_asm,
      anon_sym___asm__,
      sym_true,
      sym_false,
      anon_sym_NULL,
      anon_sym_nullptr,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_delete,
      anon_sym_co_await,
      anon_sym_new,
      anon_sym_requires,
      sym_this,
  [60799] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7025), 1,
      anon_sym_LT,
    STATE(1130), 1,
      sym_template_argument_list,
    ACTIONS(6306), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6308), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [60863] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7075), 1,
      anon_sym_LT,
    STATE(1134), 1,
      sym_template_argument_list,
    ACTIONS(6306), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6308), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [60927] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6335), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6337), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [60987] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    STATE(2390), 1,
      sym_template_argument_list,
    STATE(3696), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7315), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5294), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5296), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [61055] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7317), 1,
      anon_sym_LT,
    STATE(3571), 1,
      sym_template_argument_list,
    ACTIONS(6189), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6191), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [61121] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6111), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6113), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [61181] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6101), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6103), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [61241] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5427), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5429), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [61300] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6443), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6445), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [61359] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5467), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5469), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [61418] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5164), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5166), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [61477] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5467), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5469), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [61536] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5467), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5469), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [61595] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6399), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6401), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [61654] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6403), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6405), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [61713] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5137), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5139), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [61772] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5796), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5798), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [61831] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3631), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(3633), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [61890] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5499), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5501), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [61949] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6253), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6255), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [62008] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5491), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5493), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [62067] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5157), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5159), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [62126] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6343), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6345), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [62185] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7320), 1,
      anon_sym_LBRACK_RBRACK,
    ACTIONS(6278), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6280), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [62246] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5133), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5135), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [62305] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7322), 1,
      sym_identifier,
    STATE(3595), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(5210), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(5212), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5669), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5667), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [62372] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6435), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6437), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [62431] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6504), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6506), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [62490] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6516), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6518), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [62549] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5137), 21,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5139), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [62608] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5157), 21,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5159), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [62667] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1931), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1929), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [62726] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(63), 1,
      anon_sym_const,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7330), 1,
      anon_sym_DASH_GT,
    ACTIONS(7332), 1,
      anon_sym_requires,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(4976), 1,
      sym__function_attributes_start,
    STATE(5140), 1,
      sym_ref_qualifier,
    STATE(5914), 1,
      sym__function_attributes_end,
    STATE(6031), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7232), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7328), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4182), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4310), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6072), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5357), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(6875), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
    ACTIONS(7324), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [62835] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6508), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6510), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [62894] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6469), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6471), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [62953] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3741), 1,
      anon_sym_LBRACE,
    ACTIONS(6741), 1,
      anon_sym_LPAREN2,
    STATE(3934), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6089), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6091), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [63018] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5970), 1,
      anon_sym_EQ,
    ACTIONS(5972), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
    ACTIONS(3832), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(3824), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [63081] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6512), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6514), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [63140] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5771), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5773), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [63199] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1931), 21,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(1929), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [63258] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7335), 1,
      anon_sym_LT,
    STATE(2390), 1,
      sym_template_argument_list,
    STATE(2520), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5190), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(3822), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(3830), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
  [63327] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6439), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6441), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [63386] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6407), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6409), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [63445] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6288), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6290), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [63504] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6395), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6397), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [63563] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4041), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4037), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [63622] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6733), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
    ACTIONS(6731), 27,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
  [63681] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6323), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6325), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [63740] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6225), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6227), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [63799] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6225), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6227), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [63858] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6369), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6371), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [63917] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1947), 21,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(1945), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [63976] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(63), 1,
      anon_sym_const,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7330), 1,
      anon_sym_DASH_GT,
    ACTIONS(7337), 1,
      anon_sym_requires,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(4968), 1,
      sym__function_attributes_start,
    STATE(5195), 1,
      sym_ref_qualifier,
    STATE(5926), 1,
      sym__function_attributes_end,
    STATE(6039), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7328), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4182), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4310), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6072), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5352), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(6875), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
    ACTIONS(7324), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [64085] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7339), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7341), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7343), 1,
      anon_sym_or,
    ACTIONS(7345), 1,
      anon_sym_and,
    ACTIONS(5231), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5233), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [64152] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5123), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5125), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [64211] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7347), 1,
      anon_sym_LT,
    STATE(3696), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3814), 1,
      sym_template_argument_list,
    ACTIONS(7315), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(3822), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(3830), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [64280] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6419), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6421), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [64339] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5515), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5517), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [64398] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6107), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6109), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [64457] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5318), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5320), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [64516] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6266), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6268), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [64575] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6484), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6486), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [64634] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5176), 21,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5178), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [64693] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6225), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6227), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [64752] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5929), 3,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
    ACTIONS(3832), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3824), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [64813] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6140), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6142), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [64872] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6339), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6341), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [64931] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6144), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6146), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [64990] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5318), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5320), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [65049] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5168), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5170), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [65108] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6111), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6113), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [65167] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5887), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5885), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [65226] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7349), 1,
      sym_identifier,
    ACTIONS(7354), 1,
      sym_primitive_type,
    STATE(3614), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7352), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5338), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5336), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [65293] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6093), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6095), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [65352] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6097), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6099), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [65411] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6121), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6123), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [65470] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6125), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6127), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [65529] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6411), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6413), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [65588] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6154), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6156), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [65647] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5775), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5777), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [65706] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6365), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6367), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [65765] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3741), 1,
      anon_sym_LBRACE,
    ACTIONS(6741), 1,
      anon_sym_LPAREN2,
    STATE(3842), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6136), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6138), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [65830] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    STATE(2390), 1,
      sym_template_argument_list,
    STATE(2520), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5190), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5294), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(5296), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
  [65897] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5149), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5151), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [65956] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7341), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7345), 1,
      anon_sym_and,
    ACTIONS(5252), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5254), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [66019] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5141), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5143), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [66078] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6532), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6534), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [66137] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1947), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1945), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [66196] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5149), 21,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5151), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [66255] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6465), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6467), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [66314] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6477), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6479), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [66373] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6520), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6522), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [66432] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6101), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6103), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [66491] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5463), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5465), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [66550] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5419), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5421), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [66609] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6524), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6526), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [66668] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6528), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6530), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [66727] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6439), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6441), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [66786] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6196), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6198), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [66847] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4045), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [66906] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5443), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5445), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [66965] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5447), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5449), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [67024] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7356), 1,
      anon_sym_LT,
    STATE(2436), 1,
      sym_template_argument_list,
    ACTIONS(6306), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6308), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [67087] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5141), 21,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5143), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [67146] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5129), 21,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5131), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [67205] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5172), 21,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5174), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [67264] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5525), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5527), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [67323] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5533), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5535), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [67382] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6359), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6361), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [67441] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5549), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5551), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [67500] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4045), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [67559] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5525), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5527), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [67618] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7075), 1,
      anon_sym_LT,
    STATE(1133), 1,
      sym_template_argument_list,
    ACTIONS(6306), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6308), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [67681] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7356), 1,
      anon_sym_LT,
    STATE(3358), 1,
      sym_template_argument_list,
    ACTIONS(6306), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6308), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [67744] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5483), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5485), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [67803] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4045), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [67862] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4045), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [67921] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4045), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [67980] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6473), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6475), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [68039] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6150), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6152), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [68098] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4045), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [68157] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5168), 21,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5170), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [68216] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7359), 1,
      sym_identifier,
    STATE(3595), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(7362), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(7365), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5651), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5649), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [68283] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5459), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5461), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [68342] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6347), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6349), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [68401] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6355), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6357), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [68460] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6544), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6546), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [68519] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5423), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5425), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [68578] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5541), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5543), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [68637] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6211), 1,
      sym_literal_suffix,
    ACTIONS(3824), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
    ACTIONS(3832), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
  [68698] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6540), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6542), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [68757] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3741), 1,
      anon_sym_LBRACE,
    ACTIONS(6741), 1,
      anon_sym_LPAREN2,
    STATE(3979), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6162), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6164), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [68822] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5471), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5473), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [68881] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5123), 21,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5125), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [68940] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5455), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5457), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [68999] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6536), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6538), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [69058] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3832), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3824), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [69117] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6211), 1,
      sym_literal_suffix,
    ACTIONS(5840), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
    ACTIONS(5838), 26,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
  [69178] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6488), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6490), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [69237] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6431), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6433), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [69296] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6262), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6264), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [69355] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5224), 1,
      sym_primitive_type,
    STATE(2374), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5766), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5312), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5315), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [69420] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5119), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5121), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [69479] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5119), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5121), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [69538] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5119), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5121), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [69597] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6245), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6247), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [69656] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5439), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5441), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [69715] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5145), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5147), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [69774] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5172), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5174), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [69833] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6278), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6280), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [69892] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5479), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5481), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [69951] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5113), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5115), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [70010] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5431), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5433), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [70069] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5164), 21,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5166), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [70128] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5507), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5509), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [70187] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4999), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2202), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [70246] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6500), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6502), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [70305] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7368), 1,
      sym_identifier,
    STATE(3498), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(5210), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(5212), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5663), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5661), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [70372] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6335), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6337), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [70431] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3657), 21,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(3659), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [70490] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6415), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6417), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [70549] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(63), 1,
      anon_sym_const,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7235), 1,
      anon_sym_requires,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(4965), 1,
      sym__function_attributes_start,
    STATE(5084), 1,
      sym_ref_qualifier,
    STATE(5799), 1,
      sym_trailing_return_type,
    STATE(5890), 1,
      sym__function_attributes_end,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7232), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7328), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4182), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4310), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6072), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5356), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(6875), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
    ACTIONS(7324), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [70658] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6449), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6451), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [70717] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6496), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6498), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [70776] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3741), 1,
      anon_sym_LBRACE,
    ACTIONS(6741), 1,
      anon_sym_LPAREN2,
    STATE(3961), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6117), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6119), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [70841] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6427), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6429), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [70900] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6457), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6459), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [70959] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6492), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6494), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [71018] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6351), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6353), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [71077] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6453), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6455), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [71136] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6229), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6231), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [71195] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(63), 1,
      anon_sym_const,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7142), 1,
      anon_sym_requires,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(4969), 1,
      sym__function_attributes_start,
    STATE(5119), 1,
      sym_ref_qualifier,
    STATE(5797), 1,
      sym_trailing_return_type,
    STATE(5929), 1,
      sym__function_attributes_end,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7328), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4182), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4310), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6072), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5345), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(6875), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
    ACTIONS(7324), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [71304] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5503), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5505), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [71363] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5511), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5513), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [71422] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5145), 21,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5147), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [71481] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5537), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5539), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [71540] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5779), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5781), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [71599] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5176), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5178), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [71658] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5487), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5489), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [71717] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5129), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5131), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [71776] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5545), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5547), 35,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      sym_auto,
      anon_sym_decltype,
      anon_sym_DASH_GT_STAR,
  [71835] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5119), 21,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5121), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [71894] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5119), 21,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5121), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [71953] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5119), 21,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5121), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [72012] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5113), 21,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(5115), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [72071] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6461), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6463), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [72130] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3832), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3824), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [72189] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4045), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [72247] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4045), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [72305] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6703), 1,
      anon_sym_EQ,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7214), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7380), 1,
      anon_sym_PIPE,
    ACTIONS(7382), 1,
      anon_sym_CARET,
    ACTIONS(7384), 1,
      anon_sym_AMP,
    ACTIONS(7390), 1,
      anon_sym_GT_EQ,
    ACTIONS(7394), 1,
      anon_sym_bitor,
    ACTIONS(7396), 1,
      anon_sym_xor,
    ACTIONS(7398), 1,
      anon_sym_bitand,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7372), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7376), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7378), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7374), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7386), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7388), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6705), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_DASH_GT_STAR,
  [72407] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6532), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6534), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [72465] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1899), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(1901), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [72523] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6359), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6361), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [72581] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6365), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6367), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [72639] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5206), 2,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
    ACTIONS(5208), 12,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
    ACTIONS(3824), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
    ACTIONS(3832), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
  [72701] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6331), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
    ACTIONS(6333), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
  [72773] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3728), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7400), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5353), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5355), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [72835] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6504), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6506), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [72893] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6743), 1,
      anon_sym_LBRACK,
    STATE(3826), 1,
      sym_new_declarator,
    ACTIONS(6221), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6223), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [72955] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6347), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6349), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [73013] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6302), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
    ACTIONS(6304), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_GT_STAR,
  [73083] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1925), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(1927), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [73141] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3760), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7402), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5387), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5389), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [73203] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3760), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7402), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5377), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5379), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [73265] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1891), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(1893), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [73323] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1887), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(1889), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [73381] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7404), 1,
      anon_sym_DASH_GT,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(4992), 1,
      sym__function_attributes_start,
    STATE(5282), 1,
      sym_ref_qualifier,
    STATE(6039), 1,
      sym_trailing_return_type,
    STATE(6087), 1,
      sym__function_attributes_end,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4195), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4344), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6072), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5365), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(6875), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [73489] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6630), 1,
      anon_sym_EQ,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7148), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7192), 1,
      anon_sym_QMARK,
    ACTIONS(7214), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7380), 1,
      anon_sym_PIPE,
    ACTIONS(7382), 1,
      anon_sym_CARET,
    ACTIONS(7384), 1,
      anon_sym_AMP,
    ACTIONS(7390), 1,
      anon_sym_GT_EQ,
    ACTIONS(7394), 1,
      anon_sym_bitor,
    ACTIONS(7396), 1,
      anon_sym_xor,
    ACTIONS(7398), 1,
      anon_sym_bitand,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7372), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7376), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7378), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7374), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7386), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7388), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6634), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_DASH_GT_STAR,
  [73595] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6435), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6437), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [73653] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6461), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6463), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [73711] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6403), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6405), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [73769] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6399), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6401), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [73827] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6443), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6445), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [73885] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6688), 1,
      anon_sym_EQ,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7214), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7380), 1,
      anon_sym_PIPE,
    ACTIONS(7382), 1,
      anon_sym_CARET,
    ACTIONS(7384), 1,
      anon_sym_AMP,
    ACTIONS(7390), 1,
      anon_sym_GT_EQ,
    ACTIONS(7394), 1,
      anon_sym_bitor,
    ACTIONS(7396), 1,
      anon_sym_xor,
    ACTIONS(7398), 1,
      anon_sym_bitand,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7372), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7376), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7378), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7374), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7386), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7388), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6690), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_DASH_GT_STAR,
  [73987] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7408), 1,
      anon_sym_STAR,
    ACTIONS(7410), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7412), 1,
      anon_sym_AMP,
    ACTIONS(7414), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    STATE(3122), 1,
      sym_parameter_list,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(5881), 1,
      sym__abstract_declarator,
    STATE(5936), 1,
      sym__function_declarator_seq,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7416), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7418), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4013), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4223), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
    ACTIONS(5905), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [74081] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5129), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5131), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [74139] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6323), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6325), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [74197] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1895), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(1897), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [74255] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5176), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5178), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [74313] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5137), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5139), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [74371] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5157), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5159), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [74429] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3854), 1,
      anon_sym_EQ,
    ACTIONS(3928), 1,
      anon_sym_SEMI,
    ACTIONS(5188), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5876), 1,
      anon_sym_LPAREN2,
    ACTIONS(5882), 1,
      anon_sym_LBRACK,
    ACTIONS(3856), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
    ACTIONS(3824), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(3832), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
  [74499] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5836), 1,
      sym_literal_suffix,
    STATE(3361), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(5974), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(5976), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5838), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(5840), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [74565] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3760), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7402), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5347), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5349), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [74627] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5172), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5174), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [74685] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5836), 1,
      sym_literal_suffix,
    STATE(3361), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(5974), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(5976), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(3832), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(3824), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [74751] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7422), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7424), 1,
      anon_sym_and,
    ACTIONS(5252), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5254), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [74813] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5149), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5151), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [74871] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6670), 1,
      anon_sym_EQ,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7148), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7192), 1,
      anon_sym_QMARK,
    ACTIONS(7214), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7380), 1,
      anon_sym_PIPE,
    ACTIONS(7382), 1,
      anon_sym_CARET,
    ACTIONS(7384), 1,
      anon_sym_AMP,
    ACTIONS(7390), 1,
      anon_sym_GT_EQ,
    ACTIONS(7394), 1,
      anon_sym_bitor,
    ACTIONS(7396), 1,
      anon_sym_xor,
    ACTIONS(7398), 1,
      anon_sym_bitand,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7372), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7376), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7378), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7374), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7386), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7388), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6672), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_DASH_GT_STAR,
  [74977] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6327), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
    ACTIONS(6329), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
  [75049] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6278), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6280), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [75107] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1903), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(1905), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [75165] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6457), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6459), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [75223] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6465), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6467), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [75281] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6500), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6502), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [75339] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(63), 1,
      anon_sym_const,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7426), 1,
      anon_sym_DASH_GT,
    ACTIONS(7428), 1,
      anon_sym_requires,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(5012), 1,
      sym__function_attributes_start,
    STATE(5269), 1,
      sym_ref_qualifier,
    STATE(6096), 1,
      sym__function_attributes_end,
    STATE(6109), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7232), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7328), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4182), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4310), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6072), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5371), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(6875), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
    ACTIONS(7324), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [75447] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6496), 1,
      anon_sym_EQ,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7148), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7192), 1,
      anon_sym_QMARK,
    ACTIONS(7214), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7380), 1,
      anon_sym_PIPE,
    ACTIONS(7382), 1,
      anon_sym_CARET,
    ACTIONS(7384), 1,
      anon_sym_AMP,
    ACTIONS(7390), 1,
      anon_sym_GT_EQ,
    ACTIONS(7394), 1,
      anon_sym_bitor,
    ACTIONS(7396), 1,
      anon_sym_xor,
    ACTIONS(7398), 1,
      anon_sym_bitand,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7372), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7376), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7378), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7374), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7386), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7388), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6498), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_DASH_GT_STAR,
  [75553] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6512), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6514), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [75611] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6524), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6526), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [75669] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6508), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6510), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [75727] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6496), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6498), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [75785] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7347), 1,
      anon_sym_LT,
    STATE(3814), 1,
      sym_template_argument_list,
    ACTIONS(1941), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_COLON,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(1943), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [75849] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7408), 1,
      anon_sym_STAR,
    ACTIONS(7410), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7412), 1,
      anon_sym_AMP,
    ACTIONS(7414), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    STATE(3122), 1,
      sym_parameter_list,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(5869), 1,
      sym__abstract_declarator,
    STATE(5936), 1,
      sym__function_declarator_seq,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7416), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7418), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3687), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4231), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
    ACTIONS(5891), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [75943] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6427), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6429), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [76001] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3675), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7431), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5367), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5369), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [76063] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7422), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7424), 1,
      anon_sym_and,
    ACTIONS(7433), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7435), 1,
      anon_sym_or,
    ACTIONS(5231), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5233), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [76129] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6355), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6357), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [76187] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6415), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6417), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [76245] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3676), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7437), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5381), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5383), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [76307] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6369), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6371), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [76365] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6431), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6433), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [76423] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6477), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6479), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [76481] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1961), 2,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
    ACTIONS(4063), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4058), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [76541] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6540), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6542), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [76599] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6536), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6538), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [76657] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3760), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7402), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5373), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5375), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [76719] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3832), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(3824), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [76777] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1917), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(1919), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [76835] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6439), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6441), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [76893] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6469), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6471), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [76951] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6343), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6345), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [77009] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6492), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6494), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [77067] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6288), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6290), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [77125] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3832), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(3824), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [77183] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6544), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6546), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [77241] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6395), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6397), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [77299] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6699), 1,
      anon_sym_EQ,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7214), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7380), 1,
      anon_sym_PIPE,
    ACTIONS(7382), 1,
      anon_sym_CARET,
    ACTIONS(7384), 1,
      anon_sym_AMP,
    ACTIONS(7390), 1,
      anon_sym_GT_EQ,
    ACTIONS(7394), 1,
      anon_sym_bitor,
    ACTIONS(7396), 1,
      anon_sym_xor,
    ACTIONS(7398), 1,
      anon_sym_bitand,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7372), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7376), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7378), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7374), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7386), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7388), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6701), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_DASH_GT_STAR,
  [77401] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6516), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6518), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [77459] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6225), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6227), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [77517] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6054), 1,
      anon_sym_EQ,
    ACTIONS(6056), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
    ACTIONS(3832), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(3824), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [77579] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5887), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5885), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [77637] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5141), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5143), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [77695] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7439), 1,
      anon_sym_DASH_GT,
    ACTIONS(7441), 1,
      anon_sym_requires,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(5029), 1,
      sym__function_attributes_start,
    STATE(5253), 1,
      sym_ref_qualifier,
    STATE(6043), 1,
      sym__function_attributes_end,
    STATE(6117), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4195), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4344), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6072), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5381), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(6875), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_GT2,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [77803] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1931), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(1929), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [77861] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6528), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6530), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [77919] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6339), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6341), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [77977] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6225), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6227), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [78035] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6473), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6475), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [78093] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5145), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5147), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [78151] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5113), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5115), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [78209] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1947), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(1945), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [78267] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6488), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6490), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [78325] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6484), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6486), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [78383] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7332), 1,
      anon_sym_requires,
    ACTIONS(7404), 1,
      anon_sym_DASH_GT,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(5043), 1,
      sym__function_attributes_start,
    STATE(5227), 1,
      sym_ref_qualifier,
    STATE(6000), 1,
      sym__function_attributes_end,
    STATE(6031), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7232), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4195), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4344), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6072), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5376), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(6875), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [78491] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6520), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6522), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [78549] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7374), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
    ACTIONS(6294), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
  [78623] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6292), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
    ACTIONS(6294), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
  [78695] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3760), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7443), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5224), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5226), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [78757] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6310), 1,
      anon_sym_LT,
    STATE(2502), 1,
      sym_template_argument_list,
    ACTIONS(6306), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6308), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [78819] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6270), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
    ACTIONS(6272), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
  [78891] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6262), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6264), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [78949] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6245), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6247), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [79007] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6292), 1,
      anon_sym_EQ,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7214), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7380), 1,
      anon_sym_PIPE,
    ACTIONS(7382), 1,
      anon_sym_CARET,
    ACTIONS(7384), 1,
      anon_sym_AMP,
    ACTIONS(7390), 1,
      anon_sym_GT_EQ,
    ACTIONS(7394), 1,
      anon_sym_bitor,
    ACTIONS(7396), 1,
      anon_sym_xor,
    ACTIONS(7398), 1,
      anon_sym_bitand,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7372), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7378), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7374), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7386), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7388), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_or,
      anon_sym_DASH_GT_STAR,
  [79107] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6225), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6227), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [79165] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7446), 1,
      anon_sym_LT,
    STATE(3814), 1,
      sym_template_argument_list,
    ACTIONS(1933), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_COLON,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(1935), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [79229] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6695), 1,
      anon_sym_EQ,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7214), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7380), 1,
      anon_sym_PIPE,
    ACTIONS(7382), 1,
      anon_sym_CARET,
    ACTIONS(7384), 1,
      anon_sym_AMP,
    ACTIONS(7390), 1,
      anon_sym_GT_EQ,
    ACTIONS(7394), 1,
      anon_sym_bitor,
    ACTIONS(7396), 1,
      anon_sym_xor,
    ACTIONS(7398), 1,
      anon_sym_bitand,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7372), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7376), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7378), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7374), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7386), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7388), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6697), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_DASH_GT_STAR,
  [79331] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6351), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6353), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [79389] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5123), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5125), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [79447] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6249), 14,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
    ACTIONS(6251), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_GT_STAR,
  [79517] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6453), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6455), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [79575] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6449), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6451), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [79633] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6292), 1,
      anon_sym_EQ,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7214), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7380), 1,
      anon_sym_PIPE,
    ACTIONS(7382), 1,
      anon_sym_CARET,
    ACTIONS(7384), 1,
      anon_sym_AMP,
    ACTIONS(7390), 1,
      anon_sym_GT_EQ,
    ACTIONS(7394), 1,
      anon_sym_bitor,
    ACTIONS(7396), 1,
      anon_sym_xor,
    ACTIONS(7398), 1,
      anon_sym_bitand,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7372), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7374), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7386), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7388), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_DASH_GT_STAR,
  [79731] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7372), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7374), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
    ACTIONS(6294), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
  [79809] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4999), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(2202), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [79867] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4041), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4037), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [79925] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7214), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7382), 1,
      anon_sym_CARET,
    ACTIONS(7384), 1,
      anon_sym_AMP,
    ACTIONS(7390), 1,
      anon_sym_GT_EQ,
    ACTIONS(7396), 1,
      anon_sym_xor,
    ACTIONS(7398), 1,
      anon_sym_bitand,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6292), 2,
      anon_sym_PIPE,
      anon_sym_EQ,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7372), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7374), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7386), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7388), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_DASH_GT_STAR,
  [80019] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6407), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6409), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [80077] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7372), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7374), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 9,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
    ACTIONS(6294), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
  [80153] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6411), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6413), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [80211] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5164), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5166), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [80269] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7214), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7384), 1,
      anon_sym_AMP,
    ACTIONS(7390), 1,
      anon_sym_GT_EQ,
    ACTIONS(7398), 1,
      anon_sym_bitand,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7372), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6292), 3,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_EQ,
    ACTIONS(7374), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7386), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7388), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_DASH_GT_STAR,
  [80359] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4045), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [80417] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7214), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7390), 1,
      anon_sym_GT_EQ,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7372), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7374), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7386), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7388), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 4,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
    ACTIONS(6294), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_DASH_GT_STAR,
  [80503] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6419), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6421), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [80561] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5168), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5170), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [80619] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4045), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [80677] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7214), 1,
      anon_sym_LT_EQ_GT,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7372), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7374), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(6292), 7,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_EQ,
    ACTIONS(6294), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
  [80757] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4045), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [80815] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7428), 1,
      anon_sym_requires,
    ACTIONS(7439), 1,
      anon_sym_DASH_GT,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(4987), 1,
      sym__function_attributes_start,
    STATE(5248), 1,
      sym_ref_qualifier,
    STATE(6063), 1,
      sym__function_attributes_end,
    STATE(6109), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7232), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4195), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4344), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6072), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5370), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(6875), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_GT2,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [80923] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(4045), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [80981] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6439), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(6441), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [81039] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(63), 1,
      anon_sym_const,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7426), 1,
      anon_sym_DASH_GT,
    ACTIONS(7441), 1,
      anon_sym_requires,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(4982), 1,
      sym__function_attributes_start,
    STATE(5249), 1,
      sym_ref_qualifier,
    STATE(5990), 1,
      sym__function_attributes_end,
    STATE(6117), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7328), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4182), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4310), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6072), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5379), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(6875), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
    ACTIONS(7324), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [81147] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5949), 1,
      anon_sym_EQ,
    ACTIONS(5951), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
    ACTIONS(3832), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(3824), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [81209] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5119), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5121), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [81267] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5119), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5121), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [81325] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5119), 20,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
    ACTIONS(5121), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [81383] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    ACTIONS(6825), 1,
      anon_sym_LBRACK,
    ACTIONS(7061), 1,
      anon_sym_DOT_STAR,
    ACTIONS(7214), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7390), 1,
      anon_sym_GT_EQ,
    STATE(3507), 1,
      sym_subscript_argument_list,
    STATE(3514), 1,
      sym_argument_list,
    ACTIONS(6869), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(7228), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7372), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7392), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7374), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(7388), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 4,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ,
    ACTIONS(6294), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_GT_STAR,
  [81467] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1899), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(1901), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [81524] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1903), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(1905), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [81581] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6087), 1,
      sym_literal_suffix,
    ACTIONS(5838), 22,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5840), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [81640] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7449), 1,
      anon_sym_LBRACK,
    STATE(3959), 1,
      sym_new_declarator,
    ACTIONS(6221), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6223), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [81701] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6087), 1,
      sym_literal_suffix,
    ACTIONS(3832), 22,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3824), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [81760] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1953), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(1955), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [81819] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1953), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(1955), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [81878] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6211), 1,
      sym_literal_suffix,
    STATE(3630), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(5210), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(5212), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(5838), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(5840), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [81943] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1969), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(1971), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [82002] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6731), 23,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      anon_sym_DASH_GT,
      sym_literal_suffix,
    ACTIONS(6733), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [82059] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7132), 1,
      anon_sym___attribute__,
    ACTIONS(7451), 1,
      anon_sym_COLON,
    ACTIONS(7453), 1,
      anon_sym_LBRACE,
    STATE(4023), 1,
      sym__enum_base_clause,
    STATE(4061), 1,
      sym_enumerator_list,
    STATE(4119), 1,
      sym_attribute_specifier,
    ACTIONS(5689), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5691), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [82128] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1949), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(1951), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [82185] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6211), 1,
      sym_literal_suffix,
    STATE(3630), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(5210), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(5212), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(3832), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(3824), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [82250] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(3728), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7400), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5318), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5320), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [82311] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1959), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(1961), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [82368] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1895), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(1897), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [82425] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1891), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(1893), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [82482] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1925), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(1927), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [82539] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7457), 1,
      anon_sym_RPAREN,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(7276), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [82644] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7132), 1,
      anon_sym___attribute__,
    ACTIONS(7451), 1,
      anon_sym_COLON,
    ACTIONS(7453), 1,
      anon_sym_LBRACE,
    STATE(4007), 1,
      sym__enum_base_clause,
    STATE(4052), 1,
      sym_enumerator_list,
    STATE(4104), 1,
      sym_attribute_specifier,
    ACTIONS(5636), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5638), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [82713] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1887), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(1889), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [82770] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1961), 2,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
    ACTIONS(4063), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(4058), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [82829] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7414), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7463), 1,
      anon_sym_STAR,
    ACTIONS(7465), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7467), 1,
      anon_sym_AMP,
    STATE(3299), 1,
      sym_parameter_list,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(5970), 1,
      sym__abstract_declarator,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7416), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7418), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4013), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4245), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5905), 11,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [82922] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7414), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7463), 1,
      anon_sym_STAR,
    ACTIONS(7465), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7467), 1,
      anon_sym_AMP,
    STATE(3299), 1,
      sym_parameter_list,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(5952), 1,
      sym__abstract_declarator,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7416), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7418), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3822), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4242), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5891), 11,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [83015] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3854), 1,
      anon_sym_EQ,
    ACTIONS(3928), 1,
      anon_sym_SEMI,
    ACTIONS(3856), 13,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_and_eq,
      anon_sym_or_eq,
      anon_sym_xor_eq,
    ACTIONS(3824), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(3832), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_xor,
      anon_sym_DOT,
  [83078] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1917), 23,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(1919), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [83135] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6229), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6231), 33,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [83192] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5796), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5798), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [83249] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5779), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5781), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [83306] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5775), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5777), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [83363] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5771), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5773), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [83420] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6524), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6526), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [83476] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5149), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5151), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [83532] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4910), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8472), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4000), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [83634] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1947), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1945), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [83690] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8467), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [83792] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6355), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6357), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [83848] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4910), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8452), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4000), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [83950] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8447), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [84052] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4910), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8430), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4000), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [84154] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4395), 1,
      sym_type_specifier,
    STATE(6051), 1,
      sym_type_descriptor,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4035), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [84256] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5157), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5159), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [84312] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6399), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6401), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [84368] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6403), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6405), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [84424] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8424), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [84526] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6431), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6433), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [84582] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4910), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8405), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4000), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [84684] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8399), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [84786] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7449), 1,
      anon_sym_LBRACK,
    ACTIONS(7469), 1,
      anon_sym_LPAREN2,
    ACTIONS(7471), 1,
      sym_auto,
    ACTIONS(7473), 1,
      anon_sym_decltype,
    STATE(4068), 1,
      sym_new_declarator,
    STATE(4118), 1,
      sym_decltype_auto,
    STATE(3984), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5868), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5870), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [84858] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3832), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(3824), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [84914] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5137), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5139), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [84970] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(3766), 1,
      anon_sym_enum,
    ACTIONS(3768), 1,
      anon_sym_class,
    ACTIONS(3770), 1,
      anon_sym_struct,
    ACTIONS(3772), 1,
      anon_sym_union,
    ACTIONS(3796), 1,
      sym_auto,
    ACTIONS(3798), 1,
      anon_sym_decltype,
    ACTIONS(3800), 1,
      anon_sym_typename,
    ACTIONS(7475), 1,
      sym_identifier,
    ACTIONS(7477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7479), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2571), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2980), 1,
      sym_decltype_auto,
    STATE(3011), 1,
      sym_qualified_type_identifier,
    STATE(4353), 1,
      sym_type_specifier,
    STATE(6051), 1,
      sym_type_descriptor,
    STATE(6482), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2937), 2,
      sym_decltype,
      sym_template_type,
    STATE(4039), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3762), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2981), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [85072] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6488), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6490), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [85128] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7481), 1,
      sym_identifier,
    ACTIONS(7483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7487), 1,
      sym_primitive_type,
    ACTIONS(7489), 1,
      anon_sym_enum,
    ACTIONS(7491), 1,
      anon_sym_class,
    ACTIONS(7493), 1,
      anon_sym_struct,
    ACTIONS(7495), 1,
      anon_sym_union,
    ACTIONS(7497), 1,
      sym_auto,
    ACTIONS(7499), 1,
      anon_sym_decltype,
    ACTIONS(7501), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(4283), 1,
      sym_type_specifier,
    STATE(4291), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5018), 1,
      sym_decltype_auto,
    STATE(5045), 1,
      sym_qualified_type_identifier,
    STATE(6051), 1,
      sym_type_descriptor,
    STATE(6459), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3997), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(4972), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7485), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4980), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [85230] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4910), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8202), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4000), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [85332] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6528), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6530), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [85388] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7503), 1,
      sym_identifier,
    ACTIONS(7507), 1,
      sym_primitive_type,
    ACTIONS(7509), 1,
      anon_sym_enum,
    ACTIONS(7511), 1,
      anon_sym_class,
    ACTIONS(7513), 1,
      anon_sym_struct,
    ACTIONS(7515), 1,
      anon_sym_union,
    ACTIONS(7517), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(5052), 1,
      sym_type_specifier,
    STATE(5080), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5610), 1,
      sym__type_definition_type,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4006), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7505), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [85490] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5775), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5777), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [85546] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5771), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5773), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [85602] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8327), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [85704] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6435), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6437), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [85760] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3928), 1,
      anon_sym_SEMI,
    ACTIONS(5836), 1,
      sym_literal_suffix,
    STATE(2868), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(3858), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(3860), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
    ACTIONS(3832), 15,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(3824), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [85826] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5796), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5798), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [85882] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6473), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6475), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [85938] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5123), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5125), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [85994] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5779), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5781), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [86050] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4910), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8246), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4000), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [86152] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8223), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [86254] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7503), 1,
      sym_identifier,
    ACTIONS(7507), 1,
      sym_primitive_type,
    ACTIONS(7509), 1,
      anon_sym_enum,
    ACTIONS(7511), 1,
      anon_sym_class,
    ACTIONS(7513), 1,
      anon_sym_struct,
    ACTIONS(7515), 1,
      anon_sym_union,
    ACTIONS(7517), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(5052), 1,
      sym_type_specifier,
    STATE(5080), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5581), 1,
      sym__type_definition_type,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4006), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7505), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [86356] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7519), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7521), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5231), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5233), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [86416] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7449), 1,
      anon_sym_LBRACK,
    ACTIONS(7469), 1,
      anon_sym_LPAREN2,
    ACTIONS(7471), 1,
      sym_auto,
    ACTIONS(7473), 1,
      anon_sym_decltype,
    STATE(4058), 1,
      sym_new_declarator,
    STATE(4118), 1,
      sym_decltype_auto,
    STATE(4002), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5850), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5852), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [86488] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7335), 1,
      anon_sym_LT,
    STATE(2390), 1,
      sym_template_argument_list,
    ACTIONS(1941), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(1943), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
  [86550] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5141), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5143), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [86606] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4041), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4037), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [86662] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7449), 1,
      anon_sym_LBRACK,
    ACTIONS(7469), 1,
      anon_sym_LPAREN2,
    ACTIONS(7471), 1,
      sym_auto,
    ACTIONS(7473), 1,
      anon_sym_decltype,
    STATE(4073), 1,
      sym_new_declarator,
    STATE(4118), 1,
      sym_decltype_auto,
    STATE(4018), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5872), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5874), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [86734] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6407), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6409), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [86790] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5164), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5166), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [86846] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6249), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6251), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [86914] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5771), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5773), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [86970] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6435), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6437), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [87026] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7523), 1,
      sym_identifier,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7529), 1,
      sym_primitive_type,
    ACTIONS(7531), 1,
      anon_sym_enum,
    ACTIONS(7533), 1,
      anon_sym_class,
    ACTIONS(7535), 1,
      anon_sym_struct,
    ACTIONS(7537), 1,
      anon_sym_union,
    ACTIONS(7539), 1,
      sym_auto,
    ACTIONS(7541), 1,
      anon_sym_decltype,
    ACTIONS(7543), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(4229), 1,
      sym_type_specifier,
    STATE(4236), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4885), 1,
      sym_qualified_type_identifier,
    STATE(4919), 1,
      sym_decltype_auto,
    STATE(5891), 1,
      sym_type_descriptor,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2252), 2,
      sym_decltype,
      sym_template_type,
    STATE(4010), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7527), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4898), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [87128] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5119), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5121), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [87184] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8425), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [87286] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5119), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5121), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [87342] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8354), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [87444] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(5891), 1,
      sym_type_descriptor,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [87546] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7503), 1,
      sym_identifier,
    ACTIONS(7507), 1,
      sym_primitive_type,
    ACTIONS(7509), 1,
      anon_sym_enum,
    ACTIONS(7511), 1,
      anon_sym_class,
    ACTIONS(7513), 1,
      anon_sym_struct,
    ACTIONS(7515), 1,
      anon_sym_union,
    ACTIONS(7517), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(5052), 1,
      sym_type_specifier,
    STATE(5080), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5565), 1,
      sym__type_definition_type,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4006), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7505), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [87648] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7503), 1,
      sym_identifier,
    ACTIONS(7507), 1,
      sym_primitive_type,
    ACTIONS(7509), 1,
      anon_sym_enum,
    ACTIONS(7511), 1,
      anon_sym_class,
    ACTIONS(7513), 1,
      anon_sym_struct,
    ACTIONS(7515), 1,
      anon_sym_union,
    ACTIONS(7517), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(5052), 1,
      sym_type_specifier,
    STATE(5080), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5576), 1,
      sym__type_definition_type,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4006), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7505), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [87750] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7529), 1,
      sym_primitive_type,
    ACTIONS(7539), 1,
      sym_auto,
    ACTIONS(7541), 1,
      anon_sym_decltype,
    ACTIONS(7545), 1,
      sym_identifier,
    ACTIONS(7547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7549), 1,
      anon_sym_enum,
    ACTIONS(7551), 1,
      anon_sym_class,
    ACTIONS(7553), 1,
      anon_sym_struct,
    ACTIONS(7555), 1,
      anon_sym_union,
    ACTIONS(7557), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(4088), 1,
      sym_type_specifier,
    STATE(4236), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4885), 1,
      sym_qualified_type_identifier,
    STATE(4919), 1,
      sym_decltype_auto,
    STATE(5891), 1,
      sym_type_descriptor,
    STATE(6475), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2252), 2,
      sym_decltype,
      sym_template_type,
    STATE(4026), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7527), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4898), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [87852] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7503), 1,
      sym_identifier,
    ACTIONS(7507), 1,
      sym_primitive_type,
    ACTIONS(7509), 1,
      anon_sym_enum,
    ACTIONS(7511), 1,
      anon_sym_class,
    ACTIONS(7513), 1,
      anon_sym_struct,
    ACTIONS(7515), 1,
      anon_sym_union,
    ACTIONS(7517), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(5052), 1,
      sym_type_specifier,
    STATE(5080), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5577), 1,
      sym__type_definition_type,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4006), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7505), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [87954] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6465), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6467), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [88010] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(63), 1,
      anon_sym_const,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7559), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7562), 1,
      anon_sym_DASH_GT,
    ACTIONS(7564), 1,
      anon_sym_requires,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(5081), 1,
      sym__function_attributes_start,
    STATE(5322), 1,
      sym_ref_qualifier,
    STATE(6133), 1,
      sym__function_attributes_end,
    STATE(6303), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6875), 2,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7328), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4182), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4310), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5900), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5393), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7324), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [88116] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8438), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [88218] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5119), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5121), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [88274] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7481), 1,
      sym_identifier,
    ACTIONS(7483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7487), 1,
      sym_primitive_type,
    ACTIONS(7489), 1,
      anon_sym_enum,
    ACTIONS(7491), 1,
      anon_sym_class,
    ACTIONS(7493), 1,
      anon_sym_struct,
    ACTIONS(7495), 1,
      anon_sym_union,
    ACTIONS(7497), 1,
      sym_auto,
    ACTIONS(7499), 1,
      anon_sym_decltype,
    ACTIONS(7501), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(4238), 1,
      sym_type_specifier,
    STATE(4291), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5018), 1,
      sym_decltype_auto,
    STATE(5045), 1,
      sym_qualified_type_identifier,
    STATE(6051), 1,
      sym_type_descriptor,
    STATE(6459), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3991), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(4972), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7485), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4980), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [88376] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6411), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6413), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [88432] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6443), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6445), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [88488] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7503), 1,
      sym_identifier,
    ACTIONS(7507), 1,
      sym_primitive_type,
    ACTIONS(7509), 1,
      anon_sym_enum,
    ACTIONS(7511), 1,
      anon_sym_class,
    ACTIONS(7513), 1,
      anon_sym_struct,
    ACTIONS(7515), 1,
      anon_sym_union,
    ACTIONS(7517), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(5052), 1,
      sym_type_specifier,
    STATE(5080), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5580), 1,
      sym__type_definition_type,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4006), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7505), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [88590] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7503), 1,
      sym_identifier,
    ACTIONS(7507), 1,
      sym_primitive_type,
    ACTIONS(7509), 1,
      anon_sym_enum,
    ACTIONS(7511), 1,
      anon_sym_class,
    ACTIONS(7513), 1,
      anon_sym_struct,
    ACTIONS(7515), 1,
      anon_sym_union,
    ACTIONS(7517), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(5052), 1,
      sym_type_specifier,
    STATE(5080), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5603), 1,
      sym__type_definition_type,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4006), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7505), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [88692] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6449), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6451), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [88748] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6453), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6455), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [88804] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6461), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6463), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [88860] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6302), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6304), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [88928] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7503), 1,
      sym_identifier,
    ACTIONS(7507), 1,
      sym_primitive_type,
    ACTIONS(7509), 1,
      anon_sym_enum,
    ACTIONS(7511), 1,
      anon_sym_class,
    ACTIONS(7513), 1,
      anon_sym_struct,
    ACTIONS(7515), 1,
      anon_sym_union,
    ACTIONS(7517), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(5052), 1,
      sym_type_specifier,
    STATE(5080), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5534), 1,
      sym__type_definition_type,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4006), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7505), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [89030] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7503), 1,
      sym_identifier,
    ACTIONS(7507), 1,
      sym_primitive_type,
    ACTIONS(7509), 1,
      anon_sym_enum,
    ACTIONS(7511), 1,
      anon_sym_class,
    ACTIONS(7513), 1,
      anon_sym_struct,
    ACTIONS(7515), 1,
      anon_sym_union,
    ACTIONS(7517), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(5052), 1,
      sym_type_specifier,
    STATE(5080), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5630), 1,
      sym__type_definition_type,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4006), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7505), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [89132] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6270), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6272), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
  [89202] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6504), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6506), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [89258] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7503), 1,
      sym_identifier,
    ACTIONS(7507), 1,
      sym_primitive_type,
    ACTIONS(7509), 1,
      anon_sym_enum,
    ACTIONS(7511), 1,
      anon_sym_class,
    ACTIONS(7513), 1,
      anon_sym_struct,
    ACTIONS(7515), 1,
      anon_sym_union,
    ACTIONS(7517), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(5052), 1,
      sym_type_specifier,
    STATE(5080), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5569), 1,
      sym__type_definition_type,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4006), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7505), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [89360] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(63), 1,
      anon_sym_const,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6888), 1,
      anon_sym_LBRACK,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7559), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7562), 1,
      anon_sym_DASH_GT,
    ACTIONS(7568), 1,
      anon_sym_requires,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(5191), 1,
      sym__function_attributes_start,
    STATE(5320), 1,
      sym_ref_qualifier,
    STATE(6123), 1,
      sym__function_attributes_end,
    STATE(6377), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6875), 2,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(6898), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(7328), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4182), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(4310), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5900), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5414), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(7324), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [89466] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7503), 1,
      sym_identifier,
    ACTIONS(7507), 1,
      sym_primitive_type,
    ACTIONS(7509), 1,
      anon_sym_enum,
    ACTIONS(7511), 1,
      anon_sym_class,
    ACTIONS(7513), 1,
      anon_sym_struct,
    ACTIONS(7515), 1,
      anon_sym_union,
    ACTIONS(7517), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(5052), 1,
      sym_type_specifier,
    STATE(5080), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5597), 1,
      sym__type_definition_type,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4006), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7505), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [89568] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6492), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6494), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [89624] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7503), 1,
      sym_identifier,
    ACTIONS(7507), 1,
      sym_primitive_type,
    ACTIONS(7509), 1,
      anon_sym_enum,
    ACTIONS(7511), 1,
      anon_sym_class,
    ACTIONS(7513), 1,
      anon_sym_struct,
    ACTIONS(7515), 1,
      anon_sym_union,
    ACTIONS(7517), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(5052), 1,
      sym_type_specifier,
    STATE(5080), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5600), 1,
      sym__type_definition_type,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4006), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7505), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [89726] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7503), 1,
      sym_identifier,
    ACTIONS(7507), 1,
      sym_primitive_type,
    ACTIONS(7509), 1,
      anon_sym_enum,
    ACTIONS(7511), 1,
      anon_sym_class,
    ACTIONS(7513), 1,
      anon_sym_struct,
    ACTIONS(7515), 1,
      anon_sym_union,
    ACTIONS(7517), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(5052), 1,
      sym_type_specifier,
    STATE(5080), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5563), 1,
      sym__type_definition_type,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4006), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7505), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [89828] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7571), 1,
      anon_sym_LT,
    STATE(2390), 1,
      sym_template_argument_list,
    ACTIONS(1933), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(1935), 36,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
  [89890] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7503), 1,
      sym_identifier,
    ACTIONS(7507), 1,
      sym_primitive_type,
    ACTIONS(7509), 1,
      anon_sym_enum,
    ACTIONS(7511), 1,
      anon_sym_class,
    ACTIONS(7513), 1,
      anon_sym_struct,
    ACTIONS(7515), 1,
      anon_sym_union,
    ACTIONS(7517), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(5052), 1,
      sym_type_specifier,
    STATE(5080), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5616), 1,
      sym__type_definition_type,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4006), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7505), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [89992] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6484), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6486), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [90048] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8423), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [90150] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7503), 1,
      sym_identifier,
    ACTIONS(7507), 1,
      sym_primitive_type,
    ACTIONS(7509), 1,
      anon_sym_enum,
    ACTIONS(7511), 1,
      anon_sym_class,
    ACTIONS(7513), 1,
      anon_sym_struct,
    ACTIONS(7515), 1,
      anon_sym_union,
    ACTIONS(7517), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(5052), 1,
      sym_type_specifier,
    STATE(5080), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5545), 1,
      sym__type_definition_type,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4006), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7505), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [90252] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6500), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6502), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [90308] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8190), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [90410] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7503), 1,
      sym_identifier,
    ACTIONS(7507), 1,
      sym_primitive_type,
    ACTIONS(7509), 1,
      anon_sym_enum,
    ACTIONS(7511), 1,
      anon_sym_class,
    ACTIONS(7513), 1,
      anon_sym_struct,
    ACTIONS(7515), 1,
      anon_sym_union,
    ACTIONS(7517), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(5052), 1,
      sym_type_specifier,
    STATE(5080), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5549), 1,
      sym__type_definition_type,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4006), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7505), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [90512] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(7977), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [90614] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8268), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [90716] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6508), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6510), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [90772] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8112), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [90874] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5775), 19,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(5777), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [90930] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7529), 1,
      sym_primitive_type,
    ACTIONS(7539), 1,
      sym_auto,
    ACTIONS(7541), 1,
      anon_sym_decltype,
    ACTIONS(7545), 1,
      sym_identifier,
    ACTIONS(7547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7549), 1,
      anon_sym_enum,
    ACTIONS(7551), 1,
      anon_sym_class,
    ACTIONS(7553), 1,
      anon_sym_struct,
    ACTIONS(7555), 1,
      anon_sym_union,
    ACTIONS(7557), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(4143), 1,
      sym_type_specifier,
    STATE(4236), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4885), 1,
      sym_qualified_type_identifier,
    STATE(4919), 1,
      sym_decltype_auto,
    STATE(5891), 1,
      sym_type_descriptor,
    STATE(6475), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2252), 2,
      sym_decltype,
      sym_template_type,
    STATE(4011), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7527), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4898), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [91032] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8065), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [91134] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4999), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(2202), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [91190] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8149), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [91292] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6292), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6294), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
  [91362] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6327), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6329), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
  [91432] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6512), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6514), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [91488] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5172), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5174), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [91544] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6477), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6479), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [91600] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7521), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5252), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5254), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [91658] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7503), 1,
      sym_identifier,
    ACTIONS(7507), 1,
      sym_primitive_type,
    ACTIONS(7509), 1,
      anon_sym_enum,
    ACTIONS(7511), 1,
      anon_sym_class,
    ACTIONS(7513), 1,
      anon_sym_struct,
    ACTIONS(7515), 1,
      anon_sym_union,
    ACTIONS(7517), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(5052), 1,
      sym_type_specifier,
    STATE(5080), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5621), 1,
      sym__type_definition_type,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4006), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7505), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [91760] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8089), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [91862] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6331), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6333), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
  [91932] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6496), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6498), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [91988] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4999), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(2202), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [92044] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8006), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [92146] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8012), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [92248] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8397), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [92350] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6516), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6518), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [92406] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6544), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6546), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [92462] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6347), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6349), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [92518] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(7925), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [92620] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6457), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6459), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [92676] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(7910), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [92778] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5176), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5178), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [92834] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6473), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6475), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [92890] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8083), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [92992] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5129), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5131), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [93048] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7503), 1,
      sym_identifier,
    ACTIONS(7507), 1,
      sym_primitive_type,
    ACTIONS(7509), 1,
      anon_sym_enum,
    ACTIONS(7511), 1,
      anon_sym_class,
    ACTIONS(7513), 1,
      anon_sym_struct,
    ACTIONS(7515), 1,
      anon_sym_union,
    ACTIONS(7517), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(5052), 1,
      sym_type_specifier,
    STATE(5080), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5589), 1,
      sym__type_definition_type,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4006), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7505), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [93150] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5796), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5798), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [93206] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8056), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [93308] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1931), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(1929), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [93364] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8038), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [93466] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6229), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6231), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [93522] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6351), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6353), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [93578] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6359), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6361), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [93634] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6520), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6522), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [93690] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5113), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5115), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [93746] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7449), 1,
      anon_sym_LBRACK,
    ACTIONS(7469), 1,
      anon_sym_LPAREN2,
    ACTIONS(7471), 1,
      sym_auto,
    ACTIONS(7473), 1,
      anon_sym_decltype,
    STATE(4070), 1,
      sym_new_declarator,
    STATE(4118), 1,
      sym_decltype_auto,
    STATE(4021), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5862), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5864), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [93818] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5145), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5147), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [93874] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(7972), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [93976] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6536), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6538), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [94032] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5168), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(5170), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [94088] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8251), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [94190] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5779), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5781), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [94246] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      sym_auto,
    ACTIONS(123), 1,
      anon_sym_decltype,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7574), 1,
      sym_identifier,
    ACTIONS(7578), 1,
      sym_primitive_type,
    ACTIONS(7580), 1,
      anon_sym_enum,
    ACTIONS(7582), 1,
      anon_sym_class,
    ACTIONS(7584), 1,
      anon_sym_struct,
    ACTIONS(7586), 1,
      anon_sym_union,
    ACTIONS(7588), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2279), 1,
      sym_qualified_type_identifier,
    STATE(2298), 1,
      sym_decltype_auto,
    STATE(4520), 1,
      sym_type_specifier,
    STATE(4678), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5891), 1,
      sym_type_descriptor,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2252), 2,
      sym_decltype,
      sym_template_type,
    STATE(3988), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7576), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2277), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [94348] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(7531), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [94450] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4910), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(8590), 1,
      sym_type_descriptor,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4000), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [94552] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(7895), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [94654] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(7871), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [94756] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6540), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6542), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [94812] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4751), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(7943), 1,
      sym_type_descriptor,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4004), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [94914] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(3766), 1,
      anon_sym_enum,
    ACTIONS(3768), 1,
      anon_sym_class,
    ACTIONS(3770), 1,
      anon_sym_struct,
    ACTIONS(3772), 1,
      anon_sym_union,
    ACTIONS(3796), 1,
      sym_auto,
    ACTIONS(3798), 1,
      anon_sym_decltype,
    ACTIONS(3800), 1,
      anon_sym_typename,
    ACTIONS(7475), 1,
      sym_identifier,
    ACTIONS(7477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7479), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2571), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2980), 1,
      sym_decltype_auto,
    STATE(3011), 1,
      sym_qualified_type_identifier,
    STATE(4368), 1,
      sym_type_specifier,
    STATE(6051), 1,
      sym_type_descriptor,
    STATE(6482), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2937), 2,
      sym_decltype,
      sym_template_type,
    STATE(4030), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3762), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2981), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [95016] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6532), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6534), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [95072] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6365), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6367), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [95128] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6355), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(6357), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [95184] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1953), 22,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(1955), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [95240] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4261), 1,
      sym_type_specifier,
    STATE(6051), 1,
      sym_type_descriptor,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(3987), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [95342] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6465), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6467), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [95397] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6477), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6479), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [95452] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6461), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6463), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [95507] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4293), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [95606] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      sym_auto,
    ACTIONS(123), 1,
      anon_sym_decltype,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7574), 1,
      sym_identifier,
    ACTIONS(7578), 1,
      sym_primitive_type,
    ACTIONS(7580), 1,
      anon_sym_enum,
    ACTIONS(7582), 1,
      anon_sym_class,
    ACTIONS(7584), 1,
      anon_sym_struct,
    ACTIONS(7586), 1,
      anon_sym_union,
    ACTIONS(7588), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2279), 1,
      sym_qualified_type_identifier,
    STATE(2298), 1,
      sym_decltype_auto,
    STATE(4483), 1,
      sym_type_specifier,
    STATE(4678), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2252), 2,
      sym_decltype,
      sym_template_type,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7576), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2277), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [95705] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6524), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6526), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [95760] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(3766), 1,
      anon_sym_enum,
    ACTIONS(3768), 1,
      anon_sym_class,
    ACTIONS(3770), 1,
      anon_sym_struct,
    ACTIONS(3772), 1,
      anon_sym_union,
    ACTIONS(3796), 1,
      sym_auto,
    ACTIONS(3798), 1,
      anon_sym_decltype,
    ACTIONS(3800), 1,
      anon_sym_typename,
    ACTIONS(7475), 1,
      sym_identifier,
    ACTIONS(7477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7479), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2571), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2980), 1,
      sym_decltype_auto,
    STATE(3011), 1,
      sym_qualified_type_identifier,
    STATE(4753), 1,
      sym_type_specifier,
    STATE(6482), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2937), 2,
      sym_decltype,
      sym_template_type,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3762), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2981), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [95859] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7481), 1,
      sym_identifier,
    ACTIONS(7483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7487), 1,
      sym_primitive_type,
    ACTIONS(7489), 1,
      anon_sym_enum,
    ACTIONS(7491), 1,
      anon_sym_class,
    ACTIONS(7493), 1,
      anon_sym_struct,
    ACTIONS(7495), 1,
      anon_sym_union,
    ACTIONS(7497), 1,
      sym_auto,
    ACTIONS(7499), 1,
      anon_sym_decltype,
    ACTIONS(7501), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(4243), 1,
      sym_type_specifier,
    STATE(4291), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5018), 1,
      sym_decltype_auto,
    STATE(5045), 1,
      sym_qualified_type_identifier,
    STATE(6459), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(4972), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7485), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4980), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [95958] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6453), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6455), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [96013] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6516), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6518), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [96068] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6544), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6546), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [96123] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7414), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7590), 1,
      anon_sym_STAR,
    ACTIONS(7592), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7594), 1,
      anon_sym_AMP,
    STATE(3354), 1,
      sym_parameter_list,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(6162), 1,
      sym__abstract_declarator,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7416), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7418), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4013), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4324), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5905), 9,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [96214] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7414), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7590), 1,
      anon_sym_STAR,
    ACTIONS(7592), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7594), 1,
      anon_sym_AMP,
    STATE(3354), 1,
      sym_parameter_list,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(6111), 1,
      sym__abstract_declarator,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7416), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7418), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(3995), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4394), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5891), 9,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [96305] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7481), 1,
      sym_identifier,
    ACTIONS(7483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7487), 1,
      sym_primitive_type,
    ACTIONS(7489), 1,
      anon_sym_enum,
    ACTIONS(7491), 1,
      anon_sym_class,
    ACTIONS(7493), 1,
      anon_sym_struct,
    ACTIONS(7495), 1,
      anon_sym_union,
    ACTIONS(7497), 1,
      sym_auto,
    ACTIONS(7499), 1,
      anon_sym_decltype,
    ACTIONS(7501), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(4264), 1,
      sym_type_specifier,
    STATE(4291), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(5018), 1,
      sym_decltype_auto,
    STATE(5045), 1,
      sym_qualified_type_identifier,
    STATE(6459), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(4972), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7485), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4980), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [96404] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6347), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6349), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [96459] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6449), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6451), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [96514] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4895), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [96613] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6399), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6401), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [96668] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6403), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6405), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [96723] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6504), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6506), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [96778] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4783), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [96877] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6528), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6530), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [96932] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7503), 1,
      sym_identifier,
    ACTIONS(7507), 1,
      sym_primitive_type,
    ACTIONS(7509), 1,
      anon_sym_enum,
    ACTIONS(7511), 1,
      anon_sym_class,
    ACTIONS(7513), 1,
      anon_sym_struct,
    ACTIONS(7515), 1,
      anon_sym_union,
    ACTIONS(7517), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(5048), 1,
      sym_type_specifier,
    STATE(5080), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7505), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [97031] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7132), 1,
      anon_sym___attribute__,
    ACTIONS(7453), 1,
      anon_sym_LBRACE,
    STATE(4078), 1,
      sym_enumerator_list,
    STATE(4148), 1,
      sym_attribute_specifier,
    ACTIONS(5519), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5521), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [97094] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6443), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6445), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [97149] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6536), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6538), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [97204] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7523), 1,
      sym_identifier,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7529), 1,
      sym_primitive_type,
    ACTIONS(7531), 1,
      anon_sym_enum,
    ACTIONS(7533), 1,
      anon_sym_class,
    ACTIONS(7535), 1,
      anon_sym_struct,
    ACTIONS(7537), 1,
      anon_sym_union,
    ACTIONS(7539), 1,
      sym_auto,
    ACTIONS(7541), 1,
      anon_sym_decltype,
    ACTIONS(7543), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(4230), 1,
      sym_type_specifier,
    STATE(4236), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4885), 1,
      sym_qualified_type_identifier,
    STATE(4919), 1,
      sym_decltype_auto,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2252), 2,
      sym_decltype,
      sym_template_type,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7527), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4898), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [97303] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7529), 1,
      sym_primitive_type,
    ACTIONS(7539), 1,
      sym_auto,
    ACTIONS(7541), 1,
      anon_sym_decltype,
    ACTIONS(7545), 1,
      sym_identifier,
    ACTIONS(7547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7549), 1,
      anon_sym_enum,
    ACTIONS(7551), 1,
      anon_sym_class,
    ACTIONS(7553), 1,
      anon_sym_struct,
    ACTIONS(7555), 1,
      anon_sym_union,
    ACTIONS(7557), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(4165), 1,
      sym_type_specifier,
    STATE(4236), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4885), 1,
      sym_qualified_type_identifier,
    STATE(4919), 1,
      sym_decltype_auto,
    STATE(6475), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2252), 2,
      sym_decltype,
      sym_template_type,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7527), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4898), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [97402] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6411), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6413), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [97457] = 7,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    ACTIONS(7603), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4013), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    ACTIONS(7600), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7598), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(7596), 28,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [97520] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5771), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5773), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [97575] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5796), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5798), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [97630] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6359), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6361), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [97685] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4041), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(4037), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [97740] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6457), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6459), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [97795] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3832), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(3824), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [97850] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    STATE(2390), 1,
      sym_template_argument_list,
    STATE(2666), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5204), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5294), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5296), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [97913] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6540), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6542), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [97968] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6407), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6409), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [98023] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7132), 1,
      anon_sym___attribute__,
    ACTIONS(7453), 1,
      anon_sym_LBRACE,
    STATE(4044), 1,
      sym_enumerator_list,
    STATE(4162), 1,
      sym_attribute_specifier,
    ACTIONS(5529), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5531), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [98086] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6520), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6522), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [98141] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6431), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6433), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [98196] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7529), 1,
      sym_primitive_type,
    ACTIONS(7539), 1,
      sym_auto,
    ACTIONS(7541), 1,
      anon_sym_decltype,
    ACTIONS(7545), 1,
      sym_identifier,
    ACTIONS(7547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7549), 1,
      anon_sym_enum,
    ACTIONS(7551), 1,
      anon_sym_class,
    ACTIONS(7553), 1,
      anon_sym_struct,
    ACTIONS(7555), 1,
      anon_sym_union,
    ACTIONS(7557), 1,
      anon_sym_typename,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(4080), 1,
      sym_type_specifier,
    STATE(4236), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4885), 1,
      sym_qualified_type_identifier,
    STATE(4919), 1,
      sym_decltype_auto,
    STATE(6475), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2252), 2,
      sym_decltype,
      sym_template_type,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7527), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4898), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [98295] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5779), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5781), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [98350] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6496), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6498), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [98405] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6532), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6534), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [98460] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(3766), 1,
      anon_sym_enum,
    ACTIONS(3768), 1,
      anon_sym_class,
    ACTIONS(3770), 1,
      anon_sym_struct,
    ACTIONS(3772), 1,
      anon_sym_union,
    ACTIONS(3796), 1,
      sym_auto,
    ACTIONS(3798), 1,
      anon_sym_decltype,
    ACTIONS(3800), 1,
      anon_sym_typename,
    ACTIONS(7475), 1,
      sym_identifier,
    ACTIONS(7477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7479), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2571), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2980), 1,
      sym_decltype_auto,
    STATE(3011), 1,
      sym_qualified_type_identifier,
    STATE(4414), 1,
      sym_type_specifier,
    STATE(6482), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2937), 2,
      sym_decltype,
      sym_template_type,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3762), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2981), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [98559] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6070), 1,
      anon_sym___attribute__,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(7606), 1,
      anon_sym_COLON,
    STATE(2455), 1,
      sym_attribute_specifier,
    STATE(2685), 1,
      sym__enum_base_clause,
    STATE(2724), 1,
      sym_enumerator_list,
    ACTIONS(5636), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_DOT,
    ACTIONS(5638), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
  [98626] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6070), 1,
      anon_sym___attribute__,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(7606), 1,
      anon_sym_COLON,
    STATE(2471), 1,
      sym_attribute_specifier,
    STATE(2668), 1,
      sym__enum_base_clause,
    STATE(2751), 1,
      sym_enumerator_list,
    ACTIONS(5689), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_DOT,
    ACTIONS(5691), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
  [98693] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6508), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6510), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [98748] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6492), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6494), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [98803] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4319), 1,
      sym_type_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [98902] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6512), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6514), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [98957] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5775), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(5777), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_GT2,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [99012] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6500), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6502), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [99067] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(3766), 1,
      anon_sym_enum,
    ACTIONS(3768), 1,
      anon_sym_class,
    ACTIONS(3770), 1,
      anon_sym_struct,
    ACTIONS(3772), 1,
      anon_sym_union,
    ACTIONS(3796), 1,
      sym_auto,
    ACTIONS(3798), 1,
      anon_sym_decltype,
    ACTIONS(3800), 1,
      anon_sym_typename,
    ACTIONS(7475), 1,
      sym_identifier,
    ACTIONS(7477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7479), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2571), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2980), 1,
      sym_decltype_auto,
    STATE(3011), 1,
      sym_qualified_type_identifier,
    STATE(4313), 1,
      sym_type_specifier,
    STATE(6482), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2937), 2,
      sym_decltype,
      sym_template_type,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3762), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2981), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [99166] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7449), 1,
      anon_sym_LBRACK,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    ACTIONS(7610), 1,
      sym_auto,
    ACTIONS(7612), 1,
      anon_sym_decltype,
    STATE(2460), 1,
      sym_decltype_auto,
    STATE(4218), 1,
      sym_new_declarator,
    STATE(4021), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5862), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_DOT,
    ACTIONS(5864), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [99236] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2605), 1,
      anon_sym_STAR,
    ACTIONS(2607), 1,
      anon_sym_AMP,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(6213), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5718), 1,
      sym__scope_resolution,
    STATE(6358), 1,
      sym__declarator,
    STATE(8582), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [99328] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7132), 1,
      anon_sym___attribute__,
    STATE(4163), 1,
      sym_attribute_specifier,
    ACTIONS(5583), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5585), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [99386] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7132), 1,
      anon_sym___attribute__,
    STATE(4112), 1,
      sym_attribute_specifier,
    ACTIONS(5606), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5608), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [99444] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7132), 1,
      anon_sym___attribute__,
    STATE(4116), 1,
      sym_attribute_specifier,
    ACTIONS(5587), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5589), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [99502] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7132), 1,
      anon_sym___attribute__,
    STATE(4120), 1,
      sym_attribute_specifier,
    ACTIONS(5595), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5597), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [99560] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6962), 1,
      anon_sym_STAR,
    ACTIONS(6964), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6966), 1,
      anon_sym_AMP,
    ACTIONS(6968), 1,
      anon_sym_COLON_COLON,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5741), 1,
      sym__scope_resolution,
    STATE(6444), 1,
      sym__declarator,
    STATE(7905), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [99652] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6310), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [99744] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7132), 1,
      anon_sym___attribute__,
    STATE(4109), 1,
      sym_attribute_specifier,
    ACTIONS(5567), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5569), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [99802] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7614), 1,
      anon_sym_STAR,
    ACTIONS(7616), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7618), 1,
      anon_sym_AMP,
    ACTIONS(7622), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    STATE(3399), 1,
      sym_parameter_list,
    STATE(5027), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6201), 1,
      sym__abstract_declarator,
    ACTIONS(7624), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7626), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4536), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(4872), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5905), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [99892] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2605), 1,
      anon_sym_STAR,
    ACTIONS(2607), 1,
      anon_sym_AMP,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(6213), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5718), 1,
      sym__scope_resolution,
    STATE(6310), 1,
      sym__declarator,
    STATE(8582), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [99984] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6936), 1,
      anon_sym_STAR,
    ACTIONS(6938), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6940), 1,
      anon_sym_AMP,
    ACTIONS(6942), 1,
      anon_sym_COLON_COLON,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5732), 1,
      sym__scope_resolution,
    STATE(6550), 1,
      sym__declarator,
    STATE(7980), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [100076] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7132), 1,
      anon_sym___attribute__,
    STATE(4135), 1,
      sym_attribute_specifier,
    ACTIONS(5610), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5612), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [100134] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7614), 1,
      anon_sym_STAR,
    ACTIONS(7616), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7618), 1,
      anon_sym_AMP,
    ACTIONS(7622), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    STATE(3399), 1,
      sym_parameter_list,
    STATE(5027), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6225), 1,
      sym__abstract_declarator,
    ACTIONS(7624), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7626), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4049), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4544), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5891), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [100224] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6936), 1,
      anon_sym_STAR,
    ACTIONS(6938), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6940), 1,
      anon_sym_AMP,
    ACTIONS(6942), 1,
      anon_sym_COLON_COLON,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5732), 1,
      sym__scope_resolution,
    STATE(6530), 1,
      sym__declarator,
    STATE(7980), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [100316] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6358), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [100408] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6928), 1,
      anon_sym_STAR,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5983), 1,
      sym__declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [100500] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6928), 1,
      anon_sym_STAR,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5886), 1,
      sym__declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [100592] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7469), 1,
      anon_sym_LPAREN2,
    STATE(4016), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6117), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6119), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [100652] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7449), 1,
      anon_sym_LBRACK,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    ACTIONS(7610), 1,
      sym_auto,
    ACTIONS(7612), 1,
      anon_sym_decltype,
    STATE(2460), 1,
      sym_decltype_auto,
    STATE(4232), 1,
      sym_new_declarator,
    STATE(3984), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5868), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_DOT,
    ACTIONS(5870), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [100722] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7449), 1,
      anon_sym_LBRACK,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    ACTIONS(7610), 1,
      sym_auto,
    ACTIONS(7612), 1,
      anon_sym_decltype,
    STATE(2460), 1,
      sym_decltype_auto,
    STATE(4213), 1,
      sym_new_declarator,
    STATE(4002), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5850), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_DOT,
    ACTIONS(5852), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [100792] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7132), 1,
      anon_sym___attribute__,
    STATE(4166), 1,
      sym_attribute_specifier,
    ACTIONS(5591), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5593), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [100850] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6936), 1,
      anon_sym_STAR,
    ACTIONS(6938), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6940), 1,
      anon_sym_AMP,
    ACTIONS(6942), 1,
      anon_sym_COLON_COLON,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5732), 1,
      sym__scope_resolution,
    STATE(6548), 1,
      sym__declarator,
    STATE(7980), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [100942] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6962), 1,
      anon_sym_STAR,
    ACTIONS(6964), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6966), 1,
      anon_sym_AMP,
    ACTIONS(6968), 1,
      anon_sym_COLON_COLON,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5741), 1,
      sym__scope_resolution,
    STATE(6483), 1,
      sym__declarator,
    STATE(7905), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [101034] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6928), 1,
      anon_sym_STAR,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5896), 1,
      sym__declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [101126] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7132), 1,
      anon_sym___attribute__,
    STATE(4145), 1,
      sym_attribute_specifier,
    ACTIONS(5575), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5577), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [101184] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6962), 1,
      anon_sym_STAR,
    ACTIONS(6964), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6966), 1,
      anon_sym_AMP,
    ACTIONS(6968), 1,
      anon_sym_COLON_COLON,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5741), 1,
      sym__scope_resolution,
    STATE(6493), 1,
      sym__declarator,
    STATE(7905), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [101276] = 7,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    ACTIONS(7637), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4067), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    ACTIONS(7634), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7598), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(7596), 25,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_template,
      anon_sym_operator,
      anon_sym_try,
      anon_sym_requires,
  [101338] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7469), 1,
      anon_sym_LPAREN2,
    STATE(4029), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6162), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6164), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [101398] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2605), 1,
      anon_sym_STAR,
    ACTIONS(2607), 1,
      anon_sym_AMP,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(6213), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5718), 1,
      sym__scope_resolution,
    STATE(6345), 1,
      sym__declarator,
    STATE(8582), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [101490] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7469), 1,
      anon_sym_LPAREN2,
    STATE(4001), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6136), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6138), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [101550] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7640), 1,
      anon_sym_LT,
    STATE(2666), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2895), 1,
      sym_template_argument_list,
    ACTIONS(5204), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(3822), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(3830), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [101614] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7132), 1,
      anon_sym___attribute__,
    STATE(4164), 1,
      sym_attribute_specifier,
    ACTIONS(5614), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5616), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [101672] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7469), 1,
      anon_sym_LPAREN2,
    STATE(3985), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6089), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6091), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [101732] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6345), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [101824] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7132), 1,
      anon_sym___attribute__,
    STATE(4149), 1,
      sym_attribute_specifier,
    ACTIONS(5571), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5573), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [101882] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7132), 1,
      anon_sym___attribute__,
    STATE(4158), 1,
      sym_attribute_specifier,
    ACTIONS(5599), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5601), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [101940] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7449), 1,
      anon_sym_LBRACK,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    ACTIONS(7610), 1,
      sym_auto,
    ACTIONS(7612), 1,
      anon_sym_decltype,
    STATE(2460), 1,
      sym_decltype_auto,
    STATE(4216), 1,
      sym_new_declarator,
    STATE(4018), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5872), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_DOT,
    ACTIONS(5874), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [102010] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7132), 1,
      anon_sym___attribute__,
    STATE(4153), 1,
      sym_attribute_specifier,
    ACTIONS(5579), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5581), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [102068] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5353), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5355), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [102121] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7408), 1,
      anon_sym_STAR,
    ACTIONS(7410), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7412), 1,
      anon_sym_AMP,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7644), 1,
      sym_auto,
    ACTIONS(7646), 1,
      anon_sym_decltype,
    STATE(3122), 1,
      sym_parameter_list,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(4878), 1,
      sym_decltype_auto,
    STATE(5882), 1,
      sym__abstract_declarator,
    STATE(5936), 1,
      sym__function_declarator_seq,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4219), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
    ACTIONS(7642), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [102206] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5391), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5393), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [102259] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3934), 1,
      anon_sym_LPAREN2,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5903), 1,
      anon_sym_LBRACK,
    ACTIONS(6031), 1,
      anon_sym_STAR,
    ACTIONS(7648), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7652), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7654), 1,
      anon_sym_AMP,
    ACTIONS(7656), 1,
      anon_sym_COLON,
    ACTIONS(7658), 1,
      anon_sym_EQ,
    STATE(3745), 1,
      sym_parameter_list,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6212), 1,
      sym__declarator,
    STATE(6541), 1,
      sym__abstract_declarator,
    STATE(6639), 1,
      sym_abstract_reference_declarator,
    STATE(7127), 1,
      sym_semantics,
    STATE(7134), 1,
      sym_variadic_reference_declarator,
    STATE(7237), 1,
      sym_variadic_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    ACTIONS(7650), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [102366] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5497), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [102419] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5318), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5320), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [102474] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5475), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5477), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [102527] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7640), 1,
      anon_sym_LT,
    STATE(2895), 1,
      sym_template_argument_list,
    ACTIONS(1941), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(1943), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
  [102586] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2142), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(2144), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [102639] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7408), 1,
      anon_sym_STAR,
    ACTIONS(7410), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7412), 1,
      anon_sym_AMP,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7644), 1,
      sym_auto,
    ACTIONS(7646), 1,
      anon_sym_decltype,
    STATE(3122), 1,
      sym_parameter_list,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(4878), 1,
      sym_decltype_auto,
    STATE(5859), 1,
      sym__abstract_declarator,
    STATE(5936), 1,
      sym__function_declarator_seq,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4221), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
    ACTIONS(7660), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [102724] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7471), 1,
      sym_auto,
    ACTIONS(7473), 1,
      anon_sym_decltype,
    STATE(4118), 1,
      sym_decltype_auto,
    ACTIONS(5413), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5415), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [102783] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(3906), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7662), 1,
      anon_sym_STAR,
    ACTIONS(7664), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7666), 1,
      anon_sym_AMP,
    STATE(3505), 1,
      sym_parameter_list,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6378), 1,
      sym__abstract_declarator,
    ACTIONS(7670), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7672), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4096), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4604), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5891), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [102872] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(3906), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7676), 1,
      anon_sym_STAR,
    ACTIONS(7678), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7680), 1,
      anon_sym_AMP,
    STATE(3634), 1,
      sym_parameter_list,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6257), 1,
      sym__abstract_declarator,
    ACTIONS(7670), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7672), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4093), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4725), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5891), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [102961] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7682), 1,
      anon_sym_LT,
    STATE(2895), 1,
      sym_template_argument_list,
    ACTIONS(1933), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_DOT,
    ACTIONS(1935), 31,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
  [103020] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(3906), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7676), 1,
      anon_sym_STAR,
    ACTIONS(7678), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7680), 1,
      anon_sym_AMP,
    STATE(3634), 1,
      sym_parameter_list,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6297), 1,
      sym__abstract_declarator,
    ACTIONS(7670), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7672), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4067), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4710), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5905), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [103109] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5451), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5453), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [103162] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2260), 20,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(2262), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [103215] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(3906), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7662), 1,
      anon_sym_STAR,
    ACTIONS(7664), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7666), 1,
      anon_sym_AMP,
    STATE(3505), 1,
      sym_parameter_list,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6342), 1,
      sym__abstract_declarator,
    ACTIONS(7670), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7672), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4067), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4644), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5905), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [103304] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3934), 1,
      anon_sym_LPAREN2,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5903), 1,
      anon_sym_LBRACK,
    ACTIONS(6006), 1,
      anon_sym_STAR,
    ACTIONS(7648), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7652), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7654), 1,
      anon_sym_AMP,
    ACTIONS(7656), 1,
      anon_sym_COLON,
    ACTIONS(7685), 1,
      anon_sym_EQ,
    STATE(3679), 1,
      sym_parameter_list,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6216), 1,
      sym__declarator,
    STATE(6517), 1,
      sym__abstract_declarator,
    STATE(6645), 1,
      sym_abstract_reference_declarator,
    STATE(7127), 1,
      sym_semantics,
    STATE(7134), 1,
      sym_variadic_reference_declarator,
    STATE(7237), 1,
      sym_variadic_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    ACTIONS(7650), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [103411] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7687), 1,
      sym_identifier,
    ACTIONS(7689), 1,
      anon_sym_LPAREN2,
    ACTIONS(7691), 1,
      anon_sym_STAR,
    ACTIONS(7693), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7695), 1,
      anon_sym_AMP,
    ACTIONS(7701), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(3236), 1,
      sym__type_declarator,
    STATE(3549), 1,
      sym_pointer_type_declarator,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(7998), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4013), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4747), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7699), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3547), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [103499] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7703), 1,
      sym_identifier,
    ACTIONS(7705), 1,
      anon_sym_LPAREN2,
    ACTIONS(7707), 1,
      anon_sym_STAR,
    ACTIONS(7709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7711), 1,
      anon_sym_AMP,
    ACTIONS(7715), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6077), 1,
      sym__type_declarator,
    STATE(6279), 1,
      sym_pointer_type_declarator,
    STATE(8225), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4101), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4756), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7713), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6273), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [103587] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7703), 1,
      sym_identifier,
    ACTIONS(7705), 1,
      anon_sym_LPAREN2,
    ACTIONS(7715), 1,
      sym_primitive_type,
    ACTIONS(7717), 1,
      anon_sym_STAR,
    ACTIONS(7719), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7721), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6279), 1,
      sym_pointer_type_declarator,
    STATE(6512), 1,
      sym__type_declarator,
    STATE(8018), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4013), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4793), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7713), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6273), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [103675] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7703), 1,
      sym_identifier,
    ACTIONS(7705), 1,
      anon_sym_LPAREN2,
    ACTIONS(7707), 1,
      anon_sym_STAR,
    ACTIONS(7709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7711), 1,
      anon_sym_AMP,
    ACTIONS(7715), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6056), 1,
      sym__type_declarator,
    STATE(6279), 1,
      sym_pointer_type_declarator,
    STATE(8225), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4013), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4784), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7713), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6273), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [103763] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5318), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5320), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [103815] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7449), 1,
      anon_sym_LBRACK,
    ACTIONS(7469), 1,
      anon_sym_LPAREN2,
    ACTIONS(7610), 1,
      sym_auto,
    ACTIONS(7612), 1,
      anon_sym_decltype,
    STATE(2460), 1,
      sym_decltype_auto,
    STATE(4058), 1,
      sym_new_declarator,
    STATE(4002), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5850), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_DOT,
    ACTIONS(5852), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [103883] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5499), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5501), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [103935] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7703), 1,
      sym_identifier,
    ACTIONS(7705), 1,
      anon_sym_LPAREN2,
    ACTIONS(7715), 1,
      sym_primitive_type,
    ACTIONS(7717), 1,
      anon_sym_STAR,
    ACTIONS(7719), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7721), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6279), 1,
      sym_pointer_type_declarator,
    STATE(6511), 1,
      sym__type_declarator,
    STATE(8018), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4013), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4786), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7713), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6273), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [104023] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5515), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5517), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [104075] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5455), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5457), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [104127] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7449), 1,
      anon_sym_LBRACK,
    ACTIONS(7469), 1,
      anon_sym_LPAREN2,
    ACTIONS(7610), 1,
      sym_auto,
    ACTIONS(7612), 1,
      anon_sym_decltype,
    STATE(2460), 1,
      sym_decltype_auto,
    STATE(4068), 1,
      sym_new_declarator,
    STATE(3984), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5868), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_DOT,
    ACTIONS(5870), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [104195] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5431), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5433), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [104247] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7687), 1,
      sym_identifier,
    ACTIONS(7689), 1,
      anon_sym_LPAREN2,
    ACTIONS(7691), 1,
      anon_sym_STAR,
    ACTIONS(7693), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7695), 1,
      anon_sym_AMP,
    ACTIONS(7701), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(3236), 1,
      sym__type_declarator,
    STATE(3549), 1,
      sym_pointer_type_declarator,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(7998), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4169), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4747), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7699), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3547), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [104335] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7727), 1,
      anon_sym_STAR,
    ACTIONS(7729), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7731), 1,
      anon_sym_AMP,
    ACTIONS(7735), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6589), 1,
      sym__type_declarator,
    STATE(8394), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4013), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4832), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [104423] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5549), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5551), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [104475] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7622), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(7737), 1,
      anon_sym_STAR,
    ACTIONS(7739), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7741), 1,
      anon_sym_AMP,
    STATE(3756), 1,
      sym_parameter_list,
    STATE(5027), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6408), 1,
      sym__abstract_declarator,
    ACTIONS(7624), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7626), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4159), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4734), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5891), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [104563] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5525), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5527), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [104615] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7449), 1,
      anon_sym_LBRACK,
    ACTIONS(7469), 1,
      anon_sym_LPAREN2,
    ACTIONS(7610), 1,
      sym_auto,
    ACTIONS(7612), 1,
      anon_sym_decltype,
    STATE(2460), 1,
      sym_decltype_auto,
    STATE(4073), 1,
      sym_new_declarator,
    STATE(4018), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5872), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_DOT,
    ACTIONS(5874), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [104683] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5507), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5509), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [104735] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5459), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5461), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [104787] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5439), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5441), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [104839] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5419), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5421), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [104891] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5463), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5465), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [104943] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7687), 1,
      sym_identifier,
    ACTIONS(7689), 1,
      anon_sym_LPAREN2,
    ACTIONS(7691), 1,
      anon_sym_STAR,
    ACTIONS(7693), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7695), 1,
      anon_sym_AMP,
    ACTIONS(7701), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(3185), 1,
      sym__type_declarator,
    STATE(3549), 1,
      sym_pointer_type_declarator,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(7998), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4098), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4836), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7699), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3547), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [105031] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6187), 1,
      sym__type_declarator,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4174), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4835), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [105119] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7751), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(7749), 33,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym___based,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
      anon_sym__unaligned,
      anon_sym___unaligned,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [105171] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7755), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(7753), 33,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym___based,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
      anon_sym__unaligned,
      anon_sym___unaligned,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [105223] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6284), 1,
      anon_sym___attribute__,
    ACTIONS(6560), 1,
      anon_sym_LBRACE,
    ACTIONS(7757), 1,
      anon_sym_COLON,
    STATE(2858), 1,
      sym__enum_base_clause,
    STATE(2925), 1,
      sym_enumerator_list,
    STATE(2983), 1,
      sym_attribute_specifier,
    ACTIONS(5636), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5638), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [105287] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3934), 1,
      anon_sym_LPAREN2,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5893), 1,
      anon_sym_STAR,
    ACTIONS(5895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5897), 1,
      anon_sym_AMP,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5903), 1,
      anon_sym_LBRACK,
    ACTIONS(7648), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7761), 1,
      anon_sym_COLON,
    STATE(3363), 1,
      sym_parameter_list,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5939), 1,
      sym__declarator,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6469), 1,
      sym__abstract_declarator,
    STATE(7356), 1,
      sym_variadic_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(7759), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_EQ,
      anon_sym_GT2,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [105385] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6187), 1,
      sym__type_declarator,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4013), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4835), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [105473] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6284), 1,
      anon_sym___attribute__,
    ACTIONS(6560), 1,
      anon_sym_LBRACE,
    ACTIONS(7757), 1,
      anon_sym_COLON,
    STATE(2864), 1,
      sym__enum_base_clause,
    STATE(2914), 1,
      sym_enumerator_list,
    STATE(2962), 1,
      sym_attribute_specifier,
    ACTIONS(5689), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5691), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [105537] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7703), 1,
      sym_identifier,
    ACTIONS(7705), 1,
      anon_sym_LPAREN2,
    ACTIONS(7715), 1,
      sym_primitive_type,
    ACTIONS(7717), 1,
      anon_sym_STAR,
    ACTIONS(7719), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7721), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6279), 1,
      sym_pointer_type_declarator,
    STATE(6512), 1,
      sym__type_declarator,
    STATE(8018), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4105), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4793), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7713), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6273), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [105625] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7763), 1,
      sym_identifier,
    ACTIONS(7765), 1,
      anon_sym_LPAREN2,
    ACTIONS(7767), 1,
      anon_sym_STAR,
    ACTIONS(7769), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7771), 1,
      anon_sym_AMP,
    ACTIONS(7775), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(3091), 1,
      sym__type_declarator,
    STATE(3404), 1,
      sym_pointer_type_declarator,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(8483), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4139), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4831), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7773), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3401), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [105713] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5467), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5469), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [105765] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7763), 1,
      sym_identifier,
    ACTIONS(7765), 1,
      anon_sym_LPAREN2,
    ACTIONS(7767), 1,
      anon_sym_STAR,
    ACTIONS(7769), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7771), 1,
      anon_sym_AMP,
    ACTIONS(7775), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(3092), 1,
      sym__type_declarator,
    STATE(3404), 1,
      sym_pointer_type_declarator,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(8483), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4160), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4822), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7773), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3401), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [105853] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7777), 1,
      anon_sym_STAR,
    ACTIONS(7779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7781), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2540), 1,
      sym__type_declarator,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(8179), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4152), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4732), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [105941] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7449), 1,
      anon_sym_LBRACK,
    ACTIONS(7469), 1,
      anon_sym_LPAREN2,
    ACTIONS(7610), 1,
      sym_auto,
    ACTIONS(7612), 1,
      anon_sym_decltype,
    STATE(2460), 1,
      sym_decltype_auto,
    STATE(4070), 1,
      sym_new_declarator,
    STATE(4021), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5862), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_DOT,
    ACTIONS(5864), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [106009] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5443), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5445), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [106061] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7703), 1,
      sym_identifier,
    ACTIONS(7705), 1,
      anon_sym_LPAREN2,
    ACTIONS(7707), 1,
      anon_sym_STAR,
    ACTIONS(7709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7711), 1,
      anon_sym_AMP,
    ACTIONS(7715), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6084), 1,
      sym__type_declarator,
    STATE(6279), 1,
      sym_pointer_type_declarator,
    STATE(8225), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4138), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4745), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7713), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6273), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [106149] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7777), 1,
      anon_sym_STAR,
    ACTIONS(7779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7781), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2540), 1,
      sym__type_declarator,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(8179), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4013), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4732), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [106237] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7703), 1,
      sym_identifier,
    ACTIONS(7705), 1,
      anon_sym_LPAREN2,
    ACTIONS(7707), 1,
      anon_sym_STAR,
    ACTIONS(7709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7711), 1,
      anon_sym_AMP,
    ACTIONS(7715), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6077), 1,
      sym__type_declarator,
    STATE(6279), 1,
      sym_pointer_type_declarator,
    STATE(8225), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4013), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4756), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7713), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6273), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [106325] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7763), 1,
      sym_identifier,
    ACTIONS(7765), 1,
      anon_sym_LPAREN2,
    ACTIONS(7767), 1,
      anon_sym_STAR,
    ACTIONS(7769), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7771), 1,
      anon_sym_AMP,
    ACTIONS(7775), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(3092), 1,
      sym__type_declarator,
    STATE(3404), 1,
      sym_pointer_type_declarator,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(8483), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4013), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4822), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7773), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3401), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [106413] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6188), 1,
      sym__type_declarator,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4127), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4800), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [106501] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(3906), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7783), 1,
      anon_sym_STAR,
    ACTIONS(7785), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7787), 1,
      anon_sym_AMP,
    STATE(3708), 1,
      sym_parameter_list,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6406), 1,
      sym__abstract_declarator,
    ACTIONS(7670), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7672), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4142), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4766), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5891), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [106589] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(3906), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7783), 1,
      anon_sym_STAR,
    ACTIONS(7785), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7787), 1,
      anon_sym_AMP,
    STATE(3708), 1,
      sym_parameter_list,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6401), 1,
      sym__abstract_declarator,
    ACTIONS(7670), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7672), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4067), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4768), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5905), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [106677] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7463), 1,
      anon_sym_STAR,
    ACTIONS(7465), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7467), 1,
      anon_sym_AMP,
    ACTIONS(7644), 1,
      sym_auto,
    ACTIONS(7646), 1,
      anon_sym_decltype,
    STATE(3299), 1,
      sym_parameter_list,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(4878), 1,
      sym_decltype_auto,
    STATE(5884), 1,
      sym__abstract_declarator,
    STATE(5936), 1,
      sym__function_declarator_seq,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4254), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
    ACTIONS(7660), 11,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [106761] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5427), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5429), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [106813] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5545), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5547), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [106865] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7703), 1,
      sym_identifier,
    ACTIONS(7705), 1,
      anon_sym_LPAREN2,
    ACTIONS(7715), 1,
      sym_primitive_type,
    ACTIONS(7717), 1,
      anon_sym_STAR,
    ACTIONS(7719), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7721), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6279), 1,
      sym_pointer_type_declarator,
    STATE(6536), 1,
      sym__type_declarator,
    STATE(8018), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4100), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4803), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7713), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6273), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [106953] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5467), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5469), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [107005] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5447), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5449), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [107057] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5487), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5489), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [107109] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5318), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5320), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [107161] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7622), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(7789), 1,
      anon_sym_STAR,
    ACTIONS(7791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7793), 1,
      anon_sym_AMP,
    STATE(3791), 1,
      sym_parameter_list,
    STATE(5027), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6395), 1,
      sym__abstract_declarator,
    ACTIONS(7624), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7626), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4812), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(4872), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5905), 6,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [107249] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7777), 1,
      anon_sym_STAR,
    ACTIONS(7779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7781), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2551), 1,
      sym__type_declarator,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(8179), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4013), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4827), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [107337] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5537), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5539), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [107389] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5423), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5425), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [107441] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7777), 1,
      anon_sym_STAR,
    ACTIONS(7779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7781), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2541), 1,
      sym__type_declarator,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(8179), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4137), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4788), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [107529] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5467), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5469), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [107581] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7727), 1,
      anon_sym_STAR,
    ACTIONS(7729), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7731), 1,
      anon_sym_AMP,
    ACTIONS(7735), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6584), 1,
      sym__type_declarator,
    STATE(8394), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4013), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4833), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [107669] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5483), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5485), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [107721] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7622), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(7737), 1,
      anon_sym_STAR,
    ACTIONS(7739), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7741), 1,
      anon_sym_AMP,
    STATE(3756), 1,
      sym_parameter_list,
    STATE(5027), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6419), 1,
      sym__abstract_declarator,
    ACTIONS(7624), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7626), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4761), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(4872), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5905), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [107809] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7763), 1,
      sym_identifier,
    ACTIONS(7765), 1,
      anon_sym_LPAREN2,
    ACTIONS(7767), 1,
      anon_sym_STAR,
    ACTIONS(7769), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7771), 1,
      anon_sym_AMP,
    ACTIONS(7775), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(3128), 1,
      sym__type_declarator,
    STATE(3404), 1,
      sym_pointer_type_declarator,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(8483), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4013), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4806), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7773), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3401), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [107897] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5479), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5481), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [107949] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5511), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5513), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [108001] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5533), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5535), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [108053] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5491), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5493), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [108105] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7463), 1,
      anon_sym_STAR,
    ACTIONS(7465), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7467), 1,
      anon_sym_AMP,
    ACTIONS(7644), 1,
      sym_auto,
    ACTIONS(7646), 1,
      anon_sym_decltype,
    STATE(3299), 1,
      sym_parameter_list,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(4878), 1,
      sym_decltype_auto,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(5955), 1,
      sym__abstract_declarator,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4239), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
    ACTIONS(7642), 11,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [108189] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5503), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5505), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [108241] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7622), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(7789), 1,
      anon_sym_STAR,
    ACTIONS(7791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7793), 1,
      anon_sym_AMP,
    STATE(3791), 1,
      sym_parameter_list,
    STATE(5027), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6418), 1,
      sym__abstract_declarator,
    ACTIONS(7624), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7626), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4151), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4838), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5891), 6,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [108329] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5541), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5543), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [108381] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7687), 1,
      sym_identifier,
    ACTIONS(7689), 1,
      anon_sym_LPAREN2,
    ACTIONS(7691), 1,
      anon_sym_STAR,
    ACTIONS(7693), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7695), 1,
      anon_sym_AMP,
    ACTIONS(7701), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(3194), 1,
      sym__type_declarator,
    STATE(3549), 1,
      sym_pointer_type_declarator,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(7998), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4013), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4771), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7699), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3547), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [108469] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5525), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5527), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [108521] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5471), 19,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
    ACTIONS(5473), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [108573] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7727), 1,
      anon_sym_STAR,
    ACTIONS(7729), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7731), 1,
      anon_sym_AMP,
    ACTIONS(7735), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6589), 1,
      sym__type_declarator,
    STATE(8394), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4157), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4832), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [108661] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7727), 1,
      anon_sym_STAR,
    ACTIONS(7729), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7731), 1,
      anon_sym_AMP,
    ACTIONS(7735), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6596), 1,
      sym__type_declarator,
    STATE(8394), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4111), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4817), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [108749] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(6228), 1,
      sym__type_declarator,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7697), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4013), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4819), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7414), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [108837] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_SLASH,
    ACTIONS(7803), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7809), 1,
      anon_sym_CARET,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7821), 1,
      anon_sym_QMARK,
    ACTIONS(7823), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7825), 1,
      anon_sym_or,
    ACTIONS(7827), 1,
      anon_sym_and,
    ACTIONS(7829), 1,
      anon_sym_xor,
    ACTIONS(7831), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6670), 2,
      aux_sym_preproc_elif_token1,
      sym_identifier,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7797), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7807), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(7811), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6672), 5,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
  [108940] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6488), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6490), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [108991] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(63), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7414), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7833), 1,
      anon_sym_STAR,
    ACTIONS(7835), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(3908), 1,
      sym_parameter_list,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(6446), 1,
      sym__abstract_declarator,
    ACTIONS(7328), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7416), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7418), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4184), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4852), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5891), 5,
      anon_sym_RPAREN,
      anon_sym_LBRACK_LBRACK,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7324), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [109078] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_SLASH,
    ACTIONS(7803), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7809), 1,
      anon_sym_CARET,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7821), 1,
      anon_sym_QMARK,
    ACTIONS(7823), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7825), 1,
      anon_sym_or,
    ACTIONS(7827), 1,
      anon_sym_and,
    ACTIONS(7829), 1,
      anon_sym_xor,
    ACTIONS(7831), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6496), 2,
      aux_sym_preproc_elif_token1,
      sym_identifier,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7797), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7807), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(7811), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6498), 5,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
  [109181] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6484), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6486), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [109232] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7801), 1,
      anon_sym_SLASH,
    ACTIONS(7803), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7809), 1,
      anon_sym_CARET,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7823), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7825), 1,
      anon_sym_or,
    ACTIONS(7827), 1,
      anon_sym_and,
    ACTIONS(7829), 1,
      anon_sym_xor,
    ACTIONS(7831), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6703), 2,
      aux_sym_preproc_elif_token1,
      sym_identifier,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7797), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7807), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(7811), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6705), 7,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_QMARK,
  [109331] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6351), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6353), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [109382] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(63), 1,
      anon_sym_const,
    STATE(1957), 1,
      sym_alignas_qualifier,
    ACTIONS(7328), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7841), 2,
      anon_sym_AMP,
      anon_sym_LBRACK,
    STATE(4416), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(4479), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5819), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(7324), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
    ACTIONS(7839), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [109447] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4019), 1,
      anon_sym_LBRACE,
    ACTIONS(6626), 1,
      sym_auto,
    ACTIONS(6628), 1,
      anon_sym_decltype,
    ACTIONS(7843), 1,
      anon_sym_LPAREN2,
    ACTIONS(7845), 1,
      anon_sym_LBRACK,
    STATE(2994), 1,
      sym_decltype_auto,
    STATE(4316), 1,
      sym_new_declarator,
    STATE(4741), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5872), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5874), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [109514] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(63), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7414), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7833), 1,
      anon_sym_STAR,
    ACTIONS(7835), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(3908), 1,
      sym_parameter_list,
    STATE(4124), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(6454), 1,
      sym__abstract_declarator,
    ACTIONS(7328), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7416), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7418), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4013), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4863), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5905), 5,
      anon_sym_RPAREN,
      anon_sym_LBRACK_LBRACK,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7324), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [109601] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4019), 1,
      anon_sym_LBRACE,
    ACTIONS(6626), 1,
      sym_auto,
    ACTIONS(6628), 1,
      anon_sym_decltype,
    ACTIONS(7843), 1,
      anon_sym_LPAREN2,
    ACTIONS(7845), 1,
      anon_sym_LBRACK,
    STATE(2994), 1,
      sym_decltype_auto,
    STATE(4356), 1,
      sym_new_declarator,
    STATE(4754), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5850), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5852), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [109668] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7847), 1,
      anon_sym_LT,
    STATE(2390), 1,
      sym_template_argument_list,
    ACTIONS(1943), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
    ACTIONS(1941), 31,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      anon_sym_or,
      anon_sym_and,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [109725] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7801), 1,
      anon_sym_SLASH,
    ACTIONS(7803), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7809), 1,
      anon_sym_CARET,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7823), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7825), 1,
      anon_sym_or,
    ACTIONS(7827), 1,
      anon_sym_and,
    ACTIONS(7829), 1,
      anon_sym_xor,
    ACTIONS(7831), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6695), 2,
      aux_sym_preproc_elif_token1,
      sym_identifier,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7797), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7807), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(7811), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6697), 7,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_QMARK,
  [109824] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7801), 1,
      anon_sym_SLASH,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7799), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6292), 15,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6294), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
  [109893] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7801), 1,
      anon_sym_SLASH,
    ACTIONS(7805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7809), 1,
      anon_sym_CARET,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7823), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7827), 1,
      anon_sym_and,
    ACTIONS(7829), 1,
      anon_sym_xor,
    ACTIONS(7831), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7797), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7807), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(7811), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6292), 3,
      aux_sym_preproc_elif_token1,
      anon_sym_or,
      sym_identifier,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 8,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
  [109988] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7801), 1,
      anon_sym_SLASH,
    ACTIONS(7809), 1,
      anon_sym_CARET,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7823), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7829), 1,
      anon_sym_xor,
    ACTIONS(7831), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7797), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7807), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(7811), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 4,
      aux_sym_preproc_elif_token1,
      anon_sym_or,
      anon_sym_and,
      sym_identifier,
    ACTIONS(6294), 9,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
  [110079] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7801), 1,
      anon_sym_SLASH,
    ACTIONS(7809), 1,
      anon_sym_CARET,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7823), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7829), 1,
      anon_sym_xor,
    ACTIONS(7831), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7797), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7811), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 6,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      sym_identifier,
    ACTIONS(6294), 9,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
  [110168] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7801), 1,
      anon_sym_SLASH,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7823), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7831), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7797), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7811), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 7,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      sym_identifier,
    ACTIONS(6294), 10,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_QMARK,
  [110253] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7801), 1,
      anon_sym_SLASH,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7823), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7831), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7797), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 9,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      sym_identifier,
    ACTIONS(6294), 10,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_QMARK,
  [110336] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7801), 1,
      anon_sym_SLASH,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7823), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7797), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6292), 10,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6294), 12,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
  [110415] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    STATE(4679), 1,
      sym_alignas_qualifier,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7841), 2,
      anon_sym_AMP,
      anon_sym_LBRACK,
    STATE(4336), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(4537), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5760), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
    ACTIONS(7839), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [110480] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7801), 1,
      anon_sym_SLASH,
    ACTIONS(7823), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7797), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6292), 13,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6294), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
  [110555] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_SLASH,
    ACTIONS(7803), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7809), 1,
      anon_sym_CARET,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7821), 1,
      anon_sym_QMARK,
    ACTIONS(7823), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7825), 1,
      anon_sym_or,
    ACTIONS(7827), 1,
      anon_sym_and,
    ACTIONS(7829), 1,
      anon_sym_xor,
    ACTIONS(7831), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7797), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7807), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(7811), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7849), 2,
      aux_sym_preproc_elif_token1,
      sym_identifier,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(7851), 5,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
  [110658] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7801), 1,
      anon_sym_SLASH,
    ACTIONS(7803), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7809), 1,
      anon_sym_CARET,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7823), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7825), 1,
      anon_sym_or,
    ACTIONS(7827), 1,
      anon_sym_and,
    ACTIONS(7829), 1,
      anon_sym_xor,
    ACTIONS(7831), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6688), 2,
      aux_sym_preproc_elif_token1,
      sym_identifier,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7797), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7807), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(7811), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6690), 7,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_QMARK,
  [110757] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7801), 1,
      anon_sym_SLASH,
    ACTIONS(7803), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7809), 1,
      anon_sym_CARET,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7823), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7825), 1,
      anon_sym_or,
    ACTIONS(7827), 1,
      anon_sym_and,
    ACTIONS(7829), 1,
      anon_sym_xor,
    ACTIONS(7831), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6699), 2,
      aux_sym_preproc_elif_token1,
      sym_identifier,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7797), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7807), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(7811), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6701), 7,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_QMARK,
  [110856] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4019), 1,
      anon_sym_LBRACE,
    ACTIONS(6626), 1,
      sym_auto,
    ACTIONS(6628), 1,
      anon_sym_decltype,
    ACTIONS(7843), 1,
      anon_sym_LPAREN2,
    ACTIONS(7845), 1,
      anon_sym_LBRACK,
    STATE(2994), 1,
      sym_decltype_auto,
    STATE(4332), 1,
      sym_new_declarator,
    STATE(4821), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5862), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5864), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [110923] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7801), 1,
      anon_sym_SLASH,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7797), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6292), 13,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6294), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
  [110994] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7847), 1,
      anon_sym_LT,
    STATE(2390), 1,
      sym_template_argument_list,
    ACTIONS(1935), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
    ACTIONS(1933), 31,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      anon_sym_or,
      anon_sym_and,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [111051] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7751), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(7749), 30,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym___based,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
      anon_sym__unaligned,
      anon_sym___unaligned,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_template,
      anon_sym_operator,
      anon_sym_try,
      anon_sym_requires,
  [111102] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4019), 1,
      anon_sym_LBRACE,
    ACTIONS(6626), 1,
      sym_auto,
    ACTIONS(6628), 1,
      anon_sym_decltype,
    ACTIONS(7843), 1,
      anon_sym_LPAREN2,
    ACTIONS(7845), 1,
      anon_sym_LBRACK,
    STATE(2994), 1,
      sym_decltype_auto,
    STATE(4335), 1,
      sym_new_declarator,
    STATE(4792), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(5868), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5870), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [111169] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7755), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(7753), 30,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym___based,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
      anon_sym__unaligned,
      anon_sym___unaligned,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_template,
      anon_sym_operator,
      anon_sym_try,
      anon_sym_requires,
  [111220] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7801), 1,
      anon_sym_SLASH,
    ACTIONS(7803), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7805), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7809), 1,
      anon_sym_CARET,
    ACTIONS(7817), 1,
      anon_sym_GT_EQ,
    ACTIONS(7821), 1,
      anon_sym_QMARK,
    ACTIONS(7823), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7825), 1,
      anon_sym_or,
    ACTIONS(7827), 1,
      anon_sym_and,
    ACTIONS(7829), 1,
      anon_sym_xor,
    ACTIONS(7831), 1,
      anon_sym_not_eq,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6630), 2,
      aux_sym_preproc_elif_token1,
      sym_identifier,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7797), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7807), 2,
      anon_sym_PIPE,
      anon_sym_bitor,
    ACTIONS(7811), 2,
      anon_sym_AMP,
      anon_sym_bitand,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7815), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6634), 5,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
  [111323] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6365), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(6367), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [111374] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7801), 1,
      anon_sym_SLASH,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7797), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7799), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7819), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6292), 13,
      aux_sym_preproc_elif_token1,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      sym_identifier,
    ACTIONS(6294), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
  [111447] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5836), 1,
      sym_literal_suffix,
    ACTIONS(3832), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(3824), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [111499] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(7853), 1,
      sym_identifier,
    ACTIONS(7855), 1,
      anon_sym_LPAREN2,
    ACTIONS(7857), 1,
      anon_sym_STAR,
    ACTIONS(7859), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7861), 1,
      anon_sym_AMP,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6508), 1,
      sym__field_declarator,
    STATE(6623), 1,
      sym_operator_name,
    STATE(8364), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4225), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4874), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(6289), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [111583] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(7855), 1,
      anon_sym_LPAREN2,
    ACTIONS(7863), 1,
      sym_identifier,
    ACTIONS(7865), 1,
      anon_sym_STAR,
    ACTIONS(7867), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7869), 1,
      anon_sym_AMP,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6048), 1,
      sym__field_declarator,
    STATE(6214), 1,
      sym_operator_name,
    STATE(7986), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4217), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4935), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(6289), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [111667] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(7855), 1,
      anon_sym_LPAREN2,
    ACTIONS(7863), 1,
      sym_identifier,
    ACTIONS(7865), 1,
      anon_sym_STAR,
    ACTIONS(7867), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7869), 1,
      anon_sym_AMP,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6040), 1,
      sym__field_declarator,
    STATE(6214), 1,
      sym_operator_name,
    STATE(7986), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4067), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4944), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(6289), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [111751] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    STATE(4016), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6117), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_DOT,
    ACTIONS(6119), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [111807] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(7855), 1,
      anon_sym_LPAREN2,
    ACTIONS(7863), 1,
      sym_identifier,
    ACTIONS(7865), 1,
      anon_sym_STAR,
    ACTIONS(7867), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7869), 1,
      anon_sym_AMP,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6106), 1,
      sym__field_declarator,
    STATE(6214), 1,
      sym_operator_name,
    STATE(7986), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4212), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4923), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(6289), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [111891] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(3906), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7871), 1,
      anon_sym_STAR,
    ACTIONS(7873), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7875), 1,
      anon_sym_AMP,
    STATE(3644), 1,
      sym_parameter_list,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6547), 1,
      sym__abstract_declarator,
    ACTIONS(7670), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7672), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4226), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4916), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5891), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [111977] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    STATE(3985), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6089), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_DOT,
    ACTIONS(6091), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [112033] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(7855), 1,
      anon_sym_LPAREN2,
    ACTIONS(7863), 1,
      sym_identifier,
    ACTIONS(7865), 1,
      anon_sym_STAR,
    ACTIONS(7867), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7869), 1,
      anon_sym_AMP,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6106), 1,
      sym__field_declarator,
    STATE(6214), 1,
      sym_operator_name,
    STATE(7986), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4067), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4923), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(6289), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [112117] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    STATE(4001), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6136), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_DOT,
    ACTIONS(6138), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [112173] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7408), 1,
      anon_sym_STAR,
    ACTIONS(7410), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7412), 1,
      anon_sym_AMP,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    STATE(3122), 1,
      sym_parameter_list,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(5877), 1,
      sym__abstract_declarator,
    STATE(5936), 1,
      sym__function_declarator_seq,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4294), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
    ACTIONS(7877), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [112249] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    STATE(2390), 1,
      sym_template_argument_list,
    STATE(4312), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5294), 4,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(7879), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5296), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [112309] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7408), 1,
      anon_sym_STAR,
    ACTIONS(7410), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7412), 1,
      anon_sym_AMP,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    STATE(3122), 1,
      sym_parameter_list,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(5878), 1,
      sym__abstract_declarator,
    STATE(5936), 1,
      sym__function_declarator_seq,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4294), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
    ACTIONS(7881), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [112385] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2000), 1,
      anon_sym_LT,
    STATE(2221), 1,
      sym_template_argument_list,
    STATE(4312), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(3822), 4,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(7879), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(3830), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [112445] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7408), 1,
      anon_sym_STAR,
    ACTIONS(7410), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7412), 1,
      anon_sym_AMP,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    STATE(3122), 1,
      sym_parameter_list,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(5871), 1,
      sym__abstract_declarator,
    STATE(5936), 1,
      sym__function_declarator_seq,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4294), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
    ACTIONS(6596), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [112521] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5836), 1,
      sym_literal_suffix,
    ACTIONS(5838), 17,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5840), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [112573] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(7853), 1,
      sym_identifier,
    ACTIONS(7855), 1,
      anon_sym_LPAREN2,
    ACTIONS(7857), 1,
      anon_sym_STAR,
    ACTIONS(7859), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7861), 1,
      anon_sym_AMP,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6522), 1,
      sym__field_declarator,
    STATE(6623), 1,
      sym_operator_name,
    STATE(8364), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4067), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4928), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(6289), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [112657] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(3906), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7871), 1,
      anon_sym_STAR,
    ACTIONS(7873), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7875), 1,
      anon_sym_AMP,
    STATE(3644), 1,
      sym_parameter_list,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6546), 1,
      sym__abstract_declarator,
    ACTIONS(7670), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7672), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4067), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4937), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5905), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [112743] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(7853), 1,
      sym_identifier,
    ACTIONS(7855), 1,
      anon_sym_LPAREN2,
    ACTIONS(7857), 1,
      anon_sym_STAR,
    ACTIONS(7859), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7861), 1,
      anon_sym_AMP,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6528), 1,
      sym__field_declarator,
    STATE(6623), 1,
      sym_operator_name,
    STATE(8364), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4233), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4940), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(6289), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [112827] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6731), 18,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
      sym_literal_suffix,
    ACTIONS(6733), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [112877] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7590), 1,
      anon_sym_STAR,
    ACTIONS(7592), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7594), 1,
      anon_sym_AMP,
    ACTIONS(7644), 1,
      sym_auto,
    ACTIONS(7646), 1,
      anon_sym_decltype,
    STATE(3354), 1,
      sym_parameter_list,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(4878), 1,
      sym_decltype_auto,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(6121), 1,
      sym__abstract_declarator,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4426), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7660), 9,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [112959] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7590), 1,
      anon_sym_STAR,
    ACTIONS(7592), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7594), 1,
      anon_sym_AMP,
    ACTIONS(7644), 1,
      sym_auto,
    ACTIONS(7646), 1,
      anon_sym_decltype,
    STATE(3354), 1,
      sym_parameter_list,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(4878), 1,
      sym_decltype_auto,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(6138), 1,
      sym__abstract_declarator,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4373), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7642), 9,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [113041] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7408), 1,
      anon_sym_STAR,
    ACTIONS(7410), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7412), 1,
      anon_sym_AMP,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    STATE(3122), 1,
      sym_parameter_list,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(5881), 1,
      sym__abstract_declarator,
    STATE(5936), 1,
      sym__function_declarator_seq,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4294), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
    ACTIONS(5905), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [113117] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    STATE(4029), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6162), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_DOT,
    ACTIONS(6164), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [113173] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(7853), 1,
      sym_identifier,
    ACTIONS(7855), 1,
      anon_sym_LPAREN2,
    ACTIONS(7857), 1,
      anon_sym_STAR,
    ACTIONS(7859), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7861), 1,
      anon_sym_AMP,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6508), 1,
      sym__field_declarator,
    STATE(6623), 1,
      sym_operator_name,
    STATE(8364), 1,
      sym_ms_based_modifier,
    ACTIONS(3908), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4067), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4874), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(3906), 3,
      sym_ms_restrict_modifier,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    STATE(6289), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [113257] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3934), 1,
      anon_sym_LPAREN2,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5893), 1,
      anon_sym_STAR,
    ACTIONS(5895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(5897), 1,
      anon_sym_AMP,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5903), 1,
      anon_sym_LBRACK,
    ACTIONS(7761), 1,
      anon_sym_COLON,
    STATE(3363), 1,
      sym_parameter_list,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5939), 1,
      sym__declarator,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6469), 1,
      sym__abstract_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(7759), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_EQ,
      anon_sym_GT2,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [113349] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7883), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5252), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_DOT,
    ACTIONS(5254), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [113400] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7885), 1,
      sym_identifier,
    ACTIONS(7889), 1,
      sym_primitive_type,
    STATE(4247), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7887), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5336), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(5338), 23,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [113457] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6731), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6733), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [113506] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7614), 1,
      anon_sym_STAR,
    ACTIONS(7616), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7618), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(7891), 1,
      sym_auto,
    ACTIONS(7893), 1,
      anon_sym_decltype,
    STATE(3399), 1,
      sym_parameter_list,
    STATE(5042), 1,
      sym_decltype_auto,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6227), 1,
      sym__abstract_declarator,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4577), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7660), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [113587] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7463), 1,
      anon_sym_STAR,
    ACTIONS(7465), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7467), 1,
      anon_sym_AMP,
    STATE(3299), 1,
      sym_parameter_list,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(5958), 1,
      sym__abstract_declarator,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4294), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
    ACTIONS(7877), 11,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [113662] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5836), 1,
      sym_literal_suffix,
    ACTIONS(3832), 15,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(3824), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [113713] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7883), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7895), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(5231), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_DOT,
    ACTIONS(5233), 28,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [113766] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7463), 1,
      anon_sym_STAR,
    ACTIONS(7465), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7467), 1,
      anon_sym_AMP,
    STATE(3299), 1,
      sym_parameter_list,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(5970), 1,
      sym__abstract_declarator,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4294), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5905), 11,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [113841] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7614), 1,
      anon_sym_STAR,
    ACTIONS(7616), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7618), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(7891), 1,
      sym_auto,
    ACTIONS(7893), 1,
      anon_sym_decltype,
    STATE(3399), 1,
      sym_parameter_list,
    STATE(5042), 1,
      sym_decltype_auto,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6197), 1,
      sym__abstract_declarator,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4538), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7642), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [113922] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    STATE(2390), 1,
      sym_template_argument_list,
    STATE(4510), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5294), 3,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_const,
    ACTIONS(7897), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5296), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [113981] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7463), 1,
      anon_sym_STAR,
    ACTIONS(7465), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7467), 1,
      anon_sym_AMP,
    STATE(3299), 1,
      sym_parameter_list,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(5959), 1,
      sym__abstract_declarator,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4294), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6596), 11,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [114056] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(7905), 1,
      anon_sym_SLASH,
    ACTIONS(7911), 1,
      anon_sym_PIPE,
    ACTIONS(7915), 1,
      anon_sym_AMP,
    ACTIONS(7921), 1,
      anon_sym_GT_EQ,
    ACTIONS(7925), 1,
      anon_sym_SEMI,
    ACTIONS(7927), 1,
      anon_sym_QMARK,
    ACTIONS(7929), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7931), 1,
      anon_sym_bitor,
    ACTIONS(7933), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(6692), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8314), 1,
      sym_attribute_specifier,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7901), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7903), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7907), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7909), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7913), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7923), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7917), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7919), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [114159] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4252), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5224), 2,
      sym_primitive_type,
      sym_identifier,
    ACTIONS(7935), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5315), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(5312), 23,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [114214] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7938), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7940), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7942), 1,
      anon_sym_or,
    ACTIONS(7944), 1,
      anon_sym_and,
    ACTIONS(5231), 15,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5233), 22,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [114271] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(3906), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6577), 1,
      sym__abstract_declarator,
    ACTIONS(7670), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7672), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4067), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4978), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5905), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [114356] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5836), 1,
      sym_literal_suffix,
    ACTIONS(5838), 15,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(5840), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [114407] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7940), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7944), 1,
      anon_sym_and,
    ACTIONS(5252), 16,
      aux_sym_preproc_elif_token1,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_identifier,
    ACTIONS(5254), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [114460] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4252), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7935), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5226), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(5224), 25,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [114513] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(7905), 1,
      anon_sym_SLASH,
    ACTIONS(7911), 1,
      anon_sym_PIPE,
    ACTIONS(7915), 1,
      anon_sym_AMP,
    ACTIONS(7921), 1,
      anon_sym_GT_EQ,
    ACTIONS(7927), 1,
      anon_sym_QMARK,
    ACTIONS(7929), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7931), 1,
      anon_sym_bitor,
    ACTIONS(7933), 1,
      anon_sym_bitand,
    ACTIONS(7946), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(6719), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8419), 1,
      sym_attribute_specifier,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7901), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7903), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7907), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7909), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7913), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7923), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7917), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7919), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [114616] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7463), 1,
      anon_sym_STAR,
    ACTIONS(7465), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7467), 1,
      anon_sym_AMP,
    STATE(3299), 1,
      sym_parameter_list,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(5954), 1,
      sym__abstract_declarator,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4294), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
    ACTIONS(7881), 11,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [114691] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(7905), 1,
      anon_sym_SLASH,
    ACTIONS(7911), 1,
      anon_sym_PIPE,
    ACTIONS(7915), 1,
      anon_sym_AMP,
    ACTIONS(7921), 1,
      anon_sym_GT_EQ,
    ACTIONS(7927), 1,
      anon_sym_QMARK,
    ACTIONS(7929), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7931), 1,
      anon_sym_bitor,
    ACTIONS(7933), 1,
      anon_sym_bitand,
    ACTIONS(7948), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(6708), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8070), 1,
      sym_attribute_specifier,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7901), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7903), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7907), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7909), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7913), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7923), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7917), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7919), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [114794] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(3906), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6565), 1,
      sym__abstract_declarator,
    ACTIONS(7670), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7672), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4249), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4950), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5891), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [114879] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(3906), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7950), 1,
      anon_sym_STAR,
    ACTIONS(7952), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7954), 1,
      anon_sym_AMP,
    STATE(3794), 1,
      sym_parameter_list,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6592), 1,
      sym__abstract_declarator,
    ACTIONS(7670), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7672), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4258), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4955), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5891), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [114964] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(3906), 1,
      sym_ms_restrict_modifier,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7950), 1,
      anon_sym_STAR,
    ACTIONS(7952), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7954), 1,
      anon_sym_AMP,
    STATE(3794), 1,
      sym_parameter_list,
    STATE(4205), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6603), 1,
      sym__abstract_declarator,
    ACTIONS(7670), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7672), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4067), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(4952), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5905), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [115049] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6634), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [115143] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(7990), 1,
      anon_sym_RPAREN,
    ACTIONS(7992), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7019), 1,
      aux_sym_declaration_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [115243] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7610), 1,
      sym_auto,
    ACTIONS(7612), 1,
      anon_sym_decltype,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7662), 1,
      anon_sym_STAR,
    ACTIONS(7664), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7666), 1,
      anon_sym_AMP,
    STATE(2460), 1,
      sym_decltype_auto,
    STATE(3505), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6246), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4595), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7660), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [115323] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6292), 1,
      anon_sym_PIPE,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
  [115405] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6690), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
  [115495] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7676), 1,
      anon_sym_STAR,
    ACTIONS(7678), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7680), 1,
      anon_sym_AMP,
    ACTIONS(7891), 1,
      sym_auto,
    ACTIONS(7893), 1,
      anon_sym_decltype,
    STATE(3634), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5042), 1,
      sym_decltype_auto,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6368), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4723), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7642), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [115575] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5168), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5170), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [115623] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 10,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
  [115709] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6498), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [115803] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5119), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5121), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [115851] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6292), 1,
      anon_sym_PIPE,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 11,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
  [115935] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3934), 1,
      anon_sym_LPAREN2,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5903), 1,
      anon_sym_LBRACK,
    ACTIONS(6031), 1,
      anon_sym_STAR,
    ACTIONS(6033), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6035), 1,
      anon_sym_AMP,
    ACTIONS(7761), 1,
      anon_sym_COLON,
    STATE(3745), 1,
      sym_parameter_list,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5939), 1,
      sym__declarator,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6573), 1,
      sym__abstract_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    ACTIONS(7759), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [116025] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6705), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
  [116115] = 6,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4297), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5224), 2,
      sym_primitive_type,
      sym_identifier,
    ACTIONS(7994), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5315), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(5312), 22,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [116169] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1947), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1945), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [116217] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5157), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5159), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [116265] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5129), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5131), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [116313] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6292), 7,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [116379] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5119), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5121), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [116427] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5119), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5121), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [116475] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 8,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_or,
  [116563] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5145), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5147), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [116611] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5113), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5115), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [116659] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1931), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(1929), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [116707] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7676), 1,
      anon_sym_STAR,
    ACTIONS(7678), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7680), 1,
      anon_sym_AMP,
    ACTIONS(7891), 1,
      sym_auto,
    ACTIONS(7893), 1,
      anon_sym_decltype,
    STATE(3634), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5042), 1,
      sym_decltype_auto,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6261), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4719), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7660), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [116787] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6701), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
  [116877] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2000), 1,
      anon_sym_LT,
    STATE(2221), 1,
      sym_template_argument_list,
    ACTIONS(1933), 4,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(1935), 33,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [116931] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7997), 1,
      anon_sym_LT,
    STATE(4510), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4665), 1,
      sym_template_argument_list,
    ACTIONS(3822), 3,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_const,
    ACTIONS(7897), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(3830), 29,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [116989] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6292), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [117057] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5123), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5125), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [117105] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6292), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [117177] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3934), 1,
      anon_sym_LPAREN2,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5903), 1,
      anon_sym_LBRACK,
    ACTIONS(6006), 1,
      anon_sym_STAR,
    ACTIONS(6008), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6010), 1,
      anon_sym_AMP,
    ACTIONS(7761), 1,
      anon_sym_COLON,
    STATE(3679), 1,
      sym_parameter_list,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5939), 1,
      sym__declarator,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6601), 1,
      sym__abstract_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    ACTIONS(7759), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [117267] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7999), 1,
      sym_identifier,
    ACTIONS(8003), 1,
      sym_primitive_type,
    STATE(4272), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(8001), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5336), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(5338), 22,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [117323] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5172), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5174), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [117371] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7610), 1,
      sym_auto,
    ACTIONS(7612), 1,
      anon_sym_decltype,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7662), 1,
      anon_sym_STAR,
    ACTIONS(7664), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7666), 1,
      anon_sym_AMP,
    STATE(2460), 1,
      sym_decltype_auto,
    STATE(3505), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6292), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4607), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7642), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [117451] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8012), 1,
      anon_sym_const,
    STATE(4679), 1,
      sym_alignas_qualifier,
    ACTIONS(8007), 2,
      anon_sym_AMP,
      anon_sym_LBRACK,
    ACTIONS(8015), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4294), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8009), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
    ACTIONS(8005), 21,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [117509] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6292), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [117585] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8018), 1,
      anon_sym_COMMA,
    ACTIONS(8020), 1,
      anon_sym_SEMI,
    ACTIONS(8022), 1,
      anon_sym_RBRACE,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7409), 1,
      aux_sym_initializer_list_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [117685] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4297), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(7994), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5226), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(5224), 24,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [117737] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8027), 1,
      anon_sym_const,
    STATE(1957), 1,
      sym_alignas_qualifier,
    ACTIONS(8007), 2,
      anon_sym_AMP,
      anon_sym_LBRACK,
    ACTIONS(8030), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4298), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8024), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
    ACTIONS(8005), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [117795] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2000), 1,
      anon_sym_LT,
    STATE(2221), 1,
      sym_template_argument_list,
    ACTIONS(1941), 4,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(1943), 33,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [117849] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5141), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5143), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [117897] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5137), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5139), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [117945] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5164), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5166), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [117993] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6292), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
  [118071] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5176), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5178), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [118119] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5149), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5151), 29,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [118167] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6292), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [118237] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6697), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
  [118327] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6672), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_RBRACE,
  [118421] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4252), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5387), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(8033), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5389), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [118472] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(63), 1,
      anon_sym_const,
    STATE(1957), 1,
      sym_alignas_qualifier,
    ACTIONS(7328), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7841), 2,
      anon_sym_AMP,
      anon_sym_LBRACK,
    STATE(4298), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7324), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
    ACTIONS(7839), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [118529] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4309), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5367), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(8035), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5369), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [118580] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4252), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5347), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(8033), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5349), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [118631] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(6626), 1,
      sym_auto,
    ACTIONS(6628), 1,
      anon_sym_decltype,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(7789), 1,
      anon_sym_STAR,
    ACTIONS(7791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7793), 1,
      anon_sym_AMP,
    STATE(2994), 1,
      sym_decltype_auto,
    STATE(3791), 1,
      sym_parameter_list,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6420), 1,
      sym__abstract_declarator,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4830), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7642), 6,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [118710] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8039), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7341), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [118807] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8041), 1,
      anon_sym_COMMA,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8067), 1,
      anon_sym_RBRACK,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7220), 1,
      aux_sym_lambda_capture_specifier_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [118904] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4019), 1,
      anon_sym_LBRACE,
    ACTIONS(7843), 1,
      anon_sym_LPAREN2,
    STATE(4801), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6089), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6091), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [118957] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8077), 1,
      anon_sym_COMMA,
    ACTIONS(8079), 1,
      anon_sym_RBRACE,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7329), 1,
      aux_sym_initializer_list_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [119054] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8081), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7333), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [119151] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7610), 1,
      sym_auto,
    ACTIONS(7612), 1,
      anon_sym_decltype,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(7737), 1,
      anon_sym_STAR,
    ACTIONS(7739), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7741), 1,
      anon_sym_AMP,
    STATE(2460), 1,
      sym_decltype_auto,
    STATE(3756), 1,
      sym_parameter_list,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6413), 1,
      sym__abstract_declarator,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4744), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7642), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [119230] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4252), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5373), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(8033), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5375), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [119281] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    ACTIONS(8121), 1,
      anon_sym_GT2,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    STATE(7304), 1,
      aux_sym_template_argument_list_repeat1,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [119378] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8123), 1,
      anon_sym_COMMA,
    ACTIONS(8125), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7279), 1,
      aux_sym_generic_expression_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [119475] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    ACTIONS(8127), 1,
      anon_sym_GT2,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    STATE(7159), 1,
      aux_sym_template_argument_list_repeat1,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [119572] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7590), 1,
      anon_sym_STAR,
    ACTIONS(7592), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7594), 1,
      anon_sym_AMP,
    STATE(3354), 1,
      sym_parameter_list,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(6122), 1,
      sym__abstract_declarator,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4294), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6596), 9,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [119645] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    ACTIONS(8129), 1,
      anon_sym_GT2,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    STATE(7264), 1,
      aux_sym_template_argument_list_repeat1,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [119742] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4320), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5318), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(8131), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5320), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [119793] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    ACTIONS(8133), 1,
      anon_sym_GT2,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    STATE(7239), 1,
      aux_sym_template_argument_list_repeat1,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [119890] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(8041), 1,
      anon_sym_COMMA,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    ACTIONS(8135), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8137), 1,
      anon_sym_RBRACK,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7031), 1,
      aux_sym_lambda_capture_specifier_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [119987] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8139), 2,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [120082] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7905), 1,
      anon_sym_SLASH,
    ACTIONS(7911), 1,
      anon_sym_PIPE,
    ACTIONS(7915), 1,
      anon_sym_AMP,
    ACTIONS(7921), 1,
      anon_sym_GT_EQ,
    ACTIONS(7927), 1,
      anon_sym_QMARK,
    ACTIONS(7929), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7931), 1,
      anon_sym_bitor,
    ACTIONS(7933), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7901), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7903), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7907), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7909), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7913), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7923), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7917), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7919), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(8141), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
  [120175] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(8143), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7299), 1,
      aux_sym_declaration_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [120272] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4019), 1,
      anon_sym_LBRACE,
    ACTIONS(7843), 1,
      anon_sym_LPAREN2,
    STATE(4749), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6136), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6138), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [120325] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    ACTIONS(8145), 1,
      anon_sym_GT2,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    STATE(7213), 1,
      aux_sym_template_argument_list_repeat1,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [120422] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8149), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8147), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [120517] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4019), 1,
      anon_sym_LBRACE,
    ACTIONS(7843), 1,
      anon_sym_LPAREN2,
    STATE(4764), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6162), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6164), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [120570] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    STATE(4679), 1,
      sym_alignas_qualifier,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8153), 2,
      anon_sym_AMP,
      anon_sym_LBRACK,
    STATE(4294), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
    ACTIONS(8151), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [120627] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    ACTIONS(8155), 1,
      anon_sym_COMMA,
    ACTIONS(8157), 1,
      anon_sym_RBRACK,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7281), 1,
      aux_sym_subscript_argument_list_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [120724] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    ACTIONS(8159), 1,
      anon_sym_GT2,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    STATE(7185), 1,
      aux_sym_template_argument_list_repeat1,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [120821] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7905), 1,
      anon_sym_SLASH,
    ACTIONS(7911), 1,
      anon_sym_PIPE,
    ACTIONS(7915), 1,
      anon_sym_AMP,
    ACTIONS(7921), 1,
      anon_sym_GT_EQ,
    ACTIONS(7927), 1,
      anon_sym_QMARK,
    ACTIONS(7929), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7931), 1,
      anon_sym_bitor,
    ACTIONS(7933), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7901), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7903), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7907), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7909), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7913), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7923), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7917), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7919), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(8161), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
  [120914] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    ACTIONS(8163), 1,
      anon_sym_GT2,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    STATE(7353), 1,
      aux_sym_template_argument_list_repeat1,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [121011] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8123), 1,
      anon_sym_COMMA,
    ACTIONS(8165), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7128), 1,
      aux_sym_generic_expression_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [121108] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    ACTIONS(8167), 1,
      anon_sym_GT2,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    STATE(7286), 1,
      aux_sym_template_argument_list_repeat1,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [121205] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8169), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7068), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [121302] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    STATE(4679), 1,
      sym_alignas_qualifier,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(7841), 2,
      anon_sym_AMP,
      anon_sym_LBRACK,
    STATE(4294), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
    ACTIONS(7839), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [121359] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8171), 1,
      anon_sym_COMMA,
    ACTIONS(8173), 1,
      anon_sym_RBRACE,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7365), 1,
      aux_sym_initializer_list_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [121456] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8175), 1,
      anon_sym_COMMA,
    ACTIONS(8177), 1,
      anon_sym_RBRACE,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7058), 1,
      aux_sym_initializer_list_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [121553] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5133), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5135), 36,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [121600] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    ACTIONS(8179), 1,
      anon_sym_GT2,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    STATE(7046), 1,
      aux_sym_template_argument_list_repeat1,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [121697] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8181), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7369), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [121794] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8183), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7273), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [121891] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(5905), 1,
      anon_sym_COLON,
    ACTIONS(7622), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(8185), 1,
      anon_sym_STAR,
    ACTIONS(8187), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8189), 1,
      anon_sym_AMP,
    STATE(3679), 1,
      sym_parameter_list,
    STATE(5027), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6594), 1,
      sym__abstract_declarator,
    ACTIONS(7624), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7626), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4872), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(5056), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [121974] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8123), 1,
      anon_sym_COMMA,
    ACTIONS(8191), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7236), 1,
      aux_sym_generic_expression_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [122071] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(6626), 1,
      sym_auto,
    ACTIONS(6628), 1,
      anon_sym_decltype,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(7789), 1,
      anon_sym_STAR,
    ACTIONS(7791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7793), 1,
      anon_sym_AMP,
    STATE(2994), 1,
      sym_decltype_auto,
    STATE(3791), 1,
      sym_parameter_list,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6437), 1,
      sym__abstract_declarator,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4737), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7660), 6,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [122150] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4252), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5377), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(8033), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5379), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [122201] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8041), 1,
      anon_sym_COMMA,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    ACTIONS(8193), 1,
      anon_sym_RBRACK,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7031), 1,
      aux_sym_lambda_capture_specifier_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [122298] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4019), 1,
      anon_sym_LBRACE,
    ACTIONS(7843), 1,
      anon_sym_LPAREN2,
    STATE(4772), 2,
      sym_argument_list,
      sym_initializer_list,
    ACTIONS(6117), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6119), 24,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [122351] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7905), 1,
      anon_sym_SLASH,
    ACTIONS(7911), 1,
      anon_sym_PIPE,
    ACTIONS(7915), 1,
      anon_sym_AMP,
    ACTIONS(7921), 1,
      anon_sym_GT_EQ,
    ACTIONS(7927), 1,
      anon_sym_QMARK,
    ACTIONS(7929), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7931), 1,
      anon_sym_bitor,
    ACTIONS(7933), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7901), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7903), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7907), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7909), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7913), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7923), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6634), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
    ACTIONS(7917), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7919), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [122444] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7997), 1,
      anon_sym_LT,
    STATE(4665), 1,
      sym_template_argument_list,
    ACTIONS(1941), 3,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_const,
    ACTIONS(1943), 33,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [122497] = 4,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1496), 1,
      sym__fold_operator,
    ACTIONS(8197), 13,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_EQ,
    ACTIONS(8195), 25,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_CARET_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT_STAR,
  [122546] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7905), 1,
      anon_sym_SLASH,
    ACTIONS(7911), 1,
      anon_sym_PIPE,
    ACTIONS(7915), 1,
      anon_sym_AMP,
    ACTIONS(7921), 1,
      anon_sym_GT_EQ,
    ACTIONS(7929), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7931), 1,
      anon_sym_bitor,
    ACTIONS(7933), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7901), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7903), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7907), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7909), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7913), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7923), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7917), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7919), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6697), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
  [122635] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8199), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7034), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [122732] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8201), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7054), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [122829] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8203), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7183), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [122926] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8205), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7149), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [123023] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4320), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5353), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(8131), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5355), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [123074] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8207), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7208), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [123171] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8209), 1,
      anon_sym_COMMA,
    ACTIONS(8211), 1,
      anon_sym_RBRACE,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7116), 1,
      aux_sym_initializer_list_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [123268] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(6626), 1,
      sym_auto,
    ACTIONS(6628), 1,
      anon_sym_decltype,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7783), 1,
      anon_sym_STAR,
    ACTIONS(7785), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7787), 1,
      anon_sym_AMP,
    STATE(2994), 1,
      sym_decltype_auto,
    STATE(3708), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6416), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4765), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7660), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [123347] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(5891), 1,
      anon_sym_COLON,
    ACTIONS(7622), 1,
      sym_ms_restrict_modifier,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(8185), 1,
      anon_sym_STAR,
    ACTIONS(8187), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8189), 1,
      anon_sym_AMP,
    STATE(3679), 1,
      sym_parameter_list,
    STATE(5027), 1,
      sym_ms_unaligned_ptr_modifier,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6574), 1,
      sym__abstract_declarator,
    ACTIONS(7624), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(7626), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4351), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    STATE(5053), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [123430] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(8041), 1,
      anon_sym_COMMA,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    ACTIONS(8135), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8213), 1,
      anon_sym_RBRACK,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7031), 1,
      aux_sym_lambda_capture_specifier_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [123527] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8123), 1,
      anon_sym_COMMA,
    ACTIONS(8215), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7338), 1,
      aux_sym_generic_expression_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [123624] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    ACTIONS(8217), 1,
      anon_sym_GT2,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    STATE(7141), 1,
      aux_sym_template_argument_list_repeat1,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [123721] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7590), 1,
      anon_sym_STAR,
    ACTIONS(7592), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7594), 1,
      anon_sym_AMP,
    STATE(3354), 1,
      sym_parameter_list,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(6137), 1,
      sym__abstract_declarator,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4294), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7877), 9,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [123794] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8041), 1,
      anon_sym_COMMA,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    ACTIONS(8219), 1,
      anon_sym_RBRACK,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7031), 1,
      aux_sym_lambda_capture_specifier_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [123891] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8139), 1,
      anon_sym_SEMI,
    ACTIONS(8221), 1,
      anon_sym_COMMA,
    ACTIONS(8224), 1,
      anon_sym_RBRACE,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [123988] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    ACTIONS(8226), 1,
      anon_sym_GT2,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    STATE(7094), 1,
      aux_sym_template_argument_list_repeat1,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [124085] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7905), 1,
      anon_sym_SLASH,
    ACTIONS(7911), 1,
      anon_sym_PIPE,
    ACTIONS(7915), 1,
      anon_sym_AMP,
    ACTIONS(7921), 1,
      anon_sym_GT_EQ,
    ACTIONS(7927), 1,
      anon_sym_QMARK,
    ACTIONS(7929), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7931), 1,
      anon_sym_bitor,
    ACTIONS(7933), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7901), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7903), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7907), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7909), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7913), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7923), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6498), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
    ACTIONS(7917), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7919), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [124178] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8020), 1,
      anon_sym_SEMI,
    ACTIONS(8228), 1,
      anon_sym_COMMA,
    ACTIONS(8231), 1,
      anon_sym_RBRACE,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [124275] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8233), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7115), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [124372] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(8235), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7108), 1,
      aux_sym_declaration_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [124469] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(8237), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7319), 1,
      aux_sym_declaration_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [124566] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(8239), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7138), 1,
      aux_sym_declaration_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [124663] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8241), 1,
      anon_sym_RPAREN,
    ACTIONS(8243), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [124760] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(8245), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7252), 1,
      aux_sym_declaration_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [124857] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8247), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7290), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [124954] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4354), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5381), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(8249), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5383), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [125005] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(7992), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7019), 1,
      aux_sym_declaration_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [125102] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    ACTIONS(8251), 1,
      anon_sym_GT2,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    STATE(7307), 1,
      aux_sym_template_argument_list_repeat1,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [125199] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(8253), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7295), 1,
      aux_sym_declaration_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [125296] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8041), 1,
      anon_sym_COMMA,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    ACTIONS(8255), 1,
      anon_sym_RBRACK,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7031), 1,
      aux_sym_lambda_capture_specifier_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [125393] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    ACTIONS(8257), 1,
      anon_sym_GT2,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    STATE(7129), 1,
      aux_sym_template_argument_list_repeat1,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [125490] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7905), 1,
      anon_sym_SLASH,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7903), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6292), 7,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [125555] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7905), 1,
      anon_sym_SLASH,
    ACTIONS(7911), 1,
      anon_sym_PIPE,
    ACTIONS(7915), 1,
      anon_sym_AMP,
    ACTIONS(7921), 1,
      anon_sym_GT_EQ,
    ACTIONS(7929), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7931), 1,
      anon_sym_bitor,
    ACTIONS(7933), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7901), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7903), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7909), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7913), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7923), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7917), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7919), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 7,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_or,
  [125642] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7590), 1,
      anon_sym_STAR,
    ACTIONS(7592), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7594), 1,
      anon_sym_AMP,
    STATE(3354), 1,
      sym_parameter_list,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(6162), 1,
      sym__abstract_declarator,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4294), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5905), 9,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [125715] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7610), 1,
      sym_auto,
    ACTIONS(7612), 1,
      anon_sym_decltype,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(7737), 1,
      anon_sym_STAR,
    ACTIONS(7739), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7741), 1,
      anon_sym_AMP,
    STATE(2460), 1,
      sym_decltype_auto,
    STATE(3756), 1,
      sym_parameter_list,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6407), 1,
      sym__abstract_declarator,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4770), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7660), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [125794] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7905), 1,
      anon_sym_SLASH,
    ACTIONS(7911), 1,
      anon_sym_PIPE,
    ACTIONS(7915), 1,
      anon_sym_AMP,
    ACTIONS(7921), 1,
      anon_sym_GT_EQ,
    ACTIONS(7929), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7931), 1,
      anon_sym_bitor,
    ACTIONS(7933), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7901), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7903), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7913), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7923), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7917), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7919), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 9,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
  [125879] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    ACTIONS(8259), 1,
      anon_sym_GT2,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    STATE(7326), 1,
      aux_sym_template_argument_list_repeat1,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [125976] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7905), 1,
      anon_sym_SLASH,
    ACTIONS(7911), 1,
      anon_sym_PIPE,
    ACTIONS(7915), 1,
      anon_sym_AMP,
    ACTIONS(7921), 1,
      anon_sym_GT_EQ,
    ACTIONS(7929), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7931), 1,
      anon_sym_bitor,
    ACTIONS(7933), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7901), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7903), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7907), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7909), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7913), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7923), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7917), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7919), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6690), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
  [126065] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8123), 1,
      anon_sym_COMMA,
    ACTIONS(8261), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7067), 1,
      aux_sym_generic_expression_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [126162] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6292), 1,
      anon_sym_PIPE,
    ACTIONS(7905), 1,
      anon_sym_SLASH,
    ACTIONS(7915), 1,
      anon_sym_AMP,
    ACTIONS(7921), 1,
      anon_sym_GT_EQ,
    ACTIONS(7929), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7933), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7901), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7903), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7913), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7923), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7917), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7919), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 10,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
  [126245] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8123), 1,
      anon_sym_COMMA,
    ACTIONS(8263), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7222), 1,
      aux_sym_generic_expression_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [126342] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6292), 1,
      anon_sym_PIPE,
    ACTIONS(7905), 1,
      anon_sym_SLASH,
    ACTIONS(7915), 1,
      anon_sym_AMP,
    ACTIONS(7921), 1,
      anon_sym_GT_EQ,
    ACTIONS(7929), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7933), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7901), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7903), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7923), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7917), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7919), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 12,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
  [126423] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7905), 1,
      anon_sym_SLASH,
    ACTIONS(7921), 1,
      anon_sym_GT_EQ,
    ACTIONS(7929), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6292), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7901), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7903), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7923), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7917), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7919), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
  [126500] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7905), 1,
      anon_sym_SLASH,
    ACTIONS(7921), 1,
      anon_sym_GT_EQ,
    ACTIONS(7929), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6292), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7901), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7903), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7923), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7919), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [126575] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7905), 1,
      anon_sym_SLASH,
    ACTIONS(7929), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7901), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7903), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7923), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6292), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [126646] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7905), 1,
      anon_sym_SLASH,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7901), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7903), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6292), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [126713] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    ACTIONS(8155), 1,
      anon_sym_COMMA,
    ACTIONS(8265), 1,
      anon_sym_RBRACK,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7075), 1,
      aux_sym_subscript_argument_list_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [126810] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    ACTIONS(8267), 1,
      anon_sym_GT2,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    STATE(7261), 1,
      aux_sym_template_argument_list_repeat1,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [126907] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    ACTIONS(8269), 1,
      anon_sym_GT2,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    STATE(7344), 1,
      aux_sym_template_argument_list_repeat1,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [127004] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7905), 1,
      anon_sym_SLASH,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7901), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7903), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7923), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6292), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [127073] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8271), 1,
      anon_sym_COMMA,
    ACTIONS(8273), 1,
      anon_sym_RBRACE,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7243), 1,
      aux_sym_initializer_list_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [127170] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8275), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7270), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [127267] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7997), 1,
      anon_sym_LT,
    STATE(4665), 1,
      sym_template_argument_list,
    ACTIONS(1933), 3,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_const,
    ACTIONS(1935), 33,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [127320] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(6626), 1,
      sym_auto,
    ACTIONS(6628), 1,
      anon_sym_decltype,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7783), 1,
      anon_sym_STAR,
    ACTIONS(7785), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7787), 1,
      anon_sym_AMP,
    STATE(2994), 1,
      sym_decltype_auto,
    STATE(3708), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6412), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4767), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7642), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [127399] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7905), 1,
      anon_sym_SLASH,
    ACTIONS(7911), 1,
      anon_sym_PIPE,
    ACTIONS(7915), 1,
      anon_sym_AMP,
    ACTIONS(7921), 1,
      anon_sym_GT_EQ,
    ACTIONS(7929), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7931), 1,
      anon_sym_bitor,
    ACTIONS(7933), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7901), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7903), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7907), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7909), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7913), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7923), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7917), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7919), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6705), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
  [127488] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(63), 1,
      anon_sym_const,
    STATE(1957), 1,
      sym_alignas_qualifier,
    ACTIONS(7328), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8153), 2,
      anon_sym_AMP,
      anon_sym_LBRACK,
    STATE(4298), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7324), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
    ACTIONS(8151), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [127545] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    ACTIONS(8277), 1,
      anon_sym_GT2,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    STATE(7360), 1,
      aux_sym_template_argument_list_repeat1,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [127642] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    ACTIONS(8155), 1,
      anon_sym_COMMA,
    ACTIONS(8279), 1,
      anon_sym_RBRACK,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7146), 1,
      aux_sym_subscript_argument_list_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [127739] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    ACTIONS(8281), 1,
      anon_sym_GT2,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    STATE(7372), 1,
      aux_sym_template_argument_list_repeat1,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [127836] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8022), 1,
      anon_sym_RBRACE,
    ACTIONS(8283), 1,
      anon_sym_COMMA,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7409), 1,
      aux_sym_initializer_list_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [127933] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7905), 1,
      anon_sym_SLASH,
    ACTIONS(7911), 1,
      anon_sym_PIPE,
    ACTIONS(7915), 1,
      anon_sym_AMP,
    ACTIONS(7921), 1,
      anon_sym_GT_EQ,
    ACTIONS(7927), 1,
      anon_sym_QMARK,
    ACTIONS(7929), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7931), 1,
      anon_sym_bitor,
    ACTIONS(7933), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7901), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7903), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7907), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7909), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7913), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7923), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6672), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
    ACTIONS(7917), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7919), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [128026] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    ACTIONS(8285), 1,
      anon_sym_GT2,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    STATE(7047), 1,
      aux_sym_template_argument_list_repeat1,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [128123] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    ACTIONS(8287), 1,
      anon_sym_GT2,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    STATE(7381), 1,
      aux_sym_template_argument_list_repeat1,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [128220] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    ACTIONS(8289), 1,
      anon_sym_GT2,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    STATE(7389), 1,
      aux_sym_template_argument_list_repeat1,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [128317] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    ACTIONS(8291), 1,
      anon_sym_GT2,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    STATE(7397), 1,
      aux_sym_template_argument_list_repeat1,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [128414] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6890), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7590), 1,
      anon_sym_STAR,
    ACTIONS(7592), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7594), 1,
      anon_sym_AMP,
    STATE(3354), 1,
      sym_parameter_list,
    STATE(4679), 1,
      sym_alignas_qualifier,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(6118), 1,
      sym__abstract_declarator,
    ACTIONS(6892), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4294), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7881), 9,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(6881), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [128487] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(8293), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7069), 1,
      aux_sym_declaration_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [128584] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8295), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7030), 1,
      aux_sym_argument_list_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [128681] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7905), 1,
      anon_sym_SLASH,
    ACTIONS(7911), 1,
      anon_sym_PIPE,
    ACTIONS(7915), 1,
      anon_sym_AMP,
    ACTIONS(7921), 1,
      anon_sym_GT_EQ,
    ACTIONS(7929), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7931), 1,
      anon_sym_bitor,
    ACTIONS(7933), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7901), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7903), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7907), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7909), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7913), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7923), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7917), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7919), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6701), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_QMARK,
  [128770] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(8297), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    STATE(7055), 1,
      aux_sym_declaration_repeat1,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [128867] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6292), 7,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [128931] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8303), 1,
      anon_sym_COMMA,
    ACTIONS(8305), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [129025] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8327), 1,
      anon_sym_QMARK,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6672), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [129117] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6634), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [129209] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6701), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_QMARK,
  [129297] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6690), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [129385] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6292), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [129453] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(6292), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [129519] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6292), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [129589] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6292), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [129663] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6292), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 12,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
  [129739] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6292), 1,
      anon_sym_PIPE,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 11,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
  [129819] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6292), 1,
      anon_sym_PIPE,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 9,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
  [129901] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 8,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
  [129985] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_or,
  [130071] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8335), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [130165] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8327), 1,
      anon_sym_QMARK,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6498), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [130257] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8337), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [130351] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6697), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_QMARK,
  [130439] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8339), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [130533] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8327), 1,
      anon_sym_QMARK,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6634), 2,
      anon_sym_COMMA,
      anon_sym_COLON,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [130625] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5155), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(5153), 25,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_template,
      anon_sym_operator,
      anon_sym_try,
      anon_sym_requires,
  [130671] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8341), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [130765] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8327), 1,
      anon_sym_QMARK,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    ACTIONS(8343), 1,
      anon_sym_COMMA,
    ACTIONS(8345), 1,
      anon_sym_COLON,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [130859] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8347), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [130951] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    STATE(2390), 1,
      sym_template_argument_list,
    STATE(2520), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5294), 3,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_const,
    ACTIONS(5190), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5296), 27,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [131007] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8224), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [131099] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6249), 8,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6251), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [131157] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8349), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [131251] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8351), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [131343] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8353), 1,
      anon_sym_COMMA,
    ACTIONS(8355), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [131437] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6672), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [131529] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8327), 1,
      anon_sym_QMARK,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    ACTIONS(8343), 1,
      anon_sym_COMMA,
    ACTIONS(8357), 1,
      anon_sym_COLON,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [131623] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8359), 1,
      anon_sym_COMMA,
    ACTIONS(8361), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [131717] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    STATE(2221), 1,
      sym_template_argument_list,
    STATE(4312), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(3822), 4,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(7879), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(3830), 26,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [131773] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6705), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_QMARK,
  [131861] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1961), 2,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
    ACTIONS(4063), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4058), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [131909] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6701), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [131997] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8327), 1,
      anon_sym_QMARK,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    ACTIONS(8343), 1,
      anon_sym_COMMA,
    ACTIONS(8363), 1,
      anon_sym_COLON,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [132091] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8365), 1,
      anon_sym_COMMA,
    ACTIONS(8367), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [132185] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8231), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [132277] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2851), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(2849), 25,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_template,
      anon_sym_operator,
      anon_sym_try,
      anon_sym_requires,
  [132323] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8327), 1,
      anon_sym_QMARK,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    ACTIONS(8343), 1,
      anon_sym_COMMA,
    ACTIONS(8369), 1,
      anon_sym_COLON,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [132417] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8371), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [132511] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8373), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [132603] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8139), 1,
      anon_sym_COLON,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8327), 1,
      anon_sym_QMARK,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    ACTIONS(8343), 1,
      anon_sym_COMMA,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [132697] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8375), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [132789] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7851), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [132881] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8381), 1,
      anon_sym___attribute__,
    STATE(4479), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    ACTIONS(8379), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(8377), 32,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [132931] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8384), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [133025] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8327), 1,
      anon_sym_QMARK,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    ACTIONS(8343), 1,
      anon_sym_COMMA,
    ACTIONS(8386), 1,
      anon_sym_COLON,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [133119] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8388), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [133211] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(63), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7833), 1,
      anon_sym_STAR,
    ACTIONS(7835), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP,
    ACTIONS(8390), 1,
      sym_auto,
    ACTIONS(8392), 1,
      anon_sym_decltype,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2274), 1,
      sym_decltype_auto,
    STATE(3908), 1,
      sym_parameter_list,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(6462), 1,
      sym__abstract_declarator,
    ACTIONS(7328), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4871), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7642), 5,
      anon_sym_RPAREN,
      anon_sym_LBRACK_LBRACK,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7324), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [133289] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8394), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [133383] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8388), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [133475] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6292), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [133543] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8327), 1,
      anon_sym_QMARK,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    ACTIONS(8343), 1,
      anon_sym_COMMA,
    ACTIONS(8396), 1,
      anon_sym_COLON,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [133637] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6292), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [133703] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6731), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6733), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [133749] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(6292), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [133819] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8398), 1,
      anon_sym_COMMA,
    ACTIONS(8400), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [133913] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8402), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [134005] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8404), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [134099] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8327), 1,
      anon_sym_QMARK,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    ACTIONS(8343), 1,
      anon_sym_COMMA,
    ACTIONS(8406), 1,
      anon_sym_COLON,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [134193] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8408), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [134285] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4515), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5353), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(8410), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5355), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [134335] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4297), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5387), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(8412), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5389), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [134385] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4297), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5377), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(8412), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5379), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [134435] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5188), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5876), 1,
      anon_sym_LPAREN2,
    ACTIONS(5882), 1,
      anon_sym_LBRACK,
    ACTIONS(3832), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_DOT,
    ACTIONS(3824), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [134487] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8388), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [134579] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8327), 1,
      anon_sym_QMARK,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    ACTIONS(8343), 1,
      anon_sym_COMMA,
    ACTIONS(8414), 1,
      anon_sym_COLON,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [134673] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8416), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [134765] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4497), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5367), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(8418), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5369), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [134815] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4498), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5381), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(8420), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5383), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [134865] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8327), 1,
      anon_sym_QMARK,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    ACTIONS(8343), 1,
      anon_sym_COMMA,
    ACTIONS(8422), 1,
      anon_sym_COLON,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [134959] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8424), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [135053] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6292), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [135127] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6690), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_QMARK,
  [135215] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8388), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [135307] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4297), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5347), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(8412), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5349), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [135357] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8020), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [135451] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8426), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [135545] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(6634), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [135637] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8243), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [135731] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4297), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5373), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(8412), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5375), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [135781] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6292), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 12,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
  [135857] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6292), 1,
      anon_sym_PIPE,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 11,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
  [135937] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7845), 1,
      anon_sym_LBRACK,
    STATE(4718), 1,
      sym_new_declarator,
    ACTIONS(6221), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6223), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [135987] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(6292), 1,
      anon_sym_PIPE,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 9,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
  [136069] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(63), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7833), 1,
      anon_sym_STAR,
    ACTIONS(7835), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP,
    ACTIONS(8390), 1,
      sym_auto,
    ACTIONS(8392), 1,
      anon_sym_decltype,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2274), 1,
      sym_decltype_auto,
    STATE(3908), 1,
      sym_parameter_list,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(6460), 1,
      sym__abstract_declarator,
    ACTIONS(7328), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4853), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7660), 5,
      anon_sym_RPAREN,
      anon_sym_LBRACK_LBRACK,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7324), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [136147] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5836), 1,
      sym_literal_suffix,
    ACTIONS(5838), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(5840), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [136195] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8327), 1,
      anon_sym_QMARK,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    ACTIONS(8343), 1,
      anon_sym_COMMA,
    ACTIONS(8428), 1,
      anon_sym_COLON,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [136289] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5836), 1,
      sym_literal_suffix,
    ACTIONS(3832), 16,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym___attribute__,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(3824), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [136337] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 8,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
  [136421] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8430), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [136515] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(6690), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_GT2,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [136603] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_or,
  [136689] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6270), 8,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6272), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [136749] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(6672), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [136841] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6292), 7,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_RBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [136905] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8147), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [136997] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8327), 1,
      anon_sym_QMARK,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    ACTIONS(8343), 1,
      anon_sym_COMMA,
    ACTIONS(8432), 1,
      anon_sym_COLON,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [137091] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8434), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [137183] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6292), 8,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [137243] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8402), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [137335] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7614), 1,
      anon_sym_STAR,
    ACTIONS(7616), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7618), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    STATE(3399), 1,
      sym_parameter_list,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6204), 1,
      sym__abstract_declarator,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5200), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6596), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [137407] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8436), 1,
      anon_sym___attribute__,
    STATE(4537), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    ACTIONS(8379), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(8377), 32,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [137457] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7614), 1,
      anon_sym_STAR,
    ACTIONS(7616), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7618), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    STATE(3399), 1,
      sym_parameter_list,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6211), 1,
      sym__abstract_declarator,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5200), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7877), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [137529] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8439), 1,
      anon_sym_COMMA,
    ACTIONS(8441), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [137623] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3934), 1,
      anon_sym_LPAREN2,
    ACTIONS(3936), 1,
      anon_sym_STAR,
    ACTIONS(3938), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3940), 1,
      anon_sym_AMP,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(5903), 1,
      anon_sym_LBRACK,
    ACTIONS(6213), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7759), 1,
      anon_sym_RPAREN,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(5718), 1,
      sym__scope_resolution,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6295), 1,
      sym__declarator,
    STATE(6578), 1,
      sym__abstract_declarator,
    STATE(8582), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [137709] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8327), 1,
      anon_sym_QMARK,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    ACTIONS(8343), 1,
      anon_sym_COMMA,
    ACTIONS(8443), 1,
      anon_sym_COLON,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [137803] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6498), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [137895] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    STATE(2390), 1,
      sym_template_argument_list,
    STATE(4844), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5294), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(8445), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5296), 27,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [137951] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7614), 1,
      anon_sym_STAR,
    ACTIONS(7616), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7618), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    STATE(3399), 1,
      sym_parameter_list,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6201), 1,
      sym__abstract_declarator,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5200), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5905), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [138023] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8447), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [138117] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8449), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [138211] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(6701), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_GT2,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [138299] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8451), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [138393] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    STATE(2390), 1,
      sym_template_argument_list,
    STATE(2666), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5294), 3,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_const,
    ACTIONS(5204), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5296), 27,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [138449] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(6498), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [138541] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8453), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [138635] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6697), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [138723] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8455), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [138817] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6327), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
    ACTIONS(6329), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
  [138877] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6331), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
    ACTIONS(6333), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
  [138937] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(6705), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_GT2,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [139025] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6270), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
    ACTIONS(6272), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
  [139085] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6302), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
    ACTIONS(6304), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_GT2,
  [139143] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8457), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [139237] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8459), 1,
      anon_sym_COMMA,
    ACTIONS(8461), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [139331] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8463), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [139425] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8465), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [139519] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6302), 8,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6304), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
  [139577] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6331), 8,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6333), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [139637] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6292), 6,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 16,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
  [139707] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6292), 7,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
    ACTIONS(6294), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
  [139773] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6292), 6,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
  [139845] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6327), 8,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6329), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_COLON,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
  [139905] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(6292), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
  [139979] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(6292), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 12,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_GT2,
  [140055] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6292), 1,
      anon_sym_PIPE,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 11,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_GT2,
  [140135] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6292), 1,
      anon_sym_PIPE,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 9,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_GT2,
  [140217] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 8,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_and,
      anon_sym_GT2,
  [140301] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6294), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK,
      anon_sym_or,
      anon_sym_GT2,
  [140387] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6292), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
    ACTIONS(6294), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
  [140447] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(6292), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
    ACTIONS(6294), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_GT2,
  [140511] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7614), 1,
      anon_sym_STAR,
    ACTIONS(7616), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7618), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    STATE(3399), 1,
      sym_parameter_list,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6191), 1,
      sym__abstract_declarator,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5200), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7881), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [140583] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8327), 1,
      anon_sym_QMARK,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    ACTIONS(8343), 1,
      anon_sym_COMMA,
    ACTIONS(8467), 1,
      anon_sym_COLON,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [140677] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    STATE(4865), 1,
      sym_field_declaration_list,
    STATE(4888), 1,
      sym_attribute_specifier,
    STATE(6875), 1,
      sym_virtual_specifier,
    STATE(7654), 1,
      sym_base_class_clause,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(5327), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5329), 26,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [140739] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8083), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_QMARK,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8471), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [140831] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    ACTIONS(8091), 1,
      anon_sym_SLASH,
    ACTIONS(8097), 1,
      anon_sym_PIPE,
    ACTIONS(8101), 1,
      anon_sym_AMP,
    ACTIONS(8107), 1,
      anon_sym_LT_LT,
    ACTIONS(8109), 1,
      anon_sym_GT_GT,
    ACTIONS(8113), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8115), 1,
      anon_sym_bitor,
    ACTIONS(8117), 1,
      anon_sym_bitand,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(8087), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8089), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8093), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8095), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8099), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8119), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8103), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(6697), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_QMARK,
      anon_sym_GT2,
    ACTIONS(8105), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [140919] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    ACTIONS(7110), 1,
      anon_sym_LBRACK,
    ACTIONS(7126), 1,
      anon_sym_DOT,
    STATE(3731), 1,
      sym_argument_list,
    STATE(3732), 1,
      sym_subscript_argument_list,
    ACTIONS(7128), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(6249), 10,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
    ACTIONS(6251), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_GT2,
  [140977] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(6705), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_QMARK,
  [141065] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7144), 1,
      anon_sym_COMMA,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8473), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [141159] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8475), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [141250] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8477), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [141341] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8479), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [141432] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(8481), 1,
      anon_sym___attribute__,
    ACTIONS(8483), 1,
      anon_sym_LBRACE,
    STATE(4899), 1,
      sym_field_declaration_list,
    STATE(4998), 1,
      sym_attribute_specifier,
    STATE(6945), 1,
      sym_virtual_specifier,
    STATE(7560), 1,
      sym_base_class_clause,
    ACTIONS(5327), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(5329), 26,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [141493] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8485), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [141584] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8487), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [141675] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8489), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [141766] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8491), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [141857] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8493), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [141948] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8495), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [142039] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7662), 1,
      anon_sym_STAR,
    ACTIONS(7664), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7666), 1,
      anon_sym_AMP,
    STATE(3505), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6290), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4962), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7881), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [142110] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8497), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [142201] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8499), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [142292] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(8501), 1,
      anon_sym_COLON,
    ACTIONS(8503), 1,
      anon_sym_LBRACE,
    STATE(4795), 1,
      sym__enum_base_clause,
    STATE(4860), 1,
      sym_enumerator_list,
    STATE(4921), 1,
      sym_attribute_specifier,
    ACTIONS(5689), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5691), 28,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [142349] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    ACTIONS(8505), 1,
      anon_sym_RBRACK,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [142440] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(8501), 1,
      anon_sym_COLON,
    ACTIONS(8503), 1,
      anon_sym_LBRACE,
    STATE(4826), 1,
      sym__enum_base_clause,
    STATE(4866), 1,
      sym_enumerator_list,
    STATE(4883), 1,
      sym_attribute_specifier,
    ACTIONS(5636), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5638), 28,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [142497] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8507), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [142588] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8509), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [142679] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8511), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [142770] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7662), 1,
      anon_sym_STAR,
    ACTIONS(7664), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7666), 1,
      anon_sym_AMP,
    STATE(3505), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6342), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4962), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5905), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [142841] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8327), 1,
      anon_sym_QMARK,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    ACTIONS(8513), 1,
      anon_sym_COLON,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [142932] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3934), 1,
      anon_sym_LPAREN2,
    ACTIONS(3936), 1,
      anon_sym_STAR,
    ACTIONS(3938), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3940), 1,
      anon_sym_AMP,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(5903), 1,
      anon_sym_LBRACK,
    ACTIONS(6213), 1,
      anon_sym_COLON_COLON,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(5718), 1,
      sym__scope_resolution,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6537), 1,
      sym__declarator,
    STATE(6682), 1,
      sym__abstract_declarator,
    STATE(8582), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [143015] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7662), 1,
      anon_sym_STAR,
    ACTIONS(7664), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7666), 1,
      anon_sym_AMP,
    STATE(3505), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6381), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4962), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7877), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [143086] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8515), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [143177] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8517), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [143268] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8519), 1,
      anon_sym_COMMA,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [143359] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8521), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [143450] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8523), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [143541] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8525), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [143632] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8149), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [143723] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8527), 1,
      anon_sym_COMMA,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [143814] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8529), 1,
      anon_sym_COMMA,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [143905] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8531), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [143996] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8533), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [144087] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8535), 1,
      anon_sym_COMMA,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [144178] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6928), 1,
      anon_sym_STAR,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(5281), 1,
      sym_ms_call_modifier,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5755), 1,
      sym__declarator,
    STATE(7350), 1,
      sym_init_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [144259] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8537), 1,
      anon_sym_COMMA,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [144350] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    ACTIONS(8539), 1,
      anon_sym_RBRACK,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [144441] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8541), 1,
      anon_sym_COMMA,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [144532] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8543), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [144623] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6266), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(6268), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [144668] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6928), 1,
      anon_sym_STAR,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(5246), 1,
      sym_ms_call_modifier,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5746), 1,
      sym__declarator,
    STATE(7026), 1,
      sym_init_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [144749] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8545), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [144840] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8547), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [144931] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    ACTIONS(8549), 1,
      anon_sym_RBRACK,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [145022] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8551), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [145113] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8553), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [145204] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8555), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [145295] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6928), 1,
      anon_sym_STAR,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(5284), 1,
      sym_ms_call_modifier,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5751), 1,
      sym__declarator,
    STATE(7340), 1,
      sym_init_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [145376] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8557), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [145467] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8559), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [145558] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    ACTIONS(8561), 1,
      anon_sym_RBRACK,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [145649] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4710), 1,
      anon_sym_RBRACK,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [145740] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8563), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [145831] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6928), 1,
      anon_sym_STAR,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(5263), 1,
      sym_ms_call_modifier,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5750), 1,
      sym__declarator,
    STATE(7323), 1,
      sym_init_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [145912] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8565), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [146003] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8567), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [146094] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8569), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [146185] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8327), 1,
      anon_sym_QMARK,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    ACTIONS(8571), 1,
      anon_sym_COLON,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [146276] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7662), 1,
      anon_sym_STAR,
    ACTIONS(7664), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7666), 1,
      anon_sym_AMP,
    STATE(3505), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6313), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4962), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6596), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [146347] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8573), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [146438] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8575), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [146529] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4801), 1,
      anon_sym_RBRACK,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [146620] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8577), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [146711] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8579), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [146802] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8581), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [146893] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4712), 1,
      anon_sym_RBRACK,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [146984] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8583), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [147075] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4900), 1,
      anon_sym_RBRACK,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [147166] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8585), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [147257] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8587), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [147348] = 7,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1957), 1,
      sym_alignas_qualifier,
    ACTIONS(8589), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8005), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON_COLON,
    ACTIONS(8027), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
    ACTIONS(8007), 16,
      anon_sym_AMP,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_primitive_type,
      anon_sym_enum,
      anon_sym_class,
      anon_sym_struct,
      anon_sym_union,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
      anon_sym_typename,
      anon_sym_template,
  [147401] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8592), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [147492] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    ACTIONS(8135), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8594), 1,
      anon_sym_RBRACK,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [147583] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8327), 1,
      anon_sym_QMARK,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    ACTIONS(8596), 1,
      anon_sym_COLON,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [147674] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8598), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [147765] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4815), 1,
      anon_sym_RBRACK,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [147856] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6731), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
      sym_literal_suffix,
    ACTIONS(6733), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [147901] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8327), 1,
      anon_sym_QMARK,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    ACTIONS(8600), 1,
      anon_sym_COLON,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [147992] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6928), 1,
      anon_sym_STAR,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(5288), 1,
      sym_ms_call_modifier,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5754), 1,
      sym__declarator,
    STATE(7096), 1,
      sym_init_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [148073] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1959), 3,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_const,
    ACTIONS(1961), 34,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [148118] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1949), 3,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_const,
    ACTIONS(1951), 34,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [148163] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8602), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [148254] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1953), 3,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_const,
    ACTIONS(1955), 33,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [148301] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1953), 3,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_const,
    ACTIONS(1955), 33,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [148348] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6896), 1,
      anon_sym_DASH_GT,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(8606), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(4946), 1,
      sym_ref_qualifier,
    STATE(5556), 1,
      sym__function_attributes_end,
    STATE(5675), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5272), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [148431] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1969), 3,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_const,
    ACTIONS(1971), 33,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [148478] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(7257), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8301), 1,
      anon_sym_SLASH,
    ACTIONS(8313), 1,
      anon_sym_PIPE,
    ACTIONS(8317), 1,
      anon_sym_AMP,
    ACTIONS(8323), 1,
      anon_sym_GT_EQ,
    ACTIONS(8327), 1,
      anon_sym_QMARK,
    ACTIONS(8329), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8331), 1,
      anon_sym_bitor,
    ACTIONS(8333), 1,
      anon_sym_bitand,
    ACTIONS(8611), 1,
      anon_sym_COLON,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(7259), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8299), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8307), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8309), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8311), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8315), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8325), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8319), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8321), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [148569] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8613), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [148660] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    ACTIONS(8615), 1,
      anon_sym_RBRACK,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [148751] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1917), 3,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_const,
    ACTIONS(1919), 34,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [148796] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1887), 3,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_const,
    ACTIONS(1889), 34,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [148841] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4849), 1,
      anon_sym_RBRACK,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [148932] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8617), 1,
      sym_identifier,
    ACTIONS(8619), 1,
      sym_primitive_type,
    STATE(2410), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(6160), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5336), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_GT2,
    ACTIONS(5338), 22,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [148985] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2849), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(2851), 34,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [149030] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4841), 1,
      anon_sym_RBRACK,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [149121] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1891), 3,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_const,
    ACTIONS(1893), 34,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [149166] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1925), 3,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_const,
    ACTIONS(1927), 34,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [149211] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1899), 3,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_const,
    ACTIONS(1901), 34,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [149256] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1903), 3,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_const,
    ACTIONS(1905), 34,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [149301] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1895), 3,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_const,
    ACTIONS(1897), 34,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [149346] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    ACTIONS(8621), 1,
      anon_sym_RBRACK,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [149437] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4888), 1,
      anon_sym_RBRACK,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [149528] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4779), 1,
      anon_sym_RBRACK,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [149619] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4876), 1,
      anon_sym_RBRACK,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [149710] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4787), 1,
      anon_sym_RBRACK,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [149801] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5153), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5155), 34,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [149846] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8623), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [149937] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7847), 1,
      anon_sym_LT,
    STATE(2390), 1,
      sym_template_argument_list,
    STATE(2520), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(3822), 3,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_const,
    ACTIONS(5190), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(3830), 26,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [149992] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6928), 1,
      anon_sym_STAR,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(5225), 1,
      sym_ms_call_modifier,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5759), 1,
      sym__declarator,
    STATE(7152), 1,
      sym_init_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [150073] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6211), 1,
      sym_literal_suffix,
    ACTIONS(3832), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(3824), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [150120] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6211), 1,
      sym_literal_suffix,
    ACTIONS(5838), 17,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(5840), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [150167] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4723), 1,
      anon_sym_RBRACK,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [150258] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8625), 1,
      anon_sym_RBRACE,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [150349] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4791), 1,
      anon_sym_RBRACK,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [150440] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8627), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [150531] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8629), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [150622] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4735), 1,
      anon_sym_RBRACK,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [150713] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6896), 1,
      anon_sym_DASH_GT,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(8606), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8634), 1,
      anon_sym_requires,
    STATE(4884), 1,
      sym_ref_qualifier,
    STATE(5548), 1,
      sym__function_attributes_end,
    STATE(5721), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8631), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5307), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [150796] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8637), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [150887] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4717), 1,
      anon_sym_RBRACK,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [150978] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8639), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [151069] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8641), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [151160] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8643), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [151251] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8645), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [151342] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7676), 1,
      anon_sym_STAR,
    ACTIONS(7678), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7680), 1,
      anon_sym_AMP,
    STATE(3634), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6321), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4962), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6596), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [151413] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8647), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [151504] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4882), 1,
      anon_sym_RBRACK,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [151595] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    ACTIONS(8649), 1,
      anon_sym_RBRACK,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [151686] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4793), 1,
      anon_sym_RBRACK,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [151777] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8651), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [151868] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    ACTIONS(8653), 1,
      anon_sym_RBRACK,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [151959] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8655), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [152050] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6229), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6231), 26,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [152095] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7676), 1,
      anon_sym_STAR,
    ACTIONS(7678), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7680), 1,
      anon_sym_AMP,
    STATE(3634), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6372), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4962), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7881), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [152166] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6335), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(6337), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [152211] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6253), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(6255), 34,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [152256] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4515), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5318), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(8410), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5320), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [152305] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7676), 1,
      anon_sym_STAR,
    ACTIONS(7678), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7680), 1,
      anon_sym_AMP,
    STATE(3634), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6326), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4962), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7877), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [152376] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4803), 1,
      anon_sym_RBRACK,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [152467] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7676), 1,
      anon_sym_STAR,
    ACTIONS(7678), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7680), 1,
      anon_sym_AMP,
    STATE(3634), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6297), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4962), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5905), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [152538] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8657), 1,
      anon_sym_SEMI,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [152629] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4809), 1,
      anon_sym_RBRACK,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [152720] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4789), 1,
      anon_sym_RBRACK,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8047), 1,
      anon_sym_SLASH,
    ACTIONS(8053), 1,
      anon_sym_PIPE,
    ACTIONS(8057), 1,
      anon_sym_AMP,
    ACTIONS(8063), 1,
      anon_sym_GT_EQ,
    ACTIONS(8069), 1,
      anon_sym_QMARK,
    ACTIONS(8071), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(8073), 1,
      anon_sym_bitor,
    ACTIONS(8075), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(8043), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(8045), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8049), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(8051), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8055), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(8065), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(8059), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(8061), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [152811] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8659), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [152902] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6928), 1,
      anon_sym_STAR,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(5309), 1,
      sym_ms_call_modifier,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5758), 1,
      sym__declarator,
    STATE(7432), 1,
      sym_init_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [152983] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    ACTIONS(8661), 1,
      anon_sym_RPAREN,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [153074] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7777), 1,
      anon_sym_STAR,
    ACTIONS(7779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7781), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2551), 1,
      sym__type_declarator,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(8179), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [153146] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5283), 1,
      sym_ms_call_modifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6248), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [153224] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(7737), 1,
      anon_sym_STAR,
    ACTIONS(7739), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7741), 1,
      anon_sym_AMP,
    STATE(3756), 1,
      sym_parameter_list,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6419), 1,
      sym__abstract_declarator,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5200), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5905), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [153294] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2605), 1,
      anon_sym_STAR,
    ACTIONS(2607), 1,
      anon_sym_AMP,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(6213), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(5254), 1,
      sym_ms_call_modifier,
    STATE(5718), 1,
      sym__scope_resolution,
    STATE(6515), 1,
      sym__declarator,
    STATE(8582), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [153372] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8663), 1,
      anon_sym_LT,
    STATE(2895), 1,
      sym_template_argument_list,
    ACTIONS(1933), 3,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_const,
    ACTIONS(1935), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [153422] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(7789), 1,
      anon_sym_STAR,
    ACTIONS(7791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7793), 1,
      anon_sym_AMP,
    STATE(3791), 1,
      sym_parameter_list,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6422), 1,
      sym__abstract_declarator,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5200), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7881), 6,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [153492] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5299), 1,
      sym_ms_call_modifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6333), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [153570] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6488), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6490), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [153614] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6365), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6367), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [153658] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6457), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6459), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [153702] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6496), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6498), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [153746] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5251), 1,
      sym_ms_call_modifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6284), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [153824] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(7737), 1,
      anon_sym_STAR,
    ACTIONS(7739), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7741), 1,
      anon_sym_AMP,
    STATE(3756), 1,
      sym_parameter_list,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6389), 1,
      sym__abstract_declarator,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5200), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7877), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [153894] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7703), 1,
      sym_identifier,
    ACTIONS(7705), 1,
      anon_sym_LPAREN2,
    ACTIONS(7707), 1,
      anon_sym_STAR,
    ACTIONS(7709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7711), 1,
      anon_sym_AMP,
    ACTIONS(7715), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(6077), 1,
      sym__type_declarator,
    STATE(6279), 1,
      sym_pointer_type_declarator,
    STATE(8225), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7713), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6273), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [153966] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6484), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6486), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [154010] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7687), 1,
      sym_identifier,
    ACTIONS(7689), 1,
      anon_sym_LPAREN2,
    ACTIONS(7691), 1,
      anon_sym_STAR,
    ACTIONS(7693), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7695), 1,
      anon_sym_AMP,
    ACTIONS(7701), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(3194), 1,
      sym__type_declarator,
    STATE(3549), 1,
      sym_pointer_type_declarator,
    STATE(7998), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7699), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3547), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [154082] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4999), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2202), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [154126] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6399), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6401), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [154170] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym___attribute__,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    STATE(2482), 1,
      sym_attribute_specifier,
    STATE(5279), 1,
      sym_field_declaration_list,
    STATE(6986), 1,
      sym_virtual_specifier,
    STATE(7577), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(5329), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(5327), 24,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [154230] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7610), 1,
      sym_auto,
    ACTIONS(7612), 1,
      anon_sym_decltype,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    STATE(2460), 1,
      sym_decltype_auto,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6593), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4963), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7660), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [154306] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8663), 1,
      anon_sym_LT,
    STATE(2666), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2895), 1,
      sym_template_argument_list,
    ACTIONS(3822), 3,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_const,
    ACTIONS(5204), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(3830), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [154360] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(6626), 1,
      sym_auto,
    ACTIONS(6628), 1,
      anon_sym_decltype,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7950), 1,
      anon_sym_STAR,
    ACTIONS(7952), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7954), 1,
      anon_sym_AMP,
    STATE(2994), 1,
      sym_decltype_auto,
    STATE(3794), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6590), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4975), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7642), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [154436] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6403), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6405), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [154480] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5228), 1,
      sym_ms_call_modifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6328), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [154558] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7703), 1,
      sym_identifier,
    ACTIONS(7705), 1,
      anon_sym_LPAREN2,
    ACTIONS(7707), 1,
      anon_sym_STAR,
    ACTIONS(7709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7711), 1,
      anon_sym_AMP,
    ACTIONS(7715), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(6056), 1,
      sym__type_declarator,
    STATE(6279), 1,
      sym_pointer_type_declarator,
    STATE(8225), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7713), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6273), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [154630] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8665), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5252), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5254), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [154676] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5256), 1,
      sym_ms_call_modifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6294), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [154754] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6435), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6437), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [154798] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6504), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6506), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [154842] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(7737), 1,
      anon_sym_STAR,
    ACTIONS(7739), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7741), 1,
      anon_sym_AMP,
    STATE(3756), 1,
      sym_parameter_list,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6424), 1,
      sym__abstract_declarator,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5200), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6596), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [154912] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6508), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6510), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [154956] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6512), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6514), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [155000] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6532), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6534), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [155044] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7783), 1,
      anon_sym_STAR,
    ACTIONS(7785), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7787), 1,
      anon_sym_AMP,
    STATE(3708), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6415), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4962), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7881), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [155114] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7783), 1,
      anon_sym_STAR,
    ACTIONS(7785), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7787), 1,
      anon_sym_AMP,
    STATE(3708), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6401), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4962), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5905), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [155184] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7783), 1,
      anon_sym_STAR,
    ACTIONS(7785), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7787), 1,
      anon_sym_AMP,
    STATE(3708), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6410), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4962), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7877), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [155254] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7783), 1,
      anon_sym_STAR,
    ACTIONS(7785), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7787), 1,
      anon_sym_AMP,
    STATE(3708), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6399), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4962), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6596), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [155324] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8663), 1,
      anon_sym_LT,
    STATE(2895), 1,
      sym_template_argument_list,
    ACTIONS(1941), 3,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_const,
    ACTIONS(1943), 30,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [155374] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(7737), 1,
      anon_sym_STAR,
    ACTIONS(7739), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7741), 1,
      anon_sym_AMP,
    STATE(3756), 1,
      sym_parameter_list,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6414), 1,
      sym__abstract_declarator,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5200), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7881), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [155444] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7687), 1,
      sym_identifier,
    ACTIONS(7689), 1,
      anon_sym_LPAREN2,
    ACTIONS(7691), 1,
      anon_sym_STAR,
    ACTIONS(7693), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7695), 1,
      anon_sym_AMP,
    ACTIONS(7701), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(3159), 1,
      sym__type_declarator,
    STATE(3549), 1,
      sym_pointer_type_declarator,
    STATE(7998), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7699), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3547), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [155516] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6359), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6361), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [155560] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6524), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6526), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [155604] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6347), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6349), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [155648] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6544), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6546), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [155692] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6516), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6518), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [155736] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(6626), 1,
      sym_auto,
    ACTIONS(6628), 1,
      anon_sym_decltype,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7950), 1,
      anon_sym_STAR,
    ACTIONS(7952), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7954), 1,
      anon_sym_AMP,
    STATE(2994), 1,
      sym_decltype_auto,
    STATE(3794), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6562), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4949), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7660), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [155812] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3928), 1,
      anon_sym_SEMI,
    ACTIONS(5188), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5876), 1,
      anon_sym_LPAREN2,
    ACTIONS(5882), 1,
      anon_sym_LBRACK,
    ACTIONS(3832), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_DOT,
    ACTIONS(3824), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [155864] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    ACTIONS(6237), 1,
      anon_sym_LBRACK,
    ACTIONS(6241), 1,
      anon_sym_DOT,
    ACTIONS(7795), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(7960), 1,
      anon_sym_SLASH,
    ACTIONS(7966), 1,
      anon_sym_PIPE,
    ACTIONS(7970), 1,
      anon_sym_AMP,
    ACTIONS(7976), 1,
      anon_sym_GT_EQ,
    ACTIONS(7980), 1,
      anon_sym_QMARK,
    ACTIONS(7982), 1,
      anon_sym_LT_EQ_GT,
    ACTIONS(7984), 1,
      anon_sym_bitor,
    ACTIONS(7986), 1,
      anon_sym_bitand,
    STATE(2816), 1,
      sym_subscript_argument_list,
    STATE(2854), 1,
      sym_argument_list,
    ACTIONS(6243), 2,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
    ACTIONS(7566), 2,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
    ACTIONS(7956), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(7958), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7962), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(7964), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(7968), 2,
      anon_sym_CARET,
      anon_sym_xor,
    ACTIONS(7978), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(7972), 3,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_not_eq,
    ACTIONS(7974), 3,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [155952] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5237), 1,
      sym_ms_call_modifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6236), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [156030] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5235), 1,
      sym_ms_call_modifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6235), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [156108] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5280), 1,
      sym_ms_call_modifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6341), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [156186] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7610), 1,
      sym_auto,
    ACTIONS(7612), 1,
      anon_sym_decltype,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    STATE(2460), 1,
      sym_decltype_auto,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6563), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4964), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7642), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [156262] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7703), 1,
      sym_identifier,
    ACTIONS(7705), 1,
      anon_sym_LPAREN2,
    ACTIONS(7707), 1,
      anon_sym_STAR,
    ACTIONS(7709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7711), 1,
      anon_sym_AMP,
    ACTIONS(7715), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(6005), 1,
      sym__type_declarator,
    STATE(6279), 1,
      sym_pointer_type_declarator,
    STATE(8225), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7713), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6273), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [156334] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5261), 1,
      sym_ms_call_modifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6336), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [156412] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7703), 1,
      sym_identifier,
    ACTIONS(7705), 1,
      anon_sym_LPAREN2,
    ACTIONS(7715), 1,
      sym_primitive_type,
    ACTIONS(7717), 1,
      anon_sym_STAR,
    ACTIONS(7719), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7721), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(6279), 1,
      sym_pointer_type_declarator,
    STATE(6509), 1,
      sym__type_declarator,
    STATE(8018), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7713), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6273), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [156484] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5244), 1,
      sym_ms_call_modifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6256), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [156562] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7777), 1,
      anon_sym_STAR,
    ACTIONS(7779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7781), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2540), 1,
      sym__type_declarator,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(8179), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [156634] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6500), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6502), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [156678] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6492), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6494), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [156722] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3928), 1,
      anon_sym_SEMI,
    ACTIONS(5836), 1,
      sym_literal_suffix,
    ACTIONS(3832), 15,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DOT,
    ACTIONS(3824), 19,
      anon_sym_DOT_DOT_DOT,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [156770] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6465), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6467), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [156814] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7703), 1,
      sym_identifier,
    ACTIONS(7705), 1,
      anon_sym_LPAREN2,
    ACTIONS(7715), 1,
      sym_primitive_type,
    ACTIONS(7717), 1,
      anon_sym_STAR,
    ACTIONS(7719), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7721), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(6279), 1,
      sym_pointer_type_declarator,
    STATE(6511), 1,
      sym__type_declarator,
    STATE(8018), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7713), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6273), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [156886] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6351), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6353), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [156930] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(8503), 1,
      anon_sym_LBRACE,
    STATE(4851), 1,
      sym_enumerator_list,
    STATE(4880), 1,
      sym_attribute_specifier,
    ACTIONS(5529), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5531), 29,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [156982] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6461), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6463), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [157026] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6453), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6455), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [157070] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6449), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6451), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [157114] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6443), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6445), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [157158] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6187), 1,
      sym__type_declarator,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [157230] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6477), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6479), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [157274] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6411), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6413), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [157318] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7703), 1,
      sym_identifier,
    ACTIONS(7705), 1,
      anon_sym_LPAREN2,
    ACTIONS(7715), 1,
      sym_primitive_type,
    ACTIONS(7717), 1,
      anon_sym_STAR,
    ACTIONS(7719), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7721), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(6279), 1,
      sym_pointer_type_declarator,
    STATE(6512), 1,
      sym__type_declarator,
    STATE(8018), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7713), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6273), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [157390] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5289), 1,
      sym_ms_call_modifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6262), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [157468] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5257), 1,
      sym_ms_call_modifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6288), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [157546] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7763), 1,
      sym_identifier,
    ACTIONS(7765), 1,
      anon_sym_LPAREN2,
    ACTIONS(7767), 1,
      anon_sym_STAR,
    ACTIONS(7769), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7771), 1,
      anon_sym_AMP,
    ACTIONS(7775), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(3137), 1,
      sym__type_declarator,
    STATE(3404), 1,
      sym_pointer_type_declarator,
    STATE(8483), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7773), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3401), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [157618] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6520), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6522), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [157662] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6473), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6475), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [157706] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5252), 1,
      sym_ms_call_modifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6268), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [157784] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5255), 1,
      sym_ms_call_modifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6260), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [157862] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5304), 1,
      sym_ms_call_modifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6331), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [157940] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(7789), 1,
      anon_sym_STAR,
    ACTIONS(7791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7793), 1,
      anon_sym_AMP,
    STATE(3791), 1,
      sym_parameter_list,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6382), 1,
      sym__abstract_declarator,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5200), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(6596), 6,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [158010] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5230), 1,
      sym_ms_call_modifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6255), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [158088] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5278), 1,
      sym_ms_call_modifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6375), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [158166] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8481), 1,
      anon_sym___attribute__,
    ACTIONS(8667), 1,
      anon_sym_COLON,
    ACTIONS(8669), 1,
      anon_sym_LBRACE,
    STATE(4873), 1,
      sym__enum_base_clause,
    STATE(4942), 1,
      sym_enumerator_list,
    STATE(5020), 1,
      sym_attribute_specifier,
    ACTIONS(5689), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5691), 28,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [158222] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6355), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6357), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [158266] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7727), 1,
      anon_sym_STAR,
    ACTIONS(7729), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7731), 1,
      anon_sym_AMP,
    ACTIONS(7735), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6589), 1,
      sym__type_declarator,
    STATE(8394), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [158338] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6431), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6433), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [158382] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6198), 1,
      sym__type_declarator,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [158454] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3832), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(3824), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [158498] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6540), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6542), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [158542] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7763), 1,
      sym_identifier,
    ACTIONS(7765), 1,
      anon_sym_LPAREN2,
    ACTIONS(7767), 1,
      anon_sym_STAR,
    ACTIONS(7769), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7771), 1,
      anon_sym_AMP,
    ACTIONS(7775), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(3128), 1,
      sym__type_declarator,
    STATE(3404), 1,
      sym_pointer_type_declarator,
    STATE(8483), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7773), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3401), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [158614] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6528), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6530), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [158658] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5286), 1,
      sym_ms_call_modifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6374), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [158736] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5292), 1,
      sym_ms_call_modifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6367), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [158814] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(8503), 1,
      anon_sym_LBRACE,
    STATE(4858), 1,
      sym_enumerator_list,
    STATE(4927), 1,
      sym_attribute_specifier,
    ACTIONS(5519), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5521), 29,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [158866] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7777), 1,
      anon_sym_STAR,
    ACTIONS(7779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7781), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2575), 1,
      sym__type_declarator,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(8179), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [158938] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6536), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6538), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [158982] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1953), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(1955), 34,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_or,
      anon_sym_and,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [159026] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(7789), 1,
      anon_sym_STAR,
    ACTIONS(7791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7793), 1,
      anon_sym_AMP,
    STATE(3791), 1,
      sym_parameter_list,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6397), 1,
      sym__abstract_declarator,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5200), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7877), 6,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [159096] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7763), 1,
      sym_identifier,
    ACTIONS(7765), 1,
      anon_sym_LPAREN2,
    ACTIONS(7767), 1,
      anon_sym_STAR,
    ACTIONS(7769), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7771), 1,
      anon_sym_AMP,
    ACTIONS(7775), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(3092), 1,
      sym__type_declarator,
    STATE(3404), 1,
      sym_pointer_type_declarator,
    STATE(8483), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7773), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3401), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [159168] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7727), 1,
      anon_sym_STAR,
    ACTIONS(7729), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7731), 1,
      anon_sym_AMP,
    ACTIONS(7735), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6584), 1,
      sym__type_declarator,
    STATE(8394), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [159240] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7727), 1,
      anon_sym_STAR,
    ACTIONS(7729), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7731), 1,
      anon_sym_AMP,
    ACTIONS(7735), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6617), 1,
      sym__type_declarator,
    STATE(8394), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [159312] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5306), 1,
      sym_ms_call_modifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6300), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [159390] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6228), 1,
      sym__type_declarator,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [159462] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7687), 1,
      sym_identifier,
    ACTIONS(7689), 1,
      anon_sym_LPAREN2,
    ACTIONS(7691), 1,
      anon_sym_STAR,
    ACTIONS(7693), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7695), 1,
      anon_sym_AMP,
    ACTIONS(7701), 1,
      sym_primitive_type,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(3236), 1,
      sym__type_declarator,
    STATE(3549), 1,
      sym_pointer_type_declarator,
    STATE(7998), 1,
      sym_ms_based_modifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7699), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3547), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [159534] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6407), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6409), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [159578] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(7789), 1,
      anon_sym_STAR,
    ACTIONS(7791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7793), 1,
      anon_sym_AMP,
    STATE(3791), 1,
      sym_parameter_list,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6395), 1,
      sym__abstract_declarator,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5200), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(5905), 6,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [159648] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5265), 1,
      sym_ms_call_modifier,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6329), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [159726] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4041), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4037), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [159770] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8665), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(8671), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(5231), 11,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5233), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT_LT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
      anon_sym_GT2,
  [159818] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8481), 1,
      anon_sym___attribute__,
    ACTIONS(8667), 1,
      anon_sym_COLON,
    ACTIONS(8669), 1,
      anon_sym_LBRACE,
    STATE(4843), 1,
      sym__enum_base_clause,
    STATE(4891), 1,
      sym_enumerator_list,
    STATE(5013), 1,
      sym_attribute_specifier,
    ACTIONS(5636), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5638), 28,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [159874] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8481), 1,
      anon_sym___attribute__,
    ACTIONS(8669), 1,
      anon_sym_LBRACE,
    STATE(4943), 1,
      sym_enumerator_list,
    STATE(4990), 1,
      sym_attribute_specifier,
    ACTIONS(5519), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5521), 29,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [159925] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2197), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5347), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(8673), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5349), 27,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [159972] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(7073), 1,
      anon_sym_DASH_GT,
    ACTIONS(8606), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8675), 1,
      anon_sym___attribute__,
    STATE(5031), 1,
      sym_ref_qualifier,
    STATE(5664), 1,
      sym__function_attributes_end,
    STATE(5675), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5325), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [160053] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3928), 1,
      anon_sym_SEMI,
    ACTIONS(3832), 9,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_DOT,
    ACTIONS(3824), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_LT_EQ_GT,
      anon_sym_or,
      anon_sym_and,
      anon_sym_bitor,
      anon_sym_xor,
      anon_sym_bitand,
      anon_sym_not_eq,
      anon_sym_DASH_DASH,
      anon_sym_PLUS_PLUS,
      anon_sym_DOT_STAR,
      anon_sym_DASH_GT,
  [160098] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7073), 1,
      anon_sym_DASH_GT,
    ACTIONS(8606), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8634), 1,
      anon_sym_requires,
    ACTIONS(8675), 1,
      anon_sym___attribute__,
    STATE(5010), 1,
      sym_ref_qualifier,
    STATE(5689), 1,
      sym__function_attributes_end,
    STATE(5721), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8631), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5313), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [160179] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    STATE(4914), 1,
      sym_attribute_specifier,
    ACTIONS(5575), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5577), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [160226] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4859), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5381), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(8678), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5383), 27,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [160273] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4857), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5367), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(8680), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5369), 27,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [160320] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    STATE(4904), 1,
      sym_attribute_specifier,
    ACTIONS(5587), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5589), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [160367] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(63), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7833), 1,
      anon_sym_STAR,
    ACTIONS(7835), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(3908), 1,
      sym_parameter_list,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(6454), 1,
      sym__abstract_declarator,
    ACTIONS(7328), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4298), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5905), 5,
      anon_sym_RPAREN,
      anon_sym_LBRACK_LBRACK,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7324), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [160436] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(63), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7833), 1,
      anon_sym_STAR,
    ACTIONS(7835), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(3908), 1,
      sym_parameter_list,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(6468), 1,
      sym__abstract_declarator,
    ACTIONS(7328), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4298), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7881), 5,
      anon_sym_RPAREN,
      anon_sym_LBRACK_LBRACK,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7324), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [160505] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    STATE(4882), 1,
      sym_attribute_specifier,
    ACTIONS(5614), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5616), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [160552] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    STATE(4887), 1,
      sym_attribute_specifier,
    ACTIONS(5599), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5601), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [160599] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    STATE(4931), 1,
      sym_attribute_specifier,
    ACTIONS(5571), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5573), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [160646] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2197), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5387), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(8673), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5389), 27,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [160693] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    STATE(4933), 1,
      sym_attribute_specifier,
    ACTIONS(5579), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5581), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [160740] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2197), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5377), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(8673), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5379), 27,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [160787] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    STATE(4879), 1,
      sym_attribute_specifier,
    ACTIONS(5591), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5593), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [160834] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2197), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5373), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(8673), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5375), 27,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [160881] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    STATE(4915), 1,
      sym_attribute_specifier,
    ACTIONS(5595), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5597), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [160928] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(63), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7833), 1,
      anon_sym_STAR,
    ACTIONS(7835), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(3908), 1,
      sym_parameter_list,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(6471), 1,
      sym__abstract_declarator,
    ACTIONS(7328), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4298), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(6596), 5,
      anon_sym_RPAREN,
      anon_sym_LBRACK_LBRACK,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7324), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [160997] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    STATE(4903), 1,
      sym_attribute_specifier,
    ACTIONS(5567), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5569), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [161044] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    STATE(4881), 1,
      sym_attribute_specifier,
    ACTIONS(5583), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5585), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [161091] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    STATE(4925), 1,
      sym_attribute_specifier,
    ACTIONS(5610), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5612), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [161138] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    STATE(2286), 1,
      sym_attribute_specifier,
    STATE(5077), 1,
      sym_field_declaration_list,
    STATE(6807), 1,
      sym_virtual_specifier,
    STATE(7517), 1,
      sym_base_class_clause,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(5327), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5329), 23,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
      anon_sym_requires,
  [161197] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7644), 1,
      sym_auto,
    ACTIONS(7646), 1,
      anon_sym_decltype,
    STATE(4878), 1,
      sym_decltype_auto,
    ACTIONS(5413), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5415), 29,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [161246] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4861), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5353), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(8682), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5355), 27,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [161293] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    STATE(4936), 1,
      sym_attribute_specifier,
    ACTIONS(5606), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5608), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [161340] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(63), 1,
      anon_sym_const,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7833), 1,
      anon_sym_STAR,
    ACTIONS(7835), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(3908), 1,
      sym_parameter_list,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(6473), 1,
      sym__abstract_declarator,
    ACTIONS(7328), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4298), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7877), 5,
      anon_sym_RPAREN,
      anon_sym_LBRACK_LBRACK,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7324), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [161409] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8684), 1,
      sym_ms_restrict_modifier,
    STATE(5027), 1,
      sym_ms_unaligned_ptr_modifier,
    ACTIONS(7596), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(8687), 2,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
    ACTIONS(8690), 2,
      anon_sym__unaligned,
      anon_sym___unaligned,
    STATE(4872), 2,
      sym_ms_pointer_modifier,
      aux_sym_pointer_declarator_repeat1,
    ACTIONS(7598), 25,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [161462] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8481), 1,
      anon_sym___attribute__,
    ACTIONS(8669), 1,
      anon_sym_LBRACE,
    STATE(4877), 1,
      sym_enumerator_list,
    STATE(4979), 1,
      sym_attribute_specifier,
    ACTIONS(5529), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5531), 29,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [161513] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(7853), 1,
      sym_identifier,
    ACTIONS(7855), 1,
      anon_sym_LPAREN2,
    ACTIONS(7857), 1,
      anon_sym_STAR,
    ACTIONS(7859), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7861), 1,
      anon_sym_AMP,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6522), 1,
      sym__field_declarator,
    STATE(6623), 1,
      sym_operator_name,
    STATE(8364), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6289), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [161581] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5427), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5429), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [161623] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5455), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5457), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [161665] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8481), 1,
      anon_sym___attribute__,
    STATE(5039), 1,
      sym_attribute_specifier,
    ACTIONS(5587), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5589), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [161711] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5439), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5441), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [161753] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5503), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5505), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [161795] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5511), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5513), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [161837] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5533), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5535), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [161879] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5491), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5493), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [161921] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5499), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5501), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [161963] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6896), 1,
      anon_sym_DASH_GT,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(8695), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(8703), 1,
      anon_sym_requires,
    STATE(5551), 1,
      sym__function_attributes_end,
    STATE(5711), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8700), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5294), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8693), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [162037] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5318), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5320), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [162079] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5467), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5469), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [162121] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5483), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5485), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [162163] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5479), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5481), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [162205] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8481), 1,
      anon_sym___attribute__,
    STATE(5025), 1,
      sym_attribute_specifier,
    ACTIONS(5595), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5597), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [162251] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(8503), 1,
      anon_sym_LBRACE,
    ACTIONS(8706), 1,
      anon_sym_COLON,
    STATE(4795), 1,
      sym__enum_base_clause,
    STATE(4860), 1,
      sym_enumerator_list,
    STATE(4921), 1,
      sym_attribute_specifier,
    ACTIONS(5689), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5691), 25,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [162305] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8481), 1,
      anon_sym___attribute__,
    STATE(4986), 1,
      sym_attribute_specifier,
    ACTIONS(5610), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5612), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [162351] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(8503), 1,
      anon_sym_LBRACE,
    ACTIONS(8706), 1,
      anon_sym_COLON,
    STATE(4826), 1,
      sym__enum_base_clause,
    STATE(4866), 1,
      sym_enumerator_list,
    STATE(4883), 1,
      sym_attribute_specifier,
    ACTIONS(5636), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5638), 25,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [162405] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5467), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5469), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [162447] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5467), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5469), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [162489] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7610), 1,
      sym_auto,
    ACTIONS(7612), 1,
      anon_sym_decltype,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(7642), 1,
      anon_sym_COLON,
    ACTIONS(8185), 1,
      anon_sym_STAR,
    ACTIONS(8187), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8189), 1,
      anon_sym_AMP,
    STATE(2460), 1,
      sym_decltype_auto,
    STATE(3679), 1,
      sym_parameter_list,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6686), 1,
      sym__abstract_declarator,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5049), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [162563] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2142), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(2144), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [162605] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7083), 1,
      anon_sym_DASH_GT,
    ACTIONS(7269), 1,
      anon_sym_requires,
    ACTIONS(8606), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(5054), 1,
      sym_ref_qualifier,
    STATE(5798), 1,
      sym__function_attributes_end,
    STATE(5904), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5331), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [162685] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5318), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5320), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [162727] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8481), 1,
      anon_sym___attribute__,
    STATE(5019), 1,
      sym_attribute_specifier,
    ACTIONS(5583), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5585), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [162773] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8708), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(6335), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(6337), 29,
      anon_sym_LPAREN2,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [162817] = 7,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4472), 1,
      sym_alignas_qualifier,
    ACTIONS(8714), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8007), 7,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
    ACTIONS(8005), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
    ACTIONS(8711), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [162867] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8481), 1,
      anon_sym___attribute__,
    STATE(4983), 1,
      sym_attribute_specifier,
    ACTIONS(5606), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5608), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [162913] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5431), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5433), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [162955] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5507), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5509), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [162997] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8481), 1,
      anon_sym___attribute__,
    STATE(4999), 1,
      sym_attribute_specifier,
    ACTIONS(5599), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5601), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [163043] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7138), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8720), 1,
      anon_sym_requires,
    STATE(5047), 1,
      sym_ref_qualifier,
    STATE(5783), 1,
      sym_trailing_return_type,
    STATE(5853), 1,
      sym__function_attributes_end,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5330), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT2,
  [163123] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8481), 1,
      anon_sym___attribute__,
    STATE(5014), 1,
      sym_attribute_specifier,
    ACTIONS(5614), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5616), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [163169] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    STATE(2221), 1,
      sym_template_argument_list,
    STATE(4844), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(3822), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(8445), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(3830), 23,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [163221] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6896), 1,
      anon_sym_DASH_GT,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(8606), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8634), 1,
      anon_sym_requires,
    STATE(5548), 1,
      sym__function_attributes_end,
    STATE(5721), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8631), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5307), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [163295] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7610), 1,
      sym_auto,
    ACTIONS(7612), 1,
      anon_sym_decltype,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(7660), 1,
      anon_sym_COLON,
    ACTIONS(8185), 1,
      anon_sym_STAR,
    ACTIONS(8187), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8189), 1,
      anon_sym_AMP,
    STATE(2460), 1,
      sym_decltype_auto,
    STATE(3679), 1,
      sym_parameter_list,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6694), 1,
      sym__abstract_declarator,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5060), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [163369] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5497), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [163411] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5451), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5453), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [163453] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8481), 1,
      anon_sym___attribute__,
    STATE(5036), 1,
      sym_attribute_specifier,
    ACTIONS(5575), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5577), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [163499] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5545), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5547), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [163541] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5463), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5465), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [163583] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7871), 1,
      anon_sym_STAR,
    ACTIONS(7873), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7875), 1,
      anon_sym_AMP,
    STATE(3644), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6546), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4962), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5905), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [163651] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7083), 1,
      anon_sym_DASH_GT,
    ACTIONS(8606), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8723), 1,
      anon_sym_requires,
    STATE(5062), 1,
      sym_ref_qualifier,
    STATE(5830), 1,
      sym__function_attributes_end,
    STATE(5976), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8631), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5340), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [163731] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8481), 1,
      anon_sym___attribute__,
    STATE(5033), 1,
      sym_attribute_specifier,
    ACTIONS(5571), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5573), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [163777] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5515), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5517), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [163819] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5471), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5473), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [163861] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5419), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5421), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [163903] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6896), 1,
      anon_sym_DASH_GT,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(8606), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(5556), 1,
      sym__function_attributes_end,
    STATE(5675), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5272), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [163977] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(7855), 1,
      anon_sym_LPAREN2,
    ACTIONS(7863), 1,
      sym_identifier,
    ACTIONS(7865), 1,
      anon_sym_STAR,
    ACTIONS(7867), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7869), 1,
      anon_sym_AMP,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6040), 1,
      sym__field_declarator,
    STATE(6214), 1,
      sym_operator_name,
    STATE(7986), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6289), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [164045] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5353), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5355), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [164087] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5443), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5445), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [164129] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8481), 1,
      anon_sym___attribute__,
    STATE(5035), 1,
      sym_attribute_specifier,
    ACTIONS(5567), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5569), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [164175] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5447), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5449), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [164217] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(7853), 1,
      sym_identifier,
    ACTIONS(7855), 1,
      anon_sym_LPAREN2,
    ACTIONS(7857), 1,
      anon_sym_STAR,
    ACTIONS(7859), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7861), 1,
      anon_sym_AMP,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6526), 1,
      sym__field_declarator,
    STATE(6623), 1,
      sym_operator_name,
    STATE(8364), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6289), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [164285] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5525), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5527), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [164327] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7138), 1,
      anon_sym_DASH_GT,
    ACTIONS(7142), 1,
      anon_sym_requires,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(5057), 1,
      sym_ref_qualifier,
    STATE(5809), 1,
      sym_trailing_return_type,
    STATE(5873), 1,
      sym__function_attributes_end,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5326), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT2,
  [164407] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5487), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5489), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [164449] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5541), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5543), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [164491] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5537), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5539), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [164533] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5423), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5425), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [164575] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(7855), 1,
      anon_sym_LPAREN2,
    ACTIONS(7863), 1,
      sym_identifier,
    ACTIONS(7865), 1,
      anon_sym_STAR,
    ACTIONS(7867), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7869), 1,
      anon_sym_AMP,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6106), 1,
      sym__field_declarator,
    STATE(6214), 1,
      sym_operator_name,
    STATE(7986), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6289), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [164643] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5549), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5551), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [164685] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7871), 1,
      anon_sym_STAR,
    ACTIONS(7873), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7875), 1,
      anon_sym_AMP,
    STATE(3644), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6513), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4962), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(6596), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [164753] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5525), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5527), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [164795] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5459), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5461), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [164837] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(7853), 1,
      sym_identifier,
    ACTIONS(7855), 1,
      anon_sym_LPAREN2,
    ACTIONS(7857), 1,
      anon_sym_STAR,
    ACTIONS(7859), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7861), 1,
      anon_sym_AMP,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6508), 1,
      sym__field_declarator,
    STATE(6623), 1,
      sym_operator_name,
    STATE(8364), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6289), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [164905] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2260), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(2262), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [164947] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8481), 1,
      anon_sym___attribute__,
    STATE(5006), 1,
      sym_attribute_specifier,
    ACTIONS(5591), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5593), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [164993] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8481), 1,
      anon_sym___attribute__,
    STATE(5032), 1,
      sym_attribute_specifier,
    ACTIONS(5579), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5581), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [165039] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(7855), 1,
      anon_sym_LPAREN2,
    ACTIONS(7863), 1,
      sym_identifier,
    ACTIONS(7865), 1,
      anon_sym_STAR,
    ACTIONS(7867), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7869), 1,
      anon_sym_AMP,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(5995), 1,
      sym__field_declarator,
    STATE(6214), 1,
      sym_operator_name,
    STATE(7986), 1,
      sym_ms_based_modifier,
    ACTIONS(3910), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4901), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6289), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
    ACTIONS(3904), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [165107] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5475), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5477), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [165149] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6896), 1,
      anon_sym_DASH_GT,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(8695), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    STATE(5635), 1,
      sym__function_attributes_end,
    STATE(5643), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5250), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8693), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [165223] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      sym_auto,
    ACTIONS(123), 1,
      anon_sym_decltype,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1833), 1,
      anon_sym_enum,
    ACTIONS(1835), 1,
      anon_sym_class,
    ACTIONS(1837), 1,
      anon_sym_struct,
    ACTIONS(1839), 1,
      anon_sym_union,
    ACTIONS(1863), 1,
      anon_sym_typename,
    ACTIONS(2617), 1,
      sym_primitive_type,
    ACTIONS(4078), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8726), 1,
      sym_identifier,
    ACTIONS(8728), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8732), 1,
      anon_sym_EQ,
    STATE(2230), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2264), 1,
      sym_type_specifier,
    STATE(2279), 1,
      sym_qualified_type_identifier,
    STATE(2298), 1,
      sym_decltype_auto,
    STATE(6449), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    ACTIONS(8730), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(2252), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(55), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2277), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [165307] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4078), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8728), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8732), 1,
      anon_sym_EQ,
    ACTIONS(8734), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5445), 1,
      sym_ms_declspec_modifier,
    STATE(6449), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(8730), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(2229), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5446), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5300), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [165397] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7950), 1,
      anon_sym_STAR,
    ACTIONS(7952), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7954), 1,
      anon_sym_AMP,
    STATE(3794), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6597), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4962), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7881), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [165464] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6577), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4962), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5905), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [165531] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2260), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(2262), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [165572] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7950), 1,
      anon_sym_STAR,
    ACTIONS(7952), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7954), 1,
      anon_sym_AMP,
    STATE(3794), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6613), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4962), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(6596), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [165639] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    STATE(2390), 1,
      sym_template_argument_list,
    STATE(5083), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5296), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(5294), 25,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [165688] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(4861), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5318), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(8682), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5320), 25,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [165733] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7950), 1,
      anon_sym_STAR,
    ACTIONS(7952), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7954), 1,
      anon_sym_AMP,
    STATE(3794), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6603), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4962), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(5905), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [165800] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5391), 3,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_const,
    ACTIONS(5393), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [165841] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6284), 1,
      anon_sym___attribute__,
    ACTIONS(6560), 1,
      anon_sym_LBRACE,
    ACTIONS(8736), 1,
      anon_sym_COLON,
    STATE(2858), 1,
      sym__enum_base_clause,
    STATE(2925), 1,
      sym_enumerator_list,
    STATE(2983), 1,
      sym_attribute_specifier,
    ACTIONS(5636), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5638), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [165894] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2142), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(2144), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [165935] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7891), 1,
      sym_auto,
    ACTIONS(7893), 1,
      anon_sym_decltype,
    STATE(5042), 1,
      sym_decltype_auto,
    ACTIONS(5413), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5415), 28,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [165982] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5451), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5453), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [166023] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym___attribute__,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(8738), 1,
      anon_sym_COLON,
    STATE(2471), 1,
      sym_attribute_specifier,
    STATE(5063), 1,
      sym__enum_base_clause,
    STATE(5222), 1,
      sym_enumerator_list,
    ACTIONS(5691), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(5689), 24,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [166076] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8007), 1,
      anon_sym_AMP,
    ACTIONS(8711), 1,
      anon_sym_const,
    STATE(4472), 1,
      sym_alignas_qualifier,
    ACTIONS(8743), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4962), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8740), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
    ACTIONS(8005), 15,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [166127] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6608), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4962), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7881), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [166194] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6611), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4962), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7877), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [166261] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8720), 1,
      anon_sym_requires,
    STATE(5124), 1,
      sym_ref_qualifier,
    STATE(5783), 1,
      sym_trailing_return_type,
    STATE(5889), 1,
      sym__function_attributes_end,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5346), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [166340] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6070), 1,
      anon_sym___attribute__,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(8746), 1,
      anon_sym_COLON,
    STATE(2471), 1,
      sym_attribute_specifier,
    STATE(2668), 1,
      sym__enum_base_clause,
    STATE(2751), 1,
      sym_enumerator_list,
    ACTIONS(5689), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5691), 25,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [166393] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5475), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5477), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [166434] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7330), 1,
      anon_sym_DASH_GT,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(5137), 1,
      sym_ref_qualifier,
    STATE(5888), 1,
      sym__function_attributes_end,
    STATE(6006), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5344), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [166513] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7142), 1,
      anon_sym_requires,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(5141), 1,
      sym_ref_qualifier,
    STATE(5809), 1,
      sym_trailing_return_type,
    STATE(5950), 1,
      sym__function_attributes_end,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5361), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [166592] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6070), 1,
      anon_sym___attribute__,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(8746), 1,
      anon_sym_COLON,
    STATE(2455), 1,
      sym_attribute_specifier,
    STATE(2685), 1,
      sym__enum_base_clause,
    STATE(2724), 1,
      sym_enumerator_list,
    ACTIONS(5636), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5638), 25,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [166645] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6284), 1,
      anon_sym___attribute__,
    ACTIONS(6560), 1,
      anon_sym_LBRACE,
    ACTIONS(8736), 1,
      anon_sym_COLON,
    STATE(2864), 1,
      sym__enum_base_clause,
    STATE(2914), 1,
      sym_enumerator_list,
    STATE(2962), 1,
      sym_attribute_specifier,
    ACTIONS(5689), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5691), 25,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [166698] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5318), 3,
      anon_sym_AMP,
      anon_sym_COLON,
      anon_sym_const,
    ACTIONS(5320), 29,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [166741] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym___attribute__,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(8738), 1,
      anon_sym_COLON,
    STATE(2455), 1,
      sym_attribute_specifier,
    STATE(5051), 1,
      sym__enum_base_clause,
    STATE(5305), 1,
      sym_enumerator_list,
    ACTIONS(5638), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(5636), 24,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [166794] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5495), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5497), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [166835] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7950), 1,
      anon_sym_STAR,
    ACTIONS(7952), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7954), 1,
      anon_sym_AMP,
    STATE(3794), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6564), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4962), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(7877), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [166902] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7330), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8748), 1,
      anon_sym_requires,
    STATE(5115), 1,
      sym_ref_qualifier,
    STATE(5942), 1,
      sym__function_attributes_end,
    STATE(5998), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5348), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [166981] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5353), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5355), 31,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [167022] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      anon_sym_const,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(4472), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6615), 1,
      sym__abstract_declarator,
    ACTIONS(7674), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4962), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(6596), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7668), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [167089] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5511), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5513), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [167129] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5318), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5320), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [167169] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5541), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5543), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [167209] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7426), 1,
      anon_sym_DASH_GT,
    ACTIONS(7441), 1,
      anon_sym_requires,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(5259), 1,
      sym_ref_qualifier,
    STATE(6095), 1,
      sym__function_attributes_end,
    STATE(6128), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5374), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [167287] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5549), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5551), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [167327] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(3796), 1,
      sym_auto,
    ACTIONS(3798), 1,
      anon_sym_decltype,
    ACTIONS(7479), 1,
      sym_primitive_type,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    ACTIONS(8751), 1,
      sym_identifier,
    ACTIONS(8753), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8755), 1,
      anon_sym_enum,
    ACTIONS(8757), 1,
      anon_sym_class,
    ACTIONS(8759), 1,
      anon_sym_struct,
    ACTIONS(8761), 1,
      anon_sym_union,
    ACTIONS(8763), 1,
      anon_sym_typename,
    STATE(2571), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2980), 1,
      sym_decltype_auto,
    STATE(3011), 1,
      sym_qualified_type_identifier,
    STATE(4200), 1,
      sym_type_specifier,
    STATE(5146), 1,
      sym_argument_list,
    STATE(6505), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2937), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(3762), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2981), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [167407] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7461), 1,
      sym_primitive_type,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    ACTIONS(8765), 1,
      sym_identifier,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8769), 1,
      anon_sym_enum,
    ACTIONS(8771), 1,
      anon_sym_class,
    ACTIONS(8773), 1,
      anon_sym_struct,
    ACTIONS(8775), 1,
      anon_sym_union,
    ACTIONS(8777), 1,
      anon_sym_typename,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4134), 1,
      sym_type_specifier,
    STATE(5173), 1,
      sym_argument_list,
    STATE(6489), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [167487] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5443), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5445), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [167527] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7439), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8779), 1,
      anon_sym_requires,
    STATE(5260), 1,
      sym_ref_qualifier,
    STATE(6064), 1,
      sym__function_attributes_end,
    STATE(6141), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5369), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_GT2,
  [167605] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    ACTIONS(8782), 1,
      sym_identifier,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8788), 1,
      sym_primitive_type,
    ACTIONS(8790), 1,
      anon_sym_enum,
    ACTIONS(8792), 1,
      anon_sym_class,
    ACTIONS(8794), 1,
      anon_sym_struct,
    ACTIONS(8796), 1,
      anon_sym_union,
    ACTIONS(8798), 1,
      sym_auto,
    ACTIONS(8800), 1,
      anon_sym_decltype,
    ACTIONS(8802), 1,
      anon_sym_typename,
    STATE(2473), 1,
      sym_type_specifier,
    STATE(2557), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2650), 1,
      sym_decltype_auto,
    STATE(2663), 1,
      sym_qualified_type_identifier,
    STATE(5067), 1,
      sym_argument_list,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2549), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8786), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2655), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [167685] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5525), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5527), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [167725] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5447), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5449), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [167765] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5471), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5473), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [167805] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7404), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(5270), 1,
      sym_ref_qualifier,
    STATE(6006), 1,
      sym_trailing_return_type,
    STATE(6089), 1,
      sym__function_attributes_end,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5377), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
  [167883] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5467), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5469), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [167923] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5467), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5469), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [167963] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    ACTIONS(8804), 1,
      sym_identifier,
    ACTIONS(8806), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8810), 1,
      sym_primitive_type,
    ACTIONS(8812), 1,
      anon_sym_enum,
    ACTIONS(8814), 1,
      anon_sym_class,
    ACTIONS(8816), 1,
      anon_sym_struct,
    ACTIONS(8818), 1,
      anon_sym_union,
    ACTIONS(8820), 1,
      sym_auto,
    ACTIONS(8822), 1,
      anon_sym_decltype,
    ACTIONS(8824), 1,
      anon_sym_typename,
    STATE(2785), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3023), 1,
      sym_type_specifier,
    STATE(3253), 1,
      sym_decltype_auto,
    STATE(3259), 1,
      sym_qualified_type_identifier,
    STATE(5118), 1,
      sym_argument_list,
    STATE(6464), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(3231), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8808), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3248), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [168043] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5459), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5461), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [168083] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7461), 1,
      sym_primitive_type,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    ACTIONS(8765), 1,
      sym_identifier,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8769), 1,
      anon_sym_enum,
    ACTIONS(8771), 1,
      anon_sym_class,
    ACTIONS(8773), 1,
      anon_sym_struct,
    ACTIONS(8775), 1,
      anon_sym_union,
    ACTIONS(8777), 1,
      anon_sym_typename,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4115), 1,
      sym_type_specifier,
    STATE(5180), 1,
      sym_argument_list,
    STATE(6489), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [168163] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5479), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5481), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [168203] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5483), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5485), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [168243] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5455), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5457), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [168283] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7073), 1,
      anon_sym_DASH_GT,
    ACTIONS(8606), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8634), 1,
      anon_sym_requires,
    ACTIONS(8675), 1,
      anon_sym___attribute__,
    STATE(5689), 1,
      sym__function_attributes_end,
    STATE(5721), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8631), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5313), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [168355] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5467), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5469), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [168395] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(3796), 1,
      sym_auto,
    ACTIONS(3798), 1,
      anon_sym_decltype,
    ACTIONS(7479), 1,
      sym_primitive_type,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    ACTIONS(8751), 1,
      sym_identifier,
    ACTIONS(8753), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8755), 1,
      anon_sym_enum,
    ACTIONS(8757), 1,
      anon_sym_class,
    ACTIONS(8759), 1,
      anon_sym_struct,
    ACTIONS(8761), 1,
      anon_sym_union,
    ACTIONS(8763), 1,
      anon_sym_typename,
    STATE(2571), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2980), 1,
      sym_decltype_auto,
    STATE(3011), 1,
      sym_qualified_type_identifier,
    STATE(4183), 1,
      sym_type_specifier,
    STATE(5168), 1,
      sym_argument_list,
    STATE(6505), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2937), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(3762), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2981), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [168475] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    ACTIONS(8804), 1,
      sym_identifier,
    ACTIONS(8806), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8810), 1,
      sym_primitive_type,
    ACTIONS(8812), 1,
      anon_sym_enum,
    ACTIONS(8814), 1,
      anon_sym_class,
    ACTIONS(8816), 1,
      anon_sym_struct,
    ACTIONS(8818), 1,
      anon_sym_union,
    ACTIONS(8820), 1,
      sym_auto,
    ACTIONS(8822), 1,
      anon_sym_decltype,
    ACTIONS(8824), 1,
      anon_sym_typename,
    STATE(2785), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3002), 1,
      sym_type_specifier,
    STATE(3253), 1,
      sym_decltype_auto,
    STATE(3259), 1,
      sym_qualified_type_identifier,
    STATE(5106), 1,
      sym_argument_list,
    STATE(6464), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(3231), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8808), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3248), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [168555] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    ACTIONS(8826), 1,
      sym_identifier,
    ACTIONS(8828), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8832), 1,
      sym_primitive_type,
    ACTIONS(8834), 1,
      anon_sym_enum,
    ACTIONS(8836), 1,
      anon_sym_class,
    ACTIONS(8838), 1,
      anon_sym_struct,
    ACTIONS(8840), 1,
      anon_sym_union,
    ACTIONS(8842), 1,
      sym_auto,
    ACTIONS(8844), 1,
      anon_sym_decltype,
    ACTIONS(8846), 1,
      anon_sym_typename,
    STATE(3545), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3964), 1,
      sym_type_specifier,
    STATE(4106), 1,
      sym_decltype_auto,
    STATE(4150), 1,
      sym_qualified_type_identifier,
    STATE(5138), 1,
      sym_argument_list,
    STATE(6451), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(4084), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8830), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4102), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [168635] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5503), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5505), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [168675] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5423), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5425), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [168715] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    ACTIONS(8848), 1,
      sym_identifier,
    ACTIONS(8850), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8854), 1,
      sym_primitive_type,
    ACTIONS(8856), 1,
      anon_sym_enum,
    ACTIONS(8858), 1,
      anon_sym_class,
    ACTIONS(8860), 1,
      anon_sym_struct,
    ACTIONS(8862), 1,
      anon_sym_union,
    ACTIONS(8864), 1,
      sym_auto,
    ACTIONS(8866), 1,
      anon_sym_decltype,
    ACTIONS(8868), 1,
      anon_sym_typename,
    STATE(2748), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2950), 1,
      sym_type_specifier,
    STATE(3153), 1,
      sym_qualified_type_identifier,
    STATE(3177), 1,
      sym_decltype_auto,
    STATE(5122), 1,
      sym_argument_list,
    STATE(6486), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(3147), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8852), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3158), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [168795] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7461), 1,
      sym_primitive_type,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    ACTIONS(8765), 1,
      sym_identifier,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8769), 1,
      anon_sym_enum,
    ACTIONS(8771), 1,
      anon_sym_class,
    ACTIONS(8773), 1,
      anon_sym_struct,
    ACTIONS(8775), 1,
      anon_sym_union,
    ACTIONS(8777), 1,
      anon_sym_typename,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4040), 1,
      sym_type_specifier,
    STATE(5130), 1,
      sym_argument_list,
    STATE(6489), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [168875] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7073), 1,
      anon_sym_DASH_GT,
    ACTIONS(8695), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(8703), 1,
      anon_sym_requires,
    ACTIONS(8870), 1,
      anon_sym___attribute__,
    STATE(5692), 1,
      sym__function_attributes_end,
    STATE(5711), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8700), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5316), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8693), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [168947] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5523), 1,
      anon_sym_LBRACE,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(8873), 1,
      anon_sym_COLON,
    STATE(2293), 1,
      sym_attribute_specifier,
    STATE(5040), 1,
      sym__enum_base_clause,
    STATE(5076), 1,
      sym_enumerator_list,
    ACTIONS(5636), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5638), 23,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [168999] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7426), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8779), 1,
      anon_sym_requires,
    STATE(5247), 1,
      sym_ref_qualifier,
    STATE(6079), 1,
      sym__function_attributes_end,
    STATE(6141), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5373), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [169077] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5499), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5501), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [169117] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5491), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5493), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [169157] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7749), 3,
      anon_sym_AMP,
      sym_ms_restrict_modifier,
      anon_sym_const,
    ACTIONS(7751), 29,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym___extension__,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
      anon_sym__unaligned,
      anon_sym___unaligned,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [169197] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    ACTIONS(8875), 1,
      sym_identifier,
    ACTIONS(8877), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8881), 1,
      sym_primitive_type,
    ACTIONS(8883), 1,
      anon_sym_enum,
    ACTIONS(8885), 1,
      anon_sym_class,
    ACTIONS(8887), 1,
      anon_sym_struct,
    ACTIONS(8889), 1,
      anon_sym_union,
    ACTIONS(8891), 1,
      sym_auto,
    ACTIONS(8893), 1,
      anon_sym_decltype,
    ACTIONS(8895), 1,
      anon_sym_typename,
    STATE(2897), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3097), 1,
      sym_type_specifier,
    STATE(3530), 1,
      sym_decltype_auto,
    STATE(3541), 1,
      sym_qualified_type_identifier,
    STATE(5220), 1,
      sym_argument_list,
    STATE(6485), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(3351), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8879), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3532), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [169277] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8792), 1,
      anon_sym_class,
    ACTIONS(8794), 1,
      anon_sym_struct,
    ACTIONS(8796), 1,
      anon_sym_union,
    ACTIONS(8798), 1,
      sym_auto,
    ACTIONS(8800), 1,
      anon_sym_decltype,
    ACTIONS(8897), 1,
      sym_identifier,
    ACTIONS(8901), 1,
      sym_primitive_type,
    ACTIONS(8903), 1,
      anon_sym_enum,
    ACTIONS(8905), 1,
      anon_sym_typename,
    STATE(2488), 1,
      sym_type_specifier,
    STATE(2545), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2650), 1,
      sym_decltype_auto,
    STATE(2663), 1,
      sym_qualified_type_identifier,
    STATE(5217), 1,
      sym_argument_list,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2549), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8899), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2655), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [169357] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5515), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5517), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [169397] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5533), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5535), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [169437] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5419), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5421), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [169477] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4019), 1,
      anon_sym_LBRACE,
    ACTIONS(8907), 1,
      anon_sym_LPAREN2,
    STATE(2697), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3793), 1,
      sym_argument_list,
    STATE(4823), 1,
      sym_initializer_list,
    ACTIONS(5318), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(6174), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5320), 21,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [169529] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8792), 1,
      anon_sym_class,
    ACTIONS(8794), 1,
      anon_sym_struct,
    ACTIONS(8796), 1,
      anon_sym_union,
    ACTIONS(8798), 1,
      sym_auto,
    ACTIONS(8800), 1,
      anon_sym_decltype,
    ACTIONS(8897), 1,
      sym_identifier,
    ACTIONS(8901), 1,
      sym_primitive_type,
    ACTIONS(8903), 1,
      anon_sym_enum,
    ACTIONS(8905), 1,
      anon_sym_typename,
    STATE(2473), 1,
      sym_type_specifier,
    STATE(2545), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2650), 1,
      sym_decltype_auto,
    STATE(2663), 1,
      sym_qualified_type_identifier,
    STATE(5209), 1,
      sym_argument_list,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2549), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8899), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2655), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [169609] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5523), 1,
      anon_sym_LBRACE,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    STATE(2297), 1,
      sym_attribute_specifier,
    STATE(5123), 1,
      sym_enumerator_list,
    ACTIONS(5529), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5531), 25,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [169657] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    ACTIONS(8826), 1,
      sym_identifier,
    ACTIONS(8828), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8832), 1,
      sym_primitive_type,
    ACTIONS(8834), 1,
      anon_sym_enum,
    ACTIONS(8836), 1,
      anon_sym_class,
    ACTIONS(8838), 1,
      anon_sym_struct,
    ACTIONS(8840), 1,
      anon_sym_union,
    ACTIONS(8842), 1,
      sym_auto,
    ACTIONS(8844), 1,
      anon_sym_decltype,
    ACTIONS(8846), 1,
      anon_sym_typename,
    STATE(3545), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3874), 1,
      sym_type_specifier,
    STATE(4106), 1,
      sym_decltype_auto,
    STATE(4150), 1,
      sym_qualified_type_identifier,
    STATE(5131), 1,
      sym_argument_list,
    STATE(6451), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(4084), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8830), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4102), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [169737] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5463), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5465), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [169777] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5133), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5135), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [169817] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7753), 3,
      anon_sym_AMP,
      sym_ms_restrict_modifier,
      anon_sym_const,
    ACTIONS(7755), 29,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym___extension__,
      sym_ms_unsigned_ptr_modifier,
      sym_ms_signed_ptr_modifier,
      anon_sym__unaligned,
      anon_sym___unaligned,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [169857] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    ACTIONS(8875), 1,
      sym_identifier,
    ACTIONS(8877), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8881), 1,
      sym_primitive_type,
    ACTIONS(8883), 1,
      anon_sym_enum,
    ACTIONS(8885), 1,
      anon_sym_class,
    ACTIONS(8887), 1,
      anon_sym_struct,
    ACTIONS(8889), 1,
      anon_sym_union,
    ACTIONS(8891), 1,
      sym_auto,
    ACTIONS(8893), 1,
      anon_sym_decltype,
    ACTIONS(8895), 1,
      anon_sym_typename,
    STATE(2897), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3125), 1,
      sym_type_specifier,
    STATE(3530), 1,
      sym_decltype_auto,
    STATE(3541), 1,
      sym_qualified_type_identifier,
    STATE(5215), 1,
      sym_argument_list,
    STATE(6485), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(3351), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8879), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3532), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [169937] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7439), 1,
      anon_sym_DASH_GT,
    ACTIONS(7441), 1,
      anon_sym_requires,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(5236), 1,
      sym_ref_qualifier,
    STATE(6044), 1,
      sym__function_attributes_end,
    STATE(6128), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5372), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_GT2,
  [170015] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    ACTIONS(8782), 1,
      sym_identifier,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8788), 1,
      sym_primitive_type,
    ACTIONS(8790), 1,
      anon_sym_enum,
    ACTIONS(8792), 1,
      anon_sym_class,
    ACTIONS(8794), 1,
      anon_sym_struct,
    ACTIONS(8796), 1,
      anon_sym_union,
    ACTIONS(8798), 1,
      sym_auto,
    ACTIONS(8800), 1,
      anon_sym_decltype,
    ACTIONS(8802), 1,
      anon_sym_typename,
    STATE(2488), 1,
      sym_type_specifier,
    STATE(2557), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2650), 1,
      sym_decltype_auto,
    STATE(2663), 1,
      sym_qualified_type_identifier,
    STATE(5087), 1,
      sym_argument_list,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2549), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8786), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2655), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [170095] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(7073), 1,
      anon_sym_DASH_GT,
    ACTIONS(8695), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(8870), 1,
      anon_sym___attribute__,
    STATE(5643), 1,
      sym_trailing_return_type,
    STATE(5652), 1,
      sym__function_attributes_end,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5314), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8693), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [170167] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5537), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5539), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [170207] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5487), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5489), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [170247] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    ACTIONS(8848), 1,
      sym_identifier,
    ACTIONS(8850), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8854), 1,
      sym_primitive_type,
    ACTIONS(8856), 1,
      anon_sym_enum,
    ACTIONS(8858), 1,
      anon_sym_class,
    ACTIONS(8860), 1,
      anon_sym_struct,
    ACTIONS(8862), 1,
      anon_sym_union,
    ACTIONS(8864), 1,
      sym_auto,
    ACTIONS(8866), 1,
      anon_sym_decltype,
    ACTIONS(8868), 1,
      anon_sym_typename,
    STATE(2748), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2933), 1,
      sym_type_specifier,
    STATE(3153), 1,
      sym_qualified_type_identifier,
    STATE(3177), 1,
      sym_decltype_auto,
    STATE(5072), 1,
      sym_argument_list,
    STATE(6486), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(3147), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8852), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3158), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [170327] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5431), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5433), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [170367] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5545), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5547), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [170407] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5427), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5429), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [170447] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7461), 1,
      sym_primitive_type,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    ACTIONS(8765), 1,
      sym_identifier,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8769), 1,
      anon_sym_enum,
    ACTIONS(8771), 1,
      anon_sym_class,
    ACTIONS(8773), 1,
      anon_sym_struct,
    ACTIONS(8775), 1,
      anon_sym_union,
    ACTIONS(8777), 1,
      anon_sym_typename,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4077), 1,
      sym_type_specifier,
    STATE(5142), 1,
      sym_argument_list,
    STATE(6489), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [170527] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5507), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5509), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [170567] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5523), 1,
      anon_sym_LBRACE,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    STATE(2276), 1,
      sym_attribute_specifier,
    STATE(5095), 1,
      sym_enumerator_list,
    ACTIONS(5519), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5521), 25,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [170615] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5523), 1,
      anon_sym_LBRACE,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(8873), 1,
      anon_sym_COLON,
    STATE(2269), 1,
      sym_attribute_specifier,
    STATE(5023), 1,
      sym__enum_base_clause,
    STATE(5086), 1,
      sym_enumerator_list,
    ACTIONS(5689), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5691), 23,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [170667] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5439), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5441), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [170707] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7404), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8748), 1,
      anon_sym_requires,
    STATE(5224), 1,
      sym_ref_qualifier,
    STATE(5992), 1,
      sym__function_attributes_end,
    STATE(5998), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5380), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
  [170785] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(7073), 1,
      anon_sym_DASH_GT,
    ACTIONS(8606), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8675), 1,
      anon_sym___attribute__,
    STATE(5664), 1,
      sym__function_attributes_end,
    STATE(5675), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5325), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [170857] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5318), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5320), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [170897] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5525), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5527), 30,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___extension__,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [170937] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7138), 1,
      anon_sym_DASH_GT,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(8913), 1,
      anon_sym_requires,
    STATE(5774), 1,
      sym_trailing_return_type,
    STATE(5866), 1,
      sym__function_attributes_end,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8910), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5343), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8693), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT2,
  [171008] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5819), 1,
      sym_auto,
    ACTIONS(5821), 1,
      anon_sym_decltype,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2460), 1,
      sym_decltype_auto,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5310), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8918), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(8916), 8,
      anon_sym_AMP,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_primitive_type,
      sym_identifier,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [171061] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(7877), 1,
      anon_sym_COLON,
    ACTIONS(8185), 1,
      anon_sym_STAR,
    ACTIONS(8187), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8189), 1,
      anon_sym_AMP,
    STATE(3679), 1,
      sym_parameter_list,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6679), 1,
      sym__abstract_declarator,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5200), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [171126] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7847), 1,
      anon_sym_LT,
    STATE(2390), 1,
      sym_template_argument_list,
    STATE(5083), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(3830), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(8920), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(3822), 20,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [171175] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym___attribute__,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    STATE(2478), 1,
      sym_attribute_specifier,
    STATE(5241), 1,
      sym_enumerator_list,
    ACTIONS(5521), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(5519), 24,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [171222] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5819), 1,
      sym_auto,
    ACTIONS(5821), 1,
      anon_sym_decltype,
    STATE(1957), 1,
      sym_alignas_qualifier,
    STATE(2460), 1,
      sym_decltype_auto,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5312), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(8924), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(8922), 8,
      anon_sym_AMP,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_primitive_type,
      sym_identifier,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [171275] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(5905), 1,
      anon_sym_COLON,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(8185), 1,
      anon_sym_STAR,
    ACTIONS(8187), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8189), 1,
      anon_sym_AMP,
    STATE(3679), 1,
      sym_parameter_list,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6594), 1,
      sym__abstract_declarator,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5200), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [171340] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7083), 1,
      anon_sym_DASH_GT,
    ACTIONS(7269), 1,
      anon_sym_requires,
    ACTIONS(8695), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    STATE(5792), 1,
      sym__function_attributes_end,
    STATE(5931), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5334), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8693), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [171411] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7083), 1,
      anon_sym_DASH_GT,
    ACTIONS(8606), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8723), 1,
      anon_sym_requires,
    STATE(5830), 1,
      sym__function_attributes_end,
    STATE(5976), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8631), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5340), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [171482] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(6596), 1,
      anon_sym_COLON,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(8185), 1,
      anon_sym_STAR,
    ACTIONS(8187), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8189), 1,
      anon_sym_AMP,
    STATE(3679), 1,
      sym_parameter_list,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6571), 1,
      sym__abstract_declarator,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5200), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [171547] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7138), 1,
      anon_sym_DASH_GT,
    ACTIONS(7142), 1,
      anon_sym_requires,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    STATE(5806), 1,
      sym_trailing_return_type,
    STATE(5846), 1,
      sym__function_attributes_end,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5329), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8693), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT2,
  [171618] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7083), 1,
      anon_sym_DASH_GT,
    ACTIONS(7269), 1,
      anon_sym_requires,
    ACTIONS(8606), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(5798), 1,
      sym__function_attributes_end,
    STATE(5904), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5331), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [171689] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7138), 1,
      anon_sym_DASH_GT,
    ACTIONS(7142), 1,
      anon_sym_requires,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(5809), 1,
      sym_trailing_return_type,
    STATE(5873), 1,
      sym__function_attributes_end,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5326), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT2,
  [171760] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7630), 1,
      anon_sym_const,
    ACTIONS(7881), 1,
      anon_sym_COLON,
    ACTIONS(8185), 1,
      anon_sym_STAR,
    ACTIONS(8187), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8189), 1,
      anon_sym_AMP,
    STATE(3679), 1,
      sym_parameter_list,
    STATE(5323), 1,
      sym_alignas_qualifier,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6687), 1,
      sym__abstract_declarator,
    ACTIONS(7632), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5200), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7620), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [171825] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7138), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8720), 1,
      anon_sym_requires,
    STATE(5783), 1,
      sym_trailing_return_type,
    STATE(5853), 1,
      sym__function_attributes_end,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5330), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT2,
  [171896] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7083), 1,
      anon_sym_DASH_GT,
    ACTIONS(8695), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(8926), 1,
      anon_sym_requires,
    STATE(5835), 1,
      sym__function_attributes_end,
    STATE(5985), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8700), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5341), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8693), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [171967] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym___attribute__,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    STATE(2462), 1,
      sym_attribute_specifier,
    STATE(5271), 1,
      sym_enumerator_list,
    ACTIONS(5531), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(5529), 24,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [172014] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2284), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5508), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2308), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5504), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5238), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [172094] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5817), 1,
      anon_sym_LBRACE,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8931), 1,
      sym_identifier,
    STATE(2498), 1,
      sym_template_type,
    STATE(2553), 1,
      sym_field_declaration_list,
    STATE(2651), 1,
      sym__class_declaration,
    STATE(2657), 1,
      sym__class_declaration_item,
    STATE(5530), 1,
      sym_ms_declspec_modifier,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(6883), 1,
      sym_virtual_specifier,
    STATE(7724), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2412), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5529), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5273), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [172174] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    STATE(2287), 1,
      sym_attribute_specifier,
    ACTIONS(5599), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5601), 25,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [172216] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(8782), 1,
      sym_identifier,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8788), 1,
      sym_primitive_type,
    ACTIONS(8790), 1,
      anon_sym_enum,
    ACTIONS(8792), 1,
      anon_sym_class,
    ACTIONS(8794), 1,
      anon_sym_struct,
    ACTIONS(8796), 1,
      anon_sym_union,
    ACTIONS(8798), 1,
      sym_auto,
    ACTIONS(8800), 1,
      anon_sym_decltype,
    ACTIONS(8802), 1,
      anon_sym_typename,
    STATE(2470), 1,
      sym_type_specifier,
    STATE(2557), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2650), 1,
      sym_decltype_auto,
    STATE(2663), 1,
      sym_qualified_type_identifier,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2549), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8786), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2655), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [172290] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6928), 1,
      anon_sym_STAR,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5949), 1,
      sym__declarator,
    STATE(7147), 1,
      sym_init_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [172360] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7529), 1,
      sym_primitive_type,
    ACTIONS(7539), 1,
      sym_auto,
    ACTIONS(7541), 1,
      anon_sym_decltype,
    ACTIONS(7545), 1,
      sym_identifier,
    ACTIONS(7547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7549), 1,
      anon_sym_enum,
    ACTIONS(7551), 1,
      anon_sym_class,
    ACTIONS(7553), 1,
      anon_sym_struct,
    ACTIONS(7555), 1,
      anon_sym_union,
    ACTIONS(7557), 1,
      anon_sym_typename,
    STATE(4236), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4868), 1,
      sym_type_specifier,
    STATE(4885), 1,
      sym_qualified_type_identifier,
    STATE(4919), 1,
      sym_decltype_auto,
    STATE(6475), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2252), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7527), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4898), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [172434] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    STATE(2282), 1,
      sym_attribute_specifier,
    ACTIONS(5595), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5597), 25,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [172476] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(8848), 1,
      sym_identifier,
    ACTIONS(8850), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8854), 1,
      sym_primitive_type,
    ACTIONS(8856), 1,
      anon_sym_enum,
    ACTIONS(8858), 1,
      anon_sym_class,
    ACTIONS(8860), 1,
      anon_sym_struct,
    ACTIONS(8862), 1,
      anon_sym_union,
    ACTIONS(8864), 1,
      sym_auto,
    ACTIONS(8866), 1,
      anon_sym_decltype,
    ACTIONS(8868), 1,
      anon_sym_typename,
    STATE(2748), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3144), 1,
      sym_type_specifier,
    STATE(3153), 1,
      sym_qualified_type_identifier,
    STATE(3177), 1,
      sym_decltype_auto,
    STATE(6486), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(3147), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8852), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3158), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [172550] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(8848), 1,
      sym_identifier,
    ACTIONS(8850), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8854), 1,
      sym_primitive_type,
    ACTIONS(8856), 1,
      anon_sym_enum,
    ACTIONS(8858), 1,
      anon_sym_class,
    ACTIONS(8860), 1,
      anon_sym_struct,
    ACTIONS(8862), 1,
      anon_sym_union,
    ACTIONS(8864), 1,
      sym_auto,
    ACTIONS(8866), 1,
      anon_sym_decltype,
    ACTIONS(8868), 1,
      anon_sym_typename,
    STATE(2748), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2930), 1,
      sym_type_specifier,
    STATE(3153), 1,
      sym_qualified_type_identifier,
    STATE(3177), 1,
      sym_decltype_auto,
    STATE(6486), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(3147), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8852), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3158), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [172624] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    STATE(2290), 1,
      sym_attribute_specifier,
    ACTIONS(5614), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5616), 25,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [172666] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6928), 1,
      anon_sym_STAR,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(6103), 1,
      sym__declarator,
    STATE(7789), 1,
      sym_init_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [172736] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2197), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5375), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(8933), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5373), 21,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [172778] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    STATE(2275), 1,
      sym_attribute_specifier,
    ACTIONS(5610), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5612), 25,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [172820] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    STATE(2302), 1,
      sym_attribute_specifier,
    ACTIONS(5583), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5585), 25,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [172862] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    STATE(2307), 1,
      sym_attribute_specifier,
    ACTIONS(5606), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5608), 25,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [172904] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      sym_auto,
    ACTIONS(123), 1,
      anon_sym_decltype,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7578), 1,
      sym_primitive_type,
    ACTIONS(8936), 1,
      sym_identifier,
    ACTIONS(8938), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8940), 1,
      anon_sym_enum,
    ACTIONS(8942), 1,
      anon_sym_class,
    ACTIONS(8944), 1,
      anon_sym_struct,
    ACTIONS(8946), 1,
      anon_sym_union,
    ACTIONS(8948), 1,
      anon_sym_typename,
    STATE(2279), 1,
      sym_qualified_type_identifier,
    STATE(2298), 1,
      sym_decltype_auto,
    STATE(4678), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6461), 1,
      sym__scope_resolution,
    STATE(6684), 1,
      sym_type_specifier,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2252), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7576), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2277), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [172978] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8950), 1,
      sym_identifier,
    ACTIONS(8956), 1,
      sym_primitive_type,
    STATE(5098), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5336), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(8953), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5338), 19,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
  [173024] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7562), 1,
      anon_sym_DASH_GT,
    ACTIONS(7564), 1,
      anon_sym_requires,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8959), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(5319), 1,
      sym_ref_qualifier,
    STATE(6178), 1,
      sym__function_attributes_end,
    STATE(6237), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8604), 2,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5389), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [173100] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7503), 1,
      sym_identifier,
    ACTIONS(7507), 1,
      sym_primitive_type,
    ACTIONS(7509), 1,
      anon_sym_enum,
    ACTIONS(7511), 1,
      anon_sym_class,
    ACTIONS(7513), 1,
      anon_sym_struct,
    ACTIONS(7515), 1,
      anon_sym_union,
    ACTIONS(7517), 1,
      anon_sym_typename,
    STATE(2417), 1,
      sym_type_specifier,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(5080), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7505), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [173174] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2197), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5349), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(8962), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5347), 21,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [173216] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8720), 1,
      anon_sym_requires,
    STATE(5783), 1,
      sym_trailing_return_type,
    STATE(5889), 1,
      sym__function_attributes_end,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5346), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [173286] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(5134), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5383), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(8965), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5381), 21,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [173328] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    STATE(2295), 1,
      sym_attribute_specifier,
    ACTIONS(5591), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5593), 25,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [173370] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(8782), 1,
      sym_identifier,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8788), 1,
      sym_primitive_type,
    ACTIONS(8790), 1,
      anon_sym_enum,
    ACTIONS(8792), 1,
      anon_sym_class,
    ACTIONS(8794), 1,
      anon_sym_struct,
    ACTIONS(8796), 1,
      anon_sym_union,
    ACTIONS(8798), 1,
      sym_auto,
    ACTIONS(8800), 1,
      anon_sym_decltype,
    ACTIONS(8802), 1,
      anon_sym_typename,
    STATE(2487), 1,
      sym_type_specifier,
    STATE(2557), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2650), 1,
      sym_decltype_auto,
    STATE(2663), 1,
      sym_qualified_type_identifier,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2549), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8786), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2655), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [173444] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    ACTIONS(7477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8968), 1,
      sym_identifier,
    STATE(2876), 1,
      sym_field_declaration_list,
    STATE(2892), 1,
      sym_template_type,
    STATE(2989), 1,
      sym__class_declaration,
    STATE(3022), 1,
      sym__class_declaration_item,
    STATE(5493), 1,
      sym_ms_declspec_modifier,
    STATE(6482), 1,
      sym__scope_resolution,
    STATE(6928), 1,
      sym_virtual_specifier,
    STATE(7835), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2740), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5488), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5285), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [173524] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    ACTIONS(7477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8968), 1,
      sym_identifier,
    STATE(2876), 1,
      sym_field_declaration_list,
    STATE(2892), 1,
      sym_template_type,
    STATE(2998), 1,
      sym__class_declaration,
    STATE(3022), 1,
      sym__class_declaration_item,
    STATE(5493), 1,
      sym_ms_declspec_modifier,
    STATE(6482), 1,
      sym__scope_resolution,
    STATE(6928), 1,
      sym_virtual_specifier,
    STATE(7835), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2740), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5488), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5285), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [173604] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6928), 1,
      anon_sym_STAR,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5971), 1,
      sym__declarator,
    STATE(7152), 1,
      sym_init_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [173674] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    ACTIONS(7477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8968), 1,
      sym_identifier,
    STATE(2876), 1,
      sym_field_declaration_list,
    STATE(2892), 1,
      sym_template_type,
    STATE(3012), 1,
      sym__class_declaration,
    STATE(3022), 1,
      sym__class_declaration_item,
    STATE(5493), 1,
      sym_ms_declspec_modifier,
    STATE(6482), 1,
      sym__scope_resolution,
    STATE(6928), 1,
      sym_virtual_specifier,
    STATE(7835), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2740), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5488), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5285), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [173754] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(5136), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5369), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(8970), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5367), 21,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [173796] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8973), 1,
      sym_identifier,
    ACTIONS(8975), 1,
      anon_sym_COLON_COLON,
    STATE(2193), 1,
      sym_template_type,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(5066), 1,
      sym_field_declaration_list,
    STATE(5528), 1,
      sym_ms_declspec_modifier,
    STATE(6458), 1,
      sym__scope_resolution,
    STATE(6797), 1,
      sym_virtual_specifier,
    STATE(7519), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4867), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5526), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5262), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [173876] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(8875), 1,
      sym_identifier,
    ACTIONS(8877), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8881), 1,
      sym_primitive_type,
    ACTIONS(8883), 1,
      anon_sym_enum,
    ACTIONS(8885), 1,
      anon_sym_class,
    ACTIONS(8887), 1,
      anon_sym_struct,
    ACTIONS(8889), 1,
      anon_sym_union,
    ACTIONS(8891), 1,
      sym_auto,
    ACTIONS(8893), 1,
      anon_sym_decltype,
    ACTIONS(8895), 1,
      anon_sym_typename,
    STATE(2897), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3410), 1,
      sym_type_specifier,
    STATE(3530), 1,
      sym_decltype_auto,
    STATE(3541), 1,
      sym_qualified_type_identifier,
    STATE(6485), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(3351), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8879), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3532), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [173950] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    STATE(2303), 1,
      sym_attribute_specifier,
    ACTIONS(5579), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5581), 25,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [173992] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8973), 1,
      sym_identifier,
    ACTIONS(8975), 1,
      anon_sym_COLON_COLON,
    STATE(2193), 1,
      sym_template_type,
    STATE(2284), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(5066), 1,
      sym_field_declaration_list,
    STATE(5528), 1,
      sym_ms_declspec_modifier,
    STATE(6458), 1,
      sym__scope_resolution,
    STATE(6797), 1,
      sym_virtual_specifier,
    STATE(7519), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4867), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5526), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5262), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [174072] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8973), 1,
      sym_identifier,
    ACTIONS(8975), 1,
      anon_sym_COLON_COLON,
    STATE(2193), 1,
      sym_template_type,
    STATE(2280), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(5066), 1,
      sym_field_declaration_list,
    STATE(5528), 1,
      sym_ms_declspec_modifier,
    STATE(6458), 1,
      sym__scope_resolution,
    STATE(6797), 1,
      sym_virtual_specifier,
    STATE(7519), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4867), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5526), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5262), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [174152] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2197), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5315), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(8977), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5312), 21,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [174194] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    STATE(2289), 1,
      sym_attribute_specifier,
    ACTIONS(5571), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5573), 25,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [174236] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2280), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5508), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2311), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5504), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5238), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [174316] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2284), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5508), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2311), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5504), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5238), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [174396] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2439), 1,
      sym__class_declaration_item,
    STATE(2480), 1,
      sym__class_declaration,
    STATE(5295), 1,
      sym_field_declaration_list,
    STATE(5475), 1,
      sym_ms_declspec_modifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(6989), 1,
      sym_virtual_specifier,
    STATE(7581), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4750), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5452), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5302), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [174476] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5508), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2311), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5504), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5238), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [174556] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    STATE(2306), 1,
      sym_attribute_specifier,
    ACTIONS(5575), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5577), 25,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [174598] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(7547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    ACTIONS(8973), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(4855), 1,
      sym_field_declaration_list,
    STATE(4932), 1,
      sym__class_declaration_item,
    STATE(4934), 1,
      sym__class_declaration,
    STATE(5442), 1,
      sym_ms_declspec_modifier,
    STATE(6475), 1,
      sym__scope_resolution,
    STATE(6835), 1,
      sym_virtual_specifier,
    STATE(7667), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4579), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5440), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5264), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [174678] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(8804), 1,
      sym_identifier,
    ACTIONS(8806), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8810), 1,
      sym_primitive_type,
    ACTIONS(8812), 1,
      anon_sym_enum,
    ACTIONS(8814), 1,
      anon_sym_class,
    ACTIONS(8816), 1,
      anon_sym_struct,
    ACTIONS(8818), 1,
      anon_sym_union,
    ACTIONS(8820), 1,
      sym_auto,
    ACTIONS(8822), 1,
      anon_sym_decltype,
    ACTIONS(8824), 1,
      anon_sym_typename,
    STATE(2785), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2976), 1,
      sym_type_specifier,
    STATE(3253), 1,
      sym_decltype_auto,
    STATE(3259), 1,
      sym_qualified_type_identifier,
    STATE(6464), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(3231), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8808), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3248), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [174752] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(7547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    ACTIONS(8973), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(4855), 1,
      sym_field_declaration_list,
    STATE(4920), 1,
      sym__class_declaration,
    STATE(4932), 1,
      sym__class_declaration_item,
    STATE(5442), 1,
      sym_ms_declspec_modifier,
    STATE(6475), 1,
      sym__scope_resolution,
    STATE(6835), 1,
      sym_virtual_specifier,
    STATE(7667), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4579), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5440), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5264), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [174832] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(69), 1,
      anon_sym_enum,
    ACTIONS(71), 1,
      anon_sym_class,
    ACTIONS(73), 1,
      anon_sym_struct,
    ACTIONS(75), 1,
      anon_sym_union,
    ACTIONS(121), 1,
      sym_auto,
    ACTIONS(123), 1,
      anon_sym_decltype,
    ACTIONS(127), 1,
      anon_sym_typename,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2617), 1,
      sym_primitive_type,
    ACTIONS(3485), 1,
      sym_identifier,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    STATE(2230), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2264), 1,
      sym_type_specifier,
    STATE(2279), 1,
      sym_qualified_type_identifier,
    STATE(2298), 1,
      sym_decltype_auto,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2252), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(55), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2277), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [174906] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2438), 1,
      sym__class_declaration,
    STATE(2439), 1,
      sym__class_declaration_item,
    STATE(5295), 1,
      sym_field_declaration_list,
    STATE(5475), 1,
      sym_ms_declspec_modifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(6989), 1,
      sym_virtual_specifier,
    STATE(7581), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4750), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5452), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5302), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [174986] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5508), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2308), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5504), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5238), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [175066] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      sym_auto,
    ACTIONS(123), 1,
      anon_sym_decltype,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1833), 1,
      anon_sym_enum,
    ACTIONS(1835), 1,
      anon_sym_class,
    ACTIONS(1837), 1,
      anon_sym_struct,
    ACTIONS(1839), 1,
      anon_sym_union,
    ACTIONS(1863), 1,
      anon_sym_typename,
    ACTIONS(2617), 1,
      sym_primitive_type,
    ACTIONS(4068), 1,
      sym_identifier,
    ACTIONS(4078), 1,
      anon_sym_COLON_COLON,
    STATE(2230), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2264), 1,
      sym_type_specifier,
    STATE(2279), 1,
      sym_qualified_type_identifier,
    STATE(2298), 1,
      sym_decltype_auto,
    STATE(6449), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2252), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(55), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2277), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [175140] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4078), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8983), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2280), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5445), 1,
      sym_ms_declspec_modifier,
    STATE(6449), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2229), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5446), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5300), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [175220] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2280), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5508), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2308), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5504), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5238), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [175300] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5508), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2313), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5504), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5238), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [175380] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7330), 1,
      anon_sym_DASH_GT,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(8985), 1,
      anon_sym_requires,
    STATE(5977), 1,
      sym__function_attributes_end,
    STATE(6016), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8910), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5350), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8693), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [175450] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4078), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8983), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2284), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5445), 1,
      sym_ms_declspec_modifier,
    STATE(6449), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2229), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5446), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5300), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [175530] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4078), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8983), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5445), 1,
      sym_ms_declspec_modifier,
    STATE(6449), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2229), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5446), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5300), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [175610] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(8804), 1,
      sym_identifier,
    ACTIONS(8806), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8810), 1,
      sym_primitive_type,
    ACTIONS(8812), 1,
      anon_sym_enum,
    ACTIONS(8814), 1,
      anon_sym_class,
    ACTIONS(8816), 1,
      anon_sym_struct,
    ACTIONS(8818), 1,
      anon_sym_union,
    ACTIONS(8820), 1,
      sym_auto,
    ACTIONS(8822), 1,
      anon_sym_decltype,
    ACTIONS(8824), 1,
      anon_sym_typename,
    STATE(2785), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2973), 1,
      sym_type_specifier,
    STATE(3253), 1,
      sym_decltype_auto,
    STATE(3259), 1,
      sym_qualified_type_identifier,
    STATE(6464), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(3231), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8808), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3248), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [175684] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7142), 1,
      anon_sym_requires,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(5809), 1,
      sym_trailing_return_type,
    STATE(5950), 1,
      sym__function_attributes_end,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5361), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [175754] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2284), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5508), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2313), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5504), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5238), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [175834] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2280), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5508), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2313), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5504), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5238), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [175914] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(8848), 1,
      sym_identifier,
    ACTIONS(8850), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8854), 1,
      sym_primitive_type,
    ACTIONS(8856), 1,
      anon_sym_enum,
    ACTIONS(8858), 1,
      anon_sym_class,
    ACTIONS(8860), 1,
      anon_sym_struct,
    ACTIONS(8862), 1,
      anon_sym_union,
    ACTIONS(8864), 1,
      sym_auto,
    ACTIONS(8866), 1,
      anon_sym_decltype,
    ACTIONS(8868), 1,
      anon_sym_typename,
    STATE(2748), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2949), 1,
      sym_type_specifier,
    STATE(3153), 1,
      sym_qualified_type_identifier,
    STATE(3177), 1,
      sym_decltype_auto,
    STATE(6486), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(3147), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8852), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3158), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [175988] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    STATE(2296), 1,
      sym_attribute_specifier,
    ACTIONS(5587), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5589), 25,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [176030] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(8913), 1,
      anon_sym_requires,
    STATE(5774), 1,
      sym_trailing_return_type,
    STATE(5948), 1,
      sym__function_attributes_end,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8910), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5354), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8693), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [176100] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(7547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    ACTIONS(8973), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(4855), 1,
      sym_field_declaration_list,
    STATE(4876), 1,
      sym__class_declaration,
    STATE(4932), 1,
      sym__class_declaration_item,
    STATE(5442), 1,
      sym_ms_declspec_modifier,
    STATE(6475), 1,
      sym__scope_resolution,
    STATE(6835), 1,
      sym_virtual_specifier,
    STATE(7667), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4579), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5440), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5264), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [176180] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5508), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2229), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5504), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5238), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [176260] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7523), 1,
      sym_identifier,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7529), 1,
      sym_primitive_type,
    ACTIONS(7531), 1,
      anon_sym_enum,
    ACTIONS(7533), 1,
      anon_sym_class,
    ACTIONS(7535), 1,
      anon_sym_struct,
    ACTIONS(7537), 1,
      anon_sym_union,
    ACTIONS(7539), 1,
      sym_auto,
    ACTIONS(7541), 1,
      anon_sym_decltype,
    ACTIONS(7543), 1,
      anon_sym_typename,
    STATE(4236), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4868), 1,
      sym_type_specifier,
    STATE(4885), 1,
      sym_qualified_type_identifier,
    STATE(4919), 1,
      sym_decltype_auto,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2252), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7527), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4898), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [176334] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    STATE(2272), 1,
      sym_attribute_specifier,
    ACTIONS(5567), 3,
      anon_sym_AMP,
      anon_sym_LBRACK,
      anon_sym_const,
    ACTIONS(5569), 25,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [176376] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5508), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2314), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5504), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5238), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [176456] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7461), 1,
      sym_primitive_type,
    ACTIONS(8765), 1,
      sym_identifier,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8769), 1,
      anon_sym_enum,
    ACTIONS(8771), 1,
      anon_sym_class,
    ACTIONS(8773), 1,
      anon_sym_struct,
    ACTIONS(8775), 1,
      anon_sym_union,
    ACTIONS(8777), 1,
      anon_sym_typename,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4060), 1,
      sym_type_specifier,
    STATE(6489), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [176530] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(8826), 1,
      sym_identifier,
    ACTIONS(8828), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8832), 1,
      sym_primitive_type,
    ACTIONS(8834), 1,
      anon_sym_enum,
    ACTIONS(8836), 1,
      anon_sym_class,
    ACTIONS(8838), 1,
      anon_sym_struct,
    ACTIONS(8840), 1,
      anon_sym_union,
    ACTIONS(8842), 1,
      sym_auto,
    ACTIONS(8844), 1,
      anon_sym_decltype,
    ACTIONS(8846), 1,
      anon_sym_typename,
    STATE(3545), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3848), 1,
      sym_type_specifier,
    STATE(4106), 1,
      sym_decltype_auto,
    STATE(4150), 1,
      sym_qualified_type_identifier,
    STATE(6451), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(4084), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8830), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4102), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [176604] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2284), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5508), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2314), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5504), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5238), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [176684] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2280), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5508), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2314), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5504), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5238), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [176764] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2197), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5379), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(8988), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5377), 21,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [176806] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6928), 1,
      anon_sym_STAR,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5967), 1,
      sym__declarator,
    STATE(7203), 1,
      sym_init_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [176876] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2197), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5389), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(8991), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5387), 21,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [176918] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7330), 1,
      anon_sym_DASH_GT,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    STATE(5906), 1,
      sym__function_attributes_end,
    STATE(6028), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5351), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8693), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [176988] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(8826), 1,
      sym_identifier,
    ACTIONS(8828), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8832), 1,
      sym_primitive_type,
    ACTIONS(8834), 1,
      anon_sym_enum,
    ACTIONS(8836), 1,
      anon_sym_class,
    ACTIONS(8838), 1,
      anon_sym_struct,
    ACTIONS(8840), 1,
      anon_sym_union,
    ACTIONS(8842), 1,
      sym_auto,
    ACTIONS(8844), 1,
      anon_sym_decltype,
    ACTIONS(8846), 1,
      anon_sym_typename,
    STATE(3545), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3870), 1,
      sym_type_specifier,
    STATE(4106), 1,
      sym_decltype_auto,
    STATE(4150), 1,
      sym_qualified_type_identifier,
    STATE(6451), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(4084), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8830), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4102), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [177062] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6594), 1,
      anon_sym_LBRACE,
    ACTIONS(8877), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8994), 1,
      sym_identifier,
    STATE(3026), 1,
      sym_template_type,
    STATE(3307), 1,
      sym_field_declaration_list,
    STATE(3601), 1,
      sym__class_declaration_item,
    STATE(3607), 1,
      sym__class_declaration,
    STATE(5447), 1,
      sym_ms_declspec_modifier,
    STATE(6485), 1,
      sym__scope_resolution,
    STATE(6821), 1,
      sym_virtual_specifier,
    STATE(7734), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2908), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5458), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5266), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [177142] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7330), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8748), 1,
      anon_sym_requires,
    STATE(5942), 1,
      sym__function_attributes_end,
    STATE(5998), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5348), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [177212] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7142), 1,
      anon_sym_requires,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    STATE(5806), 1,
      sym_trailing_return_type,
    STATE(5980), 1,
      sym__function_attributes_end,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5349), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8693), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [177282] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7461), 1,
      sym_primitive_type,
    ACTIONS(8765), 1,
      sym_identifier,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8769), 1,
      anon_sym_enum,
    ACTIONS(8771), 1,
      anon_sym_class,
    ACTIONS(8773), 1,
      anon_sym_struct,
    ACTIONS(8775), 1,
      anon_sym_union,
    ACTIONS(8777), 1,
      anon_sym_typename,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4059), 1,
      sym_type_specifier,
    STATE(6489), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [177356] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(8804), 1,
      sym_identifier,
    ACTIONS(8806), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8810), 1,
      sym_primitive_type,
    ACTIONS(8812), 1,
      anon_sym_enum,
    ACTIONS(8814), 1,
      anon_sym_class,
    ACTIONS(8816), 1,
      anon_sym_struct,
    ACTIONS(8818), 1,
      anon_sym_union,
    ACTIONS(8820), 1,
      sym_auto,
    ACTIONS(8822), 1,
      anon_sym_decltype,
    ACTIONS(8824), 1,
      anon_sym_typename,
    STATE(2785), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3214), 1,
      sym_type_specifier,
    STATE(3253), 1,
      sym_decltype_auto,
    STATE(3259), 1,
      sym_qualified_type_identifier,
    STATE(6464), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(3231), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8808), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3248), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [177430] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5817), 1,
      anon_sym_LBRACE,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8931), 1,
      sym_identifier,
    STATE(2498), 1,
      sym_template_type,
    STATE(2553), 1,
      sym_field_declaration_list,
    STATE(2654), 1,
      sym__class_declaration,
    STATE(2657), 1,
      sym__class_declaration_item,
    STATE(5530), 1,
      sym_ms_declspec_modifier,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(6883), 1,
      sym_virtual_specifier,
    STATE(7724), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2412), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5529), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5273), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [177510] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5817), 1,
      anon_sym_LBRACE,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8931), 1,
      sym_identifier,
    STATE(2498), 1,
      sym_template_type,
    STATE(2553), 1,
      sym_field_declaration_list,
    STATE(2657), 1,
      sym__class_declaration_item,
    STATE(2661), 1,
      sym__class_declaration,
    STATE(5530), 1,
      sym_ms_declspec_modifier,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(6883), 1,
      sym_virtual_specifier,
    STATE(7724), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2412), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5529), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5273), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [177590] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(3796), 1,
      sym_auto,
    ACTIONS(3798), 1,
      anon_sym_decltype,
    ACTIONS(7479), 1,
      sym_primitive_type,
    ACTIONS(8751), 1,
      sym_identifier,
    ACTIONS(8753), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8755), 1,
      anon_sym_enum,
    ACTIONS(8757), 1,
      anon_sym_class,
    ACTIONS(8759), 1,
      anon_sym_struct,
    ACTIONS(8761), 1,
      anon_sym_union,
    ACTIONS(8763), 1,
      anon_sym_typename,
    STATE(2571), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2980), 1,
      sym_decltype_auto,
    STATE(3011), 1,
      sym_qualified_type_identifier,
    STATE(4185), 1,
      sym_type_specifier,
    STATE(6505), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2937), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(3762), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2981), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [177664] = 4,
    ACTIONS(3), 1,
      sym_comment,
    STATE(5075), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5355), 4,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
    ACTIONS(5353), 25,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___attribute__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [177704] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7481), 1,
      sym_identifier,
    ACTIONS(7483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7487), 1,
      sym_primitive_type,
    ACTIONS(7489), 1,
      anon_sym_enum,
    ACTIONS(7491), 1,
      anon_sym_class,
    ACTIONS(7493), 1,
      anon_sym_struct,
    ACTIONS(7495), 1,
      anon_sym_union,
    ACTIONS(7497), 1,
      sym_auto,
    ACTIONS(7499), 1,
      anon_sym_decltype,
    ACTIONS(7501), 1,
      anon_sym_typename,
    STATE(4291), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4959), 1,
      sym_type_specifier,
    STATE(5018), 1,
      sym_decltype_auto,
    STATE(5045), 1,
      sym_qualified_type_identifier,
    STATE(6459), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(4972), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7485), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4980), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [177778] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(8826), 1,
      sym_identifier,
    ACTIONS(8828), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8832), 1,
      sym_primitive_type,
    ACTIONS(8834), 1,
      anon_sym_enum,
    ACTIONS(8836), 1,
      anon_sym_class,
    ACTIONS(8838), 1,
      anon_sym_struct,
    ACTIONS(8840), 1,
      anon_sym_union,
    ACTIONS(8842), 1,
      sym_auto,
    ACTIONS(8844), 1,
      anon_sym_decltype,
    ACTIONS(8846), 1,
      anon_sym_typename,
    STATE(3545), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(4089), 1,
      sym_type_specifier,
    STATE(4106), 1,
      sym_decltype_auto,
    STATE(4150), 1,
      sym_qualified_type_identifier,
    STATE(6451), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(4084), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8830), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(4102), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [177852] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(3766), 1,
      anon_sym_enum,
    ACTIONS(3768), 1,
      anon_sym_class,
    ACTIONS(3770), 1,
      anon_sym_struct,
    ACTIONS(3772), 1,
      anon_sym_union,
    ACTIONS(3796), 1,
      sym_auto,
    ACTIONS(3798), 1,
      anon_sym_decltype,
    ACTIONS(3800), 1,
      anon_sym_typename,
    ACTIONS(7475), 1,
      sym_identifier,
    ACTIONS(7477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7479), 1,
      sym_primitive_type,
    STATE(2571), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2935), 1,
      sym_type_specifier,
    STATE(2980), 1,
      sym_decltype_auto,
    STATE(3011), 1,
      sym_qualified_type_identifier,
    STATE(6482), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2937), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(3762), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2981), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [177926] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6594), 1,
      anon_sym_LBRACE,
    ACTIONS(8877), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8994), 1,
      sym_identifier,
    STATE(3026), 1,
      sym_template_type,
    STATE(3307), 1,
      sym_field_declaration_list,
    STATE(3601), 1,
      sym__class_declaration_item,
    STATE(3605), 1,
      sym__class_declaration,
    STATE(5447), 1,
      sym_ms_declspec_modifier,
    STATE(6485), 1,
      sym__scope_resolution,
    STATE(6821), 1,
      sym_virtual_specifier,
    STATE(7734), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2908), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5458), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5266), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [178006] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6594), 1,
      anon_sym_LBRACE,
    ACTIONS(8877), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8994), 1,
      sym_identifier,
    STATE(3026), 1,
      sym_template_type,
    STATE(3307), 1,
      sym_field_declaration_list,
    STATE(3600), 1,
      sym__class_declaration,
    STATE(3601), 1,
      sym__class_declaration_item,
    STATE(5447), 1,
      sym_ms_declspec_modifier,
    STATE(6485), 1,
      sym__scope_resolution,
    STATE(6821), 1,
      sym_virtual_specifier,
    STATE(7734), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2908), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5458), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5266), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [178086] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6321), 1,
      anon_sym_LBRACE,
    ACTIONS(8850), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8996), 1,
      sym_identifier,
    STATE(2883), 1,
      sym_template_type,
    STATE(3038), 1,
      sym_field_declaration_list,
    STATE(3161), 1,
      sym__class_declaration,
    STATE(3162), 1,
      sym__class_declaration_item,
    STATE(5437), 1,
      sym_ms_declspec_modifier,
    STATE(6486), 1,
      sym__scope_resolution,
    STATE(6791), 1,
      sym_virtual_specifier,
    STATE(7603), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2753), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5438), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5298), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [178166] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6321), 1,
      anon_sym_LBRACE,
    ACTIONS(8850), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8996), 1,
      sym_identifier,
    STATE(2883), 1,
      sym_template_type,
    STATE(3038), 1,
      sym_field_declaration_list,
    STATE(3162), 1,
      sym__class_declaration_item,
    STATE(3172), 1,
      sym__class_declaration,
    STATE(5437), 1,
      sym_ms_declspec_modifier,
    STATE(6486), 1,
      sym__scope_resolution,
    STATE(6791), 1,
      sym_virtual_specifier,
    STATE(7603), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2753), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5438), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5298), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [178246] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(5066), 1,
      sym_field_declaration_list,
    STATE(5524), 1,
      sym_ms_declspec_modifier,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6797), 1,
      sym_virtual_specifier,
    STATE(7519), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4867), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5523), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5234), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [178326] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(5322), 1,
      anon_sym_LPAREN2,
    STATE(2533), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2805), 1,
      sym_argument_list,
    STATE(4005), 1,
      sym_initializer_list,
    ACTIONS(5318), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5953), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5320), 19,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
  [178376] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2284), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(5066), 1,
      sym_field_declaration_list,
    STATE(5524), 1,
      sym_ms_declspec_modifier,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6797), 1,
      sym_virtual_specifier,
    STATE(7519), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4867), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5523), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5234), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [178456] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2280), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(5066), 1,
      sym_field_declaration_list,
    STATE(5524), 1,
      sym_ms_declspec_modifier,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6797), 1,
      sym_virtual_specifier,
    STATE(7519), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4867), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5523), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5234), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [178536] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6928), 1,
      anon_sym_STAR,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5905), 1,
      sym__declarator,
    STATE(7350), 1,
      sym_init_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [178606] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2280), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5508), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2312), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5504), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5238), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [178686] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2284), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5508), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2312), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5504), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5238), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [178766] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7461), 1,
      sym_primitive_type,
    ACTIONS(8765), 1,
      sym_identifier,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8769), 1,
      anon_sym_enum,
    ACTIONS(8771), 1,
      anon_sym_class,
    ACTIONS(8773), 1,
      anon_sym_struct,
    ACTIONS(8775), 1,
      anon_sym_union,
    ACTIONS(8777), 1,
      anon_sym_typename,
    STATE(2417), 1,
      sym_type_specifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(6489), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [178840] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6425), 1,
      anon_sym_LBRACE,
    ACTIONS(8806), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8998), 1,
      sym_identifier,
    STATE(2942), 1,
      sym_template_type,
    STATE(3098), 1,
      sym_field_declaration_list,
    STATE(3261), 1,
      sym__class_declaration_item,
    STATE(3339), 1,
      sym__class_declaration,
    STATE(5479), 1,
      sym_ms_declspec_modifier,
    STATE(6464), 1,
      sym__scope_resolution,
    STATE(6992), 1,
      sym_virtual_specifier,
    STATE(7621), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2800), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5480), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5287), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [178920] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(4855), 1,
      sym_field_declaration_list,
    STATE(4932), 1,
      sym__class_declaration_item,
    STATE(4934), 1,
      sym__class_declaration,
    STATE(5463), 1,
      sym_ms_declspec_modifier,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6835), 1,
      sym_virtual_specifier,
    STATE(7667), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4579), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5453), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5243), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [179000] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5508), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2312), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5504), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5238), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [179080] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(4855), 1,
      sym_field_declaration_list,
    STATE(4920), 1,
      sym__class_declaration,
    STATE(4932), 1,
      sym__class_declaration_item,
    STATE(5463), 1,
      sym_ms_declspec_modifier,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6835), 1,
      sym_virtual_specifier,
    STATE(7667), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4579), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5453), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5243), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [179160] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(4855), 1,
      sym_field_declaration_list,
    STATE(4876), 1,
      sym__class_declaration,
    STATE(4932), 1,
      sym__class_declaration_item,
    STATE(5463), 1,
      sym_ms_declspec_modifier,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6835), 1,
      sym_virtual_specifier,
    STATE(7667), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4579), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5453), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5243), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [179240] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(3796), 1,
      sym_auto,
    ACTIONS(3798), 1,
      anon_sym_decltype,
    ACTIONS(7479), 1,
      sym_primitive_type,
    ACTIONS(8751), 1,
      sym_identifier,
    ACTIONS(8753), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8755), 1,
      anon_sym_enum,
    ACTIONS(8757), 1,
      anon_sym_class,
    ACTIONS(8759), 1,
      anon_sym_struct,
    ACTIONS(8761), 1,
      anon_sym_union,
    ACTIONS(8763), 1,
      anon_sym_typename,
    STATE(2571), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2980), 1,
      sym_decltype_auto,
    STATE(3011), 1,
      sym_qualified_type_identifier,
    STATE(4204), 1,
      sym_type_specifier,
    STATE(6505), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2937), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(3762), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2981), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [179314] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6321), 1,
      anon_sym_LBRACE,
    ACTIONS(8850), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8996), 1,
      sym_identifier,
    STATE(2883), 1,
      sym_template_type,
    STATE(3038), 1,
      sym_field_declaration_list,
    STATE(3162), 1,
      sym__class_declaration_item,
    STATE(3176), 1,
      sym__class_declaration,
    STATE(5437), 1,
      sym_ms_declspec_modifier,
    STATE(6486), 1,
      sym__scope_resolution,
    STATE(6791), 1,
      sym_virtual_specifier,
    STATE(7603), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2753), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5438), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5298), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [179394] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6425), 1,
      anon_sym_LBRACE,
    ACTIONS(8806), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8998), 1,
      sym_identifier,
    STATE(2942), 1,
      sym_template_type,
    STATE(3098), 1,
      sym_field_declaration_list,
    STATE(3261), 1,
      sym__class_declaration_item,
    STATE(3264), 1,
      sym__class_declaration,
    STATE(5479), 1,
      sym_ms_declspec_modifier,
    STATE(6464), 1,
      sym__scope_resolution,
    STATE(6992), 1,
      sym_virtual_specifier,
    STATE(7621), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2800), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5480), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5287), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [179474] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6425), 1,
      anon_sym_LBRACE,
    ACTIONS(8806), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8998), 1,
      sym_identifier,
    STATE(2942), 1,
      sym_template_type,
    STATE(3098), 1,
      sym_field_declaration_list,
    STATE(3261), 1,
      sym__class_declaration_item,
    STATE(3266), 1,
      sym__class_declaration,
    STATE(5479), 1,
      sym_ms_declspec_modifier,
    STATE(6464), 1,
      sym__scope_resolution,
    STATE(6992), 1,
      sym_virtual_specifier,
    STATE(7621), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2800), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5480), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5287), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [179554] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      sym_auto,
    ACTIONS(123), 1,
      anon_sym_decltype,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7574), 1,
      sym_identifier,
    ACTIONS(7578), 1,
      sym_primitive_type,
    ACTIONS(7580), 1,
      anon_sym_enum,
    ACTIONS(7582), 1,
      anon_sym_class,
    ACTIONS(7584), 1,
      anon_sym_struct,
    ACTIONS(7586), 1,
      anon_sym_union,
    ACTIONS(7588), 1,
      anon_sym_typename,
    STATE(2264), 1,
      sym_type_specifier,
    STATE(2279), 1,
      sym_qualified_type_identifier,
    STATE(2298), 1,
      sym_decltype_auto,
    STATE(4678), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2252), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7576), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2277), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [179628] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7461), 1,
      sym_primitive_type,
    ACTIONS(8765), 1,
      sym_identifier,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8769), 1,
      anon_sym_enum,
    ACTIONS(8771), 1,
      anon_sym_class,
    ACTIONS(8773), 1,
      anon_sym_struct,
    ACTIONS(8775), 1,
      anon_sym_union,
    ACTIONS(8777), 1,
      anon_sym_typename,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4103), 1,
      sym_type_specifier,
    STATE(6489), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [179702] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(7483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8483), 1,
      anon_sym_LBRACE,
    ACTIONS(9000), 1,
      sym_identifier,
    STATE(4671), 1,
      sym_template_type,
    STATE(4905), 1,
      sym_field_declaration_list,
    STATE(4981), 1,
      sym__class_declaration_item,
    STATE(5007), 1,
      sym__class_declaration,
    STATE(5477), 1,
      sym_ms_declspec_modifier,
    STATE(6459), 1,
      sym__scope_resolution,
    STATE(6958), 1,
      sym_virtual_specifier,
    STATE(7571), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4588), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5474), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5276), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [179782] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(7483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8483), 1,
      anon_sym_LBRACE,
    ACTIONS(9000), 1,
      sym_identifier,
    STATE(4671), 1,
      sym_template_type,
    STATE(4905), 1,
      sym_field_declaration_list,
    STATE(4981), 1,
      sym__class_declaration_item,
    STATE(4991), 1,
      sym__class_declaration,
    STATE(5477), 1,
      sym_ms_declspec_modifier,
    STATE(6459), 1,
      sym__scope_resolution,
    STATE(6958), 1,
      sym_virtual_specifier,
    STATE(7571), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4588), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5474), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5276), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [179862] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(7483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8483), 1,
      anon_sym_LBRACE,
    ACTIONS(9000), 1,
      sym_identifier,
    STATE(4671), 1,
      sym_template_type,
    STATE(4905), 1,
      sym_field_declaration_list,
    STATE(4981), 1,
      sym__class_declaration_item,
    STATE(5000), 1,
      sym__class_declaration,
    STATE(5477), 1,
      sym_ms_declspec_modifier,
    STATE(6459), 1,
      sym__scope_resolution,
    STATE(6958), 1,
      sym_virtual_specifier,
    STATE(7571), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4588), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5474), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5276), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [179942] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      sym_auto,
    ACTIONS(123), 1,
      anon_sym_decltype,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2617), 1,
      sym_primitive_type,
    ACTIONS(2621), 1,
      anon_sym_class,
    ACTIONS(2623), 1,
      anon_sym_struct,
    ACTIONS(2625), 1,
      anon_sym_union,
    ACTIONS(3485), 1,
      sym_identifier,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3497), 1,
      anon_sym_enum,
    ACTIONS(3499), 1,
      anon_sym_typename,
    STATE(2264), 1,
      sym_type_specifier,
    STATE(2279), 1,
      sym_qualified_type_identifier,
    STATE(2298), 1,
      sym_decltype_auto,
    STATE(2659), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2252), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(3495), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2277), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [180016] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6928), 1,
      anon_sym_STAR,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5932), 1,
      sym__declarator,
    STATE(7147), 1,
      sym_init_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [180086] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(7134), 1,
      anon_sym_LBRACE,
    ACTIONS(8828), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9002), 1,
      sym_identifier,
    STATE(3808), 1,
      sym_template_type,
    STATE(4076), 1,
      sym_field_declaration_list,
    STATE(4154), 1,
      sym__class_declaration,
    STATE(4168), 1,
      sym__class_declaration_item,
    STATE(5490), 1,
      sym_ms_declspec_modifier,
    STATE(6451), 1,
      sym__scope_resolution,
    STATE(6897), 1,
      sym_virtual_specifier,
    STATE(7535), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3362), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5492), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5258), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [180166] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(7461), 1,
      sym_primitive_type,
    ACTIONS(8765), 1,
      sym_identifier,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8769), 1,
      anon_sym_enum,
    ACTIONS(8771), 1,
      anon_sym_class,
    ACTIONS(8773), 1,
      anon_sym_struct,
    ACTIONS(8775), 1,
      anon_sym_union,
    ACTIONS(8777), 1,
      anon_sym_typename,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(4108), 1,
      sym_type_specifier,
    STATE(6489), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [180240] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6928), 1,
      anon_sym_STAR,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5895), 1,
      sym__declarator,
    STATE(7340), 1,
      sym_init_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [180310] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(7134), 1,
      anon_sym_LBRACE,
    ACTIONS(8828), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9002), 1,
      sym_identifier,
    STATE(3808), 1,
      sym_template_type,
    STATE(4076), 1,
      sym_field_declaration_list,
    STATE(4168), 1,
      sym__class_declaration_item,
    STATE(4171), 1,
      sym__class_declaration,
    STATE(5490), 1,
      sym_ms_declspec_modifier,
    STATE(6451), 1,
      sym__scope_resolution,
    STATE(6897), 1,
      sym_virtual_specifier,
    STATE(7535), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3362), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5492), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5258), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [180390] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(7134), 1,
      anon_sym_LBRACE,
    ACTIONS(8828), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9002), 1,
      sym_identifier,
    STATE(3808), 1,
      sym_template_type,
    STATE(4076), 1,
      sym_field_declaration_list,
    STATE(4107), 1,
      sym__class_declaration,
    STATE(4168), 1,
      sym__class_declaration_item,
    STATE(5490), 1,
      sym_ms_declspec_modifier,
    STATE(6451), 1,
      sym__scope_resolution,
    STATE(6897), 1,
      sym_virtual_specifier,
    STATE(7535), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3362), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5492), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5258), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [180470] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      sym_auto,
    ACTIONS(123), 1,
      anon_sym_decltype,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2617), 1,
      sym_primitive_type,
    ACTIONS(2619), 1,
      anon_sym_enum,
    ACTIONS(2621), 1,
      anon_sym_class,
    ACTIONS(2623), 1,
      anon_sym_struct,
    ACTIONS(2625), 1,
      anon_sym_union,
    ACTIONS(2627), 1,
      anon_sym_typename,
    ACTIONS(3485), 1,
      sym_identifier,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    STATE(2230), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2264), 1,
      sym_type_specifier,
    STATE(2279), 1,
      sym_qualified_type_identifier,
    STATE(2298), 1,
      sym_decltype_auto,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2252), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(55), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2277), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [180544] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2280), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5508), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2309), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5504), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5238), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [180624] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2284), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5508), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2309), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5504), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5238), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [180704] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2280), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5451), 1,
      sym_ms_declspec_modifier,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2466), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5459), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5229), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [180784] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6928), 1,
      anon_sym_STAR,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5982), 1,
      sym__declarator,
    STATE(7147), 1,
      sym_init_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [180854] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2284), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5451), 1,
      sym_ms_declspec_modifier,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2466), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5459), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5229), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [180934] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5451), 1,
      sym_ms_declspec_modifier,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2466), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5459), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5229), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [181014] = 22,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6877), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6879), 1,
      anon_sym_AMP,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7562), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8959), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9004), 1,
      anon_sym_requires,
    STATE(5324), 1,
      sym_ref_qualifier,
    STATE(6171), 1,
      sym__function_attributes_end,
    STATE(6379), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8604), 2,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    ACTIONS(8631), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5419), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [181090] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5508), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2310), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5504), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5238), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [181170] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2270), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5508), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2309), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5504), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5238), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [181250] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    ACTIONS(8753), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9007), 1,
      sym_identifier,
    STATE(2876), 1,
      sym_field_declaration_list,
    STATE(2892), 1,
      sym_template_type,
    STATE(2989), 1,
      sym__class_declaration,
    STATE(3022), 1,
      sym__class_declaration_item,
    STATE(5468), 1,
      sym_ms_declspec_modifier,
    STATE(6505), 1,
      sym__scope_resolution,
    STATE(6928), 1,
      sym_virtual_specifier,
    STATE(7835), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2740), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5465), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5301), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [181330] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7330), 1,
      anon_sym_DASH_GT,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(5888), 1,
      sym__function_attributes_end,
    STATE(6006), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5344), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [181400] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2284), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5508), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2310), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5504), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5238), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [181480] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2280), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5508), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2310), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5504), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5238), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [181560] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    ACTIONS(8753), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9007), 1,
      sym_identifier,
    STATE(2876), 1,
      sym_field_declaration_list,
    STATE(2892), 1,
      sym_template_type,
    STATE(2998), 1,
      sym__class_declaration,
    STATE(3022), 1,
      sym__class_declaration_item,
    STATE(5468), 1,
      sym_ms_declspec_modifier,
    STATE(6505), 1,
      sym__scope_resolution,
    STATE(6928), 1,
      sym_virtual_specifier,
    STATE(7835), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2740), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5465), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5301), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [181640] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2439), 1,
      sym__class_declaration_item,
    STATE(2445), 1,
      sym__class_declaration,
    STATE(2709), 1,
      sym_field_declaration_list,
    STATE(5518), 1,
      sym_ms_declspec_modifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(6811), 1,
      sym_virtual_specifier,
    STATE(7509), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2585), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5515), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5240), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [181720] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8007), 1,
      anon_sym_AMP,
    ACTIONS(9012), 1,
      anon_sym_const,
    STATE(5323), 1,
      sym_alignas_qualifier,
    ACTIONS(9015), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(5200), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(9009), 11,
      anon_sym___extension__,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
    ACTIONS(8005), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [181768] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2439), 1,
      sym__class_declaration_item,
    STATE(2480), 1,
      sym__class_declaration,
    STATE(2709), 1,
      sym_field_declaration_list,
    STATE(5518), 1,
      sym_ms_declspec_modifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(6811), 1,
      sym_virtual_specifier,
    STATE(7509), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2585), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5515), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5240), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [181848] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2438), 1,
      sym__class_declaration,
    STATE(2439), 1,
      sym__class_declaration_item,
    STATE(2709), 1,
      sym_field_declaration_list,
    STATE(5518), 1,
      sym_ms_declspec_modifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(6811), 1,
      sym_virtual_specifier,
    STATE(7509), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2585), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5515), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5240), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [181928] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    ACTIONS(8753), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9007), 1,
      sym_identifier,
    STATE(2876), 1,
      sym_field_declaration_list,
    STATE(2892), 1,
      sym_template_type,
    STATE(3012), 1,
      sym__class_declaration,
    STATE(3022), 1,
      sym__class_declaration_item,
    STATE(5468), 1,
      sym_ms_declspec_modifier,
    STATE(6505), 1,
      sym__scope_resolution,
    STATE(6928), 1,
      sym_virtual_specifier,
    STATE(7835), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2740), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5465), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5301), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [182008] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2284), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5508), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2229), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5504), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5238), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [182088] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      sym_auto,
    ACTIONS(123), 1,
      anon_sym_decltype,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7578), 1,
      sym_primitive_type,
    ACTIONS(8936), 1,
      sym_identifier,
    ACTIONS(8938), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8940), 1,
      anon_sym_enum,
    ACTIONS(8942), 1,
      anon_sym_class,
    ACTIONS(8944), 1,
      anon_sym_struct,
    ACTIONS(8946), 1,
      anon_sym_union,
    ACTIONS(8948), 1,
      anon_sym_typename,
    STATE(2264), 1,
      sym_type_specifier,
    STATE(2279), 1,
      sym_qualified_type_identifier,
    STATE(2298), 1,
      sym_decltype_auto,
    STATE(4678), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6461), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2252), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7576), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2277), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [182162] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(8782), 1,
      sym_identifier,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8788), 1,
      sym_primitive_type,
    ACTIONS(8790), 1,
      anon_sym_enum,
    ACTIONS(8792), 1,
      anon_sym_class,
    ACTIONS(8794), 1,
      anon_sym_struct,
    ACTIONS(8796), 1,
      anon_sym_union,
    ACTIONS(8798), 1,
      sym_auto,
    ACTIONS(8800), 1,
      anon_sym_decltype,
    ACTIONS(8802), 1,
      anon_sym_typename,
    STATE(2557), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2559), 1,
      sym_type_specifier,
    STATE(2650), 1,
      sym_decltype_auto,
    STATE(2663), 1,
      sym_qualified_type_identifier,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2549), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8786), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2655), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [182236] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3627), 1,
      anon_sym_LBRACE,
    ACTIONS(5625), 1,
      anon_sym_LPAREN2,
    STATE(2533), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3569), 1,
      sym_initializer_list,
    STATE(3570), 1,
      sym_argument_list,
    ACTIONS(5318), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5953), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5320), 19,
      anon_sym_RPAREN,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
  [182286] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2280), 1,
      sym__class_declaration,
    STATE(2305), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5508), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2229), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5504), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5238), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [182366] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8792), 1,
      anon_sym_class,
    ACTIONS(8794), 1,
      anon_sym_struct,
    ACTIONS(8796), 1,
      anon_sym_union,
    ACTIONS(8798), 1,
      sym_auto,
    ACTIONS(8800), 1,
      anon_sym_decltype,
    ACTIONS(8897), 1,
      sym_identifier,
    ACTIONS(8901), 1,
      sym_primitive_type,
    ACTIONS(8903), 1,
      anon_sym_enum,
    ACTIONS(8905), 1,
      anon_sym_typename,
    STATE(2470), 1,
      sym_type_specifier,
    STATE(2545), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2650), 1,
      sym_decltype_auto,
    STATE(2663), 1,
      sym_qualified_type_identifier,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2549), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8899), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2655), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [182440] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9018), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2439), 1,
      sym__class_declaration_item,
    STATE(2445), 1,
      sym__class_declaration,
    STATE(2709), 1,
      sym_field_declaration_list,
    STATE(5494), 1,
      sym_ms_declspec_modifier,
    STATE(6489), 1,
      sym__scope_resolution,
    STATE(6811), 1,
      sym_virtual_specifier,
    STATE(7509), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2585), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5513), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5226), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [182520] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9018), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2439), 1,
      sym__class_declaration_item,
    STATE(2480), 1,
      sym__class_declaration,
    STATE(2709), 1,
      sym_field_declaration_list,
    STATE(5494), 1,
      sym_ms_declspec_modifier,
    STATE(6489), 1,
      sym__scope_resolution,
    STATE(6811), 1,
      sym_virtual_specifier,
    STATE(7509), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2585), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5513), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5226), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [182600] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2439), 1,
      sym__class_declaration_item,
    STATE(2445), 1,
      sym__class_declaration,
    STATE(5295), 1,
      sym_field_declaration_list,
    STATE(5475), 1,
      sym_ms_declspec_modifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(6989), 1,
      sym_virtual_specifier,
    STATE(7581), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4750), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5452), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5302), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [182680] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6928), 1,
      anon_sym_STAR,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5909), 1,
      sym__declarator,
    STATE(7323), 1,
      sym_init_declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [182750] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9018), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2438), 1,
      sym__class_declaration,
    STATE(2439), 1,
      sym__class_declaration_item,
    STATE(2709), 1,
      sym_field_declaration_list,
    STATE(5494), 1,
      sym_ms_declspec_modifier,
    STATE(6489), 1,
      sym__scope_resolution,
    STATE(6811), 1,
      sym_virtual_specifier,
    STATE(7509), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2585), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5513), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5226), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [182830] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(8875), 1,
      sym_identifier,
    ACTIONS(8877), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8881), 1,
      sym_primitive_type,
    ACTIONS(8883), 1,
      anon_sym_enum,
    ACTIONS(8885), 1,
      anon_sym_class,
    ACTIONS(8887), 1,
      anon_sym_struct,
    ACTIONS(8889), 1,
      anon_sym_union,
    ACTIONS(8891), 1,
      sym_auto,
    ACTIONS(8893), 1,
      anon_sym_decltype,
    ACTIONS(8895), 1,
      anon_sym_typename,
    STATE(2897), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3104), 1,
      sym_type_specifier,
    STATE(3530), 1,
      sym_decltype_auto,
    STATE(3541), 1,
      sym_qualified_type_identifier,
    STATE(6485), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(3351), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8879), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3532), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [182904] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      sym_auto,
    ACTIONS(123), 1,
      anon_sym_decltype,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(7578), 1,
      sym_primitive_type,
    ACTIONS(8936), 1,
      sym_identifier,
    ACTIONS(8938), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8940), 1,
      anon_sym_enum,
    ACTIONS(8942), 1,
      anon_sym_class,
    ACTIONS(8944), 1,
      anon_sym_struct,
    ACTIONS(8946), 1,
      anon_sym_union,
    ACTIONS(8948), 1,
      anon_sym_typename,
    STATE(2279), 1,
      sym_qualified_type_identifier,
    STATE(2298), 1,
      sym_decltype_auto,
    STATE(4678), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6461), 1,
      sym__scope_resolution,
    STATE(6715), 1,
      sym_type_specifier,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2252), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(7576), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2277), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [182978] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8792), 1,
      anon_sym_class,
    ACTIONS(8794), 1,
      anon_sym_struct,
    ACTIONS(8796), 1,
      anon_sym_union,
    ACTIONS(8798), 1,
      sym_auto,
    ACTIONS(8800), 1,
      anon_sym_decltype,
    ACTIONS(8897), 1,
      sym_identifier,
    ACTIONS(8901), 1,
      sym_primitive_type,
    ACTIONS(8903), 1,
      anon_sym_enum,
    ACTIONS(8905), 1,
      anon_sym_typename,
    STATE(2487), 1,
      sym_type_specifier,
    STATE(2545), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2650), 1,
      sym_decltype_auto,
    STATE(2663), 1,
      sym_qualified_type_identifier,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2549), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8899), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2655), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [183052] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(3796), 1,
      sym_auto,
    ACTIONS(3798), 1,
      anon_sym_decltype,
    ACTIONS(7479), 1,
      sym_primitive_type,
    ACTIONS(8751), 1,
      sym_identifier,
    ACTIONS(8753), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8755), 1,
      anon_sym_enum,
    ACTIONS(8757), 1,
      anon_sym_class,
    ACTIONS(8759), 1,
      anon_sym_struct,
    ACTIONS(8761), 1,
      anon_sym_union,
    ACTIONS(8763), 1,
      anon_sym_typename,
    STATE(2571), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2935), 1,
      sym_type_specifier,
    STATE(2980), 1,
      sym_decltype_auto,
    STATE(3011), 1,
      sym_qualified_type_identifier,
    STATE(6505), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2937), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(3762), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2981), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [183126] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2042), 1,
      anon_sym_enum,
    ACTIONS(2044), 1,
      anon_sym_class,
    ACTIONS(2046), 1,
      anon_sym_struct,
    ACTIONS(2048), 1,
      anon_sym_union,
    ACTIONS(2072), 1,
      sym_auto,
    ACTIONS(2074), 1,
      anon_sym_decltype,
    ACTIONS(2076), 1,
      anon_sym_typename,
    ACTIONS(7455), 1,
      sym_identifier,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7461), 1,
      sym_primitive_type,
    STATE(2417), 1,
      sym_type_specifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2468), 1,
      sym_decltype_auto,
    STATE(2474), 1,
      sym_qualified_type_identifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2429), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2475), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [183200] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(8875), 1,
      sym_identifier,
    ACTIONS(8877), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8881), 1,
      sym_primitive_type,
    ACTIONS(8883), 1,
      anon_sym_enum,
    ACTIONS(8885), 1,
      anon_sym_class,
    ACTIONS(8887), 1,
      anon_sym_struct,
    ACTIONS(8889), 1,
      anon_sym_union,
    ACTIONS(8891), 1,
      sym_auto,
    ACTIONS(8893), 1,
      anon_sym_decltype,
    ACTIONS(8895), 1,
      anon_sym_typename,
    STATE(2897), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(3140), 1,
      sym_type_specifier,
    STATE(3530), 1,
      sym_decltype_auto,
    STATE(3541), 1,
      sym_qualified_type_identifier,
    STATE(6485), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(3351), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8879), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3532), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [183274] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8792), 1,
      anon_sym_class,
    ACTIONS(8794), 1,
      anon_sym_struct,
    ACTIONS(8796), 1,
      anon_sym_union,
    ACTIONS(8798), 1,
      sym_auto,
    ACTIONS(8800), 1,
      anon_sym_decltype,
    ACTIONS(8897), 1,
      sym_identifier,
    ACTIONS(8901), 1,
      sym_primitive_type,
    ACTIONS(8903), 1,
      anon_sym_enum,
    ACTIONS(8905), 1,
      anon_sym_typename,
    STATE(2545), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(2559), 1,
      sym_type_specifier,
    STATE(2650), 1,
      sym_decltype_auto,
    STATE(2663), 1,
      sym_qualified_type_identifier,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_dependent_type_identifier,
    STATE(2549), 2,
      sym_decltype,
      sym_template_type,
    ACTIONS(8899), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2655), 7,
      sym_sized_type_specifier,
      sym_enum_specifier,
      sym_struct_specifier,
      sym_union_specifier,
      sym_placeholder_type_specifier,
      sym_class_specifier,
      sym_dependent_type,
  [183348] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym___attribute__,
    STATE(2465), 1,
      sym_attribute_specifier,
    ACTIONS(5593), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(5591), 24,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [183389] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6928), 1,
      anon_sym_STAR,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_AMP,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(5939), 1,
      sym__declarator,
    STATE(8703), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [183456] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7404), 1,
      anon_sym_DASH_GT,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(8985), 1,
      anon_sym_requires,
    STATE(6015), 1,
      sym__function_attributes_end,
    STATE(6016), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8910), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5378), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8693), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
  [183525] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6242), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [183592] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9018), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2437), 1,
      sym__class_declaration_item,
    STATE(2709), 1,
      sym_field_declaration_list,
    STATE(5511), 1,
      sym_ms_declspec_modifier,
    STATE(6489), 1,
      sym__scope_resolution,
    STATE(6811), 1,
      sym_virtual_specifier,
    STATE(7509), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2585), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5512), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5872), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [183669] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7404), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8748), 1,
      anon_sym_requires,
    STATE(5992), 1,
      sym__function_attributes_end,
    STATE(5998), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5380), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
  [183738] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6380), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [183805] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2283), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5464), 1,
      sym_ms_declspec_modifier,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2466), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5527), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5872), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [183882] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6332), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [183949] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2605), 1,
      anon_sym_STAR,
    ACTIONS(2607), 1,
      anon_sym_AMP,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(6213), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(5718), 1,
      sym__scope_resolution,
    STATE(6295), 1,
      sym__declarator,
    STATE(8582), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [184016] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym___attribute__,
    STATE(2446), 1,
      sym_attribute_specifier,
    ACTIONS(5573), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(5571), 24,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [184057] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym___attribute__,
    STATE(2451), 1,
      sym_attribute_specifier,
    ACTIONS(5577), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(5575), 24,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [184098] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2283), 1,
      sym__class_declaration_item,
    STATE(5066), 1,
      sym_field_declaration_list,
    STATE(5501), 1,
      sym_ms_declspec_modifier,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6797), 1,
      sym_virtual_specifier,
    STATE(7519), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4867), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5521), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5872), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [184175] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6285), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [184242] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7439), 1,
      anon_sym_DASH_GT,
    ACTIONS(7441), 1,
      anon_sym_requires,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    STATE(6047), 1,
      sym__function_attributes_end,
    STATE(6144), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5375), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8693), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_GT2,
  [184311] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6293), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [184378] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2283), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5532), 1,
      sym_ms_declspec_modifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2229), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5519), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5872), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [184455] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6936), 1,
      anon_sym_STAR,
    ACTIONS(6938), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6940), 1,
      anon_sym_AMP,
    ACTIONS(6942), 1,
      anon_sym_COLON_COLON,
    STATE(5732), 1,
      sym__scope_resolution,
    STATE(6514), 1,
      sym__declarator,
    STATE(7980), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [184522] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2437), 1,
      sym__class_declaration_item,
    STATE(2709), 1,
      sym_field_declaration_list,
    STATE(5498), 1,
      sym_ms_declspec_modifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(6811), 1,
      sym_virtual_specifier,
    STATE(7509), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2585), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5499), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5872), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [184599] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym___attribute__,
    STATE(2442), 1,
      sym_attribute_specifier,
    ACTIONS(5581), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(5579), 24,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [184640] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2605), 1,
      anon_sym_STAR,
    ACTIONS(2607), 1,
      anon_sym_AMP,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(6213), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(5718), 1,
      sym__scope_resolution,
    STATE(6520), 1,
      sym__declarator,
    STATE(8582), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [184707] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(4855), 1,
      sym_field_declaration_list,
    STATE(4894), 1,
      sym__class_declaration_item,
    STATE(5436), 1,
      sym_ms_declspec_modifier,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6835), 1,
      sym_virtual_specifier,
    STATE(7667), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4579), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5482), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5872), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [184784] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6366), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [184851] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6896), 1,
      anon_sym_DASH_GT,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(8606), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(5556), 1,
      sym__function_attributes_end,
    STATE(5675), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [184914] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6247), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [184981] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7426), 1,
      anon_sym_DASH_GT,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(9020), 1,
      anon_sym_requires,
    STATE(6075), 1,
      sym__function_attributes_end,
    STATE(6165), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8910), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5382), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8693), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [185050] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7439), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8779), 1,
      anon_sym_requires,
    STATE(6064), 1,
      sym__function_attributes_end,
    STATE(6141), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5369), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_GT2,
  [185119] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7426), 1,
      anon_sym_DASH_GT,
    ACTIONS(7441), 1,
      anon_sym_requires,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(6095), 1,
      sym__function_attributes_end,
    STATE(6128), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5374), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [185188] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6896), 1,
      anon_sym_DASH_GT,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(9025), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    STATE(5539), 1,
      sym__function_attributes_end,
    STATE(5709), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5957), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [185251] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6317), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [185318] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6327), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [185385] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7439), 1,
      anon_sym_DASH_GT,
    ACTIONS(7441), 1,
      anon_sym_requires,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(6044), 1,
      sym__function_attributes_end,
    STATE(6128), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5372), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_GT2,
  [185454] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2605), 1,
      anon_sym_STAR,
    ACTIONS(2607), 1,
      anon_sym_AMP,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(6213), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(5718), 1,
      sym__scope_resolution,
    STATE(6537), 1,
      sym__declarator,
    STATE(8582), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [185521] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6306), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [185588] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6318), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [185655] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6373), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [185722] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(7134), 1,
      anon_sym_LBRACE,
    ACTIONS(8828), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9002), 1,
      sym_identifier,
    STATE(3808), 1,
      sym_template_type,
    STATE(4076), 1,
      sym_field_declaration_list,
    STATE(4131), 1,
      sym__class_declaration_item,
    STATE(5497), 1,
      sym_ms_declspec_modifier,
    STATE(6451), 1,
      sym__scope_resolution,
    STATE(6897), 1,
      sym_virtual_specifier,
    STATE(7535), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(3362), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5496), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5872), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [185799] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7426), 1,
      anon_sym_DASH_GT,
    ACTIONS(7441), 1,
      anon_sym_requires,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    STATE(6081), 1,
      sym__function_attributes_end,
    STATE(6144), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5368), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8693), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [185868] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7439), 1,
      anon_sym_DASH_GT,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(9020), 1,
      anon_sym_requires,
    STATE(6065), 1,
      sym__function_attributes_end,
    STATE(6165), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8910), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5364), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8693), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_GT2,
  [185937] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6311), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [186004] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8973), 1,
      sym_identifier,
    ACTIONS(8975), 1,
      anon_sym_COLON_COLON,
    STATE(2193), 1,
      sym_template_type,
    STATE(2283), 1,
      sym__class_declaration_item,
    STATE(5066), 1,
      sym_field_declaration_list,
    STATE(5520), 1,
      sym_ms_declspec_modifier,
    STATE(6458), 1,
      sym__scope_resolution,
    STATE(6797), 1,
      sym_virtual_specifier,
    STATE(7519), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4867), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5525), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5872), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [186081] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6253), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [186148] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(7547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    ACTIONS(8973), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(4855), 1,
      sym_field_declaration_list,
    STATE(4894), 1,
      sym__class_declaration_item,
    STATE(5522), 1,
      sym_ms_declspec_modifier,
    STATE(6475), 1,
      sym__scope_resolution,
    STATE(6835), 1,
      sym_virtual_specifier,
    STATE(7667), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4579), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5509), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5872), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [186225] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6231), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [186292] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6594), 1,
      anon_sym_LBRACE,
    ACTIONS(8877), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8994), 1,
      sym_identifier,
    STATE(3026), 1,
      sym_template_type,
    STATE(3307), 1,
      sym_field_declaration_list,
    STATE(3484), 1,
      sym__class_declaration_item,
    STATE(5489), 1,
      sym_ms_declspec_modifier,
    STATE(6485), 1,
      sym__scope_resolution,
    STATE(6821), 1,
      sym_virtual_specifier,
    STATE(7734), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2908), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5500), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5872), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [186369] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6936), 1,
      anon_sym_STAR,
    ACTIONS(6938), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6940), 1,
      anon_sym_AMP,
    ACTIONS(6942), 1,
      anon_sym_COLON_COLON,
    STATE(5732), 1,
      sym__scope_resolution,
    STATE(6535), 1,
      sym__declarator,
    STATE(7980), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [186436] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2605), 1,
      anon_sym_STAR,
    ACTIONS(2607), 1,
      anon_sym_AMP,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(6213), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(5718), 1,
      sym__scope_resolution,
    STATE(6519), 1,
      sym__declarator,
    STATE(8582), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [186503] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7426), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8779), 1,
      anon_sym_requires,
    STATE(6079), 1,
      sym__function_attributes_end,
    STATE(6141), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5373), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [186572] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7404), 1,
      anon_sym_DASH_GT,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    STATE(6028), 1,
      sym_trailing_return_type,
    STATE(6090), 1,
      sym__function_attributes_end,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5383), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8693), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
  [186641] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym___attribute__,
    STATE(2440), 1,
      sym_attribute_specifier,
    ACTIONS(5589), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(5587), 24,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [186682] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6896), 1,
      anon_sym_DASH_GT,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(8695), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    STATE(5635), 1,
      sym__function_attributes_end,
    STATE(5643), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [186745] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5817), 1,
      anon_sym_LBRACE,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8931), 1,
      sym_identifier,
    STATE(2498), 1,
      sym_template_type,
    STATE(2553), 1,
      sym_field_declaration_list,
    STATE(2595), 1,
      sym__class_declaration_item,
    STATE(5516), 1,
      sym_ms_declspec_modifier,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(6883), 1,
      sym_virtual_specifier,
    STATE(7724), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2412), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5517), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5872), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [186822] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6896), 1,
      anon_sym_DASH_GT,
    ACTIONS(8606), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8634), 1,
      anon_sym_requires,
    STATE(5548), 1,
      sym__function_attributes_end,
    STATE(5721), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8631), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [186885] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym___attribute__,
    STATE(2483), 1,
      sym_attribute_specifier,
    ACTIONS(5608), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(5606), 24,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [186926] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(7483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8483), 1,
      anon_sym_LBRACE,
    ACTIONS(9000), 1,
      sym_identifier,
    STATE(4671), 1,
      sym_template_type,
    STATE(4905), 1,
      sym_field_declaration_list,
    STATE(4993), 1,
      sym__class_declaration_item,
    STATE(5444), 1,
      sym_ms_declspec_modifier,
    STATE(6459), 1,
      sym__scope_resolution,
    STATE(6958), 1,
      sym_virtual_specifier,
    STATE(7571), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4588), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5466), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5872), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [187003] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym___attribute__,
    STATE(2448), 1,
      sym_attribute_specifier,
    ACTIONS(5569), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(5567), 24,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [187044] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6340), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [187111] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym___attribute__,
    STATE(2484), 1,
      sym_attribute_specifier,
    ACTIONS(5585), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(5583), 24,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [187152] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6344), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [187219] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6361), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [187286] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7404), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(6006), 1,
      sym_trailing_return_type,
    STATE(6089), 1,
      sym__function_attributes_end,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5377), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
    ACTIONS(8604), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
  [187355] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6296), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [187422] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6258), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [187489] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    ACTIONS(7477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8968), 1,
      sym_identifier,
    STATE(2876), 1,
      sym_field_declaration_list,
    STATE(2892), 1,
      sym_template_type,
    STATE(3006), 1,
      sym__class_declaration_item,
    STATE(5462), 1,
      sym_ms_declspec_modifier,
    STATE(6482), 1,
      sym__scope_resolution,
    STATE(6928), 1,
      sym_virtual_specifier,
    STATE(7835), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2740), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5470), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5872), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [187566] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6282), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [187633] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6425), 1,
      anon_sym_LBRACE,
    ACTIONS(8806), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8998), 1,
      sym_identifier,
    STATE(2942), 1,
      sym_template_type,
    STATE(3098), 1,
      sym_field_declaration_list,
    STATE(3313), 1,
      sym__class_declaration_item,
    STATE(5485), 1,
      sym_ms_declspec_modifier,
    STATE(6464), 1,
      sym__scope_resolution,
    STATE(6992), 1,
      sym_virtual_specifier,
    STATE(7621), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2800), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5434), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5872), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [187710] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6252), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [187777] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6299), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [187844] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2605), 1,
      anon_sym_STAR,
    ACTIONS(2607), 1,
      anon_sym_AMP,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(6213), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(5718), 1,
      sym__scope_resolution,
    STATE(6542), 1,
      sym__declarator,
    STATE(8582), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [187911] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6962), 1,
      anon_sym_STAR,
    ACTIONS(6964), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6966), 1,
      anon_sym_AMP,
    ACTIONS(6968), 1,
      anon_sym_COLON_COLON,
    STATE(5741), 1,
      sym__scope_resolution,
    STATE(6496), 1,
      sym__declarator,
    STATE(7905), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [187978] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6355), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [188045] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym___attribute__,
    STATE(2456), 1,
      sym_attribute_specifier,
    ACTIONS(5616), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(5614), 24,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [188086] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6896), 1,
      anon_sym_DASH_GT,
    ACTIONS(9025), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    ACTIONS(9033), 1,
      anon_sym_requires,
    STATE(5561), 1,
      sym__function_attributes_end,
    STATE(5708), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9030), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5957), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [188149] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym___attribute__,
    STATE(2450), 1,
      sym_attribute_specifier,
    ACTIONS(5601), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(5599), 24,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [188190] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6295), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [188257] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(29), 1,
      anon_sym_AMP_AMP,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2605), 1,
      anon_sym_STAR,
    ACTIONS(2607), 1,
      anon_sym_AMP,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4979), 1,
      sym_identifier,
    ACTIONS(6213), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    STATE(5718), 1,
      sym__scope_resolution,
    STATE(6553), 1,
      sym__declarator,
    STATE(8582), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [188324] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6321), 1,
      anon_sym_LBRACE,
    ACTIONS(8850), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8996), 1,
      sym_identifier,
    STATE(2883), 1,
      sym_template_type,
    STATE(3038), 1,
      sym_field_declaration_list,
    STATE(3216), 1,
      sym__class_declaration_item,
    STATE(5457), 1,
      sym_ms_declspec_modifier,
    STATE(6486), 1,
      sym__scope_resolution,
    STATE(6791), 1,
      sym_virtual_specifier,
    STATE(7603), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2753), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5456), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5872), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [188401] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6265), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [188468] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4078), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8983), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2283), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(5448), 1,
      sym_ms_declspec_modifier,
    STATE(6449), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2229), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5435), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5872), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [188545] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    ACTIONS(8753), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9007), 1,
      sym_identifier,
    STATE(2876), 1,
      sym_field_declaration_list,
    STATE(2892), 1,
      sym_template_type,
    STATE(3006), 1,
      sym__class_declaration_item,
    STATE(5454), 1,
      sym_ms_declspec_modifier,
    STATE(6505), 1,
      sym__scope_resolution,
    STATE(6928), 1,
      sym_virtual_specifier,
    STATE(7835), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(2740), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5460), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5872), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [188622] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4987), 1,
      anon_sym___attribute__,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(4993), 1,
      anon_sym___declspec,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2437), 1,
      sym__class_declaration_item,
    STATE(5295), 1,
      sym_field_declaration_list,
    STATE(5483), 1,
      sym_ms_declspec_modifier,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(6989), 1,
      sym_virtual_specifier,
    STATE(7581), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(4995), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4750), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5491), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5872), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
  [188699] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5889), 1,
      sym_identifier,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6962), 1,
      anon_sym_STAR,
    ACTIONS(6964), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6966), 1,
      anon_sym_AMP,
    ACTIONS(6968), 1,
      anon_sym_COLON_COLON,
    STATE(5741), 1,
      sym__scope_resolution,
    STATE(6427), 1,
      sym__declarator,
    STATE(7905), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [188766] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6238), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [188833] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym___attribute__,
    STATE(2477), 1,
      sym_attribute_specifier,
    ACTIONS(5612), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(5610), 24,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [188874] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6323), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [188941] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(6896), 1,
      anon_sym_DASH_GT,
    ACTIONS(8695), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(8703), 1,
      anon_sym_requires,
    STATE(5551), 1,
      sym__function_attributes_end,
    STATE(5711), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8700), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [189004] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym___attribute__,
    STATE(2434), 1,
      sym_attribute_specifier,
    ACTIONS(5597), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(5595), 24,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [189045] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2601), 1,
      anon_sym_LPAREN2,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6934), 1,
      anon_sym_LBRACK,
    ACTIONS(6944), 1,
      sym_identifier,
    ACTIONS(6946), 1,
      anon_sym_STAR,
    ACTIONS(6948), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6950), 1,
      anon_sym_AMP,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(6305), 1,
      sym__declarator,
    STATE(7935), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(6270), 11,
      sym_parenthesized_declarator,
      sym_attributed_declarator,
      sym_pointer_declarator,
      sym_function_declarator,
      sym_array_declarator,
      sym_reference_declarator,
      sym_structured_binding_declarator,
      sym_template_function,
      sym_destructor_name,
      sym_qualified_identifier,
      sym_operator_name,
  [189112] = 7,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1957), 1,
      sym_alignas_qualifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(9038), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(9036), 8,
      anon_sym_AMP,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_primitive_type,
      sym_identifier,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [189156] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(5075), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(5320), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(9040), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    ACTIONS(5318), 20,
      anon_sym_AMP,
      anon_sym___extension__,
      anon_sym___based,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_primitive_type,
      sym_identifier,
      sym_auto,
      anon_sym_decltype,
  [189196] = 7,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1957), 1,
      sym_alignas_qualifier,
    ACTIONS(65), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    STATE(4656), 2,
      sym_type_qualifier,
      aux_sym__type_definition_type_repeat1,
    ACTIONS(9045), 3,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
    ACTIONS(9043), 8,
      anon_sym_AMP,
      anon_sym___based,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
      sym_primitive_type,
      sym_identifier,
    ACTIONS(63), 12,
      anon_sym___extension__,
      anon_sym_const,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
  [189240] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7073), 1,
      anon_sym_DASH_GT,
    ACTIONS(8695), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(8703), 1,
      anon_sym_requires,
    ACTIONS(8870), 1,
      anon_sym___attribute__,
    STATE(5692), 1,
      sym__function_attributes_end,
    STATE(5711), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8700), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [189301] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(7073), 1,
      anon_sym_DASH_GT,
    ACTIONS(9025), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    ACTIONS(9047), 1,
      anon_sym___attribute__,
    STATE(5651), 1,
      sym__function_attributes_end,
    STATE(5709), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5957), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [189362] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7073), 1,
      anon_sym_DASH_GT,
    ACTIONS(8606), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8634), 1,
      anon_sym_requires,
    ACTIONS(8675), 1,
      anon_sym___attribute__,
    STATE(5689), 1,
      sym__function_attributes_end,
    STATE(5721), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8631), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [189423] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7073), 1,
      anon_sym_DASH_GT,
    ACTIONS(9025), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    ACTIONS(9033), 1,
      anon_sym_requires,
    ACTIONS(9047), 1,
      anon_sym___attribute__,
    STATE(5698), 1,
      sym__function_attributes_end,
    STATE(5708), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9030), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5957), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [189484] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1971), 1,
      anon_sym_LBRACE,
    ACTIONS(5318), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5320), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [189523] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(7073), 1,
      anon_sym_DASH_GT,
    ACTIONS(8606), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8675), 1,
      anon_sym___attribute__,
    STATE(5664), 1,
      sym__function_attributes_end,
    STATE(5675), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [189584] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7562), 1,
      anon_sym_DASH_GT,
    ACTIONS(7564), 1,
      anon_sym_requires,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(9050), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6180), 1,
      sym__function_attributes_end,
    STATE(6269), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8693), 2,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5424), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [189651] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7562), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8959), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9004), 1,
      anon_sym_requires,
    STATE(6171), 1,
      sym__function_attributes_end,
    STATE(6379), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8604), 2,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    ACTIONS(8631), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5419), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [189718] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5153), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5155), 25,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [189753] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7562), 1,
      anon_sym_DASH_GT,
    ACTIONS(7564), 1,
      anon_sym_requires,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8959), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6178), 1,
      sym__function_attributes_end,
    STATE(6237), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8604), 2,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5389), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [189820] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2849), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(2851), 25,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym___extension__,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [189855] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6901), 1,
      anon_sym_noexcept,
    ACTIONS(6903), 1,
      anon_sym_throw,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7562), 1,
      anon_sym_DASH_GT,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(9050), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9053), 1,
      anon_sym_requires,
    STATE(6135), 1,
      sym__function_attributes_end,
    STATE(6245), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8693), 2,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    ACTIONS(8700), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    STATE(5421), 3,
      sym__function_exception_specification,
      sym_noexcept,
      sym_throw_specifier,
  [189922] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(7073), 1,
      anon_sym_DASH_GT,
    ACTIONS(8695), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(8870), 1,
      anon_sym___attribute__,
    STATE(5643), 1,
      sym_trailing_return_type,
    STATE(5652), 1,
      sym__function_attributes_end,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [189983] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7138), 1,
      anon_sym_DASH_GT,
    ACTIONS(7142), 1,
      anon_sym_requires,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    STATE(5806), 1,
      sym_trailing_return_type,
    STATE(5846), 1,
      sym__function_attributes_end,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT2,
  [190043] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(5728), 1,
      sym_ms_call_modifier,
    STATE(6580), 1,
      sym__type_declarator,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(51), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
  [190101] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(5729), 1,
      sym_ms_call_modifier,
    STATE(6591), 1,
      sym__type_declarator,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(51), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
  [190159] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7138), 1,
      anon_sym_DASH_GT,
    ACTIONS(7142), 1,
      anon_sym_requires,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    STATE(5828), 1,
      sym_trailing_return_type,
    STATE(5883), 1,
      sym__function_attributes_end,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT2,
  [190219] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7138), 1,
      anon_sym_DASH_GT,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(8913), 1,
      anon_sym_requires,
    STATE(5774), 1,
      sym_trailing_return_type,
    STATE(5866), 1,
      sym__function_attributes_end,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8910), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT2,
  [190279] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7083), 1,
      anon_sym_DASH_GT,
    ACTIONS(7269), 1,
      anon_sym_requires,
    ACTIONS(8695), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    STATE(5792), 1,
      sym__function_attributes_end,
    STATE(5931), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [190339] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7138), 1,
      anon_sym_DASH_GT,
    ACTIONS(7142), 1,
      anon_sym_requires,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(5809), 1,
      sym_trailing_return_type,
    STATE(5873), 1,
      sym__function_attributes_end,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT2,
  [190399] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9056), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6080), 10,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_GT2,
    ACTIONS(6078), 13,
      anon_sym_COLON,
      anon_sym_LBRACK,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      sym_virtual,
      anon_sym_template,
      anon_sym_try,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
      anon_sym_requires,
  [190437] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7083), 1,
      anon_sym_DASH_GT,
    ACTIONS(7269), 1,
      anon_sym_requires,
    ACTIONS(9025), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    STATE(5796), 1,
      sym__function_attributes_end,
    STATE(5946), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5957), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [190497] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7138), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8720), 1,
      anon_sym_requires,
    STATE(5783), 1,
      sym_trailing_return_type,
    STATE(5853), 1,
      sym__function_attributes_end,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT2,
  [190557] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7083), 1,
      anon_sym_DASH_GT,
    ACTIONS(7269), 1,
      anon_sym_requires,
    ACTIONS(8606), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(5798), 1,
      sym__function_attributes_end,
    STATE(5904), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [190617] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(5669), 1,
      sym_ms_call_modifier,
    STATE(6586), 1,
      sym__type_declarator,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(51), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
  [190675] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7083), 1,
      anon_sym_DASH_GT,
    ACTIONS(8606), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8723), 1,
      anon_sym_requires,
    STATE(5830), 1,
      sym__function_attributes_end,
    STATE(5976), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8631), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [190735] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1971), 1,
      anon_sym_LBRACE,
    ACTIONS(5318), 2,
      anon_sym_AMP,
      anon_sym_const,
    ACTIONS(5320), 23,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym___extension__,
      anon_sym_LBRACK,
      anon_sym_constexpr,
      anon_sym_volatile,
      anon_sym_restrict,
      anon_sym___restrict__,
      anon_sym__Atomic,
      anon_sym__Noreturn,
      anon_sym_noreturn,
      anon_sym_mutable,
      anon_sym_constinit,
      anon_sym_consteval,
      anon_sym_alignas,
      anon_sym__Alignas,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [190771] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7083), 1,
      anon_sym_DASH_GT,
    ACTIONS(8695), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(8926), 1,
      anon_sym_requires,
    STATE(5835), 1,
      sym__function_attributes_end,
    STATE(5985), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8700), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [190831] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7083), 1,
      anon_sym_DASH_GT,
    ACTIONS(9025), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    ACTIONS(9059), 1,
      anon_sym_requires,
    STATE(5837), 1,
      sym__function_attributes_end,
    STATE(5885), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9030), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5957), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [190891] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(5690), 1,
      sym_ms_call_modifier,
    STATE(6614), 1,
      sym__type_declarator,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
    ACTIONS(51), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
  [190949] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7138), 1,
      anon_sym_DASH_GT,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    ACTIONS(9065), 1,
      anon_sym_requires,
    STATE(5771), 1,
      sym_trailing_return_type,
    STATE(5867), 1,
      sym__function_attributes_end,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9062), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT2,
  [191009] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7330), 1,
      anon_sym_DASH_GT,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    STATE(5906), 1,
      sym__function_attributes_end,
    STATE(6028), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [191068] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7142), 1,
      anon_sym_requires,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(5809), 1,
      sym_trailing_return_type,
    STATE(5950), 1,
      sym__function_attributes_end,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [191127] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(8913), 1,
      anon_sym_requires,
    STATE(5774), 1,
      sym_trailing_return_type,
    STATE(5948), 1,
      sym__function_attributes_end,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8910), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [191186] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(8753), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9007), 1,
      sym_identifier,
    ACTIONS(9068), 1,
      anon_sym_LPAREN2,
    ACTIONS(9070), 1,
      anon_sym_LBRACE,
    ACTIONS(9074), 1,
      anon_sym_requires,
    STATE(2892), 1,
      sym_template_type,
    STATE(4288), 1,
      sym_requirement_seq,
    STATE(5812), 1,
      sym_lambda_capture_specifier,
    STATE(6505), 1,
      sym__scope_resolution,
    STATE(7736), 1,
      sym_requires_parameter_list,
    ACTIONS(9072), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(4841), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [191247] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7330), 1,
      anon_sym_DASH_GT,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(8985), 1,
      anon_sym_requires,
    STATE(5977), 1,
      sym__function_attributes_end,
    STATE(6016), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8910), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [191306] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7142), 1,
      anon_sym_requires,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    STATE(5828), 1,
      sym_trailing_return_type,
    STATE(5961), 1,
      sym__function_attributes_end,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [191365] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7330), 1,
      anon_sym_DASH_GT,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    ACTIONS(9076), 1,
      anon_sym_requires,
    STATE(5968), 1,
      sym__function_attributes_end,
    STATE(6019), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9062), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [191424] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7330), 1,
      anon_sym_DASH_GT,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    STATE(5923), 1,
      sym__function_attributes_end,
    STATE(6066), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [191483] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7330), 1,
      anon_sym_DASH_GT,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(5888), 1,
      sym__function_attributes_end,
    STATE(6006), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [191542] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7408), 1,
      anon_sym_STAR,
    ACTIONS(7410), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7412), 1,
      anon_sym_AMP,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    STATE(3122), 1,
      sym_parameter_list,
    STATE(5870), 1,
      sym__abstract_declarator,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7759), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [191591] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    ACTIONS(9065), 1,
      anon_sym_requires,
    STATE(5771), 1,
      sym_trailing_return_type,
    STATE(5964), 1,
      sym__function_attributes_end,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9062), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [191650] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(8877), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8994), 1,
      sym_identifier,
    ACTIONS(9079), 1,
      anon_sym_LPAREN2,
    ACTIONS(9081), 1,
      anon_sym_LBRACE,
    ACTIONS(9085), 1,
      anon_sym_requires,
    STATE(3026), 1,
      sym_template_type,
    STATE(3864), 1,
      sym_requirement_seq,
    STATE(5825), 1,
      sym_lambda_capture_specifier,
    STATE(6485), 1,
      sym__scope_resolution,
    STATE(7832), 1,
      sym_requires_parameter_list,
    ACTIONS(9083), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(3869), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [191711] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8720), 1,
      anon_sym_requires,
    STATE(5783), 1,
      sym_trailing_return_type,
    STATE(5889), 1,
      sym__function_attributes_end,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [191770] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7330), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8748), 1,
      anon_sym_requires,
    STATE(5942), 1,
      sym__function_attributes_end,
    STATE(5998), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [191829] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8931), 1,
      sym_identifier,
    ACTIONS(9087), 1,
      anon_sym_LPAREN2,
    ACTIONS(9089), 1,
      anon_sym_LBRACE,
    ACTIONS(9093), 1,
      anon_sym_requires,
    STATE(2498), 1,
      sym_template_type,
    STATE(2780), 1,
      sym_requirement_seq,
    STATE(5822), 1,
      sym_lambda_capture_specifier,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(7613), 1,
      sym_requires_parameter_list,
    ACTIONS(9091), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(2783), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [191890] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(8806), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8998), 1,
      sym_identifier,
    ACTIONS(9095), 1,
      anon_sym_LPAREN2,
    ACTIONS(9097), 1,
      anon_sym_LBRACE,
    ACTIONS(9101), 1,
      anon_sym_requires,
    STATE(2942), 1,
      sym_template_type,
    STATE(3770), 1,
      sym_requirement_seq,
    STATE(5813), 1,
      sym_lambda_capture_specifier,
    STATE(6464), 1,
      sym__scope_resolution,
    STATE(7730), 1,
      sym_requires_parameter_list,
    ACTIONS(9099), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(3718), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [191951] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(8828), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9002), 1,
      sym_identifier,
    ACTIONS(9103), 1,
      anon_sym_LPAREN2,
    ACTIONS(9105), 1,
      anon_sym_LBRACE,
    ACTIONS(9109), 1,
      anon_sym_requires,
    STATE(3606), 1,
      sym_requirement_seq,
    STATE(3808), 1,
      sym_template_type,
    STATE(5823), 1,
      sym_lambda_capture_specifier,
    STATE(6451), 1,
      sym__scope_resolution,
    STATE(7602), 1,
      sym_requires_parameter_list,
    ACTIONS(9107), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(4248), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [192012] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7142), 1,
      anon_sym_requires,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    STATE(5806), 1,
      sym_trailing_return_type,
    STATE(5980), 1,
      sym__function_attributes_end,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 5,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [192071] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9018), 1,
      sym_identifier,
    ACTIONS(9103), 1,
      anon_sym_LPAREN2,
    ACTIONS(9105), 1,
      anon_sym_LBRACE,
    ACTIONS(9109), 1,
      anon_sym_requires,
    STATE(2419), 1,
      sym_template_type,
    STATE(3606), 1,
      sym_requirement_seq,
    STATE(5823), 1,
      sym_lambda_capture_specifier,
    STATE(6489), 1,
      sym__scope_resolution,
    STATE(7602), 1,
      sym_requires_parameter_list,
    ACTIONS(9111), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(4241), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [192132] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(8850), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8996), 1,
      sym_identifier,
    ACTIONS(9113), 1,
      anon_sym_LPAREN2,
    ACTIONS(9115), 1,
      anon_sym_LBRACE,
    ACTIONS(9119), 1,
      anon_sym_requires,
    STATE(2883), 1,
      sym_template_type,
    STATE(3527), 1,
      sym_requirement_seq,
    STATE(5838), 1,
      sym_lambda_capture_specifier,
    STATE(6486), 1,
      sym__scope_resolution,
    STATE(7524), 1,
      sym_requires_parameter_list,
    ACTIONS(9117), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(3526), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [192193] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7439), 1,
      anon_sym_DASH_GT,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    ACTIONS(9121), 1,
      anon_sym_requires,
    STATE(6067), 1,
      sym__function_attributes_end,
    STATE(6168), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9062), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_GT2,
  [192251] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7404), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(6006), 1,
      sym_trailing_return_type,
    STATE(6089), 1,
      sym__function_attributes_end,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
  [192309] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(7853), 1,
      sym_identifier,
    ACTIONS(7855), 1,
      anon_sym_LPAREN2,
    ACTIONS(7857), 1,
      anon_sym_STAR,
    ACTIONS(7859), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7861), 1,
      anon_sym_AMP,
    STATE(5831), 1,
      sym_ms_call_modifier,
    STATE(6538), 1,
      sym__field_declarator,
    STATE(6623), 1,
      sym_operator_name,
    STATE(8364), 1,
      sym_ms_based_modifier,
    ACTIONS(2034), 6,
      anon_sym___cdecl,
      anon_sym___clrcall,
      anon_sym___stdcall,
      anon_sym___fastcall,
      anon_sym___thiscall,
      anon_sym___vectorcall,
    STATE(6289), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
  [192363] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7463), 1,
      anon_sym_STAR,
    ACTIONS(7465), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7467), 1,
      anon_sym_AMP,
    STATE(3299), 1,
      sym_parameter_list,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(5953), 1,
      sym__abstract_declarator,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7759), 11,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [192411] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7426), 1,
      anon_sym_DASH_GT,
    ACTIONS(7441), 1,
      anon_sym_requires,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    STATE(6034), 1,
      sym__function_attributes_end,
    STATE(6170), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [192469] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7439), 1,
      anon_sym_DASH_GT,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(9020), 1,
      anon_sym_requires,
    STATE(6065), 1,
      sym__function_attributes_end,
    STATE(6165), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8910), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_GT2,
  [192527] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7439), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8779), 1,
      anon_sym_requires,
    STATE(6064), 1,
      sym__function_attributes_end,
    STATE(6141), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_GT2,
  [192585] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7426), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8779), 1,
      anon_sym_requires,
    STATE(6079), 1,
      sym__function_attributes_end,
    STATE(6141), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [192643] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7439), 1,
      anon_sym_DASH_GT,
    ACTIONS(7441), 1,
      anon_sym_requires,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    STATE(6047), 1,
      sym__function_attributes_end,
    STATE(6144), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_GT2,
  [192701] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7426), 1,
      anon_sym_DASH_GT,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(9020), 1,
      anon_sym_requires,
    STATE(6075), 1,
      sym__function_attributes_end,
    STATE(6165), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8910), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [192759] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7426), 1,
      anon_sym_DASH_GT,
    ACTIONS(7441), 1,
      anon_sym_requires,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    STATE(6081), 1,
      sym__function_attributes_end,
    STATE(6144), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [192817] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7439), 1,
      anon_sym_DASH_GT,
    ACTIONS(7441), 1,
      anon_sym_requires,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    STATE(6050), 1,
      sym__function_attributes_end,
    STATE(6170), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_GT2,
  [192875] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7404), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8748), 1,
      anon_sym_requires,
    STATE(5992), 1,
      sym__function_attributes_end,
    STATE(5998), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
  [192933] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7404), 1,
      anon_sym_DASH_GT,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    STATE(6028), 1,
      sym_trailing_return_type,
    STATE(6090), 1,
      sym__function_attributes_end,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
  [192991] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7404), 1,
      anon_sym_DASH_GT,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    ACTIONS(9076), 1,
      anon_sym_requires,
    STATE(6019), 1,
      sym_trailing_return_type,
    STATE(6032), 1,
      sym__function_attributes_end,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9062), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
  [193049] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7426), 1,
      anon_sym_DASH_GT,
    ACTIONS(7441), 1,
      anon_sym_requires,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(6095), 1,
      sym__function_attributes_end,
    STATE(6128), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [193107] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7404), 1,
      anon_sym_DASH_GT,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(8985), 1,
      anon_sym_requires,
    STATE(6015), 1,
      sym__function_attributes_end,
    STATE(6016), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8910), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
  [193165] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7439), 1,
      anon_sym_DASH_GT,
    ACTIONS(7441), 1,
      anon_sym_requires,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(6044), 1,
      sym__function_attributes_end,
    STATE(6128), 1,
      sym_trailing_return_type,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_GT2,
  [193223] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7426), 1,
      anon_sym_DASH_GT,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    ACTIONS(9121), 1,
      anon_sym_requires,
    STATE(6037), 1,
      sym__function_attributes_end,
    STATE(6168), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9062), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 4,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_GT2,
  [193281] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7404), 1,
      anon_sym_DASH_GT,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    STATE(6066), 1,
      sym_trailing_return_type,
    STATE(6092), 1,
      sym__function_attributes_end,
    STATE(6646), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5562), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
  [193339] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9126), 1,
      anon_sym_COLON,
    ACTIONS(9128), 1,
      anon_sym_SEMI,
    ACTIONS(9130), 1,
      anon_sym_LBRACE,
    ACTIONS(9132), 1,
      anon_sym_LBRACK,
    ACTIONS(9134), 1,
      anon_sym_EQ,
    ACTIONS(9136), 1,
      anon_sym_try,
    STATE(2097), 1,
      sym_try_statement,
    STATE(2098), 1,
      sym_pure_virtual_clause,
    STATE(2099), 1,
      sym_delete_method_clause,
    STATE(2100), 1,
      sym_default_method_clause,
    STATE(2101), 1,
      sym_compound_statement,
    STATE(3346), 1,
      sym_parameter_list,
    STATE(6281), 1,
      sym__function_declarator_seq,
    STATE(6716), 1,
      aux_sym_field_declaration_repeat1,
    STATE(6717), 1,
      sym_initializer_list,
    STATE(6721), 1,
      sym_bitfield_clause,
    STATE(8091), 1,
      sym_attribute_specifier,
    STATE(6208), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [193410] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9126), 1,
      anon_sym_COLON,
    ACTIONS(9132), 1,
      anon_sym_LBRACK,
    ACTIONS(9138), 1,
      anon_sym_SEMI,
    ACTIONS(9140), 1,
      anon_sym_LBRACE,
    ACTIONS(9142), 1,
      anon_sym_EQ,
    ACTIONS(9144), 1,
      anon_sym_try,
    STATE(1870), 1,
      sym_try_statement,
    STATE(1871), 1,
      sym_pure_virtual_clause,
    STATE(1872), 1,
      sym_delete_method_clause,
    STATE(1873), 1,
      sym_default_method_clause,
    STATE(1875), 1,
      sym_compound_statement,
    STATE(3346), 1,
      sym_parameter_list,
    STATE(6281), 1,
      sym__function_declarator_seq,
    STATE(6674), 1,
      sym_initializer_list,
    STATE(6675), 1,
      sym_bitfield_clause,
    STATE(6678), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8329), 1,
      sym_attribute_specifier,
    STATE(6208), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [193481] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9126), 1,
      anon_sym_COLON,
    ACTIONS(9132), 1,
      anon_sym_LBRACK,
    ACTIONS(9146), 1,
      anon_sym_SEMI,
    ACTIONS(9148), 1,
      anon_sym_LBRACE,
    ACTIONS(9150), 1,
      anon_sym_EQ,
    ACTIONS(9152), 1,
      anon_sym_try,
    STATE(2015), 1,
      sym_compound_statement,
    STATE(2016), 1,
      sym_default_method_clause,
    STATE(2017), 1,
      sym_delete_method_clause,
    STATE(2018), 1,
      sym_pure_virtual_clause,
    STATE(2022), 1,
      sym_try_statement,
    STATE(3346), 1,
      sym_parameter_list,
    STATE(6281), 1,
      sym__function_declarator_seq,
    STATE(6705), 1,
      aux_sym_field_declaration_repeat1,
    STATE(6710), 1,
      sym_initializer_list,
    STATE(6712), 1,
      sym_bitfield_clause,
    STATE(8171), 1,
      sym_attribute_specifier,
    STATE(6208), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [193552] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    ACTIONS(9109), 1,
      anon_sym_requires,
    ACTIONS(9154), 1,
      anon_sym_LPAREN2,
    STATE(2419), 1,
      sym_template_type,
    STATE(5823), 1,
      sym_lambda_capture_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    ACTIONS(9156), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5849), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [193604] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(7547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8973), 1,
      sym_identifier,
    ACTIONS(9158), 1,
      anon_sym_LPAREN2,
    ACTIONS(9162), 1,
      anon_sym_requires,
    STATE(2193), 1,
      sym_template_type,
    STATE(5811), 1,
      sym_lambda_capture_specifier,
    STATE(6475), 1,
      sym__scope_resolution,
    ACTIONS(9160), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5719), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [193656] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7562), 1,
      anon_sym_DASH_GT,
    ACTIONS(7564), 1,
      anon_sym_requires,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(9050), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6180), 1,
      sym__function_attributes_end,
    STATE(6269), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8693), 2,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
  [193712] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(7477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8968), 1,
      sym_identifier,
    ACTIONS(9074), 1,
      anon_sym_requires,
    ACTIONS(9164), 1,
      anon_sym_LPAREN2,
    STATE(2892), 1,
      sym_template_type,
    STATE(5812), 1,
      sym_lambda_capture_specifier,
    STATE(6482), 1,
      sym__scope_resolution,
    ACTIONS(9166), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6169), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [193764] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(8828), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9002), 1,
      sym_identifier,
    ACTIONS(9109), 1,
      anon_sym_requires,
    ACTIONS(9154), 1,
      anon_sym_LPAREN2,
    STATE(3808), 1,
      sym_template_type,
    STATE(5823), 1,
      sym_lambda_capture_specifier,
    STATE(6451), 1,
      sym__scope_resolution,
    ACTIONS(9168), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(4251), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [193816] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(8828), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9002), 1,
      sym_identifier,
    ACTIONS(9109), 1,
      anon_sym_requires,
    ACTIONS(9154), 1,
      anon_sym_LPAREN2,
    STATE(3808), 1,
      sym_template_type,
    STATE(5823), 1,
      sym_lambda_capture_specifier,
    STATE(6451), 1,
      sym__scope_resolution,
    ACTIONS(9170), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(3561), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [193868] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7562), 1,
      anon_sym_DASH_GT,
    ACTIONS(7564), 1,
      anon_sym_requires,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8959), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6178), 1,
      sym__function_attributes_end,
    STATE(6237), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8604), 2,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
  [193924] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    ACTIONS(9158), 1,
      anon_sym_LPAREN2,
    ACTIONS(9162), 1,
      anon_sym_requires,
    STATE(2193), 1,
      sym_template_type,
    STATE(5811), 1,
      sym_lambda_capture_specifier,
    STATE(6479), 1,
      sym__scope_resolution,
    ACTIONS(9172), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5893), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [193976] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(8753), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9007), 1,
      sym_identifier,
    ACTIONS(9074), 1,
      anon_sym_requires,
    ACTIONS(9164), 1,
      anon_sym_LPAREN2,
    STATE(2892), 1,
      sym_template_type,
    STATE(5812), 1,
      sym_lambda_capture_specifier,
    STATE(6505), 1,
      sym__scope_resolution,
    ACTIONS(9174), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(4305), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [194028] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(8753), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9007), 1,
      sym_identifier,
    ACTIONS(9074), 1,
      anon_sym_requires,
    ACTIONS(9164), 1,
      anon_sym_LPAREN2,
    STATE(2892), 1,
      sym_template_type,
    STATE(5812), 1,
      sym_lambda_capture_specifier,
    STATE(6505), 1,
      sym__scope_resolution,
    ACTIONS(9176), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(4757), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [194080] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(7547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8973), 1,
      sym_identifier,
    ACTIONS(9158), 1,
      anon_sym_LPAREN2,
    ACTIONS(9162), 1,
      anon_sym_requires,
    STATE(2193), 1,
      sym_template_type,
    STATE(5811), 1,
      sym_lambda_capture_specifier,
    STATE(6475), 1,
      sym__scope_resolution,
    ACTIONS(9178), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5700), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [194132] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    ACTIONS(9109), 1,
      anon_sym_requires,
    ACTIONS(9154), 1,
      anon_sym_LPAREN2,
    STATE(2419), 1,
      sym_template_type,
    STATE(5823), 1,
      sym_lambda_capture_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    ACTIONS(9170), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(3561), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [194184] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(8929), 1,
      sym_identifier,
    ACTIONS(9180), 1,
      anon_sym_LPAREN2,
    ACTIONS(9184), 1,
      anon_sym_requires,
    STATE(2193), 1,
      sym_template_type,
    STATE(5800), 1,
      sym_lambda_capture_specifier,
    STATE(6504), 1,
      sym__scope_resolution,
    ACTIONS(9182), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6339), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [194236] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(7477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8968), 1,
      sym_identifier,
    ACTIONS(9074), 1,
      anon_sym_requires,
    ACTIONS(9164), 1,
      anon_sym_LPAREN2,
    STATE(2892), 1,
      sym_template_type,
    STATE(5812), 1,
      sym_lambda_capture_specifier,
    STATE(6482), 1,
      sym__scope_resolution,
    ACTIONS(9186), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6124), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [194288] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(7547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8973), 1,
      sym_identifier,
    ACTIONS(9158), 1,
      anon_sym_LPAREN2,
    ACTIONS(9162), 1,
      anon_sym_requires,
    STATE(2193), 1,
      sym_template_type,
    STATE(5811), 1,
      sym_lambda_capture_specifier,
    STATE(6475), 1,
      sym__scope_resolution,
    ACTIONS(9188), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5720), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [194340] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(7477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8968), 1,
      sym_identifier,
    ACTIONS(9074), 1,
      anon_sym_requires,
    ACTIONS(9164), 1,
      anon_sym_LPAREN2,
    STATE(2892), 1,
      sym_template_type,
    STATE(5812), 1,
      sym_lambda_capture_specifier,
    STATE(6482), 1,
      sym__scope_resolution,
    ACTIONS(9174), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(4305), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [194392] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(8806), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8998), 1,
      sym_identifier,
    ACTIONS(9101), 1,
      anon_sym_requires,
    ACTIONS(9190), 1,
      anon_sym_LPAREN2,
    STATE(2942), 1,
      sym_template_type,
    STATE(5813), 1,
      sym_lambda_capture_specifier,
    STATE(6464), 1,
      sym__scope_resolution,
    ACTIONS(9192), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(3699), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [194444] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(8806), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8998), 1,
      sym_identifier,
    ACTIONS(9101), 1,
      anon_sym_requires,
    ACTIONS(9190), 1,
      anon_sym_LPAREN2,
    STATE(2942), 1,
      sym_template_type,
    STATE(5813), 1,
      sym_lambda_capture_specifier,
    STATE(6464), 1,
      sym__scope_resolution,
    ACTIONS(9194), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(3700), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [194496] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(8850), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8996), 1,
      sym_identifier,
    ACTIONS(9119), 1,
      anon_sym_requires,
    ACTIONS(9196), 1,
      anon_sym_LPAREN2,
    STATE(2883), 1,
      sym_template_type,
    STATE(5838), 1,
      sym_lambda_capture_specifier,
    STATE(6486), 1,
      sym__scope_resolution,
    ACTIONS(9198), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(3556), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [194548] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(9180), 1,
      anon_sym_LPAREN2,
    ACTIONS(9184), 1,
      anon_sym_requires,
    ACTIONS(9200), 1,
      sym_identifier,
    ACTIONS(9202), 1,
      anon_sym_COLON_COLON,
    STATE(2194), 1,
      sym_template_type,
    STATE(5764), 1,
      sym_lambda_capture_specifier,
    STATE(6501), 1,
      sym__scope_resolution,
    ACTIONS(9204), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(1961), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [194600] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(7483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9000), 1,
      sym_identifier,
    ACTIONS(9206), 1,
      anon_sym_LPAREN2,
    ACTIONS(9210), 1,
      anon_sym_requires,
    STATE(4671), 1,
      sym_template_type,
    STATE(5765), 1,
      sym_lambda_capture_specifier,
    STATE(6459), 1,
      sym__scope_resolution,
    ACTIONS(9208), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5762), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [194652] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8931), 1,
      sym_identifier,
    ACTIONS(9093), 1,
      anon_sym_requires,
    ACTIONS(9212), 1,
      anon_sym_LPAREN2,
    STATE(2498), 1,
      sym_template_type,
    STATE(5822), 1,
      sym_lambda_capture_specifier,
    STATE(6497), 1,
      sym__scope_resolution,
    ACTIONS(9214), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(2791), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [194704] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(131), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2613), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(9216), 1,
      sym_identifier,
    ACTIONS(9218), 1,
      anon_sym_template,
    STATE(2199), 1,
      sym_dependent_type_identifier,
    STATE(2205), 1,
      sym_template_type,
    STATE(2228), 1,
      sym_qualified_type_identifier,
    STATE(3063), 1,
      sym_operator_name,
    STATE(3064), 1,
      sym_qualified_identifier,
    STATE(3065), 1,
      sym_dependent_identifier,
    STATE(3072), 1,
      sym_destructor_name,
    STATE(3076), 1,
      sym_template_function,
    STATE(3078), 1,
      sym_pointer_type_declarator,
    STATE(5409), 1,
      sym__scope_resolution,
    STATE(6726), 1,
      sym_operator_cast,
    STATE(6825), 1,
      sym_qualified_operator_cast_identifier,
    STATE(8209), 1,
      sym_ms_based_modifier,
    STATE(8571), 1,
      sym_decltype,
  [194774] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8931), 1,
      sym_identifier,
    ACTIONS(9093), 1,
      anon_sym_requires,
    ACTIONS(9212), 1,
      anon_sym_LPAREN2,
    STATE(2498), 1,
      sym_template_type,
    STATE(5822), 1,
      sym_lambda_capture_specifier,
    STATE(6497), 1,
      sym__scope_resolution,
    ACTIONS(9220), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(2762), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [194826] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    ACTIONS(9109), 1,
      anon_sym_requires,
    ACTIONS(9154), 1,
      anon_sym_LPAREN2,
    STATE(2419), 1,
      sym_template_type,
    STATE(5823), 1,
      sym_lambda_capture_specifier,
    STATE(6441), 1,
      sym__scope_resolution,
    ACTIONS(9222), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5876), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [194878] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(7483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9000), 1,
      sym_identifier,
    ACTIONS(9206), 1,
      anon_sym_LPAREN2,
    ACTIONS(9210), 1,
      anon_sym_requires,
    STATE(4671), 1,
      sym_template_type,
    STATE(5765), 1,
      sym_lambda_capture_specifier,
    STATE(6459), 1,
      sym__scope_resolution,
    ACTIONS(9224), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5781), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [194930] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7777), 1,
      anon_sym_STAR,
    ACTIONS(9226), 1,
      sym_identifier,
    ACTIONS(9228), 1,
      anon_sym_TILDE,
    ACTIONS(9230), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9232), 1,
      anon_sym_template,
    ACTIONS(9234), 1,
      anon_sym_operator,
    STATE(2199), 1,
      sym_dependent_type_identifier,
    STATE(2205), 1,
      sym_template_type,
    STATE(2228), 1,
      sym_qualified_type_identifier,
    STATE(3063), 1,
      sym_operator_name,
    STATE(3064), 1,
      sym_qualified_identifier,
    STATE(3065), 1,
      sym_dependent_identifier,
    STATE(3072), 1,
      sym_destructor_name,
    STATE(3076), 1,
      sym_template_function,
    STATE(3078), 1,
      sym_pointer_type_declarator,
    STATE(5413), 1,
      sym__scope_resolution,
    STATE(6726), 1,
      sym_operator_cast,
    STATE(6825), 1,
      sym_qualified_operator_cast_identifier,
    STATE(8179), 1,
      sym_ms_based_modifier,
    STATE(8571), 1,
      sym_decltype,
  [195000] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7562), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8959), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9004), 1,
      anon_sym_requires,
    STATE(6171), 1,
      sym__function_attributes_end,
    STATE(6379), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8604), 2,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    ACTIONS(8631), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
  [195056] = 23,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(131), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3583), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(9236), 1,
      sym_identifier,
    ACTIONS(9238), 1,
      anon_sym_template,
    STATE(2199), 1,
      sym_dependent_type_identifier,
    STATE(2205), 1,
      sym_template_type,
    STATE(2228), 1,
      sym_qualified_type_identifier,
    STATE(3063), 1,
      sym_operator_name,
    STATE(3064), 1,
      sym_qualified_identifier,
    STATE(3065), 1,
      sym_dependent_identifier,
    STATE(3072), 1,
      sym_destructor_name,
    STATE(3076), 1,
      sym_template_function,
    STATE(3078), 1,
      sym_pointer_type_declarator,
    STATE(5415), 1,
      sym__scope_resolution,
    STATE(6726), 1,
      sym_operator_cast,
    STATE(6825), 1,
      sym_qualified_operator_cast_identifier,
    STATE(8209), 1,
      sym_ms_based_modifier,
    STATE(8571), 1,
      sym_decltype,
  [195126] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(9180), 1,
      anon_sym_LPAREN2,
    ACTIONS(9184), 1,
      anon_sym_requires,
    ACTIONS(9200), 1,
      sym_identifier,
    ACTIONS(9202), 1,
      anon_sym_COLON_COLON,
    STATE(2194), 1,
      sym_template_type,
    STATE(5764), 1,
      sym_lambda_capture_specifier,
    STATE(6501), 1,
      sym__scope_resolution,
    ACTIONS(9240), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(2200), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [195178] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(7483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9000), 1,
      sym_identifier,
    ACTIONS(9206), 1,
      anon_sym_LPAREN2,
    ACTIONS(9210), 1,
      anon_sym_requires,
    STATE(4671), 1,
      sym_template_type,
    STATE(5765), 1,
      sym_lambda_capture_specifier,
    STATE(6459), 1,
      sym__scope_resolution,
    ACTIONS(9242), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5779), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [195230] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(8929), 1,
      sym_identifier,
    ACTIONS(9180), 1,
      anon_sym_LPAREN2,
    ACTIONS(9184), 1,
      anon_sym_requires,
    STATE(2193), 1,
      sym_template_type,
    STATE(5800), 1,
      sym_lambda_capture_specifier,
    STATE(6504), 1,
      sym__scope_resolution,
    ACTIONS(9244), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(6304), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [195282] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7562), 1,
      anon_sym_DASH_GT,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(9050), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9053), 1,
      anon_sym_requires,
    STATE(6135), 1,
      sym__function_attributes_end,
    STATE(6245), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(8693), 2,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    ACTIONS(8700), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
  [195338] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7590), 1,
      anon_sym_STAR,
    ACTIONS(7592), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7594), 1,
      anon_sym_AMP,
    STATE(3354), 1,
      sym_parameter_list,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(6113), 1,
      sym__abstract_declarator,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7759), 9,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [195384] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7562), 1,
      anon_sym_DASH_GT,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    ACTIONS(9246), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9249), 1,
      anon_sym_requires,
    STATE(6132), 1,
      sym__function_attributes_end,
    STATE(6354), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9023), 2,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    ACTIONS(9030), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5957), 2,
      sym__function_postfix,
      sym_requires_clause,
  [195440] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(8877), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8994), 1,
      sym_identifier,
    ACTIONS(9085), 1,
      anon_sym_requires,
    ACTIONS(9252), 1,
      anon_sym_LPAREN2,
    STATE(3026), 1,
      sym_template_type,
    STATE(5825), 1,
      sym_lambda_capture_specifier,
    STATE(6485), 1,
      sym__scope_resolution,
    ACTIONS(9254), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(3832), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [195492] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9018), 1,
      sym_identifier,
    ACTIONS(9109), 1,
      anon_sym_requires,
    ACTIONS(9154), 1,
      anon_sym_LPAREN2,
    STATE(2419), 1,
      sym_template_type,
    STATE(5823), 1,
      sym_lambda_capture_specifier,
    STATE(6489), 1,
      sym__scope_resolution,
    ACTIONS(9256), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(4235), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [195544] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7562), 1,
      anon_sym_DASH_GT,
    ACTIONS(7564), 1,
      anon_sym_requires,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    ACTIONS(9246), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6154), 1,
      sym__function_attributes_end,
    STATE(6277), 1,
      sym_trailing_return_type,
    STATE(6652), 1,
      sym_gnu_asm_expression,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    ACTIONS(6894), 2,
      anon_sym_asm,
      anon_sym___asm__,
    ACTIONS(9023), 2,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    STATE(5587), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5795), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(5957), 2,
      sym__function_postfix,
      sym_requires_clause,
  [195600] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9260), 1,
      anon_sym_LPAREN2,
    STATE(5543), 1,
      sym_preproc_argument_list,
    ACTIONS(9262), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9258), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [195634] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9018), 1,
      sym_identifier,
    ACTIONS(9109), 1,
      anon_sym_requires,
    ACTIONS(9154), 1,
      anon_sym_LPAREN2,
    STATE(2419), 1,
      sym_template_type,
    STATE(5823), 1,
      sym_lambda_capture_specifier,
    STATE(6489), 1,
      sym__scope_resolution,
    ACTIONS(9170), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(3561), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [195686] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    ACTIONS(9158), 1,
      anon_sym_LPAREN2,
    ACTIONS(9162), 1,
      anon_sym_requires,
    STATE(2193), 1,
      sym_template_type,
    STATE(5811), 1,
      sym_lambda_capture_specifier,
    STATE(6479), 1,
      sym__scope_resolution,
    ACTIONS(9264), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5934), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [195738] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(8850), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8996), 1,
      sym_identifier,
    ACTIONS(9119), 1,
      anon_sym_requires,
    ACTIONS(9196), 1,
      anon_sym_LPAREN2,
    STATE(2883), 1,
      sym_template_type,
    STATE(5838), 1,
      sym_lambda_capture_specifier,
    STATE(6486), 1,
      sym__scope_resolution,
    ACTIONS(9266), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(3557), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [195790] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(9180), 1,
      anon_sym_LPAREN2,
    ACTIONS(9184), 1,
      anon_sym_requires,
    ACTIONS(9200), 1,
      sym_identifier,
    ACTIONS(9202), 1,
      anon_sym_COLON_COLON,
    STATE(2194), 1,
      sym_template_type,
    STATE(5764), 1,
      sym_lambda_capture_specifier,
    STATE(6501), 1,
      sym__scope_resolution,
    ACTIONS(9268), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(2213), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [195842] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    ACTIONS(9158), 1,
      anon_sym_LPAREN2,
    ACTIONS(9162), 1,
      anon_sym_requires,
    STATE(2193), 1,
      sym_template_type,
    STATE(5811), 1,
      sym_lambda_capture_specifier,
    STATE(6479), 1,
      sym__scope_resolution,
    ACTIONS(9188), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(5720), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [195894] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(8929), 1,
      sym_identifier,
    ACTIONS(9180), 1,
      anon_sym_LPAREN2,
    ACTIONS(9184), 1,
      anon_sym_requires,
    STATE(2193), 1,
      sym_template_type,
    STATE(5800), 1,
      sym_lambda_capture_specifier,
    STATE(6504), 1,
      sym__scope_resolution,
    ACTIONS(9204), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(1961), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [195946] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3665), 1,
      anon_sym_LBRACK,
    ACTIONS(8877), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8994), 1,
      sym_identifier,
    ACTIONS(9085), 1,
      anon_sym_requires,
    ACTIONS(9252), 1,
      anon_sym_LPAREN2,
    STATE(3026), 1,
      sym_template_type,
    STATE(5825), 1,
      sym_lambda_capture_specifier,
    STATE(6485), 1,
      sym__scope_resolution,
    ACTIONS(9270), 2,
      sym_true,
      sym_false,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    STATE(3935), 8,
      sym__class_name,
      sym_constraint_conjunction,
      sym_constraint_disjunction,
      sym__requirement_clause_constraint,
      sym_requires_expression,
      sym_lambda_expression,
      sym_fold_expression,
      sym_qualified_type_identifier,
  [195998] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(131), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4989), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(9272), 1,
      sym_identifier,
    ACTIONS(9274), 1,
      anon_sym_template,
    STATE(3063), 1,
      sym_operator_name,
    STATE(3064), 1,
      sym_qualified_identifier,
    STATE(3065), 1,
      sym_dependent_identifier,
    STATE(3072), 1,
      sym_destructor_name,
    STATE(3076), 1,
      sym_template_function,
    STATE(3078), 1,
      sym_pointer_type_declarator,
    STATE(5433), 1,
      sym__scope_resolution,
    STATE(6726), 1,
      sym_operator_cast,
    STATE(6825), 1,
      sym_qualified_operator_cast_identifier,
    STATE(8209), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [196061] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6425), 1,
      anon_sym_LBRACE,
    ACTIONS(8806), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8998), 1,
      sym_identifier,
    STATE(2942), 1,
      sym_template_type,
    STATE(3098), 1,
      sym_field_declaration_list,
    STATE(3263), 1,
      sym__class_declaration_item,
    STATE(6464), 1,
      sym__scope_resolution,
    STATE(6992), 1,
      sym_virtual_specifier,
    STATE(7621), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2800), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [196120] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4078), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8983), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2300), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(6449), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2229), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [196179] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(4855), 1,
      sym_field_declaration_list,
    STATE(4938), 1,
      sym__class_declaration_item,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6835), 1,
      sym_virtual_specifier,
    STATE(7667), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4579), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5439), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [196238] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6321), 1,
      anon_sym_LBRACE,
    ACTIONS(8850), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8996), 1,
      sym_identifier,
    STATE(2883), 1,
      sym_template_type,
    STATE(3038), 1,
      sym_field_declaration_list,
    STATE(3208), 1,
      sym__class_declaration_item,
    STATE(6486), 1,
      sym__scope_resolution,
    STATE(6791), 1,
      sym_virtual_specifier,
    STATE(7603), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2753), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5456), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [196297] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6321), 1,
      anon_sym_LBRACE,
    ACTIONS(8850), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8996), 1,
      sym_identifier,
    STATE(2883), 1,
      sym_template_type,
    STATE(3038), 1,
      sym_field_declaration_list,
    STATE(3212), 1,
      sym__class_declaration_item,
    STATE(6486), 1,
      sym__scope_resolution,
    STATE(6791), 1,
      sym_virtual_specifier,
    STATE(7603), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2753), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [196356] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(4855), 1,
      sym_field_declaration_list,
    STATE(4875), 1,
      sym__class_declaration_item,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6835), 1,
      sym_virtual_specifier,
    STATE(7667), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4579), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [196415] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    ACTIONS(8973), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(4855), 1,
      sym_field_declaration_list,
    STATE(4893), 1,
      sym__class_declaration_item,
    STATE(6475), 1,
      sym__scope_resolution,
    STATE(6835), 1,
      sym_virtual_specifier,
    STATE(7667), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4579), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [196474] = 5,
    ACTIONS(9258), 1,
      anon_sym_LF,
    ACTIONS(9276), 1,
      anon_sym_LPAREN2,
    ACTIONS(9278), 1,
      sym_comment,
    STATE(5704), 1,
      sym_preproc_argument_list,
    ACTIONS(9262), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [196507] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    ACTIONS(8973), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(4855), 1,
      sym_field_declaration_list,
    STATE(4886), 1,
      sym__class_declaration_item,
    STATE(6475), 1,
      sym__scope_resolution,
    STATE(6835), 1,
      sym_virtual_specifier,
    STATE(7667), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4579), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5509), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [196566] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9282), 1,
      anon_sym_LBRACK,
    ACTIONS(9280), 20,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_noexcept,
      anon_sym_throw,
      anon_sym_requires,
  [196595] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8483), 1,
      anon_sym_LBRACE,
    ACTIONS(9000), 1,
      sym_identifier,
    STATE(4671), 1,
      sym_template_type,
    STATE(4905), 1,
      sym_field_declaration_list,
    STATE(4989), 1,
      sym__class_declaration_item,
    STATE(6459), 1,
      sym__scope_resolution,
    STATE(6958), 1,
      sym_virtual_specifier,
    STATE(7571), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4588), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5450), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [196654] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4078), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8983), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2294), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(6449), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2229), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5435), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [196713] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4078), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8983), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2288), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(6449), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2229), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [196772] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6594), 1,
      anon_sym_LBRACE,
    ACTIONS(8877), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8994), 1,
      sym_identifier,
    STATE(3026), 1,
      sym_template_type,
    STATE(3307), 1,
      sym_field_declaration_list,
    STATE(3485), 1,
      sym__class_declaration_item,
    STATE(6485), 1,
      sym__scope_resolution,
    STATE(6821), 1,
      sym_virtual_specifier,
    STATE(7734), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2908), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5500), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [196831] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4078), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8983), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2304), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(6449), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2229), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5495), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [196890] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    ACTIONS(8753), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9007), 1,
      sym_identifier,
    STATE(2876), 1,
      sym_field_declaration_list,
    STATE(2892), 1,
      sym_template_type,
    STATE(3008), 1,
      sym__class_declaration_item,
    STATE(6505), 1,
      sym__scope_resolution,
    STATE(6928), 1,
      sym_virtual_specifier,
    STATE(7835), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2740), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [196949] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8483), 1,
      anon_sym_LBRACE,
    ACTIONS(9000), 1,
      sym_identifier,
    STATE(4671), 1,
      sym_template_type,
    STATE(4905), 1,
      sym_field_declaration_list,
    STATE(5037), 1,
      sym__class_declaration_item,
    STATE(6459), 1,
      sym__scope_resolution,
    STATE(6958), 1,
      sym_virtual_specifier,
    STATE(7571), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4588), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [197008] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2294), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2466), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5527), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [197067] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2447), 1,
      sym__class_declaration_item,
    STATE(5295), 1,
      sym_field_declaration_list,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(6989), 1,
      sym_virtual_specifier,
    STATE(7581), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4750), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [197126] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(4855), 1,
      sym_field_declaration_list,
    STATE(4893), 1,
      sym__class_declaration_item,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6835), 1,
      sym_virtual_specifier,
    STATE(7667), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4579), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [197185] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    ACTIONS(8753), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9007), 1,
      sym_identifier,
    STATE(2876), 1,
      sym_field_declaration_list,
    STATE(2892), 1,
      sym_template_type,
    STATE(2960), 1,
      sym__class_declaration_item,
    STATE(6505), 1,
      sym__scope_resolution,
    STATE(6928), 1,
      sym_virtual_specifier,
    STATE(7835), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2740), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5449), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [197244] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    ACTIONS(7477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8968), 1,
      sym_identifier,
    STATE(2876), 1,
      sym_field_declaration_list,
    STATE(2892), 1,
      sym_template_type,
    STATE(3008), 1,
      sym__class_declaration_item,
    STATE(6482), 1,
      sym__scope_resolution,
    STATE(6928), 1,
      sym_virtual_specifier,
    STATE(7835), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2740), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [197303] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6321), 1,
      anon_sym_LBRACE,
    ACTIONS(8850), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8996), 1,
      sym_identifier,
    STATE(2883), 1,
      sym_template_type,
    STATE(3038), 1,
      sym_field_declaration_list,
    STATE(3173), 1,
      sym__class_declaration_item,
    STATE(6486), 1,
      sym__scope_resolution,
    STATE(6791), 1,
      sym_virtual_specifier,
    STATE(7603), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2753), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [197362] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6321), 1,
      anon_sym_LBRACE,
    ACTIONS(8850), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8996), 1,
      sym_identifier,
    STATE(2883), 1,
      sym_template_type,
    STATE(3038), 1,
      sym_field_declaration_list,
    STATE(3163), 1,
      sym__class_declaration_item,
    STATE(6486), 1,
      sym__scope_resolution,
    STATE(6791), 1,
      sym_virtual_specifier,
    STATE(7603), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2753), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5471), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [197421] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6594), 1,
      anon_sym_LBRACE,
    ACTIONS(8877), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8994), 1,
      sym_identifier,
    STATE(3026), 1,
      sym_template_type,
    STATE(3307), 1,
      sym_field_declaration_list,
    STATE(3482), 1,
      sym__class_declaration_item,
    STATE(6485), 1,
      sym__scope_resolution,
    STATE(6821), 1,
      sym_virtual_specifier,
    STATE(7734), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2908), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [197480] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2288), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2466), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [197539] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    ACTIONS(8753), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9007), 1,
      sym_identifier,
    STATE(2876), 1,
      sym_field_declaration_list,
    STATE(2892), 1,
      sym_template_type,
    STATE(2992), 1,
      sym__class_declaration_item,
    STATE(6505), 1,
      sym__scope_resolution,
    STATE(6928), 1,
      sym_virtual_specifier,
    STATE(7835), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2740), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [197598] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2271), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2229), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [197657] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    ACTIONS(7477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8968), 1,
      sym_identifier,
    STATE(2876), 1,
      sym_field_declaration_list,
    STATE(2892), 1,
      sym_template_type,
    STATE(2960), 1,
      sym__class_declaration_item,
    STATE(6482), 1,
      sym__scope_resolution,
    STATE(6928), 1,
      sym_virtual_specifier,
    STATE(7835), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2740), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5455), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [197716] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(4855), 1,
      sym_field_declaration_list,
    STATE(4886), 1,
      sym__class_declaration_item,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6835), 1,
      sym_virtual_specifier,
    STATE(7667), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4579), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5482), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [197775] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2304), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2466), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5472), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [197834] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    ACTIONS(8753), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9007), 1,
      sym_identifier,
    STATE(2876), 1,
      sym_field_declaration_list,
    STATE(2892), 1,
      sym_template_type,
    STATE(3009), 1,
      sym__class_declaration_item,
    STATE(6505), 1,
      sym__scope_resolution,
    STATE(6928), 1,
      sym_virtual_specifier,
    STATE(7835), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2740), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [197893] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8483), 1,
      anon_sym_LBRACE,
    ACTIONS(9000), 1,
      sym_identifier,
    STATE(4671), 1,
      sym_template_type,
    STATE(4905), 1,
      sym_field_declaration_list,
    STATE(5046), 1,
      sym__class_declaration_item,
    STATE(6459), 1,
      sym__scope_resolution,
    STATE(6958), 1,
      sym_virtual_specifier,
    STATE(7571), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4588), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [197952] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    ACTIONS(8973), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(4855), 1,
      sym_field_declaration_list,
    STATE(4875), 1,
      sym__class_declaration_item,
    STATE(6475), 1,
      sym__scope_resolution,
    STATE(6835), 1,
      sym_virtual_specifier,
    STATE(7667), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4579), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [198011] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    ACTIONS(8753), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9007), 1,
      sym_identifier,
    STATE(2876), 1,
      sym_field_declaration_list,
    STATE(2892), 1,
      sym_template_type,
    STATE(2963), 1,
      sym__class_declaration_item,
    STATE(6505), 1,
      sym__scope_resolution,
    STATE(6928), 1,
      sym_virtual_specifier,
    STATE(7835), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2740), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5460), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [198070] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9284), 1,
      sym_identifier,
    ACTIONS(9286), 1,
      anon_sym_RPAREN,
    ACTIONS(9288), 1,
      anon_sym_LPAREN2,
    ACTIONS(9290), 1,
      anon_sym_defined,
    ACTIONS(9296), 1,
      sym_number_literal,
    ACTIONS(9292), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9294), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9298), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5506), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [198113] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    ACTIONS(7477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8968), 1,
      sym_identifier,
    STATE(2876), 1,
      sym_field_declaration_list,
    STATE(2892), 1,
      sym_template_type,
    STATE(2992), 1,
      sym__class_declaration_item,
    STATE(6482), 1,
      sym__scope_resolution,
    STATE(6928), 1,
      sym_virtual_specifier,
    STATE(7835), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2740), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [198172] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6321), 1,
      anon_sym_LBRACE,
    ACTIONS(8850), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8996), 1,
      sym_identifier,
    STATE(2883), 1,
      sym_template_type,
    STATE(3038), 1,
      sym_field_declaration_list,
    STATE(3235), 1,
      sym__class_declaration_item,
    STATE(6486), 1,
      sym__scope_resolution,
    STATE(6791), 1,
      sym_virtual_specifier,
    STATE(7603), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2753), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [198231] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2271), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2466), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [198290] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2454), 1,
      sym__class_declaration_item,
    STATE(2709), 1,
      sym_field_declaration_list,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(6811), 1,
      sym_virtual_specifier,
    STATE(7509), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2585), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [198349] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8483), 1,
      anon_sym_LBRACE,
    ACTIONS(9000), 1,
      sym_identifier,
    STATE(4671), 1,
      sym_template_type,
    STATE(4905), 1,
      sym_field_declaration_list,
    STATE(4994), 1,
      sym__class_declaration_item,
    STATE(6459), 1,
      sym__scope_resolution,
    STATE(6958), 1,
      sym_virtual_specifier,
    STATE(7571), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4588), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [198408] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2452), 1,
      sym__class_declaration_item,
    STATE(5295), 1,
      sym_field_declaration_list,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(6989), 1,
      sym_virtual_specifier,
    STATE(7581), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4750), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5491), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [198467] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2271), 1,
      sym__class_declaration_item,
    STATE(5066), 1,
      sym_field_declaration_list,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6797), 1,
      sym_virtual_specifier,
    STATE(7519), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4867), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [198526] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8483), 1,
      anon_sym_LBRACE,
    ACTIONS(9000), 1,
      sym_identifier,
    STATE(4671), 1,
      sym_template_type,
    STATE(4905), 1,
      sym_field_declaration_list,
    STATE(5002), 1,
      sym__class_declaration_item,
    STATE(6459), 1,
      sym__scope_resolution,
    STATE(6958), 1,
      sym_virtual_specifier,
    STATE(7571), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4588), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5466), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [198585] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9284), 1,
      sym_identifier,
    ACTIONS(9288), 1,
      anon_sym_LPAREN2,
    ACTIONS(9290), 1,
      anon_sym_defined,
    ACTIONS(9300), 1,
      anon_sym_RPAREN,
    ACTIONS(9302), 1,
      sym_number_literal,
    ACTIONS(9292), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9294), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9298), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5487), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [198628] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6425), 1,
      anon_sym_LBRACE,
    ACTIONS(8806), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8998), 1,
      sym_identifier,
    STATE(2942), 1,
      sym_template_type,
    STATE(3098), 1,
      sym_field_declaration_list,
    STATE(3328), 1,
      sym__class_declaration_item,
    STATE(6464), 1,
      sym__scope_resolution,
    STATE(6992), 1,
      sym_virtual_specifier,
    STATE(7621), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2800), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5434), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [198687] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6425), 1,
      anon_sym_LBRACE,
    ACTIONS(8806), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8998), 1,
      sym_identifier,
    STATE(2942), 1,
      sym_template_type,
    STATE(3098), 1,
      sym_field_declaration_list,
    STATE(3314), 1,
      sym__class_declaration_item,
    STATE(6464), 1,
      sym__scope_resolution,
    STATE(6992), 1,
      sym_virtual_specifier,
    STATE(7621), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2800), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [198746] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9018), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2454), 1,
      sym__class_declaration_item,
    STATE(2709), 1,
      sym_field_declaration_list,
    STATE(6489), 1,
      sym__scope_resolution,
    STATE(6811), 1,
      sym_virtual_specifier,
    STATE(7509), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2585), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [198805] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(4855), 1,
      sym_field_declaration_list,
    STATE(4929), 1,
      sym__class_declaration_item,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6835), 1,
      sym_virtual_specifier,
    STATE(7667), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4579), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [198864] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2481), 1,
      sym__class_declaration_item,
    STATE(5295), 1,
      sym_field_declaration_list,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(6989), 1,
      sym_virtual_specifier,
    STATE(7581), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4750), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5507), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [198923] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6594), 1,
      anon_sym_LBRACE,
    ACTIONS(8877), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8994), 1,
      sym_identifier,
    STATE(3026), 1,
      sym_template_type,
    STATE(3307), 1,
      sym_field_declaration_list,
    STATE(3480), 1,
      sym__class_declaration_item,
    STATE(6485), 1,
      sym__scope_resolution,
    STATE(6821), 1,
      sym_virtual_specifier,
    STATE(7734), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2908), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [198982] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6425), 1,
      anon_sym_LBRACE,
    ACTIONS(8806), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8998), 1,
      sym_identifier,
    STATE(2942), 1,
      sym_template_type,
    STATE(3098), 1,
      sym_field_declaration_list,
    STATE(3281), 1,
      sym__class_declaration_item,
    STATE(6464), 1,
      sym__scope_resolution,
    STATE(6992), 1,
      sym_virtual_specifier,
    STATE(7621), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2800), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5531), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [199041] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9304), 1,
      anon_sym_COMMA,
    ACTIONS(9306), 1,
      anon_sym_RPAREN,
    ACTIONS(9312), 1,
      anon_sym_SLASH,
    ACTIONS(9314), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(9316), 1,
      anon_sym_AMP_AMP,
    ACTIONS(9318), 1,
      anon_sym_PIPE,
    ACTIONS(9320), 1,
      anon_sym_CARET,
    ACTIONS(9322), 1,
      anon_sym_AMP,
    STATE(7275), 1,
      aux_sym_preproc_argument_list_repeat1,
    ACTIONS(9308), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9310), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9324), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9326), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9328), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(9330), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [199096] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9304), 1,
      anon_sym_COMMA,
    ACTIONS(9312), 1,
      anon_sym_SLASH,
    ACTIONS(9314), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(9316), 1,
      anon_sym_AMP_AMP,
    ACTIONS(9318), 1,
      anon_sym_PIPE,
    ACTIONS(9320), 1,
      anon_sym_CARET,
    ACTIONS(9322), 1,
      anon_sym_AMP,
    ACTIONS(9332), 1,
      anon_sym_RPAREN,
    STATE(7190), 1,
      aux_sym_preproc_argument_list_repeat1,
    ACTIONS(9308), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9310), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9324), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9326), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9328), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(9330), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [199151] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    ACTIONS(7477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8968), 1,
      sym_identifier,
    STATE(2876), 1,
      sym_field_declaration_list,
    STATE(2892), 1,
      sym_template_type,
    STATE(3009), 1,
      sym__class_declaration_item,
    STATE(6482), 1,
      sym__scope_resolution,
    STATE(6928), 1,
      sym_virtual_specifier,
    STATE(7835), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2740), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [199210] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6594), 1,
      anon_sym_LBRACE,
    ACTIONS(8877), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8994), 1,
      sym_identifier,
    STATE(3026), 1,
      sym_template_type,
    STATE(3307), 1,
      sym_field_declaration_list,
    STATE(3584), 1,
      sym__class_declaration_item,
    STATE(6485), 1,
      sym__scope_resolution,
    STATE(6821), 1,
      sym_virtual_specifier,
    STATE(7734), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2908), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5484), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [199269] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7134), 1,
      anon_sym_LBRACE,
    ACTIONS(8828), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9002), 1,
      sym_identifier,
    STATE(3808), 1,
      sym_template_type,
    STATE(4076), 1,
      sym_field_declaration_list,
    STATE(4147), 1,
      sym__class_declaration_item,
    STATE(6451), 1,
      sym__scope_resolution,
    STATE(6897), 1,
      sym_virtual_specifier,
    STATE(7535), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3362), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5496), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [199328] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2485), 1,
      sym__class_declaration_item,
    STATE(5295), 1,
      sym_field_declaration_list,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(6989), 1,
      sym_virtual_specifier,
    STATE(7581), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4750), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [199387] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7134), 1,
      anon_sym_LBRACE,
    ACTIONS(8828), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9002), 1,
      sym_identifier,
    STATE(3808), 1,
      sym_template_type,
    STATE(4076), 1,
      sym_field_declaration_list,
    STATE(4156), 1,
      sym__class_declaration_item,
    STATE(6451), 1,
      sym__scope_resolution,
    STATE(6897), 1,
      sym_virtual_specifier,
    STATE(7535), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3362), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [199446] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    ACTIONS(7477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8968), 1,
      sym_identifier,
    STATE(2876), 1,
      sym_field_declaration_list,
    STATE(2892), 1,
      sym_template_type,
    STATE(2963), 1,
      sym__class_declaration_item,
    STATE(6482), 1,
      sym__scope_resolution,
    STATE(6928), 1,
      sym_virtual_specifier,
    STATE(7835), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2740), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5470), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [199505] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9018), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2452), 1,
      sym__class_declaration_item,
    STATE(2709), 1,
      sym_field_declaration_list,
    STATE(6489), 1,
      sym__scope_resolution,
    STATE(6811), 1,
      sym_virtual_specifier,
    STATE(7509), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2585), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5512), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [199564] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4078), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8983), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2271), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(6449), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2229), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [199623] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7134), 1,
      anon_sym_LBRACE,
    ACTIONS(8828), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9002), 1,
      sym_identifier,
    STATE(3808), 1,
      sym_template_type,
    STATE(4076), 1,
      sym_field_declaration_list,
    STATE(4170), 1,
      sym__class_declaration_item,
    STATE(6451), 1,
      sym__scope_resolution,
    STATE(6897), 1,
      sym_virtual_specifier,
    STATE(7535), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3362), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [199682] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7134), 1,
      anon_sym_LBRACE,
    ACTIONS(8828), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9002), 1,
      sym_identifier,
    STATE(3808), 1,
      sym_template_type,
    STATE(4076), 1,
      sym_field_declaration_list,
    STATE(4114), 1,
      sym__class_declaration_item,
    STATE(6451), 1,
      sym__scope_resolution,
    STATE(6897), 1,
      sym_virtual_specifier,
    STATE(7535), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3362), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5502), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [199741] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2481), 1,
      sym__class_declaration_item,
    STATE(2709), 1,
      sym_field_declaration_list,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(6811), 1,
      sym_virtual_specifier,
    STATE(7509), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2585), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5473), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [199800] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2485), 1,
      sym__class_declaration_item,
    STATE(2709), 1,
      sym_field_declaration_list,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(6811), 1,
      sym_virtual_specifier,
    STATE(7509), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2585), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [199859] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6594), 1,
      anon_sym_LBRACE,
    ACTIONS(8877), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8994), 1,
      sym_identifier,
    STATE(3026), 1,
      sym_template_type,
    STATE(3307), 1,
      sym_field_declaration_list,
    STATE(3579), 1,
      sym__class_declaration_item,
    STATE(6485), 1,
      sym__scope_resolution,
    STATE(6821), 1,
      sym_virtual_specifier,
    STATE(7734), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2908), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [199918] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2304), 1,
      sym__class_declaration_item,
    STATE(5066), 1,
      sym_field_declaration_list,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6797), 1,
      sym_virtual_specifier,
    STATE(7519), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4867), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5476), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [199977] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7134), 1,
      anon_sym_LBRACE,
    ACTIONS(8828), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9002), 1,
      sym_identifier,
    STATE(3808), 1,
      sym_template_type,
    STATE(4076), 1,
      sym_field_declaration_list,
    STATE(4144), 1,
      sym__class_declaration_item,
    STATE(6451), 1,
      sym__scope_resolution,
    STATE(6897), 1,
      sym_virtual_specifier,
    STATE(7535), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(3362), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [200036] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7614), 1,
      anon_sym_STAR,
    ACTIONS(7616), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7618), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    STATE(3399), 1,
      sym_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6217), 1,
      sym__abstract_declarator,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7759), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [200081] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2288), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2229), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [200140] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9284), 1,
      sym_identifier,
    ACTIONS(9288), 1,
      anon_sym_LPAREN2,
    ACTIONS(9290), 1,
      anon_sym_defined,
    ACTIONS(9334), 1,
      anon_sym_RPAREN,
    ACTIONS(9336), 1,
      sym_number_literal,
    ACTIONS(9292), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9294), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9298), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5486), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [200183] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9304), 1,
      anon_sym_COMMA,
    ACTIONS(9312), 1,
      anon_sym_SLASH,
    ACTIONS(9314), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(9316), 1,
      anon_sym_AMP_AMP,
    ACTIONS(9318), 1,
      anon_sym_PIPE,
    ACTIONS(9320), 1,
      anon_sym_CARET,
    ACTIONS(9322), 1,
      anon_sym_AMP,
    ACTIONS(9338), 1,
      anon_sym_RPAREN,
    STATE(7056), 1,
      aux_sym_preproc_argument_list_repeat1,
    ACTIONS(9308), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9310), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9324), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9326), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9328), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(9330), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [200238] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2454), 1,
      sym__class_declaration_item,
    STATE(5295), 1,
      sym_field_declaration_list,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(6989), 1,
      sym_virtual_specifier,
    STATE(7581), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4750), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [200297] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2294), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2229), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5519), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [200356] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    ACTIONS(8973), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(4855), 1,
      sym_field_declaration_list,
    STATE(4929), 1,
      sym__class_declaration_item,
    STATE(6475), 1,
      sym__scope_resolution,
    STATE(6835), 1,
      sym_virtual_specifier,
    STATE(7667), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4579), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [200415] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8973), 1,
      sym_identifier,
    ACTIONS(8975), 1,
      anon_sym_COLON_COLON,
    STATE(2193), 1,
      sym_template_type,
    STATE(2271), 1,
      sym__class_declaration_item,
    STATE(5066), 1,
      sym_field_declaration_list,
    STATE(6458), 1,
      sym__scope_resolution,
    STATE(6797), 1,
      sym_virtual_specifier,
    STATE(7519), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4867), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [200474] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9018), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2481), 1,
      sym__class_declaration_item,
    STATE(2709), 1,
      sym_field_declaration_list,
    STATE(6489), 1,
      sym__scope_resolution,
    STATE(6811), 1,
      sym_virtual_specifier,
    STATE(7509), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2585), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5481), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [200533] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9018), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2485), 1,
      sym__class_declaration_item,
    STATE(2709), 1,
      sym_field_declaration_list,
    STATE(6489), 1,
      sym__scope_resolution,
    STATE(6811), 1,
      sym_virtual_specifier,
    STATE(7509), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2585), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [200592] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9018), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2447), 1,
      sym__class_declaration_item,
    STATE(2709), 1,
      sym_field_declaration_list,
    STATE(6489), 1,
      sym__scope_resolution,
    STATE(6811), 1,
      sym_virtual_specifier,
    STATE(7509), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2585), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [200651] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5817), 1,
      anon_sym_LBRACE,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8931), 1,
      sym_identifier,
    STATE(2498), 1,
      sym_template_type,
    STATE(2553), 1,
      sym_field_declaration_list,
    STATE(2613), 1,
      sym__class_declaration_item,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(6883), 1,
      sym_virtual_specifier,
    STATE(7724), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2412), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [200710] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2447), 1,
      sym__class_declaration_item,
    STATE(2709), 1,
      sym_field_declaration_list,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(6811), 1,
      sym_virtual_specifier,
    STATE(7509), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2585), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [200769] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5817), 1,
      anon_sym_LBRACE,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8931), 1,
      sym_identifier,
    STATE(2498), 1,
      sym_template_type,
    STATE(2553), 1,
      sym_field_declaration_list,
    STATE(2644), 1,
      sym__class_declaration_item,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(6883), 1,
      sym_virtual_specifier,
    STATE(7724), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2412), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5514), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [200828] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5817), 1,
      anon_sym_LBRACE,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8931), 1,
      sym_identifier,
    STATE(2498), 1,
      sym_template_type,
    STATE(2553), 1,
      sym_field_declaration_list,
    STATE(2626), 1,
      sym__class_declaration_item,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(6883), 1,
      sym_virtual_specifier,
    STATE(7724), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2412), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [200887] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2452), 1,
      sym__class_declaration_item,
    STATE(2709), 1,
      sym_field_declaration_list,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(6811), 1,
      sym_virtual_specifier,
    STATE(7509), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2585), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5499), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [200946] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2300), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2229), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [201005] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8973), 1,
      sym_identifier,
    ACTIONS(8975), 1,
      anon_sym_COLON_COLON,
    STATE(2193), 1,
      sym_template_type,
    STATE(2304), 1,
      sym__class_declaration_item,
    STATE(5066), 1,
      sym_field_declaration_list,
    STATE(6458), 1,
      sym__scope_resolution,
    STATE(6797), 1,
      sym_virtual_specifier,
    STATE(7519), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4867), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5510), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [201064] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2300), 1,
      sym__class_declaration_item,
    STATE(5066), 1,
      sym_field_declaration_list,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6797), 1,
      sym_virtual_specifier,
    STATE(7519), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4867), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [201123] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    ACTIONS(8973), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(4855), 1,
      sym_field_declaration_list,
    STATE(4938), 1,
      sym__class_declaration_item,
    STATE(6475), 1,
      sym__scope_resolution,
    STATE(6835), 1,
      sym_virtual_specifier,
    STATE(7667), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4579), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5467), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [201182] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2288), 1,
      sym__class_declaration_item,
    STATE(5066), 1,
      sym_field_declaration_list,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6797), 1,
      sym_virtual_specifier,
    STATE(7519), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4867), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [201241] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2294), 1,
      sym__class_declaration_item,
    STATE(5066), 1,
      sym_field_declaration_list,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6797), 1,
      sym_virtual_specifier,
    STATE(7519), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4867), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5521), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [201300] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8973), 1,
      sym_identifier,
    ACTIONS(8975), 1,
      anon_sym_COLON_COLON,
    STATE(2193), 1,
      sym_template_type,
    STATE(2300), 1,
      sym__class_declaration_item,
    STATE(5066), 1,
      sym_field_declaration_list,
    STATE(6458), 1,
      sym__scope_resolution,
    STATE(6797), 1,
      sym_virtual_specifier,
    STATE(7519), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4867), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [201359] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8973), 1,
      sym_identifier,
    ACTIONS(8975), 1,
      anon_sym_COLON_COLON,
    STATE(2193), 1,
      sym_template_type,
    STATE(2288), 1,
      sym__class_declaration_item,
    STATE(5066), 1,
      sym_field_declaration_list,
    STATE(6458), 1,
      sym__scope_resolution,
    STATE(6797), 1,
      sym_virtual_specifier,
    STATE(7519), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4867), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [201418] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2300), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2466), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [201477] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8973), 1,
      sym_identifier,
    ACTIONS(8975), 1,
      anon_sym_COLON_COLON,
    STATE(2193), 1,
      sym_template_type,
    STATE(2294), 1,
      sym__class_declaration_item,
    STATE(5066), 1,
      sym_field_declaration_list,
    STATE(6458), 1,
      sym__scope_resolution,
    STATE(6797), 1,
      sym_virtual_specifier,
    STATE(7519), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(4867), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5525), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [201536] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5817), 1,
      anon_sym_LBRACE,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8931), 1,
      sym_identifier,
    STATE(2498), 1,
      sym_template_type,
    STATE(2553), 1,
      sym_field_declaration_list,
    STATE(2591), 1,
      sym__class_declaration_item,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(6883), 1,
      sym_virtual_specifier,
    STATE(7724), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2412), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [201595] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5817), 1,
      anon_sym_LBRACE,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8931), 1,
      sym_identifier,
    STATE(2498), 1,
      sym_template_type,
    STATE(2553), 1,
      sym_field_declaration_list,
    STATE(2589), 1,
      sym__class_declaration_item,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(6883), 1,
      sym_virtual_specifier,
    STATE(7724), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2412), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5517), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [201654] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6425), 1,
      anon_sym_LBRACE,
    ACTIONS(8806), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8998), 1,
      sym_identifier,
    STATE(2942), 1,
      sym_template_type,
    STATE(3098), 1,
      sym_field_declaration_list,
    STATE(3310), 1,
      sym__class_declaration_item,
    STATE(6464), 1,
      sym__scope_resolution,
    STATE(6992), 1,
      sym_virtual_specifier,
    STATE(7621), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2800), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [201713] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2304), 1,
      sym__class_declaration_item,
    STATE(2325), 1,
      sym_field_declaration_list,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(6890), 1,
      sym_virtual_specifier,
    STATE(7554), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(2229), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(5461), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [201772] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9350), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5667), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [201812] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6425), 1,
      sym__type_declarator,
    STATE(6912), 1,
      sym__type_definition_declarators,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [201862] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9354), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5656), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [201902] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9356), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5734), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [201942] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9360), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9358), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [201970] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9362), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5670), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [202010] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6896), 1,
      anon_sym_DASH_GT,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(9366), 1,
      anon_sym_LBRACK,
    STATE(5726), 1,
      sym_trailing_return_type,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5956), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [202050] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9370), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9368), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [202078] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym___attribute__,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(7855), 1,
      anon_sym_LPAREN2,
    ACTIONS(7863), 1,
      sym_identifier,
    ACTIONS(7865), 1,
      anon_sym_STAR,
    ACTIONS(7867), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7869), 1,
      anon_sym_AMP,
    ACTIONS(9372), 1,
      anon_sym_SEMI,
    STATE(5386), 1,
      sym__field_declarator,
    STATE(6214), 1,
      sym_operator_name,
    STATE(7986), 1,
      sym_ms_based_modifier,
    STATE(7987), 1,
      sym_attribute_specifier,
    STATE(6289), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
  [202130] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym___attribute__,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(7855), 1,
      anon_sym_LPAREN2,
    ACTIONS(7863), 1,
      sym_identifier,
    ACTIONS(7865), 1,
      anon_sym_STAR,
    ACTIONS(7867), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7869), 1,
      anon_sym_AMP,
    ACTIONS(9374), 1,
      anon_sym_SEMI,
    STATE(5384), 1,
      sym__field_declarator,
    STATE(6214), 1,
      sym_operator_name,
    STATE(7986), 1,
      sym_ms_based_modifier,
    STATE(8123), 1,
      sym_attribute_specifier,
    STATE(6289), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
  [202182] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9378), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9376), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [202210] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9380), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5710), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [202250] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6425), 1,
      sym__type_declarator,
    STATE(6933), 1,
      sym__type_definition_declarators,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [202300] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9284), 1,
      sym_identifier,
    ACTIONS(9288), 1,
      anon_sym_LPAREN2,
    ACTIONS(9290), 1,
      anon_sym_defined,
    ACTIONS(9382), 1,
      sym_number_literal,
    ACTIONS(9292), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9294), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9298), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5601), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [202340] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9384), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5725), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [202380] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6896), 1,
      anon_sym_DASH_GT,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(8703), 1,
      anon_sym_requires,
    STATE(5711), 1,
      sym_trailing_return_type,
    ACTIONS(8700), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [202420] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6425), 1,
      sym__type_declarator,
    STATE(6752), 1,
      sym__type_definition_declarators,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [202470] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9388), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9386), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [202498] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6896), 1,
      anon_sym_DASH_GT,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    ACTIONS(9033), 1,
      anon_sym_requires,
    STATE(5708), 1,
      sym_trailing_return_type,
    ACTIONS(9030), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5957), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [202538] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9392), 1,
      anon_sym_LBRACK,
    STATE(4537), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5753), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(9390), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [202574] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9394), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5713), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [202614] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7662), 1,
      anon_sym_STAR,
    ACTIONS(7664), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7666), 1,
      anon_sym_AMP,
    STATE(3505), 1,
      sym_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6376), 1,
      sym__abstract_declarator,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7759), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [202658] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9284), 1,
      sym_identifier,
    ACTIONS(9288), 1,
      anon_sym_LPAREN2,
    ACTIONS(9290), 1,
      anon_sym_defined,
    ACTIONS(9396), 1,
      sym_number_literal,
    ACTIONS(9292), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9294), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9298), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5611), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [202698] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6896), 1,
      anon_sym_DASH_GT,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    STATE(5643), 1,
      sym_trailing_return_type,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [202738] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9400), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9398), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [202766] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9284), 1,
      sym_identifier,
    ACTIONS(9288), 1,
      anon_sym_LPAREN2,
    ACTIONS(9290), 1,
      anon_sym_defined,
    ACTIONS(9402), 1,
      sym_number_literal,
    ACTIONS(9292), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9294), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9298), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5618), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [202806] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9284), 1,
      sym_identifier,
    ACTIONS(9288), 1,
      anon_sym_LPAREN2,
    ACTIONS(9290), 1,
      anon_sym_defined,
    ACTIONS(9404), 1,
      sym_number_literal,
    ACTIONS(9292), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9294), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9298), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5620), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [202846] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7691), 1,
      anon_sym_STAR,
    ACTIONS(9406), 1,
      sym_identifier,
    ACTIONS(9408), 1,
      anon_sym_TILDE,
    ACTIONS(9410), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9412), 1,
      anon_sym_template,
    ACTIONS(9414), 1,
      anon_sym_operator,
    STATE(2877), 1,
      sym_dependent_type_identifier,
    STATE(2882), 1,
      sym_template_type,
    STATE(2941), 1,
      sym_qualified_type_identifier,
    STATE(3660), 1,
      sym_template_function,
    STATE(3661), 1,
      sym_destructor_name,
    STATE(3784), 1,
      sym_pointer_type_declarator,
    STATE(3788), 1,
      sym_dependent_identifier,
    STATE(3790), 1,
      sym_qualified_identifier,
    STATE(3792), 1,
      sym_operator_name,
    STATE(5560), 1,
      sym__scope_resolution,
    STATE(7998), 1,
      sym_ms_based_modifier,
    STATE(8571), 1,
      sym_decltype,
  [202910] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6896), 1,
      anon_sym_DASH_GT,
    ACTIONS(9366), 1,
      anon_sym_LBRACK,
    ACTIONS(9419), 1,
      anon_sym_requires,
    STATE(5696), 1,
      sym_trailing_return_type,
    ACTIONS(9416), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5956), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [202950] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9424), 1,
      anon_sym_LBRACK,
    STATE(4537), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5760), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(9422), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [202986] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6425), 1,
      sym__type_declarator,
    STATE(6893), 1,
      sym__type_definition_declarators,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [203036] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9284), 1,
      sym_identifier,
    ACTIONS(9288), 1,
      anon_sym_LPAREN2,
    ACTIONS(9290), 1,
      anon_sym_defined,
    ACTIONS(9426), 1,
      sym_number_literal,
    ACTIONS(9292), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9294), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9298), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5629), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [203076] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6425), 1,
      sym__type_declarator,
    STATE(6931), 1,
      sym__type_definition_declarators,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [203126] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9428), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5671), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [203166] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9312), 1,
      anon_sym_SLASH,
    ACTIONS(9320), 1,
      anon_sym_CARET,
    ACTIONS(9322), 1,
      anon_sym_AMP,
    ACTIONS(9432), 1,
      anon_sym_PIPE,
    ACTIONS(9308), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9310), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9324), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9326), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9328), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(9330), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9430), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
  [203212] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9434), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5663), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [203252] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6425), 1,
      sym__type_declarator,
    STATE(6734), 1,
      sym__type_definition_declarators,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [203302] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6896), 1,
      anon_sym_DASH_GT,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(5675), 1,
      sym_trailing_return_type,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [203342] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3942), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(9436), 1,
      sym_identifier,
    ACTIONS(9438), 1,
      anon_sym_template,
    STATE(2199), 1,
      sym_dependent_type_identifier,
    STATE(2205), 1,
      sym_template_type,
    STATE(2228), 1,
      sym_qualified_type_identifier,
    STATE(3063), 1,
      sym_operator_name,
    STATE(3064), 1,
      sym_qualified_identifier,
    STATE(3065), 1,
      sym_dependent_identifier,
    STATE(3072), 1,
      sym_destructor_name,
    STATE(3076), 1,
      sym_template_function,
    STATE(3078), 1,
      sym_pointer_type_declarator,
    STATE(5571), 1,
      sym__scope_resolution,
    STATE(8209), 1,
      sym_ms_based_modifier,
    STATE(8571), 1,
      sym_decltype,
  [203406] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9284), 1,
      sym_identifier,
    ACTIONS(9288), 1,
      anon_sym_LPAREN2,
    ACTIONS(9290), 1,
      anon_sym_defined,
    ACTIONS(9440), 1,
      sym_number_literal,
    ACTIONS(9292), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9294), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9298), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5677), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [203446] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9284), 1,
      sym_identifier,
    ACTIONS(9288), 1,
      anon_sym_LPAREN2,
    ACTIONS(9290), 1,
      anon_sym_defined,
    ACTIONS(9442), 1,
      sym_number_literal,
    ACTIONS(9292), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9294), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9298), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5567), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [203486] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7777), 1,
      anon_sym_STAR,
    ACTIONS(9444), 1,
      sym_identifier,
    ACTIONS(9446), 1,
      anon_sym_TILDE,
    ACTIONS(9448), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9450), 1,
      anon_sym_template,
    ACTIONS(9452), 1,
      anon_sym_operator,
    STATE(2405), 1,
      sym_qualified_type_identifier,
    STATE(2427), 1,
      sym_dependent_type_identifier,
    STATE(2428), 1,
      sym_template_type,
    STATE(2820), 1,
      sym_pointer_type_declarator,
    STATE(2835), 1,
      sym_template_function,
    STATE(2837), 1,
      sym_destructor_name,
    STATE(2839), 1,
      sym_dependent_identifier,
    STATE(2841), 1,
      sym_qualified_identifier,
    STATE(2847), 1,
      sym_operator_name,
    STATE(5574), 1,
      sym__scope_resolution,
    STATE(8179), 1,
      sym_ms_based_modifier,
    STATE(8571), 1,
      sym_decltype,
  [203550] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6896), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8634), 1,
      anon_sym_requires,
    STATE(5721), 1,
      sym_trailing_return_type,
    ACTIONS(8631), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [203590] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6425), 1,
      sym__type_declarator,
    STATE(6949), 1,
      sym__type_definition_declarators,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [203640] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6425), 1,
      sym__type_declarator,
    STATE(7007), 1,
      sym__type_definition_declarators,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [203690] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7777), 1,
      anon_sym_STAR,
    ACTIONS(9446), 1,
      anon_sym_TILDE,
    ACTIONS(9452), 1,
      anon_sym_operator,
    ACTIONS(9454), 1,
      sym_identifier,
    ACTIONS(9456), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9458), 1,
      anon_sym_template,
    STATE(2199), 1,
      sym_dependent_type_identifier,
    STATE(2205), 1,
      sym_template_type,
    STATE(2228), 1,
      sym_qualified_type_identifier,
    STATE(2820), 1,
      sym_pointer_type_declarator,
    STATE(2835), 1,
      sym_template_function,
    STATE(2837), 1,
      sym_destructor_name,
    STATE(2839), 1,
      sym_dependent_identifier,
    STATE(2841), 1,
      sym_qualified_identifier,
    STATE(2847), 1,
      sym_operator_name,
    STATE(5578), 1,
      sym__scope_resolution,
    STATE(8179), 1,
      sym_ms_based_modifier,
    STATE(8571), 1,
      sym_decltype,
  [203754] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9284), 1,
      sym_identifier,
    ACTIONS(9288), 1,
      anon_sym_LPAREN2,
    ACTIONS(9290), 1,
      anon_sym_defined,
    ACTIONS(9460), 1,
      sym_number_literal,
    ACTIONS(9292), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9294), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9298), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5617), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [203794] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6425), 1,
      sym__type_declarator,
    STATE(7009), 1,
      sym__type_definition_declarators,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [203844] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6425), 1,
      sym__type_declarator,
    STATE(6944), 1,
      sym__type_definition_declarators,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [203894] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9462), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5655), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [203934] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9284), 1,
      sym_identifier,
    ACTIONS(9288), 1,
      anon_sym_LPAREN2,
    ACTIONS(9290), 1,
      anon_sym_defined,
    ACTIONS(9464), 1,
      sym_number_literal,
    ACTIONS(9292), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9294), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9298), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5627), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [203974] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9284), 1,
      sym_identifier,
    ACTIONS(9288), 1,
      anon_sym_LPAREN2,
    ACTIONS(9290), 1,
      anon_sym_defined,
    ACTIONS(9466), 1,
      sym_number_literal,
    ACTIONS(9292), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9294), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9298), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5591), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [204014] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9470), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9468), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [204042] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6731), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(6733), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [204070] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(9424), 1,
      anon_sym_LBRACK,
    STATE(4479), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5819), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(9422), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [204106] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9472), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5672), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [204146] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6425), 1,
      sym__type_declarator,
    STATE(6755), 1,
      sym__type_definition_declarators,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [204196] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(9392), 1,
      anon_sym_LBRACK,
    STATE(4479), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5836), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(9390), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [204232] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9432), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9430), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [204260] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9312), 1,
      anon_sym_SLASH,
    ACTIONS(9314), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(9316), 1,
      anon_sym_AMP_AMP,
    ACTIONS(9318), 1,
      anon_sym_PIPE,
    ACTIONS(9320), 1,
      anon_sym_CARET,
    ACTIONS(9322), 1,
      anon_sym_AMP,
    ACTIONS(9308), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9310), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9324), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9326), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9328), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(9330), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9474), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [204310] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9476), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5694), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [204350] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7767), 1,
      anon_sym_STAR,
    ACTIONS(9478), 1,
      sym_identifier,
    ACTIONS(9480), 1,
      anon_sym_TILDE,
    ACTIONS(9482), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9484), 1,
      anon_sym_template,
    ACTIONS(9486), 1,
      anon_sym_operator,
    STATE(2405), 1,
      sym_qualified_type_identifier,
    STATE(2427), 1,
      sym_dependent_type_identifier,
    STATE(2428), 1,
      sym_template_type,
    STATE(3366), 1,
      sym_operator_name,
    STATE(3388), 1,
      sym_pointer_type_declarator,
    STATE(3389), 1,
      sym_template_function,
    STATE(3393), 1,
      sym_destructor_name,
    STATE(3395), 1,
      sym_dependent_identifier,
    STATE(3396), 1,
      sym_qualified_identifier,
    STATE(5594), 1,
      sym__scope_resolution,
    STATE(8483), 1,
      sym_ms_based_modifier,
    STATE(8571), 1,
      sym_decltype,
  [204414] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9488), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5716), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [204454] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7676), 1,
      anon_sym_STAR,
    ACTIONS(7678), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7680), 1,
      anon_sym_AMP,
    STATE(3634), 1,
      sym_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6259), 1,
      sym__abstract_declarator,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7759), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [204498] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6425), 1,
      sym__type_declarator,
    STATE(7003), 1,
      sym__type_definition_declarators,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [204548] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9284), 1,
      sym_identifier,
    ACTIONS(9288), 1,
      anon_sym_LPAREN2,
    ACTIONS(9290), 1,
      anon_sym_defined,
    ACTIONS(9490), 1,
      sym_number_literal,
    ACTIONS(9292), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9294), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9298), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5592), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [204588] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9494), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9492), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [204616] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6425), 1,
      sym__type_declarator,
    STATE(6827), 1,
      sym__type_definition_declarators,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [204666] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9312), 1,
      anon_sym_SLASH,
    ACTIONS(9308), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9310), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9432), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9430), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [204700] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4194), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(9496), 1,
      sym_identifier,
    ACTIONS(9498), 1,
      anon_sym_template,
    STATE(2199), 1,
      sym_dependent_type_identifier,
    STATE(2205), 1,
      sym_template_type,
    STATE(2228), 1,
      sym_qualified_type_identifier,
    STATE(3063), 1,
      sym_operator_name,
    STATE(3064), 1,
      sym_qualified_identifier,
    STATE(3065), 1,
      sym_dependent_identifier,
    STATE(3072), 1,
      sym_destructor_name,
    STATE(3076), 1,
      sym_template_function,
    STATE(3078), 1,
      sym_pointer_type_declarator,
    STATE(5602), 1,
      sym__scope_resolution,
    STATE(8209), 1,
      sym_ms_based_modifier,
    STATE(8571), 1,
      sym_decltype,
  [204764] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6425), 1,
      sym__type_declarator,
    STATE(6971), 1,
      sym__type_definition_declarators,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [204814] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9284), 1,
      sym_identifier,
    ACTIONS(9288), 1,
      anon_sym_LPAREN2,
    ACTIONS(9290), 1,
      anon_sym_defined,
    ACTIONS(9500), 1,
      sym_number_literal,
    ACTIONS(9292), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9294), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9298), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5537), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [204854] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7767), 1,
      anon_sym_STAR,
    ACTIONS(9502), 1,
      sym_identifier,
    ACTIONS(9504), 1,
      anon_sym_TILDE,
    ACTIONS(9506), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9508), 1,
      anon_sym_template,
    ACTIONS(9510), 1,
      anon_sym_operator,
    STATE(2199), 1,
      sym_dependent_type_identifier,
    STATE(2205), 1,
      sym_template_type,
    STATE(2228), 1,
      sym_qualified_type_identifier,
    STATE(3572), 1,
      sym_operator_name,
    STATE(3583), 1,
      sym_qualified_identifier,
    STATE(3588), 1,
      sym_dependent_identifier,
    STATE(3589), 1,
      sym_destructor_name,
    STATE(3590), 1,
      sym_template_function,
    STATE(3593), 1,
      sym_pointer_type_declarator,
    STATE(5605), 1,
      sym__scope_resolution,
    STATE(8483), 1,
      sym_ms_based_modifier,
    STATE(8571), 1,
      sym_decltype,
  [204918] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9512), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5699), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [204958] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7777), 1,
      anon_sym_STAR,
    ACTIONS(9446), 1,
      anon_sym_TILDE,
    ACTIONS(9452), 1,
      anon_sym_operator,
    ACTIONS(9514), 1,
      sym_identifier,
    ACTIONS(9516), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9518), 1,
      anon_sym_template,
    STATE(2199), 1,
      sym_dependent_type_identifier,
    STATE(2205), 1,
      sym_template_type,
    STATE(2228), 1,
      sym_qualified_type_identifier,
    STATE(2820), 1,
      sym_pointer_type_declarator,
    STATE(2835), 1,
      sym_template_function,
    STATE(2837), 1,
      sym_destructor_name,
    STATE(2839), 1,
      sym_dependent_identifier,
    STATE(2841), 1,
      sym_qualified_identifier,
    STATE(2847), 1,
      sym_operator_name,
    STATE(5607), 1,
      sym__scope_resolution,
    STATE(8179), 1,
      sym_ms_based_modifier,
    STATE(8571), 1,
      sym_decltype,
  [205022] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9520), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5691), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [205062] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9522), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5685), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [205102] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6425), 1,
      sym__type_declarator,
    STATE(6988), 1,
      sym__type_definition_declarators,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [205152] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9312), 1,
      anon_sym_SLASH,
    ACTIONS(9308), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9310), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9330), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9432), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9430), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [205188] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9524), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5701), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [205228] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9526), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5680), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [205268] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9530), 5,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9528), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [205296] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9312), 1,
      anon_sym_SLASH,
    ACTIONS(9310), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9432), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9430), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [205328] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6425), 1,
      sym__type_declarator,
    STATE(6976), 1,
      sym__type_definition_declarators,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [205378] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9312), 1,
      anon_sym_SLASH,
    ACTIONS(9316), 1,
      anon_sym_AMP_AMP,
    ACTIONS(9318), 1,
      anon_sym_PIPE,
    ACTIONS(9320), 1,
      anon_sym_CARET,
    ACTIONS(9322), 1,
      anon_sym_AMP,
    ACTIONS(9308), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9310), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9324), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9326), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9328), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(9330), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9430), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
  [205426] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9312), 1,
      anon_sym_SLASH,
    ACTIONS(9308), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9310), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9326), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9328), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(9330), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9432), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(9430), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [205466] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9532), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5684), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [205506] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9312), 1,
      anon_sym_SLASH,
    ACTIONS(9308), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9310), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9324), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9326), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9328), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(9330), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9432), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(9430), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
  [205548] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6425), 1,
      sym__type_declarator,
    STATE(6910), 1,
      sym__type_definition_declarators,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [205598] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9534), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5686), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [205638] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7691), 1,
      anon_sym_STAR,
    ACTIONS(9408), 1,
      anon_sym_TILDE,
    ACTIONS(9414), 1,
      anon_sym_operator,
    ACTIONS(9536), 1,
      sym_identifier,
    ACTIONS(9538), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9540), 1,
      anon_sym_template,
    STATE(2199), 1,
      sym_dependent_type_identifier,
    STATE(2205), 1,
      sym_template_type,
    STATE(2228), 1,
      sym_qualified_type_identifier,
    STATE(3660), 1,
      sym_template_function,
    STATE(3661), 1,
      sym_destructor_name,
    STATE(3784), 1,
      sym_pointer_type_declarator,
    STATE(3788), 1,
      sym_dependent_identifier,
    STATE(3790), 1,
      sym_qualified_identifier,
    STATE(3792), 1,
      sym_operator_name,
    STATE(5623), 1,
      sym__scope_resolution,
    STATE(7998), 1,
      sym_ms_based_modifier,
    STATE(8571), 1,
      sym_decltype,
  [205702] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7777), 1,
      anon_sym_STAR,
    ACTIONS(9228), 1,
      anon_sym_TILDE,
    ACTIONS(9542), 1,
      sym_identifier,
    ACTIONS(9544), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9546), 1,
      anon_sym_template,
    ACTIONS(9548), 1,
      anon_sym_operator,
    STATE(2199), 1,
      sym_dependent_type_identifier,
    STATE(2205), 1,
      sym_template_type,
    STATE(2228), 1,
      sym_qualified_type_identifier,
    STATE(3063), 1,
      sym_operator_name,
    STATE(3064), 1,
      sym_qualified_identifier,
    STATE(3065), 1,
      sym_dependent_identifier,
    STATE(3072), 1,
      sym_destructor_name,
    STATE(3076), 1,
      sym_template_function,
    STATE(3078), 1,
      sym_pointer_type_declarator,
    STATE(5624), 1,
      sym__scope_resolution,
    STATE(8179), 1,
      sym_ms_based_modifier,
    STATE(8571), 1,
      sym_decltype,
  [205766] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7767), 1,
      anon_sym_STAR,
    ACTIONS(9504), 1,
      anon_sym_TILDE,
    ACTIONS(9510), 1,
      anon_sym_operator,
    ACTIONS(9550), 1,
      sym_identifier,
    ACTIONS(9552), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9554), 1,
      anon_sym_template,
    STATE(2405), 1,
      sym_qualified_type_identifier,
    STATE(2427), 1,
      sym_dependent_type_identifier,
    STATE(2428), 1,
      sym_template_type,
    STATE(3572), 1,
      sym_operator_name,
    STATE(3583), 1,
      sym_qualified_identifier,
    STATE(3588), 1,
      sym_dependent_identifier,
    STATE(3589), 1,
      sym_destructor_name,
    STATE(3590), 1,
      sym_template_function,
    STATE(3593), 1,
      sym_pointer_type_declarator,
    STATE(5625), 1,
      sym__scope_resolution,
    STATE(8483), 1,
      sym_ms_based_modifier,
    STATE(8571), 1,
      sym_decltype,
  [205830] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym___attribute__,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(7855), 1,
      anon_sym_LPAREN2,
    ACTIONS(7863), 1,
      sym_identifier,
    ACTIONS(7865), 1,
      anon_sym_STAR,
    ACTIONS(7867), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7869), 1,
      anon_sym_AMP,
    ACTIONS(9556), 1,
      anon_sym_SEMI,
    STATE(5385), 1,
      sym__field_declarator,
    STATE(6214), 1,
      sym_operator_name,
    STATE(7986), 1,
      sym_ms_based_modifier,
    STATE(8365), 1,
      sym_attribute_specifier,
    STATE(6289), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
  [205882] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9312), 1,
      anon_sym_SLASH,
    ACTIONS(9318), 1,
      anon_sym_PIPE,
    ACTIONS(9320), 1,
      anon_sym_CARET,
    ACTIONS(9322), 1,
      anon_sym_AMP,
    ACTIONS(9308), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9310), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9324), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9326), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9328), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(9330), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9430), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
  [205928] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7777), 1,
      anon_sym_STAR,
    ACTIONS(9446), 1,
      anon_sym_TILDE,
    ACTIONS(9452), 1,
      anon_sym_operator,
    ACTIONS(9558), 1,
      sym_identifier,
    ACTIONS(9560), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9562), 1,
      anon_sym_template,
    STATE(2199), 1,
      sym_dependent_type_identifier,
    STATE(2205), 1,
      sym_template_type,
    STATE(2228), 1,
      sym_qualified_type_identifier,
    STATE(2820), 1,
      sym_pointer_type_declarator,
    STATE(2835), 1,
      sym_template_function,
    STATE(2837), 1,
      sym_destructor_name,
    STATE(2839), 1,
      sym_dependent_identifier,
    STATE(2841), 1,
      sym_qualified_identifier,
    STATE(2847), 1,
      sym_operator_name,
    STATE(5628), 1,
      sym__scope_resolution,
    STATE(8179), 1,
      sym_ms_based_modifier,
    STATE(8571), 1,
      sym_decltype,
  [205992] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9312), 1,
      anon_sym_SLASH,
    ACTIONS(9322), 1,
      anon_sym_AMP,
    ACTIONS(9432), 1,
      anon_sym_PIPE,
    ACTIONS(9308), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9310), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9324), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9326), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9328), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(9330), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9430), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
  [206036] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6425), 1,
      sym__type_declarator,
    STATE(6861), 1,
      sym__type_definition_declarators,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [206086] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9564), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5743), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [206126] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9566), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5715), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [206166] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9568), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5703), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [206206] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9284), 1,
      sym_identifier,
    ACTIONS(9288), 1,
      anon_sym_LPAREN2,
    ACTIONS(9290), 1,
      anon_sym_defined,
    ACTIONS(9570), 1,
      sym_number_literal,
    ACTIONS(9292), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9294), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9298), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5679), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [206246] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6896), 1,
      anon_sym_DASH_GT,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    STATE(5709), 1,
      sym_trailing_return_type,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5957), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [206286] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7767), 1,
      anon_sym_STAR,
    ACTIONS(9480), 1,
      anon_sym_TILDE,
    ACTIONS(9486), 1,
      anon_sym_operator,
    ACTIONS(9572), 1,
      sym_identifier,
    ACTIONS(9574), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9576), 1,
      anon_sym_template,
    STATE(2199), 1,
      sym_dependent_type_identifier,
    STATE(2205), 1,
      sym_template_type,
    STATE(2228), 1,
      sym_qualified_type_identifier,
    STATE(3366), 1,
      sym_operator_name,
    STATE(3388), 1,
      sym_pointer_type_declarator,
    STATE(3389), 1,
      sym_template_function,
    STATE(3393), 1,
      sym_destructor_name,
    STATE(3395), 1,
      sym_dependent_identifier,
    STATE(3396), 1,
      sym_qualified_identifier,
    STATE(5636), 1,
      sym__scope_resolution,
    STATE(8483), 1,
      sym_ms_based_modifier,
    STATE(8571), 1,
      sym_decltype,
  [206350] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9578), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5666), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [206390] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9340), 1,
      sym_identifier,
    ACTIONS(9342), 1,
      anon_sym_LPAREN2,
    ACTIONS(9344), 1,
      anon_sym_defined,
    ACTIONS(9580), 1,
      sym_number_literal,
    ACTIONS(9346), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9348), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9352), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5706), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [206430] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7767), 1,
      anon_sym_STAR,
    ACTIONS(9504), 1,
      anon_sym_TILDE,
    ACTIONS(9510), 1,
      anon_sym_operator,
    ACTIONS(9582), 1,
      sym_identifier,
    ACTIONS(9584), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9586), 1,
      anon_sym_template,
    STATE(2199), 1,
      sym_dependent_type_identifier,
    STATE(2205), 1,
      sym_template_type,
    STATE(2228), 1,
      sym_qualified_type_identifier,
    STATE(3572), 1,
      sym_operator_name,
    STATE(3583), 1,
      sym_qualified_identifier,
    STATE(3588), 1,
      sym_dependent_identifier,
    STATE(3589), 1,
      sym_destructor_name,
    STATE(3590), 1,
      sym_template_function,
    STATE(3593), 1,
      sym_pointer_type_declarator,
    STATE(5639), 1,
      sym__scope_resolution,
    STATE(8483), 1,
      sym_ms_based_modifier,
    STATE(8571), 1,
      sym_decltype,
  [206494] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9284), 1,
      sym_identifier,
    ACTIONS(9288), 1,
      anon_sym_LPAREN2,
    ACTIONS(9290), 1,
      anon_sym_defined,
    ACTIONS(9588), 1,
      sym_number_literal,
    ACTIONS(9292), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(9294), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9298), 5,
      anon_sym_L_SQUOTE,
      anon_sym_u_SQUOTE,
      anon_sym_U_SQUOTE,
      anon_sym_u8_SQUOTE,
      anon_sym_SQUOTE,
    STATE(5615), 7,
      sym__preproc_expression,
      sym_preproc_parenthesized_expression,
      sym_preproc_defined,
      sym_preproc_unary_expression,
      sym_preproc_call_expression,
      sym_preproc_binary_expression,
      sym_char_literal,
  [206534] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5113), 1,
      anon_sym_LBRACK,
    ACTIONS(5115), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [206561] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7703), 1,
      sym_identifier,
    ACTIONS(7705), 1,
      anon_sym_LPAREN2,
    ACTIONS(7707), 1,
      anon_sym_STAR,
    ACTIONS(7709), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7711), 1,
      anon_sym_AMP,
    ACTIONS(7715), 1,
      sym_primitive_type,
    STATE(6088), 1,
      sym__type_declarator,
    STATE(6279), 1,
      sym_pointer_type_declarator,
    STATE(8225), 1,
      sym_ms_based_modifier,
    ACTIONS(7713), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6273), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [206608] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5957), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [206643] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5901), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7707), 1,
      anon_sym_STAR,
    ACTIONS(9590), 1,
      sym_identifier,
    ACTIONS(9592), 1,
      anon_sym_template,
    STATE(5644), 1,
      sym__scope_resolution,
    STATE(6234), 1,
      sym_dependent_identifier,
    STATE(6244), 1,
      sym_destructor_name,
    STATE(6251), 1,
      sym_template_function,
    STATE(6263), 1,
      sym_pointer_type_declarator,
    STATE(6286), 1,
      sym_qualified_identifier,
    STATE(6287), 1,
      sym_operator_name,
    STATE(8225), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [206700] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5168), 1,
      anon_sym_LBRACK,
    ACTIONS(5170), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [206727] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3709), 1,
      anon_sym_LBRACE,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9594), 1,
      sym_identifier,
    ACTIONS(9596), 1,
      anon_sym_COLON_COLON,
    STATE(955), 1,
      sym_template_type,
    STATE(1024), 1,
      sym_field_declaration_list,
    STATE(5820), 1,
      sym_attribute_declaration,
    STATE(6467), 1,
      sym__scope_resolution,
    STATE(7006), 1,
      sym_virtual_specifier,
    STATE(7721), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(914), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [206782] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9600), 1,
      anon_sym_LPAREN2,
    ACTIONS(9602), 1,
      anon_sym_LBRACK,
    ACTIONS(9598), 17,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [206811] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5137), 1,
      anon_sym_LBRACK,
    ACTIONS(5139), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [206838] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5157), 1,
      anon_sym_LBRACK,
    ACTIONS(5159), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [206865] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7777), 1,
      anon_sym_STAR,
    ACTIONS(7779), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7781), 1,
      anon_sym_AMP,
    STATE(2537), 1,
      sym__type_declarator,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(8179), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [206912] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(7073), 1,
      anon_sym_DASH_GT,
    ACTIONS(9366), 1,
      anon_sym_LBRACK,
    STATE(5726), 1,
      sym_trailing_return_type,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5956), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [206951] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(7073), 1,
      anon_sym_DASH_GT,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    STATE(5709), 1,
      sym_trailing_return_type,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5957), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [206990] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(1982), 1,
      anon_sym_LBRACE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9604), 1,
      sym_identifier,
    ACTIONS(9606), 1,
      anon_sym_COLON_COLON,
    STATE(284), 1,
      sym_template_type,
    STATE(525), 1,
      sym_field_declaration_list,
    STATE(5789), 1,
      sym_attribute_declaration,
    STATE(6457), 1,
      sym__scope_resolution,
    STATE(6985), 1,
      sym_virtual_specifier,
    STATE(7782), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(159), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [207045] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5119), 1,
      anon_sym_LBRACK,
    ACTIONS(5121), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [207072] = 12,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9608), 1,
      anon_sym_LF,
    ACTIONS(9614), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(9616), 1,
      anon_sym_AMP_AMP,
    ACTIONS(9618), 1,
      anon_sym_PIPE,
    ACTIONS(9620), 1,
      anon_sym_CARET,
    ACTIONS(9622), 1,
      anon_sym_AMP,
    ACTIONS(9610), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9624), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9628), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9612), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(9626), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [207117] = 12,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9614), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(9616), 1,
      anon_sym_AMP_AMP,
    ACTIONS(9618), 1,
      anon_sym_PIPE,
    ACTIONS(9620), 1,
      anon_sym_CARET,
    ACTIONS(9622), 1,
      anon_sym_AMP,
    ACTIONS(9630), 1,
      anon_sym_LF,
    ACTIONS(9610), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9624), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9628), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9612), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(9626), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [207162] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9634), 1,
      anon_sym_LBRACK,
    ACTIONS(9632), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [207189] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9398), 1,
      anon_sym_LF,
    ACTIONS(9400), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [207216] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(9636), 1,
      sym_identifier,
    ACTIONS(9638), 1,
      anon_sym_COLON_COLON,
    STATE(525), 1,
      sym_field_declaration_list,
    STATE(2193), 1,
      sym_template_type,
    STATE(5801), 1,
      sym_attribute_declaration,
    STATE(6488), 1,
      sym__scope_resolution,
    STATE(6728), 1,
      sym_virtual_specifier,
    STATE(7542), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6465), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [207271] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7783), 1,
      anon_sym_STAR,
    ACTIONS(7785), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7787), 1,
      anon_sym_AMP,
    STATE(3708), 1,
      sym_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6403), 1,
      sym__abstract_declarator,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7759), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [207314] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9642), 1,
      anon_sym_LBRACK,
    ACTIONS(9640), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [207341] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(1913), 1,
      anon_sym_LBRACE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9644), 1,
      sym_identifier,
    ACTIONS(9646), 1,
      anon_sym_COLON_COLON,
    STATE(148), 1,
      sym_template_type,
    STATE(201), 1,
      sym_field_declaration_list,
    STATE(5763), 1,
      sym_attribute_declaration,
    STATE(6456), 1,
      sym__scope_resolution,
    STATE(6939), 1,
      sym_virtual_specifier,
    STATE(7741), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(135), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [207396] = 12,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9614), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(9616), 1,
      anon_sym_AMP_AMP,
    ACTIONS(9618), 1,
      anon_sym_PIPE,
    ACTIONS(9620), 1,
      anon_sym_CARET,
    ACTIONS(9622), 1,
      anon_sym_AMP,
    ACTIONS(9648), 1,
      anon_sym_LF,
    ACTIONS(9610), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9624), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9628), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9612), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(9626), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [207441] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(7073), 1,
      anon_sym_DASH_GT,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    STATE(5643), 1,
      sym_trailing_return_type,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [207480] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5141), 1,
      anon_sym_LBRACK,
    ACTIONS(5143), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [207507] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9358), 1,
      anon_sym_LF,
    ACTIONS(9360), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [207534] = 12,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9614), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(9616), 1,
      anon_sym_AMP_AMP,
    ACTIONS(9618), 1,
      anon_sym_PIPE,
    ACTIONS(9620), 1,
      anon_sym_CARET,
    ACTIONS(9622), 1,
      anon_sym_AMP,
    ACTIONS(9650), 1,
      anon_sym_LF,
    ACTIONS(9610), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9624), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9628), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9612), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(9626), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [207579] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7763), 1,
      sym_identifier,
    ACTIONS(7765), 1,
      anon_sym_LPAREN2,
    ACTIONS(7767), 1,
      anon_sym_STAR,
    ACTIONS(7769), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7771), 1,
      anon_sym_AMP,
    ACTIONS(7775), 1,
      sym_primitive_type,
    STATE(3127), 1,
      sym__type_declarator,
    STATE(3404), 1,
      sym_pointer_type_declarator,
    STATE(8483), 1,
      sym_ms_based_modifier,
    ACTIONS(7773), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3401), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [207626] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6605), 1,
      sym__type_declarator,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [207673] = 12,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9614), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(9616), 1,
      anon_sym_AMP_AMP,
    ACTIONS(9618), 1,
      anon_sym_PIPE,
    ACTIONS(9620), 1,
      anon_sym_CARET,
    ACTIONS(9622), 1,
      anon_sym_AMP,
    ACTIONS(9652), 1,
      anon_sym_LF,
    ACTIONS(9610), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9624), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9628), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9612), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(9626), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [207718] = 12,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9614), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(9616), 1,
      anon_sym_AMP_AMP,
    ACTIONS(9618), 1,
      anon_sym_PIPE,
    ACTIONS(9620), 1,
      anon_sym_CARET,
    ACTIONS(9622), 1,
      anon_sym_AMP,
    ACTIONS(9654), 1,
      anon_sym_LF,
    ACTIONS(9610), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9624), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9628), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9612), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(9626), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [207763] = 12,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9614), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(9616), 1,
      anon_sym_AMP_AMP,
    ACTIONS(9618), 1,
      anon_sym_PIPE,
    ACTIONS(9620), 1,
      anon_sym_CARET,
    ACTIONS(9622), 1,
      anon_sym_AMP,
    ACTIONS(9656), 1,
      anon_sym_LF,
    ACTIONS(9610), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9624), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9628), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9612), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(9626), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [207808] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7073), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8634), 1,
      anon_sym_requires,
    STATE(5721), 1,
      sym_trailing_return_type,
    ACTIONS(8631), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [207847] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9368), 1,
      anon_sym_LF,
    ACTIONS(9370), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [207874] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [207909] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8634), 1,
      anon_sym_requires,
    ACTIONS(8631), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [207944] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9312), 1,
      anon_sym_SLASH,
    ACTIONS(9314), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(9316), 1,
      anon_sym_AMP_AMP,
    ACTIONS(9318), 1,
      anon_sym_PIPE,
    ACTIONS(9320), 1,
      anon_sym_CARET,
    ACTIONS(9322), 1,
      anon_sym_AMP,
    ACTIONS(9658), 1,
      anon_sym_RPAREN,
    ACTIONS(9308), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9310), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9324), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9326), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9328), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(9330), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [207993] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6952), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(9660), 1,
      sym_identifier,
    ACTIONS(9662), 1,
      anon_sym_template,
    STATE(3063), 1,
      sym_operator_name,
    STATE(3064), 1,
      sym_qualified_identifier,
    STATE(3065), 1,
      sym_dependent_identifier,
    STATE(3072), 1,
      sym_destructor_name,
    STATE(3076), 1,
      sym_template_function,
    STATE(3078), 1,
      sym_pointer_type_declarator,
    STATE(5678), 1,
      sym__scope_resolution,
    STATE(8209), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [208050] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9312), 1,
      anon_sym_SLASH,
    ACTIONS(9314), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(9316), 1,
      anon_sym_AMP_AMP,
    ACTIONS(9318), 1,
      anon_sym_PIPE,
    ACTIONS(9320), 1,
      anon_sym_CARET,
    ACTIONS(9322), 1,
      anon_sym_AMP,
    ACTIONS(9664), 1,
      anon_sym_RPAREN,
    ACTIONS(9308), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9310), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(9324), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9326), 2,
      anon_sym_GT,
      anon_sym_LT,
    ACTIONS(9328), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(9330), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [208099] = 9,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9430), 1,
      anon_sym_LF,
    ACTIONS(9622), 1,
      anon_sym_AMP,
    ACTIONS(9610), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9624), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9628), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9612), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(9432), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
    ACTIONS(9626), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [208138] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9528), 1,
      anon_sym_LF,
    ACTIONS(9530), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [208165] = 3,
    ACTIONS(6733), 1,
      anon_sym_LF,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(6731), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [208192] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7703), 1,
      sym_identifier,
    ACTIONS(7705), 1,
      anon_sym_LPAREN2,
    ACTIONS(7715), 1,
      sym_primitive_type,
    ACTIONS(7717), 1,
      anon_sym_STAR,
    ACTIONS(7719), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7721), 1,
      anon_sym_AMP,
    STATE(6279), 1,
      sym_pointer_type_declarator,
    STATE(6529), 1,
      sym__type_declarator,
    STATE(8018), 1,
      sym_ms_based_modifier,
    ACTIONS(7713), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(6273), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [208239] = 12,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9614), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(9616), 1,
      anon_sym_AMP_AMP,
    ACTIONS(9618), 1,
      anon_sym_PIPE,
    ACTIONS(9620), 1,
      anon_sym_CARET,
    ACTIONS(9622), 1,
      anon_sym_AMP,
    ACTIONS(9666), 1,
      anon_sym_LF,
    ACTIONS(9610), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9624), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9628), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9612), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(9626), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [208284] = 8,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9430), 1,
      anon_sym_LF,
    ACTIONS(9610), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9624), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9628), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9612), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(9626), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(9432), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
  [208321] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9430), 1,
      anon_sym_LF,
    ACTIONS(9432), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [208348] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5145), 1,
      anon_sym_LBRACK,
    ACTIONS(5147), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [208375] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6487), 1,
      sym__type_declarator,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [208422] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7073), 1,
      anon_sym_DASH_GT,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(8703), 1,
      anon_sym_requires,
    STATE(5711), 1,
      sym_trailing_return_type,
    ACTIONS(8700), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [208461] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6566), 1,
      sym__type_declarator,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [208508] = 7,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9430), 1,
      anon_sym_LF,
    ACTIONS(9610), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9628), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9612), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(9626), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
    ACTIONS(9432), 7,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
  [208543] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7073), 1,
      anon_sym_DASH_GT,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    ACTIONS(9033), 1,
      anon_sym_requires,
    STATE(5708), 1,
      sym_trailing_return_type,
    ACTIONS(9030), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5957), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [208582] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(1980), 1,
      anon_sym_LBRACE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9668), 1,
      sym_identifier,
    ACTIONS(9670), 1,
      anon_sym_COLON_COLON,
    STATE(305), 1,
      sym_template_type,
    STATE(476), 1,
      sym_field_declaration_list,
    STATE(5804), 1,
      sym_attribute_declaration,
    STATE(6476), 1,
      sym__scope_resolution,
    STATE(6981), 1,
      sym_virtual_specifier,
    STATE(7625), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(156), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [208637] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9430), 1,
      anon_sym_LF,
    ACTIONS(9610), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9612), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(9432), 13,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [208668] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7687), 1,
      sym_identifier,
    ACTIONS(7689), 1,
      anon_sym_LPAREN2,
    ACTIONS(7691), 1,
      anon_sym_STAR,
    ACTIONS(7693), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7695), 1,
      anon_sym_AMP,
    ACTIONS(7701), 1,
      sym_primitive_type,
    STATE(3156), 1,
      sym__type_declarator,
    STATE(3549), 1,
      sym_pointer_type_declarator,
    STATE(7998), 1,
      sym_ms_based_modifier,
    ACTIONS(7699), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(3547), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [208715] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9674), 1,
      anon_sym_LBRACK,
    ACTIONS(9679), 1,
      anon_sym_requires,
    ACTIONS(9676), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5986), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9672), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [208750] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6230), 1,
      sym__type_declarator,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [208797] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7073), 1,
      anon_sym_DASH_GT,
    ACTIONS(9366), 1,
      anon_sym_LBRACK,
    ACTIONS(9419), 1,
      anon_sym_requires,
    STATE(5696), 1,
      sym_trailing_return_type,
    ACTIONS(9416), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5956), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [208836] = 4,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9430), 1,
      anon_sym_LF,
    ACTIONS(9612), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(9432), 15,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [208865] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5231), 1,
      anon_sym_LBRACK,
    ACTIONS(9682), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9684), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5233), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [208896] = 12,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9614), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(9616), 1,
      anon_sym_AMP_AMP,
    ACTIONS(9618), 1,
      anon_sym_PIPE,
    ACTIONS(9620), 1,
      anon_sym_CARET,
    ACTIONS(9622), 1,
      anon_sym_AMP,
    ACTIONS(9686), 1,
      anon_sym_LF,
    ACTIONS(9610), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9624), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9628), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9612), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(9626), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [208941] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5129), 1,
      anon_sym_LBRACK,
    ACTIONS(5131), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [208968] = 12,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9430), 1,
      anon_sym_LF,
    ACTIONS(9432), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(9616), 1,
      anon_sym_AMP_AMP,
    ACTIONS(9618), 1,
      anon_sym_PIPE,
    ACTIONS(9620), 1,
      anon_sym_CARET,
    ACTIONS(9622), 1,
      anon_sym_AMP,
    ACTIONS(9610), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9624), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9628), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9612), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(9626), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [209013] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9376), 1,
      anon_sym_LF,
    ACTIONS(9378), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [209040] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5176), 1,
      anon_sym_LBRACK,
    ACTIONS(5178), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [209067] = 11,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9430), 1,
      anon_sym_LF,
    ACTIONS(9618), 1,
      anon_sym_PIPE,
    ACTIONS(9620), 1,
      anon_sym_CARET,
    ACTIONS(9622), 1,
      anon_sym_AMP,
    ACTIONS(9432), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
    ACTIONS(9610), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9624), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9628), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9612), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(9626), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [209110] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7789), 1,
      anon_sym_STAR,
    ACTIONS(7791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7793), 1,
      anon_sym_AMP,
    STATE(3791), 1,
      sym_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6417), 1,
      sym__abstract_declarator,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7759), 6,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [209153] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9366), 1,
      anon_sym_LBRACK,
    ACTIONS(9419), 1,
      anon_sym_requires,
    ACTIONS(9416), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5956), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [209188] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(9366), 1,
      anon_sym_LBRACK,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5956), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [209223] = 6,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9430), 1,
      anon_sym_LF,
    ACTIONS(9610), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9628), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9612), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(9432), 11,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [209256] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    ACTIONS(9033), 1,
      anon_sym_requires,
    ACTIONS(9030), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5957), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [209291] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9468), 1,
      anon_sym_LF,
    ACTIONS(9470), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [209318] = 12,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9614), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(9616), 1,
      anon_sym_AMP_AMP,
    ACTIONS(9618), 1,
      anon_sym_PIPE,
    ACTIONS(9620), 1,
      anon_sym_CARET,
    ACTIONS(9622), 1,
      anon_sym_AMP,
    ACTIONS(9688), 1,
      anon_sym_LF,
    ACTIONS(9610), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9624), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9628), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9612), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(9626), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [209363] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7737), 1,
      anon_sym_STAR,
    ACTIONS(7739), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7741), 1,
      anon_sym_AMP,
    STATE(3756), 1,
      sym_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6411), 1,
      sym__abstract_declarator,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
    ACTIONS(7759), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [209406] = 12,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9614), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(9616), 1,
      anon_sym_AMP_AMP,
    ACTIONS(9618), 1,
      anon_sym_PIPE,
    ACTIONS(9620), 1,
      anon_sym_CARET,
    ACTIONS(9622), 1,
      anon_sym_AMP,
    ACTIONS(9690), 1,
      anon_sym_LF,
    ACTIONS(9610), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9624), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9628), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9612), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(9626), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [209451] = 12,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9614), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(9616), 1,
      anon_sym_AMP_AMP,
    ACTIONS(9618), 1,
      anon_sym_PIPE,
    ACTIONS(9620), 1,
      anon_sym_CARET,
    ACTIONS(9622), 1,
      anon_sym_AMP,
    ACTIONS(9692), 1,
      anon_sym_LF,
    ACTIONS(9610), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9624), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9628), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9612), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(9626), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [209496] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5172), 1,
      anon_sym_LBRACK,
    ACTIONS(5174), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [209523] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6213), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(9272), 1,
      sym_identifier,
    ACTIONS(9274), 1,
      anon_sym_template,
    STATE(3063), 1,
      sym_operator_name,
    STATE(3064), 1,
      sym_qualified_identifier,
    STATE(3065), 1,
      sym_dependent_identifier,
    STATE(3072), 1,
      sym_destructor_name,
    STATE(3076), 1,
      sym_template_function,
    STATE(3078), 1,
      sym_pointer_type_declarator,
    STATE(5718), 1,
      sym__scope_resolution,
    STATE(8209), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [209580] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5252), 1,
      anon_sym_LBRACK,
    ACTIONS(9684), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5254), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [209609] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5149), 1,
      anon_sym_LBRACK,
    ACTIONS(5151), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [209636] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(8703), 1,
      anon_sym_requires,
    ACTIONS(8700), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [209671] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9696), 1,
      anon_sym_LBRACK,
    ACTIONS(9694), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [209698] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(7073), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(5675), 1,
      sym_trailing_return_type,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [209737] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(1988), 1,
      anon_sym_LBRACE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9698), 1,
      sym_identifier,
    ACTIONS(9700), 1,
      anon_sym_COLON_COLON,
    STATE(243), 1,
      sym_template_type,
    STATE(384), 1,
      sym_field_declaration_list,
    STATE(5785), 1,
      sym_attribute_declaration,
    STATE(6472), 1,
      sym__scope_resolution,
    STATE(6877), 1,
      sym_virtual_specifier,
    STATE(7826), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(162), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [209792] = 12,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9614), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(9616), 1,
      anon_sym_AMP_AMP,
    ACTIONS(9618), 1,
      anon_sym_PIPE,
    ACTIONS(9620), 1,
      anon_sym_CARET,
    ACTIONS(9622), 1,
      anon_sym_AMP,
    ACTIONS(9702), 1,
      anon_sym_LF,
    ACTIONS(9610), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9624), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9628), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9612), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(9626), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [209837] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(9674), 1,
      anon_sym_LBRACK,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5986), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9672), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [209872] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9706), 1,
      anon_sym_LBRACK,
    ACTIONS(9704), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [209899] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6568), 1,
      sym__type_declarator,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [209946] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7735), 1,
      sym_primitive_type,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(7745), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7747), 1,
      anon_sym_AMP,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6581), 1,
      sym__type_declarator,
    STATE(8209), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [209993] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7743), 1,
      anon_sym_STAR,
    ACTIONS(9708), 1,
      sym_identifier,
    ACTIONS(9710), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9712), 1,
      anon_sym_template,
    STATE(3063), 1,
      sym_operator_name,
    STATE(3064), 1,
      sym_qualified_identifier,
    STATE(3065), 1,
      sym_dependent_identifier,
    STATE(3072), 1,
      sym_destructor_name,
    STATE(3076), 1,
      sym_template_function,
    STATE(3078), 1,
      sym_pointer_type_declarator,
    STATE(5730), 1,
      sym__scope_resolution,
    STATE(8209), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [210050] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5164), 1,
      anon_sym_LBRACK,
    ACTIONS(5166), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [210077] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6942), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7727), 1,
      anon_sym_STAR,
    ACTIONS(9272), 1,
      sym_identifier,
    ACTIONS(9274), 1,
      anon_sym_template,
    STATE(3063), 1,
      sym_operator_name,
    STATE(3064), 1,
      sym_qualified_identifier,
    STATE(3065), 1,
      sym_dependent_identifier,
    STATE(3072), 1,
      sym_destructor_name,
    STATE(3076), 1,
      sym_template_function,
    STATE(3078), 1,
      sym_pointer_type_declarator,
    STATE(5732), 1,
      sym__scope_resolution,
    STATE(8394), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [210134] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(7723), 1,
      sym_identifier,
    ACTIONS(7725), 1,
      anon_sym_LPAREN2,
    ACTIONS(7727), 1,
      anon_sym_STAR,
    ACTIONS(7729), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7731), 1,
      anon_sym_AMP,
    ACTIONS(7735), 1,
      sym_primitive_type,
    STATE(2639), 1,
      sym_pointer_type_declarator,
    STATE(6585), 1,
      sym__type_declarator,
    STATE(8394), 1,
      sym_ms_based_modifier,
    ACTIONS(7733), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
    STATE(2621), 5,
      sym_parenthesized_type_declarator,
      sym_attributed_type_declarator,
      sym_function_type_declarator,
      sym_array_type_declarator,
      sym_reference_type_declarator,
  [210181] = 12,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9614), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(9616), 1,
      anon_sym_AMP_AMP,
    ACTIONS(9618), 1,
      anon_sym_PIPE,
    ACTIONS(9620), 1,
      anon_sym_CARET,
    ACTIONS(9622), 1,
      anon_sym_AMP,
    ACTIONS(9714), 1,
      anon_sym_LF,
    ACTIONS(9610), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9624), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9628), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9612), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(9626), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [210226] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1931), 1,
      anon_sym_LBRACK,
    ACTIONS(1929), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [210253] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9718), 1,
      anon_sym_LBRACK,
    ACTIONS(9716), 18,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_asm,
      anon_sym___asm__,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [210280] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9386), 1,
      anon_sym_LF,
    ACTIONS(9388), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [210307] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9492), 1,
      anon_sym_LF,
    ACTIONS(9494), 18,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
  [210334] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6908), 1,
      anon_sym_requires,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [210369] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1947), 1,
      anon_sym_LBRACK,
    ACTIONS(1945), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [210396] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2603), 1,
      anon_sym_TILDE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6968), 1,
      anon_sym_COLON_COLON,
    ACTIONS(7717), 1,
      anon_sym_STAR,
    ACTIONS(9590), 1,
      sym_identifier,
    ACTIONS(9592), 1,
      anon_sym_template,
    STATE(5741), 1,
      sym__scope_resolution,
    STATE(6234), 1,
      sym_dependent_identifier,
    STATE(6244), 1,
      sym_destructor_name,
    STATE(6251), 1,
      sym_template_function,
    STATE(6263), 1,
      sym_pointer_type_declarator,
    STATE(6286), 1,
      sym_qualified_identifier,
    STATE(6287), 1,
      sym_operator_name,
    STATE(8018), 1,
      sym_ms_based_modifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [210453] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5123), 1,
      anon_sym_LBRACK,
    ACTIONS(5125), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [210480] = 10,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9430), 1,
      anon_sym_LF,
    ACTIONS(9620), 1,
      anon_sym_CARET,
    ACTIONS(9622), 1,
      anon_sym_AMP,
    ACTIONS(9610), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(9624), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(9628), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
    ACTIONS(9432), 3,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE,
    ACTIONS(9612), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(9626), 4,
      anon_sym_GT,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_LT,
  [210521] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5119), 1,
      anon_sym_LBRACK,
    ACTIONS(5121), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [210548] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5119), 1,
      anon_sym_LBRACK,
    ACTIONS(5121), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [210575] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(9144), 1,
      anon_sym_try,
    ACTIONS(9720), 1,
      anon_sym_LPAREN2,
    ACTIONS(9722), 1,
      anon_sym_COLON,
    ACTIONS(9724), 1,
      anon_sym_SEMI,
    ACTIONS(9726), 1,
      anon_sym_LBRACE,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9730), 1,
      anon_sym_EQ,
    STATE(1894), 1,
      sym_compound_statement,
    STATE(1897), 1,
      sym_try_statement,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(7040), 1,
      aux_sym_declaration_repeat1,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(7547), 2,
      sym_argument_list,
      sym_initializer_list,
  [210629] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6078), 1,
      anon_sym_LBRACK,
    ACTIONS(9732), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(5747), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6080), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [210659] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9424), 1,
      anon_sym_LBRACK,
    STATE(5747), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(9422), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [210689] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9636), 1,
      sym_identifier,
    ACTIONS(9735), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9737), 1,
      sym_virtual,
    STATE(2193), 1,
      sym_template_type,
    STATE(6315), 1,
      sym_access_specifier,
    STATE(6506), 1,
      sym__scope_resolution,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(7175), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    ACTIONS(9739), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
  [210737] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(9720), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9730), 1,
      anon_sym_EQ,
    ACTIONS(9741), 1,
      anon_sym_COLON,
    ACTIONS(9743), 1,
      anon_sym_SEMI,
    ACTIONS(9745), 1,
      anon_sym_LBRACE,
    ACTIONS(9747), 1,
      anon_sym_try,
    STATE(297), 1,
      sym_try_statement,
    STATE(298), 1,
      sym_compound_statement,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(7408), 1,
      aux_sym_declaration_repeat1,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(7547), 2,
      sym_argument_list,
      sym_initializer_list,
  [210791] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1883), 1,
      anon_sym_LBRACE,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(9720), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9730), 1,
      anon_sym_EQ,
    ACTIONS(9749), 1,
      anon_sym_COLON,
    ACTIONS(9751), 1,
      anon_sym_SEMI,
    ACTIONS(9753), 1,
      anon_sym_try,
    STATE(711), 1,
      sym_compound_statement,
    STATE(713), 1,
      sym_try_statement,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(7166), 1,
      aux_sym_declaration_repeat1,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(7547), 2,
      sym_argument_list,
      sym_initializer_list,
  [210845] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9636), 1,
      sym_identifier,
    ACTIONS(9735), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9755), 1,
      sym_virtual,
    STATE(2193), 1,
      sym_template_type,
    STATE(6264), 1,
      sym_access_specifier,
    STATE(6506), 1,
      sym__scope_resolution,
    STATE(5756), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6903), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    ACTIONS(9739), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
  [210893] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9759), 1,
      anon_sym_LBRACK,
    STATE(5747), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(9757), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [210923] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(9136), 1,
      anon_sym_try,
    ACTIONS(9720), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9730), 1,
      anon_sym_EQ,
    ACTIONS(9761), 1,
      anon_sym_COLON,
    ACTIONS(9763), 1,
      anon_sym_SEMI,
    ACTIONS(9765), 1,
      anon_sym_LBRACE,
    STATE(1994), 1,
      sym_compound_statement,
    STATE(2127), 1,
      sym_try_statement,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(7119), 1,
      aux_sym_declaration_repeat1,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(7547), 2,
      sym_argument_list,
      sym_initializer_list,
  [210977] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(9720), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9730), 1,
      anon_sym_EQ,
    ACTIONS(9767), 1,
      anon_sym_COLON,
    ACTIONS(9769), 1,
      anon_sym_SEMI,
    ACTIONS(9771), 1,
      anon_sym_LBRACE,
    ACTIONS(9773), 1,
      anon_sym_try,
    STATE(690), 1,
      sym_try_statement,
    STATE(691), 1,
      sym_compound_statement,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(7244), 1,
      aux_sym_declaration_repeat1,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(7547), 2,
      sym_argument_list,
      sym_initializer_list,
  [211031] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9636), 1,
      sym_identifier,
    ACTIONS(9735), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9775), 1,
      sym_virtual,
    STATE(2193), 1,
      sym_template_type,
    STATE(6254), 1,
      sym_access_specifier,
    STATE(6506), 1,
      sym__scope_resolution,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(6943), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    ACTIONS(9739), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
  [211079] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7406), 1,
      anon_sym_LPAREN2,
    ACTIONS(7420), 1,
      anon_sym_LBRACK,
    ACTIONS(7833), 1,
      anon_sym_STAR,
    ACTIONS(7835), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP,
    STATE(3908), 1,
      sym_parameter_list,
    STATE(5936), 1,
      sym__function_declarator_seq,
    STATE(6452), 1,
      sym__abstract_declarator,
    ACTIONS(7759), 5,
      anon_sym_RPAREN,
      anon_sym_LBRACK_LBRACK,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
    STATE(5941), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [211121] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(9152), 1,
      anon_sym_try,
    ACTIONS(9720), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9730), 1,
      anon_sym_EQ,
    ACTIONS(9777), 1,
      anon_sym_COLON,
    ACTIONS(9779), 1,
      anon_sym_SEMI,
    ACTIONS(9781), 1,
      anon_sym_LBRACE,
    STATE(1997), 1,
      sym_compound_statement,
    STATE(1999), 1,
      sym_try_statement,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(7403), 1,
      aux_sym_declaration_repeat1,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(7547), 2,
      sym_argument_list,
      sym_initializer_list,
  [211175] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(9720), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9730), 1,
      anon_sym_EQ,
    ACTIONS(9783), 1,
      anon_sym_COLON,
    ACTIONS(9785), 1,
      anon_sym_SEMI,
    ACTIONS(9787), 1,
      anon_sym_LBRACE,
    ACTIONS(9789), 1,
      anon_sym_try,
    STATE(640), 1,
      sym_try_statement,
    STATE(647), 1,
      sym_compound_statement,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(7217), 1,
      aux_sym_declaration_repeat1,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(7547), 2,
      sym_argument_list,
      sym_initializer_list,
  [211229] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9392), 1,
      anon_sym_LBRACK,
    STATE(5747), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(9390), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [211259] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9636), 1,
      sym_identifier,
    ACTIONS(9735), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9791), 1,
      sym_virtual,
    STATE(2193), 1,
      sym_template_type,
    STATE(6319), 1,
      sym_access_specifier,
    STATE(6506), 1,
      sym__scope_resolution,
    STATE(5749), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(7313), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    ACTIONS(9739), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
  [211307] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9793), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9795), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5233), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [211334] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(1913), 1,
      anon_sym_LBRACE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9644), 1,
      sym_identifier,
    ACTIONS(9646), 1,
      anon_sym_COLON_COLON,
    STATE(148), 1,
      sym_template_type,
    STATE(230), 1,
      sym_field_declaration_list,
    STATE(6456), 1,
      sym__scope_resolution,
    STATE(6980), 1,
      sym_virtual_specifier,
    STATE(7771), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(133), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [211383] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9797), 1,
      anon_sym_LT,
    ACTIONS(9799), 1,
      anon_sym_LBRACE,
    STATE(1967), 1,
      sym_compound_statement,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(5814), 1,
      sym_template_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6853), 1,
      sym_abstract_function_declarator,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [211432] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9797), 1,
      anon_sym_LT,
    ACTIONS(9801), 1,
      anon_sym_LBRACE,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(5769), 1,
      sym_template_parameter_list,
    STATE(5780), 1,
      sym_compound_statement,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6951), 1,
      sym_abstract_function_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [211481] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5147), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [211504] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(7853), 1,
      sym_identifier,
    ACTIONS(7855), 1,
      anon_sym_LPAREN2,
    ACTIONS(7857), 1,
      anon_sym_STAR,
    ACTIONS(7859), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7861), 1,
      anon_sym_AMP,
    STATE(6534), 1,
      sym__field_declarator,
    STATE(6623), 1,
      sym_operator_name,
    STATE(8364), 1,
      sym_ms_based_modifier,
    STATE(6289), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
  [211547] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5115), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [211570] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9801), 1,
      anon_sym_LBRACE,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(5766), 1,
      sym_compound_statement,
    STATE(5921), 1,
      sym_requires_clause,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6936), 1,
      sym_abstract_function_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [211619] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5131), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [211642] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_requires,
    ACTIONS(9803), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6071), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [211673] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9811), 1,
      anon_sym_LBRACK,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5790), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    ACTIONS(9809), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [211702] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5178), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [211725] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9065), 1,
      anon_sym_requires,
    ACTIONS(9062), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [211756] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1945), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [211779] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9813), 1,
      anon_sym_LBRACE,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(3620), 1,
      sym_compound_statement,
    STATE(5965), 1,
      sym_requires_clause,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6876), 1,
      sym_abstract_function_declarator,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [211828] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7871), 1,
      anon_sym_STAR,
    ACTIONS(7873), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7875), 1,
      anon_sym_AMP,
    STATE(3644), 1,
      sym_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6539), 1,
      sym__abstract_declarator,
    ACTIONS(7759), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [211869] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5143), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [211892] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9795), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5254), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [211917] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5166), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [211940] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5151), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [211963] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1929), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [211986] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8913), 1,
      anon_sym_requires,
    ACTIONS(8910), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [212017] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5159), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [212040] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(1988), 1,
      anon_sym_LBRACE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9698), 1,
      sym_identifier,
    ACTIONS(9700), 1,
      anon_sym_COLON_COLON,
    STATE(243), 1,
      sym_template_type,
    STATE(430), 1,
      sym_field_declaration_list,
    STATE(6472), 1,
      sym__scope_resolution,
    STATE(6820), 1,
      sym_virtual_specifier,
    STATE(7798), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(161), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [212089] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5139), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [212112] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5125), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [212135] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9815), 1,
      sym_identifier,
    STATE(5919), 1,
      sym_string_literal,
    STATE(6220), 1,
      sym_raw_string_literal,
    ACTIONS(9817), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
    STATE(6808), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(151), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [212170] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(1982), 1,
      anon_sym_LBRACE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9604), 1,
      sym_identifier,
    ACTIONS(9606), 1,
      anon_sym_COLON_COLON,
    STATE(284), 1,
      sym_template_type,
    STATE(466), 1,
      sym_field_declaration_list,
    STATE(6457), 1,
      sym__scope_resolution,
    STATE(6834), 1,
      sym_virtual_specifier,
    STATE(7668), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(157), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [212219] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9821), 1,
      anon_sym_LBRACK,
    ACTIONS(9823), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5790), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    ACTIONS(9819), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [212248] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9826), 1,
      anon_sym_LBRACE,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(3647), 1,
      sym_compound_statement,
    STATE(5925), 1,
      sym_requires_clause,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6911), 1,
      sym_abstract_function_declarator,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [212297] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7083), 1,
      anon_sym_DASH_GT,
    ACTIONS(7269), 1,
      anon_sym_requires,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    STATE(5946), 1,
      sym_trailing_return_type,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5957), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [212334] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9828), 1,
      anon_sym_LBRACE,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(4280), 1,
      sym_compound_statement,
    STATE(5887), 1,
      sym_requires_clause,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6967), 1,
      sym_abstract_function_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [212383] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9830), 1,
      sym_identifier,
    ACTIONS(5649), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    STATE(5794), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(9833), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(9836), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [212414] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9424), 1,
      anon_sym_LBRACK,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(9422), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [212443] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7083), 1,
      anon_sym_DASH_GT,
    ACTIONS(7269), 1,
      anon_sym_requires,
    ACTIONS(9366), 1,
      anon_sym_LBRACK,
    STATE(5951), 1,
      sym_trailing_return_type,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5956), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [212480] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7142), 1,
      anon_sym_requires,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [212511] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7083), 1,
      anon_sym_DASH_GT,
    ACTIONS(7269), 1,
      anon_sym_requires,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    STATE(5931), 1,
      sym_trailing_return_type,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [212548] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8720), 1,
      anon_sym_requires,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [212579] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9797), 1,
      anon_sym_LT,
    STATE(1967), 1,
      sym_compound_statement,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(5805), 1,
      sym_template_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6887), 1,
      sym_abstract_function_declarator,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [212628] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(9636), 1,
      sym_identifier,
    ACTIONS(9638), 1,
      anon_sym_COLON_COLON,
    STATE(466), 1,
      sym_field_declaration_list,
    STATE(2193), 1,
      sym_template_type,
    STATE(6488), 1,
      sym__scope_resolution,
    STATE(6932), 1,
      sym_virtual_specifier,
    STATE(7558), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(6447), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [212677] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5170), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [212700] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7083), 1,
      anon_sym_DASH_GT,
    ACTIONS(7269), 1,
      anon_sym_requires,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(5904), 1,
      sym_trailing_return_type,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [212737] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(1980), 1,
      anon_sym_LBRACE,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9668), 1,
      sym_identifier,
    ACTIONS(9670), 1,
      anon_sym_COLON_COLON,
    STATE(305), 1,
      sym_template_type,
    STATE(496), 1,
      sym_field_declaration_list,
    STATE(6476), 1,
      sym__scope_resolution,
    STATE(6761), 1,
      sym_virtual_specifier,
    STATE(7641), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(158), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [212786] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    STATE(1960), 1,
      sym_compound_statement,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(5960), 1,
      sym_requires_clause,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6869), 1,
      sym_abstract_function_declarator,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [212835] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7142), 1,
      anon_sym_requires,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [212866] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9839), 1,
      anon_sym_LBRACE,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(5687), 1,
      sym_compound_statement,
    STATE(5928), 1,
      sym_requires_clause,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(7002), 1,
      sym_abstract_function_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [212915] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5121), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [212938] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7142), 1,
      anon_sym_requires,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [212969] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5121), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [212992] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9797), 1,
      anon_sym_LT,
    ACTIONS(9839), 1,
      anon_sym_LBRACE,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(5731), 1,
      sym_compound_statement,
    STATE(5807), 1,
      sym_template_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(7005), 1,
      sym_abstract_function_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [213041] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9797), 1,
      anon_sym_LT,
    ACTIONS(9828), 1,
      anon_sym_LBRACE,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(4302), 1,
      sym_compound_statement,
    STATE(5793), 1,
      sym_template_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6923), 1,
      sym_abstract_function_declarator,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [213090] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9797), 1,
      anon_sym_LT,
    ACTIONS(9841), 1,
      anon_sym_LBRACE,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(3782), 1,
      sym_compound_statement,
    STATE(5824), 1,
      sym_template_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6983), 1,
      sym_abstract_function_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [213139] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9799), 1,
      anon_sym_LBRACE,
    STATE(1960), 1,
      sym_compound_statement,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(5979), 1,
      sym_requires_clause,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6905), 1,
      sym_abstract_function_declarator,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [213188] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(7855), 1,
      anon_sym_LPAREN2,
    ACTIONS(7863), 1,
      sym_identifier,
    ACTIONS(7865), 1,
      anon_sym_STAR,
    ACTIONS(7867), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7869), 1,
      anon_sym_AMP,
    STATE(6058), 1,
      sym__field_declarator,
    STATE(6214), 1,
      sym_operator_name,
    STATE(7986), 1,
      sym_ms_based_modifier,
    STATE(6289), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
  [213231] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5174), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [213254] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(7855), 1,
      anon_sym_LPAREN2,
    ACTIONS(7863), 1,
      sym_identifier,
    ACTIONS(7865), 1,
      anon_sym_STAR,
    ACTIONS(7867), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7869), 1,
      anon_sym_AMP,
    STATE(5947), 1,
      sym__field_declarator,
    STATE(6214), 1,
      sym_operator_name,
    STATE(7986), 1,
      sym_ms_based_modifier,
    STATE(6289), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
  [213297] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5121), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_or,
      anon_sym_and,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [213320] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9392), 1,
      anon_sym_LBRACK,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(9390), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [213349] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(1911), 1,
      anon_sym_COLON,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3709), 1,
      anon_sym_LBRACE,
    ACTIONS(9594), 1,
      sym_identifier,
    ACTIONS(9596), 1,
      anon_sym_COLON_COLON,
    STATE(955), 1,
      sym_template_type,
    STATE(1058), 1,
      sym_field_declaration_list,
    STATE(6467), 1,
      sym__scope_resolution,
    STATE(6739), 1,
      sym_virtual_specifier,
    STATE(7702), 1,
      sym_base_class_clause,
    ACTIONS(1915), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(919), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [213398] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9843), 1,
      anon_sym_LBRACE,
    STATE(2768), 1,
      sym_compound_statement,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(5975), 1,
      sym_requires_clause,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6736), 1,
      sym_abstract_function_declarator,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [213447] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9797), 1,
      anon_sym_LT,
    ACTIONS(9843), 1,
      anon_sym_LBRACE,
    STATE(2763), 1,
      sym_compound_statement,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(5821), 1,
      sym_template_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6727), 1,
      sym_abstract_function_declarator,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [213496] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9797), 1,
      anon_sym_LT,
    ACTIONS(9826), 1,
      anon_sym_LBRACE,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(3626), 1,
      sym_compound_statement,
    STATE(5791), 1,
      sym_template_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6901), 1,
      sym_abstract_function_declarator,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [213545] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9841), 1,
      anon_sym_LBRACE,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(3751), 1,
      sym_compound_statement,
    STATE(5945), 1,
      sym_requires_clause,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6730), 1,
      sym_abstract_function_declarator,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [213594] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9797), 1,
      anon_sym_LT,
    ACTIONS(9845), 1,
      anon_sym_LBRACE,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(3876), 1,
      sym_compound_statement,
    STATE(5832), 1,
      sym_template_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6899), 1,
      sym_abstract_function_declarator,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [213643] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9850), 1,
      anon_sym_requires,
    ACTIONS(9847), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6074), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9672), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [213674] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7083), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8723), 1,
      anon_sym_requires,
    STATE(5976), 1,
      sym_trailing_return_type,
    ACTIONS(8631), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [213711] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7142), 1,
      anon_sym_requires,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6071), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [213742] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9853), 1,
      sym_identifier,
    ACTIONS(5661), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    STATE(5834), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(9855), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(9857), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [213773] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7083), 1,
      anon_sym_DASH_GT,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(8926), 1,
      anon_sym_requires,
    STATE(5985), 1,
      sym_trailing_return_type,
    ACTIONS(8700), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [213810] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(49), 1,
      anon_sym___based,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(7853), 1,
      sym_identifier,
    ACTIONS(7855), 1,
      anon_sym_LPAREN2,
    ACTIONS(7857), 1,
      anon_sym_STAR,
    ACTIONS(7859), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7861), 1,
      anon_sym_AMP,
    STATE(6557), 1,
      sym__field_declarator,
    STATE(6623), 1,
      sym_operator_name,
    STATE(8364), 1,
      sym_ms_based_modifier,
    STATE(6289), 7,
      sym_parenthesized_field_declarator,
      sym_attributed_field_declarator,
      sym_pointer_field_declarator,
      sym_function_field_declarator,
      sym_array_field_declarator,
      sym_reference_field_declarator,
      sym_template_method,
  [213853] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9845), 1,
      anon_sym_LBRACE,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(3965), 1,
      sym_compound_statement,
    STATE(5912), 1,
      sym_requires_clause,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6828), 1,
      sym_abstract_function_declarator,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [213902] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7142), 1,
      anon_sym_requires,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6074), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9672), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [213933] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9859), 1,
      sym_identifier,
    ACTIONS(5667), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    STATE(5794), 3,
      sym_string_literal,
      sym_raw_string_literal,
      aux_sym_concatenated_string_repeat1,
    ACTIONS(9855), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(9857), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [213964] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7083), 1,
      anon_sym_DASH_GT,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    ACTIONS(9059), 1,
      anon_sym_requires,
    STATE(5885), 1,
      sym_trailing_return_type,
    ACTIONS(9030), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5957), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [214001] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9759), 1,
      anon_sym_LBRACK,
    STATE(5333), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(9757), 13,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [214030] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7083), 1,
      anon_sym_DASH_GT,
    ACTIONS(9366), 1,
      anon_sym_LBRACK,
    ACTIONS(9861), 1,
      anon_sym_requires,
    STATE(5987), 1,
      sym_trailing_return_type,
    ACTIONS(9416), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5956), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [214067] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9797), 1,
      anon_sym_LT,
    ACTIONS(9813), 1,
      anon_sym_LBRACE,
    STATE(3483), 1,
      sym_compound_statement,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(5776), 1,
      sym_template_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6896), 1,
      sym_abstract_function_declarator,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [214116] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9864), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5839), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    ACTIONS(9819), 12,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [214142] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7950), 1,
      anon_sym_STAR,
    ACTIONS(7952), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7954), 1,
      anon_sym_AMP,
    STATE(3794), 1,
      sym_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6602), 1,
      sym__abstract_declarator,
    ACTIONS(7759), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [214182] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9867), 1,
      sym_identifier,
    ACTIONS(9869), 1,
      sym_primitive_type,
    STATE(2230), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(2262), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(55), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [214222] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4078), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9867), 1,
      sym_identifier,
    ACTIONS(9869), 1,
      sym_primitive_type,
    STATE(2230), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6449), 1,
      sym__scope_resolution,
    STATE(2262), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(55), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [214262] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9871), 1,
      sym_identifier,
    ACTIONS(9873), 1,
      sym_primitive_type,
    STATE(2571), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6482), 1,
      sym__scope_resolution,
    STATE(2943), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(3762), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [214302] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9875), 1,
      sym_identifier,
    ACTIONS(9877), 1,
      sym_primitive_type,
    STATE(4236), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(4924), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(7527), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [214342] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(8938), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9879), 1,
      sym_identifier,
    ACTIONS(9881), 1,
      sym_primitive_type,
    STATE(4678), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6461), 1,
      sym__scope_resolution,
    STATE(2262), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(7576), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [214382] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7138), 1,
      anon_sym_DASH_GT,
    ACTIONS(7142), 1,
      anon_sym_requires,
    STATE(5828), 1,
      sym_trailing_return_type,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
  [214416] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7138), 1,
      anon_sym_DASH_GT,
    ACTIONS(8720), 1,
      anon_sym_requires,
    STATE(5783), 1,
      sym_trailing_return_type,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
  [214450] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9883), 1,
      sym_identifier,
    ACTIONS(9885), 1,
      sym_primitive_type,
    STATE(5080), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(2476), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(7505), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [214490] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5252), 1,
      anon_sym_AMP,
    ACTIONS(9887), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5254), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_or,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [214516] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9879), 1,
      sym_identifier,
    ACTIONS(9881), 1,
      sym_primitive_type,
    STATE(4678), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(2262), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(7576), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [214556] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(8753), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9873), 1,
      sym_primitive_type,
    ACTIONS(9889), 1,
      sym_identifier,
    STATE(2571), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6505), 1,
      sym__scope_resolution,
    STATE(2943), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(3762), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [214596] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3657), 1,
      anon_sym_LBRACK,
    ACTIONS(3659), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [214620] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7138), 1,
      anon_sym_DASH_GT,
    ACTIONS(8913), 1,
      anon_sym_requires,
    STATE(5774), 1,
      sym_trailing_return_type,
    ACTIONS(8910), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
  [214654] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(8806), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9891), 1,
      sym_identifier,
    ACTIONS(9893), 1,
      sym_primitive_type,
    STATE(2785), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6464), 1,
      sym__scope_resolution,
    STATE(3223), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(8808), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [214694] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9504), 1,
      anon_sym_TILDE,
    ACTIONS(9895), 1,
      sym_identifier,
    ACTIONS(9897), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(9900), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9902), 1,
      anon_sym_template,
    STATE(6114), 1,
      sym__scope_resolution,
    STATE(7633), 1,
      sym_operator_name,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(3633), 4,
      sym_template_method,
      sym_destructor_name,
      sym_dependent_field_identifier,
      sym_qualified_field_identifier,
  [214736] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9904), 1,
      sym_identifier,
    ACTIONS(9906), 1,
      sym_primitive_type,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6489), 1,
      sym__scope_resolution,
    STATE(2476), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [214776] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9875), 1,
      sym_identifier,
    ACTIONS(9877), 1,
      sym_primitive_type,
    STATE(4236), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6475), 1,
      sym__scope_resolution,
    STATE(4924), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(7527), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [214816] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3631), 1,
      anon_sym_LBRACK,
    ACTIONS(3633), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_DASH_GT,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [214840] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3122), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9908), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [214870] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(8828), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9912), 1,
      sym_identifier,
    ACTIONS(9914), 1,
      sym_primitive_type,
    STATE(3545), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6451), 1,
      sym__scope_resolution,
    STATE(4079), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(8830), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [214910] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(8877), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9916), 1,
      sym_identifier,
    ACTIONS(9918), 1,
      sym_primitive_type,
    STATE(2897), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6485), 1,
      sym__scope_resolution,
    STATE(3440), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(8879), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [214950] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7138), 1,
      anon_sym_DASH_GT,
    ACTIONS(7142), 1,
      anon_sym_requires,
    STATE(5809), 1,
      sym_trailing_return_type,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
  [214984] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9920), 1,
      sym_identifier,
    ACTIONS(9922), 1,
      sym_primitive_type,
    STATE(2557), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(2612), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(8786), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [215024] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(8850), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9924), 1,
      sym_identifier,
    ACTIONS(9926), 1,
      sym_primitive_type,
    STATE(2748), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6486), 1,
      sym__scope_resolution,
    STATE(3136), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(8852), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [215064] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9906), 1,
      sym_primitive_type,
    ACTIONS(9928), 1,
      sym_identifier,
    STATE(2443), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(2476), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(2036), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [215104] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7138), 1,
      anon_sym_DASH_GT,
    ACTIONS(9065), 1,
      anon_sym_requires,
    STATE(5771), 1,
      sym_trailing_return_type,
    ACTIONS(9062), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
  [215138] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7138), 1,
      anon_sym_DASH_GT,
    ACTIONS(9806), 1,
      anon_sym_requires,
    STATE(5826), 1,
      sym_trailing_return_type,
    ACTIONS(9803), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6071), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
  [215172] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5839), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    ACTIONS(9809), 12,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [215198] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3122), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9930), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [215228] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3122), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9932), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [215258] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3122), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9934), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [215288] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9938), 1,
      anon_sym___attribute__,
    ACTIONS(9943), 2,
      anon_sym_alignas,
      anon_sym__Alignas,
    ACTIONS(9941), 3,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
    STATE(5872), 3,
      sym_attribute_specifier,
      sym_alignas_qualifier,
      aux_sym__class_declaration_repeat1,
    ACTIONS(9936), 7,
      anon_sym_COLON,
      anon_sym___declspec,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_template,
  [215318] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7138), 1,
      anon_sym_DASH_GT,
    ACTIONS(7142), 1,
      anon_sym_requires,
    STATE(5806), 1,
      sym_trailing_return_type,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
  [215352] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6578), 1,
      sym__abstract_declarator,
    ACTIONS(7759), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [215392] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9946), 1,
      sym_identifier,
    ACTIONS(9948), 1,
      sym_primitive_type,
    STATE(2545), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(2612), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(8899), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [215432] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5231), 1,
      anon_sym_AMP,
    ACTIONS(9887), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(9950), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(5233), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [215460] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3122), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9952), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [215490] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3122), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9954), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [215520] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9867), 1,
      sym_identifier,
    ACTIONS(9869), 1,
      sym_primitive_type,
    STATE(2659), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(2262), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(3495), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [215560] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9956), 1,
      sym_identifier,
    ACTIONS(9958), 1,
      sym_primitive_type,
    STATE(4291), 1,
      aux_sym_sized_type_specifier_repeat1,
    STATE(6459), 1,
      sym__scope_resolution,
    STATE(4977), 2,
      sym_sized_type_specifier,
      sym_qualified_type_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    ACTIONS(7485), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [215600] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3122), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9960), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [215630] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3122), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9962), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [215660] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7138), 1,
      anon_sym_DASH_GT,
    ACTIONS(7142), 1,
      anon_sym_requires,
    STATE(5833), 1,
      sym_trailing_return_type,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6071), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_GT2,
  [215694] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3299), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9908), 11,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [215723] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9366), 1,
      anon_sym_LBRACK,
    ACTIONS(9861), 1,
      anon_sym_requires,
    ACTIONS(9416), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5956), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [215754] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(9964), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [215787] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9828), 1,
      anon_sym_LBRACE,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(4301), 1,
      sym_compound_statement,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6997), 1,
      sym_abstract_function_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [215830] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7330), 1,
      anon_sym_DASH_GT,
    ACTIONS(7337), 1,
      anon_sym_requires,
    STATE(6028), 1,
      sym_trailing_return_type,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [215863] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(8913), 1,
      anon_sym_requires,
    STATE(5774), 1,
      sym_trailing_return_type,
    ACTIONS(8910), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_try,
  [215896] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(8720), 1,
      anon_sym_requires,
    STATE(5783), 1,
      sym_trailing_return_type,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_try,
  [215929] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9968), 1,
      anon_sym_LBRACK,
    ACTIONS(9966), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [215952] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9972), 1,
      anon_sym_LBRACK,
    ACTIONS(9970), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [215975] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5231), 1,
      anon_sym_LBRACK,
    ACTIONS(9974), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(9976), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5233), 10,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [216002] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9446), 1,
      anon_sym_TILDE,
    ACTIONS(9978), 1,
      sym_identifier,
    ACTIONS(9980), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9982), 1,
      anon_sym_template,
    STATE(6146), 1,
      sym__scope_resolution,
    STATE(7692), 1,
      sym_operator_name,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(2798), 4,
      sym_template_method,
      sym_destructor_name,
      sym_dependent_field_identifier,
      sym_qualified_field_identifier,
  [216041] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(9720), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9730), 1,
      anon_sym_EQ,
    ACTIONS(9749), 1,
      anon_sym_COLON,
    ACTIONS(9751), 1,
      anon_sym_SEMI,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(7166), 1,
      aux_sym_declaration_repeat1,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(7547), 2,
      sym_argument_list,
      sym_initializer_list,
  [216086] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(9984), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [216119] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9986), 1,
      sym_identifier,
    ACTIONS(9988), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(9990), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(9992), 1,
      aux_sym_preproc_elif_token1,
    STATE(6348), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(6349), 1,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
    STATE(6559), 1,
      sym_enumerator,
    ACTIONS(9994), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(8094), 3,
      sym_preproc_else_in_enumerator_list,
      sym_preproc_elif_in_enumerator_list,
      sym_preproc_elifdef_in_enumerator_list,
    STATE(8095), 3,
      sym_preproc_else_in_enumerator_list_no_comma,
      sym_preproc_elif_in_enumerator_list_no_comma,
      sym_preproc_elifdef_in_enumerator_list_no_comma,
  [216158] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9998), 1,
      anon_sym_LBRACK,
    ACTIONS(9996), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [216181] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10002), 1,
      anon_sym_LBRACK,
    ACTIONS(10000), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [216204] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8604), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [216227] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10006), 1,
      anon_sym_LBRACK,
    ACTIONS(10004), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [216250] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9446), 1,
      anon_sym_TILDE,
    ACTIONS(9978), 1,
      sym_identifier,
    ACTIONS(10008), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10010), 1,
      anon_sym_template,
    STATE(6174), 1,
      sym__scope_resolution,
    STATE(7549), 1,
      sym_operator_name,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(2798), 4,
      sym_template_method,
      sym_destructor_name,
      sym_dependent_field_identifier,
      sym_qualified_field_identifier,
  [216289] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(8693), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [216312] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7269), 1,
      anon_sym_requires,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [216343] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(9720), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9730), 1,
      anon_sym_EQ,
    ACTIONS(9767), 1,
      anon_sym_COLON,
    ACTIONS(9769), 1,
      anon_sym_SEMI,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(7244), 1,
      aux_sym_declaration_repeat1,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(7547), 2,
      sym_argument_list,
      sym_initializer_list,
  [216388] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7330), 1,
      anon_sym_DASH_GT,
    ACTIONS(7337), 1,
      anon_sym_requires,
    STATE(6066), 1,
      sym_trailing_return_type,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [216421] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10014), 1,
      anon_sym_LBRACK,
    ACTIONS(10012), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [216444] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9815), 1,
      sym_identifier,
    STATE(5919), 1,
      sym_string_literal,
    STATE(6220), 1,
      sym_raw_string_literal,
    STATE(7422), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(151), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [216475] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(9720), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9730), 1,
      anon_sym_EQ,
    ACTIONS(9741), 1,
      anon_sym_COLON,
    ACTIONS(9743), 1,
      anon_sym_SEMI,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(7408), 1,
      aux_sym_declaration_repeat1,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(7547), 2,
      sym_argument_list,
      sym_initializer_list,
  [216520] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9815), 1,
      sym_identifier,
    STATE(5919), 1,
      sym_string_literal,
    STATE(6220), 1,
      sym_raw_string_literal,
    STATE(7143), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(151), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [216551] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9815), 1,
      sym_identifier,
    STATE(5919), 1,
      sym_string_literal,
    STATE(6220), 1,
      sym_raw_string_literal,
    STATE(7425), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(151), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [216582] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9845), 1,
      anon_sym_LBRACE,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(3850), 1,
      sym_compound_statement,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6794), 1,
      sym_abstract_function_declarator,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [216625] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9815), 1,
      sym_identifier,
    STATE(5919), 1,
      sym_string_literal,
    STATE(6220), 1,
      sym_raw_string_literal,
    STATE(7198), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(151), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [216656] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7330), 1,
      anon_sym_DASH_GT,
    ACTIONS(8748), 1,
      anon_sym_requires,
    STATE(5998), 1,
      sym_trailing_return_type,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [216689] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10018), 1,
      anon_sym_LBRACK,
    ACTIONS(10016), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [216712] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10022), 1,
      anon_sym_LBRACK,
    ACTIONS(10020), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [216735] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10026), 1,
      anon_sym_LBRACK,
    ACTIONS(10024), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [216758] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10030), 1,
      anon_sym_LBRACK,
    ACTIONS(10028), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [216781] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(5829), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(5840), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(9855), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(9857), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [216808] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10034), 1,
      anon_sym_LBRACK,
    ACTIONS(10032), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [216831] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9801), 1,
      anon_sym_LBRACE,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(5786), 1,
      sym_compound_statement,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6925), 1,
      sym_abstract_function_declarator,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [216874] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9815), 1,
      sym_identifier,
    STATE(5919), 1,
      sym_string_literal,
    STATE(6220), 1,
      sym_raw_string_literal,
    STATE(7050), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(151), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [216905] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7330), 1,
      anon_sym_DASH_GT,
    ACTIONS(7337), 1,
      anon_sym_requires,
    STATE(6073), 1,
      sym_trailing_return_type,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6071), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [216938] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10038), 1,
      anon_sym_LBRACK,
    ACTIONS(10036), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [216961] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9826), 1,
      anon_sym_LBRACE,
    STATE(3502), 1,
      sym_compound_statement,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6884), 1,
      sym_abstract_function_declarator,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [217004] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7330), 1,
      anon_sym_DASH_GT,
    ACTIONS(7337), 1,
      anon_sym_requires,
    STATE(6006), 1,
      sym_trailing_return_type,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [217037] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    ACTIONS(9023), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [217060] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9839), 1,
      anon_sym_LBRACE,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(5648), 1,
      sym_compound_statement,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(7004), 1,
      sym_abstract_function_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [217103] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7142), 1,
      anon_sym_requires,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    STATE(5809), 1,
      sym_trailing_return_type,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_try,
  [217136] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9504), 1,
      anon_sym_TILDE,
    ACTIONS(9895), 1,
      sym_identifier,
    ACTIONS(9900), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9902), 1,
      anon_sym_template,
    STATE(6114), 1,
      sym__scope_resolution,
    STATE(7633), 1,
      sym_operator_name,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(3633), 4,
      sym_template_method,
      sym_destructor_name,
      sym_dependent_field_identifier,
      sym_qualified_field_identifier,
  [217175] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7269), 1,
      anon_sym_requires,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5957), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [217206] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(9720), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9730), 1,
      anon_sym_EQ,
    ACTIONS(10040), 1,
      anon_sym_COLON,
    ACTIONS(10042), 1,
      anon_sym_SEMI,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(7083), 1,
      aux_sym_declaration_repeat1,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(7547), 2,
      sym_argument_list,
      sym_initializer_list,
  [217251] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10046), 1,
      anon_sym_LBRACK,
    ACTIONS(10044), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [217274] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5252), 1,
      anon_sym_LBRACK,
    ACTIONS(9976), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5254), 12,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_or,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [217299] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9815), 1,
      sym_identifier,
    STATE(5919), 1,
      sym_string_literal,
    STATE(6220), 1,
      sym_raw_string_literal,
    STATE(7162), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(151), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [217330] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10050), 1,
      anon_sym_LBRACK,
    ACTIONS(10048), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [217353] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9815), 1,
      sym_identifier,
    STATE(5919), 1,
      sym_string_literal,
    STATE(6220), 1,
      sym_raw_string_literal,
    STATE(7260), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(151), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [217384] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9815), 1,
      sym_identifier,
    STATE(5919), 1,
      sym_string_literal,
    STATE(6220), 1,
      sym_raw_string_literal,
    STATE(7176), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(151), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [217415] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10052), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [217448] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9815), 1,
      sym_identifier,
    STATE(5919), 1,
      sym_string_literal,
    STATE(6220), 1,
      sym_raw_string_literal,
    STATE(7100), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(151), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [217479] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10056), 1,
      anon_sym_LBRACK,
    ACTIONS(10054), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [217502] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7330), 1,
      anon_sym_DASH_GT,
    ACTIONS(8985), 1,
      anon_sym_requires,
    STATE(6016), 1,
      sym_trailing_return_type,
    ACTIONS(8910), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [217535] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9986), 1,
      sym_identifier,
    ACTIONS(9990), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(9992), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(10058), 1,
      aux_sym_preproc_if_token2,
    STATE(6274), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(6275), 1,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
    STATE(6559), 1,
      sym_enumerator,
    ACTIONS(9994), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(8280), 3,
      sym_preproc_else_in_enumerator_list,
      sym_preproc_elif_in_enumerator_list,
      sym_preproc_elifdef_in_enumerator_list,
    STATE(8281), 3,
      sym_preproc_else_in_enumerator_list_no_comma,
      sym_preproc_elif_in_enumerator_list_no_comma,
      sym_preproc_elifdef_in_enumerator_list_no_comma,
  [217574] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10060), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [217607] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9841), 1,
      anon_sym_LBRACE,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(3692), 1,
      sym_compound_statement,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6763), 1,
      sym_abstract_function_declarator,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [217650] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7269), 1,
      anon_sym_requires,
    ACTIONS(9366), 1,
      anon_sym_LBRACK,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5956), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [217681] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9126), 1,
      anon_sym_COLON,
    ACTIONS(9132), 1,
      anon_sym_LBRACK,
    ACTIONS(10064), 1,
      anon_sym_EQ,
    STATE(3346), 1,
      sym_parameter_list,
    STATE(6281), 1,
      sym__function_declarator_seq,
    STATE(7249), 1,
      sym_bitfield_clause,
    STATE(7251), 1,
      sym_initializer_list,
    STATE(6208), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10062), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
  [217724] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(9065), 1,
      anon_sym_requires,
    STATE(5771), 1,
      sym_trailing_return_type,
    ACTIONS(9062), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_try,
  [217757] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(9720), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9730), 1,
      anon_sym_EQ,
    ACTIONS(10042), 1,
      anon_sym_SEMI,
    ACTIONS(10066), 1,
      anon_sym_COLON,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(7083), 1,
      aux_sym_declaration_repeat1,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(7547), 2,
      sym_argument_list,
      sym_initializer_list,
  [217802] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7142), 1,
      anon_sym_requires,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    STATE(5806), 1,
      sym_trailing_return_type,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_try,
  [217835] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7269), 1,
      anon_sym_requires,
    ACTIONS(9674), 1,
      anon_sym_LBRACK,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5986), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9672), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [217866] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3299), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9930), 11,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [217895] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3299), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9932), 11,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [217924] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3299), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9954), 11,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [217953] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3299), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9962), 11,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [217982] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9674), 1,
      anon_sym_LBRACK,
    ACTIONS(9672), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [218005] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9366), 1,
      anon_sym_LBRACK,
    ACTIONS(9364), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [218028] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3299), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9952), 11,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [218057] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3299), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9934), 11,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [218086] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    STATE(1950), 1,
      sym_compound_statement,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6865), 1,
      sym_abstract_function_declarator,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [218129] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7142), 1,
      anon_sym_requires,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    STATE(5833), 1,
      sym_trailing_return_type,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6071), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_try,
  [218162] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9815), 1,
      sym_identifier,
    STATE(5919), 1,
      sym_string_literal,
    STATE(6220), 1,
      sym_raw_string_literal,
    STATE(7087), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(151), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [218193] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9815), 1,
      sym_identifier,
    STATE(5919), 1,
      sym_string_literal,
    STATE(6220), 1,
      sym_raw_string_literal,
    STATE(7097), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(151), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [218224] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    ACTIONS(9806), 1,
      anon_sym_requires,
    STATE(5826), 1,
      sym_trailing_return_type,
    ACTIONS(9803), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6071), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_try,
  [218257] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9813), 1,
      anon_sym_LBRACE,
    STATE(3488), 1,
      sym_compound_statement,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6978), 1,
      sym_abstract_function_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [218300] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9815), 1,
      sym_identifier,
    STATE(5919), 1,
      sym_string_literal,
    STATE(6220), 1,
      sym_raw_string_literal,
    STATE(7423), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(151), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [218331] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(9720), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9730), 1,
      anon_sym_EQ,
    ACTIONS(10068), 1,
      anon_sym_COLON,
    ACTIONS(10070), 1,
      anon_sym_SEMI,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(7161), 1,
      aux_sym_declaration_repeat1,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(7547), 2,
      sym_argument_list,
      sym_initializer_list,
  [218376] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7330), 1,
      anon_sym_DASH_GT,
    ACTIONS(10072), 1,
      anon_sym_requires,
    STATE(6094), 1,
      sym_trailing_return_type,
    ACTIONS(9803), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6071), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [218409] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9986), 1,
      sym_identifier,
    ACTIONS(9990), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(9992), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(10075), 1,
      aux_sym_preproc_if_token2,
    STATE(6301), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(6314), 1,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
    STATE(6559), 1,
      sym_enumerator,
    ACTIONS(9994), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(8499), 3,
      sym_preproc_else_in_enumerator_list,
      sym_preproc_elif_in_enumerator_list,
      sym_preproc_elifdef_in_enumerator_list,
    STATE(8501), 3,
      sym_preproc_else_in_enumerator_list_no_comma,
      sym_preproc_elif_in_enumerator_list_no_comma,
      sym_preproc_elifdef_in_enumerator_list_no_comma,
  [218448] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3299), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9960), 11,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [218477] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(9720), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9730), 1,
      anon_sym_EQ,
    ACTIONS(9783), 1,
      anon_sym_COLON,
    ACTIONS(9785), 1,
      anon_sym_SEMI,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(7217), 1,
      aux_sym_declaration_repeat1,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(7547), 2,
      sym_argument_list,
      sym_initializer_list,
  [218522] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9408), 1,
      anon_sym_TILDE,
    ACTIONS(10077), 1,
      sym_identifier,
    ACTIONS(10079), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10081), 1,
      anon_sym_template,
    STATE(6131), 1,
      sym__scope_resolution,
    STATE(7757), 1,
      sym_operator_name,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
    STATE(3720), 4,
      sym_template_method,
      sym_destructor_name,
      sym_dependent_field_identifier,
      sym_qualified_field_identifier,
  [218561] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(8723), 1,
      anon_sym_requires,
    ACTIONS(8631), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [218592] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9986), 1,
      sym_identifier,
    ACTIONS(9990), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(9992), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(10083), 1,
      aux_sym_preproc_if_token2,
    STATE(6346), 1,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
    STATE(6347), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(6559), 1,
      sym_enumerator,
    ACTIONS(9994), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(8363), 3,
      sym_preproc_else_in_enumerator_list,
      sym_preproc_elif_in_enumerator_list,
      sym_preproc_elifdef_in_enumerator_list,
    STATE(8368), 3,
      sym_preproc_else_in_enumerator_list_no_comma,
      sym_preproc_elif_in_enumerator_list_no_comma,
      sym_preproc_elifdef_in_enumerator_list_no_comma,
  [218631] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9843), 1,
      anon_sym_LBRACE,
    STATE(2782), 1,
      sym_compound_statement,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6793), 1,
      sym_abstract_function_declarator,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [218674] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(8926), 1,
      anon_sym_requires,
    ACTIONS(8700), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [218705] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7330), 1,
      anon_sym_DASH_GT,
    ACTIONS(9076), 1,
      anon_sym_requires,
    STATE(6019), 1,
      sym_trailing_return_type,
    ACTIONS(9062), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [218738] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9815), 1,
      sym_identifier,
    STATE(5919), 1,
      sym_string_literal,
    STATE(6220), 1,
      sym_raw_string_literal,
    STATE(7310), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(151), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [218769] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(9799), 1,
      anon_sym_LBRACE,
    STATE(1950), 1,
      sym_compound_statement,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6929), 1,
      sym__abstract_declarator,
    STATE(6935), 1,
      sym_abstract_function_declarator,
    STATE(6033), 4,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [218812] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7142), 1,
      anon_sym_requires,
    ACTIONS(7370), 1,
      anon_sym_DASH_GT,
    STATE(5828), 1,
      sym_trailing_return_type,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 6,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_try,
  [218845] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9815), 1,
      sym_identifier,
    STATE(5919), 1,
      sym_string_literal,
    STATE(6220), 1,
      sym_raw_string_literal,
    STATE(7334), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(151), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [218876] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(9720), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10042), 1,
      anon_sym_SEMI,
    ACTIONS(10066), 1,
      anon_sym_COLON,
    ACTIONS(10085), 1,
      anon_sym_EQ,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(7083), 1,
      aux_sym_declaration_repeat1,
    STATE(7406), 1,
      sym_initializer_list,
    STATE(7547), 1,
      sym_argument_list,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [218923] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10087), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [218956] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9815), 1,
      sym_identifier,
    STATE(5919), 1,
      sym_string_literal,
    STATE(6220), 1,
      sym_raw_string_literal,
    STATE(7358), 2,
      sym__string,
      sym_concatenated_string,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(151), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [218987] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    ACTIONS(9059), 1,
      anon_sym_requires,
    ACTIONS(9030), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5957), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [219018] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10091), 1,
      anon_sym_LBRACK,
    ACTIONS(10089), 14,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [219041] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9674), 1,
      anon_sym_LBRACK,
    ACTIONS(10093), 1,
      anon_sym_requires,
    ACTIONS(9676), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5986), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9672), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [219072] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7269), 1,
      anon_sym_requires,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [219103] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7759), 1,
      anon_sym_COLON,
    ACTIONS(8185), 1,
      anon_sym_STAR,
    ACTIONS(8187), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8189), 1,
      anon_sym_AMP,
    STATE(3679), 1,
      sym_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6601), 1,
      sym__abstract_declarator,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [219141] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7426), 1,
      anon_sym_DASH_GT,
    ACTIONS(7441), 1,
      anon_sym_requires,
    STATE(6128), 1,
      sym_trailing_return_type,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [219173] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8669), 1,
      anon_sym_LBRACE,
    ACTIONS(9000), 1,
      sym_identifier,
    STATE(4671), 1,
      sym_template_type,
    STATE(4907), 1,
      sym_enumerator_list,
    STATE(6459), 1,
      sym__scope_resolution,
    ACTIONS(10096), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(4842), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [219213] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7404), 1,
      anon_sym_DASH_GT,
    ACTIONS(8985), 1,
      anon_sym_requires,
    STATE(6016), 1,
      sym_trailing_return_type,
    ACTIONS(8910), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
  [219245] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9636), 1,
      sym_identifier,
    ACTIONS(9735), 1,
      anon_sym_COLON_COLON,
    STATE(2193), 1,
      sym_template_type,
    STATE(6435), 1,
      sym_access_specifier,
    STATE(6506), 1,
      sym__scope_resolution,
    STATE(7180), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    ACTIONS(9739), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
  [219283] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5771), 1,
      sym_identifier,
    ACTIONS(5773), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [219305] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9132), 1,
      anon_sym_LBRACK,
    STATE(3346), 1,
      sym_parameter_list,
    STATE(6281), 1,
      sym__function_declarator_seq,
    STATE(6208), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10098), 7,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [219337] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9815), 1,
      sym_identifier,
    STATE(7965), 1,
      sym_concatenated_string,
    STATE(6129), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(151), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [219365] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(5293), 1,
      sym_enumerator_list,
    STATE(6441), 1,
      sym__scope_resolution,
    ACTIONS(10100), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(4973), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [219405] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8985), 1,
      anon_sym_requires,
    ACTIONS(8910), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [219433] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8503), 1,
      anon_sym_LBRACE,
    ACTIONS(8973), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(4854), 1,
      sym_enumerator_list,
    STATE(6475), 1,
      sym__scope_resolution,
    ACTIONS(10102), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(4600), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [219473] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7404), 1,
      anon_sym_DASH_GT,
    ACTIONS(8748), 1,
      anon_sym_requires,
    STATE(5998), 1,
      sym_trailing_return_type,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
  [219505] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5842), 1,
      anon_sym_LBRACK,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    ACTIONS(10106), 1,
      anon_sym_SEMI,
    ACTIONS(10108), 1,
      anon_sym_LBRACE,
    ACTIONS(10110), 1,
      anon_sym_EQ,
    ACTIONS(10112), 1,
      anon_sym_try,
    STATE(2188), 1,
      sym_compound_statement,
    STATE(7763), 1,
      sym_field_initializer_list,
    ACTIONS(5188), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(2184), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [219543] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8693), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [219563] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5523), 1,
      anon_sym_LBRACE,
    ACTIONS(8973), 1,
      sym_identifier,
    ACTIONS(8975), 1,
      anon_sym_COLON_COLON,
    STATE(2193), 1,
      sym_template_type,
    STATE(5073), 1,
      sym_enumerator_list,
    STATE(6458), 1,
      sym__scope_resolution,
    ACTIONS(10114), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(6391), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [219603] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5842), 1,
      anon_sym_LBRACK,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    ACTIONS(10116), 1,
      anon_sym_SEMI,
    ACTIONS(10118), 1,
      anon_sym_LBRACE,
    ACTIONS(10120), 1,
      anon_sym_EQ,
    ACTIONS(10122), 1,
      anon_sym_try,
    STATE(1911), 1,
      sym_compound_statement,
    STATE(7705), 1,
      sym_field_initializer_list,
    ACTIONS(5188), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(1915), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [219641] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10124), 1,
      anon_sym_LBRACK,
    STATE(6307), 1,
      sym_parameter_list,
    STATE(6112), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6066), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [219671] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [219699] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9636), 1,
      sym_identifier,
    ACTIONS(9735), 1,
      anon_sym_COLON_COLON,
    STATE(2193), 1,
      sym_template_type,
    STATE(6392), 1,
      sym_access_specifier,
    STATE(6506), 1,
      sym__scope_resolution,
    STATE(7175), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    ACTIONS(9739), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
  [219737] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5775), 1,
      sym_identifier,
    ACTIONS(5777), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [219759] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9636), 1,
      sym_identifier,
    ACTIONS(9735), 1,
      anon_sym_COLON_COLON,
    STATE(2193), 1,
      sym_template_type,
    STATE(6431), 1,
      sym_access_specifier,
    STATE(6506), 1,
      sym__scope_resolution,
    STATE(6943), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    ACTIONS(9739), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
  [219797] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9815), 1,
      sym_identifier,
    STATE(8077), 1,
      sym_concatenated_string,
    STATE(6143), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(151), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [219825] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5842), 1,
      anon_sym_LBRACK,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    ACTIONS(10126), 1,
      anon_sym_SEMI,
    ACTIONS(10128), 1,
      anon_sym_LBRACE,
    ACTIONS(10130), 1,
      anon_sym_EQ,
    ACTIONS(10132), 1,
      anon_sym_try,
    STATE(2073), 1,
      sym_compound_statement,
    STATE(7644), 1,
      sym_field_initializer_list,
    ACTIONS(5188), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(2072), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [219863] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10016), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [219883] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(793), 1,
      anon_sym_LBRACE,
    ACTIONS(5842), 1,
      anon_sym_LBRACK,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    ACTIONS(10134), 1,
      anon_sym_SEMI,
    ACTIONS(10136), 1,
      anon_sym_EQ,
    ACTIONS(10138), 1,
      anon_sym_try,
    STATE(650), 1,
      sym_compound_statement,
    STATE(7439), 1,
      sym_field_initializer_list,
    ACTIONS(5188), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(649), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [219921] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(633), 1,
      anon_sym_LBRACE,
    ACTIONS(5842), 1,
      anon_sym_LBRACK,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    ACTIONS(10140), 1,
      anon_sym_SEMI,
    ACTIONS(10142), 1,
      anon_sym_EQ,
    ACTIONS(10144), 1,
      anon_sym_try,
    STATE(686), 1,
      sym_compound_statement,
    STATE(7553), 1,
      sym_field_initializer_list,
    ACTIONS(5188), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(685), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [219959] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7404), 1,
      anon_sym_DASH_GT,
    ACTIONS(9076), 1,
      anon_sym_requires,
    STATE(6019), 1,
      sym_trailing_return_type,
    ACTIONS(9062), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
  [219991] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9076), 1,
      anon_sym_requires,
    ACTIONS(9062), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [220019] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(633), 1,
      anon_sym_LBRACE,
    ACTIONS(5842), 1,
      anon_sym_LBRACK,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    ACTIONS(10142), 1,
      anon_sym_EQ,
    ACTIONS(10144), 1,
      anon_sym_try,
    ACTIONS(10146), 1,
      anon_sym_SEMI,
    STATE(669), 1,
      sym_compound_statement,
    STATE(7529), 1,
      sym_field_initializer_list,
    ACTIONS(5188), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(671), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [220057] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(793), 1,
      anon_sym_LBRACE,
    ACTIONS(5842), 1,
      anon_sym_LBRACK,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    ACTIONS(10136), 1,
      anon_sym_EQ,
    ACTIONS(10138), 1,
      anon_sym_try,
    ACTIONS(10148), 1,
      anon_sym_SEMI,
    STATE(620), 1,
      sym_compound_statement,
    STATE(7831), 1,
      sym_field_initializer_list,
    ACTIONS(5188), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(621), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [220095] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10072), 1,
      anon_sym_requires,
    ACTIONS(9803), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6071), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [220123] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9815), 1,
      sym_identifier,
    STATE(8026), 1,
      sym_concatenated_string,
    STATE(6145), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(151), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [220151] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10028), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [220171] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6560), 1,
      anon_sym_LBRACE,
    ACTIONS(7477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8968), 1,
      sym_identifier,
    STATE(2892), 1,
      sym_template_type,
    STATE(2901), 1,
      sym_enumerator_list,
    STATE(6482), 1,
      sym__scope_resolution,
    ACTIONS(10150), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(4957), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [220211] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10012), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [220231] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2000), 1,
      anon_sym_LT,
    STATE(6210), 1,
      sym_template_argument_list,
    ACTIONS(4050), 2,
      anon_sym_COLON,
      anon_sym_LBRACK,
    ACTIONS(4045), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [220259] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      anon_sym_LBRACE,
    ACTIONS(5842), 1,
      anon_sym_LBRACK,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    ACTIONS(10152), 1,
      anon_sym_SEMI,
    ACTIONS(10154), 1,
      anon_sym_EQ,
    ACTIONS(10156), 1,
      anon_sym_try,
    STATE(299), 1,
      sym_compound_statement,
    STATE(7614), 1,
      sym_field_initializer_list,
    ACTIONS(5188), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(315), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [220297] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5523), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2329), 1,
      sym_enumerator_list,
    STATE(6504), 1,
      sym__scope_resolution,
    ACTIONS(10158), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(2341), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [220337] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9023), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [220357] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [220385] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    ACTIONS(5842), 1,
      anon_sym_LBRACK,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    ACTIONS(10160), 1,
      anon_sym_SEMI,
    ACTIONS(10162), 1,
      anon_sym_EQ,
    ACTIONS(10164), 1,
      anon_sym_try,
    STATE(806), 1,
      sym_compound_statement,
    STATE(7462), 1,
      sym_field_initializer_list,
    ACTIONS(5188), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(808), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [220423] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6602), 1,
      anon_sym_LBRACE,
    ACTIONS(8850), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8996), 1,
      sym_identifier,
    STATE(2883), 1,
      sym_template_type,
    STATE(3036), 1,
      sym_enumerator_list,
    STATE(6486), 1,
      sym__scope_resolution,
    ACTIONS(10166), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(2912), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [220463] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8748), 1,
      anon_sym_requires,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [220491] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7404), 1,
      anon_sym_DASH_GT,
    ACTIONS(10072), 1,
      anon_sym_requires,
    STATE(6094), 1,
      sym_trailing_return_type,
    ACTIONS(9803), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6071), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
  [220523] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10054), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [220543] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7426), 1,
      anon_sym_DASH_GT,
    ACTIONS(7441), 1,
      anon_sym_requires,
    STATE(6172), 1,
      sym_trailing_return_type,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6071), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [220575] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9815), 1,
      sym_identifier,
    STATE(8275), 1,
      sym_concatenated_string,
    STATE(6156), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(151), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [220603] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    ACTIONS(5842), 1,
      anon_sym_LBRACK,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    ACTIONS(10162), 1,
      anon_sym_EQ,
    ACTIONS(10164), 1,
      anon_sym_try,
    ACTIONS(10168), 1,
      anon_sym_SEMI,
    STATE(731), 1,
      sym_compound_statement,
    STATE(7629), 1,
      sym_field_initializer_list,
    ACTIONS(5188), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(728), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [220641] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7426), 1,
      anon_sym_DASH_GT,
    ACTIONS(10170), 1,
      anon_sym_requires,
    STATE(6176), 1,
      sym_trailing_return_type,
    ACTIONS(9803), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6071), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [220673] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9815), 1,
      sym_identifier,
    STATE(7867), 1,
      sym_concatenated_string,
    STATE(6108), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(151), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [220701] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [220729] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9132), 1,
      anon_sym_LBRACK,
    STATE(3346), 1,
      sym_parameter_list,
    STATE(6281), 1,
      sym__function_declarator_seq,
    STATE(6208), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10173), 7,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [220761] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9815), 1,
      sym_identifier,
    STATE(8230), 1,
      sym_concatenated_string,
    STATE(6151), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(151), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [220789] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5911), 1,
      anon_sym_LBRACE,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8931), 1,
      sym_identifier,
    STATE(2498), 1,
      sym_template_type,
    STATE(2552), 1,
      sym_enumerator_list,
    STATE(6497), 1,
      sym__scope_resolution,
    ACTIONS(10175), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(2696), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [220829] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7439), 1,
      anon_sym_DASH_GT,
    ACTIONS(7441), 1,
      anon_sym_requires,
    STATE(6128), 1,
      sym_trailing_return_type,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 5,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [220861] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7439), 1,
      anon_sym_DASH_GT,
    ACTIONS(7441), 1,
      anon_sym_requires,
    STATE(6144), 1,
      sym_trailing_return_type,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 5,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [220893] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5523), 1,
      anon_sym_LBRACE,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2329), 1,
      sym_enumerator_list,
    STATE(6479), 1,
      sym__scope_resolution,
    ACTIONS(10177), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(2777), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [220933] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10024), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [220953] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7439), 1,
      anon_sym_DASH_GT,
    ACTIONS(7441), 1,
      anon_sym_requires,
    STATE(6170), 1,
      sym_trailing_return_type,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 5,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [220985] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9132), 1,
      anon_sym_LBRACK,
    STATE(3346), 1,
      sym_parameter_list,
    STATE(6281), 1,
      sym__function_declarator_seq,
    STATE(6208), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10179), 7,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [221017] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9018), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2741), 1,
      sym_enumerator_list,
    STATE(6489), 1,
      sym__scope_resolution,
    ACTIONS(10181), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(4031), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [221057] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7439), 1,
      anon_sym_DASH_GT,
    ACTIONS(7441), 1,
      anon_sym_requires,
    STATE(6172), 1,
      sym_trailing_return_type,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6071), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 5,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [221089] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9966), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [221109] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9364), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [221129] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5523), 1,
      anon_sym_LBRACE,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(5073), 1,
      sym_enumerator_list,
    STATE(6479), 1,
      sym__scope_resolution,
    ACTIONS(10183), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(5011), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [221169] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5796), 1,
      sym_identifier,
    ACTIONS(5798), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [221191] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6713), 1,
      anon_sym_LBRACE,
    ACTIONS(8877), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8994), 1,
      sym_identifier,
    STATE(3026), 1,
      sym_template_type,
    STATE(3316), 1,
      sym_enumerator_list,
    STATE(6485), 1,
      sym__scope_resolution,
    ACTIONS(10185), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(3080), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [221231] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10124), 1,
      anon_sym_LBRACK,
    STATE(6307), 1,
      sym_parameter_list,
    STATE(6112), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6026), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [221261] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4078), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5523), 1,
      anon_sym_LBRACE,
    ACTIONS(8983), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2329), 1,
      sym_enumerator_list,
    STATE(6449), 1,
      sym__scope_resolution,
    ACTIONS(10187), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(2386), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [221301] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9132), 1,
      anon_sym_LBRACK,
    STATE(3346), 1,
      sym_parameter_list,
    STATE(6281), 1,
      sym__function_declarator_seq,
    STATE(6208), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10189), 7,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [221333] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5523), 1,
      anon_sym_LBRACE,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2329), 1,
      sym_enumerator_list,
    STATE(6479), 1,
      sym__scope_resolution,
    ACTIONS(10191), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(2599), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [221373] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9636), 1,
      sym_identifier,
    ACTIONS(9735), 1,
      anon_sym_COLON_COLON,
    STATE(2193), 1,
      sym_template_type,
    STATE(6398), 1,
      sym_access_specifier,
    STATE(6506), 1,
      sym__scope_resolution,
    STATE(6778), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
    ACTIONS(9739), 3,
      anon_sym_public,
      anon_sym_private,
      anon_sym_protected,
  [221411] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2741), 1,
      sym_enumerator_list,
    STATE(6441), 1,
      sym__scope_resolution,
    ACTIONS(10193), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(4970), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [221451] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      anon_sym_LBRACE,
    ACTIONS(5842), 1,
      anon_sym_LBRACK,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    ACTIONS(10154), 1,
      anon_sym_EQ,
    ACTIONS(10156), 1,
      anon_sym_try,
    ACTIONS(10195), 1,
      anon_sym_SEMI,
    STATE(292), 1,
      sym_compound_statement,
    STATE(7635), 1,
      sym_field_initializer_list,
    ACTIONS(5188), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(291), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [221489] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7439), 1,
      anon_sym_DASH_GT,
    ACTIONS(8779), 1,
      anon_sym_requires,
    STATE(6141), 1,
      sym_trailing_return_type,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 5,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [221521] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7439), 1,
      anon_sym_DASH_GT,
    ACTIONS(9020), 1,
      anon_sym_requires,
    STATE(6165), 1,
      sym_trailing_return_type,
    ACTIONS(8910), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 5,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [221553] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7439), 1,
      anon_sym_DASH_GT,
    ACTIONS(9121), 1,
      anon_sym_requires,
    STATE(6168), 1,
      sym_trailing_return_type,
    ACTIONS(9062), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 5,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [221585] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6071), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [221613] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7439), 1,
      anon_sym_DASH_GT,
    ACTIONS(10170), 1,
      anon_sym_requires,
    STATE(6176), 1,
      sym_trailing_return_type,
    ACTIONS(9803), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6071), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 5,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [221645] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10036), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [221665] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5842), 1,
      anon_sym_LBRACK,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    ACTIONS(10128), 1,
      anon_sym_LBRACE,
    ACTIONS(10130), 1,
      anon_sym_EQ,
    ACTIONS(10132), 1,
      anon_sym_try,
    ACTIONS(10197), 1,
      anon_sym_SEMI,
    STATE(2150), 1,
      sym_compound_statement,
    STATE(7662), 1,
      sym_field_initializer_list,
    ACTIONS(5188), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(2174), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [221703] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6616), 1,
      anon_sym_LBRACE,
    ACTIONS(8806), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8998), 1,
      sym_identifier,
    STATE(2942), 1,
      sym_template_type,
    STATE(3096), 1,
      sym_enumerator_list,
    STATE(6464), 1,
      sym__scope_resolution,
    ACTIONS(10199), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(2928), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [221743] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9672), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [221763] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8604), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [221783] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6074), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9672), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [221811] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10089), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [221831] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7426), 1,
      anon_sym_DASH_GT,
    ACTIONS(9121), 1,
      anon_sym_requires,
    STATE(6168), 1,
      sym_trailing_return_type,
    ACTIONS(9062), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [221863] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10048), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [221883] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10124), 1,
      anon_sym_LBRACK,
    STATE(6307), 1,
      sym_parameter_list,
    STATE(6112), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(5998), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [221913] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5911), 1,
      anon_sym_LBRACE,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8931), 1,
      sym_identifier,
    STATE(2498), 1,
      sym_template_type,
    STATE(2552), 1,
      sym_enumerator_list,
    STATE(6497), 1,
      sym__scope_resolution,
    ACTIONS(10201), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(2784), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [221953] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7426), 1,
      anon_sym_DASH_GT,
    ACTIONS(9020), 1,
      anon_sym_requires,
    STATE(6165), 1,
      sym_trailing_return_type,
    ACTIONS(8910), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [221985] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6560), 1,
      anon_sym_LBRACE,
    ACTIONS(8753), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9007), 1,
      sym_identifier,
    STATE(2892), 1,
      sym_template_type,
    STATE(2901), 1,
      sym_enumerator_list,
    STATE(6505), 1,
      sym__scope_resolution,
    ACTIONS(10203), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(4125), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [222025] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7426), 1,
      anon_sym_DASH_GT,
    ACTIONS(7441), 1,
      anon_sym_requires,
    STATE(6170), 1,
      sym_trailing_return_type,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [222057] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7453), 1,
      anon_sym_LBRACE,
    ACTIONS(8828), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9002), 1,
      sym_identifier,
    STATE(3808), 1,
      sym_template_type,
    STATE(4072), 1,
      sym_enumerator_list,
    STATE(6451), 1,
      sym__scope_resolution,
    ACTIONS(10205), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(3819), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [222097] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5779), 1,
      sym_identifier,
    ACTIONS(5781), 13,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [222119] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10124), 1,
      anon_sym_LBRACK,
    STATE(6307), 1,
      sym_parameter_list,
    STATE(6112), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6002), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [222149] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6278), 1,
      anon_sym_LBRACK,
    ACTIONS(10207), 1,
      anon_sym_LBRACK_RBRACK,
    ACTIONS(6280), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [222173] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10020), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [222193] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7404), 1,
      anon_sym_DASH_GT,
    STATE(6006), 1,
      sym_trailing_return_type,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
  [222225] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10124), 1,
      anon_sym_LBRACK,
    STATE(6307), 1,
      sym_parameter_list,
    STATE(6112), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(5982), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [222255] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7404), 1,
      anon_sym_DASH_GT,
    STATE(6028), 1,
      sym_trailing_return_type,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
  [222287] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7404), 1,
      anon_sym_DASH_GT,
    STATE(6066), 1,
      sym_trailing_return_type,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
  [222319] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8503), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(4854), 1,
      sym_enumerator_list,
    STATE(6479), 1,
      sym__scope_resolution,
    ACTIONS(10209), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(4892), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [222359] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7337), 1,
      anon_sym_requires,
    ACTIONS(7404), 1,
      anon_sym_DASH_GT,
    STATE(6073), 1,
      sym_trailing_return_type,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6071), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
  [222391] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9970), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [222411] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10211), 1,
      anon_sym_requires,
    ACTIONS(9847), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6074), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9672), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [222439] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7426), 1,
      anon_sym_DASH_GT,
    ACTIONS(7441), 1,
      anon_sym_requires,
    STATE(6144), 1,
      sym_trailing_return_type,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [222471] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7426), 1,
      anon_sym_DASH_GT,
    ACTIONS(8779), 1,
      anon_sym_requires,
    STATE(6141), 1,
      sym_trailing_return_type,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 5,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [222503] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10044), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [222523] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2000), 1,
      anon_sym_LT,
    STATE(6210), 1,
      sym_template_argument_list,
    ACTIONS(5842), 2,
      anon_sym_COLON,
      anon_sym_LBRACK,
    ACTIONS(5188), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [222551] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9996), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [222571] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10000), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [222591] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9815), 1,
      sym_identifier,
    STATE(8119), 1,
      sym_concatenated_string,
    STATE(6147), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(151), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [222619] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5842), 1,
      anon_sym_LBRACK,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    ACTIONS(10118), 1,
      anon_sym_LBRACE,
    ACTIONS(10120), 1,
      anon_sym_EQ,
    ACTIONS(10122), 1,
      anon_sym_try,
    ACTIONS(10214), 1,
      anon_sym_SEMI,
    STATE(1907), 1,
      sym_compound_statement,
    STATE(7729), 1,
      sym_field_initializer_list,
    ACTIONS(5188), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(1896), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [222657] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9720), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9730), 1,
      anon_sym_EQ,
    ACTIONS(10218), 1,
      anon_sym_COLON,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    ACTIONS(10216), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    STATE(7547), 2,
      sym_argument_list,
      sym_initializer_list,
  [222697] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10032), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [222717] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5842), 1,
      anon_sym_LBRACK,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    ACTIONS(10108), 1,
      anon_sym_LBRACE,
    ACTIONS(10110), 1,
      anon_sym_EQ,
    ACTIONS(10112), 1,
      anon_sym_try,
    ACTIONS(10220), 1,
      anon_sym_SEMI,
    STATE(2074), 1,
      sym_compound_statement,
    STATE(7737), 1,
      sym_field_initializer_list,
    ACTIONS(5188), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(2075), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [222755] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9132), 1,
      anon_sym_LBRACK,
    STATE(3346), 1,
      sym_parameter_list,
    STATE(6281), 1,
      sym__function_declarator_seq,
    STATE(6208), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10222), 7,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [222787] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10004), 14,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_try,
      anon_sym_requires,
  [222807] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10224), 1,
      anon_sym_RPAREN,
    STATE(5829), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(9855), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(9857), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [222832] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8779), 1,
      anon_sym_requires,
    ACTIONS(8717), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [222859] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10228), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(10232), 1,
      anon_sym_RBRACE,
    ACTIONS(10230), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(7440), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(7848), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6182), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [222892] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3354), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9930), 9,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [222919] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6132), 1,
      anon_sym_LBRACK,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(5747), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6134), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [222944] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3354), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9932), 9,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [222971] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9900), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9902), 1,
      anon_sym_template,
    ACTIONS(10234), 1,
      sym_identifier,
    STATE(3521), 1,
      sym_qualified_field_identifier,
    STATE(3522), 1,
      sym_dependent_field_identifier,
    STATE(3536), 1,
      sym_template_method,
    STATE(6114), 1,
      sym__scope_resolution,
    STATE(7633), 1,
      sym_operator_name,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [223010] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    ACTIONS(5842), 1,
      anon_sym_LBRACK,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    ACTIONS(10162), 1,
      anon_sym_EQ,
    ACTIONS(10164), 1,
      anon_sym_try,
    STATE(731), 1,
      sym_compound_statement,
    STATE(7629), 1,
      sym_field_initializer_list,
    ACTIONS(5188), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(728), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [223045] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10228), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(10236), 1,
      anon_sym_RBRACE,
    ACTIONS(10230), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(7746), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(7983), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6179), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [223078] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7441), 1,
      anon_sym_requires,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6002), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [223105] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3354), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9954), 9,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [223132] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6682), 1,
      sym__abstract_declarator,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [223167] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10228), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(10238), 1,
      anon_sym_RBRACE,
    ACTIONS(10230), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(7530), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8526), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6127), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [223200] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3354), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9908), 9,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [223227] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3354), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9934), 9,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [223254] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7562), 1,
      anon_sym_DASH_GT,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(9004), 1,
      anon_sym_requires,
    STATE(6379), 1,
      sym_trailing_return_type,
    ACTIONS(8631), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [223287] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10240), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5254), 11,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_or,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [223308] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10228), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(10242), 1,
      anon_sym_RBRACE,
    ACTIONS(10230), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(7790), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(7922), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6241), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [223341] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10228), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(10244), 1,
      anon_sym_RBRACE,
    ACTIONS(10230), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(7599), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8263), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6241), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [223374] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10228), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(10246), 1,
      anon_sym_RBRACE,
    ACTIONS(10230), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(7523), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8533), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6241), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [223407] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7441), 1,
      anon_sym_requires,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [223434] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10248), 1,
      anon_sym_RPAREN,
    STATE(5829), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(9855), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(9857), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [223459] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10228), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(10250), 1,
      anon_sym_RBRACE,
    ACTIONS(10230), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(7611), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8239), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6126), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [223492] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(10079), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10081), 1,
      anon_sym_template,
    ACTIONS(10252), 1,
      sym_identifier,
    STATE(3741), 1,
      sym_qualified_field_identifier,
    STATE(3749), 1,
      sym_template_method,
    STATE(3766), 1,
      sym_dependent_field_identifier,
    STATE(6131), 1,
      sym__scope_resolution,
    STATE(7757), 1,
      sym_operator_name,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [223531] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7562), 1,
      anon_sym_DASH_GT,
    ACTIONS(9366), 1,
      anon_sym_LBRACK,
    ACTIONS(10254), 1,
      anon_sym_requires,
    STATE(6330), 1,
      sym_trailing_return_type,
    ACTIONS(9416), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5956), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [223564] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7562), 1,
      anon_sym_DASH_GT,
    ACTIONS(7564), 1,
      anon_sym_requires,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    STATE(6237), 1,
      sym_trailing_return_type,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [223597] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(633), 1,
      anon_sym_LBRACE,
    ACTIONS(5842), 1,
      anon_sym_LBRACK,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    ACTIONS(10142), 1,
      anon_sym_EQ,
    ACTIONS(10144), 1,
      anon_sym_try,
    STATE(686), 1,
      sym_compound_statement,
    STATE(7553), 1,
      sym_field_initializer_list,
    ACTIONS(5188), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(685), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [223632] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7562), 1,
      anon_sym_DASH_GT,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    ACTIONS(9249), 1,
      anon_sym_requires,
    STATE(6354), 1,
      sym_trailing_return_type,
    ACTIONS(9030), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5957), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [223665] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10228), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(10257), 1,
      anon_sym_RBRACE,
    ACTIONS(10230), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(7718), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8033), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6140), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [223698] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3354), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9952), 9,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [223725] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3354), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9962), 9,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [223752] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      anon_sym_LBRACE,
    ACTIONS(5842), 1,
      anon_sym_LBRACK,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    ACTIONS(10154), 1,
      anon_sym_EQ,
    ACTIONS(10156), 1,
      anon_sym_try,
    STATE(292), 1,
      sym_compound_statement,
    STATE(7635), 1,
      sym_field_initializer_list,
    ACTIONS(5188), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(291), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [223787] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10228), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(10259), 1,
      anon_sym_RBRACE,
    ACTIONS(10230), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(7699), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8054), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6241), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [223820] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9020), 1,
      anon_sym_requires,
    ACTIONS(8910), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6027), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [223847] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(10261), 1,
      sym_identifier,
    ACTIONS(10263), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10265), 1,
      anon_sym_template,
    STATE(2706), 1,
      sym_template_method,
    STATE(2732), 1,
      sym_dependent_field_identifier,
    STATE(2754), 1,
      sym_qualified_field_identifier,
    STATE(6142), 1,
      sym__scope_resolution,
    STATE(7466), 1,
      sym_operator_name,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [223886] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10267), 1,
      anon_sym_RPAREN,
    STATE(5829), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(9855), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(9857), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [223911] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7441), 1,
      anon_sym_requires,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [223938] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10269), 1,
      anon_sym_RPAREN,
    STATE(5829), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(9855), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(9857), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [223963] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9980), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9982), 1,
      anon_sym_template,
    ACTIONS(10271), 1,
      sym_identifier,
    STATE(2706), 1,
      sym_template_method,
    STATE(2732), 1,
      sym_dependent_field_identifier,
    STATE(2754), 1,
      sym_qualified_field_identifier,
    STATE(6146), 1,
      sym__scope_resolution,
    STATE(7692), 1,
      sym_operator_name,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [224002] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10273), 1,
      anon_sym_RPAREN,
    STATE(5829), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(9855), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(9857), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [224027] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10228), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(10275), 1,
      anon_sym_RBRACE,
    ACTIONS(10230), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(7564), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8373), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6181), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [224060] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(10263), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10277), 1,
      sym_identifier,
    STATE(6142), 1,
      sym__scope_resolution,
    STATE(7466), 1,
      sym_operator_name,
    STATE(7600), 1,
      sym_field_initializer,
    STATE(6775), 2,
      sym_template_method,
      sym_qualified_field_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [224097] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(793), 1,
      anon_sym_LBRACE,
    ACTIONS(5842), 1,
      anon_sym_LBRACK,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    ACTIONS(10136), 1,
      anon_sym_EQ,
    ACTIONS(10138), 1,
      anon_sym_try,
    STATE(650), 1,
      sym_compound_statement,
    STATE(7439), 1,
      sym_field_initializer_list,
    ACTIONS(5188), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(649), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [224132] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10279), 1,
      anon_sym_RPAREN,
    STATE(5829), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(9855), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(9857), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [224157] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(10263), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10277), 1,
      sym_identifier,
    STATE(6142), 1,
      sym__scope_resolution,
    STATE(7311), 1,
      sym_field_initializer,
    STATE(7466), 1,
      sym_operator_name,
    STATE(6775), 2,
      sym_template_method,
      sym_qualified_field_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [224194] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10228), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(10281), 1,
      anon_sym_RBRACE,
    ACTIONS(10230), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(7642), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8139), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6241), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [224227] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7562), 1,
      anon_sym_DASH_GT,
    ACTIONS(7564), 1,
      anon_sym_requires,
    ACTIONS(9366), 1,
      anon_sym_LBRACK,
    STATE(6280), 1,
      sym_trailing_return_type,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5956), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [224260] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6343), 1,
      anon_sym_LBRACK,
    ACTIONS(6345), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [224281] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10283), 1,
      anon_sym_RPAREN,
    STATE(5829), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(9855), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(9857), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [224306] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    ACTIONS(7871), 1,
      anon_sym_STAR,
    ACTIONS(7873), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7875), 1,
      anon_sym_AMP,
    STATE(3644), 1,
      sym_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6521), 1,
      sym__abstract_declarator,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [224341] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      anon_sym_LPAREN2,
    ACTIONS(4072), 1,
      anon_sym_STAR,
    ACTIONS(4074), 1,
      anon_sym_AMP_AMP,
    ACTIONS(4076), 1,
      anon_sym_AMP,
    ACTIONS(7628), 1,
      anon_sym_LBRACK,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(6076), 1,
      sym__function_declarator_seq,
    STATE(6685), 1,
      sym__abstract_declarator,
    STATE(6033), 5,
      sym_abstract_parenthesized_declarator,
      sym_abstract_pointer_declarator,
      sym_abstract_function_declarator,
      sym_abstract_array_declarator,
      sym_abstract_reference_declarator,
  [224376] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(793), 1,
      anon_sym_LBRACE,
    ACTIONS(5842), 1,
      anon_sym_LBRACK,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    ACTIONS(10136), 1,
      anon_sym_EQ,
    ACTIONS(10138), 1,
      anon_sym_try,
    STATE(620), 1,
      sym_compound_statement,
    STATE(7831), 1,
      sym_field_initializer_list,
    ACTIONS(5188), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(621), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [224411] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10228), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(10285), 1,
      anon_sym_RBRACE,
    ACTIONS(10230), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(7565), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8369), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6241), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [224444] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10289), 1,
      anon_sym_LBRACK,
    STATE(5747), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10287), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [224469] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3354), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9960), 9,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [224496] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10228), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(10291), 1,
      anon_sym_RBRACE,
    ACTIONS(10230), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(7656), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8120), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6153), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [224529] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2000), 1,
      anon_sym_LT,
    ACTIONS(6306), 1,
      anon_sym_LBRACK,
    STATE(6210), 1,
      sym_template_argument_list,
    ACTIONS(6308), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [224554] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9121), 1,
      anon_sym_requires,
    ACTIONS(9062), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6052), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [224581] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10228), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(10293), 1,
      anon_sym_RBRACE,
    ACTIONS(10230), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(7646), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8129), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6241), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [224614] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6278), 1,
      anon_sym_LBRACK,
    ACTIONS(6280), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LT,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [224635] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10170), 1,
      anon_sym_requires,
    ACTIONS(9803), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6071), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [224662] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10240), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(10295), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(5233), 9,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [224685] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7441), 1,
      anon_sym_requires,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6071), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [224712] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7562), 1,
      anon_sym_DASH_GT,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(9053), 1,
      anon_sym_requires,
    STATE(6245), 1,
      sym_trailing_return_type,
    ACTIONS(8700), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [224745] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7441), 1,
      anon_sym_requires,
    ACTIONS(7140), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6074), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9672), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [224772] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(633), 1,
      anon_sym_LBRACE,
    ACTIONS(5842), 1,
      anon_sym_LBRACK,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    ACTIONS(10142), 1,
      anon_sym_EQ,
    ACTIONS(10144), 1,
      anon_sym_try,
    STATE(669), 1,
      sym_compound_statement,
    STATE(7529), 1,
      sym_field_initializer_list,
    ACTIONS(5188), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(671), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [224807] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(10008), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10010), 1,
      anon_sym_template,
    ACTIONS(10271), 1,
      sym_identifier,
    STATE(2706), 1,
      sym_template_method,
    STATE(2732), 1,
      sym_dependent_field_identifier,
    STATE(2754), 1,
      sym_qualified_field_identifier,
    STATE(6174), 1,
      sym__scope_resolution,
    STATE(7549), 1,
      sym_operator_name,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [224846] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10228), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(10297), 1,
      anon_sym_RBRACE,
    ACTIONS(10230), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(7627), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8206), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6166), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [224879] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10299), 1,
      anon_sym_requires,
    ACTIONS(9847), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5868), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(6074), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9672), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [224906] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    ACTIONS(5842), 1,
      anon_sym_LBRACK,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    ACTIONS(10162), 1,
      anon_sym_EQ,
    ACTIONS(10164), 1,
      anon_sym_try,
    STATE(806), 1,
      sym_compound_statement,
    STATE(7462), 1,
      sym_field_initializer_list,
    ACTIONS(5188), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(808), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [224941] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7562), 1,
      anon_sym_DASH_GT,
    ACTIONS(7564), 1,
      anon_sym_requires,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    STATE(6269), 1,
      sym_trailing_return_type,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [224974] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10228), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(10302), 1,
      anon_sym_RBRACE,
    ACTIONS(10230), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(7775), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(7942), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6241), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [225007] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7562), 1,
      anon_sym_DASH_GT,
    ACTIONS(7564), 1,
      anon_sym_requires,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    STATE(6277), 1,
      sym_trailing_return_type,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5957), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [225040] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10228), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(10304), 1,
      anon_sym_RBRACE,
    ACTIONS(10230), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(7525), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8408), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6241), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [225073] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10228), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(10306), 1,
      anon_sym_RBRACE,
    ACTIONS(10230), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(7722), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(7950), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6241), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [225106] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10228), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(10308), 1,
      anon_sym_RBRACE,
    ACTIONS(10230), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(7820), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(7870), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6125), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [225139] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      sym_preproc_directive,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10228), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(10310), 1,
      anon_sym_RBRACE,
    ACTIONS(10230), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(7541), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(8450), 2,
      sym_preproc_if_in_enumerator_list_no_comma,
      sym_preproc_ifdef_in_enumerator_list_no_comma,
    STATE(6160), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [225172] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      anon_sym_LBRACE,
    ACTIONS(5842), 1,
      anon_sym_LBRACK,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    ACTIONS(10154), 1,
      anon_sym_EQ,
    ACTIONS(10156), 1,
      anon_sym_try,
    STATE(299), 1,
      sym_compound_statement,
    STATE(7614), 1,
      sym_field_initializer_list,
    ACTIONS(5188), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
    STATE(315), 4,
      sym_constructor_try_statement,
      sym_default_method_clause,
      sym_delete_method_clause,
      sym_pure_virtual_clause,
  [225207] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6602), 1,
      anon_sym_LBRACE,
    ACTIONS(8850), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8996), 1,
      sym_identifier,
    STATE(2883), 1,
      sym_template_type,
    STATE(3068), 1,
      sym_enumerator_list,
    STATE(6486), 1,
      sym__scope_resolution,
    STATE(2916), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [225243] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5988), 1,
      anon_sym_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    STATE(2652), 1,
      sym_parameter_list,
    STATE(6250), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(5998), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_try,
  [225271] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5988), 1,
      anon_sym_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    STATE(2652), 1,
      sym_parameter_list,
    STATE(6250), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6002), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_try,
  [225299] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2000), 1,
      anon_sym_LT,
    STATE(2221), 1,
      sym_template_argument_list,
    STATE(4844), 1,
      aux_sym_sized_type_specifier_repeat1,
    ACTIONS(3830), 4,
      anon_sym_COMMA,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
    ACTIONS(8445), 4,
      anon_sym_signed,
      anon_sym_unsigned,
      anon_sym_long,
      anon_sym_short,
  [225327] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5523), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2324), 1,
      sym_enumerator_list,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(2355), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [225363] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3399), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9954), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [225389] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(5308), 1,
      sym_enumerator_list,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(4961), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [225425] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9018), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2725), 1,
      sym_enumerator_list,
    STATE(6489), 1,
      sym__scope_resolution,
    STATE(4032), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [225461] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8669), 1,
      anon_sym_LBRACE,
    ACTIONS(9000), 1,
      sym_identifier,
    STATE(4671), 1,
      sym_template_type,
    STATE(4889), 1,
      sym_enumerator_list,
    STATE(6459), 1,
      sym__scope_resolution,
    STATE(4815), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [225497] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6616), 1,
      anon_sym_LBRACE,
    ACTIONS(8806), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8998), 1,
      sym_identifier,
    STATE(2942), 1,
      sym_template_type,
    STATE(3143), 1,
      sym_enumerator_list,
    STATE(6464), 1,
      sym__scope_resolution,
    STATE(2948), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [225533] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8503), 1,
      anon_sym_LBRACE,
    ACTIONS(8973), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(4862), 1,
      sym_enumerator_list,
    STATE(6475), 1,
      sym__scope_resolution,
    STATE(4598), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [225569] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3399), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9962), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [225595] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5988), 1,
      anon_sym_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    STATE(2652), 1,
      sym_parameter_list,
    STATE(6250), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6066), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_try,
  [225623] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6713), 1,
      anon_sym_LBRACE,
    ACTIONS(8877), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8994), 1,
      sym_identifier,
    STATE(3026), 1,
      sym_template_type,
    STATE(3246), 1,
      sym_enumerator_list,
    STATE(6485), 1,
      sym__scope_resolution,
    STATE(3034), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [225659] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5523), 1,
      anon_sym_LBRACE,
    ACTIONS(8973), 1,
      sym_identifier,
    ACTIONS(8975), 1,
      anon_sym_COLON_COLON,
    STATE(2193), 1,
      sym_template_type,
    STATE(5070), 1,
      sym_enumerator_list,
    STATE(6458), 1,
      sym__scope_resolution,
    STATE(6390), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [225695] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3399), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9960), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [225721] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10316), 1,
      anon_sym_LT,
    ACTIONS(10318), 1,
      anon_sym_LBRACK,
    STATE(6283), 1,
      sym_template_argument_list,
    ACTIONS(10314), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [225745] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1933), 1,
      anon_sym_COLON,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2000), 1,
      anon_sym_LT,
    STATE(2221), 1,
      sym_template_argument_list,
    ACTIONS(1935), 8,
      anon_sym_COMMA,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      sym_auto,
      anon_sym_decltype,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
  [225771] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3399), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9934), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [225797] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6078), 1,
      anon_sym_LBRACK,
    ACTIONS(10320), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(6205), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6080), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [225821] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6560), 1,
      anon_sym_LBRACE,
    ACTIONS(7477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8968), 1,
      sym_identifier,
    STATE(2892), 1,
      sym_template_type,
    STATE(2905), 1,
      sym_enumerator_list,
    STATE(6482), 1,
      sym__scope_resolution,
    STATE(4971), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [225857] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5911), 1,
      anon_sym_LBRACE,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8931), 1,
      sym_identifier,
    STATE(2498), 1,
      sym_template_type,
    STATE(2564), 1,
      sym_enumerator_list,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(2824), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [225893] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10325), 1,
      anon_sym_LBRACK,
    STATE(5747), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10323), 8,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [225917] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6172), 1,
      anon_sym_LBRACE,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8981), 1,
      sym_identifier,
    STATE(2419), 1,
      sym_template_type,
    STATE(2725), 1,
      sym_enumerator_list,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(4966), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [225953] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1961), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4063), 2,
      anon_sym_COLON,
      anon_sym_LBRACK,
    ACTIONS(4058), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [225975] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3399), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9952), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [226001] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10329), 1,
      anon_sym_COLON,
    ACTIONS(10331), 1,
      anon_sym_EQ,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(7354), 1,
      sym_semantics,
    ACTIONS(10327), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [226037] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4078), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5523), 1,
      anon_sym_LBRACE,
    ACTIONS(8983), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2324), 1,
      sym_enumerator_list,
    STATE(6449), 1,
      sym__scope_resolution,
    STATE(2377), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [226073] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10316), 1,
      anon_sym_LT,
    ACTIONS(10335), 1,
      anon_sym_LBRACK,
    STATE(6322), 1,
      sym_template_argument_list,
    ACTIONS(10333), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [226097] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5823), 6,
      anon_sym_AMP,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
    ACTIONS(5825), 6,
      anon_sym_LPAREN2,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_COLON_COLON,
      anon_sym_LBRACK,
  [226117] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10329), 1,
      anon_sym_COLON,
    ACTIONS(10337), 1,
      anon_sym_EQ,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(7354), 1,
      sym_semantics,
    ACTIONS(10327), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [226153] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3399), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9932), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [226179] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7453), 1,
      anon_sym_LBRACE,
    ACTIONS(8828), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9002), 1,
      sym_identifier,
    STATE(3808), 1,
      sym_template_type,
    STATE(4045), 1,
      sym_enumerator_list,
    STATE(6451), 1,
      sym__scope_resolution,
    STATE(3810), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [226215] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5523), 1,
      anon_sym_LBRACE,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2324), 1,
      sym_enumerator_list,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(2597), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [226251] = 4,
    ACTIONS(3), 1,
      sym_comment,
    STATE(5829), 2,
      sym_string_literal,
      sym_raw_string_literal,
    ACTIONS(9855), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
    ACTIONS(9857), 5,
      anon_sym_R_DQUOTE,
      anon_sym_LR_DQUOTE,
      anon_sym_uR_DQUOTE,
      anon_sym_UR_DQUOTE,
      anon_sym_u8R_DQUOTE,
  [226273] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5911), 1,
      anon_sym_LBRACE,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8931), 1,
      sym_identifier,
    STATE(2498), 1,
      sym_template_type,
    STATE(2564), 1,
      sym_enumerator_list,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(2684), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [226309] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8503), 1,
      anon_sym_LBRACE,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(4862), 1,
      sym_enumerator_list,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(4890), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [226345] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(6560), 1,
      anon_sym_LBRACE,
    ACTIONS(8753), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9007), 1,
      sym_identifier,
    STATE(2892), 1,
      sym_template_type,
    STATE(2905), 1,
      sym_enumerator_list,
    STATE(6505), 1,
      sym__scope_resolution,
    STATE(4128), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [226381] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5523), 1,
      anon_sym_LBRACE,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(2324), 1,
      sym_enumerator_list,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(2850), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [226417] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3399), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9930), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [226443] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10341), 1,
      anon_sym_COLON,
    ACTIONS(10344), 1,
      anon_sym_LBRACK,
    STATE(6357), 1,
      sym_semantics,
    ACTIONS(10339), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [226467] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3399), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9908), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [226493] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5988), 1,
      anon_sym_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    STATE(2652), 1,
      sym_parameter_list,
    STATE(6250), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6026), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_try,
  [226521] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(5523), 1,
      anon_sym_LBRACE,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(8929), 1,
      sym_identifier,
    STATE(2193), 1,
      sym_template_type,
    STATE(5070), 1,
      sym_enumerator_list,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(5041), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [226557] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5988), 1,
      anon_sym_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    STATE(2652), 1,
      sym_parameter_list,
    STATE(6250), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(5982), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_try,
  [226585] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9753), 1,
      anon_sym_try,
    STATE(709), 1,
      sym_compound_statement,
    STATE(729), 1,
      sym_try_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [226620] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6111), 1,
      anon_sym_LBRACK,
    ACTIONS(6113), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [226639] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10348), 1,
      anon_sym_LBRACK,
    ACTIONS(10346), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [226658] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 1,
      anon_sym_LBRACK,
    ACTIONS(4045), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [226677] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(793), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9789), 1,
      anon_sym_try,
    STATE(593), 1,
      sym_try_statement,
    STATE(594), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [226712] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(793), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9789), 1,
      anon_sym_try,
    STATE(581), 1,
      sym_try_statement,
    STATE(582), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [226747] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7564), 1,
      anon_sym_requires,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [226774] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(633), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9773), 1,
      anon_sym_try,
    STATE(555), 1,
      sym_try_statement,
    STATE(556), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [226809] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1933), 1,
      anon_sym_COLON,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    STATE(2390), 1,
      sym_template_argument_list,
    ACTIONS(1935), 7,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_else,
      anon_sym_while,
      anon_sym_final,
      anon_sym_override,
  [226834] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10352), 1,
      anon_sym_LBRACK,
    ACTIONS(10350), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [226853] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10354), 1,
      sym_identifier,
    ACTIONS(10357), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(10363), 1,
      sym_preproc_directive,
    ACTIONS(10366), 1,
      anon_sym_RBRACE,
    ACTIONS(10360), 2,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
    STATE(8064), 2,
      sym_preproc_call,
      sym_enumerator,
    STATE(6241), 3,
      sym_preproc_if_in_enumerator_list,
      sym_preproc_ifdef_in_enumerator_list,
      aux_sym_enumerator_list_repeat1,
  [226882] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(793), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9789), 1,
      anon_sym_try,
    STATE(596), 1,
      sym_try_statement,
    STATE(597), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [226917] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9710), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10368), 1,
      sym_identifier,
    STATE(5730), 1,
      sym__scope_resolution,
    STATE(8529), 1,
      sym_qualified_identifier,
    ACTIONS(10370), 2,
      anon_sym_enum,
      anon_sym_namespace,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [226948] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 1,
      anon_sym_LBRACK,
    ACTIONS(4045), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [226967] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    ACTIONS(9249), 1,
      anon_sym_requires,
    ACTIONS(9030), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5957), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [226994] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3505), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9908), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [227019] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9144), 1,
      anon_sym_try,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10118), 1,
      anon_sym_LBRACE,
    STATE(1863), 1,
      sym_compound_statement,
    STATE(1869), 1,
      sym_try_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [227054] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9144), 1,
      anon_sym_try,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10118), 1,
      anon_sym_LBRACE,
    STATE(1865), 1,
      sym_try_statement,
    STATE(1933), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [227089] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9710), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10372), 1,
      sym_identifier,
    STATE(5730), 1,
      sym__scope_resolution,
    STATE(7839), 1,
      sym_qualified_identifier,
    ACTIONS(10374), 2,
      anon_sym_enum,
      anon_sym_namespace,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [227120] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6132), 1,
      anon_sym_LBRACK,
    STATE(6205), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6134), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACE,
      anon_sym_try,
  [227143] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 1,
      anon_sym_LBRACK,
    ACTIONS(4045), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [227162] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9136), 1,
      anon_sym_try,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10128), 1,
      anon_sym_LBRACE,
    STATE(2062), 1,
      sym_compound_statement,
    STATE(2069), 1,
      sym_try_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [227197] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(293), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9747), 1,
      anon_sym_try,
    STATE(251), 1,
      sym_try_statement,
    STATE(253), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [227232] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9636), 1,
      sym_identifier,
    ACTIONS(9735), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10376), 1,
      sym_virtual,
    STATE(2193), 1,
      sym_template_type,
    STATE(6506), 1,
      sym__scope_resolution,
    STATE(6778), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [227265] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(633), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9773), 1,
      anon_sym_try,
    STATE(609), 1,
      sym_try_statement,
    STATE(610), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [227300] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(293), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9747), 1,
      anon_sym_try,
    STATE(249), 1,
      sym_try_statement,
    STATE(250), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [227335] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3634), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9930), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [227360] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9753), 1,
      anon_sym_try,
    STATE(730), 1,
      sym_compound_statement,
    STATE(733), 1,
      sym_try_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [227395] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3634), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9932), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [227420] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9136), 1,
      anon_sym_try,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10128), 1,
      anon_sym_LBRACE,
    STATE(2077), 1,
      sym_compound_statement,
    STATE(2078), 1,
      sym_try_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [227455] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3634), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9908), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [227480] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9144), 1,
      anon_sym_try,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10118), 1,
      anon_sym_LBRACE,
    STATE(1851), 1,
      sym_compound_statement,
    STATE(1858), 1,
      sym_try_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [227515] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 1,
      anon_sym_LBRACK,
    ACTIONS(4045), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [227534] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9636), 1,
      sym_identifier,
    ACTIONS(9735), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10378), 1,
      sym_virtual,
    STATE(2193), 1,
      sym_template_type,
    STATE(6506), 1,
      sym__scope_resolution,
    STATE(6943), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [227567] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9753), 1,
      anon_sym_try,
    STATE(732), 1,
      sym_try_statement,
    STATE(752), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [227602] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6107), 1,
      anon_sym_LBRACK,
    ACTIONS(6109), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [227621] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10382), 1,
      anon_sym_LBRACK,
    ACTIONS(10380), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [227640] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9136), 1,
      anon_sym_try,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10128), 1,
      anon_sym_LBRACE,
    STATE(2114), 1,
      sym_compound_statement,
    STATE(2115), 1,
      sym_try_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [227675] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7564), 1,
      anon_sym_requires,
    ACTIONS(9028), 1,
      anon_sym_LBRACK,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5957), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9023), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [227702] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5842), 1,
      anon_sym_LBRACK,
    ACTIONS(5188), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [227721] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10384), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10386), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(10388), 1,
      aux_sym_preproc_elif_token1,
    STATE(6274), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(8250), 1,
      sym_enumerator,
    ACTIONS(10390), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(8280), 3,
      sym_preproc_else_in_enumerator_list,
      sym_preproc_elif_in_enumerator_list,
      sym_preproc_elifdef_in_enumerator_list,
  [227752] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6093), 1,
      anon_sym_LBRACK,
    ACTIONS(6095), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [227771] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6097), 1,
      anon_sym_LBRACK,
    ACTIONS(6099), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [227790] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10386), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(10388), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(10392), 1,
      aux_sym_preproc_if_token2,
    STATE(6532), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(8250), 1,
      sym_enumerator,
    ACTIONS(10390), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(8358), 3,
      sym_preproc_else_in_enumerator_list,
      sym_preproc_elif_in_enumerator_list,
      sym_preproc_elifdef_in_enumerator_list,
  [227821] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9986), 1,
      sym_identifier,
    ACTIONS(10394), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10396), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(10398), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(10400), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(6545), 2,
      sym_enumerator,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
    STATE(8361), 3,
      sym_preproc_else_in_enumerator_list_no_comma,
      sym_preproc_elif_in_enumerator_list_no_comma,
      sym_preproc_elifdef_in_enumerator_list_no_comma,
  [227850] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9986), 1,
      sym_identifier,
    ACTIONS(10396), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(10398), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(10402), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10400), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(6346), 2,
      sym_enumerator,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
    STATE(8368), 3,
      sym_preproc_else_in_enumerator_list_no_comma,
      sym_preproc_elif_in_enumerator_list_no_comma,
      sym_preproc_elifdef_in_enumerator_list_no_comma,
  [227879] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7564), 1,
      anon_sym_requires,
    ACTIONS(9366), 1,
      anon_sym_LBRACK,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5956), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [227906] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6121), 1,
      anon_sym_LBRACK,
    ACTIONS(6123), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [227925] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6125), 1,
      anon_sym_LBRACK,
    ACTIONS(6127), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [227944] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7564), 1,
      anon_sym_requires,
    ACTIONS(9674), 1,
      anon_sym_LBRACK,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5986), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9672), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [227971] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10406), 1,
      anon_sym_LBRACK,
    ACTIONS(10404), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [227990] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(293), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9747), 1,
      anon_sym_try,
    STATE(317), 1,
      sym_try_statement,
    STATE(318), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [228025] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6196), 1,
      anon_sym_LBRACK,
    ACTIONS(6198), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [228044] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9753), 1,
      anon_sym_try,
    STATE(814), 1,
      sym_compound_statement,
    STATE(818), 1,
      sym_try_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [228079] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(793), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9789), 1,
      anon_sym_try,
    STATE(561), 1,
      sym_try_statement,
    STATE(571), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [228114] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 1,
      anon_sym_LBRACK,
    ACTIONS(4045), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [228133] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 1,
      anon_sym_LBRACK,
    ACTIONS(4045), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [228152] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(293), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9747), 1,
      anon_sym_try,
    STATE(246), 1,
      sym_compound_statement,
    STATE(260), 1,
      sym_try_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [228187] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10335), 1,
      anon_sym_LBRACK,
    ACTIONS(10333), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [228206] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3505), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9954), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [228231] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10083), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10386), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(10388), 1,
      aux_sym_preproc_elif_token1,
    STATE(6347), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(8250), 1,
      sym_enumerator,
    ACTIONS(10390), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(8363), 3,
      sym_preproc_else_in_enumerator_list,
      sym_preproc_elif_in_enumerator_list,
      sym_preproc_elifdef_in_enumerator_list,
  [228262] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3505), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9962), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [228287] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(793), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9789), 1,
      anon_sym_try,
    STATE(558), 1,
      sym_try_statement,
    STATE(560), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [228322] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(793), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9789), 1,
      anon_sym_try,
    STATE(552), 1,
      sym_try_statement,
    STATE(557), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [228357] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10052), 4,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [228386] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9144), 1,
      anon_sym_try,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10118), 1,
      anon_sym_LBRACE,
    STATE(1839), 1,
      sym_compound_statement,
    STATE(1906), 1,
      sym_try_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [228421] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3634), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9960), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [228446] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10410), 1,
      anon_sym_LBRACK,
    ACTIONS(10408), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [228465] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9144), 1,
      anon_sym_try,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10118), 1,
      anon_sym_LBRACE,
    STATE(1898), 1,
      sym_compound_statement,
    STATE(1908), 1,
      sym_try_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [228500] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9144), 1,
      anon_sym_try,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10118), 1,
      anon_sym_LBRACE,
    STATE(1919), 1,
      sym_compound_statement,
    STATE(1924), 1,
      sym_try_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [228535] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10386), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(10388), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(10412), 1,
      aux_sym_preproc_if_token2,
    STATE(6532), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(8250), 1,
      sym_enumerator,
    ACTIONS(10390), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(8580), 3,
      sym_preproc_else_in_enumerator_list,
      sym_preproc_elif_in_enumerator_list,
      sym_preproc_elifdef_in_enumerator_list,
  [228566] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10416), 1,
      anon_sym_LBRACK,
    ACTIONS(10414), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [228585] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7564), 1,
      anon_sym_requires,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [228612] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5231), 1,
      anon_sym_LBRACK,
    ACTIONS(10418), 2,
      anon_sym_PIPE_PIPE,
      anon_sym_or,
    ACTIONS(10420), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5233), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [228635] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9152), 1,
      anon_sym_try,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10108), 1,
      anon_sym_LBRACE,
    STATE(2052), 1,
      sym_compound_statement,
    STATE(2053), 1,
      sym_try_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [228670] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9136), 1,
      anon_sym_try,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10128), 1,
      anon_sym_LBRACE,
    STATE(2049), 1,
      sym_try_statement,
    STATE(2147), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [228705] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6150), 1,
      anon_sym_LBRACK,
    ACTIONS(6152), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [228724] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10424), 1,
      anon_sym_LBRACK,
    ACTIONS(10422), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [228743] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5887), 1,
      anon_sym_LBRACK,
    ACTIONS(5885), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [228762] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(9964), 4,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [228791] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9152), 1,
      anon_sym_try,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10108), 1,
      anon_sym_LBRACE,
    STATE(2046), 1,
      sym_try_statement,
    STATE(2079), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [228826] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10428), 1,
      anon_sym_LBRACK,
    ACTIONS(10426), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [228845] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3505), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9934), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [228870] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9986), 1,
      sym_identifier,
    ACTIONS(10396), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(10398), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(10430), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10400), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(6545), 2,
      sym_enumerator,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
    STATE(8581), 3,
      sym_preproc_else_in_enumerator_list_no_comma,
      sym_preproc_elif_in_enumerator_list_no_comma,
      sym_preproc_elifdef_in_enumerator_list_no_comma,
  [228899] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9636), 1,
      sym_identifier,
    ACTIONS(9735), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10432), 1,
      sym_virtual,
    STATE(2193), 1,
      sym_template_type,
    STATE(6506), 1,
      sym__scope_resolution,
    STATE(7180), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [228932] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10436), 1,
      anon_sym_LBRACK,
    ACTIONS(10434), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [228951] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9753), 1,
      anon_sym_try,
    STATE(782), 1,
      sym_compound_statement,
    STATE(786), 1,
      sym_try_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [228986] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(793), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9789), 1,
      anon_sym_try,
    STATE(591), 1,
      sym_compound_statement,
    STATE(592), 1,
      sym_try_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [229021] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9636), 1,
      sym_identifier,
    ACTIONS(9735), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10438), 1,
      sym_virtual,
    STATE(2193), 1,
      sym_template_type,
    STATE(6506), 1,
      sym__scope_resolution,
    STATE(7175), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [229054] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10060), 4,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [229083] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3634), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9934), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [229108] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6323), 1,
      anon_sym_LBRACK,
    ACTIONS(6325), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [229127] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9144), 1,
      anon_sym_try,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10118), 1,
      anon_sym_LBRACE,
    STATE(1883), 1,
      sym_try_statement,
    STATE(1900), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [229162] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9710), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10440), 1,
      sym_identifier,
    STATE(5730), 1,
      sym__scope_resolution,
    STATE(8002), 1,
      sym_qualified_identifier,
    ACTIONS(10442), 2,
      anon_sym_enum,
      anon_sym_namespace,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [229193] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10075), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10386), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(10388), 1,
      aux_sym_preproc_elif_token1,
    STATE(6301), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(8250), 1,
      sym_enumerator,
    ACTIONS(10390), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(8499), 3,
      sym_preproc_else_in_enumerator_list,
      sym_preproc_elif_in_enumerator_list,
      sym_preproc_elifdef_in_enumerator_list,
  [229224] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3634), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9952), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [229249] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9136), 1,
      anon_sym_try,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10128), 1,
      anon_sym_LBRACE,
    STATE(2149), 1,
      sym_try_statement,
    STATE(2159), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [229284] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9136), 1,
      anon_sym_try,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10128), 1,
      anon_sym_LBRACE,
    STATE(2135), 1,
      sym_try_statement,
    STATE(2138), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [229319] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9753), 1,
      anon_sym_try,
    STATE(789), 1,
      sym_compound_statement,
    STATE(793), 1,
      sym_try_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [229354] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9674), 1,
      anon_sym_LBRACK,
    ACTIONS(10444), 1,
      anon_sym_requires,
    ACTIONS(9676), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5986), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9672), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [229381] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(633), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9773), 1,
      anon_sym_try,
    STATE(568), 1,
      sym_try_statement,
    STATE(569), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [229416] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(633), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9773), 1,
      anon_sym_try,
    STATE(570), 1,
      sym_try_statement,
    STATE(572), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [229451] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9753), 1,
      anon_sym_try,
    STATE(750), 1,
      sym_compound_statement,
    STATE(751), 1,
      sym_try_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [229486] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9710), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10447), 1,
      sym_identifier,
    STATE(5730), 1,
      sym__scope_resolution,
    STATE(8109), 1,
      sym_qualified_identifier,
    ACTIONS(10449), 2,
      anon_sym_enum,
      anon_sym_namespace,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [229517] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6101), 1,
      anon_sym_LBRACK,
    ACTIONS(6103), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [229536] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9152), 1,
      anon_sym_try,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10108), 1,
      anon_sym_LBRACE,
    STATE(2092), 1,
      sym_try_statement,
    STATE(2093), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [229571] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9710), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10451), 1,
      sym_identifier,
    STATE(5730), 1,
      sym__scope_resolution,
    STATE(8011), 1,
      sym_qualified_identifier,
    ACTIONS(10453), 2,
      anon_sym_enum,
      anon_sym_namespace,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [229602] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10386), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(10388), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(10455), 1,
      aux_sym_preproc_if_token2,
    STATE(6348), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(8250), 1,
      sym_enumerator,
    ACTIONS(10390), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(8094), 3,
      sym_preproc_else_in_enumerator_list,
      sym_preproc_elif_in_enumerator_list,
      sym_preproc_elifdef_in_enumerator_list,
  [229633] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5252), 1,
      anon_sym_LBRACK,
    ACTIONS(10420), 2,
      anon_sym_AMP_AMP,
      anon_sym_and,
    ACTIONS(5254), 8,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK_LBRACK,
      anon_sym_or,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [229654] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9152), 1,
      anon_sym_try,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10108), 1,
      anon_sym_LBRACE,
    STATE(2104), 1,
      sym_try_statement,
    STATE(2106), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [229689] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9152), 1,
      anon_sym_try,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10108), 1,
      anon_sym_LBRACE,
    STATE(2054), 1,
      sym_compound_statement,
    STATE(2055), 1,
      sym_try_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [229724] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3505), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9960), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [229749] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9986), 1,
      sym_identifier,
    ACTIONS(10396), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(10398), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(10457), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10400), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(6314), 2,
      sym_enumerator,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
    STATE(8501), 3,
      sym_preproc_else_in_enumerator_list_no_comma,
      sym_preproc_elif_in_enumerator_list_no_comma,
      sym_preproc_elifdef_in_enumerator_list_no_comma,
  [229778] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9152), 1,
      anon_sym_try,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10108), 1,
      anon_sym_LBRACE,
    STATE(2139), 1,
      sym_try_statement,
    STATE(2145), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [229813] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10087), 4,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [229842] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9986), 1,
      sym_identifier,
    ACTIONS(10396), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(10398), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(10459), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10400), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(6545), 2,
      sym_enumerator,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
    STATE(8531), 3,
      sym_preproc_else_in_enumerator_list_no_comma,
      sym_preproc_elif_in_enumerator_list_no_comma,
      sym_preproc_elifdef_in_enumerator_list_no_comma,
  [229871] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10386), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(10388), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(10461), 1,
      aux_sym_preproc_if_token2,
    STATE(6532), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(8250), 1,
      sym_enumerator,
    ACTIONS(10390), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(8528), 3,
      sym_preproc_else_in_enumerator_list,
      sym_preproc_elif_in_enumerator_list,
      sym_preproc_elifdef_in_enumerator_list,
  [229902] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(10386), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(10388), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(10463), 1,
      aux_sym_preproc_if_token2,
    STATE(6532), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(8250), 1,
      sym_enumerator,
    ACTIONS(10390), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(8284), 3,
      sym_preproc_else_in_enumerator_list,
      sym_preproc_elif_in_enumerator_list,
      sym_preproc_elifdef_in_enumerator_list,
  [229933] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9986), 1,
      sym_identifier,
    ACTIONS(10396), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(10398), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(10465), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10400), 2,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
    STATE(6545), 2,
      sym_enumerator,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
    STATE(8287), 3,
      sym_preproc_else_in_enumerator_list_no_comma,
      sym_preproc_elif_in_enumerator_list_no_comma,
      sym_preproc_elifdef_in_enumerator_list_no_comma,
  [229962] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10469), 1,
      anon_sym_LBRACK,
    ACTIONS(10467), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [229981] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10473), 1,
      anon_sym_LBRACK,
    ACTIONS(10471), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [230000] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10477), 1,
      anon_sym_LBRACK,
    ACTIONS(10475), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [230019] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9710), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10479), 1,
      sym_identifier,
    STATE(5730), 1,
      sym__scope_resolution,
    STATE(8236), 1,
      sym_qualified_identifier,
    ACTIONS(10481), 2,
      anon_sym_enum,
      anon_sym_namespace,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [230050] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9366), 1,
      anon_sym_LBRACK,
    ACTIONS(10254), 1,
      anon_sym_requires,
    ACTIONS(9416), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5956), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(9364), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [230077] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(633), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9773), 1,
      anon_sym_try,
    STATE(583), 1,
      sym_try_statement,
    STATE(584), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [230112] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6140), 1,
      anon_sym_LBRACK,
    ACTIONS(6142), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [230131] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10485), 1,
      anon_sym_LBRACK,
    ACTIONS(10483), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [230150] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(9984), 4,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_try,
  [230179] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10489), 1,
      anon_sym_LBRACK,
    ACTIONS(10487), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [230198] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10493), 1,
      anon_sym_LBRACK,
    ACTIONS(10491), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [230217] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(633), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9773), 1,
      anon_sym_try,
    STATE(636), 1,
      sym_try_statement,
    STATE(637), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [230252] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10497), 1,
      anon_sym_LBRACK,
    ACTIONS(10495), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [230271] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(1941), 1,
      anon_sym_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    STATE(2390), 1,
      sym_template_argument_list,
    ACTIONS(1943), 7,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_else,
      anon_sym_while,
      anon_sym_final,
      anon_sym_override,
  [230296] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10501), 1,
      anon_sym_LBRACK,
    ACTIONS(10499), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [230315] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6339), 1,
      anon_sym_LBRACK,
    ACTIONS(6341), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [230334] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(293), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9747), 1,
      anon_sym_try,
    STATE(242), 1,
      sym_compound_statement,
    STATE(244), 1,
      sym_try_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [230369] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(633), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9773), 1,
      anon_sym_try,
    STATE(634), 1,
      sym_try_statement,
    STATE(635), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [230404] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3634), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9962), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [230429] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6154), 1,
      anon_sym_LBRACK,
    ACTIONS(6156), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [230448] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6144), 1,
      anon_sym_LBRACK,
    ACTIONS(6146), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_GT2,
      anon_sym_try,
  [230467] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9710), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10503), 1,
      sym_identifier,
    STATE(5730), 1,
      sym__scope_resolution,
    STATE(8294), 1,
      sym_qualified_identifier,
    ACTIONS(10505), 2,
      anon_sym_enum,
      anon_sym_namespace,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [230498] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3634), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9954), 7,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_final,
      anon_sym_override,
      anon_sym_try,
      anon_sym_requires,
  [230523] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(293), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9747), 1,
      anon_sym_try,
    STATE(247), 1,
      sym_compound_statement,
    STATE(248), 1,
      sym_try_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [230558] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(293), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9747), 1,
      anon_sym_try,
    STATE(279), 1,
      sym_compound_statement,
    STATE(289), 1,
      sym_try_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [230593] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9152), 1,
      anon_sym_try,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10108), 1,
      anon_sym_LBRACE,
    STATE(2132), 1,
      sym_compound_statement,
    STATE(2136), 1,
      sym_try_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [230628] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3505), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9932), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [230653] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8609), 1,
      anon_sym_LBRACK,
    ACTIONS(9004), 1,
      anon_sym_requires,
    ACTIONS(8631), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5903), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8604), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [230680] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3505), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9930), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [230705] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8698), 1,
      anon_sym_LBRACK,
    ACTIONS(9053), 1,
      anon_sym_requires,
    ACTIONS(8700), 2,
      anon_sym_final,
      anon_sym_override,
    STATE(5772), 2,
      sym_virtual_specifier,
      aux_sym__function_postfix_repeat1,
    STATE(5927), 2,
      sym__function_postfix,
      sym_requires_clause,
    ACTIONS(8693), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [230732] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9136), 1,
      anon_sym_try,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10128), 1,
      anon_sym_LBRACE,
    STATE(2065), 1,
      sym_try_statement,
    STATE(2071), 1,
      sym_compound_statement,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [230767] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3505), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9952), 7,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [230792] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3791), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9934), 6,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [230816] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10511), 1,
      anon_sym_delete,
    ACTIONS(10513), 1,
      anon_sym_new,
    ACTIONS(10509), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(10507), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [230838] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10515), 1,
      anon_sym_delete,
    ACTIONS(10517), 1,
      anon_sym_new,
    ACTIONS(10509), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(10507), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [230860] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10519), 1,
      anon_sym_delete,
    ACTIONS(10521), 1,
      anon_sym_new,
    ACTIONS(10509), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(10507), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [230882] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10523), 1,
      anon_sym_delete,
    ACTIONS(10525), 1,
      anon_sym_new,
    ACTIONS(10509), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(10507), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [230904] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10527), 1,
      anon_sym_delete,
    ACTIONS(10529), 1,
      anon_sym_new,
    ACTIONS(10509), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(10507), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [230926] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10531), 1,
      anon_sym_delete,
    ACTIONS(10533), 1,
      anon_sym_new,
    ACTIONS(10509), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(10507), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [230948] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3756), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9952), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [230972] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5523), 1,
      anon_sym_LBRACE,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(10535), 1,
      anon_sym_COLON,
    STATE(2269), 1,
      sym_attribute_specifier,
    STATE(5023), 1,
      sym__enum_base_clause,
    STATE(5086), 1,
      sym_enumerator_list,
    ACTIONS(5691), 4,
      anon_sym_COMMA,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [231000] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5523), 1,
      anon_sym_LBRACE,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(10535), 1,
      anon_sym_COLON,
    STATE(2293), 1,
      sym_attribute_specifier,
    STATE(5040), 1,
      sym__enum_base_clause,
    STATE(5076), 1,
      sym_enumerator_list,
    ACTIONS(5638), 4,
      anon_sym_COMMA,
      sym_auto,
      anon_sym_decltype,
      anon_sym_GT2,
  [231028] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9636), 1,
      sym_identifier,
    ACTIONS(9735), 1,
      anon_sym_COLON_COLON,
    STATE(2193), 1,
      sym_template_type,
    STATE(6506), 1,
      sym__scope_resolution,
    STATE(7180), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [231058] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10537), 1,
      anon_sym_delete,
    ACTIONS(10539), 1,
      anon_sym_new,
    ACTIONS(10509), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(10507), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [231080] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10543), 1,
      anon_sym_LBRACK,
    STATE(6965), 1,
      sym_gnu_asm_input_operand,
    STATE(8324), 1,
      sym_string_literal,
    ACTIONS(10541), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
  [231104] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3791), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9960), 6,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [231128] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10329), 1,
      anon_sym_COLON,
    ACTIONS(10344), 1,
      anon_sym_LBRACK,
    STATE(6357), 1,
      sym_semantics,
    ACTIONS(10339), 7,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [231150] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3791), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9952), 6,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [231174] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9636), 1,
      sym_identifier,
    ACTIONS(9735), 1,
      anon_sym_COLON_COLON,
    STATE(2193), 1,
      sym_template_type,
    STATE(6506), 1,
      sym__scope_resolution,
    STATE(6882), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [231204] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3708), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9934), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [231228] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1895), 1,
      anon_sym_LBRACK,
    ACTIONS(1897), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [231246] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3708), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9960), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [231270] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10545), 1,
      anon_sym_delete,
    ACTIONS(10547), 1,
      anon_sym_new,
    ACTIONS(10509), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(10507), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [231292] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3708), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9932), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [231316] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1903), 1,
      anon_sym_LBRACK,
    ACTIONS(1905), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [231334] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1899), 1,
      anon_sym_LBRACK,
    ACTIONS(1901), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [231352] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3708), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9930), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [231376] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3756), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9908), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [231400] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3756), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9930), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [231424] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1927), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [231442] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3708), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9952), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [231466] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3756), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9932), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [231490] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3708), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9962), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [231514] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3756), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9962), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [231538] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3756), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9954), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [231562] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3708), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9954), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [231586] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3708), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9908), 6,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [231610] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3791), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9932), 6,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [231634] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3791), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9930), 6,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [231658] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3756), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9960), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [231682] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3791), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9962), 6,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [231706] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10517), 1,
      anon_sym_new,
    ACTIONS(10549), 1,
      anon_sym_delete,
    ACTIONS(10509), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(10507), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [231728] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3791), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9954), 6,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [231752] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10533), 1,
      anon_sym_new,
    ACTIONS(10551), 1,
      anon_sym_delete,
    ACTIONS(10509), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(10507), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [231774] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3756), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9934), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [231798] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5988), 1,
      anon_sym_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10553), 1,
      anon_sym_COMMA,
    STATE(2652), 1,
      sym_parameter_list,
    STATE(6888), 1,
      aux_sym__type_definition_declarators_repeat1,
    ACTIONS(10555), 2,
      anon_sym_SEMI,
      anon_sym___attribute__,
    STATE(6250), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [231828] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10557), 1,
      anon_sym_delete,
    ACTIONS(10559), 1,
      anon_sym_new,
    ACTIONS(10509), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(10507), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [231850] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10561), 1,
      anon_sym_EQ,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(8299), 1,
      sym_initializer_list,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [231882] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(10563), 1,
      sym_identifier,
    ACTIONS(10565), 1,
      anon_sym_COLON_COLON,
    STATE(3032), 1,
      sym_template_type,
    STATE(6481), 1,
      sym__scope_resolution,
    STATE(3037), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [231912] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10559), 1,
      anon_sym_new,
    ACTIONS(10567), 1,
      anon_sym_delete,
    ACTIONS(10509), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(10507), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [231934] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10517), 1,
      anon_sym_new,
    ACTIONS(10569), 1,
      anon_sym_delete,
    ACTIONS(10509), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(10507), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [231956] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9636), 1,
      sym_identifier,
    ACTIONS(9735), 1,
      anon_sym_COLON_COLON,
    STATE(2193), 1,
      sym_template_type,
    STATE(6506), 1,
      sym__scope_resolution,
    STATE(6778), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [231986] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10289), 1,
      anon_sym_LBRACK,
    STATE(6205), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10287), 6,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [232008] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1917), 1,
      anon_sym_LBRACK,
    ACTIONS(1919), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [232026] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1887), 1,
      anon_sym_LBRACK,
    ACTIONS(1889), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [232044] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9636), 1,
      sym_identifier,
    ACTIONS(9735), 1,
      anon_sym_COLON_COLON,
    STATE(2193), 1,
      sym_template_type,
    STATE(6506), 1,
      sym__scope_resolution,
    STATE(7272), 2,
      sym__class_name,
      sym_qualified_type_identifier,
    STATE(8571), 2,
      sym_decltype,
      sym_dependent_type_identifier,
  [232074] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1891), 1,
      anon_sym_LBRACK,
    ACTIONS(1893), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [232092] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3791), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9908), 6,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_final,
      anon_sym_override,
      anon_sym_GT2,
      anon_sym_requires,
  [232116] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10573), 1,
      anon_sym_LBRACK,
    STATE(7013), 1,
      sym_gnu_asm_output_operand,
    STATE(8214), 1,
      sym_string_literal,
    ACTIONS(10571), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
  [232140] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    ACTIONS(10060), 2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [232167] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10575), 1,
      sym_identifier,
    ACTIONS(10579), 1,
      sym_system_lib_string,
    STATE(8267), 2,
      sym_preproc_call_expression,
      sym_string_literal,
    ACTIONS(10577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
  [232188] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7459), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10581), 1,
      sym_identifier,
    ACTIONS(10583), 1,
      anon_sym_template,
    STATE(2405), 1,
      sym_qualified_type_identifier,
    STATE(2427), 1,
      sym_dependent_type_identifier,
    STATE(2428), 1,
      sym_template_type,
    STATE(6441), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [232219] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5361), 1,
      anon_sym_AMP,
    ACTIONS(5365), 2,
      anon_sym_EQ,
      anon_sym_DOT,
    ACTIONS(5359), 6,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [232238] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3363), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9930), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT2,
  [232261] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    ACTIONS(9964), 2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [232288] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3363), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9960), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT2,
  [232311] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3908), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9930), 5,
      anon_sym_RPAREN,
      anon_sym_LBRACK_LBRACK,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [232334] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(410), 1,
      sym_field_declaration_list,
    STATE(6999), 1,
      sym_virtual_specifier,
    STATE(7578), 1,
      sym_base_class_clause,
    ACTIONS(1909), 2,
      anon_sym_else,
      anon_sym_while,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
  [232361] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3363), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9934), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT2,
  [232384] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(4078), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10585), 1,
      sym_identifier,
    ACTIONS(10587), 1,
      anon_sym_template,
    STATE(2199), 1,
      sym_dependent_type_identifier,
    STATE(2205), 1,
      sym_template_type,
    STATE(2228), 1,
      sym_qualified_type_identifier,
    STATE(6449), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [232415] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10589), 1,
      sym_identifier,
    ACTIONS(10591), 1,
      sym_system_lib_string,
    STATE(8579), 2,
      sym_preproc_call_expression,
      sym_string_literal,
    ACTIONS(10577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
  [232436] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(8828), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10593), 1,
      sym_identifier,
    ACTIONS(10595), 1,
      anon_sym_template,
    STATE(3805), 1,
      sym_dependent_type_identifier,
    STATE(3806), 1,
      sym_template_type,
    STATE(3982), 1,
      sym_qualified_type_identifier,
    STATE(6451), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [232467] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3908), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9932), 5,
      anon_sym_RPAREN,
      anon_sym_LBRACK_LBRACK,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [232490] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4384), 1,
      anon_sym_LBRACE,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10597), 1,
      sym_identifier,
    ACTIONS(10599), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10601), 1,
      anon_sym_inline,
    STATE(285), 1,
      sym_declaration_list,
    STATE(6570), 1,
      sym_attribute_declaration,
    STATE(7609), 1,
      sym_nested_namespace_specifier,
    STATE(8298), 1,
      sym__namespace_specifier,
  [232521] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3908), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9960), 5,
      anon_sym_RPAREN,
      anon_sym_LBRACK_LBRACK,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [232544] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9710), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10603), 1,
      sym_identifier,
    STATE(5730), 1,
      sym__scope_resolution,
    STATE(7908), 1,
      sym_qualified_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [232571] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9646), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10605), 1,
      sym_identifier,
    ACTIONS(10607), 1,
      anon_sym_template,
    STATE(143), 1,
      sym_dependent_type_identifier,
    STATE(144), 1,
      sym_template_type,
    STATE(149), 1,
      sym_qualified_type_identifier,
    STATE(6456), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [232602] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9606), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10609), 1,
      sym_identifier,
    ACTIONS(10611), 1,
      anon_sym_template,
    STATE(307), 1,
      sym_template_type,
    STATE(327), 1,
      sym_dependent_type_identifier,
    STATE(330), 1,
      sym_qualified_type_identifier,
    STATE(6457), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [232633] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(8975), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10613), 1,
      sym_identifier,
    ACTIONS(10615), 1,
      anon_sym_template,
    STATE(2199), 1,
      sym_dependent_type_identifier,
    STATE(2205), 1,
      sym_template_type,
    STATE(2363), 1,
      sym_qualified_type_identifier,
    STATE(6458), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [232664] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7483), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10617), 1,
      sym_identifier,
    ACTIONS(10619), 1,
      anon_sym_template,
    STATE(4668), 1,
      sym_dependent_type_identifier,
    STATE(4669), 1,
      sym_template_type,
    STATE(4829), 1,
      sym_qualified_type_identifier,
    STATE(6459), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [232695] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3908), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9908), 5,
      anon_sym_RPAREN,
      anon_sym_LBRACK_LBRACK,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [232718] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(8938), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10613), 1,
      sym_identifier,
    ACTIONS(10615), 1,
      anon_sym_template,
    STATE(2199), 1,
      sym_dependent_type_identifier,
    STATE(2205), 1,
      sym_template_type,
    STATE(2228), 1,
      sym_qualified_type_identifier,
    STATE(6461), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [232749] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3908), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9962), 5,
      anon_sym_RPAREN,
      anon_sym_LBRACK_LBRACK,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [232772] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5361), 1,
      anon_sym_AMP,
    ACTIONS(5363), 2,
      anon_sym_if,
      anon_sym_for,
    ACTIONS(5359), 6,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [232791] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(8806), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10621), 1,
      sym_identifier,
    ACTIONS(10623), 1,
      anon_sym_template,
    STATE(2931), 1,
      sym_template_type,
    STATE(2947), 1,
      sym_dependent_type_identifier,
    STATE(2961), 1,
      sym_qualified_type_identifier,
    STATE(6464), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [232822] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(463), 1,
      sym_field_declaration_list,
    STATE(6934), 1,
      sym_virtual_specifier,
    STATE(7561), 1,
      sym_base_class_clause,
    ACTIONS(1923), 2,
      anon_sym_else,
      anon_sym_while,
    ACTIONS(6074), 2,
      anon_sym_final,
      anon_sym_override,
  [232849] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10625), 1,
      sym_identifier,
    ACTIONS(10627), 1,
      sym_system_lib_string,
    STATE(8569), 2,
      sym_preproc_call_expression,
      sym_string_literal,
    ACTIONS(10577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
  [232870] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9596), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10629), 1,
      sym_identifier,
    ACTIONS(10631), 1,
      anon_sym_template,
    STATE(950), 1,
      sym_template_type,
    STATE(951), 1,
      sym_dependent_type_identifier,
    STATE(954), 1,
      sym_qualified_type_identifier,
    STATE(6467), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [232901] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3908), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9954), 5,
      anon_sym_RPAREN,
      anon_sym_LBRACK_LBRACK,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [232924] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3363), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9932), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_EQ,
      anon_sym_GT2,
  [232947] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9710), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10633), 1,
      sym_identifier,
    STATE(5730), 1,
      sym__scope_resolution,
    STATE(7973), 1,
      sym_qualified_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [232974] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3908), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9934), 5,
      anon_sym_RPAREN,
      anon_sym_LBRACK_LBRACK,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [232997] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9700), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10635), 1,
      sym_identifier,
    ACTIONS(10637), 1,
      anon_sym_template,
    STATE(241), 1,
      sym_dependent_type_identifier,
    STATE(252), 1,
      sym_template_type,
    STATE(277), 1,
      sym_qualified_type_identifier,
    STATE(6472), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [233028] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9910), 1,
      anon_sym_LBRACK,
    STATE(3908), 1,
      sym_parameter_list,
    STATE(5907), 1,
      sym__function_declarator_seq,
    ACTIONS(9952), 5,
      anon_sym_RPAREN,
      anon_sym_LBRACK_LBRACK,
      anon_sym_final,
      anon_sym_override,
      anon_sym_requires,
  [233051] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9710), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10639), 1,
      sym_identifier,
    STATE(5730), 1,
      sym__scope_resolution,
    STATE(8276), 1,
      sym_qualified_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [233078] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7547), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10615), 1,
      anon_sym_template,
    ACTIONS(10641), 1,
      sym_identifier,
    STATE(2199), 1,
      sym_dependent_type_identifier,
    STATE(2205), 1,
      sym_template_type,
    STATE(2363), 1,
      sym_qualified_type_identifier,
    STATE(6475), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [233109] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9670), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10643), 1,
      sym_identifier,
    ACTIONS(10645), 1,
      anon_sym_template,
    STATE(302), 1,
      sym_qualified_type_identifier,
    STATE(311), 1,
      sym_template_type,
    STATE(321), 1,
      sym_dependent_type_identifier,
    STATE(6476), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [233140] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    STATE(3035), 1,
      sym_template_argument_list,
    ACTIONS(5842), 2,
      anon_sym_COLON,
      anon_sym_LBRACK,
    ACTIONS(5188), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
  [233163] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    STATE(3035), 1,
      sym_template_argument_list,
    ACTIONS(4050), 2,
      anon_sym_COLON,
      anon_sym_LBRACK,
    ACTIONS(4045), 4,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
  [233186] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7525), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10647), 1,
      sym_identifier,
    ACTIONS(10649), 1,
      anon_sym_template,
    STATE(2199), 1,
      sym_dependent_type_identifier,
    STATE(2205), 1,
      sym_template_type,
    STATE(2363), 1,
      sym_qualified_type_identifier,
    STATE(6479), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [233217] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9710), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10651), 1,
      sym_identifier,
    STATE(5730), 1,
      sym__scope_resolution,
    STATE(8415), 1,
      sym_qualified_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [233244] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(10565), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10653), 1,
      sym_identifier,
    ACTIONS(10655), 1,
      anon_sym_template,
    STATE(3041), 1,
      sym_qualified_type_identifier,
    STATE(3074), 1,
      sym_template_type,
    STATE(3075), 1,
      sym_dependent_type_identifier,
    STATE(6481), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [233275] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(7477), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10657), 1,
      sym_identifier,
    ACTIONS(10659), 1,
      anon_sym_template,
    STATE(2877), 1,
      sym_dependent_type_identifier,
    STATE(2882), 1,
      sym_template_type,
    STATE(2941), 1,
      sym_qualified_type_identifier,
    STATE(6482), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [233306] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    ACTIONS(10087), 2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [233333] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4388), 1,
      anon_sym_LBRACE,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10599), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10601), 1,
      anon_sym_inline,
    ACTIONS(10661), 1,
      sym_identifier,
    STATE(546), 1,
      sym_declaration_list,
    STATE(6609), 1,
      sym_attribute_declaration,
    STATE(7742), 1,
      sym_nested_namespace_specifier,
    STATE(8298), 1,
      sym__namespace_specifier,
  [233364] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(8877), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10663), 1,
      sym_identifier,
    ACTIONS(10665), 1,
      anon_sym_template,
    STATE(3066), 1,
      sym_dependent_type_identifier,
    STATE(3067), 1,
      sym_template_type,
    STATE(3102), 1,
      sym_qualified_type_identifier,
    STATE(6485), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [233395] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(8850), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10667), 1,
      sym_identifier,
    ACTIONS(10669), 1,
      anon_sym_template,
    STATE(2902), 1,
      sym_dependent_type_identifier,
    STATE(2909), 1,
      sym_template_type,
    STATE(2932), 1,
      sym_qualified_type_identifier,
    STATE(6486), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [233426] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5988), 1,
      anon_sym_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    STATE(2652), 1,
      sym_parameter_list,
    STATE(6250), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(10671), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
  [233451] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9638), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10673), 1,
      sym_identifier,
    STATE(2199), 1,
      sym_dependent_type_identifier,
    STATE(2205), 1,
      sym_template_type,
    STATE(2405), 1,
      sym_qualified_type_identifier,
    STATE(6488), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [233482] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(8767), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10583), 1,
      anon_sym_template,
    ACTIONS(10675), 1,
      sym_identifier,
    STATE(2405), 1,
      sym_qualified_type_identifier,
    STATE(2427), 1,
      sym_dependent_type_identifier,
    STATE(2428), 1,
      sym_template_type,
    STATE(6489), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [233513] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4386), 1,
      anon_sym_LBRACE,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10599), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10601), 1,
      anon_sym_inline,
    ACTIONS(10677), 1,
      sym_identifier,
    STATE(666), 1,
      sym_declaration_list,
    STATE(6567), 1,
      sym_attribute_declaration,
    STATE(7522), 1,
      sym_nested_namespace_specifier,
    STATE(8298), 1,
      sym__namespace_specifier,
  [233544] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9710), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10679), 1,
      sym_identifier,
    STATE(5730), 1,
      sym__scope_resolution,
    STATE(8126), 1,
      sym_qualified_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [233571] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4380), 1,
      anon_sym_LBRACE,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10599), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10601), 1,
      anon_sym_inline,
    ACTIONS(10681), 1,
      sym_identifier,
    STATE(754), 1,
      sym_declaration_list,
    STATE(6569), 1,
      sym_attribute_declaration,
    STATE(7810), 1,
      sym_nested_namespace_specifier,
    STATE(8298), 1,
      sym__namespace_specifier,
  [233602] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    ACTIONS(9984), 2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [233629] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10683), 1,
      sym_identifier,
    ACTIONS(10685), 1,
      sym_system_lib_string,
    STATE(8036), 2,
      sym_preproc_call_expression,
      sym_string_literal,
    ACTIONS(10577), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
  [233650] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4384), 1,
      anon_sym_LBRACE,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10599), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10601), 1,
      anon_sym_inline,
    ACTIONS(10687), 1,
      sym_identifier,
    STATE(329), 1,
      sym_declaration_list,
    STATE(6572), 1,
      sym_attribute_declaration,
    STATE(7626), 1,
      sym_nested_namespace_specifier,
    STATE(8298), 1,
      sym__namespace_specifier,
  [233681] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    ACTIONS(10052), 2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [233708] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(8784), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10689), 1,
      sym_identifier,
    ACTIONS(10691), 1,
      anon_sym_template,
    STATE(2495), 1,
      sym_dependent_type_identifier,
    STATE(2496), 1,
      sym_template_type,
    STATE(2529), 1,
      sym_qualified_type_identifier,
    STATE(6497), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [233739] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9710), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10693), 1,
      sym_identifier,
    STATE(5730), 1,
      sym__scope_resolution,
    STATE(8185), 1,
      sym_qualified_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [233766] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4388), 1,
      anon_sym_LBRACE,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10599), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10601), 1,
      anon_sym_inline,
    ACTIONS(10695), 1,
      sym_identifier,
    STATE(676), 1,
      sym_declaration_list,
    STATE(6582), 1,
      sym_attribute_declaration,
    STATE(7732), 1,
      sym_nested_namespace_specifier,
    STATE(8298), 1,
      sym__namespace_specifier,
  [233797] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9710), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10697), 1,
      sym_identifier,
    STATE(5730), 1,
      sym__scope_resolution,
    STATE(8040), 1,
      sym_qualified_identifier,
    STATE(8571), 3,
      sym_decltype,
      sym_template_type,
      sym_dependent_type_identifier,
  [233824] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9202), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10699), 1,
      sym_identifier,
    ACTIONS(10701), 1,
      anon_sym_template,
    STATE(2198), 1,
      sym_dependent_type_identifier,
    STATE(2206), 1,
      sym_template_type,
    STATE(2215), 1,
      sym_qualified_type_identifier,
    STATE(6501), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [233855] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4380), 1,
      anon_sym_LBRACE,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10599), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10601), 1,
      anon_sym_inline,
    ACTIONS(10703), 1,
      sym_identifier,
    STATE(777), 1,
      sym_declaration_list,
    STATE(6587), 1,
      sym_attribute_declaration,
    STATE(7585), 1,
      sym_nested_namespace_specifier,
    STATE(8298), 1,
      sym__namespace_specifier,
  [233886] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4386), 1,
      anon_sym_LBRACE,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10599), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10601), 1,
      anon_sym_inline,
    ACTIONS(10705), 1,
      sym_identifier,
    STATE(699), 1,
      sym_declaration_list,
    STATE(6616), 1,
      sym_attribute_declaration,
    STATE(7540), 1,
      sym_nested_namespace_specifier,
    STATE(8298), 1,
      sym__namespace_specifier,
  [233917] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(3493), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10647), 1,
      sym_identifier,
    ACTIONS(10649), 1,
      anon_sym_template,
    STATE(2199), 1,
      sym_dependent_type_identifier,
    STATE(2205), 1,
      sym_template_type,
    STATE(2228), 1,
      sym_qualified_type_identifier,
    STATE(6504), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [233948] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(8753), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10659), 1,
      anon_sym_template,
    ACTIONS(10707), 1,
      sym_identifier,
    STATE(2877), 1,
      sym_dependent_type_identifier,
    STATE(2882), 1,
      sym_template_type,
    STATE(2941), 1,
      sym_qualified_type_identifier,
    STATE(6505), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [233979] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      anon_sym_template,
    ACTIONS(2855), 1,
      anon_sym_decltype,
    ACTIONS(9735), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10673), 1,
      sym_identifier,
    STATE(2199), 1,
      sym_dependent_type_identifier,
    STATE(2205), 1,
      sym_template_type,
    STATE(2228), 1,
      sym_qualified_type_identifier,
    STATE(6506), 1,
      sym__scope_resolution,
    STATE(8571), 1,
      sym_decltype,
  [234010] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    ACTIONS(10709), 1,
      anon_sym_SEMI,
    ACTIONS(10711), 1,
      anon_sym_EQ,
    STATE(2390), 1,
      sym_template_argument_list,
    STATE(6979), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234036] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9132), 1,
      anon_sym_LBRACK,
    ACTIONS(10222), 1,
      anon_sym_RPAREN,
    STATE(3891), 1,
      sym_parameter_list,
    STATE(6281), 1,
      sym__function_declarator_seq,
    STATE(6620), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234062] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10124), 1,
      anon_sym_LBRACK,
    STATE(6307), 1,
      sym_parameter_list,
    ACTIONS(6066), 2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(6595), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234086] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    ACTIONS(10713), 1,
      anon_sym_SEMI,
    ACTIONS(10715), 1,
      anon_sym_EQ,
    STATE(2390), 1,
      sym_template_argument_list,
    STATE(6921), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234112] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10124), 1,
      anon_sym_LBRACK,
    STATE(6307), 1,
      sym_parameter_list,
    ACTIONS(6026), 2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(6595), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234136] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10124), 1,
      anon_sym_LBRACK,
    STATE(6307), 1,
      sym_parameter_list,
    ACTIONS(5998), 2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(6595), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234160] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3644), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9934), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [234182] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10717), 1,
      anon_sym_COLON,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234208] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10719), 1,
      anon_sym_RPAREN,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234234] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    ACTIONS(10721), 1,
      anon_sym_SEMI,
    ACTIONS(10723), 1,
      anon_sym_EQ,
    STATE(2390), 1,
      sym_template_argument_list,
    STATE(6743), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234260] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    ACTIONS(10329), 1,
      anon_sym_COLON,
    STATE(3679), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    STATE(7349), 1,
      sym_semantics,
    ACTIONS(10327), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [234286] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10543), 1,
      anon_sym_LBRACK,
    STATE(7204), 1,
      sym_gnu_asm_input_operand,
    STATE(8324), 1,
      sym_string_literal,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
  [234306] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10725), 1,
      anon_sym_SEMI,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234332] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10727), 1,
      anon_sym_SEMI,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234358] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3644), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(10729), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [234380] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9132), 1,
      anon_sym_LBRACK,
    ACTIONS(10173), 1,
      anon_sym_RPAREN,
    STATE(3891), 1,
      sym_parameter_list,
    STATE(6281), 1,
      sym__function_declarator_seq,
    STATE(6620), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234406] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10733), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(10731), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [234422] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10735), 1,
      anon_sym_SEMI,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234448] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4050), 1,
      anon_sym_LBRACK,
    ACTIONS(5298), 1,
      anon_sym_LT,
    STATE(6210), 1,
      sym_template_argument_list,
    ACTIONS(4045), 4,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [234470] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9132), 1,
      anon_sym_LBRACK,
    ACTIONS(10098), 1,
      anon_sym_RPAREN,
    STATE(3891), 1,
      sym_parameter_list,
    STATE(6281), 1,
      sym__function_declarator_seq,
    STATE(6620), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234496] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10737), 1,
      anon_sym_SEMI,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234522] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9132), 1,
      anon_sym_LBRACK,
    ACTIONS(10179), 1,
      anon_sym_RPAREN,
    STATE(3891), 1,
      sym_parameter_list,
    STATE(6281), 1,
      sym__function_declarator_seq,
    STATE(6620), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234548] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10124), 1,
      anon_sym_LBRACK,
    STATE(6307), 1,
      sym_parameter_list,
    ACTIONS(5982), 2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(6595), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234572] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9984), 1,
      anon_sym_COLON,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234598] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10573), 1,
      anon_sym_LBRACK,
    STATE(7437), 1,
      sym_gnu_asm_output_operand,
    STATE(8214), 1,
      sym_string_literal,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
  [234618] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10739), 1,
      sym_identifier,
    ACTIONS(10744), 1,
      aux_sym_preproc_elif_token1,
    STATE(6532), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(8250), 1,
      sym_enumerator,
    ACTIONS(10742), 4,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
  [234640] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10060), 1,
      anon_sym_COLON,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234666] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9132), 1,
      anon_sym_LBRACK,
    ACTIONS(10189), 1,
      anon_sym_RPAREN,
    STATE(3891), 1,
      sym_parameter_list,
    STATE(6281), 1,
      sym__function_declarator_seq,
    STATE(6620), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234692] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10052), 1,
      anon_sym_COLON,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234718] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10124), 1,
      anon_sym_LBRACK,
    STATE(6307), 1,
      sym_parameter_list,
    ACTIONS(6002), 2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    STATE(6595), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234742] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10746), 1,
      anon_sym_RPAREN,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234768] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9132), 1,
      anon_sym_LBRACK,
    ACTIONS(10748), 1,
      anon_sym_RPAREN,
    STATE(3891), 1,
      sym_parameter_list,
    STATE(6281), 1,
      sym__function_declarator_seq,
    STATE(6620), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234794] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3644), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9932), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [234816] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10750), 1,
      anon_sym_SEMI,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234842] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    ACTIONS(10329), 1,
      anon_sym_COLON,
    STATE(3745), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    STATE(7349), 1,
      sym_semantics,
    ACTIONS(10327), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
  [234868] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10752), 1,
      anon_sym_SEMI,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [234894] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10756), 3,
      anon_sym_TILDE,
      anon_sym_STAR,
      anon_sym_COLON_COLON,
    ACTIONS(10754), 5,
      anon_sym___based,
      sym_identifier,
      anon_sym_decltype,
      anon_sym_template,
      anon_sym_operator,
  [234910] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10760), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(10762), 1,
      anon_sym_EQ,
    ACTIONS(10758), 6,
      anon_sym_COMMA,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      sym_identifier,
  [234928] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10764), 1,
      sym_identifier,
    ACTIONS(10769), 1,
      aux_sym_preproc_elif_token1,
    STATE(6545), 2,
      sym_enumerator,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
    ACTIONS(10767), 4,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
  [234948] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3644), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9960), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [234970] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3644), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9930), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [234992] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10087), 1,
      anon_sym_COLON,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [235018] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    ACTIONS(10771), 1,
      anon_sym_SEMI,
    ACTIONS(10773), 1,
      anon_sym_EQ,
    STATE(2390), 1,
      sym_template_argument_list,
    STATE(6856), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [235044] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(9964), 1,
      anon_sym_COLON,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(6161), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [235070] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    ACTIONS(10775), 1,
      anon_sym_SEMI,
    ACTIONS(10777), 1,
      anon_sym_EQ,
    STATE(2390), 1,
      sym_template_argument_list,
    STATE(6764), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [235096] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    ACTIONS(10779), 1,
      anon_sym_SEMI,
    ACTIONS(10781), 1,
      anon_sym_EQ,
    STATE(2390), 1,
      sym_template_argument_list,
    STATE(6885), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [235122] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10783), 1,
      anon_sym_SEMI,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [235148] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5298), 1,
      anon_sym_LT,
    ACTIONS(6306), 1,
      anon_sym_LBRACK,
    STATE(3035), 1,
      sym_template_argument_list,
    ACTIONS(6308), 5,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
  [235168] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    ACTIONS(5842), 1,
      anon_sym_LBRACK,
    STATE(6210), 1,
      sym_template_argument_list,
    ACTIONS(5188), 4,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [235190] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    ACTIONS(10785), 1,
      anon_sym_SEMI,
    STATE(3428), 1,
      sym_parameter_list,
    STATE(6396), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [235216] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9132), 1,
      anon_sym_LBRACK,
    ACTIONS(10787), 1,
      anon_sym_RPAREN,
    STATE(3891), 1,
      sym_parameter_list,
    STATE(6281), 1,
      sym__function_declarator_seq,
    STATE(6620), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [235242] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    ACTIONS(10789), 1,
      anon_sym_SEMI,
    ACTIONS(10791), 1,
      anon_sym_EQ,
    STATE(2390), 1,
      sym_template_argument_list,
    STATE(6759), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [235268] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10795), 1,
      anon_sym_COMMA,
    ACTIONS(10797), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(10793), 5,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      sym_identifier,
  [235285] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10799), 1,
      anon_sym_LBRACK,
    ACTIONS(10801), 1,
      anon_sym_EQ,
    ACTIONS(10803), 1,
      anon_sym_DOT,
    STATE(6604), 4,
      sym_subscript_designator,
      sym_subscript_range_designator,
      sym_field_designator,
      aux_sym_initializer_pair_repeat1,
  [235304] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9728), 1,
      anon_sym_LBRACK,
    STATE(3124), 1,
      sym_parameter_list,
    STATE(6226), 1,
      sym__function_declarator_seq,
    STATE(6432), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [235327] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3794), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9908), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
  [235348] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9962), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [235369] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3794), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9952), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
  [235390] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9930), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [235411] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5988), 1,
      anon_sym_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10805), 1,
      anon_sym_RPAREN,
    STATE(2652), 1,
      sym_parameter_list,
    STATE(6250), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [235434] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4386), 1,
      anon_sym_LBRACE,
    ACTIONS(10599), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10601), 1,
      anon_sym_inline,
    ACTIONS(10705), 1,
      sym_identifier,
    STATE(699), 1,
      sym_declaration_list,
    STATE(7540), 1,
      sym_nested_namespace_specifier,
    STATE(8298), 1,
      sym__namespace_specifier,
  [235459] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5988), 1,
      anon_sym_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10807), 1,
      anon_sym_RPAREN,
    STATE(2652), 1,
      sym_parameter_list,
    STATE(6250), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [235482] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4380), 1,
      anon_sym_LBRACE,
    ACTIONS(10599), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10601), 1,
      anon_sym_inline,
    ACTIONS(10809), 1,
      sym_identifier,
    STATE(722), 1,
      sym_declaration_list,
    STATE(7700), 1,
      sym_nested_namespace_specifier,
    STATE(8298), 1,
      sym__namespace_specifier,
  [235507] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4384), 1,
      anon_sym_LBRACE,
    ACTIONS(10599), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10601), 1,
      anon_sym_inline,
    ACTIONS(10687), 1,
      sym_identifier,
    STATE(329), 1,
      sym_declaration_list,
    STATE(7626), 1,
      sym_nested_namespace_specifier,
    STATE(8298), 1,
      sym__namespace_specifier,
  [235532] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3679), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9934), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [235553] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4384), 1,
      anon_sym_LBRACE,
    ACTIONS(10599), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10601), 1,
      anon_sym_inline,
    ACTIONS(10811), 1,
      sym_identifier,
    STATE(267), 1,
      sym_declaration_list,
    STATE(7645), 1,
      sym_nested_namespace_specifier,
    STATE(8298), 1,
      sym__namespace_specifier,
  [235578] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3745), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9932), 3,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_GT2,
  [235599] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3679), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9930), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [235620] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5361), 1,
      anon_sym_AMP,
    ACTIONS(5359), 6,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [235635] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3745), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9934), 3,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_GT2,
  [235656] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9960), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [235677] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9932), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [235698] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5308), 1,
      anon_sym_AMP,
    ACTIONS(5310), 6,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_requires,
  [235713] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5988), 1,
      anon_sym_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10813), 1,
      anon_sym_RPAREN,
    STATE(2652), 1,
      sym_parameter_list,
    STATE(6250), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [235736] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5988), 1,
      anon_sym_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10815), 1,
      anon_sym_RPAREN,
    STATE(2652), 1,
      sym_parameter_list,
    STATE(6250), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [235759] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4388), 1,
      anon_sym_LBRACE,
    ACTIONS(10599), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10601), 1,
      anon_sym_inline,
    ACTIONS(10661), 1,
      sym_identifier,
    STATE(546), 1,
      sym_declaration_list,
    STATE(7742), 1,
      sym_nested_namespace_specifier,
    STATE(8298), 1,
      sym__namespace_specifier,
  [235784] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4521), 1,
      anon_sym_AMP,
    ACTIONS(4519), 6,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [235799] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5988), 1,
      anon_sym_LBRACK,
    ACTIONS(6026), 1,
      anon_sym_COLON,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    STATE(2652), 1,
      sym_parameter_list,
    STATE(6657), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [235822] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5982), 1,
      anon_sym_COLON,
    ACTIONS(5988), 1,
      anon_sym_LBRACK,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    STATE(2652), 1,
      sym_parameter_list,
    STATE(6657), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [235845] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5988), 1,
      anon_sym_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10817), 1,
      anon_sym_RPAREN,
    STATE(2652), 1,
      sym_parameter_list,
    STATE(6250), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [235868] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4380), 1,
      anon_sym_LBRACE,
    ACTIONS(10599), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10601), 1,
      anon_sym_inline,
    ACTIONS(10681), 1,
      sym_identifier,
    STATE(754), 1,
      sym_declaration_list,
    STATE(7810), 1,
      sym_nested_namespace_specifier,
    STATE(8298), 1,
      sym__namespace_specifier,
  [235893] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10821), 1,
      anon_sym_AMP,
    ACTIONS(10819), 6,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [235908] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5988), 1,
      anon_sym_LBRACK,
    ACTIONS(5998), 1,
      anon_sym_COLON,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    STATE(2652), 1,
      sym_parameter_list,
    STATE(6657), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [235931] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3794), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9962), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
  [235952] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5988), 1,
      anon_sym_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10823), 1,
      anon_sym_RPAREN,
    STATE(2652), 1,
      sym_parameter_list,
    STATE(6250), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [235975] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3794), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9930), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
  [235996] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9908), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [236017] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3679), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9960), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [236038] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6132), 1,
      anon_sym_LBRACK,
    STATE(6205), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
    ACTIONS(6134), 3,
      anon_sym_LPAREN2,
      anon_sym_LBRACE,
      anon_sym_EQ,
  [236057] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5988), 1,
      anon_sym_LBRACK,
    ACTIONS(6002), 1,
      anon_sym_COLON,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    STATE(2652), 1,
      sym_parameter_list,
    STATE(6657), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [236080] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3794), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9954), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
  [236101] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3745), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9960), 3,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_GT2,
  [236122] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10827), 1,
      anon_sym_AMP,
    ACTIONS(10825), 6,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [236137] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3745), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9930), 3,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_GT2,
  [236158] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3679), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9932), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [236179] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3794), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9932), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
  [236200] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3794), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9960), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
  [236221] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10829), 1,
      anon_sym_LBRACK,
    ACTIONS(10832), 1,
      anon_sym_EQ,
    ACTIONS(10834), 1,
      anon_sym_DOT,
    STATE(6604), 4,
      sym_subscript_designator,
      sym_subscript_range_designator,
      sym_field_designator,
      aux_sym_initializer_pair_repeat1,
  [236240] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5988), 1,
      anon_sym_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10837), 1,
      anon_sym_RPAREN,
    STATE(2652), 1,
      sym_parameter_list,
    STATE(6250), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [236263] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5298), 1,
      anon_sym_LT,
    ACTIONS(6306), 1,
      anon_sym_LBRACK,
    STATE(6210), 1,
      sym_template_argument_list,
    ACTIONS(6308), 4,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
      anon_sym_LBRACE,
      anon_sym_try,
  [236282] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5300), 1,
      anon_sym_AMP,
    ACTIONS(5302), 6,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_requires,
  [236297] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9954), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [236318] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4388), 1,
      anon_sym_LBRACE,
    ACTIONS(10599), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10601), 1,
      anon_sym_inline,
    ACTIONS(10839), 1,
      sym_identifier,
    STATE(616), 1,
      sym_declaration_list,
    STATE(7774), 1,
      sym_nested_namespace_specifier,
    STATE(8298), 1,
      sym__namespace_specifier,
  [236343] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(5298), 1,
      anon_sym_LT,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    STATE(2679), 1,
      sym_template_argument_list,
    STATE(7132), 2,
      sym_argument_list,
      sym_initializer_list,
  [236366] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9952), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [236387] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10843), 1,
      anon_sym_AMP,
    ACTIONS(10841), 6,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LT,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
  [236402] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3794), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9934), 3,
      anon_sym_DOT_DOT_DOT,
      anon_sym_COMMA,
      anon_sym_GT2,
  [236423] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(5988), 1,
      anon_sym_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10845), 1,
      anon_sym_RPAREN,
    STATE(2652), 1,
      sym_parameter_list,
    STATE(6250), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [236446] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
    ACTIONS(9934), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_SEMI,
  [236467] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4386), 1,
      anon_sym_LBRACE,
    ACTIONS(10599), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10601), 1,
      anon_sym_inline,
    ACTIONS(10847), 1,
      sym_identifier,
    STATE(670), 1,
      sym_declaration_list,
    STATE(7562), 1,
      sym_nested_namespace_specifier,
    STATE(8298), 1,
      sym__namespace_specifier,
  [236492] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5988), 1,
      anon_sym_LBRACK,
    ACTIONS(6066), 1,
      anon_sym_COLON,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    STATE(2652), 1,
      sym_parameter_list,
    STATE(6657), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [236515] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5262), 1,
      anon_sym_AMP,
    ACTIONS(5264), 6,
      anon_sym_LPAREN2,
      anon_sym_STAR,
      anon_sym_AMP_AMP,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_requires,
  [236530] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10849), 2,
      anon_sym_RBRACE,
      sym_identifier,
    ACTIONS(10851), 4,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [236544] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10325), 1,
      anon_sym_LBRACK,
    ACTIONS(10323), 2,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
    STATE(6205), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [236562] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9152), 1,
      anon_sym_try,
    ACTIONS(10108), 1,
      anon_sym_LBRACE,
    ACTIONS(10853), 1,
      anon_sym_SEMI,
    ACTIONS(10855), 1,
      anon_sym_EQ,
    STATE(2172), 2,
      sym_compound_statement,
      sym_try_statement,
  [236582] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10857), 1,
      anon_sym_LPAREN2,
    STATE(6624), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(10859), 3,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
  [236598] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5298), 1,
      anon_sym_LT,
    ACTIONS(10335), 1,
      anon_sym_LBRACK,
    STATE(6322), 1,
      sym_template_argument_list,
    ACTIONS(10333), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [236616] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10861), 1,
      anon_sym_LPAREN2,
    STATE(6633), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(10859), 3,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
  [236632] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10863), 1,
      anon_sym_LPAREN2,
    STATE(6638), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(10859), 3,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
  [236648] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9152), 1,
      anon_sym_try,
    ACTIONS(10108), 1,
      anon_sym_LBRACE,
    ACTIONS(10865), 1,
      anon_sym_SEMI,
    ACTIONS(10867), 1,
      anon_sym_EQ,
    STATE(2090), 2,
      sym_compound_statement,
      sym_try_statement,
  [236668] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10869), 1,
      anon_sym_LPAREN2,
    STATE(6670), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(10859), 3,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
  [236684] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      anon_sym_LBRACE,
    ACTIONS(9747), 1,
      anon_sym_try,
    ACTIONS(10871), 1,
      anon_sym_SEMI,
    ACTIONS(10873), 1,
      anon_sym_EQ,
    STATE(335), 2,
      sym_compound_statement,
      sym_try_statement,
  [236704] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(633), 1,
      anon_sym_LBRACE,
    ACTIONS(9773), 1,
      anon_sym_try,
    ACTIONS(10875), 1,
      anon_sym_SEMI,
    ACTIONS(10877), 1,
      anon_sym_EQ,
    STATE(553), 2,
      sym_compound_statement,
      sym_try_statement,
  [236724] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10879), 2,
      anon_sym_RBRACE,
      sym_identifier,
    ACTIONS(10881), 4,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [236738] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    ACTIONS(9753), 1,
      anon_sym_try,
    ACTIONS(10883), 1,
      anon_sym_SEMI,
    ACTIONS(10885), 1,
      anon_sym_EQ,
    STATE(802), 2,
      sym_compound_statement,
      sym_try_statement,
  [236758] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10887), 1,
      anon_sym_LPAREN2,
    STATE(6655), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(10859), 3,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
  [236774] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10889), 1,
      anon_sym_LPAREN2,
    STATE(6633), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(10891), 3,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
  [236790] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10366), 2,
      anon_sym_RBRACE,
      sym_identifier,
    ACTIONS(10894), 4,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [236804] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9136), 1,
      anon_sym_try,
    ACTIONS(10128), 1,
      anon_sym_LBRACE,
    ACTIONS(10896), 1,
      anon_sym_SEMI,
    ACTIONS(10898), 1,
      anon_sym_EQ,
    STATE(2179), 2,
      sym_compound_statement,
      sym_try_statement,
  [236824] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9144), 1,
      anon_sym_try,
    ACTIONS(10118), 1,
      anon_sym_LBRACE,
    ACTIONS(10900), 1,
      anon_sym_SEMI,
    ACTIONS(10902), 1,
      anon_sym_EQ,
    STATE(1849), 2,
      sym_compound_statement,
      sym_try_statement,
  [236844] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10904), 2,
      anon_sym_RBRACE,
      sym_identifier,
    ACTIONS(10906), 4,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [236858] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10908), 1,
      anon_sym_LPAREN2,
    STATE(6633), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(10859), 3,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
  [236874] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10910), 1,
      anon_sym_EQ,
    ACTIONS(10054), 5,
      anon_sym_COMMA,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
      anon_sym_GT2,
  [236888] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5628), 1,
      anon_sym_LT,
    ACTIONS(6306), 1,
      anon_sym_LBRACK,
    STATE(2441), 1,
      sym_template_argument_list,
    ACTIONS(6308), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [236906] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      anon_sym_LBRACE,
    ACTIONS(9747), 1,
      anon_sym_try,
    ACTIONS(10912), 1,
      anon_sym_SEMI,
    ACTIONS(10914), 1,
      anon_sym_EQ,
    STATE(287), 2,
      sym_compound_statement,
      sym_try_statement,
  [236926] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10879), 2,
      anon_sym_RBRACE,
      sym_identifier,
    ACTIONS(10881), 4,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [236940] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10916), 1,
      anon_sym_LPAREN2,
    STATE(6651), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(10859), 3,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
  [236956] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10918), 2,
      anon_sym_RBRACE,
      sym_identifier,
    ACTIONS(10920), 4,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [236970] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10922), 1,
      anon_sym_EQ,
    ACTIONS(10054), 5,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_COLON,
      anon_sym_LBRACK,
  [236984] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6883), 1,
      anon_sym___attribute__,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    STATE(5552), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5760), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [237002] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5298), 1,
      anon_sym_LT,
    ACTIONS(10318), 1,
      anon_sym_LBRACK,
    STATE(6283), 1,
      sym_template_argument_list,
    ACTIONS(10314), 3,
      anon_sym_RPAREN,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [237020] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10924), 1,
      anon_sym_LPAREN2,
    STATE(6633), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(10859), 3,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
  [237036] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10926), 1,
      anon_sym_LPAREN2,
    STATE(6648), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(10859), 3,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
  [237052] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5298), 1,
      anon_sym_LT,
    ACTIONS(6306), 1,
      anon_sym_LBRACK,
    STATE(2441), 1,
      sym_template_argument_list,
    ACTIONS(6308), 3,
      anon_sym_LPAREN2,
      anon_sym_SEMI,
      anon_sym_LBRACK_LBRACK,
  [237070] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10928), 1,
      anon_sym_LPAREN2,
    STATE(6633), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(10859), 3,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
  [237086] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4991), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    STATE(5590), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
    STATE(5819), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [237104] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    ACTIONS(9753), 1,
      anon_sym_try,
    ACTIONS(10930), 1,
      anon_sym_SEMI,
    ACTIONS(10932), 1,
      anon_sym_EQ,
    STATE(811), 2,
      sym_compound_statement,
      sym_try_statement,
  [237124] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10934), 2,
      anon_sym_RBRACE,
      sym_identifier,
    ACTIONS(10936), 4,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [237138] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10938), 1,
      anon_sym_LPAREN2,
    STATE(6633), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(10859), 3,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
  [237154] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9136), 1,
      anon_sym_try,
    ACTIONS(10128), 1,
      anon_sym_LBRACE,
    ACTIONS(10940), 1,
      anon_sym_SEMI,
    ACTIONS(10942), 1,
      anon_sym_EQ,
    STATE(2060), 2,
      sym_compound_statement,
      sym_try_statement,
  [237174] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6132), 1,
      anon_sym_LBRACK,
    ACTIONS(7136), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(6134), 2,
      anon_sym_LPAREN2,
      anon_sym_COLON,
    STATE(5747), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [237192] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(8593), 1,
      sym_string_literal,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
  [237206] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10944), 2,
      anon_sym_RBRACE,
      sym_identifier,
    ACTIONS(10946), 4,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [237220] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(633), 1,
      anon_sym_LBRACE,
    ACTIONS(9773), 1,
      anon_sym_try,
    ACTIONS(10948), 1,
      anon_sym_SEMI,
    ACTIONS(10950), 1,
      anon_sym_EQ,
    STATE(683), 2,
      sym_compound_statement,
      sym_try_statement,
  [237240] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10952), 1,
      anon_sym_LPAREN2,
    STATE(6633), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(10859), 3,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
  [237256] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10954), 2,
      anon_sym_RBRACE,
      sym_identifier,
    ACTIONS(10956), 4,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [237270] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10744), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(10742), 5,
      aux_sym_preproc_if_token2,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elifdef_token1,
      aux_sym_preproc_elifdef_token2,
      sym_identifier,
  [237284] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9144), 1,
      anon_sym_try,
    ACTIONS(10118), 1,
      anon_sym_LBRACE,
    ACTIONS(10958), 1,
      anon_sym_SEMI,
    ACTIONS(10960), 1,
      anon_sym_EQ,
    STATE(1918), 2,
      sym_compound_statement,
      sym_try_statement,
  [237304] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10962), 2,
      anon_sym_RBRACE,
      sym_identifier,
    ACTIONS(10964), 4,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [237318] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10954), 2,
      anon_sym_RBRACE,
      sym_identifier,
    ACTIONS(10956), 4,
      aux_sym_preproc_if_token1,
      aux_sym_preproc_ifdef_token1,
      aux_sym_preproc_ifdef_token2,
      sym_preproc_directive,
  [237332] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(8466), 1,
      sym_string_literal,
    ACTIONS(115), 5,
      anon_sym_L_DQUOTE,
      anon_sym_u_DQUOTE,
      anon_sym_U_DQUOTE,
      anon_sym_u8_DQUOTE,
      anon_sym_DQUOTE,
  [237346] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(793), 1,
      anon_sym_LBRACE,
    ACTIONS(9789), 1,
      anon_sym_try,
    ACTIONS(10966), 1,
      anon_sym_SEMI,
    ACTIONS(10968), 1,
      anon_sym_EQ,
    STATE(632), 2,
      sym_compound_statement,
      sym_try_statement,
  [237366] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10970), 1,
      anon_sym_LPAREN2,
    STATE(6661), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(10859), 3,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
  [237382] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10972), 1,
      anon_sym_LPAREN2,
    STATE(6633), 2,
      sym_gnu_asm_qualifier,
      aux_sym_gnu_asm_expression_repeat1,
    ACTIONS(10859), 3,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
  [237398] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(793), 1,
      anon_sym_LBRACE,
    ACTIONS(9789), 1,
      anon_sym_try,
    ACTIONS(10974), 1,
      anon_sym_SEMI,
    ACTIONS(10976), 1,
      anon_sym_EQ,
    STATE(633), 2,
      sym_compound_statement,
      sym_try_statement,
  [237418] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(10978), 1,
      anon_sym_SEMI,
    STATE(6906), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8556), 1,
      sym_attribute_specifier,
  [237437] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(10980), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
    STATE(2742), 1,
      sym_template_method,
    STATE(7692), 1,
      sym_operator_name,
  [237456] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(10982), 1,
      anon_sym_SEMI,
    STATE(6691), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8319), 1,
      sym_attribute_specifier,
  [237475] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(10984), 1,
      anon_sym_SEMI,
    STATE(6690), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8285), 1,
      sym_attribute_specifier,
  [237494] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10599), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10601), 1,
      anon_sym_inline,
    ACTIONS(10986), 1,
      sym_identifier,
    STATE(7098), 1,
      sym__namespace_specifier,
    STATE(7819), 1,
      sym_nested_namespace_specifier,
  [237513] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10599), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10601), 1,
      anon_sym_inline,
    ACTIONS(10988), 1,
      sym_identifier,
    STATE(7863), 1,
      sym_nested_namespace_specifier,
    STATE(8298), 1,
      sym__namespace_specifier,
  [237532] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(10990), 1,
      anon_sym_SEMI,
    STATE(6906), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8318), 1,
      sym_attribute_specifier,
  [237551] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9952), 1,
      anon_sym_COLON,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3679), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
  [237570] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(10980), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
    STATE(2742), 1,
      sym_template_method,
    STATE(7549), 1,
      sym_operator_name,
  [237589] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10599), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10601), 1,
      anon_sym_inline,
    ACTIONS(10992), 1,
      sym_identifier,
    STATE(7928), 1,
      sym_nested_namespace_specifier,
    STATE(8298), 1,
      sym__namespace_specifier,
  [237608] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    ACTIONS(10994), 1,
      anon_sym_RPAREN,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
  [237627] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    ACTIONS(10996), 1,
      anon_sym_RPAREN,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
  [237646] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8390), 1,
      sym_auto,
    ACTIONS(8392), 1,
      anon_sym_decltype,
    STATE(2274), 1,
      sym_decltype_auto,
    ACTIONS(10998), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
  [237663] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    ACTIONS(11000), 1,
      anon_sym_RPAREN,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
  [237682] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9962), 1,
      anon_sym_COLON,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3679), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
  [237701] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9954), 1,
      anon_sym_COLON,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3679), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
  [237720] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(11002), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
    STATE(3735), 1,
      sym_template_method,
    STATE(7757), 1,
      sym_operator_name,
  [237739] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(11004), 1,
      anon_sym_SEMI,
    STATE(6693), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8313), 1,
      sym_attribute_specifier,
  [237758] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(11006), 1,
      anon_sym_SEMI,
    STATE(6906), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8312), 1,
      sym_attribute_specifier,
  [237777] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(11008), 1,
      anon_sym_SEMI,
    STATE(6906), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8311), 1,
      sym_attribute_specifier,
  [237796] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(11010), 1,
      anon_sym_SEMI,
    STATE(6906), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8309), 1,
      sym_attribute_specifier,
  [237815] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(11012), 1,
      anon_sym_SEMI,
    STATE(6906), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8308), 1,
      sym_attribute_specifier,
  [237834] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(9908), 1,
      anon_sym_COLON,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3679), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
  [237853] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10599), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10601), 1,
      anon_sym_inline,
    ACTIONS(10986), 1,
      sym_identifier,
    STATE(7024), 1,
      sym__namespace_specifier,
    STATE(7610), 1,
      sym_nested_namespace_specifier,
  [237872] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    STATE(2679), 1,
      sym_template_argument_list,
    ACTIONS(6191), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACE,
  [237889] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11014), 2,
      anon_sym_class,
      anon_sym_typename,
    STATE(7618), 3,
      sym_type_parameter_declaration,
      sym_variadic_type_parameter_declaration,
      sym_optional_type_parameter_declaration,
  [237902] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    ACTIONS(11016), 1,
      anon_sym_RPAREN,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
  [237921] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11020), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11018), 4,
      sym_identifier,
      anon_sym_decltype,
      sym_virtual,
      anon_sym_template,
  [237934] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(11022), 1,
      anon_sym_SEMI,
    STATE(6906), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8449), 1,
      sym_attribute_specifier,
  [237953] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(11024), 1,
      anon_sym_SEMI,
    STATE(6906), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8442), 1,
      sym_attribute_specifier,
  [237972] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10599), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10601), 1,
      anon_sym_inline,
    ACTIONS(11026), 1,
      sym_identifier,
    STATE(8113), 1,
      sym_nested_namespace_specifier,
    STATE(8298), 1,
      sym__namespace_specifier,
  [237991] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(11028), 1,
      anon_sym_SEMI,
    STATE(6672), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8432), 1,
      sym_attribute_specifier,
  [238010] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10599), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10601), 1,
      anon_sym_inline,
    ACTIONS(11030), 1,
      sym_identifier,
    STATE(8298), 1,
      sym__namespace_specifier,
    STATE(8355), 1,
      sym_nested_namespace_specifier,
  [238029] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(11032), 1,
      anon_sym_SEMI,
    STATE(6906), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8296), 1,
      sym_attribute_specifier,
  [238048] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(11034), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
    STATE(3516), 1,
      sym_template_method,
    STATE(7633), 1,
      sym_operator_name,
  [238067] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(11036), 1,
      anon_sym_SEMI,
    STATE(6906), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8062), 1,
      sym_attribute_specifier,
  [238086] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(11038), 1,
      anon_sym_SEMI,
    STATE(6906), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8063), 1,
      sym_attribute_specifier,
  [238105] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(11040), 1,
      anon_sym_SEMI,
    STATE(6906), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8066), 1,
      sym_attribute_specifier,
  [238124] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(11042), 1,
      anon_sym_SEMI,
    STATE(6700), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8295), 1,
      sym_attribute_specifier,
  [238143] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(11044), 1,
      anon_sym_SEMI,
    STATE(6906), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8067), 1,
      sym_attribute_specifier,
  [238162] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(11046), 1,
      anon_sym_SEMI,
    STATE(6701), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8292), 1,
      sym_attribute_specifier,
  [238181] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(11048), 1,
      anon_sym_SEMI,
    STATE(6707), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8068), 1,
      sym_attribute_specifier,
  [238200] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9986), 1,
      sym_identifier,
    ACTIONS(11050), 1,
      aux_sym_preproc_if_token2,
    STATE(6559), 1,
      sym_enumerator,
    STATE(6850), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(6851), 1,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
  [238219] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8390), 1,
      sym_auto,
    ACTIONS(8392), 1,
      anon_sym_decltype,
    STATE(2274), 1,
      sym_decltype_auto,
    ACTIONS(11052), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
  [238236] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(11054), 1,
      anon_sym_SEMI,
    STATE(6906), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8076), 1,
      sym_attribute_specifier,
  [238255] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(11056), 1,
      anon_sym_SEMI,
    STATE(6709), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8078), 1,
      sym_attribute_specifier,
  [238274] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8728), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(8732), 1,
      anon_sym_EQ,
    ACTIONS(11058), 1,
      sym_identifier,
    ACTIONS(8730), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
  [238291] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(11060), 1,
      anon_sym_SEMI,
    STATE(6906), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8555), 1,
      sym_attribute_specifier,
  [238310] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5298), 1,
      anon_sym_LT,
    ACTIONS(6306), 1,
      anon_sym_LBRACK,
    STATE(2433), 1,
      sym_template_argument_list,
    ACTIONS(6308), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [238327] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(7899), 1,
      anon_sym_COMMA,
    ACTIONS(11062), 1,
      anon_sym_SEMI,
    STATE(6711), 1,
      aux_sym_field_declaration_repeat1,
    STATE(8080), 1,
      sym_attribute_specifier,
  [238346] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5298), 1,
      anon_sym_LT,
    ACTIONS(6306), 1,
      anon_sym_LBRACK,
    STATE(2851), 1,
      sym_template_argument_list,
    ACTIONS(6308), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK_LBRACK,
  [238363] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    ACTIONS(11066), 1,
      anon_sym_COLON_COLON,
    STATE(7758), 1,
      sym_argument_list,
    ACTIONS(11064), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK_RBRACK,
  [238380] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2078), 1,
      anon_sym_operator,
    ACTIONS(11068), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
    STATE(2742), 1,
      sym_template_method,
    STATE(7466), 1,
      sym_operator_name,
  [238399] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11070), 1,
      anon_sym_COMMA,
    STATE(6725), 1,
      aux_sym__type_definition_declarators_repeat1,
    ACTIONS(11073), 2,
      anon_sym_SEMI,
      anon_sym___attribute__,
  [238413] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11075), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [238423] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9843), 1,
      anon_sym_LBRACE,
    STATE(2769), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [238437] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(466), 1,
      sym_field_declaration_list,
    STATE(7558), 1,
      sym_base_class_clause,
  [238453] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11077), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11079), 1,
      anon_sym_GT2,
    STATE(7382), 1,
      aux_sym_template_argument_list_repeat1,
  [238469] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9841), 1,
      anon_sym_LBRACE,
    STATE(3693), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [238483] = 4,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11081), 1,
      anon_sym_SQUOTE,
    STATE(6731), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(11083), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [238497] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3741), 1,
      anon_sym_LBRACE,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    STATE(3570), 1,
      sym_argument_list,
    STATE(3855), 1,
      sym_initializer_list,
  [238513] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11077), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11086), 1,
      anon_sym_GT2,
    STATE(7373), 1,
      aux_sym_template_argument_list_repeat1,
  [238529] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11088), 1,
      anon_sym_SEMI,
    STATE(6768), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [238543] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11090), 1,
      anon_sym_SEMI,
    STATE(4479), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [238557] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9843), 1,
      anon_sym_LBRACE,
    STATE(2781), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [238571] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11092), 1,
      anon_sym_DQUOTE,
    ACTIONS(11094), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11096), 1,
      sym_escape_sequence,
    STATE(6738), 1,
      aux_sym_string_literal_repeat1,
  [238587] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11098), 1,
      anon_sym_DQUOTE,
    ACTIONS(11100), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11103), 1,
      sym_escape_sequence,
    STATE(6738), 1,
      aux_sym_string_literal_repeat1,
  [238603] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3709), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(1020), 1,
      sym_field_declaration_list,
    STATE(7686), 1,
      sym_base_class_clause,
  [238619] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11106), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(11108), 1,
      anon_sym_LPAREN,
    ACTIONS(11110), 1,
      sym_preproc_arg,
    STATE(7727), 1,
      sym_preproc_params,
  [238635] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3709), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(998), 1,
      sym_field_declaration_list,
    STATE(7685), 1,
      sym_base_class_clause,
  [238651] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10777), 1,
      anon_sym_EQ,
    STATE(6764), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [238665] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(11112), 1,
      anon_sym_EQ,
    STATE(6205), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [238679] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11114), 1,
      anon_sym_DQUOTE,
    ACTIONS(11116), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11118), 1,
      sym_escape_sequence,
    STATE(6737), 1,
      aux_sym_string_literal_repeat1,
  [238695] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11120), 1,
      anon_sym_DQUOTE,
    ACTIONS(11122), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11124), 1,
      sym_escape_sequence,
    STATE(7011), 1,
      aux_sym_string_literal_repeat1,
  [238711] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10791), 1,
      anon_sym_EQ,
    STATE(6759), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [238725] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4192), 1,
      anon_sym_LT,
    ACTIONS(11126), 1,
      sym_identifier,
    STATE(901), 1,
      sym_template_parameter_list,
    STATE(2195), 1,
      sym_template_type,
  [238741] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(11128), 1,
      anon_sym_EQ,
    STATE(6205), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [238755] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11077), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11130), 1,
      anon_sym_GT2,
    STATE(7154), 1,
      aux_sym_template_argument_list_repeat1,
  [238771] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11077), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11132), 1,
      anon_sym_GT2,
    STATE(7361), 1,
      aux_sym_template_argument_list_repeat1,
  [238787] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11094), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11096), 1,
      sym_escape_sequence,
    ACTIONS(11134), 1,
      anon_sym_DQUOTE,
    STATE(6738), 1,
      aux_sym_string_literal_repeat1,
  [238803] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11136), 1,
      anon_sym_SEMI,
    STATE(6795), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [238817] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11138), 1,
      anon_sym_SEMI,
    STATE(4479), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [238831] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11140), 1,
      anon_sym_DQUOTE,
    ACTIONS(11142), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11144), 1,
      sym_escape_sequence,
    STATE(6751), 1,
      aux_sym_string_literal_repeat1,
  [238847] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11146), 1,
      anon_sym_SEMI,
    STATE(6753), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [238861] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    STATE(2731), 1,
      sym_field_declaration_list,
    STATE(7569), 1,
      sym_base_class_clause,
  [238877] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(11148), 1,
      anon_sym_EQ,
    STATE(6748), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [238891] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11077), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11150), 1,
      anon_sym_GT2,
    STATE(7345), 1,
      aux_sym_template_argument_list_repeat1,
  [238907] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(11152), 1,
      anon_sym_EQ,
    STATE(6205), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [238921] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9115), 1,
      anon_sym_LBRACE,
    ACTIONS(11154), 1,
      anon_sym_LPAREN2,
    STATE(3527), 1,
      sym_requirement_seq,
    STATE(7524), 1,
      sym_requires_parameter_list,
  [238937] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1980), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(513), 1,
      sym_field_declaration_list,
    STATE(7676), 1,
      sym_base_class_clause,
  [238953] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10773), 1,
      anon_sym_EQ,
    STATE(6856), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [238967] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9841), 1,
      anon_sym_LBRACE,
    STATE(3787), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [238981] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(11156), 1,
      anon_sym_EQ,
    STATE(6205), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [238995] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11094), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11096), 1,
      sym_escape_sequence,
    ACTIONS(11158), 1,
      anon_sym_DQUOTE,
    STATE(6738), 1,
      aux_sym_string_literal_repeat1,
  [239011] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1980), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(516), 1,
      sym_field_declaration_list,
    STATE(7677), 1,
      sym_base_class_clause,
  [239027] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11160), 1,
      anon_sym_DQUOTE,
    ACTIONS(11162), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11164), 1,
      sym_escape_sequence,
    STATE(6765), 1,
      aux_sym_string_literal_repeat1,
  [239043] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11166), 1,
      anon_sym_SEMI,
    STATE(4479), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [239057] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11077), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11168), 1,
      anon_sym_GT2,
    STATE(7327), 1,
      aux_sym_template_argument_list_repeat1,
  [239073] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    STATE(7223), 1,
      sym_compound_statement,
    STATE(7537), 1,
      sym_field_initializer_list,
  [239089] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3709), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(1039), 1,
      sym_field_declaration_list,
    STATE(7682), 1,
      sym_base_class_clause,
  [239105] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11094), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11096), 1,
      sym_escape_sequence,
    ACTIONS(11170), 1,
      anon_sym_DQUOTE,
    STATE(6738), 1,
      aux_sym_string_literal_repeat1,
  [239121] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9089), 1,
      anon_sym_LBRACE,
    ACTIONS(11154), 1,
      anon_sym_LPAREN2,
    STATE(2780), 1,
      sym_requirement_seq,
    STATE(7613), 1,
      sym_requires_parameter_list,
  [239137] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11172), 1,
      anon_sym_DQUOTE,
    ACTIONS(11174), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11176), 1,
      sym_escape_sequence,
    STATE(6772), 1,
      aux_sym_string_literal_repeat1,
  [239153] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    STATE(7142), 2,
      sym_argument_list,
      sym_initializer_list,
  [239167] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11077), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11178), 1,
      anon_sym_GT2,
    STATE(7308), 1,
      aux_sym_template_argument_list_repeat1,
  [239183] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4386), 1,
      anon_sym_LBRACE,
    ACTIONS(11180), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11182), 1,
      anon_sym_EQ,
    STATE(694), 1,
      sym_declaration_list,
  [239199] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11184), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11186), 1,
      anon_sym_COMMA,
    ACTIONS(11188), 1,
      anon_sym_LBRACE,
    STATE(7182), 1,
      aux_sym_base_class_clause_repeat1,
  [239215] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11094), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11096), 1,
      sym_escape_sequence,
    ACTIONS(11190), 1,
      anon_sym_DQUOTE,
    STATE(6738), 1,
      aux_sym_string_literal_repeat1,
  [239231] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11077), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11192), 1,
      anon_sym_GT2,
    STATE(7090), 1,
      aux_sym_template_argument_list_repeat1,
  [239247] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4384), 1,
      anon_sym_LBRACE,
    ACTIONS(11180), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11194), 1,
      anon_sym_EQ,
    STATE(306), 1,
      sym_declaration_list,
  [239263] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11196), 1,
      anon_sym_SEMI,
    ACTIONS(11198), 1,
      anon_sym_DASH_GT,
    ACTIONS(11200), 1,
      anon_sym_noexcept,
    STATE(8334), 1,
      sym_trailing_return_type,
  [239279] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1988), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(386), 1,
      sym_field_declaration_list,
    STATE(7755), 1,
      sym_base_class_clause,
  [239295] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11202), 1,
      anon_sym_DQUOTE,
    ACTIONS(11204), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11206), 1,
      sym_escape_sequence,
    STATE(6779), 1,
      aux_sym_string_literal_repeat1,
  [239311] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(11208), 1,
      anon_sym_EQ,
    STATE(6907), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [239325] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11094), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11096), 1,
      sym_escape_sequence,
    ACTIONS(11210), 1,
      anon_sym_DQUOTE,
    STATE(6738), 1,
      aux_sym_string_literal_repeat1,
  [239341] = 4,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11212), 1,
      anon_sym_SQUOTE,
    STATE(6731), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(11214), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [239355] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11077), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11216), 1,
      anon_sym_GT2,
    STATE(7287), 1,
      aux_sym_template_argument_list_repeat1,
  [239371] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11218), 1,
      anon_sym_SEMI,
    STATE(4479), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [239385] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4192), 1,
      anon_sym_LT,
    ACTIONS(11126), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
    STATE(6697), 1,
      sym_template_parameter_list,
  [239401] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(6321), 1,
      anon_sym_LBRACE,
    STATE(3073), 1,
      sym_field_declaration_list,
    STATE(7630), 1,
      sym_base_class_clause,
  [239417] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11094), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11096), 1,
      sym_escape_sequence,
    ACTIONS(11220), 1,
      anon_sym_DQUOTE,
    STATE(6738), 1,
      aux_sym_string_literal_repeat1,
  [239433] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9843), 1,
      anon_sym_LBRACE,
    STATE(2853), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [239447] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9845), 1,
      anon_sym_LBRACE,
    STATE(3968), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [239461] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11222), 1,
      anon_sym_SEMI,
    STATE(4479), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [239475] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1980), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(533), 1,
      sym_field_declaration_list,
    STATE(7679), 1,
      sym_base_class_clause,
  [239491] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(5078), 1,
      sym_field_declaration_list,
    STATE(7516), 1,
      sym_base_class_clause,
  [239507] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11224), 1,
      anon_sym_DQUOTE,
    ACTIONS(11226), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11228), 1,
      sym_escape_sequence,
    STATE(6792), 1,
      aux_sym_string_literal_repeat1,
  [239523] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    STATE(7157), 1,
      sym_compound_statement,
    STATE(7661), 1,
      sym_field_initializer_list,
  [239539] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    ACTIONS(11230), 1,
      anon_sym_SEMI,
    STATE(2390), 1,
      sym_template_argument_list,
  [239555] = 4,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11232), 1,
      anon_sym_SQUOTE,
    STATE(6731), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(11214), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [239569] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11077), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11234), 1,
      anon_sym_GT2,
    STATE(7265), 1,
      aux_sym_template_argument_list_repeat1,
  [239585] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    ACTIONS(11236), 1,
      anon_sym_SEMI,
    STATE(2390), 1,
      sym_template_argument_list,
  [239601] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10723), 1,
      anon_sym_EQ,
    STATE(6743), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [239615] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    STATE(2805), 1,
      sym_argument_list,
    STATE(4005), 1,
      sym_initializer_list,
  [239631] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11094), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11096), 1,
      sym_escape_sequence,
    ACTIONS(11238), 1,
      anon_sym_DQUOTE,
    STATE(6738), 1,
      aux_sym_string_literal_repeat1,
  [239647] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(5099), 1,
      sym_field_declaration_list,
    STATE(7515), 1,
      sym_base_class_clause,
  [239663] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11240), 1,
      anon_sym_COMMA,
    STATE(6996), 1,
      aux_sym_gnu_asm_clobber_list_repeat1,
    ACTIONS(11242), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [239677] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9105), 1,
      anon_sym_LBRACE,
    ACTIONS(11154), 1,
      anon_sym_LPAREN2,
    STATE(3606), 1,
      sym_requirement_seq,
    STATE(7602), 1,
      sym_requires_parameter_list,
  [239693] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11244), 1,
      anon_sym_DQUOTE,
    ACTIONS(11246), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11248), 1,
      sym_escape_sequence,
    STATE(6838), 1,
      aux_sym_string_literal_repeat1,
  [239709] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    STATE(2719), 1,
      sym_field_declaration_list,
    STATE(7545), 1,
      sym_base_class_clause,
  [239725] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3627), 1,
      anon_sym_LBRACE,
    ACTIONS(6618), 1,
      anon_sym_LPAREN2,
    STATE(3569), 1,
      sym_initializer_list,
    STATE(3570), 1,
      sym_argument_list,
  [239741] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11250), 1,
      anon_sym_DQUOTE,
    ACTIONS(11252), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11254), 1,
      sym_escape_sequence,
    STATE(6806), 1,
      aux_sym_string_literal_repeat1,
  [239757] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11256), 1,
      anon_sym_COMMA,
    STATE(6864), 1,
      aux_sym_gnu_asm_input_operand_list_repeat1,
    ACTIONS(11258), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [239771] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11077), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11260), 1,
      anon_sym_GT2,
    STATE(7390), 1,
      aux_sym_template_argument_list_repeat1,
  [239787] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11108), 1,
      anon_sym_LPAREN,
    ACTIONS(11262), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(11264), 1,
      sym_preproc_arg,
    STATE(7660), 1,
      sym_preproc_params,
  [239803] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11108), 1,
      anon_sym_LPAREN,
    ACTIONS(11266), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(11268), 1,
      sym_preproc_arg,
    STATE(7620), 1,
      sym_preproc_params,
  [239819] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11077), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11270), 1,
      anon_sym_GT2,
    STATE(7240), 1,
      aux_sym_template_argument_list_repeat1,
  [239835] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1988), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(399), 1,
      sym_field_declaration_list,
    STATE(7759), 1,
      sym_base_class_clause,
  [239851] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1988), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(418), 1,
      sym_field_declaration_list,
    STATE(7760), 1,
      sym_base_class_clause,
  [239867] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(6594), 1,
      anon_sym_LBRACE,
    STATE(3242), 1,
      sym_field_declaration_list,
    STATE(7715), 1,
      sym_base_class_clause,
  [239883] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11094), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11096), 1,
      sym_escape_sequence,
    ACTIONS(11272), 1,
      anon_sym_DQUOTE,
    STATE(6738), 1,
      aux_sym_string_literal_repeat1,
  [239899] = 4,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11274), 1,
      anon_sym_SQUOTE,
    STATE(6731), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(11214), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [239913] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11077), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11276), 1,
      anon_sym_GT2,
    STATE(7398), 1,
      aux_sym_template_argument_list_repeat1,
  [239929] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11075), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_try,
  [239939] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11278), 1,
      anon_sym_SEMI,
    STATE(4479), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [239953] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11280), 1,
      anon_sym_SEMI,
    STATE(6789), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [239967] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9845), 1,
      anon_sym_LBRACE,
    STATE(3841), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [239981] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11282), 1,
      anon_sym_DQUOTE,
    ACTIONS(11284), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11286), 1,
      sym_escape_sequence,
    STATE(6786), 1,
      aux_sym_string_literal_repeat1,
  [239997] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1982), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(408), 1,
      sym_field_declaration_list,
    STATE(7695), 1,
      sym_base_class_clause,
  [240013] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11288), 1,
      anon_sym_DQUOTE,
    ACTIONS(11290), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11292), 1,
      sym_escape_sequence,
    STATE(6822), 1,
      aux_sym_string_literal_repeat1,
  [240029] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(2317), 1,
      sym_field_declaration_list,
    STATE(7749), 1,
      sym_base_class_clause,
  [240045] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10781), 1,
      anon_sym_EQ,
    STATE(6885), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [240059] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1982), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(409), 1,
      sym_field_declaration_list,
    STATE(7697), 1,
      sym_base_class_clause,
  [240075] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    STATE(4870), 1,
      sym_field_declaration_list,
    STATE(7653), 1,
      sym_base_class_clause,
  [240091] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4192), 1,
      anon_sym_LT,
    ACTIONS(11126), 1,
      sym_identifier,
    STATE(900), 1,
      sym_template_parameter_list,
    STATE(2195), 1,
      sym_template_type,
  [240107] = 4,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11294), 1,
      anon_sym_SQUOTE,
    STATE(6731), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(11214), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [240121] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11094), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11096), 1,
      sym_escape_sequence,
    ACTIONS(11296), 1,
      anon_sym_DQUOTE,
    STATE(6738), 1,
      aux_sym_string_literal_repeat1,
  [240137] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1982), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(403), 1,
      sym_field_declaration_list,
    STATE(7587), 1,
      sym_base_class_clause,
  [240153] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11077), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11298), 1,
      anon_sym_GT2,
    STATE(7214), 1,
      aux_sym_template_argument_list_repeat1,
  [240169] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11300), 1,
      anon_sym___except,
    ACTIONS(11302), 1,
      anon_sym___finally,
    STATE(467), 2,
      sym_seh_except_clause,
      sym_seh_finally_clause,
  [240183] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    STATE(7387), 1,
      sym_compound_statement,
    STATE(7691), 1,
      sym_field_initializer_list,
  [240199] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11304), 1,
      anon_sym_SEMI,
    STATE(4479), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [240213] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    ACTIONS(11306), 1,
      anon_sym_SEMI,
    STATE(2390), 1,
      sym_template_argument_list,
  [240229] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    STATE(7401), 1,
      sym_compound_statement,
    STATE(7833), 1,
      sym_field_initializer_list,
  [240245] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11094), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11096), 1,
      sym_escape_sequence,
    ACTIONS(11308), 1,
      anon_sym_DQUOTE,
    STATE(6738), 1,
      aux_sym_string_literal_repeat1,
  [240261] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11154), 1,
      anon_sym_LPAREN2,
    ACTIONS(11310), 1,
      anon_sym_LBRACE,
    STATE(5742), 1,
      sym_requirement_seq,
    STATE(7617), 1,
      sym_requires_parameter_list,
  [240277] = 4,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11312), 1,
      anon_sym_SQUOTE,
    STATE(6731), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(11214), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [240291] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11314), 1,
      anon_sym___except,
    ACTIONS(11316), 1,
      anon_sym___finally,
    STATE(467), 2,
      sym_seh_except_clause,
      sym_seh_finally_clause,
  [240305] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(11318), 1,
      aux_sym_preproc_if_token2,
    STATE(6532), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(8250), 1,
      sym_enumerator,
  [240321] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9986), 1,
      sym_identifier,
    ACTIONS(11320), 1,
      aux_sym_preproc_if_token2,
    STATE(6545), 2,
      sym_enumerator,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
  [240335] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4192), 1,
      anon_sym_LT,
    ACTIONS(11126), 1,
      sym_identifier,
    STATE(902), 1,
      sym_template_parameter_list,
    STATE(2195), 1,
      sym_template_type,
  [240351] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9799), 1,
      anon_sym_LBRACE,
    STATE(1935), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [240365] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11077), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11322), 1,
      anon_sym_GT2,
    STATE(7184), 1,
      aux_sym_template_argument_list_repeat1,
  [240381] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10226), 1,
      sym_identifier,
    ACTIONS(11050), 1,
      aux_sym_preproc_if_token2,
    STATE(6850), 1,
      aux_sym_preproc_if_in_enumerator_list_repeat1,
    STATE(8250), 1,
      sym_enumerator,
  [240397] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(11324), 1,
      anon_sym_EQ,
    STATE(6205), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [240411] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11326), 1,
      anon_sym_DQUOTE,
    ACTIONS(11328), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11330), 1,
      sym_escape_sequence,
    STATE(6846), 1,
      aux_sym_string_literal_repeat1,
  [240427] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11332), 1,
      anon_sym_SEMI,
    STATE(4479), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [240441] = 4,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11334), 1,
      anon_sym_SQUOTE,
    STATE(6731), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(11214), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [240455] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11336), 1,
      anon_sym_DQUOTE,
    ACTIONS(11338), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11340), 1,
      sym_escape_sequence,
    STATE(6895), 1,
      aux_sym_string_literal_repeat1,
  [240471] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11342), 1,
      anon_sym_SEMI,
    STATE(6913), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [240485] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    STATE(2907), 1,
      sym_field_declaration_list,
    STATE(7785), 1,
      sym_base_class_clause,
  [240501] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9986), 1,
      sym_identifier,
    ACTIONS(11344), 1,
      aux_sym_preproc_if_token2,
    STATE(6851), 2,
      sym_enumerator,
      aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1,
  [240515] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11346), 1,
      anon_sym_COMMA,
    STATE(6864), 1,
      aux_sym_gnu_asm_input_operand_list_repeat1,
    ACTIONS(11349), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [240529] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(1968), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [240543] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    STATE(7708), 1,
      sym_argument_list,
    ACTIONS(11351), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK_RBRACK,
  [240557] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11108), 1,
      anon_sym_LPAREN,
    ACTIONS(11353), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(11355), 1,
      sym_preproc_arg,
    STATE(7739), 1,
      sym_preproc_params,
  [240573] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3523), 1,
      anon_sym_LBRACE,
    ACTIONS(5854), 1,
      anon_sym_LPAREN2,
    STATE(2805), 1,
      sym_argument_list,
    STATE(2840), 1,
      sym_initializer_list,
  [240589] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(1964), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [240603] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11357), 1,
      anon_sym___except,
    ACTIONS(11359), 1,
      anon_sym___finally,
    STATE(495), 2,
      sym_seh_except_clause,
      sym_seh_finally_clause,
  [240617] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4192), 1,
      anon_sym_LT,
    ACTIONS(11126), 1,
      sym_identifier,
    STATE(898), 1,
      sym_template_parameter_list,
    STATE(2195), 1,
      sym_template_type,
  [240633] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11108), 1,
      anon_sym_LPAREN,
    ACTIONS(11361), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(11363), 1,
      sym_preproc_arg,
    STATE(7648), 1,
      sym_preproc_params,
  [240649] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4192), 1,
      anon_sym_LT,
    ACTIONS(11126), 1,
      sym_identifier,
    STATE(897), 1,
      sym_template_parameter_list,
    STATE(2195), 1,
      sym_template_type,
  [240665] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11077), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11365), 1,
      anon_sym_GT2,
    STATE(7186), 1,
      aux_sym_template_argument_list_repeat1,
  [240681] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    STATE(4856), 1,
      sym_field_declaration_list,
    STATE(7595), 1,
      sym_base_class_clause,
  [240697] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9813), 1,
      anon_sym_LBRACE,
    STATE(3494), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [240711] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1988), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(430), 1,
      sym_field_declaration_list,
    STATE(7798), 1,
      sym_base_class_clause,
  [240727] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11367), 1,
      anon_sym___except,
    ACTIONS(11369), 1,
      anon_sym___finally,
    STATE(1026), 2,
      sym_seh_except_clause,
      sym_seh_finally_clause,
  [240741] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4019), 1,
      anon_sym_LBRACE,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    STATE(3793), 1,
      sym_argument_list,
    STATE(4823), 1,
      sym_initializer_list,
  [240757] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(7134), 1,
      anon_sym_LBRACE,
    STATE(4075), 1,
      sym_field_declaration_list,
    STATE(7520), 1,
      sym_base_class_clause,
  [240773] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11077), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11371), 1,
      anon_sym_GT2,
    STATE(7140), 1,
      aux_sym_template_argument_list_repeat1,
  [240789] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11186), 1,
      anon_sym_COMMA,
    ACTIONS(11373), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11375), 1,
      anon_sym_LBRACE,
    STATE(7163), 1,
      aux_sym_base_class_clause_repeat1,
  [240805] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(5817), 1,
      anon_sym_LBRACE,
    STATE(2580), 1,
      sym_field_declaration_list,
    STATE(7752), 1,
      sym_base_class_clause,
  [240821] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9826), 1,
      anon_sym_LBRACE,
    STATE(3594), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [240835] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(11377), 1,
      anon_sym_EQ,
    STATE(6205), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [240849] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    ACTIONS(11379), 1,
      anon_sym_SEMI,
    STATE(2390), 1,
      sym_template_argument_list,
  [240865] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(1935), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [240879] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10553), 1,
      anon_sym_COMMA,
    STATE(6725), 1,
      aux_sym__type_definition_declarators_repeat1,
    ACTIONS(11381), 2,
      anon_sym_SEMI,
      anon_sym___attribute__,
  [240893] = 4,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11383), 1,
      anon_sym_SQUOTE,
    STATE(6731), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(11214), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [240907] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(2327), 1,
      sym_field_declaration_list,
    STATE(7802), 1,
      sym_base_class_clause,
  [240923] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11094), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11096), 1,
      sym_escape_sequence,
    ACTIONS(11385), 1,
      anon_sym_DQUOTE,
    STATE(6738), 1,
      aux_sym_string_literal_repeat1,
  [240939] = 4,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11387), 1,
      anon_sym_SQUOTE,
    STATE(6731), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(11214), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [240953] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11389), 1,
      anon_sym_SEMI,
    STATE(6826), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [240967] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11391), 1,
      anon_sym_SEMI,
    STATE(4479), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [240981] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11094), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11096), 1,
      sym_escape_sequence,
    ACTIONS(11393), 1,
      anon_sym_DQUOTE,
    STATE(6738), 1,
      aux_sym_string_literal_repeat1,
  [240997] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9813), 1,
      anon_sym_LBRACE,
    STATE(3624), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [241011] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(7134), 1,
      anon_sym_LBRACE,
    STATE(4043), 1,
      sym_field_declaration_list,
    STATE(7526), 1,
      sym_base_class_clause,
  [241027] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    ACTIONS(11395), 1,
      anon_sym_SEMI,
    STATE(2390), 1,
      sym_template_argument_list,
  [241043] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9845), 1,
      anon_sym_LBRACE,
    STATE(3963), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [241057] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11108), 1,
      anon_sym_LPAREN,
    ACTIONS(11397), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(11399), 1,
      sym_preproc_arg,
    STATE(7534), 1,
      sym_preproc_params,
  [241073] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9826), 1,
      anon_sym_LBRACE,
    STATE(3657), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [241087] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4388), 1,
      anon_sym_LBRACE,
    ACTIONS(11180), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11401), 1,
      anon_sym_EQ,
    STATE(653), 1,
      sym_declaration_list,
  [241103] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11186), 1,
      anon_sym_COMMA,
    ACTIONS(11403), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11405), 1,
      anon_sym_LBRACE,
    STATE(7395), 1,
      aux_sym_base_class_clause_repeat1,
  [241119] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4192), 1,
      anon_sym_LT,
    ACTIONS(11126), 1,
      sym_identifier,
    STATE(896), 1,
      sym_template_parameter_list,
    STATE(2195), 1,
      sym_template_type,
  [241135] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9799), 1,
      anon_sym_LBRACE,
    STATE(1964), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [241149] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11407), 1,
      anon_sym_COMMA,
    STATE(6906), 1,
      aux_sym_field_declaration_repeat1,
    ACTIONS(11410), 2,
      anon_sym_SEMI,
      anon_sym___attribute__,
  [241163] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(11412), 1,
      anon_sym_EQ,
    STATE(6205), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [241177] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11154), 1,
      anon_sym_LPAREN2,
    ACTIONS(11414), 1,
      anon_sym_LBRACE,
    STATE(1938), 1,
      sym_requirement_seq,
    STATE(7663), 1,
      sym_requires_parameter_list,
  [241193] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9070), 1,
      anon_sym_LBRACE,
    ACTIONS(11154), 1,
      anon_sym_LPAREN2,
    STATE(4288), 1,
      sym_requirement_seq,
    STATE(7736), 1,
      sym_requires_parameter_list,
  [241209] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11416), 1,
      anon_sym_SEMI,
    STATE(6990), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [241223] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9826), 1,
      anon_sym_LBRACE,
    STATE(3503), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [241237] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11418), 1,
      anon_sym_SEMI,
    STATE(6940), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [241251] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11420), 1,
      anon_sym_SEMI,
    STATE(4479), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [241265] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11077), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11422), 1,
      anon_sym_GT2,
    STATE(7352), 1,
      aux_sym_template_argument_list_repeat1,
  [241281] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11424), 1,
      anon_sym_DQUOTE,
    ACTIONS(11426), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11428), 1,
      sym_escape_sequence,
    STATE(6891), 1,
      aux_sym_string_literal_repeat1,
  [241297] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4380), 1,
      anon_sym_LBRACE,
    ACTIONS(11180), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11430), 1,
      anon_sym_EQ,
    STATE(746), 1,
      sym_declaration_list,
  [241313] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11432), 1,
      sym_identifier,
    ACTIONS(11434), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_GT2,
  [241325] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11094), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11096), 1,
      sym_escape_sequence,
    ACTIONS(11436), 1,
      anon_sym_DQUOTE,
    STATE(6738), 1,
      aux_sym_string_literal_repeat1,
  [241341] = 4,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11438), 1,
      anon_sym_SQUOTE,
    STATE(6731), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(11214), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [241355] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11440), 1,
      anon_sym_SEMI,
    STATE(4479), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [241369] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(11442), 1,
      anon_sym_EQ,
    STATE(6205), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [241383] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11077), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11444), 1,
      anon_sym_GT2,
    STATE(7303), 1,
      aux_sym_template_argument_list_repeat1,
  [241399] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9828), 1,
      anon_sym_LBRACE,
    STATE(4281), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [241413] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11446), 1,
      anon_sym_SEMI,
    STATE(4479), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [241427] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9801), 1,
      anon_sym_LBRACE,
    STATE(5802), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [241441] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    STATE(7225), 1,
      sym_compound_statement,
    STATE(7723), 1,
      sym_field_initializer_list,
  [241457] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3675), 1,
      anon_sym_LBRACE,
    ACTIONS(6678), 1,
      anon_sym_LPAREN2,
    STATE(3747), 1,
      sym_initializer_list,
    STATE(3793), 1,
      sym_argument_list,
  [241473] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    STATE(2886), 1,
      sym_field_declaration_list,
    STATE(7816), 1,
      sym_base_class_clause,
  [241489] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    ACTIONS(10312), 1,
      anon_sym_LBRACK,
    STATE(3525), 1,
      sym_parameter_list,
    STATE(6023), 1,
      sym__function_declarator_seq,
  [241505] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11448), 1,
      anon_sym_SEMI,
    STATE(4479), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [241519] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11450), 1,
      anon_sym_SEMI,
    STATE(6924), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [241533] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(409), 1,
      sym_field_declaration_list,
    STATE(7579), 1,
      sym_base_class_clause,
  [241549] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11452), 1,
      anon_sym_SEMI,
    STATE(6977), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [241563] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(408), 1,
      sym_field_declaration_list,
    STATE(7580), 1,
      sym_base_class_clause,
  [241579] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9799), 1,
      anon_sym_LBRACE,
    STATE(1968), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [241593] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9801), 1,
      anon_sym_LBRACE,
    STATE(5784), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [241607] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11094), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11096), 1,
      sym_escape_sequence,
    ACTIONS(11454), 1,
      anon_sym_DQUOTE,
    STATE(6738), 1,
      aux_sym_string_literal_repeat1,
  [241623] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11456), 1,
      anon_sym___except,
    ACTIONS(11458), 1,
      anon_sym___finally,
    STATE(431), 2,
      sym_seh_except_clause,
      sym_seh_finally_clause,
  [241637] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1913), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(230), 1,
      sym_field_declaration_list,
    STATE(7771), 1,
      sym_base_class_clause,
  [241653] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11460), 1,
      anon_sym_SEMI,
    STATE(4479), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [241667] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11077), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11462), 1,
      anon_sym_GT2,
    STATE(7130), 1,
      aux_sym_template_argument_list_repeat1,
  [241683] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4192), 1,
      anon_sym_LT,
    ACTIONS(11126), 1,
      sym_identifier,
    STATE(899), 1,
      sym_template_parameter_list,
    STATE(2195), 1,
      sym_template_type,
  [241699] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11186), 1,
      anon_sym_COMMA,
    ACTIONS(11464), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11466), 1,
      anon_sym_LBRACE,
    STATE(7297), 1,
      aux_sym_base_class_clause_repeat1,
  [241715] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11468), 1,
      anon_sym_SEMI,
    STATE(6894), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [241729] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(8483), 1,
      anon_sym_LBRACE,
    STATE(4918), 1,
      sym_field_declaration_list,
    STATE(7550), 1,
      sym_base_class_clause,
  [241745] = 4,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11470), 1,
      anon_sym_SQUOTE,
    STATE(6731), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(11214), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [241759] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(5817), 1,
      anon_sym_LBRACE,
    STATE(2568), 1,
      sym_field_declaration_list,
    STATE(7779), 1,
      sym_base_class_clause,
  [241775] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11472), 1,
      anon_sym_COMMA,
    STATE(6966), 1,
      aux_sym_gnu_asm_output_operand_list_repeat1,
    ACTIONS(11474), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [241789] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11476), 1,
      anon_sym_SEMI,
    STATE(6930), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [241803] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11077), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11478), 1,
      anon_sym_GT2,
    STATE(7045), 1,
      aux_sym_template_argument_list_repeat1,
  [241819] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9801), 1,
      anon_sym_LBRACE,
    STATE(5768), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [241833] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11154), 1,
      anon_sym_LPAREN2,
    ACTIONS(11480), 1,
      anon_sym_LBRACE,
    STATE(5787), 1,
      sym_requirement_seq,
    STATE(7567), 1,
      sym_requires_parameter_list,
  [241849] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11094), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11096), 1,
      sym_escape_sequence,
    ACTIONS(11482), 1,
      anon_sym_DQUOTE,
    STATE(6738), 1,
      aux_sym_string_literal_repeat1,
  [241865] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11094), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11096), 1,
      sym_escape_sequence,
    ACTIONS(11484), 1,
      anon_sym_DQUOTE,
    STATE(6738), 1,
      aux_sym_string_literal_repeat1,
  [241881] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11108), 1,
      anon_sym_LPAREN,
    ACTIONS(11486), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(11488), 1,
      sym_preproc_arg,
    STATE(7829), 1,
      sym_preproc_params,
  [241897] = 4,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11490), 1,
      anon_sym_SQUOTE,
    STATE(6731), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(11214), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [241911] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11492), 4,
      anon_sym_LPAREN2,
      anon_sym_inline,
      anon_sym_volatile,
      anon_sym_goto,
  [241921] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(8483), 1,
      anon_sym_LBRACE,
    STATE(4902), 1,
      sym_field_declaration_list,
    STATE(7559), 1,
      sym_base_class_clause,
  [241937] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11494), 1,
      anon_sym_DQUOTE,
    ACTIONS(11496), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11498), 1,
      sym_escape_sequence,
    STATE(6937), 1,
      aux_sym_string_literal_repeat1,
  [241953] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(6321), 1,
      anon_sym_LBRACE,
    STATE(3044), 1,
      sym_field_declaration_list,
    STATE(7652), 1,
      sym_base_class_clause,
  [241969] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    ACTIONS(11500), 1,
      anon_sym_SEMI,
    STATE(2390), 1,
      sym_template_argument_list,
  [241985] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11502), 1,
      anon_sym_DQUOTE,
    ACTIONS(11504), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11506), 1,
      sym_escape_sequence,
    STATE(6918), 1,
      aux_sym_string_literal_repeat1,
  [242001] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(6594), 1,
      anon_sym_LBRACE,
    STATE(3340), 1,
      sym_field_declaration_list,
    STATE(7696), 1,
      sym_base_class_clause,
  [242017] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10711), 1,
      anon_sym_EQ,
    STATE(6979), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [242031] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11256), 1,
      anon_sym_COMMA,
    STATE(6814), 1,
      aux_sym_gnu_asm_input_operand_list_repeat1,
    ACTIONS(11508), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [242045] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11510), 1,
      anon_sym_COMMA,
    STATE(6966), 1,
      aux_sym_gnu_asm_output_operand_list_repeat1,
    ACTIONS(11513), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [242059] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9828), 1,
      anon_sym_LBRACE,
    STATE(4274), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [242073] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11515), 1,
      anon_sym_COMMA,
    STATE(6968), 1,
      aux_sym_gnu_asm_clobber_list_repeat1,
    ACTIONS(11518), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [242087] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11520), 1,
      anon_sym_DQUOTE,
    ACTIONS(11522), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11524), 1,
      sym_escape_sequence,
    STATE(6953), 1,
      aux_sym_string_literal_repeat1,
  [242103] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9081), 1,
      anon_sym_LBRACE,
    ACTIONS(11154), 1,
      anon_sym_LPAREN2,
    STATE(3864), 1,
      sym_requirement_seq,
    STATE(7832), 1,
      sym_requires_parameter_list,
  [242119] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11526), 1,
      anon_sym_SEMI,
    STATE(6858), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [242133] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11528), 1,
      anon_sym_DQUOTE,
    ACTIONS(11530), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11532), 1,
      sym_escape_sequence,
    STATE(6954), 1,
      aux_sym_string_literal_repeat1,
  [242149] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11534), 1,
      anon_sym_DQUOTE,
    ACTIONS(11536), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11538), 1,
      sym_escape_sequence,
    STATE(6995), 1,
      aux_sym_string_literal_repeat1,
  [242165] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(10715), 1,
      anon_sym_EQ,
    STATE(6921), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [242179] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    STATE(7366), 1,
      sym_compound_statement,
    STATE(7459), 1,
      sym_field_initializer_list,
  [242195] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11540), 1,
      anon_sym_SEMI,
    STATE(6987), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [242209] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11542), 1,
      anon_sym_SEMI,
    STATE(4479), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [242223] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9813), 1,
      anon_sym_LBRACE,
    STATE(3542), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [242237] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(45), 1,
      anon_sym_LBRACK_LBRACK,
    ACTIONS(11544), 1,
      anon_sym_EQ,
    STATE(6205), 2,
      sym_attribute_declaration,
      aux_sym_attributed_declarator_repeat1,
  [242251] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1913), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(199), 1,
      sym_field_declaration_list,
    STATE(7800), 1,
      sym_base_class_clause,
  [242267] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1980), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(496), 1,
      sym_field_declaration_list,
    STATE(7641), 1,
      sym_base_class_clause,
  [242283] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1913), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(200), 1,
      sym_field_declaration_list,
    STATE(7805), 1,
      sym_base_class_clause,
  [242299] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9841), 1,
      anon_sym_LBRACE,
    STATE(3752), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [242313] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11546), 1,
      anon_sym___except,
    ACTIONS(11548), 1,
      anon_sym___finally,
    STATE(225), 2,
      sym_seh_except_clause,
      sym_seh_finally_clause,
  [242327] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1982), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(466), 1,
      sym_field_declaration_list,
    STATE(7668), 1,
      sym_base_class_clause,
  [242343] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    STATE(5232), 1,
      sym_field_declaration_list,
    STATE(7574), 1,
      sym_base_class_clause,
  [242359] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11550), 1,
      anon_sym_SEMI,
    STATE(4479), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [242373] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11552), 1,
      anon_sym_SEMI,
    STATE(6920), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [242387] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    STATE(5275), 1,
      sym_field_declaration_list,
    STATE(7576), 1,
      sym_base_class_clause,
  [242403] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11554), 1,
      anon_sym_SEMI,
    STATE(4479), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [242417] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(6425), 1,
      anon_sym_LBRACE,
    STATE(3118), 1,
      sym_field_declaration_list,
    STATE(7597), 1,
      sym_base_class_clause,
  [242433] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    ACTIONS(6425), 1,
      anon_sym_LBRACE,
    STATE(3095), 1,
      sym_field_declaration_list,
    STATE(7606), 1,
      sym_base_class_clause,
  [242449] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    ACTIONS(10104), 1,
      anon_sym_COLON,
    STATE(7079), 1,
      sym_compound_statement,
    STATE(7768), 1,
      sym_field_initializer_list,
  [242465] = 4,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11556), 1,
      anon_sym_SQUOTE,
    STATE(6731), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(11214), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [242479] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11094), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11096), 1,
      sym_escape_sequence,
    ACTIONS(11558), 1,
      anon_sym_DQUOTE,
    STATE(6738), 1,
      aux_sym_string_literal_repeat1,
  [242495] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11240), 1,
      anon_sym_COMMA,
    STATE(6968), 1,
      aux_sym_gnu_asm_clobber_list_repeat1,
    ACTIONS(11560), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [242509] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9828), 1,
      anon_sym_LBRACE,
    STATE(4265), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [242523] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4045), 1,
      anon_sym_SEMI,
    ACTIONS(5298), 1,
      anon_sym_LT,
    STATE(2404), 1,
      sym_template_argument_list,
  [242539] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(403), 1,
      sym_field_declaration_list,
    STATE(7584), 1,
      sym_base_class_clause,
  [242555] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11077), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11562), 1,
      anon_sym_GT2,
    STATE(7048), 1,
      aux_sym_template_argument_list_repeat1,
  [242571] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9097), 1,
      anon_sym_LBRACE,
    ACTIONS(11154), 1,
      anon_sym_LPAREN2,
    STATE(3770), 1,
      sym_requirement_seq,
    STATE(7730), 1,
      sym_requires_parameter_list,
  [242587] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9839), 1,
      anon_sym_LBRACE,
    STATE(5649), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [242601] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11564), 1,
      anon_sym_SEMI,
    STATE(6735), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [242615] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9839), 1,
      anon_sym_LBRACE,
    STATE(5645), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [242629] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9839), 1,
      anon_sym_LBRACE,
    STATE(5641), 1,
      sym_compound_statement,
    ACTIONS(10054), 2,
      anon_sym_LPAREN2,
      anon_sym_LBRACK,
  [242643] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3709), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(1058), 1,
      sym_field_declaration_list,
    STATE(7702), 1,
      sym_base_class_clause,
  [242659] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11566), 1,
      anon_sym_SEMI,
    STATE(6843), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [242673] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11568), 1,
      anon_sym_SEMI,
    STATE(4479), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [242687] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7326), 1,
      anon_sym___attribute__,
    ACTIONS(11570), 1,
      anon_sym_SEMI,
    STATE(7008), 2,
      sym_attribute_specifier,
      aux_sym_type_definition_repeat1,
  [242701] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1939), 1,
      anon_sym_COLON_COLON,
    ACTIONS(5298), 1,
      anon_sym_LT,
    ACTIONS(11572), 1,
      anon_sym_SEMI,
    STATE(2390), 1,
      sym_template_argument_list,
  [242717] = 5,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11094), 1,
      aux_sym_string_literal_token1,
    ACTIONS(11096), 1,
      sym_escape_sequence,
    ACTIONS(11574), 1,
      anon_sym_DQUOTE,
    STATE(6738), 1,
      aux_sym_string_literal_repeat1,
  [242733] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1913), 1,
      anon_sym_LBRACE,
    ACTIONS(5813), 1,
      anon_sym_COLON,
    STATE(187), 1,
      sym_field_declaration_list,
    STATE(7809), 1,
      sym_base_class_clause,
  [242749] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11472), 1,
      anon_sym_COMMA,
    STATE(6948), 1,
      aux_sym_gnu_asm_output_operand_list_repeat1,
    ACTIONS(11576), 2,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [242763] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11186), 1,
      anon_sym_COMMA,
    ACTIONS(11578), 1,
      anon_sym_LBRACE,
    STATE(7271), 1,
      aux_sym_base_class_clause_repeat1,
  [242776] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8139), 3,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_SEMI,
  [242785] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11580), 1,
      anon_sym_COMMA,
    ACTIONS(11582), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(7033), 1,
      aux_sym_attribute_declaration_repeat1,
  [242798] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11584), 1,
      anon_sym_RPAREN,
    ACTIONS(11586), 1,
      anon_sym_COLON,
    STATE(7065), 1,
      sym_gnu_asm_clobber_list,
  [242811] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11588), 1,
      anon_sym_RPAREN,
    ACTIONS(11590), 1,
      anon_sym_COLON,
    STATE(7900), 1,
      sym_gnu_asm_goto_list,
  [242824] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(11592), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [242837] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4380), 1,
      anon_sym_LBRACE,
    ACTIONS(11180), 1,
      anon_sym_COLON_COLON,
    STATE(724), 1,
      sym_declaration_list,
  [242850] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11594), 1,
      anon_sym_catch,
    STATE(1969), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [242861] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11180), 3,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
  [242870] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11596), 1,
      anon_sym_RPAREN,
    ACTIONS(11598), 1,
      anon_sym_COLON,
    STATE(7017), 1,
      sym_gnu_asm_input_operand_list,
  [242883] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11602), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11600), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [242894] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    ACTIONS(11606), 1,
      anon_sym_constexpr,
    STATE(833), 1,
      sym_condition_clause,
  [242907] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(11608), 1,
      anon_sym_SEMI,
    STATE(7041), 1,
      aux_sym_declaration_repeat1,
  [242920] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11586), 1,
      anon_sym_COLON,
    ACTIONS(11610), 1,
      anon_sym_RPAREN,
    STATE(7018), 1,
      sym_gnu_asm_clobber_list,
  [242933] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11612), 1,
      anon_sym_COMMA,
    ACTIONS(11614), 1,
      anon_sym_RPAREN,
    STATE(7376), 1,
      aux_sym_throw_specifier_repeat1,
  [242946] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11616), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
    STATE(3539), 1,
      sym_template_function,
  [242959] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(11618), 1,
      anon_sym_RPAREN,
    STATE(7216), 1,
      aux_sym_argument_list_repeat1,
  [242972] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8041), 1,
      anon_sym_COMMA,
    ACTIONS(11620), 1,
      anon_sym_RBRACK,
    STATE(7433), 1,
      aux_sym_lambda_capture_specifier_repeat1,
  [242985] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5944), 1,
      anon_sym_COMMA,
    ACTIONS(11622), 1,
      anon_sym_RBRACK,
    STATE(7254), 1,
      aux_sym_structured_binding_declarator_repeat1,
  [242998] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11580), 1,
      anon_sym_COMMA,
    ACTIONS(11624), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(7201), 1,
      aux_sym_attribute_declaration_repeat1,
  [243011] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(11626), 1,
      anon_sym_RPAREN,
    STATE(7216), 1,
      aux_sym_argument_list_repeat1,
  [243024] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11198), 1,
      anon_sym_DASH_GT,
    ACTIONS(11628), 1,
      anon_sym_SEMI,
    STATE(8491), 1,
      sym_trailing_return_type,
  [243037] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11630), 3,
      anon_sym_SEMI,
      anon_sym_COLON_COLON,
      anon_sym_LBRACE,
  [243046] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11632), 1,
      anon_sym_GT2,
    STATE(7049), 1,
      aux_sym_template_argument_list_repeat1,
  [243059] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11634), 1,
      anon_sym_catch,
    STATE(1948), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [243070] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11636), 1,
      anon_sym_COMMA,
    ACTIONS(11638), 1,
      anon_sym_RPAREN,
    STATE(7291), 1,
      aux_sym_parameter_list_repeat1,
  [243083] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(11640), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [243096] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(11642), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [243109] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11644), 1,
      anon_sym_default,
    ACTIONS(11646), 1,
      anon_sym_delete,
    ACTIONS(11648), 1,
      anon_sym_0,
  [243122] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    ACTIONS(11650), 1,
      anon_sym_constexpr,
    STATE(865), 1,
      sym_condition_clause,
  [243135] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11652), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [243148] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11654), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [243161] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11656), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [243174] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11658), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [243187] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11660), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [243200] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11662), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [243213] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11664), 1,
      anon_sym_RPAREN,
    ACTIONS(11666), 1,
      anon_sym_COLON,
    STATE(7023), 1,
      sym_gnu_asm_output_operand_list,
  [243226] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11598), 1,
      anon_sym_COLON,
    ACTIONS(11668), 1,
      anon_sym_RPAREN,
    STATE(7027), 1,
      sym_gnu_asm_input_operand_list,
  [243239] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11586), 1,
      anon_sym_COLON,
    ACTIONS(11670), 1,
      anon_sym_RPAREN,
    STATE(7103), 1,
      sym_gnu_asm_clobber_list,
  [243252] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11672), 1,
      anon_sym_COMMA,
    ACTIONS(11675), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [243265] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8295), 1,
      anon_sym_RPAREN,
    STATE(7216), 1,
      aux_sym_argument_list_repeat1,
  [243278] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(11677), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [243291] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9304), 1,
      anon_sym_COMMA,
    ACTIONS(11679), 1,
      anon_sym_RPAREN,
    STATE(7224), 1,
      aux_sym_preproc_argument_list_repeat1,
  [243304] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    STATE(6889), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(11681), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [243315] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4362), 1,
      anon_sym_RBRACE,
    ACTIONS(11683), 1,
      anon_sym_COMMA,
    STATE(7247), 1,
      aux_sym_initializer_list_repeat1,
  [243328] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11598), 1,
      anon_sym_COLON,
    ACTIONS(11685), 1,
      anon_sym_RPAREN,
    STATE(7104), 1,
      sym_gnu_asm_input_operand_list,
  [243341] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11580), 1,
      anon_sym_COMMA,
    ACTIONS(11687), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(7201), 1,
      aux_sym_attribute_declaration_repeat1,
  [243354] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4388), 1,
      anon_sym_LBRACE,
    ACTIONS(11180), 1,
      anon_sym_COLON_COLON,
    STATE(577), 1,
      sym_declaration_list,
  [243367] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5697), 1,
      anon_sym_EQ,
    ACTIONS(5695), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
  [243378] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11689), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [243387] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11691), 1,
      anon_sym_COMMA,
    ACTIONS(11694), 1,
      anon_sym_RPAREN,
    STATE(7064), 1,
      aux_sym_gnu_asm_goto_list_repeat1,
  [243400] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11590), 1,
      anon_sym_COLON,
    ACTIONS(11696), 1,
      anon_sym_RPAREN,
    STATE(7899), 1,
      sym_gnu_asm_goto_list,
  [243413] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8207), 1,
      anon_sym_RPAREN,
    STATE(7208), 1,
      aux_sym_argument_list_repeat1,
  [243426] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8123), 1,
      anon_sym_COMMA,
    ACTIONS(11698), 1,
      anon_sym_RPAREN,
    STATE(7091), 1,
      aux_sym_generic_expression_repeat1,
  [243439] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8199), 1,
      anon_sym_RPAREN,
    STATE(7216), 1,
      aux_sym_argument_list_repeat1,
  [243452] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(11700), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [243465] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11636), 1,
      anon_sym_COMMA,
    ACTIONS(11702), 1,
      anon_sym_RPAREN,
    STATE(7291), 1,
      aux_sym_parameter_list_repeat1,
  [243478] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    ACTIONS(11704), 1,
      anon_sym_constexpr,
    STATE(848), 1,
      sym_condition_clause,
  [243491] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11706), 1,
      anon_sym_COMMA,
    ACTIONS(11708), 1,
      anon_sym_RPAREN,
    STATE(7064), 1,
      aux_sym_gnu_asm_goto_list_repeat1,
  [243504] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    STATE(6946), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(11710), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [243515] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11712), 3,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_DOT,
  [243524] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8155), 1,
      anon_sym_COMMA,
    ACTIONS(11714), 1,
      anon_sym_RBRACK,
    STATE(7245), 1,
      aux_sym_subscript_argument_list_repeat1,
  [243537] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    ACTIONS(11716), 1,
      anon_sym_constexpr,
    STATE(821), 1,
      sym_condition_clause,
  [243550] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11590), 1,
      anon_sym_COLON,
    ACTIONS(11718), 1,
      anon_sym_RPAREN,
    STATE(8488), 1,
      sym_gnu_asm_goto_list,
  [243563] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11720), 1,
      anon_sym_catch,
    STATE(348), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [243574] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11634), 1,
      anon_sym_catch,
    STATE(1959), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [243585] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11722), 1,
      anon_sym_COMMA,
    ACTIONS(11724), 1,
      anon_sym_RPAREN,
    STATE(7316), 1,
      aux_sym_requires_parameter_list_repeat1,
  [243598] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11636), 1,
      anon_sym_COMMA,
    ACTIONS(11726), 1,
      anon_sym_RPAREN,
    STATE(7039), 1,
      aux_sym_parameter_list_repeat1,
  [243611] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(11728), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [243624] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(11730), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [243637] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11636), 1,
      anon_sym_COMMA,
    ACTIONS(11732), 1,
      anon_sym_RPAREN,
    STATE(7291), 1,
      aux_sym_parameter_list_repeat1,
  [243650] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8022), 1,
      anon_sym_RBRACE,
    ACTIONS(8283), 1,
      anon_sym_COMMA,
    STATE(7409), 1,
      aux_sym_initializer_list_repeat1,
  [243663] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11734), 1,
      anon_sym_COMMA,
    ACTIONS(11736), 1,
      anon_sym_GT2,
    STATE(7348), 1,
      aux_sym_template_parameter_list_repeat1,
  [243676] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11738), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [243685] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11740), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [243694] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11742), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [243707] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11744), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [243720] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11746), 1,
      anon_sym_COMMA,
    ACTIONS(11749), 1,
      anon_sym_RPAREN,
    STATE(7091), 1,
      aux_sym_generic_expression_repeat1,
  [243733] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11722), 1,
      anon_sym_COMMA,
    ACTIONS(11751), 1,
      anon_sym_RPAREN,
    STATE(7080), 1,
      aux_sym_requires_parameter_list_repeat1,
  [243746] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11590), 1,
      anon_sym_COLON,
    ACTIONS(11753), 1,
      anon_sym_RPAREN,
    STATE(8207), 1,
      sym_gnu_asm_goto_list,
  [243759] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11755), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [243772] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11757), 1,
      anon_sym_GT2,
    STATE(7044), 1,
      aux_sym_template_argument_list_repeat1,
  [243785] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(11759), 1,
      anon_sym_SEMI,
    STATE(7120), 1,
      aux_sym_declaration_repeat1,
  [243798] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11666), 1,
      anon_sym_COLON,
    ACTIONS(11761), 1,
      anon_sym_RPAREN,
    STATE(7059), 1,
      sym_gnu_asm_output_operand_list,
  [243811] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11602), 1,
      anon_sym_COLON_COLON,
    ACTIONS(11763), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [243822] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11765), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
    STATE(3425), 1,
      sym_template_function,
  [243835] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11666), 1,
      anon_sym_COLON,
    ACTIONS(11767), 1,
      anon_sym_RPAREN,
    STATE(7051), 1,
      sym_gnu_asm_output_operand_list,
  [243848] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11586), 1,
      anon_sym_COLON,
    ACTIONS(11769), 1,
      anon_sym_RPAREN,
    STATE(7093), 1,
      sym_gnu_asm_clobber_list,
  [243861] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    STATE(6919), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(11771), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [243872] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11590), 1,
      anon_sym_COLON,
    ACTIONS(11773), 1,
      anon_sym_RPAREN,
    STATE(8310), 1,
      sym_gnu_asm_goto_list,
  [243885] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11586), 1,
      anon_sym_COLON,
    ACTIONS(11775), 1,
      anon_sym_RPAREN,
    STATE(7126), 1,
      sym_gnu_asm_clobber_list,
  [243898] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11590), 1,
      anon_sym_COLON,
    ACTIONS(11777), 1,
      anon_sym_RPAREN,
    STATE(8201), 1,
      sym_gnu_asm_goto_list,
  [243911] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11598), 1,
      anon_sym_COLON,
    ACTIONS(11779), 1,
      anon_sym_RPAREN,
    STATE(7052), 1,
      sym_gnu_asm_input_operand_list,
  [243924] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11781), 1,
      anon_sym_EQ,
    ACTIONS(10758), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [243935] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(11783), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [243948] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8175), 1,
      anon_sym_COMMA,
    ACTIONS(8177), 1,
      anon_sym_RBRACE,
    STATE(7058), 1,
      aux_sym_initializer_list_repeat1,
  [243961] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2006), 1,
      anon_sym_while,
    ACTIONS(11785), 1,
      anon_sym_else,
    STATE(398), 1,
      sym_else_clause,
  [243974] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4388), 1,
      anon_sym_LBRACE,
    ACTIONS(11180), 1,
      anon_sym_COLON_COLON,
    STATE(617), 1,
      sym_declaration_list,
  [243987] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11598), 1,
      anon_sym_COLON,
    ACTIONS(11787), 1,
      anon_sym_RPAREN,
    STATE(7101), 1,
      sym_gnu_asm_input_operand_list,
  [244000] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11586), 1,
      anon_sym_COLON,
    ACTIONS(11789), 1,
      anon_sym_RPAREN,
    STATE(7105), 1,
      sym_gnu_asm_clobber_list,
  [244013] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11791), 1,
      anon_sym_GT2,
    STATE(7131), 1,
      aux_sym_template_argument_list_repeat1,
  [244026] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(11793), 1,
      anon_sym_RPAREN,
    STATE(7216), 1,
      aux_sym_argument_list_repeat1,
  [244039] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4364), 1,
      anon_sym_RBRACE,
    ACTIONS(11795), 1,
      anon_sym_COMMA,
    STATE(7247), 1,
      aux_sym_initializer_list_repeat1,
  [244052] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8169), 1,
      anon_sym_RPAREN,
    STATE(7068), 1,
      aux_sym_argument_list_repeat1,
  [244065] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11580), 1,
      anon_sym_COMMA,
    ACTIONS(11797), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(7167), 1,
      aux_sym_attribute_declaration_repeat1,
  [244078] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(11799), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [244091] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(11801), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [244104] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11580), 1,
      anon_sym_COMMA,
    ACTIONS(11803), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(7201), 1,
      aux_sym_attribute_declaration_repeat1,
  [244117] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11734), 1,
      anon_sym_COMMA,
    ACTIONS(11805), 1,
      anon_sym_GT2,
    STATE(7348), 1,
      aux_sym_template_parameter_list_repeat1,
  [244130] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4386), 1,
      anon_sym_LBRACE,
    ACTIONS(11180), 1,
      anon_sym_COLON_COLON,
    STATE(602), 1,
      sym_declaration_list,
  [244143] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11594), 1,
      anon_sym_catch,
    STATE(1974), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [244154] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8271), 1,
      anon_sym_COMMA,
    ACTIONS(8273), 1,
      anon_sym_RBRACE,
    STATE(7243), 1,
      aux_sym_initializer_list_repeat1,
  [244167] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11590), 1,
      anon_sym_COLON,
    ACTIONS(11807), 1,
      anon_sym_RPAREN,
    STATE(8306), 1,
      sym_gnu_asm_goto_list,
  [244180] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11809), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_GT2,
  [244189] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8123), 1,
      anon_sym_COMMA,
    ACTIONS(11811), 1,
      anon_sym_RPAREN,
    STATE(7091), 1,
      aux_sym_generic_expression_repeat1,
  [244202] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11813), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [244215] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11815), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [244228] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11817), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [244241] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11819), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11821), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [244252] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11823), 1,
      anon_sym_default,
    ACTIONS(11825), 1,
      anon_sym_delete,
    ACTIONS(11827), 1,
      anon_sym_0,
  [244265] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11829), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_GT2,
  [244274] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11586), 1,
      anon_sym_COLON,
    ACTIONS(11831), 1,
      anon_sym_RPAREN,
    STATE(7386), 1,
      sym_gnu_asm_clobber_list,
  [244287] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11833), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [244300] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11835), 1,
      anon_sym_catch,
    STATE(326), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [244311] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(11837), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [244324] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11839), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
    STATE(3056), 1,
      sym_template_function,
  [244337] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11841), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [244350] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11843), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [244363] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11845), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11847), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [244374] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11666), 1,
      anon_sym_COLON,
    ACTIONS(11849), 1,
      anon_sym_RPAREN,
    STATE(7112), 1,
      sym_gnu_asm_output_operand_list,
  [244387] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11598), 1,
      anon_sym_COLON,
    ACTIONS(11851), 1,
      anon_sym_RPAREN,
    STATE(7113), 1,
      sym_gnu_asm_input_operand_list,
  [244400] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11835), 1,
      anon_sym_catch,
    STATE(706), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [244411] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8155), 1,
      anon_sym_COMMA,
    ACTIONS(11853), 1,
      anon_sym_RBRACK,
    STATE(7245), 1,
      aux_sym_subscript_argument_list_repeat1,
  [244424] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(11855), 1,
      anon_sym_SEMI,
    STATE(7082), 1,
      aux_sym_declaration_repeat1,
  [244437] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11634), 1,
      anon_sym_catch,
    STATE(1939), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [244448] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8233), 1,
      anon_sym_RPAREN,
    STATE(7216), 1,
      aux_sym_argument_list_repeat1,
  [244461] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    STATE(6859), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(11857), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [244472] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11859), 1,
      sym_identifier,
    ACTIONS(11861), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
  [244483] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(11863), 1,
      anon_sym_SEMI,
    STATE(7218), 1,
      aux_sym_declaration_repeat1,
  [244496] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11865), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [244509] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11867), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [244522] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11869), 1,
      anon_sym_catch,
    STATE(294), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [244533] = 4,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11871), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(11873), 1,
      anon_sym_LPAREN2,
    STATE(8134), 1,
      sym_preproc_argument_list,
  [244546] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11594), 1,
      anon_sym_catch,
    STATE(1936), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [244557] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11875), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
    STATE(3056), 1,
      sym_template_function,
  [244570] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11877), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [244583] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(11879), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [244596] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(11881), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [244609] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11666), 1,
      anon_sym_COLON,
    ACTIONS(11883), 1,
      anon_sym_RPAREN,
    STATE(7420), 1,
      sym_gnu_asm_output_operand_list,
  [244622] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11186), 1,
      anon_sym_COMMA,
    ACTIONS(11578), 1,
      anon_sym_LBRACE,
    STATE(7330), 1,
      aux_sym_base_class_clause_repeat1,
  [244635] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11885), 1,
      sym_identifier,
    STATE(2416), 1,
      sym_template_type,
    STATE(3539), 1,
      sym_template_function,
  [244648] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5944), 1,
      anon_sym_COMMA,
    ACTIONS(11887), 1,
      anon_sym_RBRACK,
    STATE(7032), 1,
      aux_sym_structured_binding_declarator_repeat1,
  [244661] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(11889), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [244674] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11580), 1,
      anon_sym_COMMA,
    ACTIONS(11891), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(7201), 1,
      aux_sym_attribute_declaration_repeat1,
  [244687] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(11893), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [244700] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11706), 1,
      anon_sym_COMMA,
    ACTIONS(11895), 1,
      anon_sym_RPAREN,
    STATE(7072), 1,
      aux_sym_gnu_asm_goto_list_repeat1,
  [244713] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11598), 1,
      anon_sym_COLON,
    ACTIONS(11897), 1,
      anon_sym_RPAREN,
    STATE(7315), 1,
      sym_gnu_asm_input_operand_list,
  [244726] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11580), 1,
      anon_sym_COMMA,
    ACTIONS(11899), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(7121), 1,
      aux_sym_attribute_declaration_repeat1,
  [244739] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11901), 1,
      anon_sym_GT2,
    STATE(7136), 1,
      aux_sym_template_argument_list_repeat1,
  [244752] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8275), 1,
      anon_sym_RPAREN,
    STATE(7270), 1,
      aux_sym_argument_list_repeat1,
  [244765] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2010), 1,
      anon_sym_while,
    ACTIONS(11785), 1,
      anon_sym_else,
    STATE(424), 1,
      sym_else_clause,
  [244778] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11903), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11905), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [244789] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11666), 1,
      anon_sym_COLON,
    ACTIONS(11907), 1,
      anon_sym_RPAREN,
    STATE(7144), 1,
      sym_gnu_asm_output_operand_list,
  [244802] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11909), 1,
      anon_sym_GT2,
    STATE(7187), 1,
      aux_sym_template_argument_list_repeat1,
  [244815] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11636), 1,
      anon_sym_COMMA,
    ACTIONS(11911), 1,
      anon_sym_RPAREN,
    STATE(7070), 1,
      aux_sym_parameter_list_repeat1,
  [244828] = 4,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11873), 1,
      anon_sym_LPAREN2,
    ACTIONS(11913), 1,
      aux_sym_preproc_include_token2,
    STATE(8134), 1,
      sym_preproc_argument_list,
  [244841] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11915), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(11917), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [244852] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11186), 1,
      anon_sym_COMMA,
    ACTIONS(11375), 1,
      anon_sym_LBRACE,
    STATE(7163), 1,
      aux_sym_base_class_clause_repeat1,
  [244865] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11186), 1,
      anon_sym_COMMA,
    ACTIONS(11375), 1,
      anon_sym_LBRACE,
    STATE(7330), 1,
      aux_sym_base_class_clause_repeat1,
  [244878] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(11919), 1,
      anon_sym_RPAREN,
    STATE(7216), 1,
      aux_sym_argument_list_repeat1,
  [244891] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11921), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [244904] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11923), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [244917] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11925), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [244930] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11927), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [244943] = 4,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11873), 1,
      anon_sym_LPAREN2,
    ACTIONS(11929), 1,
      aux_sym_preproc_include_token2,
    STATE(8134), 1,
      sym_preproc_argument_list,
  [244956] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8205), 1,
      anon_sym_RPAREN,
    STATE(7149), 1,
      aux_sym_argument_list_repeat1,
  [244969] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9304), 1,
      anon_sym_COMMA,
    ACTIONS(11931), 1,
      anon_sym_RPAREN,
    STATE(7224), 1,
      aux_sym_preproc_argument_list_repeat1,
  [244982] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11933), 1,
      anon_sym_COMMA,
    ACTIONS(11935), 1,
      anon_sym_RPAREN,
    STATE(7219), 1,
      aux_sym_preproc_params_repeat1,
  [244995] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11580), 1,
      anon_sym_COMMA,
    ACTIONS(11937), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(7201), 1,
      aux_sym_attribute_declaration_repeat1,
  [245008] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11580), 1,
      anon_sym_COMMA,
    ACTIONS(11939), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(7201), 1,
      aux_sym_attribute_declaration_repeat1,
  [245021] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11734), 1,
      anon_sym_COMMA,
    ACTIONS(11941), 1,
      anon_sym_GT2,
    STATE(7086), 1,
      aux_sym_template_parameter_list_repeat1,
  [245034] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11943), 1,
      anon_sym_default,
    ACTIONS(11945), 1,
      anon_sym_delete,
    ACTIONS(11947), 1,
      anon_sym_0,
  [245047] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    ACTIONS(11949), 1,
      anon_sym_constexpr,
    STATE(823), 1,
      sym_condition_clause,
  [245060] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5298), 1,
      anon_sym_LT,
    ACTIONS(6308), 1,
      anon_sym_SEMI,
    STATE(2404), 1,
      sym_template_argument_list,
  [245073] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11666), 1,
      anon_sym_COLON,
    ACTIONS(11951), 1,
      anon_sym_RPAREN,
    STATE(7253), 1,
      sym_gnu_asm_output_operand_list,
  [245086] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11953), 1,
      anon_sym_COMMA,
    ACTIONS(11955), 1,
      anon_sym_LBRACE,
    STATE(7248), 1,
      aux_sym_field_initializer_list_repeat1,
  [245099] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11957), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
    STATE(6365), 1,
      sym_template_function,
  [245112] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11959), 1,
      anon_sym_COMMA,
    ACTIONS(11962), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(7201), 1,
      aux_sym_attribute_declaration_repeat1,
  [245125] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11964), 1,
      anon_sym_GT2,
    STATE(7267), 1,
      aux_sym_template_argument_list_repeat1,
  [245138] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(11966), 1,
      anon_sym_SEMI,
    STATE(7160), 1,
      aux_sym_declaration_repeat1,
  [245151] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11968), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [245160] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8155), 1,
      anon_sym_COMMA,
    ACTIONS(8265), 1,
      anon_sym_RBRACK,
    STATE(7075), 1,
      aux_sym_subscript_argument_list_repeat1,
  [245173] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11970), 1,
      sym_identifier,
    STATE(2416), 1,
      sym_template_type,
    STATE(2764), 1,
      sym_template_function,
  [245186] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11972), 1,
      anon_sym_default,
    ACTIONS(11974), 1,
      anon_sym_delete,
    ACTIONS(11976), 1,
      anon_sym_0,
  [245199] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8203), 1,
      anon_sym_RPAREN,
    STATE(7216), 1,
      aux_sym_argument_list_repeat1,
  [245212] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11598), 1,
      anon_sym_COLON,
    ACTIONS(11978), 1,
      anon_sym_RPAREN,
    STATE(7259), 1,
      sym_gnu_asm_input_operand_list,
  [245225] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5365), 3,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_DOT,
  [245234] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11980), 1,
      anon_sym_catch,
    STATE(1817), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [245245] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11982), 1,
      anon_sym_GT2,
    STATE(7215), 1,
      aux_sym_template_argument_list_repeat1,
  [245258] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11984), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [245271] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11986), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [245284] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(11988), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [245297] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8416), 1,
      anon_sym_RPAREN,
    ACTIONS(11990), 1,
      anon_sym_COMMA,
    STATE(7216), 1,
      aux_sym_argument_list_repeat1,
  [245310] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(11993), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [245323] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(11995), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [245336] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11997), 1,
      anon_sym_COMMA,
    ACTIONS(12000), 1,
      anon_sym_RPAREN,
    STATE(7219), 1,
      aux_sym_preproc_params_repeat1,
  [245349] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8041), 1,
      anon_sym_COMMA,
    ACTIONS(12002), 1,
      anon_sym_RBRACK,
    STATE(7433), 1,
      aux_sym_lambda_capture_specifier_repeat1,
  [245362] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    ACTIONS(12004), 1,
      anon_sym_constexpr,
    STATE(822), 1,
      sym_condition_clause,
  [245375] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8123), 1,
      anon_sym_COMMA,
    ACTIONS(12006), 1,
      anon_sym_RPAREN,
    STATE(7091), 1,
      aux_sym_generic_expression_repeat1,
  [245388] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11720), 1,
      anon_sym_catch,
    STATE(350), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [245399] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9474), 1,
      anon_sym_RPAREN,
    ACTIONS(12008), 1,
      anon_sym_COMMA,
    STATE(7224), 1,
      aux_sym_preproc_argument_list_repeat1,
  [245412] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11869), 1,
      anon_sym_catch,
    STATE(349), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [245423] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11590), 1,
      anon_sym_COLON,
    ACTIONS(12011), 1,
      anon_sym_RPAREN,
    STATE(8059), 1,
      sym_gnu_asm_goto_list,
  [245436] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12013), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [245445] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11580), 1,
      anon_sym_COMMA,
    ACTIONS(12015), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(7192), 1,
      aux_sym_attribute_declaration_repeat1,
  [245458] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11636), 1,
      anon_sym_COMMA,
    ACTIONS(12017), 1,
      anon_sym_RPAREN,
    STATE(7084), 1,
      aux_sym_parameter_list_repeat1,
  [245471] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12019), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [245480] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11580), 1,
      anon_sym_COMMA,
    ACTIONS(12021), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(7394), 1,
      aux_sym_attribute_declaration_repeat1,
  [245493] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11586), 1,
      anon_sym_COLON,
    ACTIONS(12023), 1,
      anon_sym_RPAREN,
    STATE(7226), 1,
      sym_gnu_asm_clobber_list,
  [245506] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12025), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
    STATE(3056), 1,
      sym_template_function,
  [245519] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11590), 1,
      anon_sym_COLON,
    ACTIONS(12027), 1,
      anon_sym_RPAREN,
    STATE(8047), 1,
      sym_gnu_asm_goto_list,
  [245532] = 4,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11873), 1,
      anon_sym_LPAREN2,
    ACTIONS(12029), 1,
      aux_sym_preproc_include_token2,
    STATE(8134), 1,
      sym_preproc_argument_list,
  [245545] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8123), 1,
      anon_sym_COMMA,
    ACTIONS(12031), 1,
      anon_sym_RPAREN,
    STATE(7091), 1,
      aux_sym_generic_expression_repeat1,
  [245558] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11829), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_GT2,
  [245567] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12033), 1,
      anon_sym_GT2,
    STATE(7241), 1,
      aux_sym_template_argument_list_repeat1,
  [245580] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12035), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [245593] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12037), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [245606] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12039), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [245619] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(12041), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [245632] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4366), 1,
      anon_sym_RBRACE,
    ACTIONS(12043), 1,
      anon_sym_COMMA,
    STATE(7247), 1,
      aux_sym_initializer_list_repeat1,
  [245645] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(12045), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [245658] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8347), 1,
      anon_sym_RBRACK,
    ACTIONS(12047), 1,
      anon_sym_COMMA,
    STATE(7245), 1,
      aux_sym_subscript_argument_list_repeat1,
  [245671] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    STATE(6837), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(12050), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [245682] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8224), 1,
      anon_sym_RBRACE,
    ACTIONS(12052), 1,
      anon_sym_COMMA,
    STATE(7247), 1,
      aux_sym_initializer_list_repeat1,
  [245695] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12055), 1,
      anon_sym_COMMA,
    ACTIONS(12058), 1,
      anon_sym_LBRACE,
    STATE(7248), 1,
      aux_sym_field_initializer_list_repeat1,
  [245708] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12060), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
  [245717] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    ACTIONS(12062), 1,
      anon_sym_constexpr,
    STATE(879), 1,
      sym_condition_clause,
  [245730] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12064), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
  [245739] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(12066), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [245752] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11598), 1,
      anon_sym_COLON,
    ACTIONS(12068), 1,
      anon_sym_RPAREN,
    STATE(7262), 1,
      sym_gnu_asm_input_operand_list,
  [245765] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12070), 1,
      anon_sym_COMMA,
    ACTIONS(12073), 1,
      anon_sym_RBRACK,
    STATE(7254), 1,
      aux_sym_structured_binding_declarator_repeat1,
  [245778] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12075), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
    STATE(3056), 1,
      sym_template_function,
  [245791] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8161), 3,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym___attribute__,
  [245800] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11598), 1,
      anon_sym_COLON,
    ACTIONS(12077), 1,
      anon_sym_RPAREN,
    STATE(7232), 1,
      sym_gnu_asm_input_operand_list,
  [245813] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12079), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
    STATE(2764), 1,
      sym_template_function,
  [245826] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11586), 1,
      anon_sym_COLON,
    ACTIONS(12081), 1,
      anon_sym_RPAREN,
    STATE(7234), 1,
      sym_gnu_asm_clobber_list,
  [245839] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11666), 1,
      anon_sym_COLON,
    ACTIONS(12083), 1,
      anon_sym_RPAREN,
    STATE(7317), 1,
      sym_gnu_asm_output_operand_list,
  [245852] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12085), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [245865] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11586), 1,
      anon_sym_COLON,
    ACTIONS(12087), 1,
      anon_sym_RPAREN,
    STATE(7320), 1,
      sym_gnu_asm_clobber_list,
  [245878] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12089), 1,
      anon_sym_GT2,
    STATE(7266), 1,
      aux_sym_template_argument_list_repeat1,
  [245891] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12091), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [245904] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12093), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [245917] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12095), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [245930] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12097), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [245943] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11580), 1,
      anon_sym_COMMA,
    ACTIONS(12099), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(7438), 1,
      aux_sym_attribute_declaration_repeat1,
  [245956] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12101), 1,
      anon_sym_default,
    ACTIONS(12103), 1,
      anon_sym_delete,
    ACTIONS(12105), 1,
      anon_sym_0,
  [245969] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8247), 1,
      anon_sym_RPAREN,
    STATE(7216), 1,
      aux_sym_argument_list_repeat1,
  [245982] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11186), 1,
      anon_sym_COMMA,
    ACTIONS(12107), 1,
      anon_sym_LBRACE,
    STATE(7330), 1,
      aux_sym_base_class_clause_repeat1,
  [245995] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12109), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12111), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [246006] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(12113), 1,
      anon_sym_RPAREN,
    STATE(7216), 1,
      aux_sym_argument_list_repeat1,
  [246019] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    ACTIONS(12115), 1,
      anon_sym_constexpr,
    STATE(831), 1,
      sym_condition_clause,
  [246032] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9304), 1,
      anon_sym_COMMA,
    ACTIONS(12117), 1,
      anon_sym_RPAREN,
    STATE(7224), 1,
      aux_sym_preproc_argument_list_repeat1,
  [246045] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11612), 1,
      anon_sym_COMMA,
    ACTIONS(12119), 1,
      anon_sym_RPAREN,
    STATE(7028), 1,
      aux_sym_throw_specifier_repeat1,
  [246058] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11869), 1,
      anon_sym_catch,
    STATE(351), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [246069] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11734), 1,
      anon_sym_COMMA,
    ACTIONS(12121), 1,
      anon_sym_GT2,
    STATE(7122), 1,
      aux_sym_template_parameter_list_repeat1,
  [246082] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8123), 1,
      anon_sym_COMMA,
    ACTIONS(12123), 1,
      anon_sym_RPAREN,
    STATE(7091), 1,
      aux_sym_generic_expression_repeat1,
  [246095] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12125), 1,
      sym_identifier,
    STATE(2893), 1,
      sym_template_type,
    STATE(3748), 1,
      sym_template_function,
  [246108] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8155), 1,
      anon_sym_COMMA,
    ACTIONS(12127), 1,
      anon_sym_RBRACK,
    STATE(7245), 1,
      aux_sym_subscript_argument_list_repeat1,
  [246121] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12129), 1,
      anon_sym_catch,
    STATE(160), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [246132] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11636), 1,
      anon_sym_COMMA,
    ACTIONS(12131), 1,
      anon_sym_RPAREN,
    STATE(7291), 1,
      aux_sym_parameter_list_repeat1,
  [246145] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11590), 1,
      anon_sym_COLON,
    ACTIONS(12133), 1,
      anon_sym_RPAREN,
    STATE(8097), 1,
      sym_gnu_asm_goto_list,
  [246158] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12135), 1,
      anon_sym_GT2,
    STATE(7288), 1,
      aux_sym_template_argument_list_repeat1,
  [246171] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12137), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [246184] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12139), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [246197] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12141), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [246210] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11720), 1,
      anon_sym_catch,
    STATE(339), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [246221] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(12143), 1,
      anon_sym_RPAREN,
    STATE(7216), 1,
      aux_sym_argument_list_repeat1,
  [246234] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12145), 1,
      anon_sym_COMMA,
    ACTIONS(12148), 1,
      anon_sym_RPAREN,
    STATE(7291), 1,
      aux_sym_parameter_list_repeat1,
  [246247] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11586), 1,
      anon_sym_COLON,
    ACTIONS(12150), 1,
      anon_sym_RPAREN,
    STATE(7284), 1,
      sym_gnu_asm_clobber_list,
  [246260] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11590), 1,
      anon_sym_COLON,
    ACTIONS(12152), 1,
      anon_sym_RPAREN,
    STATE(8088), 1,
      sym_gnu_asm_goto_list,
  [246273] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12129), 1,
      anon_sym_catch,
    STATE(147), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [246284] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(12154), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [246297] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12156), 1,
      anon_sym_GT2,
    STATE(7153), 1,
      aux_sym_template_argument_list_repeat1,
  [246310] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11186), 1,
      anon_sym_COMMA,
    ACTIONS(11188), 1,
      anon_sym_LBRACE,
    STATE(7330), 1,
      aux_sym_base_class_clause_repeat1,
  [246323] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12158), 1,
      anon_sym_GT2,
    STATE(7089), 1,
      aux_sym_template_argument_list_repeat1,
  [246336] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(12160), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [246349] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11598), 1,
      anon_sym_COLON,
    ACTIONS(12162), 1,
      anon_sym_RPAREN,
    STATE(7292), 1,
      sym_gnu_asm_input_operand_list,
  [246362] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12164), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
    STATE(3056), 1,
      sym_template_function,
  [246375] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12166), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [246388] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12168), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [246401] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12170), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [246414] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11586), 1,
      anon_sym_COLON,
    ACTIONS(12172), 1,
      anon_sym_RPAREN,
    STATE(7293), 1,
      sym_gnu_asm_clobber_list,
  [246427] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12174), 1,
      anon_sym_GT2,
    STATE(7309), 1,
      aux_sym_template_argument_list_repeat1,
  [246440] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12176), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [246453] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12178), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [246466] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12180), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [246479] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11666), 1,
      anon_sym_COLON,
    ACTIONS(12182), 1,
      anon_sym_RPAREN,
    STATE(7257), 1,
      sym_gnu_asm_output_operand_list,
  [246492] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11953), 1,
      anon_sym_COMMA,
    ACTIONS(12184), 1,
      anon_sym_LBRACE,
    STATE(7199), 1,
      aux_sym_field_initializer_list_repeat1,
  [246505] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8181), 1,
      anon_sym_RPAREN,
    STATE(7369), 1,
      aux_sym_argument_list_repeat1,
  [246518] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12186), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12188), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [246529] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4380), 1,
      anon_sym_LBRACE,
    ACTIONS(11180), 1,
      anon_sym_COLON_COLON,
    STATE(714), 1,
      sym_declaration_list,
  [246542] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11586), 1,
      anon_sym_COLON,
    ACTIONS(12190), 1,
      anon_sym_RPAREN,
    STATE(7077), 1,
      sym_gnu_asm_clobber_list,
  [246555] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12192), 1,
      anon_sym_COMMA,
    ACTIONS(12195), 1,
      anon_sym_RPAREN,
    STATE(7316), 1,
      aux_sym_requires_parameter_list_repeat1,
  [246568] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11598), 1,
      anon_sym_COLON,
    ACTIONS(12197), 1,
      anon_sym_RPAREN,
    STATE(7324), 1,
      sym_gnu_asm_input_operand_list,
  [246581] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    STATE(6994), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(12199), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [246592] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(12201), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [246605] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11590), 1,
      anon_sym_COLON,
    ACTIONS(12203), 1,
      anon_sym_RPAREN,
    STATE(7982), 1,
      sym_gnu_asm_goto_list,
  [246618] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12205), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
    STATE(3539), 1,
      sym_template_function,
  [246631] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12207), 1,
      anon_sym_default,
    ACTIONS(12209), 1,
      anon_sym_delete,
    ACTIONS(12211), 1,
      anon_sym_0,
  [246644] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(12213), 1,
      anon_sym_SEMI,
    STATE(7407), 1,
      aux_sym_declaration_repeat1,
  [246657] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11586), 1,
      anon_sym_COLON,
    ACTIONS(12215), 1,
      anon_sym_RPAREN,
    STATE(7337), 1,
      sym_gnu_asm_clobber_list,
  [246670] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12217), 1,
      anon_sym_GT2,
    STATE(7328), 1,
      aux_sym_template_argument_list_repeat1,
  [246683] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12219), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [246696] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12221), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [246709] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12223), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [246722] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4360), 1,
      anon_sym_RBRACE,
    ACTIONS(12225), 1,
      anon_sym_COMMA,
    STATE(7247), 1,
      aux_sym_initializer_list_repeat1,
  [246735] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12188), 1,
      anon_sym_LBRACE,
    ACTIONS(12227), 1,
      anon_sym_COMMA,
    STATE(7330), 1,
      aux_sym_base_class_clause_repeat1,
  [246748] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12232), 1,
      anon_sym_RPAREN,
    ACTIONS(12230), 2,
      anon_sym_DOT_DOT_DOT,
      sym_identifier,
  [246759] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4384), 1,
      anon_sym_LBRACE,
    ACTIONS(11180), 1,
      anon_sym_COLON_COLON,
    STATE(333), 1,
      sym_declaration_list,
  [246772] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(12234), 1,
      anon_sym_RPAREN,
    STATE(7216), 1,
      aux_sym_argument_list_repeat1,
  [246785] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11666), 1,
      anon_sym_COLON,
    ACTIONS(12236), 1,
      anon_sym_RPAREN,
    STATE(7106), 1,
      sym_gnu_asm_output_operand_list,
  [246798] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11933), 1,
      anon_sym_COMMA,
    ACTIONS(12238), 1,
      anon_sym_RPAREN,
    STATE(7191), 1,
      aux_sym_preproc_params_repeat1,
  [246811] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    STATE(6956), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(12240), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [246822] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11590), 1,
      anon_sym_COLON,
    ACTIONS(12242), 1,
      anon_sym_RPAREN,
    STATE(7984), 1,
      sym_gnu_asm_goto_list,
  [246835] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8123), 1,
      anon_sym_COMMA,
    ACTIONS(12244), 1,
      anon_sym_RPAREN,
    STATE(7091), 1,
      aux_sym_generic_expression_repeat1,
  [246848] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12246), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
    STATE(3056), 1,
      sym_template_function,
  [246861] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(12248), 1,
      anon_sym_SEMI,
    STATE(7168), 1,
      aux_sym_declaration_repeat1,
  [246874] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8183), 1,
      anon_sym_RPAREN,
    STATE(7216), 1,
      aux_sym_argument_list_repeat1,
  [246887] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11980), 1,
      anon_sym_catch,
    STATE(1818), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [246898] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12250), 1,
      anon_sym_GT2,
    STATE(7346), 1,
      aux_sym_template_argument_list_repeat1,
  [246911] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12252), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [246924] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12254), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [246937] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12256), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [246950] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1996), 1,
      anon_sym_while,
    ACTIONS(11785), 1,
      anon_sym_else,
    STATE(454), 1,
      sym_else_clause,
  [246963] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12258), 1,
      anon_sym_COMMA,
    ACTIONS(12261), 1,
      anon_sym_GT2,
    STATE(7348), 1,
      aux_sym_template_parameter_list_repeat1,
  [246976] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12263), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_GT2,
  [246985] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(12265), 1,
      anon_sym_SEMI,
    STATE(7242), 1,
      aux_sym_declaration_repeat1,
  [246998] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12267), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [247011] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12269), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [247024] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12271), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [247037] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12263), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_GT2,
  [247046] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12273), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
    STATE(3748), 1,
      sym_template_function,
  [247059] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12275), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_GT2,
  [247068] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12277), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_GT2,
  [247077] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11666), 1,
      anon_sym_COLON,
    ACTIONS(12279), 1,
      anon_sym_RPAREN,
    STATE(7300), 1,
      sym_gnu_asm_output_operand_list,
  [247090] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12281), 1,
      anon_sym_GT2,
    STATE(7362), 1,
      aux_sym_template_argument_list_repeat1,
  [247103] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12283), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [247116] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12285), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [247129] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12287), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [247142] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11598), 1,
      anon_sym_COLON,
    ACTIONS(12289), 1,
      anon_sym_RPAREN,
    STATE(7305), 1,
      sym_gnu_asm_input_operand_list,
  [247155] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    STATE(6892), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(12291), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [247166] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4376), 1,
      anon_sym_RBRACE,
    ACTIONS(12293), 1,
      anon_sym_COMMA,
    STATE(7247), 1,
      aux_sym_initializer_list_repeat1,
  [247179] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11835), 1,
      anon_sym_catch,
    STATE(704), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [247190] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12295), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
    STATE(2764), 1,
      sym_template_function,
  [247203] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    STATE(6848), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(12297), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [247214] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8081), 1,
      anon_sym_RPAREN,
    STATE(7216), 1,
      aux_sym_argument_list_repeat1,
  [247227] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8209), 1,
      anon_sym_COMMA,
    ACTIONS(8211), 1,
      anon_sym_RBRACE,
    STATE(7116), 1,
      aux_sym_initializer_list_repeat1,
  [247240] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12299), 1,
      anon_sym_GT2,
    STATE(7374), 1,
      aux_sym_template_argument_list_repeat1,
  [247253] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12301), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [247266] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12303), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [247279] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12305), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [247292] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11580), 1,
      anon_sym_COMMA,
    ACTIONS(12307), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(7060), 1,
      aux_sym_attribute_declaration_repeat1,
  [247305] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12309), 1,
      anon_sym_COMMA,
    ACTIONS(12312), 1,
      anon_sym_RPAREN,
    STATE(7376), 1,
      aux_sym_throw_specifier_repeat1,
  [247318] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12314), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
    STATE(3056), 1,
      sym_template_function,
  [247331] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    STATE(6823), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(12316), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [247342] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4386), 1,
      anon_sym_LBRACE,
    ACTIONS(11180), 1,
      anon_sym_COLON_COLON,
    STATE(672), 1,
      sym_declaration_list,
  [247355] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12318), 1,
      anon_sym_GT2,
    STATE(7383), 1,
      aux_sym_template_argument_list_repeat1,
  [247368] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12320), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [247381] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12322), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [247394] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12324), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [247407] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11580), 1,
      anon_sym_COMMA,
    ACTIONS(12326), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(7193), 1,
      aux_sym_attribute_declaration_repeat1,
  [247420] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8155), 1,
      anon_sym_COMMA,
    ACTIONS(8157), 1,
      anon_sym_RBRACK,
    STATE(7281), 1,
      aux_sym_subscript_argument_list_repeat1,
  [247433] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11590), 1,
      anon_sym_COLON,
    ACTIONS(12328), 1,
      anon_sym_RPAREN,
    STATE(8574), 1,
      sym_gnu_asm_goto_list,
  [247446] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11980), 1,
      anon_sym_catch,
    STATE(1814), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [247457] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12330), 1,
      anon_sym_GT2,
    STATE(7391), 1,
      aux_sym_template_argument_list_repeat1,
  [247470] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12332), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [247483] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12334), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [247496] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12336), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [247509] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12338), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
    STATE(2764), 1,
      sym_template_function,
  [247522] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8201), 1,
      anon_sym_RPAREN,
    STATE(7054), 1,
      aux_sym_argument_list_repeat1,
  [247535] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11580), 1,
      anon_sym_COMMA,
    ACTIONS(12340), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(7201), 1,
      aux_sym_attribute_declaration_repeat1,
  [247548] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11186), 1,
      anon_sym_COMMA,
    ACTIONS(11466), 1,
      anon_sym_LBRACE,
    STATE(7330), 1,
      aux_sym_base_class_clause_repeat1,
  [247561] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12342), 1,
      anon_sym_GT2,
    STATE(7399), 1,
      aux_sym_template_argument_list_repeat1,
  [247574] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12344), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [247587] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12346), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [247600] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12348), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [247613] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    ACTIONS(12350), 1,
      anon_sym_constexpr,
    STATE(846), 1,
      sym_condition_clause,
  [247626] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12129), 1,
      anon_sym_catch,
    STATE(163), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [247637] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(12352), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [247650] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(12354), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [247663] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12356), 3,
      anon_sym_LBRACK,
      anon_sym_EQ,
      anon_sym_DOT,
  [247672] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11636), 1,
      anon_sym_COMMA,
    ACTIONS(12358), 1,
      anon_sym_RPAREN,
    STATE(7283), 1,
      aux_sym_parameter_list_repeat1,
  [247685] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12362), 1,
      anon_sym_RPAREN,
    ACTIONS(12360), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [247696] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(12364), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [247709] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(12366), 1,
      anon_sym_SEMI,
    STATE(7053), 1,
      aux_sym_declaration_repeat1,
  [247722] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4215), 1,
      anon_sym_RBRACE,
    ACTIONS(12368), 1,
      anon_sym_COMMA,
    STATE(7247), 1,
      aux_sym_initializer_list_repeat1,
  [247735] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    ACTIONS(12370), 1,
      anon_sym_constexpr,
    STATE(887), 1,
      sym_condition_clause,
  [247748] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12372), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
    STATE(3056), 1,
      sym_template_function,
  [247761] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    STATE(6787), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(12374), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [247772] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12376), 1,
      anon_sym_COMMA,
    ACTIONS(12379), 1,
      anon_sym_GT2,
    STATE(7413), 1,
      aux_sym_template_argument_list_repeat1,
  [247785] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11186), 1,
      anon_sym_COMMA,
    ACTIONS(11466), 1,
      anon_sym_LBRACE,
    STATE(7297), 1,
      aux_sym_base_class_clause_repeat1,
  [247798] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12381), 1,
      anon_sym_GT2,
    STATE(7302), 1,
      aux_sym_template_argument_list_repeat1,
  [247811] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    ACTIONS(12383), 1,
      anon_sym_constexpr,
    STATE(856), 1,
      sym_condition_clause,
  [247824] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8155), 1,
      anon_sym_COMMA,
    ACTIONS(8279), 1,
      anon_sym_RBRACK,
    STATE(7146), 1,
      aux_sym_subscript_argument_list_repeat1,
  [247837] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12385), 1,
      anon_sym_catch,
    STATE(953), 2,
      sym_catch_clause,
      aux_sym_constructor_try_statement_repeat1,
  [247848] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8085), 1,
      anon_sym_COMMA,
    ACTIONS(12387), 1,
      anon_sym_GT2,
    STATE(7351), 1,
      aux_sym_template_argument_list_repeat1,
  [247861] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11598), 1,
      anon_sym_COLON,
    ACTIONS(12389), 1,
      anon_sym_RPAREN,
    STATE(7135), 1,
      sym_gnu_asm_input_operand_list,
  [247874] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    STATE(6801), 1,
      aux_sym_char_literal_repeat1,
    ACTIONS(12391), 2,
      aux_sym_char_literal_token1,
      sym_escape_sequence,
  [247885] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11666), 1,
      anon_sym_COLON,
    ACTIONS(12393), 1,
      anon_sym_RPAREN,
    STATE(7209), 1,
      sym_gnu_asm_output_operand_list,
  [247898] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11666), 1,
      anon_sym_COLON,
    ACTIONS(12395), 1,
      anon_sym_RPAREN,
    STATE(7363), 1,
      sym_gnu_asm_output_operand_list,
  [247911] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11077), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(12397), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
  [247922] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11666), 1,
      anon_sym_COLON,
    ACTIONS(12399), 1,
      anon_sym_RPAREN,
    STATE(7170), 1,
      sym_gnu_asm_output_operand_list,
  [247935] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12401), 1,
      sym_identifier,
    STATE(2416), 1,
      sym_template_type,
    STATE(3425), 1,
      sym_template_function,
  [247948] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11186), 1,
      anon_sym_COMMA,
    ACTIONS(11188), 1,
      anon_sym_LBRACE,
    STATE(7182), 1,
      aux_sym_base_class_clause_repeat1,
  [247961] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    ACTIONS(12403), 1,
      anon_sym_constexpr,
    STATE(826), 1,
      sym_condition_clause,
  [247974] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12405), 1,
      anon_sym_default,
    ACTIONS(12407), 1,
      anon_sym_delete,
    ACTIONS(12409), 1,
      anon_sym_0,
  [247987] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8077), 1,
      anon_sym_COMMA,
    ACTIONS(8079), 1,
      anon_sym_RBRACE,
    STATE(7329), 1,
      aux_sym_initializer_list_repeat1,
  [248000] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4384), 1,
      anon_sym_LBRACE,
    ACTIONS(11180), 1,
      anon_sym_COLON_COLON,
    STATE(268), 1,
      sym_declaration_list,
  [248013] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7988), 1,
      anon_sym_COMMA,
    ACTIONS(12411), 1,
      anon_sym_SEMI,
    STATE(7402), 1,
      aux_sym_declaration_repeat1,
  [248026] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8434), 1,
      anon_sym_RBRACK,
    ACTIONS(12413), 1,
      anon_sym_COMMA,
    STATE(7433), 1,
      aux_sym_lambda_capture_specifier_repeat1,
  [248039] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8171), 1,
      anon_sym_COMMA,
    ACTIONS(8173), 1,
      anon_sym_RBRACE,
    STATE(7365), 1,
      aux_sym_initializer_list_repeat1,
  [248052] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8037), 1,
      anon_sym_COMMA,
    ACTIONS(8039), 1,
      anon_sym_RPAREN,
    STATE(7341), 1,
      aux_sym_argument_list_repeat1,
  [248065] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12416), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
    STATE(3056), 1,
      sym_template_function,
  [248078] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12418), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_COLON,
  [248087] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11580), 1,
      anon_sym_COMMA,
    ACTIONS(12420), 1,
      anon_sym_RBRACK_RBRACK,
    STATE(7201), 1,
      aux_sym_attribute_declaration_repeat1,
  [248100] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(793), 1,
      anon_sym_LBRACE,
    STATE(611), 1,
      sym_compound_statement,
  [248110] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10306), 1,
      anon_sym_RBRACE,
    ACTIONS(12422), 1,
      anon_sym_COMMA,
  [248120] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6451), 2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
  [248128] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12424), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(12426), 1,
      sym_preproc_arg,
  [248138] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(7289), 1,
      sym_compound_statement,
  [248148] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6455), 2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
  [248156] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    STATE(8470), 1,
      sym_argument_list,
  [248166] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6494), 2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
  [248174] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6502), 2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
  [248182] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6518), 2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
  [248190] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(6870), 1,
      sym_compound_statement,
  [248200] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    STATE(857), 1,
      sym_condition_clause,
  [248210] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    STATE(7513), 1,
      sym_condition_clause,
  [248220] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12428), 1,
      sym_identifier,
    STATE(7231), 1,
      sym_attribute,
  [248230] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    STATE(824), 1,
      sym_condition_clause,
  [248240] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6546), 2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
  [248248] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6514), 2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
  [248256] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    STATE(879), 1,
      sym_condition_clause,
  [248266] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12430), 1,
      anon_sym_LPAREN2,
    ACTIONS(12432), 1,
      sym_raw_string_delimiter,
  [248276] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12434), 1,
      anon_sym_if,
    ACTIONS(12436), 1,
      anon_sym_for,
  [248286] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(7145), 1,
      sym_compound_statement,
  [248296] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12438), 1,
      anon_sym_LT,
    STATE(3814), 1,
      sym_template_argument_list,
  [248306] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12440), 1,
      anon_sym_LPAREN2,
    ACTIONS(12442), 1,
      sym_raw_string_delimiter,
  [248316] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(783), 1,
      sym_compound_statement,
  [248326] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12444), 1,
      anon_sym_LPAREN2,
    ACTIONS(12446), 1,
      sym_raw_string_delimiter,
  [248336] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12448), 1,
      anon_sym_LPAREN2,
    ACTIONS(12450), 1,
      sym_raw_string_delimiter,
  [248346] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7997), 1,
      anon_sym_LT,
    STATE(4665), 1,
      sym_template_argument_list,
  [248356] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5298), 1,
      anon_sym_LT,
    STATE(2755), 1,
      sym_template_argument_list,
  [248366] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12452), 1,
      anon_sym_LPAREN2,
    ACTIONS(12454), 1,
      sym_raw_string_delimiter,
  [248376] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12456), 1,
      anon_sym_LPAREN2,
    ACTIONS(12458), 1,
      sym_raw_string_delimiter,
  [248386] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12460), 1,
      anon_sym_LPAREN2,
    ACTIONS(12462), 1,
      sym_raw_string_delimiter,
  [248396] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12464), 1,
      anon_sym_LT,
    STATE(2938), 1,
      sym_template_argument_list,
  [248406] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12466), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(12468), 1,
      sym_preproc_arg,
  [248416] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12470), 1,
      anon_sym_LPAREN2,
    ACTIONS(12472), 1,
      sym_raw_string_delimiter,
  [248426] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12474), 1,
      anon_sym_LPAREN2,
    ACTIONS(12476), 1,
      sym_raw_string_delimiter,
  [248436] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3723), 1,
      anon_sym_LT,
    STATE(952), 1,
      sym_template_argument_list,
  [248446] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12478), 1,
      anon_sym_LPAREN2,
    ACTIONS(12480), 1,
      sym_raw_string_delimiter,
  [248456] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6510), 2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
  [248464] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12482), 1,
      sym_identifier,
    STATE(3811), 1,
      sym_template_type,
  [248474] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12484), 1,
      anon_sym_LPAREN2,
    ACTIONS(12486), 1,
      sym_raw_string_delimiter,
  [248484] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12428), 1,
      sym_identifier,
    STATE(7375), 1,
      sym_attribute,
  [248494] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    STATE(8346), 1,
      sym_argument_list,
  [248504] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12488), 1,
      anon_sym_LPAREN2,
    ACTIONS(12490), 1,
      sym_raw_string_delimiter,
  [248514] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6522), 2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
  [248522] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2002), 1,
      anon_sym_LT,
    STATE(293), 1,
      sym_template_argument_list,
  [248532] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12492), 1,
      sym_identifier,
    STATE(4666), 1,
      sym_template_type,
  [248542] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6413), 2,
      anon_sym___attribute__,
      anon_sym_LBRACK_LBRACK,
  [248550] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12494), 1,
      anon_sym_LPAREN2,
    ACTIONS(12496), 1,
      sym_raw_string_delimiter,
  [248560] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2000), 1,
      anon_sym_LT,
    STATE(2221), 1,
      sym_template_argument_list,
  [248570] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12498), 1,
      sym_identifier,
    STATE(2939), 1,
      sym_template_type,
  [248580] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12500), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(12502), 1,
      sym_preproc_arg,
  [248590] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    STATE(7557), 1,
      sym_condition_clause,
  [248600] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6612), 1,
      anon_sym_LT,
    STATE(3029), 1,
      sym_template_argument_list,
  [248610] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12504), 1,
      anon_sym_LPAREN2,
    ACTIONS(12506), 1,
      sym_raw_string_delimiter,
  [248620] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12508), 1,
      sym_identifier,
    STATE(958), 1,
      sym_template_type,
  [248630] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    STATE(838), 1,
      sym_condition_clause,
  [248640] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12510), 1,
      anon_sym_LPAREN2,
    ACTIONS(12512), 1,
      sym_raw_string_delimiter,
  [248650] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12514), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [248658] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12516), 1,
      anon_sym_LT,
    STATE(3030), 1,
      sym_template_argument_list,
  [248668] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    STATE(877), 1,
      sym_condition_clause,
  [248678] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(7137), 1,
      sym_compound_statement,
  [248688] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12518), 1,
      sym_identifier,
    STATE(239), 1,
      sym_template_type,
  [248698] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12520), 1,
      anon_sym_LPAREN2,
    ACTIONS(12522), 1,
      sym_raw_string_delimiter,
  [248708] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12524), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [248716] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3627), 1,
      anon_sym_LBRACE,
    STATE(3569), 1,
      sym_initializer_list,
  [248726] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12526), 1,
      sym_identifier,
    ACTIONS(12528), 1,
      anon_sym_LPAREN2,
  [248736] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12530), 1,
      sym_identifier,
    ACTIONS(12532), 1,
      anon_sym_LPAREN2,
  [248746] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5196), 1,
      anon_sym_LT,
    STATE(2212), 1,
      sym_template_argument_list,
  [248756] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12534), 1,
      sym_identifier,
    STATE(2416), 1,
      sym_template_type,
  [248766] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11126), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
  [248776] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    STATE(2719), 1,
      sym_field_declaration_list,
  [248786] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_LBRACE,
    STATE(4005), 1,
      sym_initializer_list,
  [248796] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12536), 1,
      sym_identifier,
    STATE(3088), 1,
      sym_template_type,
  [248806] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    STATE(826), 1,
      sym_condition_clause,
  [248816] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(633), 1,
      anon_sym_LBRACE,
    STATE(478), 1,
      sym_compound_statement,
  [248826] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12538), 1,
      anon_sym_LPAREN2,
    STATE(8362), 1,
      sym_parenthesized_expression,
  [248836] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    STATE(5128), 1,
      sym_field_declaration_list,
  [248846] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    STATE(5104), 1,
      sym_field_declaration_list,
  [248856] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    STATE(5099), 1,
      sym_field_declaration_list,
  [248866] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12111), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [248874] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    STATE(5078), 1,
      sym_field_declaration_list,
  [248884] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7134), 1,
      anon_sym_LBRACE,
    STATE(4048), 1,
      sym_field_declaration_list,
  [248894] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    STATE(7570), 1,
      sym_parameter_list,
  [248904] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4386), 1,
      anon_sym_LBRACE,
    STATE(693), 1,
      sym_declaration_list,
  [248914] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12422), 1,
      anon_sym_COMMA,
    ACTIONS(12540), 1,
      anon_sym_RBRACE,
  [248924] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9115), 1,
      anon_sym_LBRACE,
    STATE(3652), 1,
      sym_requirement_seq,
  [248934] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12422), 1,
      anon_sym_COMMA,
    ACTIONS(12542), 1,
      anon_sym_RBRACE,
  [248944] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7134), 1,
      anon_sym_LBRACE,
    STATE(4065), 1,
      sym_field_declaration_list,
  [248954] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12544), 1,
      anon_sym_LPAREN2,
    ACTIONS(12546), 1,
      sym_raw_string_delimiter,
  [248964] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7134), 1,
      anon_sym_LBRACE,
    STATE(4075), 1,
      sym_field_declaration_list,
  [248974] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(633), 1,
      anon_sym_LBRACE,
    STATE(689), 1,
      sym_compound_statement,
  [248984] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10246), 1,
      anon_sym_RBRACE,
    ACTIONS(12422), 1,
      anon_sym_COMMA,
  [248994] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12312), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [249002] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12548), 1,
      sym_identifier,
    ACTIONS(12550), 1,
      anon_sym_RPAREN,
  [249012] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8663), 1,
      anon_sym_LT,
    STATE(2895), 1,
      sym_template_argument_list,
  [249022] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12552), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(12554), 1,
      sym_preproc_arg,
  [249032] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7134), 1,
      anon_sym_LBRACE,
    STATE(4043), 1,
      sym_field_declaration_list,
  [249042] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7847), 1,
      anon_sym_LT,
    STATE(2390), 1,
      sym_template_argument_list,
  [249052] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(7078), 1,
      sym_compound_statement,
  [249062] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    STATE(7978), 1,
      sym_argument_list,
  [249072] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12556), 1,
      sym_identifier,
    STATE(3031), 1,
      sym_template_type,
  [249082] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4386), 1,
      anon_sym_LBRACE,
    STATE(668), 1,
      sym_declaration_list,
  [249092] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10285), 1,
      anon_sym_RBRACE,
    ACTIONS(12422), 1,
      anon_sym_COMMA,
  [249102] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    STATE(466), 1,
      sym_field_declaration_list,
  [249112] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(6849), 1,
      sym_compound_statement,
  [249122] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    STATE(2731), 1,
      sym_field_declaration_list,
  [249132] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    STATE(2729), 1,
      sym_field_declaration_list,
  [249142] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4670), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [249150] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12360), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [249158] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8255), 1,
      anon_sym_RBRACK,
    ACTIONS(12558), 1,
      anon_sym_COMMA,
  [249168] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12560), 1,
      anon_sym_LT,
    STATE(2755), 1,
      sym_template_argument_list,
  [249178] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8483), 1,
      anon_sym_LBRACE,
    STATE(4926), 1,
      sym_field_declaration_list,
  [249188] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11917), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [249196] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    STATE(830), 1,
      sym_condition_clause,
  [249206] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(633), 1,
      anon_sym_LBRACE,
    STATE(607), 1,
      sym_compound_statement,
  [249216] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    STATE(2327), 1,
      sym_field_declaration_list,
  [249226] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    STATE(836), 1,
      sym_condition_clause,
  [249236] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    STATE(846), 1,
      sym_condition_clause,
  [249246] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(541), 1,
      sym_compound_statement,
  [249256] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    STATE(409), 1,
      sym_field_declaration_list,
  [249266] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8483), 1,
      anon_sym_LBRACE,
    STATE(4913), 1,
      sym_field_declaration_list,
  [249276] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8483), 1,
      anon_sym_LBRACE,
    STATE(4918), 1,
      sym_field_declaration_list,
  [249286] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    STATE(408), 1,
      sym_field_declaration_list,
  [249296] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4386), 1,
      anon_sym_LBRACE,
    STATE(601), 1,
      sym_declaration_list,
  [249306] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12538), 1,
      anon_sym_LPAREN2,
    STATE(7575), 1,
      sym_parenthesized_expression,
  [249316] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10304), 1,
      anon_sym_RBRACE,
    ACTIONS(12422), 1,
      anon_sym_COMMA,
  [249326] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12422), 1,
      anon_sym_COMMA,
    ACTIONS(12562), 1,
      anon_sym_RBRACE,
  [249336] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1937), 1,
      anon_sym_LT,
    STATE(146), 1,
      sym_template_argument_list,
  [249346] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11480), 1,
      anon_sym_LBRACE,
    STATE(5770), 1,
      sym_requirement_seq,
  [249356] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12564), 1,
      anon_sym_if,
    ACTIONS(12566), 1,
      anon_sym_for,
  [249366] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    STATE(2727), 1,
      sym_field_declaration_list,
  [249376] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(633), 1,
      anon_sym_LBRACE,
    STATE(362), 1,
      sym_compound_statement,
  [249386] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8483), 1,
      anon_sym_LBRACE,
    STATE(4902), 1,
      sym_field_declaration_list,
  [249396] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11180), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12568), 1,
      anon_sym_SEMI,
  [249406] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12570), 1,
      anon_sym_LT,
    STATE(3449), 1,
      sym_template_argument_list,
  [249416] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    STATE(5277), 1,
      sym_field_declaration_list,
  [249426] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(402), 1,
      sym_compound_statement,
  [249436] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    STATE(5233), 1,
      sym_field_declaration_list,
  [249446] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    STATE(5232), 1,
      sym_field_declaration_list,
  [249456] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    STATE(403), 1,
      sym_field_declaration_list,
  [249466] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    STATE(404), 1,
      sym_field_declaration_list,
  [249476] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    STATE(405), 1,
      sym_field_declaration_list,
  [249486] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6072), 1,
      anon_sym_LBRACE,
    STATE(5275), 1,
      sym_field_declaration_list,
  [249496] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(411), 1,
      sym_compound_statement,
  [249506] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12572), 1,
      sym_identifier,
    STATE(2209), 1,
      sym_template_type,
  [249516] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    STATE(426), 1,
      sym_field_declaration_list,
  [249526] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4380), 1,
      anon_sym_LBRACE,
    STATE(743), 1,
      sym_declaration_list,
  [249536] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11905), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [249544] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1982), 1,
      anon_sym_LBRACE,
    STATE(426), 1,
      sym_field_declaration_list,
  [249554] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12574), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(12576), 1,
      sym_preproc_arg,
  [249564] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12578), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(12580), 1,
      sym_preproc_arg,
  [249574] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12000), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [249582] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    STATE(863), 1,
      sym_condition_clause,
  [249592] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3523), 1,
      anon_sym_LBRACE,
    STATE(2840), 1,
      sym_initializer_list,
  [249602] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12582), 1,
      sym_identifier,
    STATE(2891), 1,
      sym_template_type,
  [249612] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8347), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [249620] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    STATE(4864), 1,
      sym_field_declaration_list,
  [249630] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10128), 1,
      anon_sym_LBRACE,
    STATE(1993), 1,
      sym_compound_statement,
  [249640] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6425), 1,
      anon_sym_LBRACE,
    STATE(3135), 1,
      sym_field_declaration_list,
  [249650] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12584), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [249658] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12422), 1,
      anon_sym_COMMA,
    ACTIONS(12586), 1,
      anon_sym_RBRACE,
  [249668] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12058), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [249676] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12588), 2,
      anon_sym_COMMA,
      anon_sym_LBRACE,
  [249684] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9105), 1,
      anon_sym_LBRACE,
    STATE(3577), 1,
      sym_requirement_seq,
  [249694] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6321), 1,
      anon_sym_LBRACE,
    STATE(3073), 1,
      sym_field_declaration_list,
  [249704] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    STATE(887), 1,
      sym_condition_clause,
  [249714] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      anon_sym_LBRACE,
    STATE(205), 1,
      sym_compound_statement,
  [249724] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6425), 1,
      anon_sym_LBRACE,
    STATE(3105), 1,
      sym_field_declaration_list,
  [249734] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6425), 1,
      anon_sym_LBRACE,
    STATE(3118), 1,
      sym_field_declaration_list,
  [249744] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12148), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [249752] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4384), 1,
      anon_sym_LBRACE,
    STATE(304), 1,
      sym_declaration_list,
  [249762] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11600), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [249770] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10244), 1,
      anon_sym_RBRACE,
    ACTIONS(12422), 1,
      anon_sym_COMMA,
  [249780] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12195), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [249788] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9089), 1,
      anon_sym_LBRACE,
    STATE(2810), 1,
      sym_requirement_seq,
  [249798] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      anon_sym_LBRACE,
    STATE(295), 1,
      sym_compound_statement,
  [249808] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2016), 1,
      anon_sym_LT,
    STATE(324), 1,
      sym_template_argument_list,
  [249818] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12261), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
  [249826] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11310), 1,
      anon_sym_LBRACE,
    STATE(5702), 1,
      sym_requirement_seq,
  [249836] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12590), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
  [249844] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12592), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
  [249852] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12594), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(12596), 1,
      sym_preproc_arg,
  [249862] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6425), 1,
      anon_sym_LBRACE,
    STATE(3095), 1,
      sym_field_declaration_list,
  [249872] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12598), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
  [249880] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5298), 1,
      anon_sym_LT,
    STATE(2221), 1,
      sym_template_argument_list,
  [249890] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    STATE(7823), 1,
      sym_parameter_list,
  [249900] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1980), 1,
      anon_sym_LBRACE,
    STATE(496), 1,
      sym_field_declaration_list,
  [249910] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4384), 1,
      anon_sym_LBRACE,
    STATE(266), 1,
      sym_declaration_list,
  [249920] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10293), 1,
      anon_sym_RBRACE,
    ACTIONS(12422), 1,
      anon_sym_COMMA,
  [249930] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12600), 1,
      sym_identifier,
    STATE(2893), 1,
      sym_template_type,
  [249940] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(753), 1,
      sym_compound_statement,
  [249950] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6321), 1,
      anon_sym_LBRACE,
    STATE(3042), 1,
      sym_field_declaration_list,
  [249960] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6321), 1,
      anon_sym_LBRACE,
    STATE(3044), 1,
      sym_field_declaration_list,
  [249970] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(6841), 1,
      sym_compound_statement,
  [249980] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12570), 1,
      anon_sym_LT,
    STATE(3520), 1,
      sym_template_argument_list,
  [249990] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    STATE(868), 1,
      sym_condition_clause,
  [250000] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      anon_sym_LBRACE,
    STATE(262), 1,
      sym_compound_statement,
  [250010] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    STATE(8493), 1,
      sym_argument_list,
  [250020] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(511), 1,
      sym_compound_statement,
  [250030] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10118), 1,
      anon_sym_LBRACE,
    STATE(1834), 1,
      sym_compound_statement,
  [250040] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12602), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(12604), 1,
      sym_preproc_arg,
  [250050] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    STATE(8371), 1,
      sym_argument_list,
  [250060] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1980), 1,
      anon_sym_LBRACE,
    STATE(513), 1,
      sym_field_declaration_list,
  [250070] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12422), 1,
      anon_sym_COMMA,
    ACTIONS(12606), 1,
      anon_sym_RBRACE,
  [250080] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1980), 1,
      anon_sym_LBRACE,
    STATE(516), 1,
      sym_field_declaration_list,
  [250090] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10128), 1,
      anon_sym_LBRACE,
    STATE(2117), 1,
      sym_compound_statement,
  [250100] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4384), 1,
      anon_sym_LBRACE,
    STATE(332), 1,
      sym_declaration_list,
  [250110] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12422), 1,
      anon_sym_COMMA,
    ACTIONS(12608), 1,
      anon_sym_RBRACE,
  [250120] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    STATE(7596), 1,
      sym_parameter_list,
  [250130] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12610), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(12612), 1,
      sym_preproc_arg,
  [250140] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    STATE(8233), 1,
      sym_argument_list,
  [250150] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(7021), 1,
      sym_compound_statement,
  [250160] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12428), 1,
      sym_identifier,
    STATE(7016), 1,
      sym_attribute,
  [250170] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6321), 1,
      anon_sym_LBRACE,
    STATE(3040), 1,
      sym_field_declaration_list,
  [250180] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    STATE(4848), 1,
      sym_field_declaration_list,
  [250190] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    STATE(4856), 1,
      sym_field_declaration_list,
  [250200] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      anon_sym_LBRACE,
    STATE(172), 1,
      sym_compound_statement,
  [250210] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10281), 1,
      anon_sym_RBRACE,
    ACTIONS(12422), 1,
      anon_sym_COMMA,
  [250220] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11962), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK_RBRACK,
  [250228] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11180), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12614), 1,
      anon_sym_SEMI,
  [250238] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5628), 1,
      anon_sym_LT,
    STATE(2221), 1,
      sym_template_argument_list,
  [250248] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12616), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(12618), 1,
      sym_preproc_arg,
  [250258] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(7124), 1,
      sym_compound_statement,
  [250268] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10128), 1,
      anon_sym_LBRACE,
    STATE(2113), 1,
      sym_compound_statement,
  [250278] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11414), 1,
      anon_sym_LBRACE,
    STATE(1940), 1,
      sym_requirement_seq,
  [250288] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8351), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [250296] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12538), 1,
      anon_sym_LPAREN2,
    STATE(7706), 1,
      sym_parenthesized_expression,
  [250306] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(633), 1,
      anon_sym_LBRACE,
    STATE(411), 1,
      sym_compound_statement,
  [250316] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8469), 1,
      anon_sym_LBRACE,
    STATE(4870), 1,
      sym_field_declaration_list,
  [250326] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1982), 1,
      anon_sym_LBRACE,
    STATE(409), 1,
      sym_field_declaration_list,
  [250336] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1982), 1,
      anon_sym_LBRACE,
    STATE(408), 1,
      sym_field_declaration_list,
  [250346] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12073), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [250354] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5298), 1,
      anon_sym_LT,
    STATE(2679), 1,
      sym_template_argument_list,
  [250364] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    STATE(7638), 1,
      sym_parameter_list,
  [250374] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(532), 1,
      sym_compound_statement,
  [250384] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1980), 1,
      anon_sym_LBRACE,
    STATE(533), 1,
      sym_field_declaration_list,
  [250394] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12620), 1,
      sym_identifier,
    STATE(142), 1,
      sym_template_type,
  [250404] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1980), 1,
      anon_sym_LBRACE,
    STATE(537), 1,
      sym_field_declaration_list,
  [250414] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1980), 1,
      anon_sym_LBRACE,
    STATE(539), 1,
      sym_field_declaration_list,
  [250424] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    STATE(8115), 1,
      sym_argument_list,
  [250434] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1980), 1,
      anon_sym_LBRACE,
    STATE(492), 1,
      sym_field_declaration_list,
  [250444] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(7211), 1,
      sym_compound_statement,
  [250454] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8224), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [250462] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3709), 1,
      anon_sym_LBRACE,
    STATE(1052), 1,
      sym_field_declaration_list,
  [250472] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12428), 1,
      sym_identifier,
    STATE(7228), 1,
      sym_attribute,
  [250482] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8231), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [250490] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3709), 1,
      anon_sym_LBRACE,
    STATE(1041), 1,
      sym_field_declaration_list,
  [250500] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3709), 1,
      anon_sym_LBRACE,
    STATE(1040), 1,
      sym_field_declaration_list,
  [250510] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12622), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
  [250520] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3709), 1,
      anon_sym_LBRACE,
    STATE(1039), 1,
      sym_field_declaration_list,
  [250530] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1695), 1,
      anon_sym_LBRACE,
    STATE(1038), 1,
      sym_compound_statement,
  [250540] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12538), 1,
      anon_sym_LPAREN2,
    STATE(7689), 1,
      sym_parenthesized_expression,
  [250550] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(7342), 1,
      sym_compound_statement,
  [250560] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12624), 1,
      anon_sym_LT,
    STATE(2755), 1,
      sym_template_argument_list,
  [250570] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    STATE(7694), 1,
      sym_parameter_list,
  [250580] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1695), 1,
      anon_sym_LBRACE,
    STATE(991), 1,
      sym_compound_statement,
  [250590] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1982), 1,
      anon_sym_LBRACE,
    STATE(405), 1,
      sym_field_declaration_list,
  [250600] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6594), 1,
      anon_sym_LBRACE,
    STATE(3326), 1,
      sym_field_declaration_list,
  [250610] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1982), 1,
      anon_sym_LBRACE,
    STATE(404), 1,
      sym_field_declaration_list,
  [250620] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1982), 1,
      anon_sym_LBRACE,
    STATE(403), 1,
      sym_field_declaration_list,
  [250630] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12422), 1,
      anon_sym_COMMA,
    ACTIONS(12626), 1,
      anon_sym_RBRACE,
  [250640] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4380), 1,
      anon_sym_LBRACE,
    STATE(716), 1,
      sym_declaration_list,
  [250650] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3709), 1,
      anon_sym_LBRACE,
    STATE(998), 1,
      sym_field_declaration_list,
  [250660] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3709), 1,
      anon_sym_LBRACE,
    STATE(1020), 1,
      sym_field_declaration_list,
  [250670] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1695), 1,
      anon_sym_LBRACE,
    STATE(1025), 1,
      sym_compound_statement,
  [250680] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5298), 1,
      anon_sym_LT,
    STATE(2390), 1,
      sym_template_argument_list,
  [250690] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10118), 1,
      anon_sym_LBRACE,
    STATE(1860), 1,
      sym_compound_statement,
  [250700] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(633), 1,
      anon_sym_LBRACE,
    STATE(402), 1,
      sym_compound_statement,
  [250710] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8416), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [250718] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12628), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK_RBRACK,
  [250726] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12630), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(12632), 1,
      sym_preproc_arg,
  [250736] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12634), 2,
      anon_sym_DOT_DOT_DOT,
      sym_identifier,
  [250744] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12636), 1,
      anon_sym_if,
    ACTIONS(12638), 1,
      anon_sym_for,
  [250754] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4019), 1,
      anon_sym_LBRACE,
    STATE(4823), 1,
      sym_initializer_list,
  [250764] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    STATE(8014), 1,
      sym_argument_list,
  [250774] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(7418), 1,
      sym_compound_statement,
  [250784] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6594), 1,
      anon_sym_LBRACE,
    STATE(3344), 1,
      sym_field_declaration_list,
  [250794] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6594), 1,
      anon_sym_LBRACE,
    STATE(3340), 1,
      sym_field_declaration_list,
  [250804] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12640), 1,
      sym_identifier,
    STATE(2493), 1,
      sym_template_type,
  [250814] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10259), 1,
      anon_sym_RBRACE,
    ACTIONS(12422), 1,
      anon_sym_COMMA,
  [250824] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12428), 1,
      sym_identifier,
    STATE(7384), 1,
      sym_attribute,
  [250834] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12538), 1,
      anon_sym_LPAREN2,
    STATE(7766), 1,
      sym_parenthesized_expression,
  [250844] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3709), 1,
      anon_sym_LBRACE,
    STATE(1058), 1,
      sym_field_declaration_list,
  [250854] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12422), 1,
      anon_sym_COMMA,
    ACTIONS(12642), 1,
      anon_sym_RBRACE,
  [250864] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(7277), 1,
      sym_compound_statement,
  [250874] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5817), 1,
      anon_sym_LBRACE,
    STATE(2580), 1,
      sym_field_declaration_list,
  [250884] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2000), 1,
      anon_sym_LT,
    STATE(337), 1,
      sym_template_argument_list,
  [250894] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(793), 1,
      anon_sym_LBRACE,
    STATE(443), 1,
      sym_compound_statement,
  [250904] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12644), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(12646), 1,
      sym_preproc_arg,
  [250914] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10108), 1,
      anon_sym_LBRACE,
    STATE(1990), 1,
      sym_compound_statement,
  [250924] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10118), 1,
      anon_sym_LBRACE,
    STATE(1904), 1,
      sym_compound_statement,
  [250934] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9097), 1,
      anon_sym_LBRACE,
    STATE(3688), 1,
      sym_requirement_seq,
  [250944] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    STATE(7728), 1,
      sym_parameter_list,
  [250954] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4388), 1,
      anon_sym_LBRACE,
    STATE(651), 1,
      sym_declaration_list,
  [250964] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12538), 1,
      anon_sym_LPAREN2,
    STATE(7933), 1,
      sym_parenthesized_expression,
  [250974] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6594), 1,
      anon_sym_LBRACE,
    STATE(3242), 1,
      sym_field_declaration_list,
  [250984] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12560), 1,
      anon_sym_LT,
    STATE(2679), 1,
      sym_template_argument_list,
  [250994] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9070), 1,
      anon_sym_LBRACE,
    STATE(4275), 1,
      sym_requirement_seq,
  [251004] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10108), 1,
      anon_sym_LBRACE,
    STATE(2166), 1,
      sym_compound_statement,
  [251014] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12648), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(12650), 1,
      sym_preproc_arg,
  [251024] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12652), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(12654), 1,
      sym_preproc_arg,
  [251034] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12570), 1,
      anon_sym_LT,
    STATE(2884), 1,
      sym_template_argument_list,
  [251044] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1913), 1,
      anon_sym_LBRACE,
    STATE(230), 1,
      sym_field_declaration_list,
  [251054] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4388), 1,
      anon_sym_LBRACE,
    STATE(615), 1,
      sym_declaration_list,
  [251064] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12656), 1,
      sym_identifier,
    STATE(322), 1,
      sym_template_type,
  [251074] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12658), 1,
      anon_sym_if,
    ACTIONS(12660), 1,
      anon_sym_for,
  [251084] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3675), 1,
      anon_sym_LBRACE,
    STATE(3747), 1,
      sym_initializer_list,
  [251094] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10302), 1,
      anon_sym_RBRACE,
    ACTIONS(12422), 1,
      anon_sym_COMMA,
  [251104] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(6878), 1,
      sym_compound_statement,
  [251114] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12662), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(12664), 1,
      sym_preproc_arg,
  [251124] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    STATE(2315), 1,
      sym_field_declaration_list,
  [251134] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    STATE(7851), 1,
      sym_argument_list,
  [251144] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5817), 1,
      anon_sym_LBRACE,
    STATE(2568), 1,
      sym_field_declaration_list,
  [251154] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5817), 1,
      anon_sym_LBRACE,
    STATE(2563), 1,
      sym_field_declaration_list,
  [251164] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(7148), 1,
      sym_compound_statement,
  [251174] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    STATE(7834), 1,
      sym_condition_clause,
  [251184] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1988), 1,
      anon_sym_LBRACE,
    STATE(392), 1,
      sym_field_declaration_list,
  [251194] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12428), 1,
      sym_identifier,
    STATE(7118), 1,
      sym_attribute,
  [251204] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12464), 1,
      anon_sym_LT,
    STATE(3689), 1,
      sym_template_argument_list,
  [251214] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12666), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK_RBRACK,
  [251222] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1988), 1,
      anon_sym_LBRACE,
    STATE(388), 1,
      sym_field_declaration_list,
  [251232] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1988), 1,
      anon_sym_LBRACE,
    STATE(387), 1,
      sym_field_declaration_list,
  [251242] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12428), 1,
      sym_identifier,
    STATE(7657), 1,
      sym_attribute,
  [251252] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12538), 1,
      anon_sym_LPAREN2,
    STATE(7793), 1,
      sym_parenthesized_expression,
  [251262] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10108), 1,
      anon_sym_LBRACE,
    STATE(2082), 1,
      sym_compound_statement,
  [251272] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1988), 1,
      anon_sym_LBRACE,
    STATE(386), 1,
      sym_field_declaration_list,
  [251282] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    STATE(853), 1,
      sym_condition_clause,
  [251292] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(793), 1,
      anon_sym_LBRACE,
    STATE(385), 1,
      sym_compound_statement,
  [251302] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12428), 1,
      sym_identifier,
    STATE(7268), 1,
      sym_attribute,
  [251312] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(7038), 1,
      sym_compound_statement,
  [251322] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      anon_sym_LBRACE,
    STATE(193), 1,
      sym_compound_statement,
  [251332] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    STATE(7605), 1,
      sym_condition_clause,
  [251342] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1913), 1,
      anon_sym_LBRACE,
    STATE(199), 1,
      sym_field_declaration_list,
  [251352] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    STATE(825), 1,
      sym_condition_clause,
  [251362] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1913), 1,
      anon_sym_LBRACE,
    STATE(200), 1,
      sym_field_declaration_list,
  [251372] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4388), 1,
      anon_sym_LBRACE,
    STATE(576), 1,
      sym_declaration_list,
  [251382] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12422), 1,
      anon_sym_COMMA,
    ACTIONS(12668), 1,
      anon_sym_RBRACE,
  [251392] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(7294), 1,
      sym_compound_statement,
  [251402] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    STATE(7784), 1,
      sym_parameter_list,
  [251412] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12538), 1,
      anon_sym_LPAREN2,
    STATE(7934), 1,
      sym_parenthesized_expression,
  [251422] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5817), 1,
      anon_sym_LBRACE,
    STATE(2562), 1,
      sym_field_declaration_list,
  [251432] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8147), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [251440] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12538), 1,
      anon_sym_LPAREN2,
    STATE(7970), 1,
      sym_parenthesized_expression,
  [251450] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1982), 1,
      anon_sym_LBRACE,
    STATE(466), 1,
      sym_field_declaration_list,
  [251460] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12670), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
  [251470] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(793), 1,
      anon_sym_LBRACE,
    STATE(361), 1,
      sym_compound_statement,
  [251480] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    STATE(2889), 1,
      sym_field_declaration_list,
  [251490] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11180), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12672), 1,
      anon_sym_SEMI,
  [251500] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8241), 1,
      anon_sym_RPAREN,
    ACTIONS(8243), 1,
      anon_sym_SEMI,
  [251510] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12464), 1,
      anon_sym_LT,
    STATE(3571), 1,
      sym_template_argument_list,
  [251520] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10216), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [251528] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12422), 1,
      anon_sym_COMMA,
    ACTIONS(12674), 1,
      anon_sym_RBRACE,
  [251538] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    STATE(8215), 1,
      sym_argument_list,
  [251548] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(6984), 1,
      sym_compound_statement,
  [251558] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 1,
      anon_sym_LBRACE,
    STATE(186), 1,
      sym_compound_statement,
  [251568] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1913), 1,
      anon_sym_LBRACE,
    STATE(187), 1,
      sym_field_declaration_list,
  [251578] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    STATE(823), 1,
      sym_condition_clause,
  [251588] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12676), 1,
      anon_sym_if,
    ACTIONS(12678), 1,
      anon_sym_for,
  [251598] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1988), 1,
      anon_sym_LBRACE,
    STATE(399), 1,
      sym_field_declaration_list,
  [251608] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1988), 1,
      anon_sym_LBRACE,
    STATE(418), 1,
      sym_field_declaration_list,
  [251618] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(793), 1,
      anon_sym_LBRACE,
    STATE(420), 1,
      sym_compound_statement,
  [251628] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1913), 1,
      anon_sym_LBRACE,
    STATE(195), 1,
      sym_field_declaration_list,
  [251638] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12680), 1,
      anon_sym_if,
    ACTIONS(12682), 1,
      anon_sym_for,
  [251648] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    STATE(2318), 1,
      sym_field_declaration_list,
  [251658] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(5331), 1,
      anon_sym_LBRACE,
    STATE(2317), 1,
      sym_field_declaration_list,
  [251668] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    STATE(865), 1,
      sym_condition_clause,
  [251678] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1913), 1,
      anon_sym_LBRACE,
    STATE(196), 1,
      sym_field_declaration_list,
  [251688] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(6938), 1,
      sym_compound_statement,
  [251698] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7608), 1,
      anon_sym_LPAREN2,
    STATE(7992), 1,
      sym_argument_list,
  [251708] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12684), 1,
      sym_identifier,
    STATE(2195), 1,
      sym_template_type,
  [251718] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1913), 1,
      anon_sym_LBRACE,
    STATE(215), 1,
      sym_field_declaration_list,
  [251728] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4380), 1,
      anon_sym_LBRACE,
    STATE(718), 1,
      sym_declaration_list,
  [251738] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(7155), 1,
      sym_compound_statement,
  [251748] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    STATE(849), 1,
      sym_condition_clause,
  [251758] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    STATE(7726), 1,
      sym_condition_clause,
  [251768] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12428), 1,
      sym_identifier,
    STATE(7171), 1,
      sym_attribute,
  [251778] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12686), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(12688), 1,
      sym_preproc_arg,
  [251788] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    STATE(2911), 1,
      sym_field_declaration_list,
  [251798] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    STATE(2907), 1,
      sym_field_declaration_list,
  [251808] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3741), 1,
      anon_sym_LBRACE,
    STATE(3855), 1,
      sym_initializer_list,
  [251818] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11763), 2,
      anon_sym_SEMI,
      anon_sym_LBRACE,
  [251826] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10242), 1,
      anon_sym_RBRACE,
    ACTIONS(12422), 1,
      anon_sym_COMMA,
  [251836] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12690), 1,
      sym_identifier,
    STATE(331), 1,
      sym_template_type,
  [251846] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11180), 1,
      anon_sym_COLON_COLON,
    ACTIONS(12692), 1,
      anon_sym_SEMI,
  [251856] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(377), 1,
      sym_compound_statement,
  [251866] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12538), 1,
      anon_sym_LPAREN2,
    STATE(7673), 1,
      sym_parenthesized_expression,
  [251876] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12538), 1,
      anon_sym_LPAREN2,
    STATE(8118), 1,
      sym_parenthesized_expression,
  [251886] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1988), 1,
      anon_sym_LBRACE,
    STATE(430), 1,
      sym_field_declaration_list,
  [251896] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9124), 1,
      anon_sym_LPAREN2,
    STATE(7655), 1,
      sym_parameter_list,
  [251906] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12560), 1,
      anon_sym_LT,
    STATE(2489), 1,
      sym_template_argument_list,
  [251916] = 3,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12694), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(12696), 1,
      sym_preproc_arg,
  [251926] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12698), 2,
      anon_sym_COMMA,
      anon_sym_GT2,
  [251934] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(793), 1,
      anon_sym_LBRACE,
    STATE(654), 1,
      sym_compound_statement,
  [251944] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9081), 1,
      anon_sym_LBRACE,
    STATE(3953), 1,
      sym_requirement_seq,
  [251954] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_LBRACE,
    STATE(7282), 1,
      sym_compound_statement,
  [251964] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1695), 1,
      anon_sym_LBRACE,
    STATE(1003), 1,
      sym_compound_statement,
  [251974] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6286), 1,
      anon_sym_LBRACE,
    STATE(2886), 1,
      sym_field_declaration_list,
  [251984] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_LPAREN2,
    STATE(851), 1,
      sym_condition_clause,
  [251994] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12700), 1,
      sym_identifier,
  [252001] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12702), 1,
      anon_sym_DQUOTE,
  [252008] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10713), 1,
      anon_sym_SEMI,
  [252015] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7238), 1,
      sym_identifier,
  [252022] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12704), 1,
      anon_sym_RPAREN,
  [252029] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12706), 1,
      anon_sym_SEMI,
  [252036] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8357), 1,
      anon_sym_COLON,
  [252043] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12708), 1,
      anon_sym_DQUOTE,
  [252050] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12710), 1,
      aux_sym_preproc_include_token2,
  [252057] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12712), 1,
      anon_sym_RPAREN,
  [252064] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12714), 1,
      anon_sym_RPAREN,
  [252071] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10306), 1,
      anon_sym_RBRACE,
  [252078] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8341), 1,
      anon_sym_SEMI,
  [252085] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12716), 1,
      anon_sym_SEMI,
  [252092] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12718), 1,
      anon_sym_RPAREN,
  [252099] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12720), 1,
      anon_sym_SEMI,
  [252106] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12722), 1,
      anon_sym_RPAREN,
  [252113] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12724), 1,
      sym_identifier,
  [252120] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8583), 1,
      anon_sym_RPAREN,
  [252127] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8273), 1,
      anon_sym_RBRACE,
  [252134] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12726), 1,
      anon_sym_RPAREN,
  [252141] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12728), 1,
      sym_identifier,
  [252148] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12730), 1,
      anon_sym_RPAREN,
  [252155] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12732), 1,
      sym_identifier,
  [252162] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12734), 1,
      anon_sym_RPAREN,
  [252169] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12736), 1,
      anon_sym_RPAREN,
  [252176] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12738), 1,
      anon_sym_SEMI,
  [252183] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12740), 1,
      anon_sym_RPAREN,
  [252190] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12742), 1,
      sym_identifier,
  [252197] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12744), 1,
      aux_sym_preproc_include_token2,
  [252204] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10224), 1,
      anon_sym_RPAREN,
  [252211] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12746), 1,
      sym_identifier,
  [252218] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12748), 1,
      sym_raw_string_delimiter,
  [252225] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10242), 1,
      anon_sym_RBRACE,
  [252232] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12750), 1,
      anon_sym_SEMI,
  [252239] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12752), 1,
      anon_sym_SEMI,
  [252246] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12754), 1,
      anon_sym_RPAREN,
  [252253] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12756), 1,
      anon_sym_SEMI,
  [252260] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12758), 1,
      anon_sym_SEMI,
  [252267] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12760), 1,
      anon_sym_DQUOTE,
  [252274] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12762), 1,
      anon_sym_COLON,
  [252281] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12764), 1,
      anon_sym_LBRACE,
  [252288] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12766), 1,
      sym_identifier,
  [252295] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4649), 1,
      anon_sym_DOT_DOT_DOT,
  [252302] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4526), 1,
      anon_sym_DOT_DOT_DOT,
  [252309] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4623), 1,
      anon_sym_DOT_DOT_DOT,
  [252316] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4545), 1,
      anon_sym_DOT_DOT_DOT,
  [252323] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4523), 1,
      anon_sym_DOT_DOT_DOT,
  [252330] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4516), 1,
      anon_sym_DOT_DOT_DOT,
  [252337] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4584), 1,
      anon_sym_DOT_DOT_DOT,
  [252344] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4587), 1,
      anon_sym_DOT_DOT_DOT,
  [252351] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12768), 1,
      sym_identifier,
  [252358] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12770), 1,
      sym_identifier,
  [252365] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4600), 1,
      anon_sym_DOT_DOT_DOT,
  [252372] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12772), 1,
      sym_identifier,
  [252379] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12774), 1,
      anon_sym_RPAREN,
  [252386] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8022), 1,
      anon_sym_RBRACE,
  [252393] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4603), 1,
      anon_sym_DOT_DOT_DOT,
  [252400] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12776), 1,
      anon_sym_RPAREN,
  [252407] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8623), 1,
      anon_sym_RPAREN,
  [252414] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12778), 1,
      anon_sym_RPAREN,
  [252421] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12780), 1,
      sym_identifier,
  [252428] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12782), 1,
      anon_sym_RPAREN,
  [252435] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12784), 1,
      anon_sym_RPAREN,
  [252442] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12786), 1,
      anon_sym_COLON,
  [252449] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12788), 1,
      anon_sym_DQUOTE,
  [252456] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12790), 1,
      anon_sym_RPAREN,
  [252463] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12792), 1,
      anon_sym_SEMI,
  [252470] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12794), 1,
      anon_sym_STAR,
  [252477] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12796), 1,
      anon_sym_LPAREN2,
  [252484] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4620), 1,
      anon_sym_DOT_DOT_DOT,
  [252491] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11306), 1,
      anon_sym_SEMI,
  [252498] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT_DOT_DOT,
  [252505] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12798), 1,
      anon_sym_SEMI,
  [252512] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12800), 1,
      anon_sym_RPAREN,
  [252519] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8349), 1,
      anon_sym_SEMI,
  [252526] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12802), 1,
      anon_sym_SEMI,
  [252533] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12804), 1,
      anon_sym_SEMI,
  [252540] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12806), 1,
      anon_sym_SEMI,
  [252547] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12808), 1,
      sym_auto,
  [252554] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8386), 1,
      anon_sym_COLON,
  [252561] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12810), 1,
      aux_sym_preproc_include_token2,
  [252568] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12812), 1,
      sym_identifier,
  [252575] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8337), 1,
      anon_sym_SEMI,
  [252582] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12814), 1,
      aux_sym_preproc_if_token2,
  [252589] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12674), 1,
      anon_sym_RBRACE,
  [252596] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12816), 1,
      anon_sym_SEMI,
  [252603] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12818), 1,
      anon_sym_SEMI,
  [252610] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12820), 1,
      anon_sym_SEMI,
  [252617] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12822), 1,
      anon_sym_LPAREN2,
  [252624] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12824), 1,
      sym_identifier,
  [252631] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12826), 1,
      anon_sym_SEMI,
  [252638] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12828), 1,
      anon_sym_SEMI,
  [252645] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8241), 1,
      anon_sym_RPAREN,
  [252652] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12830), 1,
      anon_sym_RPAREN,
  [252659] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12832), 1,
      anon_sym_RPAREN,
  [252666] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12834), 1,
      anon_sym_SEMI,
  [252673] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12836), 1,
      anon_sym_SEMI,
  [252680] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12838), 1,
      anon_sym_STAR,
  [252687] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12840), 1,
      anon_sym_SEMI,
  [252694] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12842), 1,
      anon_sym_RPAREN,
  [252701] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12844), 1,
      anon_sym_RPAREN,
  [252708] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12846), 1,
      sym_identifier,
  [252715] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12848), 1,
      aux_sym_preproc_include_token2,
  [252722] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8384), 1,
      anon_sym_SEMI,
  [252729] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12668), 1,
      anon_sym_RBRACE,
  [252736] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12850), 1,
      anon_sym_SEMI,
  [252743] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12852), 1,
      anon_sym_RPAREN,
  [252750] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12854), 1,
      anon_sym_SEMI,
  [252757] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12856), 1,
      anon_sym_RPAREN,
  [252764] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12858), 1,
      sym_identifier,
  [252771] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12860), 1,
      anon_sym_RPAREN,
  [252778] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12862), 1,
      anon_sym_DQUOTE,
  [252785] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12642), 1,
      anon_sym_RBRACE,
  [252792] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8404), 1,
      anon_sym_SEMI,
  [252799] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12864), 1,
      aux_sym_preproc_if_token2,
  [252806] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12866), 1,
      aux_sym_preproc_if_token2,
  [252813] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12868), 1,
      aux_sym_preproc_include_token2,
  [252820] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12870), 1,
      anon_sym_RPAREN,
  [252827] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12872), 1,
      sym_identifier,
  [252834] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8428), 1,
      anon_sym_COLON,
  [252841] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12874), 1,
      sym_auto,
  [252848] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12876), 1,
      anon_sym_SEMI,
  [252855] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12878), 1,
      sym_identifier,
  [252862] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12880), 1,
      sym_identifier,
  [252869] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12882), 1,
      sym_identifier,
  [252876] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12884), 1,
      anon_sym_RPAREN,
  [252883] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4828), 1,
      anon_sym_SEMI,
  [252890] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10248), 1,
      anon_sym_RPAREN,
  [252897] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12886), 1,
      anon_sym_SEMI,
  [252904] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12888), 1,
      sym_raw_string_delimiter,
  [252911] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12890), 1,
      sym_identifier,
  [252918] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12892), 1,
      sym_identifier,
  [252925] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12894), 1,
      anon_sym_SEMI,
  [252932] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12896), 1,
      anon_sym_RPAREN,
  [252939] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12898), 1,
      anon_sym_SEMI,
  [252946] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11500), 1,
      anon_sym_SEMI,
  [252953] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12900), 1,
      sym_identifier,
  [252960] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12902), 1,
      anon_sym_RPAREN,
  [252967] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12904), 1,
      anon_sym_SEMI,
  [252974] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12906), 1,
      anon_sym_RPAREN,
  [252981] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12908), 1,
      anon_sym_RPAREN,
  [252988] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12910), 1,
      anon_sym_RPAREN,
  [252995] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12912), 1,
      anon_sym_STAR,
  [253002] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12914), 1,
      anon_sym_DQUOTE,
  [253009] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12916), 1,
      anon_sym_RPAREN,
  [253016] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10302), 1,
      anon_sym_RBRACE,
  [253023] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12918), 1,
      anon_sym_RPAREN,
  [253030] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8424), 1,
      anon_sym_RPAREN,
  [253037] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12920), 1,
      anon_sym_STAR,
  [253044] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12922), 1,
      anon_sym_SEMI,
  [253051] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8177), 1,
      anon_sym_RBRACE,
  [253058] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8661), 1,
      anon_sym_RPAREN,
  [253065] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12924), 1,
      aux_sym_preproc_include_token2,
  [253072] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12926), 1,
      anon_sym_SEMI,
  [253079] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12928), 1,
      anon_sym_RPAREN,
  [253086] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12930), 1,
      anon_sym_RPAREN,
  [253093] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12932), 1,
      aux_sym_preproc_if_token2,
  [253100] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12934), 1,
      anon_sym_RPAREN,
  [253107] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12936), 1,
      anon_sym_LPAREN2,
  [253114] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12938), 1,
      anon_sym_RPAREN,
  [253121] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12940), 1,
      anon_sym_STAR,
  [253128] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12942), 1,
      anon_sym_RPAREN,
  [253135] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12944), 1,
      sym_identifier,
  [253142] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12946), 1,
      anon_sym_RPAREN,
  [253149] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10775), 1,
      anon_sym_SEMI,
  [253156] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8243), 1,
      anon_sym_SEMI,
  [253163] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12948), 1,
      sym_identifier,
  [253170] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7320), 1,
      sym_identifier,
  [253177] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12950), 1,
      anon_sym_RPAREN,
  [253184] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6282), 1,
      sym_identifier,
  [253191] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12952), 1,
      anon_sym_SEMI,
  [253198] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8463), 1,
      anon_sym_SEMI,
  [253205] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12954), 1,
      anon_sym_RPAREN,
  [253212] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10721), 1,
      anon_sym_SEMI,
  [253219] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12956), 1,
      anon_sym_COMMA,
  [253226] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12958), 1,
      anon_sym_RPAREN,
  [253233] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12960), 1,
      anon_sym_RPAREN,
  [253240] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8473), 1,
      anon_sym_SEMI,
  [253247] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12962), 1,
      anon_sym_SEMI,
  [253254] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12964), 1,
      anon_sym_SEMI,
  [253261] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12966), 1,
      anon_sym_STAR,
  [253268] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8335), 1,
      anon_sym_SEMI,
  [253275] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12968), 1,
      sym_identifier,
  [253282] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12970), 1,
      anon_sym_RPAREN,
  [253289] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12972), 1,
      sym_identifier,
  [253296] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12974), 1,
      anon_sym_DOT_DOT_DOT,
  [253303] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12976), 1,
      anon_sym_DOT_DOT_DOT,
  [253310] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12979), 1,
      anon_sym_RPAREN,
  [253317] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10269), 1,
      anon_sym_RPAREN,
  [253324] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12981), 1,
      anon_sym_RPAREN,
  [253331] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12983), 1,
      sym_raw_string_delimiter,
  [253338] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12985), 1,
      anon_sym_RPAREN,
  [253345] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12987), 1,
      sym_identifier,
  [253352] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8515), 1,
      anon_sym_RPAREN,
  [253359] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8173), 1,
      anon_sym_RBRACE,
  [253366] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10259), 1,
      anon_sym_RBRACE,
  [253373] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12989), 1,
      aux_sym_preproc_include_token2,
  [253380] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9468), 1,
      aux_sym_preproc_include_token2,
  [253387] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11929), 1,
      aux_sym_preproc_include_token2,
  [253394] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12991), 1,
      anon_sym_RPAREN,
  [253401] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12993), 1,
      anon_sym_RPAREN,
  [253408] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12995), 1,
      anon_sym_RPAREN,
  [253415] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11236), 1,
      anon_sym_SEMI,
  [253422] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12997), 1,
      anon_sym_SEMI,
  [253429] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12999), 1,
      aux_sym_preproc_if_token2,
  [253436] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13001), 1,
      anon_sym_SEMI,
  [253443] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13003), 1,
      anon_sym_SEMI,
  [253450] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13005), 1,
      aux_sym_preproc_if_token2,
  [253457] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13007), 1,
      anon_sym_COLON,
  [253464] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13009), 1,
      anon_sym_RPAREN,
  [253471] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13011), 1,
      anon_sym_LPAREN2,
  [253478] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4811), 1,
      anon_sym_SEMI,
  [253485] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13013), 1,
      anon_sym_SEMI,
  [253492] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13015), 1,
      sym_auto,
  [253499] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8467), 1,
      anon_sym_COLON,
  [253506] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(13017), 1,
      aux_sym_preproc_include_token2,
  [253513] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12626), 1,
      anon_sym_RBRACE,
  [253520] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13019), 1,
      sym_identifier,
  [253527] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13021), 1,
      anon_sym_SEMI,
  [253534] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13023), 1,
      anon_sym_RPAREN,
  [253541] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13025), 1,
      aux_sym_preproc_if_token2,
  [253548] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13027), 1,
      anon_sym_RPAREN,
  [253555] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13029), 1,
      sym_identifier,
  [253562] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13031), 1,
      anon_sym_RPAREN,
  [253569] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13033), 1,
      anon_sym_SEMI,
  [253576] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13035), 1,
      anon_sym_SEMI,
  [253583] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12422), 1,
      anon_sym_COMMA,
  [253590] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13037), 1,
      anon_sym_SEMI,
  [253597] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13039), 1,
      anon_sym_SEMI,
  [253604] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13041), 1,
      anon_sym_SEMI,
  [253611] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13043), 1,
      anon_sym_SEMI,
  [253618] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13045), 1,
      anon_sym_SEMI,
  [253625] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13047), 1,
      anon_sym_SEMI,
  [253632] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13049), 1,
      aux_sym_preproc_if_token2,
  [253639] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13051), 1,
      anon_sym_DQUOTE,
  [253646] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13053), 1,
      anon_sym_DQUOTE,
  [253653] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13055), 1,
      anon_sym_SEMI,
  [253660] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13057), 1,
      anon_sym_RPAREN,
  [253667] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13059), 1,
      anon_sym_SEMI,
  [253674] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10267), 1,
      anon_sym_RPAREN,
  [253681] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13061), 1,
      anon_sym_SEMI,
  [253688] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13063), 1,
      sym_raw_string_delimiter,
  [253695] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13065), 1,
      anon_sym_SEMI,
  [253702] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13067), 1,
      sym_identifier,
  [253709] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13069), 1,
      anon_sym_RPAREN,
  [253716] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13071), 1,
      anon_sym_SEMI,
  [253723] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13073), 1,
      anon_sym_SEMI,
  [253730] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13075), 1,
      aux_sym_preproc_if_token2,
  [253737] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13077), 1,
      aux_sym_preproc_if_token2,
  [253744] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(13079), 1,
      aux_sym_preproc_include_token2,
  [253751] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13081), 1,
      anon_sym_RPAREN,
  [253758] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13083), 1,
      anon_sym_SEMI,
  [253765] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13085), 1,
      anon_sym_RPAREN,
  [253772] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13087), 1,
      anon_sym_SEMI,
  [253779] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13089), 1,
      sym_identifier,
  [253786] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13091), 1,
      aux_sym_preproc_if_token2,
  [253793] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13093), 1,
      aux_sym_preproc_if_token2,
  [253800] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13095), 1,
      aux_sym_preproc_if_token2,
  [253807] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13097), 1,
      anon_sym_LPAREN2,
  [253814] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13099), 1,
      anon_sym_RPAREN,
  [253821] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13101), 1,
      anon_sym_DQUOTE,
  [253828] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(13103), 1,
      aux_sym_preproc_include_token2,
  [253835] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13105), 1,
      anon_sym_RPAREN,
  [253842] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13107), 1,
      aux_sym_preproc_if_token2,
  [253849] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13109), 1,
      anon_sym_RPAREN,
  [253856] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13111), 1,
      anon_sym_RPAREN,
  [253863] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13113), 1,
      anon_sym_RPAREN,
  [253870] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13115), 1,
      sym_identifier,
  [253877] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13117), 1,
      anon_sym_RPAREN,
  [253884] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13119), 1,
      anon_sym_RPAREN,
  [253891] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13121), 1,
      anon_sym_RPAREN,
  [253898] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10789), 1,
      anon_sym_SEMI,
  [253905] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13123), 1,
      anon_sym_DQUOTE,
  [253912] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13125), 1,
      anon_sym_SEMI,
  [253919] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13127), 1,
      anon_sym_SEMI,
  [253926] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13129), 1,
      anon_sym_SEMI,
  [253933] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(13131), 1,
      aux_sym_preproc_include_token2,
  [253940] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13133), 1,
      anon_sym_RPAREN,
  [253947] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13135), 1,
      sym_identifier,
  [253954] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13137), 1,
      anon_sym_RPAREN,
  [253961] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13139), 1,
      anon_sym_SEMI,
  [253968] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10273), 1,
      anon_sym_RPAREN,
  [253975] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10281), 1,
      anon_sym_RBRACE,
  [253982] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13141), 1,
      sym_raw_string_delimiter,
  [253989] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13143), 1,
      anon_sym_RPAREN,
  [253996] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13145), 1,
      anon_sym_SEMI,
  [254003] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13147), 1,
      anon_sym_RPAREN,
  [254010] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13149), 1,
      anon_sym_SEMI,
  [254017] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11379), 1,
      anon_sym_SEMI,
  [254024] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13151), 1,
      anon_sym_SEMI,
  [254031] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13153), 1,
      anon_sym_LPAREN2,
  [254038] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12608), 1,
      anon_sym_RBRACE,
  [254045] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4824), 1,
      anon_sym_SEMI,
  [254052] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(13155), 1,
      aux_sym_preproc_include_token2,
  [254059] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13157), 1,
      anon_sym_RPAREN,
  [254066] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13159), 1,
      anon_sym_SEMI,
  [254073] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9376), 1,
      aux_sym_preproc_include_token2,
  [254080] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13161), 1,
      sym_auto,
  [254087] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13163), 1,
      sym_raw_string_delimiter,
  [254094] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8406), 1,
      anon_sym_COLON,
  [254101] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(13165), 1,
      aux_sym_preproc_include_token2,
  [254108] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12606), 1,
      anon_sym_RBRACE,
  [254115] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13167), 1,
      anon_sym_SEMI,
  [254122] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13169), 1,
      anon_sym_LPAREN2,
  [254129] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13171), 1,
      sym_identifier,
  [254136] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13173), 1,
      aux_sym_preproc_if_token2,
  [254143] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13175), 1,
      anon_sym_RPAREN,
  [254150] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13177), 1,
      aux_sym_preproc_if_token2,
  [254157] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13179), 1,
      aux_sym_preproc_if_token2,
  [254164] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13181), 1,
      sym_raw_string_delimiter,
  [254171] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(13183), 1,
      aux_sym_preproc_include_token2,
  [254178] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13185), 1,
      anon_sym_SEMI,
  [254185] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13187), 1,
      anon_sym_LPAREN2,
  [254192] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13189), 1,
      anon_sym_LPAREN2,
  [254199] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13191), 1,
      anon_sym_RPAREN,
  [254206] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13193), 1,
      sym_raw_string_delimiter,
  [254213] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13195), 1,
      anon_sym_SEMI,
  [254220] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13197), 1,
      anon_sym_RPAREN,
  [254227] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13199), 1,
      sym_raw_string_delimiter,
  [254234] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13201), 1,
      anon_sym_DQUOTE,
  [254241] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13203), 1,
      anon_sym_RPAREN,
  [254248] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13205), 1,
      sym_raw_string_delimiter,
  [254255] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13207), 1,
      anon_sym_RPAREN,
  [254262] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13209), 1,
      sym_raw_string_delimiter,
  [254269] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13211), 1,
      anon_sym_RPAREN,
  [254276] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13213), 1,
      sym_raw_string_delimiter,
  [254283] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13215), 1,
      anon_sym_RPAREN,
  [254290] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13217), 1,
      sym_raw_string_delimiter,
  [254297] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13219), 1,
      anon_sym_RPAREN,
  [254304] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13221), 1,
      sym_raw_string_delimiter,
  [254311] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13223), 1,
      anon_sym_RPAREN,
  [254318] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13225), 1,
      sym_raw_string_delimiter,
  [254325] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8443), 1,
      anon_sym_COLON,
  [254332] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13227), 1,
      anon_sym_SEMI,
  [254339] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13229), 1,
      sym_auto,
  [254346] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13231), 1,
      anon_sym_LPAREN2,
  [254353] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13233), 1,
      anon_sym_SEMI,
  [254360] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13235), 1,
      anon_sym_LPAREN2,
  [254367] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13237), 1,
      anon_sym_LPAREN2,
  [254374] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13239), 1,
      anon_sym_LPAREN2,
  [254381] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13241), 1,
      anon_sym_SEMI,
  [254388] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13243), 1,
      anon_sym_STAR,
  [254395] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13245), 1,
      anon_sym_LPAREN2,
  [254402] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13247), 1,
      anon_sym_SEMI,
  [254409] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13249), 1,
      anon_sym_LPAREN2,
  [254416] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_CARET_EQ,
  [254423] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8455), 1,
      anon_sym_RPAREN,
  [254430] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11395), 1,
      anon_sym_SEMI,
  [254437] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8457), 1,
      anon_sym_RPAREN,
  [254444] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13253), 1,
      anon_sym_RPAREN,
  [254451] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13255), 1,
      anon_sym_RPAREN,
  [254458] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8465), 1,
      anon_sym_SEMI,
  [254465] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13257), 1,
      anon_sym_RPAREN,
  [254472] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13259), 1,
      anon_sym_RPAREN,
  [254479] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_GT_GT_EQ,
  [254486] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13261), 1,
      anon_sym_SEMI,
  [254493] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13263), 1,
      anon_sym_RPAREN,
  [254500] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13265), 1,
      anon_sym_RPAREN,
  [254507] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13267), 1,
      anon_sym_while,
  [254514] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13269), 1,
      anon_sym_DQUOTE,
  [254521] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13271), 1,
      anon_sym_LPAREN2,
  [254528] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13273), 1,
      anon_sym_LPAREN2,
  [254535] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13275), 1,
      anon_sym_SEMI,
  [254542] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13277), 1,
      anon_sym_RPAREN,
  [254549] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13279), 1,
      anon_sym_COLON,
  [254556] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13281), 1,
      anon_sym_COLON,
  [254563] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13283), 1,
      anon_sym_EQ,
  [254570] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13285), 1,
      sym_raw_string_content,
  [254577] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10293), 1,
      anon_sym_RBRACE,
  [254584] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13287), 1,
      anon_sym_RPAREN,
  [254591] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8079), 1,
      anon_sym_RBRACE,
  [254598] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13289), 1,
      anon_sym_STAR,
  [254605] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13291), 1,
      anon_sym_LPAREN2,
  [254612] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8489), 1,
      anon_sym_RPAREN,
  [254619] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13293), 1,
      anon_sym_RPAREN,
  [254626] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13295), 1,
      anon_sym_RPAREN,
  [254633] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13297), 1,
      anon_sym_LPAREN2,
  [254640] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13299), 1,
      anon_sym_RPAREN,
  [254647] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13301), 1,
      anon_sym_RPAREN,
  [254654] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13303), 1,
      anon_sym_RPAREN,
  [254661] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13305), 1,
      aux_sym_preproc_if_token2,
  [254668] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13307), 1,
      anon_sym_RPAREN,
  [254675] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(13309), 1,
      aux_sym_preproc_include_token2,
  [254682] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13311), 1,
      sym_identifier,
  [254689] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13313), 1,
      anon_sym_RPAREN,
  [254696] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13315), 1,
      anon_sym_COMMA,
  [254703] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_DASH_GT_STAR,
  [254710] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13317), 1,
      anon_sym_STAR,
  [254717] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_DOT_STAR,
  [254724] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_not_eq,
  [254731] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8432), 1,
      anon_sym_COLON,
  [254738] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13319), 1,
      sym_identifier,
  [254745] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10279), 1,
      anon_sym_RPAREN,
  [254752] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_bitand,
  [254759] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13321), 1,
      sym_raw_string_delimiter,
  [254766] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13323), 1,
      anon_sym_RPAREN,
  [254773] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_xor,
  [254780] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13325), 1,
      anon_sym_LBRACE,
  [254787] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10771), 1,
      anon_sym_SEMI,
  [254794] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_bitor,
  [254801] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7081), 1,
      sym_identifier,
  [254808] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10244), 1,
      anon_sym_RBRACE,
  [254815] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13327), 1,
      anon_sym_SEMI,
  [254822] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13329), 1,
      anon_sym_RPAREN,
  [254829] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8394), 1,
      anon_sym_SEMI,
  [254836] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_and,
  [254843] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13331), 1,
      anon_sym_RPAREN,
  [254850] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13333), 1,
      anon_sym_RPAREN,
  [254857] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13335), 1,
      anon_sym_COLON,
  [254864] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8371), 1,
      anon_sym_SEMI,
  [254871] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_or,
  [254878] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13337), 1,
      anon_sym_SEMI,
  [254885] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10795), 1,
      anon_sym_COMMA,
  [254892] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13339), 1,
      anon_sym_SEMI,
  [254899] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_PIPE_EQ,
  [254906] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13341), 1,
      sym_identifier,
  [254913] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13343), 1,
      sym_auto,
  [254920] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8345), 1,
      anon_sym_COLON,
  [254927] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13345), 1,
      anon_sym_RPAREN,
  [254934] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13347), 1,
      anon_sym_RPAREN,
  [254941] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13349), 1,
      anon_sym_RPAREN,
  [254948] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13351), 1,
      anon_sym_RPAREN,
  [254955] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13353), 1,
      sym_raw_string_content,
  [254962] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13355), 1,
      anon_sym_RPAREN,
  [254969] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6912), 1,
      anon_sym_RPAREN,
  [254976] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12586), 1,
      anon_sym_RBRACE,
  [254983] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13357), 1,
      anon_sym_LPAREN2,
  [254990] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13359), 1,
      anon_sym_DQUOTE,
  [254997] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(13361), 1,
      aux_sym_preproc_include_token2,
  [255004] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(12029), 1,
      aux_sym_preproc_include_token2,
  [255011] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13363), 1,
      anon_sym_SEMI,
  [255018] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9492), 1,
      aux_sym_preproc_include_token2,
  [255025] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13365), 1,
      anon_sym_SEMI,
  [255032] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13367), 1,
      anon_sym_SEMI,
  [255039] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13369), 1,
      sym_raw_string_delimiter,
  [255046] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13371), 1,
      anon_sym_COLON,
  [255053] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13373), 1,
      sym_identifier,
  [255060] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10283), 1,
      anon_sym_RPAREN,
  [255067] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11572), 1,
      anon_sym_SEMI,
  [255074] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13375), 1,
      aux_sym_preproc_if_token2,
  [255081] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13377), 1,
      aux_sym_preproc_if_token2,
  [255088] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_PIPE,
  [255095] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13379), 1,
      aux_sym_preproc_if_token2,
  [255102] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13381), 1,
      aux_sym_preproc_if_token2,
  [255109] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13383), 1,
      anon_sym_RBRACE,
  [255116] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13385), 1,
      sym_identifier,
  [255123] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13387), 1,
      aux_sym_preproc_if_token2,
  [255130] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13389), 1,
      anon_sym_SEMI,
  [255137] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13391), 1,
      anon_sym_RBRACE,
  [255144] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13393), 1,
      aux_sym_preproc_if_token2,
  [255151] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_AMP_EQ,
  [255158] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13395), 1,
      sym_identifier,
  [255165] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13397), 1,
      aux_sym_preproc_if_token2,
  [255172] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13399), 1,
      aux_sym_preproc_if_token2,
  [255179] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13401), 1,
      anon_sym_SEMI,
  [255186] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13403), 1,
      anon_sym_EQ,
  [255193] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10709), 1,
      anon_sym_SEMI,
  [255200] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13405), 1,
      anon_sym_SEMI,
  [255207] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13407), 1,
      anon_sym_SEMI,
  [255214] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13409), 1,
      anon_sym_RPAREN,
  [255221] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11602), 1,
      anon_sym_COLON_COLON,
  [255228] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12362), 1,
      anon_sym_RPAREN,
  [255235] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8451), 1,
      anon_sym_RPAREN,
  [255242] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8449), 1,
      anon_sym_RPAREN,
  [255249] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13411), 1,
      sym_identifier,
  [255256] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7990), 1,
      anon_sym_RPAREN,
  [255263] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8447), 1,
      anon_sym_RPAREN,
  [255270] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13413), 1,
      anon_sym_RBRACK,
  [255277] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13415), 1,
      anon_sym_RPAREN,
  [255284] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10207), 1,
      sym_identifier,
  [255291] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13417), 1,
      anon_sym_SEMI,
  [255298] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13419), 1,
      anon_sym_SEMI,
  [255305] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13421), 1,
      anon_sym_RPAREN,
  [255312] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13423), 1,
      anon_sym_SEMI,
  [255319] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13425), 1,
      anon_sym_SEMI,
  [255326] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13427), 1,
      anon_sym_SEMI,
  [255333] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13429), 1,
      anon_sym_SEMI,
  [255340] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13431), 1,
      aux_sym_preproc_if_token2,
  [255347] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13433), 1,
      anon_sym_DQUOTE,
  [255354] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13435), 1,
      anon_sym_SEMI,
  [255361] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13437), 1,
      anon_sym_SEMI,
  [255368] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13439), 1,
      anon_sym_SEMI,
  [255375] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_STAR_EQ,
  [255382] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13441), 1,
      sym_identifier,
  [255389] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13443), 1,
      sym_identifier,
  [255396] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13445), 1,
      aux_sym_preproc_if_token2,
  [255403] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13447), 1,
      anon_sym_LPAREN2,
  [255410] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13449), 1,
      aux_sym_preproc_if_token2,
  [255417] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_LT_LT_EQ,
  [255424] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13451), 1,
      anon_sym_SEMI,
  [255431] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13453), 1,
      anon_sym_RPAREN,
  [255438] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13455), 1,
      anon_sym_SEMI,
  [255445] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13457), 1,
      anon_sym_SEMI,
  [255452] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13459), 1,
      anon_sym_DQUOTE,
  [255459] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_DASH_EQ,
  [255466] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13461), 1,
      aux_sym_preproc_if_token2,
  [255473] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11628), 1,
      anon_sym_SEMI,
  [255480] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13463), 1,
      anon_sym_RPAREN,
  [255487] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13465), 1,
      anon_sym_RPAREN,
  [255494] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13467), 1,
      anon_sym_RPAREN,
  [255501] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_PLUS_EQ,
  [255508] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13469), 1,
      sym_raw_string_content,
  [255515] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_PERCENT_EQ,
  [255522] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13471), 1,
      aux_sym_preproc_if_token2,
  [255529] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13473), 1,
      anon_sym_RPAREN,
  [255536] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13475), 1,
      anon_sym_RPAREN,
  [255543] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13477), 1,
      aux_sym_preproc_if_token2,
  [255550] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13479), 1,
      sym_identifier,
  [255557] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13481), 1,
      anon_sym_STAR,
  [255564] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13483), 1,
      anon_sym_RBRACE,
  [255571] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13485), 1,
      anon_sym_DQUOTE,
  [255578] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13487), 1,
      anon_sym_SEMI,
  [255585] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13489), 1,
      anon_sym_LPAREN2,
  [255592] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13491), 1,
      anon_sym_SEMI,
  [255599] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13493), 1,
      anon_sym_RPAREN,
  [255606] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8339), 1,
      anon_sym_SEMI,
  [255613] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13495), 1,
      anon_sym_SEMI,
  [255620] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13497), 1,
      anon_sym_SEMI,
  [255627] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13499), 1,
      anon_sym_LBRACE,
  [255634] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_SLASH_EQ,
  [255641] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13501), 1,
      aux_sym_preproc_if_token2,
  [255648] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13503), 1,
      anon_sym_RBRACE,
  [255655] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13505), 1,
      anon_sym_RPAREN,
  [255662] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13507), 1,
      aux_sym_preproc_if_token2,
  [255669] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13509), 1,
      anon_sym_SEMI,
  [255676] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13511), 1,
      aux_sym_preproc_if_token2,
  [255683] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13513), 1,
      anon_sym_STAR,
  [255690] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13515), 1,
      anon_sym_SEMI,
  [255697] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13517), 1,
      anon_sym_SEMI,
  [255704] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_LT,
  [255711] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13519), 1,
      aux_sym_preproc_if_token2,
  [255718] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12562), 1,
      anon_sym_RBRACE,
  [255725] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8627), 1,
      anon_sym_RPAREN,
  [255732] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13521), 1,
      anon_sym_RPAREN,
  [255739] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13523), 1,
      anon_sym_while,
  [255746] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10304), 1,
      anon_sym_RBRACE,
  [255753] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_EQ,
  [255760] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13525), 1,
      anon_sym_LPAREN2,
  [255767] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13527), 1,
      anon_sym_LPAREN2,
  [255774] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13529), 1,
      anon_sym_LPAREN2,
  [255781] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13531), 1,
      anon_sym_LPAREN2,
  [255788] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13533), 1,
      anon_sym_COLON,
  [255795] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13535), 1,
      anon_sym_LPAREN2,
  [255802] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13537), 1,
      anon_sym_RPAREN,
  [255809] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13539), 1,
      anon_sym_RPAREN,
  [255816] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13541), 1,
      anon_sym_RPAREN,
  [255823] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13543), 1,
      aux_sym_preproc_if_token2,
  [255830] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13545), 1,
      aux_sym_preproc_if_token2,
  [255837] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13547), 1,
      anon_sym_while,
  [255844] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_GT_GT,
  [255851] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13549), 1,
      anon_sym_LPAREN2,
  [255858] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13551), 1,
      anon_sym_RPAREN,
  [255865] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(13553), 1,
      aux_sym_preproc_include_token2,
  [255872] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_LT_LT,
  [255879] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13555), 1,
      anon_sym_EQ,
  [255886] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13557), 1,
      sym_raw_string_content,
  [255893] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13559), 1,
      anon_sym_STAR,
  [255900] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13561), 1,
      anon_sym_LPAREN2,
  [255907] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13563), 1,
      sym_auto,
  [255914] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13565), 1,
      anon_sym_SEMI,
  [255921] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13567), 1,
      anon_sym_RPAREN,
  [255928] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13569), 1,
      anon_sym_COMMA,
  [255935] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8363), 1,
      anon_sym_COLON,
  [255942] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13571), 1,
      aux_sym_preproc_if_token2,
  [255949] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13573), 1,
      sym_auto,
  [255956] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13575), 1,
      anon_sym_SEMI,
  [255963] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13577), 1,
      anon_sym_RPAREN,
  [255970] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13579), 1,
      anon_sym_COLON,
  [255977] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13581), 1,
      anon_sym_SEMI,
  [255984] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13583), 1,
      anon_sym_SEMI,
  [255991] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12542), 1,
      anon_sym_RBRACE,
  [255998] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13585), 1,
      anon_sym_LPAREN2,
  [256005] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13587), 1,
      anon_sym_LPAREN2,
  [256012] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13589), 1,
      anon_sym_LPAREN2,
  [256019] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13591), 1,
      aux_sym_preproc_if_token2,
  [256026] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13593), 1,
      anon_sym_LPAREN2,
  [256033] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13595), 1,
      anon_sym_RBRACE,
  [256040] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11230), 1,
      anon_sym_SEMI,
  [256047] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13597), 1,
      anon_sym_while,
  [256054] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8396), 1,
      anon_sym_COLON,
  [256061] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13599), 1,
      anon_sym_LPAREN2,
  [256068] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13601), 1,
      anon_sym_SEMI,
  [256075] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13603), 1,
      anon_sym_RPAREN,
  [256082] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13605), 1,
      anon_sym_EQ,
  [256089] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13607), 1,
      sym_raw_string_content,
  [256096] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13609), 1,
      anon_sym_SEMI,
  [256103] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13611), 1,
      anon_sym_COMMA,
  [256110] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13613), 1,
      anon_sym_RPAREN,
  [256117] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13615), 1,
      anon_sym_RPAREN,
  [256124] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13617), 1,
      anon_sym_RPAREN,
  [256131] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13619), 1,
      anon_sym_RPAREN,
  [256138] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13621), 1,
      anon_sym_RPAREN,
  [256145] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13623), 1,
      anon_sym_COLON,
  [256152] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8020), 1,
      anon_sym_SEMI,
  [256159] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13625), 1,
      anon_sym_SEMI,
  [256166] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13627), 1,
      anon_sym_LPAREN2,
  [256173] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13629), 1,
      anon_sym_LPAREN2,
  [256180] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13631), 1,
      anon_sym_LPAREN2,
  [256187] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13633), 1,
      anon_sym_DQUOTE,
  [256194] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13635), 1,
      anon_sym_LPAREN2,
  [256201] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13637), 1,
      anon_sym_SEMI,
  [256208] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13639), 1,
      anon_sym_SEMI,
  [256215] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13641), 1,
      anon_sym_while,
  [256222] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13643), 1,
      anon_sym_LPAREN2,
  [256229] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13645), 1,
      anon_sym_SEMI,
  [256236] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13647), 1,
      anon_sym_SEMI,
  [256243] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13649), 1,
      anon_sym_EQ,
  [256250] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13651), 1,
      sym_raw_string_content,
  [256257] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13653), 1,
      anon_sym_DQUOTE,
  [256264] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13655), 1,
      anon_sym_COMMA,
  [256271] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_STAR,
  [256278] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13657), 1,
      anon_sym_SEMI,
  [256285] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10285), 1,
      anon_sym_RBRACE,
  [256292] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13659), 1,
      anon_sym_RPAREN,
  [256299] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13661), 1,
      anon_sym_COLON,
  [256306] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6910), 1,
      anon_sym_RPAREN,
  [256313] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13663), 1,
      anon_sym_LPAREN2,
  [256320] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13665), 1,
      anon_sym_LPAREN2,
  [256327] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13667), 1,
      anon_sym_LPAREN2,
  [256334] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_LT_EQ,
  [256341] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13669), 1,
      anon_sym_LPAREN2,
  [256348] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13671), 1,
      sym_identifier,
  [256355] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8211), 1,
      anon_sym_RBRACE,
  [256362] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13673), 1,
      anon_sym_LPAREN2,
  [256369] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8531), 1,
      anon_sym_RPAREN,
  [256376] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_GT_EQ,
  [256383] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13675), 1,
      anon_sym_EQ,
  [256390] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13677), 1,
      sym_raw_string_content,
  [256397] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13679), 1,
      anon_sym_LPAREN2,
  [256404] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13681), 1,
      anon_sym_COMMA,
  [256411] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13683), 1,
      anon_sym_RPAREN,
  [256418] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8426), 1,
      anon_sym_RPAREN,
  [256425] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13685), 1,
      anon_sym_RPAREN,
  [256432] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13687), 1,
      anon_sym_RPAREN,
  [256439] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13689), 1,
      anon_sym_COLON,
  [256446] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_GT,
  [256453] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13691), 1,
      anon_sym_LPAREN2,
  [256460] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8523), 1,
      anon_sym_RPAREN,
  [256467] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13693), 1,
      anon_sym_LPAREN2,
  [256474] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_BANG_EQ,
  [256481] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13695), 1,
      aux_sym_preproc_if_token2,
  [256488] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_EQ_EQ,
  [256495] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(13697), 1,
      aux_sym_preproc_include_token2,
  [256502] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13699), 1,
      anon_sym_EQ,
  [256509] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13701), 1,
      sym_raw_string_content,
  [256516] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13703), 1,
      anon_sym_STAR,
  [256523] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13705), 1,
      anon_sym_RPAREN,
  [256530] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13707), 1,
      anon_sym_RBRACK,
  [256537] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_AMP,
  [256544] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13709), 1,
      anon_sym_RPAREN,
  [256551] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13711), 1,
      anon_sym_RPAREN,
  [256558] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13713), 1,
      anon_sym_LPAREN2,
  [256565] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13715), 1,
      anon_sym_LPAREN2,
  [256572] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13717), 1,
      anon_sym_SEMI,
  [256579] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13719), 1,
      sym_raw_string_content,
  [256586] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13721), 1,
      anon_sym_RPAREN,
  [256593] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13723), 1,
      anon_sym_RBRACE,
  [256600] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13725), 1,
      anon_sym_RPAREN,
  [256607] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_CARET,
  [256614] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13727), 1,
      anon_sym_LPAREN2,
  [256621] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13729), 1,
      anon_sym_LPAREN2,
  [256628] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13731), 1,
      aux_sym_preproc_if_token2,
  [256635] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13733), 1,
      sym_raw_string_content,
  [256642] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13735), 1,
      aux_sym_preproc_if_token2,
  [256649] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13737), 1,
      anon_sym_RPAREN,
  [256656] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13739), 1,
      anon_sym_LPAREN2,
  [256663] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13741), 1,
      anon_sym_LPAREN2,
  [256670] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13743), 1,
      sym_raw_string_content,
  [256677] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13745), 1,
      anon_sym_RPAREN,
  [256684] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13747), 1,
      sym_raw_string_content,
  [256691] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13749), 1,
      anon_sym_RPAREN,
  [256698] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13751), 1,
      sym_raw_string_content,
  [256705] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13753), 1,
      anon_sym_RPAREN,
  [256712] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13755), 1,
      sym_raw_string_content,
  [256719] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13757), 1,
      anon_sym_RPAREN,
  [256726] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13759), 1,
      sym_raw_string_content,
  [256733] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13761), 1,
      anon_sym_RPAREN,
  [256740] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13763), 1,
      sym_raw_string_content,
  [256747] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13765), 1,
      anon_sym_RPAREN,
  [256754] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13767), 1,
      sym_raw_string_content,
  [256761] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13769), 1,
      anon_sym_RPAREN,
  [256768] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13771), 1,
      sym_raw_string_content,
  [256775] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13773), 1,
      anon_sym_RPAREN,
  [256782] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13775), 1,
      sym_identifier,
  [256789] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13777), 1,
      sym_identifier,
  [256796] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13779), 1,
      anon_sym_LPAREN2,
  [256803] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13781), 1,
      anon_sym_LPAREN2,
  [256810] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13783), 1,
      sym_identifier,
  [256817] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10246), 1,
      anon_sym_RBRACE,
  [256824] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13785), 1,
      anon_sym_RPAREN,
  [256831] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13787), 1,
      aux_sym_preproc_if_token2,
  [256838] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(10779), 1,
      anon_sym_SEMI,
  [256845] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13789), 1,
      sym_auto,
  [256852] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13791), 1,
      aux_sym_preproc_if_token2,
  [256859] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7066), 1,
      sym_identifier,
  [256866] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(12540), 1,
      anon_sym_RBRACE,
  [256873] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13793), 1,
      anon_sym_DQUOTE,
  [256880] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13795), 1,
      anon_sym_LPAREN2,
  [256887] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13797), 1,
      aux_sym_preproc_if_token2,
  [256894] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13799), 1,
      aux_sym_preproc_if_token2,
  [256901] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13801), 1,
      anon_sym_SEMI,
  [256908] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13803), 1,
      anon_sym_LPAREN2,
  [256915] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8453), 1,
      anon_sym_SEMI,
  [256922] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13805), 1,
      anon_sym_RPAREN,
  [256929] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13807), 1,
      sym_identifier,
  [256936] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13809), 1,
      sym_identifier,
  [256943] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13811), 1,
      sym_raw_string_content,
  [256950] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13813), 1,
      anon_sym_RPAREN,
  [256957] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13815), 1,
      anon_sym_RPAREN,
  [256964] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13817), 1,
      anon_sym_RPAREN,
  [256971] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13819), 1,
      anon_sym_DQUOTE,
  [256978] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13821), 1,
      anon_sym_RPAREN,
  [256985] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13823), 1,
      anon_sym_RPAREN,
  [256992] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13825), 1,
      anon_sym_RPAREN,
  [256999] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13827), 1,
      anon_sym_RPAREN,
  [257006] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_AMP_AMP,
  [257013] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_PIPE_PIPE,
  [257020] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13829), 1,
      anon_sym_SEMI,
  [257027] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13831), 1,
      anon_sym_SEMI,
  [257034] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_PERCENT,
  [257041] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8430), 1,
      anon_sym_SEMI,
  [257048] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(13833), 1,
      aux_sym_preproc_include_token2,
  [257055] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13835), 1,
      anon_sym_SEMI,
  [257062] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13837), 1,
      anon_sym_SEMI,
  [257069] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13839), 1,
      sym_identifier,
  [257076] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13841), 1,
      anon_sym_SLASH,
  [257083] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13843), 1,
      sym_identifier,
  [257090] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13845), 1,
      anon_sym_RPAREN,
  [257097] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13847), 1,
      anon_sym_RPAREN,
  [257104] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13849), 1,
      anon_sym_RPAREN,
  [257111] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13851), 1,
      anon_sym_RPAREN,
  [257118] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11913), 1,
      aux_sym_preproc_include_token2,
  [257125] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13853), 1,
      anon_sym_RPAREN,
  [257132] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1957), 1,
      anon_sym_COLON_COLON,
  [257139] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13855), 1,
      anon_sym_RPAREN,
  [257146] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(6787), 1,
      anon_sym_RPAREN,
  [257153] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13857), 1,
      anon_sym_RPAREN,
  [257160] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8422), 1,
      anon_sym_COLON,
  [257167] = 2,
    ACTIONS(5777), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(9278), 1,
      sym_comment,
  [257174] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(13859), 1,
      aux_sym_preproc_include_token2,
  [257181] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13861), 1,
      anon_sym_RPAREN,
  [257188] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(11871), 1,
      aux_sym_preproc_include_token2,
  [257195] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13863), 1,
      aux_sym_preproc_if_token2,
  [257202] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13865), 1,
      aux_sym_preproc_if_token2,
  [257209] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13867), 1,
      anon_sym_STAR,
  [257216] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_PLUS,
  [257223] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13869), 1,
      ts_builtin_sym_end,
  [257230] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13871), 1,
      anon_sym_DQUOTE,
  [257237] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13873), 1,
      aux_sym_preproc_if_token2,
  [257244] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13875), 1,
      anon_sym_DQUOTE,
  [257251] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13877), 1,
      sym_identifier,
  [257258] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13879), 1,
      anon_sym_LPAREN2,
  [257265] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13881), 1,
      anon_sym_COLON,
  [257272] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13883), 1,
      sym_identifier,
  [257279] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_DASH,
  [257286] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13885), 1,
      anon_sym_LPAREN2,
  [257293] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13887), 1,
      anon_sym_SEMI,
  [257300] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13889), 1,
      anon_sym_LPAREN2,
  [257307] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13891), 1,
      anon_sym_SEMI,
  [257314] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13893), 1,
      anon_sym_LPAREN2,
  [257321] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13895), 1,
      anon_sym_COLON,
  [257328] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13897), 1,
      sym_identifier,
  [257335] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13899), 1,
      anon_sym_RPAREN,
  [257342] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13901), 1,
      anon_sym_LPAREN2,
  [257349] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13903), 1,
      anon_sym_LPAREN2,
  [257356] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13251), 1,
      anon_sym_COMMA,
  [257363] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8369), 1,
      anon_sym_COLON,
  [257370] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13905), 1,
      anon_sym_LPAREN2,
  [257377] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13907), 1,
      sym_identifier,
  [257384] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13909), 1,
      anon_sym_LPAREN2,
  [257391] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13911), 1,
      anon_sym_LPAREN2,
  [257398] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13913), 1,
      sym_identifier,
  [257405] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13915), 1,
      anon_sym_DQUOTE,
  [257412] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13917), 1,
      anon_sym_SEMI,
  [257419] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13919), 1,
      anon_sym_SEMI,
  [257426] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13921), 1,
      anon_sym_LPAREN2,
  [257433] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13923), 1,
      sym_identifier,
  [257440] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13925), 1,
      sym_raw_string_content,
  [257447] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13927), 1,
      anon_sym_LPAREN2,
  [257454] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13929), 1,
      anon_sym_DQUOTE,
  [257461] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13931), 1,
      anon_sym_COLON,
  [257468] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13933), 1,
      anon_sym_LPAREN2,
  [257475] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13935), 1,
      anon_sym_LPAREN2,
  [257482] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13937), 1,
      sym_identifier,
  [257489] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13939), 1,
      sym_identifier,
  [257496] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13941), 1,
      aux_sym_preproc_if_token2,
  [257503] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13943), 1,
      anon_sym_LPAREN2,
  [257510] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13945), 1,
      sym_identifier,
  [257517] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13947), 1,
      sym_raw_string_content,
  [257524] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13949), 1,
      anon_sym_DQUOTE,
  [257531] = 2,
    ACTIONS(5773), 1,
      aux_sym_preproc_include_token2,
    ACTIONS(9278), 1,
      sym_comment,
  [257538] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(11020), 1,
      anon_sym_COLON,
  [257545] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13951), 1,
      anon_sym_LPAREN2,
  [257552] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13953), 1,
      sym_identifier,
  [257559] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13955), 1,
      anon_sym_DQUOTE,
  [257566] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13957), 1,
      anon_sym_DQUOTE,
  [257573] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13959), 1,
      sym_identifier,
  [257580] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13961), 1,
      sym_raw_string_content,
  [257587] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13963), 1,
      anon_sym_DQUOTE,
  [257594] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13965), 1,
      anon_sym_LPAREN2,
  [257601] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13967), 1,
      anon_sym_LPAREN2,
  [257608] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13969), 1,
      sym_identifier,
  [257615] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13971), 1,
      aux_sym_preproc_if_token2,
  [257622] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13973), 1,
      sym_identifier,
  [257629] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13975), 1,
      sym_identifier,
  [257636] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13977), 1,
      sym_raw_string_content,
  [257643] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13979), 1,
      anon_sym_LPAREN2,
  [257650] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13981), 1,
      anon_sym_RPAREN,
  [257657] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13983), 1,
      anon_sym_LPAREN2,
  [257664] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13985), 1,
      sym_identifier,
  [257671] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13987), 1,
      anon_sym_DQUOTE,
  [257678] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13989), 1,
      sym_identifier,
  [257685] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13991), 1,
      sym_raw_string_content,
  [257692] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13993), 1,
      anon_sym_RPAREN,
  [257699] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(13995), 1,
      aux_sym_preproc_include_token2,
  [257706] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13997), 1,
      sym_identifier,
  [257713] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13999), 1,
      sym_raw_string_content,
  [257720] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14001), 1,
      anon_sym_LPAREN2,
  [257727] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14003), 1,
      anon_sym_LPAREN2,
  [257734] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14005), 1,
      sym_raw_string_content,
  [257741] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14007), 1,
      anon_sym_DQUOTE,
  [257748] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14009), 1,
      sym_raw_string_content,
  [257755] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14011), 1,
      anon_sym_DQUOTE,
  [257762] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14013), 1,
      sym_raw_string_content,
  [257769] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14015), 1,
      anon_sym_DQUOTE,
  [257776] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14017), 1,
      sym_raw_string_content,
  [257783] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14019), 1,
      anon_sym_DQUOTE,
  [257790] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14021), 1,
      sym_raw_string_content,
  [257797] = 2,
    ACTIONS(9278), 1,
      sym_comment,
    ACTIONS(9398), 1,
      aux_sym_preproc_include_token2,
  [257804] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14023), 1,
      sym_raw_string_content,
  [257811] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14025), 1,
      anon_sym_SEMI,
  [257818] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14027), 1,
      sym_raw_string_content,
  [257825] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14029), 1,
      anon_sym_SEMI,
  [257832] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14031), 1,
      sym_raw_string_content,
  [257839] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14033), 1,
      anon_sym_SEMI,
  [257846] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14035), 1,
      sym_raw_string_content,
  [257853] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14037), 1,
      anon_sym_LPAREN2,
  [257860] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14039), 1,
      anon_sym_LPAREN2,
  [257867] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14041), 1,
      sym_auto,
  [257874] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14043), 1,
      anon_sym_LPAREN2,
  [257881] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14045), 1,
      anon_sym_LPAREN2,
  [257888] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14047), 1,
      sym_identifier,
  [257895] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14049), 1,
      anon_sym_LPAREN2,
  [257902] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14051), 1,
      anon_sym_LPAREN2,
  [257909] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14053), 1,
      sym_identifier,
  [257916] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14055), 1,
      anon_sym_LPAREN2,
  [257923] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14057), 1,
      anon_sym_LPAREN2,
  [257930] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14059), 1,
      sym_identifier,
  [257937] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14061), 1,
      anon_sym_LPAREN2,
  [257944] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14063), 1,
      anon_sym_LPAREN2,
  [257951] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14065), 1,
      sym_identifier,
  [257958] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14067), 1,
      anon_sym_LPAREN2,
  [257965] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14069), 1,
      anon_sym_LPAREN2,
  [257972] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14071), 1,
      anon_sym_LPAREN2,
  [257979] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14073), 1,
      anon_sym_LPAREN2,
  [257986] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14075), 1,
      anon_sym_LPAREN2,
  [257993] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14077), 1,
      anon_sym_LPAREN2,
  [258000] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14079), 1,
      anon_sym_LPAREN2,
  [258007] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14081), 1,
      anon_sym_LPAREN2,
  [258014] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14083), 1,
      anon_sym_LPAREN2,
  [258021] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14085), 1,
      anon_sym_LPAREN2,
  [258028] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14087), 1,
      anon_sym_LPAREN2,
  [258035] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14089), 1,
      anon_sym_DQUOTE,
  [258042] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(8414), 1,
      anon_sym_COLON,
  [258049] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14091), 1,
      sym_identifier,
  [258056] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14093), 1,
      anon_sym_STAR,
  [258063] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14095), 1,
      sym_identifier,
  [258070] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14097), 1,
      anon_sym_LPAREN2,
  [258077] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14099), 1,
      anon_sym_LPAREN2,
  [258084] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14101), 1,
      anon_sym_LPAREN2,
  [258091] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14103), 1,
      anon_sym_LPAREN2,
  [258098] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(14105), 1,
      anon_sym_LPAREN2,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(2665)] = 0,
  [SMALL_STATE(2666)] = 75,
  [SMALL_STATE(2667)] = 150,
  [SMALL_STATE(2668)] = 225,
  [SMALL_STATE(2669)] = 304,
  [SMALL_STATE(2670)] = 379,
  [SMALL_STATE(2671)] = 450,
  [SMALL_STATE(2672)] = 525,
  [SMALL_STATE(2673)] = 600,
  [SMALL_STATE(2674)] = 675,
  [SMALL_STATE(2675)] = 754,
  [SMALL_STATE(2676)] = 829,
  [SMALL_STATE(2677)] = 908,
  [SMALL_STATE(2678)] = 983,
  [SMALL_STATE(2679)] = 1060,
  [SMALL_STATE(2680)] = 1133,
  [SMALL_STATE(2681)] = 1204,
  [SMALL_STATE(2682)] = 1275,
  [SMALL_STATE(2683)] = 1354,
  [SMALL_STATE(2684)] = 1429,
  [SMALL_STATE(2685)] = 1512,
  [SMALL_STATE(2686)] = 1591,
  [SMALL_STATE(2687)] = 1666,
  [SMALL_STATE(2688)] = 1739,
  [SMALL_STATE(2689)] = 1810,
  [SMALL_STATE(2690)] = 1885,
  [SMALL_STATE(2691)] = 1956,
  [SMALL_STATE(2692)] = 2033,
  [SMALL_STATE(2693)] = 2114,
  [SMALL_STATE(2694)] = 2185,
  [SMALL_STATE(2695)] = 2256,
  [SMALL_STATE(2696)] = 2327,
  [SMALL_STATE(2697)] = 2410,
  [SMALL_STATE(2698)] = 2485,
  [SMALL_STATE(2699)] = 2564,
  [SMALL_STATE(2700)] = 2643,
  [SMALL_STATE(2701)] = 2770,
  [SMALL_STATE(2702)] = 2845,
  [SMALL_STATE(2703)] = 2920,
  [SMALL_STATE(2704)] = 2995,
  [SMALL_STATE(2705)] = 3122,
  [SMALL_STATE(2706)] = 3197,
  [SMALL_STATE(2707)] = 3267,
  [SMALL_STATE(2708)] = 3337,
  [SMALL_STATE(2709)] = 3407,
  [SMALL_STATE(2710)] = 3481,
  [SMALL_STATE(2711)] = 3565,
  [SMALL_STATE(2712)] = 3635,
  [SMALL_STATE(2713)] = 3717,
  [SMALL_STATE(2714)] = 3787,
  [SMALL_STATE(2715)] = 3857,
  [SMALL_STATE(2716)] = 3927,
  [SMALL_STATE(2717)] = 4001,
  [SMALL_STATE(2718)] = 4079,
  [SMALL_STATE(2719)] = 4149,
  [SMALL_STATE(2720)] = 4223,
  [SMALL_STATE(2721)] = 4297,
  [SMALL_STATE(2722)] = 4367,
  [SMALL_STATE(2723)] = 4437,
  [SMALL_STATE(2724)] = 4521,
  [SMALL_STATE(2725)] = 4595,
  [SMALL_STATE(2726)] = 4669,
  [SMALL_STATE(2727)] = 4741,
  [SMALL_STATE(2728)] = 4815,
  [SMALL_STATE(2729)] = 4885,
  [SMALL_STATE(2730)] = 4959,
  [SMALL_STATE(2731)] = 5029,
  [SMALL_STATE(2732)] = 5103,
  [SMALL_STATE(2733)] = 5173,
  [SMALL_STATE(2734)] = 5243,
  [SMALL_STATE(2735)] = 5313,
  [SMALL_STATE(2736)] = 5387,
  [SMALL_STATE(2737)] = 5459,
  [SMALL_STATE(2738)] = 5533,
  [SMALL_STATE(2739)] = 5607,
  [SMALL_STATE(2740)] = 5683,
  [SMALL_STATE(2741)] = 5769,
  [SMALL_STATE(2742)] = 5843,
  [SMALL_STATE(2743)] = 5913,
  [SMALL_STATE(2744)] = 5997,
  [SMALL_STATE(2745)] = 6067,
  [SMALL_STATE(2746)] = 6137,
  [SMALL_STATE(2747)] = 6207,
  [SMALL_STATE(2748)] = 6277,
  [SMALL_STATE(2749)] = 6355,
  [SMALL_STATE(2750)] = 6437,
  [SMALL_STATE(2751)] = 6511,
  [SMALL_STATE(2752)] = 6585,
  [SMALL_STATE(2753)] = 6657,
  [SMALL_STATE(2754)] = 6743,
  [SMALL_STATE(2755)] = 6813,
  [SMALL_STATE(2756)] = 6883,
  [SMALL_STATE(2757)] = 6967,
  [SMALL_STATE(2758)] = 7037,
  [SMALL_STATE(2759)] = 7107,
  [SMALL_STATE(2760)] = 7177,
  [SMALL_STATE(2761)] = 7261,
  [SMALL_STATE(2762)] = 7331,
  [SMALL_STATE(2763)] = 7400,
  [SMALL_STATE(2764)] = 7469,
  [SMALL_STATE(2765)] = 7538,
  [SMALL_STATE(2766)] = 7607,
  [SMALL_STATE(2767)] = 7676,
  [SMALL_STATE(2768)] = 7745,
  [SMALL_STATE(2769)] = 7814,
  [SMALL_STATE(2770)] = 7883,
  [SMALL_STATE(2771)] = 7952,
  [SMALL_STATE(2772)] = 8021,
  [SMALL_STATE(2773)] = 8098,
  [SMALL_STATE(2774)] = 8167,
  [SMALL_STATE(2775)] = 8246,
  [SMALL_STATE(2776)] = 8315,
  [SMALL_STATE(2777)] = 8384,
  [SMALL_STATE(2778)] = 8465,
  [SMALL_STATE(2779)] = 8534,
  [SMALL_STATE(2780)] = 8603,
  [SMALL_STATE(2781)] = 8672,
  [SMALL_STATE(2782)] = 8741,
  [SMALL_STATE(2783)] = 8810,
  [SMALL_STATE(2784)] = 8887,
  [SMALL_STATE(2785)] = 8968,
  [SMALL_STATE(2786)] = 9045,
  [SMALL_STATE(2787)] = 9114,
  [SMALL_STATE(2788)] = 9191,
  [SMALL_STATE(2789)] = 9260,
  [SMALL_STATE(2790)] = 9329,
  [SMALL_STATE(2791)] = 9398,
  [SMALL_STATE(2792)] = 9471,
  [SMALL_STATE(2793)] = 9540,
  [SMALL_STATE(2794)] = 9609,
  [SMALL_STATE(2795)] = 9678,
  [SMALL_STATE(2796)] = 9747,
  [SMALL_STATE(2797)] = 9816,
  [SMALL_STATE(2798)] = 9885,
  [SMALL_STATE(2799)] = 9954,
  [SMALL_STATE(2800)] = 10023,
  [SMALL_STATE(2801)] = 10108,
  [SMALL_STATE(2802)] = 10177,
  [SMALL_STATE(2803)] = 10246,
  [SMALL_STATE(2804)] = 10315,
  [SMALL_STATE(2805)] = 10384,
  [SMALL_STATE(2806)] = 10453,
  [SMALL_STATE(2807)] = 10522,
  [SMALL_STATE(2808)] = 10599,
  [SMALL_STATE(2809)] = 10668,
  [SMALL_STATE(2810)] = 10737,
  [SMALL_STATE(2811)] = 10806,
  [SMALL_STATE(2812)] = 10875,
  [SMALL_STATE(2813)] = 10944,
  [SMALL_STATE(2814)] = 11013,
  [SMALL_STATE(2815)] = 11082,
  [SMALL_STATE(2816)] = 11151,
  [SMALL_STATE(2817)] = 11220,
  [SMALL_STATE(2818)] = 11289,
  [SMALL_STATE(2819)] = 11358,
  [SMALL_STATE(2820)] = 11433,
  [SMALL_STATE(2821)] = 11502,
  [SMALL_STATE(2822)] = 11571,
  [SMALL_STATE(2823)] = 11640,
  [SMALL_STATE(2824)] = 11709,
  [SMALL_STATE(2825)] = 11790,
  [SMALL_STATE(2826)] = 11863,
  [SMALL_STATE(2827)] = 11932,
  [SMALL_STATE(2828)] = 12001,
  [SMALL_STATE(2829)] = 12070,
  [SMALL_STATE(2830)] = 12139,
  [SMALL_STATE(2831)] = 12208,
  [SMALL_STATE(2832)] = 12277,
  [SMALL_STATE(2833)] = 12346,
  [SMALL_STATE(2834)] = 12415,
  [SMALL_STATE(2835)] = 12484,
  [SMALL_STATE(2836)] = 12553,
  [SMALL_STATE(2837)] = 12622,
  [SMALL_STATE(2838)] = 12691,
  [SMALL_STATE(2839)] = 12760,
  [SMALL_STATE(2840)] = 12829,
  [SMALL_STATE(2841)] = 12898,
  [SMALL_STATE(2842)] = 12967,
  [SMALL_STATE(2843)] = 13036,
  [SMALL_STATE(2844)] = 13105,
  [SMALL_STATE(2845)] = 13174,
  [SMALL_STATE(2846)] = 13243,
  [SMALL_STATE(2847)] = 13312,
  [SMALL_STATE(2848)] = 13381,
  [SMALL_STATE(2849)] = 13450,
  [SMALL_STATE(2850)] = 13519,
  [SMALL_STATE(2851)] = 13600,
  [SMALL_STATE(2852)] = 13673,
  [SMALL_STATE(2853)] = 13742,
  [SMALL_STATE(2854)] = 13811,
  [SMALL_STATE(2855)] = 13880,
  [SMALL_STATE(2856)] = 13948,
  [SMALL_STATE(2857)] = 14024,
  [SMALL_STATE(2858)] = 14098,
  [SMALL_STATE(2859)] = 14174,
  [SMALL_STATE(2860)] = 14242,
  [SMALL_STATE(2861)] = 14314,
  [SMALL_STATE(2862)] = 14386,
  [SMALL_STATE(2863)] = 14458,
  [SMALL_STATE(2864)] = 14536,
  [SMALL_STATE(2865)] = 14612,
  [SMALL_STATE(2866)] = 14680,
  [SMALL_STATE(2867)] = 14752,
  [SMALL_STATE(2868)] = 14826,
  [SMALL_STATE(2869)] = 14902,
  [SMALL_STATE(2870)] = 14970,
  [SMALL_STATE(2871)] = 15046,
  [SMALL_STATE(2872)] = 15118,
  [SMALL_STATE(2873)] = 15190,
  [SMALL_STATE(2874)] = 15262,
  [SMALL_STATE(2875)] = 15329,
  [SMALL_STATE(2876)] = 15396,
  [SMALL_STATE(2877)] = 15467,
  [SMALL_STATE(2878)] = 15536,
  [SMALL_STATE(2879)] = 15603,
  [SMALL_STATE(2880)] = 15670,
  [SMALL_STATE(2881)] = 15741,
  [SMALL_STATE(2882)] = 15808,
  [SMALL_STATE(2883)] = 15877,
  [SMALL_STATE(2884)] = 15946,
  [SMALL_STATE(2885)] = 16013,
  [SMALL_STATE(2886)] = 16086,
  [SMALL_STATE(2887)] = 16157,
  [SMALL_STATE(2888)] = 16228,
  [SMALL_STATE(2889)] = 16301,
  [SMALL_STATE(2890)] = 16372,
  [SMALL_STATE(2891)] = 16439,
  [SMALL_STATE(2892)] = 16506,
  [SMALL_STATE(2893)] = 16575,
  [SMALL_STATE(2894)] = 16642,
  [SMALL_STATE(2895)] = 16713,
  [SMALL_STATE(2896)] = 16780,
  [SMALL_STATE(2897)] = 16851,
  [SMALL_STATE(2898)] = 16926,
  [SMALL_STATE(2899)] = 16997,
  [SMALL_STATE(2900)] = 17070,
  [SMALL_STATE(2901)] = 17141,
  [SMALL_STATE(2902)] = 17212,
  [SMALL_STATE(2903)] = 17281,
  [SMALL_STATE(2904)] = 17352,
  [SMALL_STATE(2905)] = 17423,
  [SMALL_STATE(2906)] = 17494,
  [SMALL_STATE(2907)] = 17561,
  [SMALL_STATE(2908)] = 17632,
  [SMALL_STATE(2909)] = 17715,
  [SMALL_STATE(2910)] = 17784,
  [SMALL_STATE(2911)] = 17901,
  [SMALL_STATE(2912)] = 17972,
  [SMALL_STATE(2913)] = 18051,
  [SMALL_STATE(2914)] = 18168,
  [SMALL_STATE(2915)] = 18239,
  [SMALL_STATE(2916)] = 18306,
  [SMALL_STATE(2917)] = 18385,
  [SMALL_STATE(2918)] = 18452,
  [SMALL_STATE(2919)] = 18519,
  [SMALL_STATE(2920)] = 18590,
  [SMALL_STATE(2921)] = 18665,
  [SMALL_STATE(2922)] = 18736,
  [SMALL_STATE(2923)] = 18807,
  [SMALL_STATE(2924)] = 18874,
  [SMALL_STATE(2925)] = 18945,
  [SMALL_STATE(2926)] = 19016,
  [SMALL_STATE(2927)] = 19092,
  [SMALL_STATE(2928)] = 19164,
  [SMALL_STATE(2929)] = 19242,
  [SMALL_STATE(2930)] = 19308,
  [SMALL_STATE(2931)] = 19390,
  [SMALL_STATE(2932)] = 19458,
  [SMALL_STATE(2933)] = 19524,
  [SMALL_STATE(2934)] = 19606,
  [SMALL_STATE(2935)] = 19672,
  [SMALL_STATE(2936)] = 19744,
  [SMALL_STATE(2937)] = 19810,
  [SMALL_STATE(2938)] = 19878,
  [SMALL_STATE(2939)] = 19944,
  [SMALL_STATE(2940)] = 20010,
  [SMALL_STATE(2941)] = 20080,
  [SMALL_STATE(2942)] = 20146,
  [SMALL_STATE(2943)] = 20214,
  [SMALL_STATE(2944)] = 20280,
  [SMALL_STATE(2945)] = 20346,
  [SMALL_STATE(2946)] = 20418,
  [SMALL_STATE(2947)] = 20484,
  [SMALL_STATE(2948)] = 20552,
  [SMALL_STATE(2949)] = 20630,
  [SMALL_STATE(2950)] = 20712,
  [SMALL_STATE(2951)] = 20794,
  [SMALL_STATE(2952)] = 20860,
  [SMALL_STATE(2953)] = 20975,
  [SMALL_STATE(2954)] = 21040,
  [SMALL_STATE(2955)] = 21153,
  [SMALL_STATE(2956)] = 21222,
  [SMALL_STATE(2957)] = 21335,
  [SMALL_STATE(2958)] = 21400,
  [SMALL_STATE(2959)] = 21485,
  [SMALL_STATE(2960)] = 21550,
  [SMALL_STATE(2961)] = 21615,
  [SMALL_STATE(2962)] = 21680,
  [SMALL_STATE(2963)] = 21745,
  [SMALL_STATE(2964)] = 21810,
  [SMALL_STATE(2965)] = 21879,
  [SMALL_STATE(2966)] = 21944,
  [SMALL_STATE(2967)] = 22027,
  [SMALL_STATE(2968)] = 22108,
  [SMALL_STATE(2969)] = 22177,
  [SMALL_STATE(2970)] = 22246,
  [SMALL_STATE(2971)] = 22361,
  [SMALL_STATE(2972)] = 22426,
  [SMALL_STATE(2973)] = 22491,
  [SMALL_STATE(2974)] = 22572,
  [SMALL_STATE(2975)] = 22637,
  [SMALL_STATE(2976)] = 22706,
  [SMALL_STATE(2977)] = 22787,
  [SMALL_STATE(2978)] = 22852,
  [SMALL_STATE(2979)] = 22967,
  [SMALL_STATE(2980)] = 23032,
  [SMALL_STATE(2981)] = 23097,
  [SMALL_STATE(2982)] = 23162,
  [SMALL_STATE(2983)] = 23233,
  [SMALL_STATE(2984)] = 23298,
  [SMALL_STATE(2985)] = 23363,
  [SMALL_STATE(2986)] = 23478,
  [SMALL_STATE(2987)] = 23587,
  [SMALL_STATE(2988)] = 23700,
  [SMALL_STATE(2989)] = 23773,
  [SMALL_STATE(2990)] = 23838,
  [SMALL_STATE(2991)] = 23903,
  [SMALL_STATE(2992)] = 23968,
  [SMALL_STATE(2993)] = 24033,
  [SMALL_STATE(2994)] = 24104,
  [SMALL_STATE(2995)] = 24169,
  [SMALL_STATE(2996)] = 24234,
  [SMALL_STATE(2997)] = 24303,
  [SMALL_STATE(2998)] = 24368,
  [SMALL_STATE(2999)] = 24433,
  [SMALL_STATE(3000)] = 24498,
  [SMALL_STATE(3001)] = 24607,
  [SMALL_STATE(3002)] = 24672,
  [SMALL_STATE(3003)] = 24753,
  [SMALL_STATE(3004)] = 24818,
  [SMALL_STATE(3005)] = 24883,
  [SMALL_STATE(3006)] = 24992,
  [SMALL_STATE(3007)] = 25057,
  [SMALL_STATE(3008)] = 25144,
  [SMALL_STATE(3009)] = 25209,
  [SMALL_STATE(3010)] = 25274,
  [SMALL_STATE(3011)] = 25339,
  [SMALL_STATE(3012)] = 25404,
  [SMALL_STATE(3013)] = 25469,
  [SMALL_STATE(3014)] = 25560,
  [SMALL_STATE(3015)] = 25625,
  [SMALL_STATE(3016)] = 25720,
  [SMALL_STATE(3017)] = 25817,
  [SMALL_STATE(3018)] = 25926,
  [SMALL_STATE(3019)] = 26031,
  [SMALL_STATE(3020)] = 26100,
  [SMALL_STATE(3021)] = 26173,
  [SMALL_STATE(3022)] = 26272,
  [SMALL_STATE(3023)] = 26337,
  [SMALL_STATE(3024)] = 26418,
  [SMALL_STATE(3025)] = 26483,
  [SMALL_STATE(3026)] = 26584,
  [SMALL_STATE(3027)] = 26650,
  [SMALL_STATE(3028)] = 26714,
  [SMALL_STATE(3029)] = 26778,
  [SMALL_STATE(3030)] = 26842,
  [SMALL_STATE(3031)] = 26906,
  [SMALL_STATE(3032)] = 26970,
  [SMALL_STATE(3033)] = 27036,
  [SMALL_STATE(3034)] = 27100,
  [SMALL_STATE(3035)] = 27176,
  [SMALL_STATE(3036)] = 27242,
  [SMALL_STATE(3037)] = 27310,
  [SMALL_STATE(3038)] = 27374,
  [SMALL_STATE(3039)] = 27442,
  [SMALL_STATE(3040)] = 27506,
  [SMALL_STATE(3041)] = 27574,
  [SMALL_STATE(3042)] = 27638,
  [SMALL_STATE(3043)] = 27706,
  [SMALL_STATE(3044)] = 27770,
  [SMALL_STATE(3045)] = 27838,
  [SMALL_STATE(3046)] = 27902,
  [SMALL_STATE(3047)] = 27966,
  [SMALL_STATE(3048)] = 28030,
  [SMALL_STATE(3049)] = 28102,
  [SMALL_STATE(3050)] = 28166,
  [SMALL_STATE(3051)] = 28230,
  [SMALL_STATE(3052)] = 28294,
  [SMALL_STATE(3053)] = 28362,
  [SMALL_STATE(3054)] = 28426,
  [SMALL_STATE(3055)] = 28490,
  [SMALL_STATE(3056)] = 28558,
  [SMALL_STATE(3057)] = 28622,
  [SMALL_STATE(3058)] = 28686,
  [SMALL_STATE(3059)] = 28750,
  [SMALL_STATE(3060)] = 28816,
  [SMALL_STATE(3061)] = 28880,
  [SMALL_STATE(3062)] = 28946,
  [SMALL_STATE(3063)] = 29010,
  [SMALL_STATE(3064)] = 29074,
  [SMALL_STATE(3065)] = 29138,
  [SMALL_STATE(3066)] = 29202,
  [SMALL_STATE(3067)] = 29268,
  [SMALL_STATE(3068)] = 29334,
  [SMALL_STATE(3069)] = 29402,
  [SMALL_STATE(3070)] = 29466,
  [SMALL_STATE(3071)] = 29534,
  [SMALL_STATE(3072)] = 29602,
  [SMALL_STATE(3073)] = 29666,
  [SMALL_STATE(3074)] = 29734,
  [SMALL_STATE(3075)] = 29800,
  [SMALL_STATE(3076)] = 29866,
  [SMALL_STATE(3077)] = 29930,
  [SMALL_STATE(3078)] = 29994,
  [SMALL_STATE(3079)] = 30058,
  [SMALL_STATE(3080)] = 30126,
  [SMALL_STATE(3081)] = 30202,
  [SMALL_STATE(3082)] = 30266,
  [SMALL_STATE(3083)] = 30330,
  [SMALL_STATE(3084)] = 30398,
  [SMALL_STATE(3085)] = 30462,
  [SMALL_STATE(3086)] = 30534,
  [SMALL_STATE(3087)] = 30598,
  [SMALL_STATE(3088)] = 30662,
  [SMALL_STATE(3089)] = 30726,
  [SMALL_STATE(3090)] = 30790,
  [SMALL_STATE(3091)] = 30857,
  [SMALL_STATE(3092)] = 30930,
  [SMALL_STATE(3093)] = 31003,
  [SMALL_STATE(3094)] = 31066,
  [SMALL_STATE(3095)] = 31133,
  [SMALL_STATE(3096)] = 31200,
  [SMALL_STATE(3097)] = 31267,
  [SMALL_STATE(3098)] = 31346,
  [SMALL_STATE(3099)] = 31413,
  [SMALL_STATE(3100)] = 31492,
  [SMALL_STATE(3101)] = 31603,
  [SMALL_STATE(3102)] = 31714,
  [SMALL_STATE(3103)] = 31777,
  [SMALL_STATE(3104)] = 31844,
  [SMALL_STATE(3105)] = 31923,
  [SMALL_STATE(3106)] = 31990,
  [SMALL_STATE(3107)] = 32103,
  [SMALL_STATE(3108)] = 32166,
  [SMALL_STATE(3109)] = 32229,
  [SMALL_STATE(3110)] = 32330,
  [SMALL_STATE(3111)] = 32427,
  [SMALL_STATE(3112)] = 32522,
  [SMALL_STATE(3113)] = 32683,
  [SMALL_STATE(3114)] = 32774,
  [SMALL_STATE(3115)] = 32863,
  [SMALL_STATE(3116)] = 32948,
  [SMALL_STATE(3117)] = 33029,
  [SMALL_STATE(3118)] = 33138,
  [SMALL_STATE(3119)] = 33205,
  [SMALL_STATE(3120)] = 33288,
  [SMALL_STATE(3121)] = 33353,
  [SMALL_STATE(3122)] = 33416,
  [SMALL_STATE(3123)] = 33529,
  [SMALL_STATE(3124)] = 33642,
  [SMALL_STATE(3125)] = 33755,
  [SMALL_STATE(3126)] = 33834,
  [SMALL_STATE(3127)] = 33943,
  [SMALL_STATE(3128)] = 34016,
  [SMALL_STATE(3129)] = 34089,
  [SMALL_STATE(3130)] = 34194,
  [SMALL_STATE(3131)] = 34265,
  [SMALL_STATE(3132)] = 34378,
  [SMALL_STATE(3133)] = 34445,
  [SMALL_STATE(3134)] = 34508,
  [SMALL_STATE(3135)] = 34575,
  [SMALL_STATE(3136)] = 34642,
  [SMALL_STATE(3137)] = 34705,
  [SMALL_STATE(3138)] = 34778,
  [SMALL_STATE(3139)] = 34939,
  [SMALL_STATE(3140)] = 35048,
  [SMALL_STATE(3141)] = 35127,
  [SMALL_STATE(3142)] = 35288,
  [SMALL_STATE(3143)] = 35351,
  [SMALL_STATE(3144)] = 35418,
  [SMALL_STATE(3145)] = 35487,
  [SMALL_STATE(3146)] = 35550,
  [SMALL_STATE(3147)] = 35615,
  [SMALL_STATE(3148)] = 35680,
  [SMALL_STATE(3149)] = 35751,
  [SMALL_STATE(3150)] = 35818,
  [SMALL_STATE(3151)] = 35927,
  [SMALL_STATE(3152)] = 35989,
  [SMALL_STATE(3153)] = 36051,
  [SMALL_STATE(3154)] = 36113,
  [SMALL_STATE(3155)] = 36179,
  [SMALL_STATE(3156)] = 36249,
  [SMALL_STATE(3157)] = 36321,
  [SMALL_STATE(3158)] = 36429,
  [SMALL_STATE(3159)] = 36491,
  [SMALL_STATE(3160)] = 36563,
  [SMALL_STATE(3161)] = 36633,
  [SMALL_STATE(3162)] = 36695,
  [SMALL_STATE(3163)] = 36757,
  [SMALL_STATE(3164)] = 36819,
  [SMALL_STATE(3165)] = 36927,
  [SMALL_STATE(3166)] = 36997,
  [SMALL_STATE(3167)] = 37105,
  [SMALL_STATE(3168)] = 37213,
  [SMALL_STATE(3169)] = 37275,
  [SMALL_STATE(3170)] = 37341,
  [SMALL_STATE(3171)] = 37403,
  [SMALL_STATE(3172)] = 37473,
  [SMALL_STATE(3173)] = 37535,
  [SMALL_STATE(3174)] = 37597,
  [SMALL_STATE(3175)] = 37659,
  [SMALL_STATE(3176)] = 37727,
  [SMALL_STATE(3177)] = 37789,
  [SMALL_STATE(3178)] = 37851,
  [SMALL_STATE(3179)] = 37959,
  [SMALL_STATE(3180)] = 38021,
  [SMALL_STATE(3181)] = 38083,
  [SMALL_STATE(3182)] = 38191,
  [SMALL_STATE(3183)] = 38299,
  [SMALL_STATE(3184)] = 38407,
  [SMALL_STATE(3185)] = 38475,
  [SMALL_STATE(3186)] = 38547,
  [SMALL_STATE(3187)] = 38609,
  [SMALL_STATE(3188)] = 38671,
  [SMALL_STATE(3189)] = 38779,
  [SMALL_STATE(3190)] = 38845,
  [SMALL_STATE(3191)] = 38953,
  [SMALL_STATE(3192)] = 39015,
  [SMALL_STATE(3193)] = 39081,
  [SMALL_STATE(3194)] = 39189,
  [SMALL_STATE(3195)] = 39261,
  [SMALL_STATE(3196)] = 39331,
  [SMALL_STATE(3197)] = 39439,
  [SMALL_STATE(3198)] = 39501,
  [SMALL_STATE(3199)] = 39563,
  [SMALL_STATE(3200)] = 39625,
  [SMALL_STATE(3201)] = 39693,
  [SMALL_STATE(3202)] = 39759,
  [SMALL_STATE(3203)] = 39821,
  [SMALL_STATE(3204)] = 39929,
  [SMALL_STATE(3205)] = 40037,
  [SMALL_STATE(3206)] = 40099,
  [SMALL_STATE(3207)] = 40161,
  [SMALL_STATE(3208)] = 40269,
  [SMALL_STATE(3209)] = 40331,
  [SMALL_STATE(3210)] = 40393,
  [SMALL_STATE(3211)] = 40455,
  [SMALL_STATE(3212)] = 40521,
  [SMALL_STATE(3213)] = 40583,
  [SMALL_STATE(3214)] = 40645,
  [SMALL_STATE(3215)] = 40713,
  [SMALL_STATE(3216)] = 40821,
  [SMALL_STATE(3217)] = 40883,
  [SMALL_STATE(3218)] = 40945,
  [SMALL_STATE(3219)] = 41013,
  [SMALL_STATE(3220)] = 41121,
  [SMALL_STATE(3221)] = 41229,
  [SMALL_STATE(3222)] = 41295,
  [SMALL_STATE(3223)] = 41403,
  [SMALL_STATE(3224)] = 41465,
  [SMALL_STATE(3225)] = 41527,
  [SMALL_STATE(3226)] = 41589,
  [SMALL_STATE(3227)] = 41651,
  [SMALL_STATE(3228)] = 41713,
  [SMALL_STATE(3229)] = 41779,
  [SMALL_STATE(3230)] = 41849,
  [SMALL_STATE(3231)] = 41913,
  [SMALL_STATE(3232)] = 41977,
  [SMALL_STATE(3233)] = 42039,
  [SMALL_STATE(3234)] = 42101,
  [SMALL_STATE(3235)] = 42209,
  [SMALL_STATE(3236)] = 42271,
  [SMALL_STATE(3237)] = 42343,
  [SMALL_STATE(3238)] = 42412,
  [SMALL_STATE(3239)] = 42519,
  [SMALL_STATE(3240)] = 42580,
  [SMALL_STATE(3241)] = 42645,
  [SMALL_STATE(3242)] = 42710,
  [SMALL_STATE(3243)] = 42775,
  [SMALL_STATE(3244)] = 42840,
  [SMALL_STATE(3245)] = 42905,
  [SMALL_STATE(3246)] = 42970,
  [SMALL_STATE(3247)] = 43035,
  [SMALL_STATE(3248)] = 43096,
  [SMALL_STATE(3249)] = 43157,
  [SMALL_STATE(3250)] = 43264,
  [SMALL_STATE(3251)] = 43333,
  [SMALL_STATE(3252)] = 43440,
  [SMALL_STATE(3253)] = 43501,
  [SMALL_STATE(3254)] = 43562,
  [SMALL_STATE(3255)] = 43639,
  [SMALL_STATE(3256)] = 43718,
  [SMALL_STATE(3257)] = 43799,
  [SMALL_STATE(3258)] = 43906,
  [SMALL_STATE(3259)] = 43967,
  [SMALL_STATE(3260)] = 44028,
  [SMALL_STATE(3261)] = 44101,
  [SMALL_STATE(3262)] = 44162,
  [SMALL_STATE(3263)] = 44229,
  [SMALL_STATE(3264)] = 44290,
  [SMALL_STATE(3265)] = 44351,
  [SMALL_STATE(3266)] = 44412,
  [SMALL_STATE(3267)] = 44473,
  [SMALL_STATE(3268)] = 44556,
  [SMALL_STATE(3269)] = 44637,
  [SMALL_STATE(3270)] = 44724,
  [SMALL_STATE(3271)] = 44799,
  [SMALL_STATE(3272)] = 44888,
  [SMALL_STATE(3273)] = 44967,
  [SMALL_STATE(3274)] = 45060,
  [SMALL_STATE(3275)] = 45155,
  [SMALL_STATE(3276)] = 45238,
  [SMALL_STATE(3277)] = 45325,
  [SMALL_STATE(3278)] = 45414,
  [SMALL_STATE(3279)] = 45507,
  [SMALL_STATE(3280)] = 45568,
  [SMALL_STATE(3281)] = 45663,
  [SMALL_STATE(3282)] = 45724,
  [SMALL_STATE(3283)] = 45835,
  [SMALL_STATE(3284)] = 45896,
  [SMALL_STATE(3285)] = 45995,
  [SMALL_STATE(3286)] = 46098,
  [SMALL_STATE(3287)] = 46205,
  [SMALL_STATE(3288)] = 46266,
  [SMALL_STATE(3289)] = 46327,
  [SMALL_STATE(3290)] = 46390,
  [SMALL_STATE(3291)] = 46465,
  [SMALL_STATE(3292)] = 46576,
  [SMALL_STATE(3293)] = 46637,
  [SMALL_STATE(3294)] = 46736,
  [SMALL_STATE(3295)] = 46797,
  [SMALL_STATE(3296)] = 46900,
  [SMALL_STATE(3297)] = 46977,
  [SMALL_STATE(3298)] = 47038,
  [SMALL_STATE(3299)] = 47099,
  [SMALL_STATE(3300)] = 47210,
  [SMALL_STATE(3301)] = 47321,
  [SMALL_STATE(3302)] = 47382,
  [SMALL_STATE(3303)] = 47447,
  [SMALL_STATE(3304)] = 47508,
  [SMALL_STATE(3305)] = 47575,
  [SMALL_STATE(3306)] = 47636,
  [SMALL_STATE(3307)] = 47711,
  [SMALL_STATE(3308)] = 47776,
  [SMALL_STATE(3309)] = 47887,
  [SMALL_STATE(3310)] = 47948,
  [SMALL_STATE(3311)] = 48009,
  [SMALL_STATE(3312)] = 48070,
  [SMALL_STATE(3313)] = 48181,
  [SMALL_STATE(3314)] = 48242,
  [SMALL_STATE(3315)] = 48303,
  [SMALL_STATE(3316)] = 48364,
  [SMALL_STATE(3317)] = 48429,
  [SMALL_STATE(3318)] = 48498,
  [SMALL_STATE(3319)] = 48609,
  [SMALL_STATE(3320)] = 48716,
  [SMALL_STATE(3321)] = 48823,
  [SMALL_STATE(3322)] = 48890,
  [SMALL_STATE(3323)] = 48955,
  [SMALL_STATE(3324)] = 49016,
  [SMALL_STATE(3325)] = 49077,
  [SMALL_STATE(3326)] = 49146,
  [SMALL_STATE(3327)] = 49211,
  [SMALL_STATE(3328)] = 49284,
  [SMALL_STATE(3329)] = 49345,
  [SMALL_STATE(3330)] = 49406,
  [SMALL_STATE(3331)] = 49467,
  [SMALL_STATE(3332)] = 49528,
  [SMALL_STATE(3333)] = 49595,
  [SMALL_STATE(3334)] = 49662,
  [SMALL_STATE(3335)] = 49727,
  [SMALL_STATE(3336)] = 49834,
  [SMALL_STATE(3337)] = 49899,
  [SMALL_STATE(3338)] = 49964,
  [SMALL_STATE(3339)] = 50029,
  [SMALL_STATE(3340)] = 50090,
  [SMALL_STATE(3341)] = 50155,
  [SMALL_STATE(3342)] = 50222,
  [SMALL_STATE(3343)] = 50283,
  [SMALL_STATE(3344)] = 50348,
  [SMALL_STATE(3345)] = 50413,
  [SMALL_STATE(3346)] = 50476,
  [SMALL_STATE(3347)] = 50587,
  [SMALL_STATE(3348)] = 50648,
  [SMALL_STATE(3349)] = 50711,
  [SMALL_STATE(3350)] = 50786,
  [SMALL_STATE(3351)] = 50861,
  [SMALL_STATE(3352)] = 50923,
  [SMALL_STATE(3353)] = 50983,
  [SMALL_STATE(3354)] = 51043,
  [SMALL_STATE(3355)] = 51153,
  [SMALL_STATE(3356)] = 51223,
  [SMALL_STATE(3357)] = 51331,
  [SMALL_STATE(3358)] = 51405,
  [SMALL_STATE(3359)] = 51467,
  [SMALL_STATE(3360)] = 51529,
  [SMALL_STATE(3361)] = 51591,
  [SMALL_STATE(3362)] = 51659,
  [SMALL_STATE(3363)] = 51735,
  [SMALL_STATE(3364)] = 51845,
  [SMALL_STATE(3365)] = 51949,
  [SMALL_STATE(3366)] = 52009,
  [SMALL_STATE(3367)] = 52069,
  [SMALL_STATE(3368)] = 52183,
  [SMALL_STATE(3369)] = 52259,
  [SMALL_STATE(3370)] = 52333,
  [SMALL_STATE(3371)] = 52433,
  [SMALL_STATE(3372)] = 52529,
  [SMALL_STATE(3373)] = 52621,
  [SMALL_STATE(3374)] = 52777,
  [SMALL_STATE(3375)] = 52933,
  [SMALL_STATE(3376)] = 53023,
  [SMALL_STATE(3377)] = 53109,
  [SMALL_STATE(3378)] = 53193,
  [SMALL_STATE(3379)] = 53275,
  [SMALL_STATE(3380)] = 53353,
  [SMALL_STATE(3381)] = 53413,
  [SMALL_STATE(3382)] = 53485,
  [SMALL_STATE(3383)] = 53589,
  [SMALL_STATE(3384)] = 53649,
  [SMALL_STATE(3385)] = 53723,
  [SMALL_STATE(3386)] = 53797,
  [SMALL_STATE(3387)] = 53877,
  [SMALL_STATE(3388)] = 53937,
  [SMALL_STATE(3389)] = 53997,
  [SMALL_STATE(3390)] = 54057,
  [SMALL_STATE(3391)] = 54123,
  [SMALL_STATE(3392)] = 54189,
  [SMALL_STATE(3393)] = 54253,
  [SMALL_STATE(3394)] = 54313,
  [SMALL_STATE(3395)] = 54385,
  [SMALL_STATE(3396)] = 54445,
  [SMALL_STATE(3397)] = 54505,
  [SMALL_STATE(3398)] = 54579,
  [SMALL_STATE(3399)] = 54641,
  [SMALL_STATE(3400)] = 54751,
  [SMALL_STATE(3401)] = 54855,
  [SMALL_STATE(3402)] = 54915,
  [SMALL_STATE(3403)] = 54977,
  [SMALL_STATE(3404)] = 55037,
  [SMALL_STATE(3405)] = 55097,
  [SMALL_STATE(3406)] = 55205,
  [SMALL_STATE(3407)] = 55267,
  [SMALL_STATE(3408)] = 55327,
  [SMALL_STATE(3409)] = 55431,
  [SMALL_STATE(3410)] = 55499,
  [SMALL_STATE(3411)] = 55565,
  [SMALL_STATE(3412)] = 55625,
  [SMALL_STATE(3413)] = 55689,
  [SMALL_STATE(3414)] = 55797,
  [SMALL_STATE(3415)] = 55953,
  [SMALL_STATE(3416)] = 56019,
  [SMALL_STATE(3417)] = 56175,
  [SMALL_STATE(3418)] = 56235,
  [SMALL_STATE(3419)] = 56295,
  [SMALL_STATE(3420)] = 56361,
  [SMALL_STATE(3421)] = 56517,
  [SMALL_STATE(3422)] = 56673,
  [SMALL_STATE(3423)] = 56747,
  [SMALL_STATE(3424)] = 56827,
  [SMALL_STATE(3425)] = 56983,
  [SMALL_STATE(3426)] = 57043,
  [SMALL_STATE(3427)] = 57103,
  [SMALL_STATE(3428)] = 57163,
  [SMALL_STATE(3429)] = 57273,
  [SMALL_STATE(3430)] = 57333,
  [SMALL_STATE(3431)] = 57489,
  [SMALL_STATE(3432)] = 57549,
  [SMALL_STATE(3433)] = 57621,
  [SMALL_STATE(3434)] = 57695,
  [SMALL_STATE(3435)] = 57769,
  [SMALL_STATE(3436)] = 57875,
  [SMALL_STATE(3437)] = 57947,
  [SMALL_STATE(3438)] = 58007,
  [SMALL_STATE(3439)] = 58113,
  [SMALL_STATE(3440)] = 58223,
  [SMALL_STATE(3441)] = 58283,
  [SMALL_STATE(3442)] = 58343,
  [SMALL_STATE(3443)] = 58407,
  [SMALL_STATE(3444)] = 58467,
  [SMALL_STATE(3445)] = 58527,
  [SMALL_STATE(3446)] = 58587,
  [SMALL_STATE(3447)] = 58663,
  [SMALL_STATE(3448)] = 58819,
  [SMALL_STATE(3449)] = 58879,
  [SMALL_STATE(3450)] = 58941,
  [SMALL_STATE(3451)] = 59015,
  [SMALL_STATE(3452)] = 59117,
  [SMALL_STATE(3453)] = 59215,
  [SMALL_STATE(3454)] = 59309,
  [SMALL_STATE(3455)] = 59369,
  [SMALL_STATE(3456)] = 59461,
  [SMALL_STATE(3457)] = 59529,
  [SMALL_STATE(3458)] = 59593,
  [SMALL_STATE(3459)] = 59681,
  [SMALL_STATE(3460)] = 59767,
  [SMALL_STATE(3461)] = 59849,
  [SMALL_STATE(3462)] = 59927,
  [SMALL_STATE(3463)] = 60001,
  [SMALL_STATE(3464)] = 60067,
  [SMALL_STATE(3465)] = 60173,
  [SMALL_STATE(3466)] = 60283,
  [SMALL_STATE(3467)] = 60389,
  [SMALL_STATE(3468)] = 60449,
  [SMALL_STATE(3469)] = 60509,
  [SMALL_STATE(3470)] = 60569,
  [SMALL_STATE(3471)] = 60679,
  [SMALL_STATE(3472)] = 60739,
  [SMALL_STATE(3473)] = 60799,
  [SMALL_STATE(3474)] = 60863,
  [SMALL_STATE(3475)] = 60927,
  [SMALL_STATE(3476)] = 60987,
  [SMALL_STATE(3477)] = 61055,
  [SMALL_STATE(3478)] = 61121,
  [SMALL_STATE(3479)] = 61181,
  [SMALL_STATE(3480)] = 61241,
  [SMALL_STATE(3481)] = 61300,
  [SMALL_STATE(3482)] = 61359,
  [SMALL_STATE(3483)] = 61418,
  [SMALL_STATE(3484)] = 61477,
  [SMALL_STATE(3485)] = 61536,
  [SMALL_STATE(3486)] = 61595,
  [SMALL_STATE(3487)] = 61654,
  [SMALL_STATE(3488)] = 61713,
  [SMALL_STATE(3489)] = 61772,
  [SMALL_STATE(3490)] = 61831,
  [SMALL_STATE(3491)] = 61890,
  [SMALL_STATE(3492)] = 61949,
  [SMALL_STATE(3493)] = 62008,
  [SMALL_STATE(3494)] = 62067,
  [SMALL_STATE(3495)] = 62126,
  [SMALL_STATE(3496)] = 62185,
  [SMALL_STATE(3497)] = 62246,
  [SMALL_STATE(3498)] = 62305,
  [SMALL_STATE(3499)] = 62372,
  [SMALL_STATE(3500)] = 62431,
  [SMALL_STATE(3501)] = 62490,
  [SMALL_STATE(3502)] = 62549,
  [SMALL_STATE(3503)] = 62608,
  [SMALL_STATE(3504)] = 62667,
  [SMALL_STATE(3505)] = 62726,
  [SMALL_STATE(3506)] = 62835,
  [SMALL_STATE(3507)] = 62894,
  [SMALL_STATE(3508)] = 62953,
  [SMALL_STATE(3509)] = 63018,
  [SMALL_STATE(3510)] = 63081,
  [SMALL_STATE(3511)] = 63140,
  [SMALL_STATE(3512)] = 63199,
  [SMALL_STATE(3513)] = 63258,
  [SMALL_STATE(3514)] = 63327,
  [SMALL_STATE(3515)] = 63386,
  [SMALL_STATE(3516)] = 63445,
  [SMALL_STATE(3517)] = 63504,
  [SMALL_STATE(3518)] = 63563,
  [SMALL_STATE(3519)] = 63622,
  [SMALL_STATE(3520)] = 63681,
  [SMALL_STATE(3521)] = 63740,
  [SMALL_STATE(3522)] = 63799,
  [SMALL_STATE(3523)] = 63858,
  [SMALL_STATE(3524)] = 63917,
  [SMALL_STATE(3525)] = 63976,
  [SMALL_STATE(3526)] = 64085,
  [SMALL_STATE(3527)] = 64152,
  [SMALL_STATE(3528)] = 64211,
  [SMALL_STATE(3529)] = 64280,
  [SMALL_STATE(3530)] = 64339,
  [SMALL_STATE(3531)] = 64398,
  [SMALL_STATE(3532)] = 64457,
  [SMALL_STATE(3533)] = 64516,
  [SMALL_STATE(3534)] = 64575,
  [SMALL_STATE(3535)] = 64634,
  [SMALL_STATE(3536)] = 64693,
  [SMALL_STATE(3537)] = 64752,
  [SMALL_STATE(3538)] = 64813,
  [SMALL_STATE(3539)] = 64872,
  [SMALL_STATE(3540)] = 64931,
  [SMALL_STATE(3541)] = 64990,
  [SMALL_STATE(3542)] = 65049,
  [SMALL_STATE(3543)] = 65108,
  [SMALL_STATE(3544)] = 65167,
  [SMALL_STATE(3545)] = 65226,
  [SMALL_STATE(3546)] = 65293,
  [SMALL_STATE(3547)] = 65352,
  [SMALL_STATE(3548)] = 65411,
  [SMALL_STATE(3549)] = 65470,
  [SMALL_STATE(3550)] = 65529,
  [SMALL_STATE(3551)] = 65588,
  [SMALL_STATE(3552)] = 65647,
  [SMALL_STATE(3553)] = 65706,
  [SMALL_STATE(3554)] = 65765,
  [SMALL_STATE(3555)] = 65830,
  [SMALL_STATE(3556)] = 65897,
  [SMALL_STATE(3557)] = 65956,
  [SMALL_STATE(3558)] = 66019,
  [SMALL_STATE(3559)] = 66078,
  [SMALL_STATE(3560)] = 66137,
  [SMALL_STATE(3561)] = 66196,
  [SMALL_STATE(3562)] = 66255,
  [SMALL_STATE(3563)] = 66314,
  [SMALL_STATE(3564)] = 66373,
  [SMALL_STATE(3565)] = 66432,
  [SMALL_STATE(3566)] = 66491,
  [SMALL_STATE(3567)] = 66550,
  [SMALL_STATE(3568)] = 66609,
  [SMALL_STATE(3569)] = 66668,
  [SMALL_STATE(3570)] = 66727,
  [SMALL_STATE(3571)] = 66786,
  [SMALL_STATE(3572)] = 66847,
  [SMALL_STATE(3573)] = 66906,
  [SMALL_STATE(3574)] = 66965,
  [SMALL_STATE(3575)] = 67024,
  [SMALL_STATE(3576)] = 67087,
  [SMALL_STATE(3577)] = 67146,
  [SMALL_STATE(3578)] = 67205,
  [SMALL_STATE(3579)] = 67264,
  [SMALL_STATE(3580)] = 67323,
  [SMALL_STATE(3581)] = 67382,
  [SMALL_STATE(3582)] = 67441,
  [SMALL_STATE(3583)] = 67500,
  [SMALL_STATE(3584)] = 67559,
  [SMALL_STATE(3585)] = 67618,
  [SMALL_STATE(3586)] = 67681,
  [SMALL_STATE(3587)] = 67744,
  [SMALL_STATE(3588)] = 67803,
  [SMALL_STATE(3589)] = 67862,
  [SMALL_STATE(3590)] = 67921,
  [SMALL_STATE(3591)] = 67980,
  [SMALL_STATE(3592)] = 68039,
  [SMALL_STATE(3593)] = 68098,
  [SMALL_STATE(3594)] = 68157,
  [SMALL_STATE(3595)] = 68216,
  [SMALL_STATE(3596)] = 68283,
  [SMALL_STATE(3597)] = 68342,
  [SMALL_STATE(3598)] = 68401,
  [SMALL_STATE(3599)] = 68460,
  [SMALL_STATE(3600)] = 68519,
  [SMALL_STATE(3601)] = 68578,
  [SMALL_STATE(3602)] = 68637,
  [SMALL_STATE(3603)] = 68698,
  [SMALL_STATE(3604)] = 68757,
  [SMALL_STATE(3605)] = 68822,
  [SMALL_STATE(3606)] = 68881,
  [SMALL_STATE(3607)] = 68940,
  [SMALL_STATE(3608)] = 68999,
  [SMALL_STATE(3609)] = 69058,
  [SMALL_STATE(3610)] = 69117,
  [SMALL_STATE(3611)] = 69178,
  [SMALL_STATE(3612)] = 69237,
  [SMALL_STATE(3613)] = 69296,
  [SMALL_STATE(3614)] = 69355,
  [SMALL_STATE(3615)] = 69420,
  [SMALL_STATE(3616)] = 69479,
  [SMALL_STATE(3617)] = 69538,
  [SMALL_STATE(3618)] = 69597,
  [SMALL_STATE(3619)] = 69656,
  [SMALL_STATE(3620)] = 69715,
  [SMALL_STATE(3621)] = 69774,
  [SMALL_STATE(3622)] = 69833,
  [SMALL_STATE(3623)] = 69892,
  [SMALL_STATE(3624)] = 69951,
  [SMALL_STATE(3625)] = 70010,
  [SMALL_STATE(3626)] = 70069,
  [SMALL_STATE(3627)] = 70128,
  [SMALL_STATE(3628)] = 70187,
  [SMALL_STATE(3629)] = 70246,
  [SMALL_STATE(3630)] = 70305,
  [SMALL_STATE(3631)] = 70372,
  [SMALL_STATE(3632)] = 70431,
  [SMALL_STATE(3633)] = 70490,
  [SMALL_STATE(3634)] = 70549,
  [SMALL_STATE(3635)] = 70658,
  [SMALL_STATE(3636)] = 70717,
  [SMALL_STATE(3637)] = 70776,
  [SMALL_STATE(3638)] = 70841,
  [SMALL_STATE(3639)] = 70900,
  [SMALL_STATE(3640)] = 70959,
  [SMALL_STATE(3641)] = 71018,
  [SMALL_STATE(3642)] = 71077,
  [SMALL_STATE(3643)] = 71136,
  [SMALL_STATE(3644)] = 71195,
  [SMALL_STATE(3645)] = 71304,
  [SMALL_STATE(3646)] = 71363,
  [SMALL_STATE(3647)] = 71422,
  [SMALL_STATE(3648)] = 71481,
  [SMALL_STATE(3649)] = 71540,
  [SMALL_STATE(3650)] = 71599,
  [SMALL_STATE(3651)] = 71658,
  [SMALL_STATE(3652)] = 71717,
  [SMALL_STATE(3653)] = 71776,
  [SMALL_STATE(3654)] = 71835,
  [SMALL_STATE(3655)] = 71894,
  [SMALL_STATE(3656)] = 71953,
  [SMALL_STATE(3657)] = 72012,
  [SMALL_STATE(3658)] = 72071,
  [SMALL_STATE(3659)] = 72130,
  [SMALL_STATE(3660)] = 72189,
  [SMALL_STATE(3661)] = 72247,
  [SMALL_STATE(3662)] = 72305,
  [SMALL_STATE(3663)] = 72407,
  [SMALL_STATE(3664)] = 72465,
  [SMALL_STATE(3665)] = 72523,
  [SMALL_STATE(3666)] = 72581,
  [SMALL_STATE(3667)] = 72639,
  [SMALL_STATE(3668)] = 72701,
  [SMALL_STATE(3669)] = 72773,
  [SMALL_STATE(3670)] = 72835,
  [SMALL_STATE(3671)] = 72893,
  [SMALL_STATE(3672)] = 72955,
  [SMALL_STATE(3673)] = 73013,
  [SMALL_STATE(3674)] = 73083,
  [SMALL_STATE(3675)] = 73141,
  [SMALL_STATE(3676)] = 73203,
  [SMALL_STATE(3677)] = 73265,
  [SMALL_STATE(3678)] = 73323,
  [SMALL_STATE(3679)] = 73381,
  [SMALL_STATE(3680)] = 73489,
  [SMALL_STATE(3681)] = 73595,
  [SMALL_STATE(3682)] = 73653,
  [SMALL_STATE(3683)] = 73711,
  [SMALL_STATE(3684)] = 73769,
  [SMALL_STATE(3685)] = 73827,
  [SMALL_STATE(3686)] = 73885,
  [SMALL_STATE(3687)] = 73987,
  [SMALL_STATE(3688)] = 74081,
  [SMALL_STATE(3689)] = 74139,
  [SMALL_STATE(3690)] = 74197,
  [SMALL_STATE(3691)] = 74255,
  [SMALL_STATE(3692)] = 74313,
  [SMALL_STATE(3693)] = 74371,
  [SMALL_STATE(3694)] = 74429,
  [SMALL_STATE(3695)] = 74499,
  [SMALL_STATE(3696)] = 74565,
  [SMALL_STATE(3697)] = 74627,
  [SMALL_STATE(3698)] = 74685,
  [SMALL_STATE(3699)] = 74751,
  [SMALL_STATE(3700)] = 74813,
  [SMALL_STATE(3701)] = 74871,
  [SMALL_STATE(3702)] = 74977,
  [SMALL_STATE(3703)] = 75049,
  [SMALL_STATE(3704)] = 75107,
  [SMALL_STATE(3705)] = 75165,
  [SMALL_STATE(3706)] = 75223,
  [SMALL_STATE(3707)] = 75281,
  [SMALL_STATE(3708)] = 75339,
  [SMALL_STATE(3709)] = 75447,
  [SMALL_STATE(3710)] = 75553,
  [SMALL_STATE(3711)] = 75611,
  [SMALL_STATE(3712)] = 75669,
  [SMALL_STATE(3713)] = 75727,
  [SMALL_STATE(3714)] = 75785,
  [SMALL_STATE(3715)] = 75849,
  [SMALL_STATE(3716)] = 75943,
  [SMALL_STATE(3717)] = 76001,
  [SMALL_STATE(3718)] = 76063,
  [SMALL_STATE(3719)] = 76129,
  [SMALL_STATE(3720)] = 76187,
  [SMALL_STATE(3721)] = 76245,
  [SMALL_STATE(3722)] = 76307,
  [SMALL_STATE(3723)] = 76365,
  [SMALL_STATE(3724)] = 76423,
  [SMALL_STATE(3725)] = 76481,
  [SMALL_STATE(3726)] = 76541,
  [SMALL_STATE(3727)] = 76599,
  [SMALL_STATE(3728)] = 76657,
  [SMALL_STATE(3729)] = 76719,
  [SMALL_STATE(3730)] = 76777,
  [SMALL_STATE(3731)] = 76835,
  [SMALL_STATE(3732)] = 76893,
  [SMALL_STATE(3733)] = 76951,
  [SMALL_STATE(3734)] = 77009,
  [SMALL_STATE(3735)] = 77067,
  [SMALL_STATE(3736)] = 77125,
  [SMALL_STATE(3737)] = 77183,
  [SMALL_STATE(3738)] = 77241,
  [SMALL_STATE(3739)] = 77299,
  [SMALL_STATE(3740)] = 77401,
  [SMALL_STATE(3741)] = 77459,
  [SMALL_STATE(3742)] = 77517,
  [SMALL_STATE(3743)] = 77579,
  [SMALL_STATE(3744)] = 77637,
  [SMALL_STATE(3745)] = 77695,
  [SMALL_STATE(3746)] = 77803,
  [SMALL_STATE(3747)] = 77861,
  [SMALL_STATE(3748)] = 77919,
  [SMALL_STATE(3749)] = 77977,
  [SMALL_STATE(3750)] = 78035,
  [SMALL_STATE(3751)] = 78093,
  [SMALL_STATE(3752)] = 78151,
  [SMALL_STATE(3753)] = 78209,
  [SMALL_STATE(3754)] = 78267,
  [SMALL_STATE(3755)] = 78325,
  [SMALL_STATE(3756)] = 78383,
  [SMALL_STATE(3757)] = 78491,
  [SMALL_STATE(3758)] = 78549,
  [SMALL_STATE(3759)] = 78623,
  [SMALL_STATE(3760)] = 78695,
  [SMALL_STATE(3761)] = 78757,
  [SMALL_STATE(3762)] = 78819,
  [SMALL_STATE(3763)] = 78891,
  [SMALL_STATE(3764)] = 78949,
  [SMALL_STATE(3765)] = 79007,
  [SMALL_STATE(3766)] = 79107,
  [SMALL_STATE(3767)] = 79165,
  [SMALL_STATE(3768)] = 79229,
  [SMALL_STATE(3769)] = 79331,
  [SMALL_STATE(3770)] = 79389,
  [SMALL_STATE(3771)] = 79447,
  [SMALL_STATE(3772)] = 79517,
  [SMALL_STATE(3773)] = 79575,
  [SMALL_STATE(3774)] = 79633,
  [SMALL_STATE(3775)] = 79731,
  [SMALL_STATE(3776)] = 79809,
  [SMALL_STATE(3777)] = 79867,
  [SMALL_STATE(3778)] = 79925,
  [SMALL_STATE(3779)] = 80019,
  [SMALL_STATE(3780)] = 80077,
  [SMALL_STATE(3781)] = 80153,
  [SMALL_STATE(3782)] = 80211,
  [SMALL_STATE(3783)] = 80269,
  [SMALL_STATE(3784)] = 80359,
  [SMALL_STATE(3785)] = 80417,
  [SMALL_STATE(3786)] = 80503,
  [SMALL_STATE(3787)] = 80561,
  [SMALL_STATE(3788)] = 80619,
  [SMALL_STATE(3789)] = 80677,
  [SMALL_STATE(3790)] = 80757,
  [SMALL_STATE(3791)] = 80815,
  [SMALL_STATE(3792)] = 80923,
  [SMALL_STATE(3793)] = 80981,
  [SMALL_STATE(3794)] = 81039,
  [SMALL_STATE(3795)] = 81147,
  [SMALL_STATE(3796)] = 81209,
  [SMALL_STATE(3797)] = 81267,
  [SMALL_STATE(3798)] = 81325,
  [SMALL_STATE(3799)] = 81383,
  [SMALL_STATE(3800)] = 81467,
  [SMALL_STATE(3801)] = 81524,
  [SMALL_STATE(3802)] = 81581,
  [SMALL_STATE(3803)] = 81640,
  [SMALL_STATE(3804)] = 81701,
  [SMALL_STATE(3805)] = 81760,
  [SMALL_STATE(3806)] = 81819,
  [SMALL_STATE(3807)] = 81878,
  [SMALL_STATE(3808)] = 81943,
  [SMALL_STATE(3809)] = 82002,
  [SMALL_STATE(3810)] = 82059,
  [SMALL_STATE(3811)] = 82128,
  [SMALL_STATE(3812)] = 82185,
  [SMALL_STATE(3813)] = 82250,
  [SMALL_STATE(3814)] = 82311,
  [SMALL_STATE(3815)] = 82368,
  [SMALL_STATE(3816)] = 82425,
  [SMALL_STATE(3817)] = 82482,
  [SMALL_STATE(3818)] = 82539,
  [SMALL_STATE(3819)] = 82644,
  [SMALL_STATE(3820)] = 82713,
  [SMALL_STATE(3821)] = 82770,
  [SMALL_STATE(3822)] = 82829,
  [SMALL_STATE(3823)] = 82922,
  [SMALL_STATE(3824)] = 83015,
  [SMALL_STATE(3825)] = 83078,
  [SMALL_STATE(3826)] = 83135,
  [SMALL_STATE(3827)] = 83192,
  [SMALL_STATE(3828)] = 83249,
  [SMALL_STATE(3829)] = 83306,
  [SMALL_STATE(3830)] = 83363,
  [SMALL_STATE(3831)] = 83420,
  [SMALL_STATE(3832)] = 83476,
  [SMALL_STATE(3833)] = 83532,
  [SMALL_STATE(3834)] = 83634,
  [SMALL_STATE(3835)] = 83690,
  [SMALL_STATE(3836)] = 83792,
  [SMALL_STATE(3837)] = 83848,
  [SMALL_STATE(3838)] = 83950,
  [SMALL_STATE(3839)] = 84052,
  [SMALL_STATE(3840)] = 84154,
  [SMALL_STATE(3841)] = 84256,
  [SMALL_STATE(3842)] = 84312,
  [SMALL_STATE(3843)] = 84368,
  [SMALL_STATE(3844)] = 84424,
  [SMALL_STATE(3845)] = 84526,
  [SMALL_STATE(3846)] = 84582,
  [SMALL_STATE(3847)] = 84684,
  [SMALL_STATE(3848)] = 84786,
  [SMALL_STATE(3849)] = 84858,
  [SMALL_STATE(3850)] = 84914,
  [SMALL_STATE(3851)] = 84970,
  [SMALL_STATE(3852)] = 85072,
  [SMALL_STATE(3853)] = 85128,
  [SMALL_STATE(3854)] = 85230,
  [SMALL_STATE(3855)] = 85332,
  [SMALL_STATE(3856)] = 85388,
  [SMALL_STATE(3857)] = 85490,
  [SMALL_STATE(3858)] = 85546,
  [SMALL_STATE(3859)] = 85602,
  [SMALL_STATE(3860)] = 85704,
  [SMALL_STATE(3861)] = 85760,
  [SMALL_STATE(3862)] = 85826,
  [SMALL_STATE(3863)] = 85882,
  [SMALL_STATE(3864)] = 85938,
  [SMALL_STATE(3865)] = 85994,
  [SMALL_STATE(3866)] = 86050,
  [SMALL_STATE(3867)] = 86152,
  [SMALL_STATE(3868)] = 86254,
  [SMALL_STATE(3869)] = 86356,
  [SMALL_STATE(3870)] = 86416,
  [SMALL_STATE(3871)] = 86488,
  [SMALL_STATE(3872)] = 86550,
  [SMALL_STATE(3873)] = 86606,
  [SMALL_STATE(3874)] = 86662,
  [SMALL_STATE(3875)] = 86734,
  [SMALL_STATE(3876)] = 86790,
  [SMALL_STATE(3877)] = 86846,
  [SMALL_STATE(3878)] = 86914,
  [SMALL_STATE(3879)] = 86970,
  [SMALL_STATE(3880)] = 87026,
  [SMALL_STATE(3881)] = 87128,
  [SMALL_STATE(3882)] = 87184,
  [SMALL_STATE(3883)] = 87286,
  [SMALL_STATE(3884)] = 87342,
  [SMALL_STATE(3885)] = 87444,
  [SMALL_STATE(3886)] = 87546,
  [SMALL_STATE(3887)] = 87648,
  [SMALL_STATE(3888)] = 87750,
  [SMALL_STATE(3889)] = 87852,
  [SMALL_STATE(3890)] = 87954,
  [SMALL_STATE(3891)] = 88010,
  [SMALL_STATE(3892)] = 88116,
  [SMALL_STATE(3893)] = 88218,
  [SMALL_STATE(3894)] = 88274,
  [SMALL_STATE(3895)] = 88376,
  [SMALL_STATE(3896)] = 88432,
  [SMALL_STATE(3897)] = 88488,
  [SMALL_STATE(3898)] = 88590,
  [SMALL_STATE(3899)] = 88692,
  [SMALL_STATE(3900)] = 88748,
  [SMALL_STATE(3901)] = 88804,
  [SMALL_STATE(3902)] = 88860,
  [SMALL_STATE(3903)] = 88928,
  [SMALL_STATE(3904)] = 89030,
  [SMALL_STATE(3905)] = 89132,
  [SMALL_STATE(3906)] = 89202,
  [SMALL_STATE(3907)] = 89258,
  [SMALL_STATE(3908)] = 89360,
  [SMALL_STATE(3909)] = 89466,
  [SMALL_STATE(3910)] = 89568,
  [SMALL_STATE(3911)] = 89624,
  [SMALL_STATE(3912)] = 89726,
  [SMALL_STATE(3913)] = 89828,
  [SMALL_STATE(3914)] = 89890,
  [SMALL_STATE(3915)] = 89992,
  [SMALL_STATE(3916)] = 90048,
  [SMALL_STATE(3917)] = 90150,
  [SMALL_STATE(3918)] = 90252,
  [SMALL_STATE(3919)] = 90308,
  [SMALL_STATE(3920)] = 90410,
  [SMALL_STATE(3921)] = 90512,
  [SMALL_STATE(3922)] = 90614,
  [SMALL_STATE(3923)] = 90716,
  [SMALL_STATE(3924)] = 90772,
  [SMALL_STATE(3925)] = 90874,
  [SMALL_STATE(3926)] = 90930,
  [SMALL_STATE(3927)] = 91032,
  [SMALL_STATE(3928)] = 91134,
  [SMALL_STATE(3929)] = 91190,
  [SMALL_STATE(3930)] = 91292,
  [SMALL_STATE(3931)] = 91362,
  [SMALL_STATE(3932)] = 91432,
  [SMALL_STATE(3933)] = 91488,
  [SMALL_STATE(3934)] = 91544,
  [SMALL_STATE(3935)] = 91600,
  [SMALL_STATE(3936)] = 91658,
  [SMALL_STATE(3937)] = 91760,
  [SMALL_STATE(3938)] = 91862,
  [SMALL_STATE(3939)] = 91932,
  [SMALL_STATE(3940)] = 91988,
  [SMALL_STATE(3941)] = 92044,
  [SMALL_STATE(3942)] = 92146,
  [SMALL_STATE(3943)] = 92248,
  [SMALL_STATE(3944)] = 92350,
  [SMALL_STATE(3945)] = 92406,
  [SMALL_STATE(3946)] = 92462,
  [SMALL_STATE(3947)] = 92518,
  [SMALL_STATE(3948)] = 92620,
  [SMALL_STATE(3949)] = 92676,
  [SMALL_STATE(3950)] = 92778,
  [SMALL_STATE(3951)] = 92834,
  [SMALL_STATE(3952)] = 92890,
  [SMALL_STATE(3953)] = 92992,
  [SMALL_STATE(3954)] = 93048,
  [SMALL_STATE(3955)] = 93150,
  [SMALL_STATE(3956)] = 93206,
  [SMALL_STATE(3957)] = 93308,
  [SMALL_STATE(3958)] = 93364,
  [SMALL_STATE(3959)] = 93466,
  [SMALL_STATE(3960)] = 93522,
  [SMALL_STATE(3961)] = 93578,
  [SMALL_STATE(3962)] = 93634,
  [SMALL_STATE(3963)] = 93690,
  [SMALL_STATE(3964)] = 93746,
  [SMALL_STATE(3965)] = 93818,
  [SMALL_STATE(3966)] = 93874,
  [SMALL_STATE(3967)] = 93976,
  [SMALL_STATE(3968)] = 94032,
  [SMALL_STATE(3969)] = 94088,
  [SMALL_STATE(3970)] = 94190,
  [SMALL_STATE(3971)] = 94246,
  [SMALL_STATE(3972)] = 94348,
  [SMALL_STATE(3973)] = 94450,
  [SMALL_STATE(3974)] = 94552,
  [SMALL_STATE(3975)] = 94654,
  [SMALL_STATE(3976)] = 94756,
  [SMALL_STATE(3977)] = 94812,
  [SMALL_STATE(3978)] = 94914,
  [SMALL_STATE(3979)] = 95016,
  [SMALL_STATE(3980)] = 95072,
  [SMALL_STATE(3981)] = 95128,
  [SMALL_STATE(3982)] = 95184,
  [SMALL_STATE(3983)] = 95240,
  [SMALL_STATE(3984)] = 95342,
  [SMALL_STATE(3985)] = 95397,
  [SMALL_STATE(3986)] = 95452,
  [SMALL_STATE(3987)] = 95507,
  [SMALL_STATE(3988)] = 95606,
  [SMALL_STATE(3989)] = 95705,
  [SMALL_STATE(3990)] = 95760,
  [SMALL_STATE(3991)] = 95859,
  [SMALL_STATE(3992)] = 95958,
  [SMALL_STATE(3993)] = 96013,
  [SMALL_STATE(3994)] = 96068,
  [SMALL_STATE(3995)] = 96123,
  [SMALL_STATE(3996)] = 96214,
  [SMALL_STATE(3997)] = 96305,
  [SMALL_STATE(3998)] = 96404,
  [SMALL_STATE(3999)] = 96459,
  [SMALL_STATE(4000)] = 96514,
  [SMALL_STATE(4001)] = 96613,
  [SMALL_STATE(4002)] = 96668,
  [SMALL_STATE(4003)] = 96723,
  [SMALL_STATE(4004)] = 96778,
  [SMALL_STATE(4005)] = 96877,
  [SMALL_STATE(4006)] = 96932,
  [SMALL_STATE(4007)] = 97031,
  [SMALL_STATE(4008)] = 97094,
  [SMALL_STATE(4009)] = 97149,
  [SMALL_STATE(4010)] = 97204,
  [SMALL_STATE(4011)] = 97303,
  [SMALL_STATE(4012)] = 97402,
  [SMALL_STATE(4013)] = 97457,
  [SMALL_STATE(4014)] = 97520,
  [SMALL_STATE(4015)] = 97575,
  [SMALL_STATE(4016)] = 97630,
  [SMALL_STATE(4017)] = 97685,
  [SMALL_STATE(4018)] = 97740,
  [SMALL_STATE(4019)] = 97795,
  [SMALL_STATE(4020)] = 97850,
  [SMALL_STATE(4021)] = 97913,
  [SMALL_STATE(4022)] = 97968,
  [SMALL_STATE(4023)] = 98023,
  [SMALL_STATE(4024)] = 98086,
  [SMALL_STATE(4025)] = 98141,
  [SMALL_STATE(4026)] = 98196,
  [SMALL_STATE(4027)] = 98295,
  [SMALL_STATE(4028)] = 98350,
  [SMALL_STATE(4029)] = 98405,
  [SMALL_STATE(4030)] = 98460,
  [SMALL_STATE(4031)] = 98559,
  [SMALL_STATE(4032)] = 98626,
  [SMALL_STATE(4033)] = 98693,
  [SMALL_STATE(4034)] = 98748,
  [SMALL_STATE(4035)] = 98803,
  [SMALL_STATE(4036)] = 98902,
  [SMALL_STATE(4037)] = 98957,
  [SMALL_STATE(4038)] = 99012,
  [SMALL_STATE(4039)] = 99067,
  [SMALL_STATE(4040)] = 99166,
  [SMALL_STATE(4041)] = 99236,
  [SMALL_STATE(4042)] = 99328,
  [SMALL_STATE(4043)] = 99386,
  [SMALL_STATE(4044)] = 99444,
  [SMALL_STATE(4045)] = 99502,
  [SMALL_STATE(4046)] = 99560,
  [SMALL_STATE(4047)] = 99652,
  [SMALL_STATE(4048)] = 99744,
  [SMALL_STATE(4049)] = 99802,
  [SMALL_STATE(4050)] = 99892,
  [SMALL_STATE(4051)] = 99984,
  [SMALL_STATE(4052)] = 100076,
  [SMALL_STATE(4053)] = 100134,
  [SMALL_STATE(4054)] = 100224,
  [SMALL_STATE(4055)] = 100316,
  [SMALL_STATE(4056)] = 100408,
  [SMALL_STATE(4057)] = 100500,
  [SMALL_STATE(4058)] = 100592,
  [SMALL_STATE(4059)] = 100652,
  [SMALL_STATE(4060)] = 100722,
  [SMALL_STATE(4061)] = 100792,
  [SMALL_STATE(4062)] = 100850,
  [SMALL_STATE(4063)] = 100942,
  [SMALL_STATE(4064)] = 101034,
  [SMALL_STATE(4065)] = 101126,
  [SMALL_STATE(4066)] = 101184,
  [SMALL_STATE(4067)] = 101276,
  [SMALL_STATE(4068)] = 101338,
  [SMALL_STATE(4069)] = 101398,
  [SMALL_STATE(4070)] = 101490,
  [SMALL_STATE(4071)] = 101550,
  [SMALL_STATE(4072)] = 101614,
  [SMALL_STATE(4073)] = 101672,
  [SMALL_STATE(4074)] = 101732,
  [SMALL_STATE(4075)] = 101824,
  [SMALL_STATE(4076)] = 101882,
  [SMALL_STATE(4077)] = 101940,
  [SMALL_STATE(4078)] = 102010,
  [SMALL_STATE(4079)] = 102068,
  [SMALL_STATE(4080)] = 102121,
  [SMALL_STATE(4081)] = 102206,
  [SMALL_STATE(4082)] = 102259,
  [SMALL_STATE(4083)] = 102366,
  [SMALL_STATE(4084)] = 102419,
  [SMALL_STATE(4085)] = 102474,
  [SMALL_STATE(4086)] = 102527,
  [SMALL_STATE(4087)] = 102586,
  [SMALL_STATE(4088)] = 102639,
  [SMALL_STATE(4089)] = 102724,
  [SMALL_STATE(4090)] = 102783,
  [SMALL_STATE(4091)] = 102872,
  [SMALL_STATE(4092)] = 102961,
  [SMALL_STATE(4093)] = 103020,
  [SMALL_STATE(4094)] = 103109,
  [SMALL_STATE(4095)] = 103162,
  [SMALL_STATE(4096)] = 103215,
  [SMALL_STATE(4097)] = 103304,
  [SMALL_STATE(4098)] = 103411,
  [SMALL_STATE(4099)] = 103499,
  [SMALL_STATE(4100)] = 103587,
  [SMALL_STATE(4101)] = 103675,
  [SMALL_STATE(4102)] = 103763,
  [SMALL_STATE(4103)] = 103815,
  [SMALL_STATE(4104)] = 103883,
  [SMALL_STATE(4105)] = 103935,
  [SMALL_STATE(4106)] = 104023,
  [SMALL_STATE(4107)] = 104075,
  [SMALL_STATE(4108)] = 104127,
  [SMALL_STATE(4109)] = 104195,
  [SMALL_STATE(4110)] = 104247,
  [SMALL_STATE(4111)] = 104335,
  [SMALL_STATE(4112)] = 104423,
  [SMALL_STATE(4113)] = 104475,
  [SMALL_STATE(4114)] = 104563,
  [SMALL_STATE(4115)] = 104615,
  [SMALL_STATE(4116)] = 104683,
  [SMALL_STATE(4117)] = 104735,
  [SMALL_STATE(4118)] = 104787,
  [SMALL_STATE(4119)] = 104839,
  [SMALL_STATE(4120)] = 104891,
  [SMALL_STATE(4121)] = 104943,
  [SMALL_STATE(4122)] = 105031,
  [SMALL_STATE(4123)] = 105119,
  [SMALL_STATE(4124)] = 105171,
  [SMALL_STATE(4125)] = 105223,
  [SMALL_STATE(4126)] = 105287,
  [SMALL_STATE(4127)] = 105385,
  [SMALL_STATE(4128)] = 105473,
  [SMALL_STATE(4129)] = 105537,
  [SMALL_STATE(4130)] = 105625,
  [SMALL_STATE(4131)] = 105713,
  [SMALL_STATE(4132)] = 105765,
  [SMALL_STATE(4133)] = 105853,
  [SMALL_STATE(4134)] = 105941,
  [SMALL_STATE(4135)] = 106009,
  [SMALL_STATE(4136)] = 106061,
  [SMALL_STATE(4137)] = 106149,
  [SMALL_STATE(4138)] = 106237,
  [SMALL_STATE(4139)] = 106325,
  [SMALL_STATE(4140)] = 106413,
  [SMALL_STATE(4141)] = 106501,
  [SMALL_STATE(4142)] = 106589,
  [SMALL_STATE(4143)] = 106677,
  [SMALL_STATE(4144)] = 106761,
  [SMALL_STATE(4145)] = 106813,
  [SMALL_STATE(4146)] = 106865,
  [SMALL_STATE(4147)] = 106953,
  [SMALL_STATE(4148)] = 107005,
  [SMALL_STATE(4149)] = 107057,
  [SMALL_STATE(4150)] = 107109,
  [SMALL_STATE(4151)] = 107161,
  [SMALL_STATE(4152)] = 107249,
  [SMALL_STATE(4153)] = 107337,
  [SMALL_STATE(4154)] = 107389,
  [SMALL_STATE(4155)] = 107441,
  [SMALL_STATE(4156)] = 107529,
  [SMALL_STATE(4157)] = 107581,
  [SMALL_STATE(4158)] = 107669,
  [SMALL_STATE(4159)] = 107721,
  [SMALL_STATE(4160)] = 107809,
  [SMALL_STATE(4161)] = 107897,
  [SMALL_STATE(4162)] = 107949,
  [SMALL_STATE(4163)] = 108001,
  [SMALL_STATE(4164)] = 108053,
  [SMALL_STATE(4165)] = 108105,
  [SMALL_STATE(4166)] = 108189,
  [SMALL_STATE(4167)] = 108241,
  [SMALL_STATE(4168)] = 108329,
  [SMALL_STATE(4169)] = 108381,
  [SMALL_STATE(4170)] = 108469,
  [SMALL_STATE(4171)] = 108521,
  [SMALL_STATE(4172)] = 108573,
  [SMALL_STATE(4173)] = 108661,
  [SMALL_STATE(4174)] = 108749,
  [SMALL_STATE(4175)] = 108837,
  [SMALL_STATE(4176)] = 108940,
  [SMALL_STATE(4177)] = 108991,
  [SMALL_STATE(4178)] = 109078,
  [SMALL_STATE(4179)] = 109181,
  [SMALL_STATE(4180)] = 109232,
  [SMALL_STATE(4181)] = 109331,
  [SMALL_STATE(4182)] = 109382,
  [SMALL_STATE(4183)] = 109447,
  [SMALL_STATE(4184)] = 109514,
  [SMALL_STATE(4185)] = 109601,
  [SMALL_STATE(4186)] = 109668,
  [SMALL_STATE(4187)] = 109725,
  [SMALL_STATE(4188)] = 109824,
  [SMALL_STATE(4189)] = 109893,
  [SMALL_STATE(4190)] = 109988,
  [SMALL_STATE(4191)] = 110079,
  [SMALL_STATE(4192)] = 110168,
  [SMALL_STATE(4193)] = 110253,
  [SMALL_STATE(4194)] = 110336,
  [SMALL_STATE(4195)] = 110415,
  [SMALL_STATE(4196)] = 110480,
  [SMALL_STATE(4197)] = 110555,
  [SMALL_STATE(4198)] = 110658,
  [SMALL_STATE(4199)] = 110757,
  [SMALL_STATE(4200)] = 110856,
  [SMALL_STATE(4201)] = 110923,
  [SMALL_STATE(4202)] = 110994,
  [SMALL_STATE(4203)] = 111051,
  [SMALL_STATE(4204)] = 111102,
  [SMALL_STATE(4205)] = 111169,
  [SMALL_STATE(4206)] = 111220,
  [SMALL_STATE(4207)] = 111323,
  [SMALL_STATE(4208)] = 111374,
  [SMALL_STATE(4209)] = 111447,
  [SMALL_STATE(4210)] = 111499,
  [SMALL_STATE(4211)] = 111583,
  [SMALL_STATE(4212)] = 111667,
  [SMALL_STATE(4213)] = 111751,
  [SMALL_STATE(4214)] = 111807,
  [SMALL_STATE(4215)] = 111891,
  [SMALL_STATE(4216)] = 111977,
  [SMALL_STATE(4217)] = 112033,
  [SMALL_STATE(4218)] = 112117,
  [SMALL_STATE(4219)] = 112173,
  [SMALL_STATE(4220)] = 112249,
  [SMALL_STATE(4221)] = 112309,
  [SMALL_STATE(4222)] = 112385,
  [SMALL_STATE(4223)] = 112445,
  [SMALL_STATE(4224)] = 112521,
  [SMALL_STATE(4225)] = 112573,
  [SMALL_STATE(4226)] = 112657,
  [SMALL_STATE(4227)] = 112743,
  [SMALL_STATE(4228)] = 112827,
  [SMALL_STATE(4229)] = 112877,
  [SMALL_STATE(4230)] = 112959,
  [SMALL_STATE(4231)] = 113041,
  [SMALL_STATE(4232)] = 113117,
  [SMALL_STATE(4233)] = 113173,
  [SMALL_STATE(4234)] = 113257,
  [SMALL_STATE(4235)] = 113349,
  [SMALL_STATE(4236)] = 113400,
  [SMALL_STATE(4237)] = 113457,
  [SMALL_STATE(4238)] = 113506,
  [SMALL_STATE(4239)] = 113587,
  [SMALL_STATE(4240)] = 113662,
  [SMALL_STATE(4241)] = 113713,
  [SMALL_STATE(4242)] = 113766,
  [SMALL_STATE(4243)] = 113841,
  [SMALL_STATE(4244)] = 113922,
  [SMALL_STATE(4245)] = 113981,
  [SMALL_STATE(4246)] = 114056,
  [SMALL_STATE(4247)] = 114159,
  [SMALL_STATE(4248)] = 114214,
  [SMALL_STATE(4249)] = 114271,
  [SMALL_STATE(4250)] = 114356,
  [SMALL_STATE(4251)] = 114407,
  [SMALL_STATE(4252)] = 114460,
  [SMALL_STATE(4253)] = 114513,
  [SMALL_STATE(4254)] = 114616,
  [SMALL_STATE(4255)] = 114691,
  [SMALL_STATE(4256)] = 114794,
  [SMALL_STATE(4257)] = 114879,
  [SMALL_STATE(4258)] = 114964,
  [SMALL_STATE(4259)] = 115049,
  [SMALL_STATE(4260)] = 115143,
  [SMALL_STATE(4261)] = 115243,
  [SMALL_STATE(4262)] = 115323,
  [SMALL_STATE(4263)] = 115405,
  [SMALL_STATE(4264)] = 115495,
  [SMALL_STATE(4265)] = 115575,
  [SMALL_STATE(4266)] = 115623,
  [SMALL_STATE(4267)] = 115709,
  [SMALL_STATE(4268)] = 115803,
  [SMALL_STATE(4269)] = 115851,
  [SMALL_STATE(4270)] = 115935,
  [SMALL_STATE(4271)] = 116025,
  [SMALL_STATE(4272)] = 116115,
  [SMALL_STATE(4273)] = 116169,
  [SMALL_STATE(4274)] = 116217,
  [SMALL_STATE(4275)] = 116265,
  [SMALL_STATE(4276)] = 116313,
  [SMALL_STATE(4277)] = 116379,
  [SMALL_STATE(4278)] = 116427,
  [SMALL_STATE(4279)] = 116475,
  [SMALL_STATE(4280)] = 116563,
  [SMALL_STATE(4281)] = 116611,
  [SMALL_STATE(4282)] = 116659,
  [SMALL_STATE(4283)] = 116707,
  [SMALL_STATE(4284)] = 116787,
  [SMALL_STATE(4285)] = 116877,
  [SMALL_STATE(4286)] = 116931,
  [SMALL_STATE(4287)] = 116989,
  [SMALL_STATE(4288)] = 117057,
  [SMALL_STATE(4289)] = 117105,
  [SMALL_STATE(4290)] = 117177,
  [SMALL_STATE(4291)] = 117267,
  [SMALL_STATE(4292)] = 117323,
  [SMALL_STATE(4293)] = 117371,
  [SMALL_STATE(4294)] = 117451,
  [SMALL_STATE(4295)] = 117509,
  [SMALL_STATE(4296)] = 117585,
  [SMALL_STATE(4297)] = 117685,
  [SMALL_STATE(4298)] = 117737,
  [SMALL_STATE(4299)] = 117795,
  [SMALL_STATE(4300)] = 117849,
  [SMALL_STATE(4301)] = 117897,
  [SMALL_STATE(4302)] = 117945,
  [SMALL_STATE(4303)] = 117993,
  [SMALL_STATE(4304)] = 118071,
  [SMALL_STATE(4305)] = 118119,
  [SMALL_STATE(4306)] = 118167,
  [SMALL_STATE(4307)] = 118237,
  [SMALL_STATE(4308)] = 118327,
  [SMALL_STATE(4309)] = 118421,
  [SMALL_STATE(4310)] = 118472,
  [SMALL_STATE(4311)] = 118529,
  [SMALL_STATE(4312)] = 118580,
  [SMALL_STATE(4313)] = 118631,
  [SMALL_STATE(4314)] = 118710,
  [SMALL_STATE(4315)] = 118807,
  [SMALL_STATE(4316)] = 118904,
  [SMALL_STATE(4317)] = 118957,
  [SMALL_STATE(4318)] = 119054,
  [SMALL_STATE(4319)] = 119151,
  [SMALL_STATE(4320)] = 119230,
  [SMALL_STATE(4321)] = 119281,
  [SMALL_STATE(4322)] = 119378,
  [SMALL_STATE(4323)] = 119475,
  [SMALL_STATE(4324)] = 119572,
  [SMALL_STATE(4325)] = 119645,
  [SMALL_STATE(4326)] = 119742,
  [SMALL_STATE(4327)] = 119793,
  [SMALL_STATE(4328)] = 119890,
  [SMALL_STATE(4329)] = 119987,
  [SMALL_STATE(4330)] = 120082,
  [SMALL_STATE(4331)] = 120175,
  [SMALL_STATE(4332)] = 120272,
  [SMALL_STATE(4333)] = 120325,
  [SMALL_STATE(4334)] = 120422,
  [SMALL_STATE(4335)] = 120517,
  [SMALL_STATE(4336)] = 120570,
  [SMALL_STATE(4337)] = 120627,
  [SMALL_STATE(4338)] = 120724,
  [SMALL_STATE(4339)] = 120821,
  [SMALL_STATE(4340)] = 120914,
  [SMALL_STATE(4341)] = 121011,
  [SMALL_STATE(4342)] = 121108,
  [SMALL_STATE(4343)] = 121205,
  [SMALL_STATE(4344)] = 121302,
  [SMALL_STATE(4345)] = 121359,
  [SMALL_STATE(4346)] = 121456,
  [SMALL_STATE(4347)] = 121553,
  [SMALL_STATE(4348)] = 121600,
  [SMALL_STATE(4349)] = 121697,
  [SMALL_STATE(4350)] = 121794,
  [SMALL_STATE(4351)] = 121891,
  [SMALL_STATE(4352)] = 121974,
  [SMALL_STATE(4353)] = 122071,
  [SMALL_STATE(4354)] = 122150,
  [SMALL_STATE(4355)] = 122201,
  [SMALL_STATE(4356)] = 122298,
  [SMALL_STATE(4357)] = 122351,
  [SMALL_STATE(4358)] = 122444,
  [SMALL_STATE(4359)] = 122497,
  [SMALL_STATE(4360)] = 122546,
  [SMALL_STATE(4361)] = 122635,
  [SMALL_STATE(4362)] = 122732,
  [SMALL_STATE(4363)] = 122829,
  [SMALL_STATE(4364)] = 122926,
  [SMALL_STATE(4365)] = 123023,
  [SMALL_STATE(4366)] = 123074,
  [SMALL_STATE(4367)] = 123171,
  [SMALL_STATE(4368)] = 123268,
  [SMALL_STATE(4369)] = 123347,
  [SMALL_STATE(4370)] = 123430,
  [SMALL_STATE(4371)] = 123527,
  [SMALL_STATE(4372)] = 123624,
  [SMALL_STATE(4373)] = 123721,
  [SMALL_STATE(4374)] = 123794,
  [SMALL_STATE(4375)] = 123891,
  [SMALL_STATE(4376)] = 123988,
  [SMALL_STATE(4377)] = 124085,
  [SMALL_STATE(4378)] = 124178,
  [SMALL_STATE(4379)] = 124275,
  [SMALL_STATE(4380)] = 124372,
  [SMALL_STATE(4381)] = 124469,
  [SMALL_STATE(4382)] = 124566,
  [SMALL_STATE(4383)] = 124663,
  [SMALL_STATE(4384)] = 124760,
  [SMALL_STATE(4385)] = 124857,
  [SMALL_STATE(4386)] = 124954,
  [SMALL_STATE(4387)] = 125005,
  [SMALL_STATE(4388)] = 125102,
  [SMALL_STATE(4389)] = 125199,
  [SMALL_STATE(4390)] = 125296,
  [SMALL_STATE(4391)] = 125393,
  [SMALL_STATE(4392)] = 125490,
  [SMALL_STATE(4393)] = 125555,
  [SMALL_STATE(4394)] = 125642,
  [SMALL_STATE(4395)] = 125715,
  [SMALL_STATE(4396)] = 125794,
  [SMALL_STATE(4397)] = 125879,
  [SMALL_STATE(4398)] = 125976,
  [SMALL_STATE(4399)] = 126065,
  [SMALL_STATE(4400)] = 126162,
  [SMALL_STATE(4401)] = 126245,
  [SMALL_STATE(4402)] = 126342,
  [SMALL_STATE(4403)] = 126423,
  [SMALL_STATE(4404)] = 126500,
  [SMALL_STATE(4405)] = 126575,
  [SMALL_STATE(4406)] = 126646,
  [SMALL_STATE(4407)] = 126713,
  [SMALL_STATE(4408)] = 126810,
  [SMALL_STATE(4409)] = 126907,
  [SMALL_STATE(4410)] = 127004,
  [SMALL_STATE(4411)] = 127073,
  [SMALL_STATE(4412)] = 127170,
  [SMALL_STATE(4413)] = 127267,
  [SMALL_STATE(4414)] = 127320,
  [SMALL_STATE(4415)] = 127399,
  [SMALL_STATE(4416)] = 127488,
  [SMALL_STATE(4417)] = 127545,
  [SMALL_STATE(4418)] = 127642,
  [SMALL_STATE(4419)] = 127739,
  [SMALL_STATE(4420)] = 127836,
  [SMALL_STATE(4421)] = 127933,
  [SMALL_STATE(4422)] = 128026,
  [SMALL_STATE(4423)] = 128123,
  [SMALL_STATE(4424)] = 128220,
  [SMALL_STATE(4425)] = 128317,
  [SMALL_STATE(4426)] = 128414,
  [SMALL_STATE(4427)] = 128487,
  [SMALL_STATE(4428)] = 128584,
  [SMALL_STATE(4429)] = 128681,
  [SMALL_STATE(4430)] = 128770,
  [SMALL_STATE(4431)] = 128867,
  [SMALL_STATE(4432)] = 128931,
  [SMALL_STATE(4433)] = 129025,
  [SMALL_STATE(4434)] = 129117,
  [SMALL_STATE(4435)] = 129209,
  [SMALL_STATE(4436)] = 129297,
  [SMALL_STATE(4437)] = 129385,
  [SMALL_STATE(4438)] = 129453,
  [SMALL_STATE(4439)] = 129519,
  [SMALL_STATE(4440)] = 129589,
  [SMALL_STATE(4441)] = 129663,
  [SMALL_STATE(4442)] = 129739,
  [SMALL_STATE(4443)] = 129819,
  [SMALL_STATE(4444)] = 129901,
  [SMALL_STATE(4445)] = 129985,
  [SMALL_STATE(4446)] = 130071,
  [SMALL_STATE(4447)] = 130165,
  [SMALL_STATE(4448)] = 130257,
  [SMALL_STATE(4449)] = 130351,
  [SMALL_STATE(4450)] = 130439,
  [SMALL_STATE(4451)] = 130533,
  [SMALL_STATE(4452)] = 130625,
  [SMALL_STATE(4453)] = 130671,
  [SMALL_STATE(4454)] = 130765,
  [SMALL_STATE(4455)] = 130859,
  [SMALL_STATE(4456)] = 130951,
  [SMALL_STATE(4457)] = 131007,
  [SMALL_STATE(4458)] = 131099,
  [SMALL_STATE(4459)] = 131157,
  [SMALL_STATE(4460)] = 131251,
  [SMALL_STATE(4461)] = 131343,
  [SMALL_STATE(4462)] = 131437,
  [SMALL_STATE(4463)] = 131529,
  [SMALL_STATE(4464)] = 131623,
  [SMALL_STATE(4465)] = 131717,
  [SMALL_STATE(4466)] = 131773,
  [SMALL_STATE(4467)] = 131861,
  [SMALL_STATE(4468)] = 131909,
  [SMALL_STATE(4469)] = 131997,
  [SMALL_STATE(4470)] = 132091,
  [SMALL_STATE(4471)] = 132185,
  [SMALL_STATE(4472)] = 132277,
  [SMALL_STATE(4473)] = 132323,
  [SMALL_STATE(4474)] = 132417,
  [SMALL_STATE(4475)] = 132511,
  [SMALL_STATE(4476)] = 132603,
  [SMALL_STATE(4477)] = 132697,
  [SMALL_STATE(4478)] = 132789,
  [SMALL_STATE(4479)] = 132881,
  [SMALL_STATE(4480)] = 132931,
  [SMALL_STATE(4481)] = 133025,
  [SMALL_STATE(4482)] = 133119,
  [SMALL_STATE(4483)] = 133211,
  [SMALL_STATE(4484)] = 133289,
  [SMALL_STATE(4485)] = 133383,
  [SMALL_STATE(4486)] = 133475,
  [SMALL_STATE(4487)] = 133543,
  [SMALL_STATE(4488)] = 133637,
  [SMALL_STATE(4489)] = 133703,
  [SMALL_STATE(4490)] = 133749,
  [SMALL_STATE(4491)] = 133819,
  [SMALL_STATE(4492)] = 133913,
  [SMALL_STATE(4493)] = 134005,
  [SMALL_STATE(4494)] = 134099,
  [SMALL_STATE(4495)] = 134193,
  [SMALL_STATE(4496)] = 134285,
  [SMALL_STATE(4497)] = 134335,
  [SMALL_STATE(4498)] = 134385,
  [SMALL_STATE(4499)] = 134435,
  [SMALL_STATE(4500)] = 134487,
  [SMALL_STATE(4501)] = 134579,
  [SMALL_STATE(4502)] = 134673,
  [SMALL_STATE(4503)] = 134765,
  [SMALL_STATE(4504)] = 134815,
  [SMALL_STATE(4505)] = 134865,
  [SMALL_STATE(4506)] = 134959,
  [SMALL_STATE(4507)] = 135053,
  [SMALL_STATE(4508)] = 135127,
  [SMALL_STATE(4509)] = 135215,
  [SMALL_STATE(4510)] = 135307,
  [SMALL_STATE(4511)] = 135357,
  [SMALL_STATE(4512)] = 135451,
  [SMALL_STATE(4513)] = 135545,
  [SMALL_STATE(4514)] = 135637,
  [SMALL_STATE(4515)] = 135731,
  [SMALL_STATE(4516)] = 135781,
  [SMALL_STATE(4517)] = 135857,
  [SMALL_STATE(4518)] = 135937,
  [SMALL_STATE(4519)] = 135987,
  [SMALL_STATE(4520)] = 136069,
  [SMALL_STATE(4521)] = 136147,
  [SMALL_STATE(4522)] = 136195,
  [SMALL_STATE(4523)] = 136289,
  [SMALL_STATE(4524)] = 136337,
  [SMALL_STATE(4525)] = 136421,
  [SMALL_STATE(4526)] = 136515,
  [SMALL_STATE(4527)] = 136603,
  [SMALL_STATE(4528)] = 136689,
  [SMALL_STATE(4529)] = 136749,
  [SMALL_STATE(4530)] = 136841,
  [SMALL_STATE(4531)] = 136905,
  [SMALL_STATE(4532)] = 136997,
  [SMALL_STATE(4533)] = 137091,
  [SMALL_STATE(4534)] = 137183,
  [SMALL_STATE(4535)] = 137243,
  [SMALL_STATE(4536)] = 137335,
  [SMALL_STATE(4537)] = 137407,
  [SMALL_STATE(4538)] = 137457,
  [SMALL_STATE(4539)] = 137529,
  [SMALL_STATE(4540)] = 137623,
  [SMALL_STATE(4541)] = 137709,
  [SMALL_STATE(4542)] = 137803,
  [SMALL_STATE(4543)] = 137895,
  [SMALL_STATE(4544)] = 137951,
  [SMALL_STATE(4545)] = 138023,
  [SMALL_STATE(4546)] = 138117,
  [SMALL_STATE(4547)] = 138211,
  [SMALL_STATE(4548)] = 138299,
  [SMALL_STATE(4549)] = 138393,
  [SMALL_STATE(4550)] = 138449,
  [SMALL_STATE(4551)] = 138541,
  [SMALL_STATE(4552)] = 138635,
  [SMALL_STATE(4553)] = 138723,
  [SMALL_STATE(4554)] = 138817,
  [SMALL_STATE(4555)] = 138877,
  [SMALL_STATE(4556)] = 138937,
  [SMALL_STATE(4557)] = 139025,
  [SMALL_STATE(4558)] = 139085,
  [SMALL_STATE(4559)] = 139143,
  [SMALL_STATE(4560)] = 139237,
  [SMALL_STATE(4561)] = 139331,
  [SMALL_STATE(4562)] = 139425,
  [SMALL_STATE(4563)] = 139519,
  [SMALL_STATE(4564)] = 139577,
  [SMALL_STATE(4565)] = 139637,
  [SMALL_STATE(4566)] = 139707,
  [SMALL_STATE(4567)] = 139773,
  [SMALL_STATE(4568)] = 139845,
  [SMALL_STATE(4569)] = 139905,
  [SMALL_STATE(4570)] = 139979,
  [SMALL_STATE(4571)] = 140055,
  [SMALL_STATE(4572)] = 140135,
  [SMALL_STATE(4573)] = 140217,
  [SMALL_STATE(4574)] = 140301,
  [SMALL_STATE(4575)] = 140387,
  [SMALL_STATE(4576)] = 140447,
  [SMALL_STATE(4577)] = 140511,
  [SMALL_STATE(4578)] = 140583,
  [SMALL_STATE(4579)] = 140677,
  [SMALL_STATE(4580)] = 140739,
  [SMALL_STATE(4581)] = 140831,
  [SMALL_STATE(4582)] = 140919,
  [SMALL_STATE(4583)] = 140977,
  [SMALL_STATE(4584)] = 141065,
  [SMALL_STATE(4585)] = 141159,
  [SMALL_STATE(4586)] = 141250,
  [SMALL_STATE(4587)] = 141341,
  [SMALL_STATE(4588)] = 141432,
  [SMALL_STATE(4589)] = 141493,
  [SMALL_STATE(4590)] = 141584,
  [SMALL_STATE(4591)] = 141675,
  [SMALL_STATE(4592)] = 141766,
  [SMALL_STATE(4593)] = 141857,
  [SMALL_STATE(4594)] = 141948,
  [SMALL_STATE(4595)] = 142039,
  [SMALL_STATE(4596)] = 142110,
  [SMALL_STATE(4597)] = 142201,
  [SMALL_STATE(4598)] = 142292,
  [SMALL_STATE(4599)] = 142349,
  [SMALL_STATE(4600)] = 142440,
  [SMALL_STATE(4601)] = 142497,
  [SMALL_STATE(4602)] = 142588,
  [SMALL_STATE(4603)] = 142679,
  [SMALL_STATE(4604)] = 142770,
  [SMALL_STATE(4605)] = 142841,
  [SMALL_STATE(4606)] = 142932,
  [SMALL_STATE(4607)] = 143015,
  [SMALL_STATE(4608)] = 143086,
  [SMALL_STATE(4609)] = 143177,
  [SMALL_STATE(4610)] = 143268,
  [SMALL_STATE(4611)] = 143359,
  [SMALL_STATE(4612)] = 143450,
  [SMALL_STATE(4613)] = 143541,
  [SMALL_STATE(4614)] = 143632,
  [SMALL_STATE(4615)] = 143723,
  [SMALL_STATE(4616)] = 143814,
  [SMALL_STATE(4617)] = 143905,
  [SMALL_STATE(4618)] = 143996,
  [SMALL_STATE(4619)] = 144087,
  [SMALL_STATE(4620)] = 144178,
  [SMALL_STATE(4621)] = 144259,
  [SMALL_STATE(4622)] = 144350,
  [SMALL_STATE(4623)] = 144441,
  [SMALL_STATE(4624)] = 144532,
  [SMALL_STATE(4625)] = 144623,
  [SMALL_STATE(4626)] = 144668,
  [SMALL_STATE(4627)] = 144749,
  [SMALL_STATE(4628)] = 144840,
  [SMALL_STATE(4629)] = 144931,
  [SMALL_STATE(4630)] = 145022,
  [SMALL_STATE(4631)] = 145113,
  [SMALL_STATE(4632)] = 145204,
  [SMALL_STATE(4633)] = 145295,
  [SMALL_STATE(4634)] = 145376,
  [SMALL_STATE(4635)] = 145467,
  [SMALL_STATE(4636)] = 145558,
  [SMALL_STATE(4637)] = 145649,
  [SMALL_STATE(4638)] = 145740,
  [SMALL_STATE(4639)] = 145831,
  [SMALL_STATE(4640)] = 145912,
  [SMALL_STATE(4641)] = 146003,
  [SMALL_STATE(4642)] = 146094,
  [SMALL_STATE(4643)] = 146185,
  [SMALL_STATE(4644)] = 146276,
  [SMALL_STATE(4645)] = 146347,
  [SMALL_STATE(4646)] = 146438,
  [SMALL_STATE(4647)] = 146529,
  [SMALL_STATE(4648)] = 146620,
  [SMALL_STATE(4649)] = 146711,
  [SMALL_STATE(4650)] = 146802,
  [SMALL_STATE(4651)] = 146893,
  [SMALL_STATE(4652)] = 146984,
  [SMALL_STATE(4653)] = 147075,
  [SMALL_STATE(4654)] = 147166,
  [SMALL_STATE(4655)] = 147257,
  [SMALL_STATE(4656)] = 147348,
  [SMALL_STATE(4657)] = 147401,
  [SMALL_STATE(4658)] = 147492,
  [SMALL_STATE(4659)] = 147583,
  [SMALL_STATE(4660)] = 147674,
  [SMALL_STATE(4661)] = 147765,
  [SMALL_STATE(4662)] = 147856,
  [SMALL_STATE(4663)] = 147901,
  [SMALL_STATE(4664)] = 147992,
  [SMALL_STATE(4665)] = 148073,
  [SMALL_STATE(4666)] = 148118,
  [SMALL_STATE(4667)] = 148163,
  [SMALL_STATE(4668)] = 148254,
  [SMALL_STATE(4669)] = 148301,
  [SMALL_STATE(4670)] = 148348,
  [SMALL_STATE(4671)] = 148431,
  [SMALL_STATE(4672)] = 148478,
  [SMALL_STATE(4673)] = 148569,
  [SMALL_STATE(4674)] = 148660,
  [SMALL_STATE(4675)] = 148751,
  [SMALL_STATE(4676)] = 148796,
  [SMALL_STATE(4677)] = 148841,
  [SMALL_STATE(4678)] = 148932,
  [SMALL_STATE(4679)] = 148985,
  [SMALL_STATE(4680)] = 149030,
  [SMALL_STATE(4681)] = 149121,
  [SMALL_STATE(4682)] = 149166,
  [SMALL_STATE(4683)] = 149211,
  [SMALL_STATE(4684)] = 149256,
  [SMALL_STATE(4685)] = 149301,
  [SMALL_STATE(4686)] = 149346,
  [SMALL_STATE(4687)] = 149437,
  [SMALL_STATE(4688)] = 149528,
  [SMALL_STATE(4689)] = 149619,
  [SMALL_STATE(4690)] = 149710,
  [SMALL_STATE(4691)] = 149801,
  [SMALL_STATE(4692)] = 149846,
  [SMALL_STATE(4693)] = 149937,
  [SMALL_STATE(4694)] = 149992,
  [SMALL_STATE(4695)] = 150073,
  [SMALL_STATE(4696)] = 150120,
  [SMALL_STATE(4697)] = 150167,
  [SMALL_STATE(4698)] = 150258,
  [SMALL_STATE(4699)] = 150349,
  [SMALL_STATE(4700)] = 150440,
  [SMALL_STATE(4701)] = 150531,
  [SMALL_STATE(4702)] = 150622,
  [SMALL_STATE(4703)] = 150713,
  [SMALL_STATE(4704)] = 150796,
  [SMALL_STATE(4705)] = 150887,
  [SMALL_STATE(4706)] = 150978,
  [SMALL_STATE(4707)] = 151069,
  [SMALL_STATE(4708)] = 151160,
  [SMALL_STATE(4709)] = 151251,
  [SMALL_STATE(4710)] = 151342,
  [SMALL_STATE(4711)] = 151413,
  [SMALL_STATE(4712)] = 151504,
  [SMALL_STATE(4713)] = 151595,
  [SMALL_STATE(4714)] = 151686,
  [SMALL_STATE(4715)] = 151777,
  [SMALL_STATE(4716)] = 151868,
  [SMALL_STATE(4717)] = 151959,
  [SMALL_STATE(4718)] = 152050,
  [SMALL_STATE(4719)] = 152095,
  [SMALL_STATE(4720)] = 152166,
  [SMALL_STATE(4721)] = 152211,
  [SMALL_STATE(4722)] = 152256,
  [SMALL_STATE(4723)] = 152305,
  [SMALL_STATE(4724)] = 152376,
  [SMALL_STATE(4725)] = 152467,
  [SMALL_STATE(4726)] = 152538,
  [SMALL_STATE(4727)] = 152629,
  [SMALL_STATE(4728)] = 152720,
  [SMALL_STATE(4729)] = 152811,
  [SMALL_STATE(4730)] = 152902,
  [SMALL_STATE(4731)] = 152983,
  [SMALL_STATE(4732)] = 153074,
  [SMALL_STATE(4733)] = 153146,
  [SMALL_STATE(4734)] = 153224,
  [SMALL_STATE(4735)] = 153294,
  [SMALL_STATE(4736)] = 153372,
  [SMALL_STATE(4737)] = 153422,
  [SMALL_STATE(4738)] = 153492,
  [SMALL_STATE(4739)] = 153570,
  [SMALL_STATE(4740)] = 153614,
  [SMALL_STATE(4741)] = 153658,
  [SMALL_STATE(4742)] = 153702,
  [SMALL_STATE(4743)] = 153746,
  [SMALL_STATE(4744)] = 153824,
  [SMALL_STATE(4745)] = 153894,
  [SMALL_STATE(4746)] = 153966,
  [SMALL_STATE(4747)] = 154010,
  [SMALL_STATE(4748)] = 154082,
  [SMALL_STATE(4749)] = 154126,
  [SMALL_STATE(4750)] = 154170,
  [SMALL_STATE(4751)] = 154230,
  [SMALL_STATE(4752)] = 154306,
  [SMALL_STATE(4753)] = 154360,
  [SMALL_STATE(4754)] = 154436,
  [SMALL_STATE(4755)] = 154480,
  [SMALL_STATE(4756)] = 154558,
  [SMALL_STATE(4757)] = 154630,
  [SMALL_STATE(4758)] = 154676,
  [SMALL_STATE(4759)] = 154754,
  [SMALL_STATE(4760)] = 154798,
  [SMALL_STATE(4761)] = 154842,
  [SMALL_STATE(4762)] = 154912,
  [SMALL_STATE(4763)] = 154956,
  [SMALL_STATE(4764)] = 155000,
  [SMALL_STATE(4765)] = 155044,
  [SMALL_STATE(4766)] = 155114,
  [SMALL_STATE(4767)] = 155184,
  [SMALL_STATE(4768)] = 155254,
  [SMALL_STATE(4769)] = 155324,
  [SMALL_STATE(4770)] = 155374,
  [SMALL_STATE(4771)] = 155444,
  [SMALL_STATE(4772)] = 155516,
  [SMALL_STATE(4773)] = 155560,
  [SMALL_STATE(4774)] = 155604,
  [SMALL_STATE(4775)] = 155648,
  [SMALL_STATE(4776)] = 155692,
  [SMALL_STATE(4777)] = 155736,
  [SMALL_STATE(4778)] = 155812,
  [SMALL_STATE(4779)] = 155864,
  [SMALL_STATE(4780)] = 155952,
  [SMALL_STATE(4781)] = 156030,
  [SMALL_STATE(4782)] = 156108,
  [SMALL_STATE(4783)] = 156186,
  [SMALL_STATE(4784)] = 156262,
  [SMALL_STATE(4785)] = 156334,
  [SMALL_STATE(4786)] = 156412,
  [SMALL_STATE(4787)] = 156484,
  [SMALL_STATE(4788)] = 156562,
  [SMALL_STATE(4789)] = 156634,
  [SMALL_STATE(4790)] = 156678,
  [SMALL_STATE(4791)] = 156722,
  [SMALL_STATE(4792)] = 156770,
  [SMALL_STATE(4793)] = 156814,
  [SMALL_STATE(4794)] = 156886,
  [SMALL_STATE(4795)] = 156930,
  [SMALL_STATE(4796)] = 156982,
  [SMALL_STATE(4797)] = 157026,
  [SMALL_STATE(4798)] = 157070,
  [SMALL_STATE(4799)] = 157114,
  [SMALL_STATE(4800)] = 157158,
  [SMALL_STATE(4801)] = 157230,
  [SMALL_STATE(4802)] = 157274,
  [SMALL_STATE(4803)] = 157318,
  [SMALL_STATE(4804)] = 157390,
  [SMALL_STATE(4805)] = 157468,
  [SMALL_STATE(4806)] = 157546,
  [SMALL_STATE(4807)] = 157618,
  [SMALL_STATE(4808)] = 157662,
  [SMALL_STATE(4809)] = 157706,
  [SMALL_STATE(4810)] = 157784,
  [SMALL_STATE(4811)] = 157862,
  [SMALL_STATE(4812)] = 157940,
  [SMALL_STATE(4813)] = 158010,
  [SMALL_STATE(4814)] = 158088,
  [SMALL_STATE(4815)] = 158166,
  [SMALL_STATE(4816)] = 158222,
  [SMALL_STATE(4817)] = 158266,
  [SMALL_STATE(4818)] = 158338,
  [SMALL_STATE(4819)] = 158382,
  [SMALL_STATE(4820)] = 158454,
  [SMALL_STATE(4821)] = 158498,
  [SMALL_STATE(4822)] = 158542,
  [SMALL_STATE(4823)] = 158614,
  [SMALL_STATE(4824)] = 158658,
  [SMALL_STATE(4825)] = 158736,
  [SMALL_STATE(4826)] = 158814,
  [SMALL_STATE(4827)] = 158866,
  [SMALL_STATE(4828)] = 158938,
  [SMALL_STATE(4829)] = 158982,
  [SMALL_STATE(4830)] = 159026,
  [SMALL_STATE(4831)] = 159096,
  [SMALL_STATE(4832)] = 159168,
  [SMALL_STATE(4833)] = 159240,
  [SMALL_STATE(4834)] = 159312,
  [SMALL_STATE(4835)] = 159390,
  [SMALL_STATE(4836)] = 159462,
  [SMALL_STATE(4837)] = 159534,
  [SMALL_STATE(4838)] = 159578,
  [SMALL_STATE(4839)] = 159648,
  [SMALL_STATE(4840)] = 159726,
  [SMALL_STATE(4841)] = 159770,
  [SMALL_STATE(4842)] = 159818,
  [SMALL_STATE(4843)] = 159874,
  [SMALL_STATE(4844)] = 159925,
  [SMALL_STATE(4845)] = 159972,
  [SMALL_STATE(4846)] = 160053,
  [SMALL_STATE(4847)] = 160098,
  [SMALL_STATE(4848)] = 160179,
  [SMALL_STATE(4849)] = 160226,
  [SMALL_STATE(4850)] = 160273,
  [SMALL_STATE(4851)] = 160320,
  [SMALL_STATE(4852)] = 160367,
  [SMALL_STATE(4853)] = 160436,
  [SMALL_STATE(4854)] = 160505,
  [SMALL_STATE(4855)] = 160552,
  [SMALL_STATE(4856)] = 160599,
  [SMALL_STATE(4857)] = 160646,
  [SMALL_STATE(4858)] = 160693,
  [SMALL_STATE(4859)] = 160740,
  [SMALL_STATE(4860)] = 160787,
  [SMALL_STATE(4861)] = 160834,
  [SMALL_STATE(4862)] = 160881,
  [SMALL_STATE(4863)] = 160928,
  [SMALL_STATE(4864)] = 160997,
  [SMALL_STATE(4865)] = 161044,
  [SMALL_STATE(4866)] = 161091,
  [SMALL_STATE(4867)] = 161138,
  [SMALL_STATE(4868)] = 161197,
  [SMALL_STATE(4869)] = 161246,
  [SMALL_STATE(4870)] = 161293,
  [SMALL_STATE(4871)] = 161340,
  [SMALL_STATE(4872)] = 161409,
  [SMALL_STATE(4873)] = 161462,
  [SMALL_STATE(4874)] = 161513,
  [SMALL_STATE(4875)] = 161581,
  [SMALL_STATE(4876)] = 161623,
  [SMALL_STATE(4877)] = 161665,
  [SMALL_STATE(4878)] = 161711,
  [SMALL_STATE(4879)] = 161753,
  [SMALL_STATE(4880)] = 161795,
  [SMALL_STATE(4881)] = 161837,
  [SMALL_STATE(4882)] = 161879,
  [SMALL_STATE(4883)] = 161921,
  [SMALL_STATE(4884)] = 161963,
  [SMALL_STATE(4885)] = 162037,
  [SMALL_STATE(4886)] = 162079,
  [SMALL_STATE(4887)] = 162121,
  [SMALL_STATE(4888)] = 162163,
  [SMALL_STATE(4889)] = 162205,
  [SMALL_STATE(4890)] = 162251,
  [SMALL_STATE(4891)] = 162305,
  [SMALL_STATE(4892)] = 162351,
  [SMALL_STATE(4893)] = 162405,
  [SMALL_STATE(4894)] = 162447,
  [SMALL_STATE(4895)] = 162489,
  [SMALL_STATE(4896)] = 162563,
  [SMALL_STATE(4897)] = 162605,
  [SMALL_STATE(4898)] = 162685,
  [SMALL_STATE(4899)] = 162727,
  [SMALL_STATE(4900)] = 162773,
  [SMALL_STATE(4901)] = 162817,
  [SMALL_STATE(4902)] = 162867,
  [SMALL_STATE(4903)] = 162913,
  [SMALL_STATE(4904)] = 162955,
  [SMALL_STATE(4905)] = 162997,
  [SMALL_STATE(4906)] = 163043,
  [SMALL_STATE(4907)] = 163123,
  [SMALL_STATE(4908)] = 163169,
  [SMALL_STATE(4909)] = 163221,
  [SMALL_STATE(4910)] = 163295,
  [SMALL_STATE(4911)] = 163369,
  [SMALL_STATE(4912)] = 163411,
  [SMALL_STATE(4913)] = 163453,
  [SMALL_STATE(4914)] = 163499,
  [SMALL_STATE(4915)] = 163541,
  [SMALL_STATE(4916)] = 163583,
  [SMALL_STATE(4917)] = 163651,
  [SMALL_STATE(4918)] = 163731,
  [SMALL_STATE(4919)] = 163777,
  [SMALL_STATE(4920)] = 163819,
  [SMALL_STATE(4921)] = 163861,
  [SMALL_STATE(4922)] = 163903,
  [SMALL_STATE(4923)] = 163977,
  [SMALL_STATE(4924)] = 164045,
  [SMALL_STATE(4925)] = 164087,
  [SMALL_STATE(4926)] = 164129,
  [SMALL_STATE(4927)] = 164175,
  [SMALL_STATE(4928)] = 164217,
  [SMALL_STATE(4929)] = 164285,
  [SMALL_STATE(4930)] = 164327,
  [SMALL_STATE(4931)] = 164407,
  [SMALL_STATE(4932)] = 164449,
  [SMALL_STATE(4933)] = 164491,
  [SMALL_STATE(4934)] = 164533,
  [SMALL_STATE(4935)] = 164575,
  [SMALL_STATE(4936)] = 164643,
  [SMALL_STATE(4937)] = 164685,
  [SMALL_STATE(4938)] = 164753,
  [SMALL_STATE(4939)] = 164795,
  [SMALL_STATE(4940)] = 164837,
  [SMALL_STATE(4941)] = 164905,
  [SMALL_STATE(4942)] = 164947,
  [SMALL_STATE(4943)] = 164993,
  [SMALL_STATE(4944)] = 165039,
  [SMALL_STATE(4945)] = 165107,
  [SMALL_STATE(4946)] = 165149,
  [SMALL_STATE(4947)] = 165223,
  [SMALL_STATE(4948)] = 165307,
  [SMALL_STATE(4949)] = 165397,
  [SMALL_STATE(4950)] = 165464,
  [SMALL_STATE(4951)] = 165531,
  [SMALL_STATE(4952)] = 165572,
  [SMALL_STATE(4953)] = 165639,
  [SMALL_STATE(4954)] = 165688,
  [SMALL_STATE(4955)] = 165733,
  [SMALL_STATE(4956)] = 165800,
  [SMALL_STATE(4957)] = 165841,
  [SMALL_STATE(4958)] = 165894,
  [SMALL_STATE(4959)] = 165935,
  [SMALL_STATE(4960)] = 165982,
  [SMALL_STATE(4961)] = 166023,
  [SMALL_STATE(4962)] = 166076,
  [SMALL_STATE(4963)] = 166127,
  [SMALL_STATE(4964)] = 166194,
  [SMALL_STATE(4965)] = 166261,
  [SMALL_STATE(4966)] = 166340,
  [SMALL_STATE(4967)] = 166393,
  [SMALL_STATE(4968)] = 166434,
  [SMALL_STATE(4969)] = 166513,
  [SMALL_STATE(4970)] = 166592,
  [SMALL_STATE(4971)] = 166645,
  [SMALL_STATE(4972)] = 166698,
  [SMALL_STATE(4973)] = 166741,
  [SMALL_STATE(4974)] = 166794,
  [SMALL_STATE(4975)] = 166835,
  [SMALL_STATE(4976)] = 166902,
  [SMALL_STATE(4977)] = 166981,
  [SMALL_STATE(4978)] = 167022,
  [SMALL_STATE(4979)] = 167089,
  [SMALL_STATE(4980)] = 167129,
  [SMALL_STATE(4981)] = 167169,
  [SMALL_STATE(4982)] = 167209,
  [SMALL_STATE(4983)] = 167287,
  [SMALL_STATE(4984)] = 167327,
  [SMALL_STATE(4985)] = 167407,
  [SMALL_STATE(4986)] = 167487,
  [SMALL_STATE(4987)] = 167527,
  [SMALL_STATE(4988)] = 167605,
  [SMALL_STATE(4989)] = 167685,
  [SMALL_STATE(4990)] = 167725,
  [SMALL_STATE(4991)] = 167765,
  [SMALL_STATE(4992)] = 167805,
  [SMALL_STATE(4993)] = 167883,
  [SMALL_STATE(4994)] = 167923,
  [SMALL_STATE(4995)] = 167963,
  [SMALL_STATE(4996)] = 168043,
  [SMALL_STATE(4997)] = 168083,
  [SMALL_STATE(4998)] = 168163,
  [SMALL_STATE(4999)] = 168203,
  [SMALL_STATE(5000)] = 168243,
  [SMALL_STATE(5001)] = 168283,
  [SMALL_STATE(5002)] = 168355,
  [SMALL_STATE(5003)] = 168395,
  [SMALL_STATE(5004)] = 168475,
  [SMALL_STATE(5005)] = 168555,
  [SMALL_STATE(5006)] = 168635,
  [SMALL_STATE(5007)] = 168675,
  [SMALL_STATE(5008)] = 168715,
  [SMALL_STATE(5009)] = 168795,
  [SMALL_STATE(5010)] = 168875,
  [SMALL_STATE(5011)] = 168947,
  [SMALL_STATE(5012)] = 168999,
  [SMALL_STATE(5013)] = 169077,
  [SMALL_STATE(5014)] = 169117,
  [SMALL_STATE(5015)] = 169157,
  [SMALL_STATE(5016)] = 169197,
  [SMALL_STATE(5017)] = 169277,
  [SMALL_STATE(5018)] = 169357,
  [SMALL_STATE(5019)] = 169397,
  [SMALL_STATE(5020)] = 169437,
  [SMALL_STATE(5021)] = 169477,
  [SMALL_STATE(5022)] = 169529,
  [SMALL_STATE(5023)] = 169609,
  [SMALL_STATE(5024)] = 169657,
  [SMALL_STATE(5025)] = 169737,
  [SMALL_STATE(5026)] = 169777,
  [SMALL_STATE(5027)] = 169817,
  [SMALL_STATE(5028)] = 169857,
  [SMALL_STATE(5029)] = 169937,
  [SMALL_STATE(5030)] = 170015,
  [SMALL_STATE(5031)] = 170095,
  [SMALL_STATE(5032)] = 170167,
  [SMALL_STATE(5033)] = 170207,
  [SMALL_STATE(5034)] = 170247,
  [SMALL_STATE(5035)] = 170327,
  [SMALL_STATE(5036)] = 170367,
  [SMALL_STATE(5037)] = 170407,
  [SMALL_STATE(5038)] = 170447,
  [SMALL_STATE(5039)] = 170527,
  [SMALL_STATE(5040)] = 170567,
  [SMALL_STATE(5041)] = 170615,
  [SMALL_STATE(5042)] = 170667,
  [SMALL_STATE(5043)] = 170707,
  [SMALL_STATE(5044)] = 170785,
  [SMALL_STATE(5045)] = 170857,
  [SMALL_STATE(5046)] = 170897,
  [SMALL_STATE(5047)] = 170937,
  [SMALL_STATE(5048)] = 171008,
  [SMALL_STATE(5049)] = 171061,
  [SMALL_STATE(5050)] = 171126,
  [SMALL_STATE(5051)] = 171175,
  [SMALL_STATE(5052)] = 171222,
  [SMALL_STATE(5053)] = 171275,
  [SMALL_STATE(5054)] = 171340,
  [SMALL_STATE(5055)] = 171411,
  [SMALL_STATE(5056)] = 171482,
  [SMALL_STATE(5057)] = 171547,
  [SMALL_STATE(5058)] = 171618,
  [SMALL_STATE(5059)] = 171689,
  [SMALL_STATE(5060)] = 171760,
  [SMALL_STATE(5061)] = 171825,
  [SMALL_STATE(5062)] = 171896,
  [SMALL_STATE(5063)] = 171967,
  [SMALL_STATE(5064)] = 172014,
  [SMALL_STATE(5065)] = 172094,
  [SMALL_STATE(5066)] = 172174,
  [SMALL_STATE(5067)] = 172216,
  [SMALL_STATE(5068)] = 172290,
  [SMALL_STATE(5069)] = 172360,
  [SMALL_STATE(5070)] = 172434,
  [SMALL_STATE(5071)] = 172476,
  [SMALL_STATE(5072)] = 172550,
  [SMALL_STATE(5073)] = 172624,
  [SMALL_STATE(5074)] = 172666,
  [SMALL_STATE(5075)] = 172736,
  [SMALL_STATE(5076)] = 172778,
  [SMALL_STATE(5077)] = 172820,
  [SMALL_STATE(5078)] = 172862,
  [SMALL_STATE(5079)] = 172904,
  [SMALL_STATE(5080)] = 172978,
  [SMALL_STATE(5081)] = 173024,
  [SMALL_STATE(5082)] = 173100,
  [SMALL_STATE(5083)] = 173174,
  [SMALL_STATE(5084)] = 173216,
  [SMALL_STATE(5085)] = 173286,
  [SMALL_STATE(5086)] = 173328,
  [SMALL_STATE(5087)] = 173370,
  [SMALL_STATE(5088)] = 173444,
  [SMALL_STATE(5089)] = 173524,
  [SMALL_STATE(5090)] = 173604,
  [SMALL_STATE(5091)] = 173674,
  [SMALL_STATE(5092)] = 173754,
  [SMALL_STATE(5093)] = 173796,
  [SMALL_STATE(5094)] = 173876,
  [SMALL_STATE(5095)] = 173950,
  [SMALL_STATE(5096)] = 173992,
  [SMALL_STATE(5097)] = 174072,
  [SMALL_STATE(5098)] = 174152,
  [SMALL_STATE(5099)] = 174194,
  [SMALL_STATE(5100)] = 174236,
  [SMALL_STATE(5101)] = 174316,
  [SMALL_STATE(5102)] = 174396,
  [SMALL_STATE(5103)] = 174476,
  [SMALL_STATE(5104)] = 174556,
  [SMALL_STATE(5105)] = 174598,
  [SMALL_STATE(5106)] = 174678,
  [SMALL_STATE(5107)] = 174752,
  [SMALL_STATE(5108)] = 174832,
  [SMALL_STATE(5109)] = 174906,
  [SMALL_STATE(5110)] = 174986,
  [SMALL_STATE(5111)] = 175066,
  [SMALL_STATE(5112)] = 175140,
  [SMALL_STATE(5113)] = 175220,
  [SMALL_STATE(5114)] = 175300,
  [SMALL_STATE(5115)] = 175380,
  [SMALL_STATE(5116)] = 175450,
  [SMALL_STATE(5117)] = 175530,
  [SMALL_STATE(5118)] = 175610,
  [SMALL_STATE(5119)] = 175684,
  [SMALL_STATE(5120)] = 175754,
  [SMALL_STATE(5121)] = 175834,
  [SMALL_STATE(5122)] = 175914,
  [SMALL_STATE(5123)] = 175988,
  [SMALL_STATE(5124)] = 176030,
  [SMALL_STATE(5125)] = 176100,
  [SMALL_STATE(5126)] = 176180,
  [SMALL_STATE(5127)] = 176260,
  [SMALL_STATE(5128)] = 176334,
  [SMALL_STATE(5129)] = 176376,
  [SMALL_STATE(5130)] = 176456,
  [SMALL_STATE(5131)] = 176530,
  [SMALL_STATE(5132)] = 176604,
  [SMALL_STATE(5133)] = 176684,
  [SMALL_STATE(5134)] = 176764,
  [SMALL_STATE(5135)] = 176806,
  [SMALL_STATE(5136)] = 176876,
  [SMALL_STATE(5137)] = 176918,
  [SMALL_STATE(5138)] = 176988,
  [SMALL_STATE(5139)] = 177062,
  [SMALL_STATE(5140)] = 177142,
  [SMALL_STATE(5141)] = 177212,
  [SMALL_STATE(5142)] = 177282,
  [SMALL_STATE(5143)] = 177356,
  [SMALL_STATE(5144)] = 177430,
  [SMALL_STATE(5145)] = 177510,
  [SMALL_STATE(5146)] = 177590,
  [SMALL_STATE(5147)] = 177664,
  [SMALL_STATE(5148)] = 177704,
  [SMALL_STATE(5149)] = 177778,
  [SMALL_STATE(5150)] = 177852,
  [SMALL_STATE(5151)] = 177926,
  [SMALL_STATE(5152)] = 178006,
  [SMALL_STATE(5153)] = 178086,
  [SMALL_STATE(5154)] = 178166,
  [SMALL_STATE(5155)] = 178246,
  [SMALL_STATE(5156)] = 178326,
  [SMALL_STATE(5157)] = 178376,
  [SMALL_STATE(5158)] = 178456,
  [SMALL_STATE(5159)] = 178536,
  [SMALL_STATE(5160)] = 178606,
  [SMALL_STATE(5161)] = 178686,
  [SMALL_STATE(5162)] = 178766,
  [SMALL_STATE(5163)] = 178840,
  [SMALL_STATE(5164)] = 178920,
  [SMALL_STATE(5165)] = 179000,
  [SMALL_STATE(5166)] = 179080,
  [SMALL_STATE(5167)] = 179160,
  [SMALL_STATE(5168)] = 179240,
  [SMALL_STATE(5169)] = 179314,
  [SMALL_STATE(5170)] = 179394,
  [SMALL_STATE(5171)] = 179474,
  [SMALL_STATE(5172)] = 179554,
  [SMALL_STATE(5173)] = 179628,
  [SMALL_STATE(5174)] = 179702,
  [SMALL_STATE(5175)] = 179782,
  [SMALL_STATE(5176)] = 179862,
  [SMALL_STATE(5177)] = 179942,
  [SMALL_STATE(5178)] = 180016,
  [SMALL_STATE(5179)] = 180086,
  [SMALL_STATE(5180)] = 180166,
  [SMALL_STATE(5181)] = 180240,
  [SMALL_STATE(5182)] = 180310,
  [SMALL_STATE(5183)] = 180390,
  [SMALL_STATE(5184)] = 180470,
  [SMALL_STATE(5185)] = 180544,
  [SMALL_STATE(5186)] = 180624,
  [SMALL_STATE(5187)] = 180704,
  [SMALL_STATE(5188)] = 180784,
  [SMALL_STATE(5189)] = 180854,
  [SMALL_STATE(5190)] = 180934,
  [SMALL_STATE(5191)] = 181014,
  [SMALL_STATE(5192)] = 181090,
  [SMALL_STATE(5193)] = 181170,
  [SMALL_STATE(5194)] = 181250,
  [SMALL_STATE(5195)] = 181330,
  [SMALL_STATE(5196)] = 181400,
  [SMALL_STATE(5197)] = 181480,
  [SMALL_STATE(5198)] = 181560,
  [SMALL_STATE(5199)] = 181640,
  [SMALL_STATE(5200)] = 181720,
  [SMALL_STATE(5201)] = 181768,
  [SMALL_STATE(5202)] = 181848,
  [SMALL_STATE(5203)] = 181928,
  [SMALL_STATE(5204)] = 182008,
  [SMALL_STATE(5205)] = 182088,
  [SMALL_STATE(5206)] = 182162,
  [SMALL_STATE(5207)] = 182236,
  [SMALL_STATE(5208)] = 182286,
  [SMALL_STATE(5209)] = 182366,
  [SMALL_STATE(5210)] = 182440,
  [SMALL_STATE(5211)] = 182520,
  [SMALL_STATE(5212)] = 182600,
  [SMALL_STATE(5213)] = 182680,
  [SMALL_STATE(5214)] = 182750,
  [SMALL_STATE(5215)] = 182830,
  [SMALL_STATE(5216)] = 182904,
  [SMALL_STATE(5217)] = 182978,
  [SMALL_STATE(5218)] = 183052,
  [SMALL_STATE(5219)] = 183126,
  [SMALL_STATE(5220)] = 183200,
  [SMALL_STATE(5221)] = 183274,
  [SMALL_STATE(5222)] = 183348,
  [SMALL_STATE(5223)] = 183389,
  [SMALL_STATE(5224)] = 183456,
  [SMALL_STATE(5225)] = 183525,
  [SMALL_STATE(5226)] = 183592,
  [SMALL_STATE(5227)] = 183669,
  [SMALL_STATE(5228)] = 183738,
  [SMALL_STATE(5229)] = 183805,
  [SMALL_STATE(5230)] = 183882,
  [SMALL_STATE(5231)] = 183949,
  [SMALL_STATE(5232)] = 184016,
  [SMALL_STATE(5233)] = 184057,
  [SMALL_STATE(5234)] = 184098,
  [SMALL_STATE(5235)] = 184175,
  [SMALL_STATE(5236)] = 184242,
  [SMALL_STATE(5237)] = 184311,
  [SMALL_STATE(5238)] = 184378,
  [SMALL_STATE(5239)] = 184455,
  [SMALL_STATE(5240)] = 184522,
  [SMALL_STATE(5241)] = 184599,
  [SMALL_STATE(5242)] = 184640,
  [SMALL_STATE(5243)] = 184707,
  [SMALL_STATE(5244)] = 184784,
  [SMALL_STATE(5245)] = 184851,
  [SMALL_STATE(5246)] = 184914,
  [SMALL_STATE(5247)] = 184981,
  [SMALL_STATE(5248)] = 185050,
  [SMALL_STATE(5249)] = 185119,
  [SMALL_STATE(5250)] = 185188,
  [SMALL_STATE(5251)] = 185251,
  [SMALL_STATE(5252)] = 185318,
  [SMALL_STATE(5253)] = 185385,
  [SMALL_STATE(5254)] = 185454,
  [SMALL_STATE(5255)] = 185521,
  [SMALL_STATE(5256)] = 185588,
  [SMALL_STATE(5257)] = 185655,
  [SMALL_STATE(5258)] = 185722,
  [SMALL_STATE(5259)] = 185799,
  [SMALL_STATE(5260)] = 185868,
  [SMALL_STATE(5261)] = 185937,
  [SMALL_STATE(5262)] = 186004,
  [SMALL_STATE(5263)] = 186081,
  [SMALL_STATE(5264)] = 186148,
  [SMALL_STATE(5265)] = 186225,
  [SMALL_STATE(5266)] = 186292,
  [SMALL_STATE(5267)] = 186369,
  [SMALL_STATE(5268)] = 186436,
  [SMALL_STATE(5269)] = 186503,
  [SMALL_STATE(5270)] = 186572,
  [SMALL_STATE(5271)] = 186641,
  [SMALL_STATE(5272)] = 186682,
  [SMALL_STATE(5273)] = 186745,
  [SMALL_STATE(5274)] = 186822,
  [SMALL_STATE(5275)] = 186885,
  [SMALL_STATE(5276)] = 186926,
  [SMALL_STATE(5277)] = 187003,
  [SMALL_STATE(5278)] = 187044,
  [SMALL_STATE(5279)] = 187111,
  [SMALL_STATE(5280)] = 187152,
  [SMALL_STATE(5281)] = 187219,
  [SMALL_STATE(5282)] = 187286,
  [SMALL_STATE(5283)] = 187355,
  [SMALL_STATE(5284)] = 187422,
  [SMALL_STATE(5285)] = 187489,
  [SMALL_STATE(5286)] = 187566,
  [SMALL_STATE(5287)] = 187633,
  [SMALL_STATE(5288)] = 187710,
  [SMALL_STATE(5289)] = 187777,
  [SMALL_STATE(5290)] = 187844,
  [SMALL_STATE(5291)] = 187911,
  [SMALL_STATE(5292)] = 187978,
  [SMALL_STATE(5293)] = 188045,
  [SMALL_STATE(5294)] = 188086,
  [SMALL_STATE(5295)] = 188149,
  [SMALL_STATE(5296)] = 188190,
  [SMALL_STATE(5297)] = 188257,
  [SMALL_STATE(5298)] = 188324,
  [SMALL_STATE(5299)] = 188401,
  [SMALL_STATE(5300)] = 188468,
  [SMALL_STATE(5301)] = 188545,
  [SMALL_STATE(5302)] = 188622,
  [SMALL_STATE(5303)] = 188699,
  [SMALL_STATE(5304)] = 188766,
  [SMALL_STATE(5305)] = 188833,
  [SMALL_STATE(5306)] = 188874,
  [SMALL_STATE(5307)] = 188941,
  [SMALL_STATE(5308)] = 189004,
  [SMALL_STATE(5309)] = 189045,
  [SMALL_STATE(5310)] = 189112,
  [SMALL_STATE(5311)] = 189156,
  [SMALL_STATE(5312)] = 189196,
  [SMALL_STATE(5313)] = 189240,
  [SMALL_STATE(5314)] = 189301,
  [SMALL_STATE(5315)] = 189362,
  [SMALL_STATE(5316)] = 189423,
  [SMALL_STATE(5317)] = 189484,
  [SMALL_STATE(5318)] = 189523,
  [SMALL_STATE(5319)] = 189584,
  [SMALL_STATE(5320)] = 189651,
  [SMALL_STATE(5321)] = 189718,
  [SMALL_STATE(5322)] = 189753,
  [SMALL_STATE(5323)] = 189820,
  [SMALL_STATE(5324)] = 189855,
  [SMALL_STATE(5325)] = 189922,
  [SMALL_STATE(5326)] = 189983,
  [SMALL_STATE(5327)] = 190043,
  [SMALL_STATE(5328)] = 190101,
  [SMALL_STATE(5329)] = 190159,
  [SMALL_STATE(5330)] = 190219,
  [SMALL_STATE(5331)] = 190279,
  [SMALL_STATE(5332)] = 190339,
  [SMALL_STATE(5333)] = 190399,
  [SMALL_STATE(5334)] = 190437,
  [SMALL_STATE(5335)] = 190497,
  [SMALL_STATE(5336)] = 190557,
  [SMALL_STATE(5337)] = 190617,
  [SMALL_STATE(5338)] = 190675,
  [SMALL_STATE(5339)] = 190735,
  [SMALL_STATE(5340)] = 190771,
  [SMALL_STATE(5341)] = 190831,
  [SMALL_STATE(5342)] = 190891,
  [SMALL_STATE(5343)] = 190949,
  [SMALL_STATE(5344)] = 191009,
  [SMALL_STATE(5345)] = 191068,
  [SMALL_STATE(5346)] = 191127,
  [SMALL_STATE(5347)] = 191186,
  [SMALL_STATE(5348)] = 191247,
  [SMALL_STATE(5349)] = 191306,
  [SMALL_STATE(5350)] = 191365,
  [SMALL_STATE(5351)] = 191424,
  [SMALL_STATE(5352)] = 191483,
  [SMALL_STATE(5353)] = 191542,
  [SMALL_STATE(5354)] = 191591,
  [SMALL_STATE(5355)] = 191650,
  [SMALL_STATE(5356)] = 191711,
  [SMALL_STATE(5357)] = 191770,
  [SMALL_STATE(5358)] = 191829,
  [SMALL_STATE(5359)] = 191890,
  [SMALL_STATE(5360)] = 191951,
  [SMALL_STATE(5361)] = 192012,
  [SMALL_STATE(5362)] = 192071,
  [SMALL_STATE(5363)] = 192132,
  [SMALL_STATE(5364)] = 192193,
  [SMALL_STATE(5365)] = 192251,
  [SMALL_STATE(5366)] = 192309,
  [SMALL_STATE(5367)] = 192363,
  [SMALL_STATE(5368)] = 192411,
  [SMALL_STATE(5369)] = 192469,
  [SMALL_STATE(5370)] = 192527,
  [SMALL_STATE(5371)] = 192585,
  [SMALL_STATE(5372)] = 192643,
  [SMALL_STATE(5373)] = 192701,
  [SMALL_STATE(5374)] = 192759,
  [SMALL_STATE(5375)] = 192817,
  [SMALL_STATE(5376)] = 192875,
  [SMALL_STATE(5377)] = 192933,
  [SMALL_STATE(5378)] = 192991,
  [SMALL_STATE(5379)] = 193049,
  [SMALL_STATE(5380)] = 193107,
  [SMALL_STATE(5381)] = 193165,
  [SMALL_STATE(5382)] = 193223,
  [SMALL_STATE(5383)] = 193281,
  [SMALL_STATE(5384)] = 193339,
  [SMALL_STATE(5385)] = 193410,
  [SMALL_STATE(5386)] = 193481,
  [SMALL_STATE(5387)] = 193552,
  [SMALL_STATE(5388)] = 193604,
  [SMALL_STATE(5389)] = 193656,
  [SMALL_STATE(5390)] = 193712,
  [SMALL_STATE(5391)] = 193764,
  [SMALL_STATE(5392)] = 193816,
  [SMALL_STATE(5393)] = 193868,
  [SMALL_STATE(5394)] = 193924,
  [SMALL_STATE(5395)] = 193976,
  [SMALL_STATE(5396)] = 194028,
  [SMALL_STATE(5397)] = 194080,
  [SMALL_STATE(5398)] = 194132,
  [SMALL_STATE(5399)] = 194184,
  [SMALL_STATE(5400)] = 194236,
  [SMALL_STATE(5401)] = 194288,
  [SMALL_STATE(5402)] = 194340,
  [SMALL_STATE(5403)] = 194392,
  [SMALL_STATE(5404)] = 194444,
  [SMALL_STATE(5405)] = 194496,
  [SMALL_STATE(5406)] = 194548,
  [SMALL_STATE(5407)] = 194600,
  [SMALL_STATE(5408)] = 194652,
  [SMALL_STATE(5409)] = 194704,
  [SMALL_STATE(5410)] = 194774,
  [SMALL_STATE(5411)] = 194826,
  [SMALL_STATE(5412)] = 194878,
  [SMALL_STATE(5413)] = 194930,
  [SMALL_STATE(5414)] = 195000,
  [SMALL_STATE(5415)] = 195056,
  [SMALL_STATE(5416)] = 195126,
  [SMALL_STATE(5417)] = 195178,
  [SMALL_STATE(5418)] = 195230,
  [SMALL_STATE(5419)] = 195282,
  [SMALL_STATE(5420)] = 195338,
  [SMALL_STATE(5421)] = 195384,
  [SMALL_STATE(5422)] = 195440,
  [SMALL_STATE(5423)] = 195492,
  [SMALL_STATE(5424)] = 195544,
  [SMALL_STATE(5425)] = 195600,
  [SMALL_STATE(5426)] = 195634,
  [SMALL_STATE(5427)] = 195686,
  [SMALL_STATE(5428)] = 195738,
  [SMALL_STATE(5429)] = 195790,
  [SMALL_STATE(5430)] = 195842,
  [SMALL_STATE(5431)] = 195894,
  [SMALL_STATE(5432)] = 195946,
  [SMALL_STATE(5433)] = 195998,
  [SMALL_STATE(5434)] = 196061,
  [SMALL_STATE(5435)] = 196120,
  [SMALL_STATE(5436)] = 196179,
  [SMALL_STATE(5437)] = 196238,
  [SMALL_STATE(5438)] = 196297,
  [SMALL_STATE(5439)] = 196356,
  [SMALL_STATE(5440)] = 196415,
  [SMALL_STATE(5441)] = 196474,
  [SMALL_STATE(5442)] = 196507,
  [SMALL_STATE(5443)] = 196566,
  [SMALL_STATE(5444)] = 196595,
  [SMALL_STATE(5445)] = 196654,
  [SMALL_STATE(5446)] = 196713,
  [SMALL_STATE(5447)] = 196772,
  [SMALL_STATE(5448)] = 196831,
  [SMALL_STATE(5449)] = 196890,
  [SMALL_STATE(5450)] = 196949,
  [SMALL_STATE(5451)] = 197008,
  [SMALL_STATE(5452)] = 197067,
  [SMALL_STATE(5453)] = 197126,
  [SMALL_STATE(5454)] = 197185,
  [SMALL_STATE(5455)] = 197244,
  [SMALL_STATE(5456)] = 197303,
  [SMALL_STATE(5457)] = 197362,
  [SMALL_STATE(5458)] = 197421,
  [SMALL_STATE(5459)] = 197480,
  [SMALL_STATE(5460)] = 197539,
  [SMALL_STATE(5461)] = 197598,
  [SMALL_STATE(5462)] = 197657,
  [SMALL_STATE(5463)] = 197716,
  [SMALL_STATE(5464)] = 197775,
  [SMALL_STATE(5465)] = 197834,
  [SMALL_STATE(5466)] = 197893,
  [SMALL_STATE(5467)] = 197952,
  [SMALL_STATE(5468)] = 198011,
  [SMALL_STATE(5469)] = 198070,
  [SMALL_STATE(5470)] = 198113,
  [SMALL_STATE(5471)] = 198172,
  [SMALL_STATE(5472)] = 198231,
  [SMALL_STATE(5473)] = 198290,
  [SMALL_STATE(5474)] = 198349,
  [SMALL_STATE(5475)] = 198408,
  [SMALL_STATE(5476)] = 198467,
  [SMALL_STATE(5477)] = 198526,
  [SMALL_STATE(5478)] = 198585,
  [SMALL_STATE(5479)] = 198628,
  [SMALL_STATE(5480)] = 198687,
  [SMALL_STATE(5481)] = 198746,
  [SMALL_STATE(5482)] = 198805,
  [SMALL_STATE(5483)] = 198864,
  [SMALL_STATE(5484)] = 198923,
  [SMALL_STATE(5485)] = 198982,
  [SMALL_STATE(5486)] = 199041,
  [SMALL_STATE(5487)] = 199096,
  [SMALL_STATE(5488)] = 199151,
  [SMALL_STATE(5489)] = 199210,
  [SMALL_STATE(5490)] = 199269,
  [SMALL_STATE(5491)] = 199328,
  [SMALL_STATE(5492)] = 199387,
  [SMALL_STATE(5493)] = 199446,
  [SMALL_STATE(5494)] = 199505,
  [SMALL_STATE(5495)] = 199564,
  [SMALL_STATE(5496)] = 199623,
  [SMALL_STATE(5497)] = 199682,
  [SMALL_STATE(5498)] = 199741,
  [SMALL_STATE(5499)] = 199800,
  [SMALL_STATE(5500)] = 199859,
  [SMALL_STATE(5501)] = 199918,
  [SMALL_STATE(5502)] = 199977,
  [SMALL_STATE(5503)] = 200036,
  [SMALL_STATE(5504)] = 200081,
  [SMALL_STATE(5505)] = 200140,
  [SMALL_STATE(5506)] = 200183,
  [SMALL_STATE(5507)] = 200238,
  [SMALL_STATE(5508)] = 200297,
  [SMALL_STATE(5509)] = 200356,
  [SMALL_STATE(5510)] = 200415,
  [SMALL_STATE(5511)] = 200474,
  [SMALL_STATE(5512)] = 200533,
  [SMALL_STATE(5513)] = 200592,
  [SMALL_STATE(5514)] = 200651,
  [SMALL_STATE(5515)] = 200710,
  [SMALL_STATE(5516)] = 200769,
  [SMALL_STATE(5517)] = 200828,
  [SMALL_STATE(5518)] = 200887,
  [SMALL_STATE(5519)] = 200946,
  [SMALL_STATE(5520)] = 201005,
  [SMALL_STATE(5521)] = 201064,
  [SMALL_STATE(5522)] = 201123,
  [SMALL_STATE(5523)] = 201182,
  [SMALL_STATE(5524)] = 201241,
  [SMALL_STATE(5525)] = 201300,
  [SMALL_STATE(5526)] = 201359,
  [SMALL_STATE(5527)] = 201418,
  [SMALL_STATE(5528)] = 201477,
  [SMALL_STATE(5529)] = 201536,
  [SMALL_STATE(5530)] = 201595,
  [SMALL_STATE(5531)] = 201654,
  [SMALL_STATE(5532)] = 201713,
  [SMALL_STATE(5533)] = 201772,
  [SMALL_STATE(5534)] = 201812,
  [SMALL_STATE(5535)] = 201862,
  [SMALL_STATE(5536)] = 201902,
  [SMALL_STATE(5537)] = 201942,
  [SMALL_STATE(5538)] = 201970,
  [SMALL_STATE(5539)] = 202010,
  [SMALL_STATE(5540)] = 202050,
  [SMALL_STATE(5541)] = 202078,
  [SMALL_STATE(5542)] = 202130,
  [SMALL_STATE(5543)] = 202182,
  [SMALL_STATE(5544)] = 202210,
  [SMALL_STATE(5545)] = 202250,
  [SMALL_STATE(5546)] = 202300,
  [SMALL_STATE(5547)] = 202340,
  [SMALL_STATE(5548)] = 202380,
  [SMALL_STATE(5549)] = 202420,
  [SMALL_STATE(5550)] = 202470,
  [SMALL_STATE(5551)] = 202498,
  [SMALL_STATE(5552)] = 202538,
  [SMALL_STATE(5553)] = 202574,
  [SMALL_STATE(5554)] = 202614,
  [SMALL_STATE(5555)] = 202658,
  [SMALL_STATE(5556)] = 202698,
  [SMALL_STATE(5557)] = 202738,
  [SMALL_STATE(5558)] = 202766,
  [SMALL_STATE(5559)] = 202806,
  [SMALL_STATE(5560)] = 202846,
  [SMALL_STATE(5561)] = 202910,
  [SMALL_STATE(5562)] = 202950,
  [SMALL_STATE(5563)] = 202986,
  [SMALL_STATE(5564)] = 203036,
  [SMALL_STATE(5565)] = 203076,
  [SMALL_STATE(5566)] = 203126,
  [SMALL_STATE(5567)] = 203166,
  [SMALL_STATE(5568)] = 203212,
  [SMALL_STATE(5569)] = 203252,
  [SMALL_STATE(5570)] = 203302,
  [SMALL_STATE(5571)] = 203342,
  [SMALL_STATE(5572)] = 203406,
  [SMALL_STATE(5573)] = 203446,
  [SMALL_STATE(5574)] = 203486,
  [SMALL_STATE(5575)] = 203550,
  [SMALL_STATE(5576)] = 203590,
  [SMALL_STATE(5577)] = 203640,
  [SMALL_STATE(5578)] = 203690,
  [SMALL_STATE(5579)] = 203754,
  [SMALL_STATE(5580)] = 203794,
  [SMALL_STATE(5581)] = 203844,
  [SMALL_STATE(5582)] = 203894,
  [SMALL_STATE(5583)] = 203934,
  [SMALL_STATE(5584)] = 203974,
  [SMALL_STATE(5585)] = 204014,
  [SMALL_STATE(5586)] = 204042,
  [SMALL_STATE(5587)] = 204070,
  [SMALL_STATE(5588)] = 204106,
  [SMALL_STATE(5589)] = 204146,
  [SMALL_STATE(5590)] = 204196,
  [SMALL_STATE(5591)] = 204232,
  [SMALL_STATE(5592)] = 204260,
  [SMALL_STATE(5593)] = 204310,
  [SMALL_STATE(5594)] = 204350,
  [SMALL_STATE(5595)] = 204414,
  [SMALL_STATE(5596)] = 204454,
  [SMALL_STATE(5597)] = 204498,
  [SMALL_STATE(5598)] = 204548,
  [SMALL_STATE(5599)] = 204588,
  [SMALL_STATE(5600)] = 204616,
  [SMALL_STATE(5601)] = 204666,
  [SMALL_STATE(5602)] = 204700,
  [SMALL_STATE(5603)] = 204764,
  [SMALL_STATE(5604)] = 204814,
  [SMALL_STATE(5605)] = 204854,
  [SMALL_STATE(5606)] = 204918,
  [SMALL_STATE(5607)] = 204958,
  [SMALL_STATE(5608)] = 205022,
  [SMALL_STATE(5609)] = 205062,
  [SMALL_STATE(5610)] = 205102,
  [SMALL_STATE(5611)] = 205152,
  [SMALL_STATE(5612)] = 205188,
  [SMALL_STATE(5613)] = 205228,
  [SMALL_STATE(5614)] = 205268,
  [SMALL_STATE(5615)] = 205296,
  [SMALL_STATE(5616)] = 205328,
  [SMALL_STATE(5617)] = 205378,
  [SMALL_STATE(5618)] = 205426,
  [SMALL_STATE(5619)] = 205466,
  [SMALL_STATE(5620)] = 205506,
  [SMALL_STATE(5621)] = 205548,
  [SMALL_STATE(5622)] = 205598,
  [SMALL_STATE(5623)] = 205638,
  [SMALL_STATE(5624)] = 205702,
  [SMALL_STATE(5625)] = 205766,
  [SMALL_STATE(5626)] = 205830,
  [SMALL_STATE(5627)] = 205882,
  [SMALL_STATE(5628)] = 205928,
  [SMALL_STATE(5629)] = 205992,
  [SMALL_STATE(5630)] = 206036,
  [SMALL_STATE(5631)] = 206086,
  [SMALL_STATE(5632)] = 206126,
  [SMALL_STATE(5633)] = 206166,
  [SMALL_STATE(5634)] = 206206,
  [SMALL_STATE(5635)] = 206246,
  [SMALL_STATE(5636)] = 206286,
  [SMALL_STATE(5637)] = 206350,
  [SMALL_STATE(5638)] = 206390,
  [SMALL_STATE(5639)] = 206430,
  [SMALL_STATE(5640)] = 206494,
  [SMALL_STATE(5641)] = 206534,
  [SMALL_STATE(5642)] = 206561,
  [SMALL_STATE(5643)] = 206608,
  [SMALL_STATE(5644)] = 206643,
  [SMALL_STATE(5645)] = 206700,
  [SMALL_STATE(5646)] = 206727,
  [SMALL_STATE(5647)] = 206782,
  [SMALL_STATE(5648)] = 206811,
  [SMALL_STATE(5649)] = 206838,
  [SMALL_STATE(5650)] = 206865,
  [SMALL_STATE(5651)] = 206912,
  [SMALL_STATE(5652)] = 206951,
  [SMALL_STATE(5653)] = 206990,
  [SMALL_STATE(5654)] = 207045,
  [SMALL_STATE(5655)] = 207072,
  [SMALL_STATE(5656)] = 207117,
  [SMALL_STATE(5657)] = 207162,
  [SMALL_STATE(5658)] = 207189,
  [SMALL_STATE(5659)] = 207216,
  [SMALL_STATE(5660)] = 207271,
  [SMALL_STATE(5661)] = 207314,
  [SMALL_STATE(5662)] = 207341,
  [SMALL_STATE(5663)] = 207396,
  [SMALL_STATE(5664)] = 207441,
  [SMALL_STATE(5665)] = 207480,
  [SMALL_STATE(5666)] = 207507,
  [SMALL_STATE(5667)] = 207534,
  [SMALL_STATE(5668)] = 207579,
  [SMALL_STATE(5669)] = 207626,
  [SMALL_STATE(5670)] = 207673,
  [SMALL_STATE(5671)] = 207718,
  [SMALL_STATE(5672)] = 207763,
  [SMALL_STATE(5673)] = 207808,
  [SMALL_STATE(5674)] = 207847,
  [SMALL_STATE(5675)] = 207874,
  [SMALL_STATE(5676)] = 207909,
  [SMALL_STATE(5677)] = 207944,
  [SMALL_STATE(5678)] = 207993,
  [SMALL_STATE(5679)] = 208050,
  [SMALL_STATE(5680)] = 208099,
  [SMALL_STATE(5681)] = 208138,
  [SMALL_STATE(5682)] = 208165,
  [SMALL_STATE(5683)] = 208192,
  [SMALL_STATE(5684)] = 208239,
  [SMALL_STATE(5685)] = 208284,
  [SMALL_STATE(5686)] = 208321,
  [SMALL_STATE(5687)] = 208348,
  [SMALL_STATE(5688)] = 208375,
  [SMALL_STATE(5689)] = 208422,
  [SMALL_STATE(5690)] = 208461,
  [SMALL_STATE(5691)] = 208508,
  [SMALL_STATE(5692)] = 208543,
  [SMALL_STATE(5693)] = 208582,
  [SMALL_STATE(5694)] = 208637,
  [SMALL_STATE(5695)] = 208668,
  [SMALL_STATE(5696)] = 208715,
  [SMALL_STATE(5697)] = 208750,
  [SMALL_STATE(5698)] = 208797,
  [SMALL_STATE(5699)] = 208836,
  [SMALL_STATE(5700)] = 208865,
  [SMALL_STATE(5701)] = 208896,
  [SMALL_STATE(5702)] = 208941,
  [SMALL_STATE(5703)] = 208968,
  [SMALL_STATE(5704)] = 209013,
  [SMALL_STATE(5705)] = 209040,
  [SMALL_STATE(5706)] = 209067,
  [SMALL_STATE(5707)] = 209110,
  [SMALL_STATE(5708)] = 209153,
  [SMALL_STATE(5709)] = 209188,
  [SMALL_STATE(5710)] = 209223,
  [SMALL_STATE(5711)] = 209256,
  [SMALL_STATE(5712)] = 209291,
  [SMALL_STATE(5713)] = 209318,
  [SMALL_STATE(5714)] = 209363,
  [SMALL_STATE(5715)] = 209406,
  [SMALL_STATE(5716)] = 209451,
  [SMALL_STATE(5717)] = 209496,
  [SMALL_STATE(5718)] = 209523,
  [SMALL_STATE(5719)] = 209580,
  [SMALL_STATE(5720)] = 209609,
  [SMALL_STATE(5721)] = 209636,
  [SMALL_STATE(5722)] = 209671,
  [SMALL_STATE(5723)] = 209698,
  [SMALL_STATE(5724)] = 209737,
  [SMALL_STATE(5725)] = 209792,
  [SMALL_STATE(5726)] = 209837,
  [SMALL_STATE(5727)] = 209872,
  [SMALL_STATE(5728)] = 209899,
  [SMALL_STATE(5729)] = 209946,
  [SMALL_STATE(5730)] = 209993,
  [SMALL_STATE(5731)] = 210050,
  [SMALL_STATE(5732)] = 210077,
  [SMALL_STATE(5733)] = 210134,
  [SMALL_STATE(5734)] = 210181,
  [SMALL_STATE(5735)] = 210226,
  [SMALL_STATE(5736)] = 210253,
  [SMALL_STATE(5737)] = 210280,
  [SMALL_STATE(5738)] = 210307,
  [SMALL_STATE(5739)] = 210334,
  [SMALL_STATE(5740)] = 210369,
  [SMALL_STATE(5741)] = 210396,
  [SMALL_STATE(5742)] = 210453,
  [SMALL_STATE(5743)] = 210480,
  [SMALL_STATE(5744)] = 210521,
  [SMALL_STATE(5745)] = 210548,
  [SMALL_STATE(5746)] = 210575,
  [SMALL_STATE(5747)] = 210629,
  [SMALL_STATE(5748)] = 210659,
  [SMALL_STATE(5749)] = 210689,
  [SMALL_STATE(5750)] = 210737,
  [SMALL_STATE(5751)] = 210791,
  [SMALL_STATE(5752)] = 210845,
  [SMALL_STATE(5753)] = 210893,
  [SMALL_STATE(5754)] = 210923,
  [SMALL_STATE(5755)] = 210977,
  [SMALL_STATE(5756)] = 211031,
  [SMALL_STATE(5757)] = 211079,
  [SMALL_STATE(5758)] = 211121,
  [SMALL_STATE(5759)] = 211175,
  [SMALL_STATE(5760)] = 211229,
  [SMALL_STATE(5761)] = 211259,
  [SMALL_STATE(5762)] = 211307,
  [SMALL_STATE(5763)] = 211334,
  [SMALL_STATE(5764)] = 211383,
  [SMALL_STATE(5765)] = 211432,
  [SMALL_STATE(5766)] = 211481,
  [SMALL_STATE(5767)] = 211504,
  [SMALL_STATE(5768)] = 211547,
  [SMALL_STATE(5769)] = 211570,
  [SMALL_STATE(5770)] = 211619,
  [SMALL_STATE(5771)] = 211642,
  [SMALL_STATE(5772)] = 211673,
  [SMALL_STATE(5773)] = 211702,
  [SMALL_STATE(5774)] = 211725,
  [SMALL_STATE(5775)] = 211756,
  [SMALL_STATE(5776)] = 211779,
  [SMALL_STATE(5777)] = 211828,
  [SMALL_STATE(5778)] = 211869,
  [SMALL_STATE(5779)] = 211892,
  [SMALL_STATE(5780)] = 211917,
  [SMALL_STATE(5781)] = 211940,
  [SMALL_STATE(5782)] = 211963,
  [SMALL_STATE(5783)] = 211986,
  [SMALL_STATE(5784)] = 212017,
  [SMALL_STATE(5785)] = 212040,
  [SMALL_STATE(5786)] = 212089,
  [SMALL_STATE(5787)] = 212112,
  [SMALL_STATE(5788)] = 212135,
  [SMALL_STATE(5789)] = 212170,
  [SMALL_STATE(5790)] = 212219,
  [SMALL_STATE(5791)] = 212248,
  [SMALL_STATE(5792)] = 212297,
  [SMALL_STATE(5793)] = 212334,
  [SMALL_STATE(5794)] = 212383,
  [SMALL_STATE(5795)] = 212414,
  [SMALL_STATE(5796)] = 212443,
  [SMALL_STATE(5797)] = 212480,
  [SMALL_STATE(5798)] = 212511,
  [SMALL_STATE(5799)] = 212548,
  [SMALL_STATE(5800)] = 212579,
  [SMALL_STATE(5801)] = 212628,
  [SMALL_STATE(5802)] = 212677,
  [SMALL_STATE(5803)] = 212700,
  [SMALL_STATE(5804)] = 212737,
  [SMALL_STATE(5805)] = 212786,
  [SMALL_STATE(5806)] = 212835,
  [SMALL_STATE(5807)] = 212866,
  [SMALL_STATE(5808)] = 212915,
  [SMALL_STATE(5809)] = 212938,
  [SMALL_STATE(5810)] = 212969,
  [SMALL_STATE(5811)] = 212992,
  [SMALL_STATE(5812)] = 213041,
  [SMALL_STATE(5813)] = 213090,
  [SMALL_STATE(5814)] = 213139,
  [SMALL_STATE(5815)] = 213188,
  [SMALL_STATE(5816)] = 213231,
  [SMALL_STATE(5817)] = 213254,
  [SMALL_STATE(5818)] = 213297,
  [SMALL_STATE(5819)] = 213320,
  [SMALL_STATE(5820)] = 213349,
  [SMALL_STATE(5821)] = 213398,
  [SMALL_STATE(5822)] = 213447,
  [SMALL_STATE(5823)] = 213496,
  [SMALL_STATE(5824)] = 213545,
  [SMALL_STATE(5825)] = 213594,
  [SMALL_STATE(5826)] = 213643,
  [SMALL_STATE(5827)] = 213674,
  [SMALL_STATE(5828)] = 213711,
  [SMALL_STATE(5829)] = 213742,
  [SMALL_STATE(5830)] = 213773,
  [SMALL_STATE(5831)] = 213810,
  [SMALL_STATE(5832)] = 213853,
  [SMALL_STATE(5833)] = 213902,
  [SMALL_STATE(5834)] = 213933,
  [SMALL_STATE(5835)] = 213964,
  [SMALL_STATE(5836)] = 214001,
  [SMALL_STATE(5837)] = 214030,
  [SMALL_STATE(5838)] = 214067,
  [SMALL_STATE(5839)] = 214116,
  [SMALL_STATE(5840)] = 214142,
  [SMALL_STATE(5841)] = 214182,
  [SMALL_STATE(5842)] = 214222,
  [SMALL_STATE(5843)] = 214262,
  [SMALL_STATE(5844)] = 214302,
  [SMALL_STATE(5845)] = 214342,
  [SMALL_STATE(5846)] = 214382,
  [SMALL_STATE(5847)] = 214416,
  [SMALL_STATE(5848)] = 214450,
  [SMALL_STATE(5849)] = 214490,
  [SMALL_STATE(5850)] = 214516,
  [SMALL_STATE(5851)] = 214556,
  [SMALL_STATE(5852)] = 214596,
  [SMALL_STATE(5853)] = 214620,
  [SMALL_STATE(5854)] = 214654,
  [SMALL_STATE(5855)] = 214694,
  [SMALL_STATE(5856)] = 214736,
  [SMALL_STATE(5857)] = 214776,
  [SMALL_STATE(5858)] = 214816,
  [SMALL_STATE(5859)] = 214840,
  [SMALL_STATE(5860)] = 214870,
  [SMALL_STATE(5861)] = 214910,
  [SMALL_STATE(5862)] = 214950,
  [SMALL_STATE(5863)] = 214984,
  [SMALL_STATE(5864)] = 215024,
  [SMALL_STATE(5865)] = 215064,
  [SMALL_STATE(5866)] = 215104,
  [SMALL_STATE(5867)] = 215138,
  [SMALL_STATE(5868)] = 215172,
  [SMALL_STATE(5869)] = 215198,
  [SMALL_STATE(5870)] = 215228,
  [SMALL_STATE(5871)] = 215258,
  [SMALL_STATE(5872)] = 215288,
  [SMALL_STATE(5873)] = 215318,
  [SMALL_STATE(5874)] = 215352,
  [SMALL_STATE(5875)] = 215392,
  [SMALL_STATE(5876)] = 215432,
  [SMALL_STATE(5877)] = 215460,
  [SMALL_STATE(5878)] = 215490,
  [SMALL_STATE(5879)] = 215520,
  [SMALL_STATE(5880)] = 215560,
  [SMALL_STATE(5881)] = 215600,
  [SMALL_STATE(5882)] = 215630,
  [SMALL_STATE(5883)] = 215660,
  [SMALL_STATE(5884)] = 215694,
  [SMALL_STATE(5885)] = 215723,
  [SMALL_STATE(5886)] = 215754,
  [SMALL_STATE(5887)] = 215787,
  [SMALL_STATE(5888)] = 215830,
  [SMALL_STATE(5889)] = 215863,
  [SMALL_STATE(5890)] = 215896,
  [SMALL_STATE(5891)] = 215929,
  [SMALL_STATE(5892)] = 215952,
  [SMALL_STATE(5893)] = 215975,
  [SMALL_STATE(5894)] = 216002,
  [SMALL_STATE(5895)] = 216041,
  [SMALL_STATE(5896)] = 216086,
  [SMALL_STATE(5897)] = 216119,
  [SMALL_STATE(5898)] = 216158,
  [SMALL_STATE(5899)] = 216181,
  [SMALL_STATE(5900)] = 216204,
  [SMALL_STATE(5901)] = 216227,
  [SMALL_STATE(5902)] = 216250,
  [SMALL_STATE(5903)] = 216289,
  [SMALL_STATE(5904)] = 216312,
  [SMALL_STATE(5905)] = 216343,
  [SMALL_STATE(5906)] = 216388,
  [SMALL_STATE(5907)] = 216421,
  [SMALL_STATE(5908)] = 216444,
  [SMALL_STATE(5909)] = 216475,
  [SMALL_STATE(5910)] = 216520,
  [SMALL_STATE(5911)] = 216551,
  [SMALL_STATE(5912)] = 216582,
  [SMALL_STATE(5913)] = 216625,
  [SMALL_STATE(5914)] = 216656,
  [SMALL_STATE(5915)] = 216689,
  [SMALL_STATE(5916)] = 216712,
  [SMALL_STATE(5917)] = 216735,
  [SMALL_STATE(5918)] = 216758,
  [SMALL_STATE(5919)] = 216781,
  [SMALL_STATE(5920)] = 216808,
  [SMALL_STATE(5921)] = 216831,
  [SMALL_STATE(5922)] = 216874,
  [SMALL_STATE(5923)] = 216905,
  [SMALL_STATE(5924)] = 216938,
  [SMALL_STATE(5925)] = 216961,
  [SMALL_STATE(5926)] = 217004,
  [SMALL_STATE(5927)] = 217037,
  [SMALL_STATE(5928)] = 217060,
  [SMALL_STATE(5929)] = 217103,
  [SMALL_STATE(5930)] = 217136,
  [SMALL_STATE(5931)] = 217175,
  [SMALL_STATE(5932)] = 217206,
  [SMALL_STATE(5933)] = 217251,
  [SMALL_STATE(5934)] = 217274,
  [SMALL_STATE(5935)] = 217299,
  [SMALL_STATE(5936)] = 217330,
  [SMALL_STATE(5937)] = 217353,
  [SMALL_STATE(5938)] = 217384,
  [SMALL_STATE(5939)] = 217415,
  [SMALL_STATE(5940)] = 217448,
  [SMALL_STATE(5941)] = 217479,
  [SMALL_STATE(5942)] = 217502,
  [SMALL_STATE(5943)] = 217535,
  [SMALL_STATE(5944)] = 217574,
  [SMALL_STATE(5945)] = 217607,
  [SMALL_STATE(5946)] = 217650,
  [SMALL_STATE(5947)] = 217681,
  [SMALL_STATE(5948)] = 217724,
  [SMALL_STATE(5949)] = 217757,
  [SMALL_STATE(5950)] = 217802,
  [SMALL_STATE(5951)] = 217835,
  [SMALL_STATE(5952)] = 217866,
  [SMALL_STATE(5953)] = 217895,
  [SMALL_STATE(5954)] = 217924,
  [SMALL_STATE(5955)] = 217953,
  [SMALL_STATE(5956)] = 217982,
  [SMALL_STATE(5957)] = 218005,
  [SMALL_STATE(5958)] = 218028,
  [SMALL_STATE(5959)] = 218057,
  [SMALL_STATE(5960)] = 218086,
  [SMALL_STATE(5961)] = 218129,
  [SMALL_STATE(5962)] = 218162,
  [SMALL_STATE(5963)] = 218193,
  [SMALL_STATE(5964)] = 218224,
  [SMALL_STATE(5965)] = 218257,
  [SMALL_STATE(5966)] = 218300,
  [SMALL_STATE(5967)] = 218331,
  [SMALL_STATE(5968)] = 218376,
  [SMALL_STATE(5969)] = 218409,
  [SMALL_STATE(5970)] = 218448,
  [SMALL_STATE(5971)] = 218477,
  [SMALL_STATE(5972)] = 218522,
  [SMALL_STATE(5973)] = 218561,
  [SMALL_STATE(5974)] = 218592,
  [SMALL_STATE(5975)] = 218631,
  [SMALL_STATE(5976)] = 218674,
  [SMALL_STATE(5977)] = 218705,
  [SMALL_STATE(5978)] = 218738,
  [SMALL_STATE(5979)] = 218769,
  [SMALL_STATE(5980)] = 218812,
  [SMALL_STATE(5981)] = 218845,
  [SMALL_STATE(5982)] = 218876,
  [SMALL_STATE(5983)] = 218923,
  [SMALL_STATE(5984)] = 218956,
  [SMALL_STATE(5985)] = 218987,
  [SMALL_STATE(5986)] = 219018,
  [SMALL_STATE(5987)] = 219041,
  [SMALL_STATE(5988)] = 219072,
  [SMALL_STATE(5989)] = 219103,
  [SMALL_STATE(5990)] = 219141,
  [SMALL_STATE(5991)] = 219173,
  [SMALL_STATE(5992)] = 219213,
  [SMALL_STATE(5993)] = 219245,
  [SMALL_STATE(5994)] = 219283,
  [SMALL_STATE(5995)] = 219305,
  [SMALL_STATE(5996)] = 219337,
  [SMALL_STATE(5997)] = 219365,
  [SMALL_STATE(5998)] = 219405,
  [SMALL_STATE(5999)] = 219433,
  [SMALL_STATE(6000)] = 219473,
  [SMALL_STATE(6001)] = 219505,
  [SMALL_STATE(6002)] = 219543,
  [SMALL_STATE(6003)] = 219563,
  [SMALL_STATE(6004)] = 219603,
  [SMALL_STATE(6005)] = 219641,
  [SMALL_STATE(6006)] = 219671,
  [SMALL_STATE(6007)] = 219699,
  [SMALL_STATE(6008)] = 219737,
  [SMALL_STATE(6009)] = 219759,
  [SMALL_STATE(6010)] = 219797,
  [SMALL_STATE(6011)] = 219825,
  [SMALL_STATE(6012)] = 219863,
  [SMALL_STATE(6013)] = 219883,
  [SMALL_STATE(6014)] = 219921,
  [SMALL_STATE(6015)] = 219959,
  [SMALL_STATE(6016)] = 219991,
  [SMALL_STATE(6017)] = 220019,
  [SMALL_STATE(6018)] = 220057,
  [SMALL_STATE(6019)] = 220095,
  [SMALL_STATE(6020)] = 220123,
  [SMALL_STATE(6021)] = 220151,
  [SMALL_STATE(6022)] = 220171,
  [SMALL_STATE(6023)] = 220211,
  [SMALL_STATE(6024)] = 220231,
  [SMALL_STATE(6025)] = 220259,
  [SMALL_STATE(6026)] = 220297,
  [SMALL_STATE(6027)] = 220337,
  [SMALL_STATE(6028)] = 220357,
  [SMALL_STATE(6029)] = 220385,
  [SMALL_STATE(6030)] = 220423,
  [SMALL_STATE(6031)] = 220463,
  [SMALL_STATE(6032)] = 220491,
  [SMALL_STATE(6033)] = 220523,
  [SMALL_STATE(6034)] = 220543,
  [SMALL_STATE(6035)] = 220575,
  [SMALL_STATE(6036)] = 220603,
  [SMALL_STATE(6037)] = 220641,
  [SMALL_STATE(6038)] = 220673,
  [SMALL_STATE(6039)] = 220701,
  [SMALL_STATE(6040)] = 220729,
  [SMALL_STATE(6041)] = 220761,
  [SMALL_STATE(6042)] = 220789,
  [SMALL_STATE(6043)] = 220829,
  [SMALL_STATE(6044)] = 220861,
  [SMALL_STATE(6045)] = 220893,
  [SMALL_STATE(6046)] = 220933,
  [SMALL_STATE(6047)] = 220953,
  [SMALL_STATE(6048)] = 220985,
  [SMALL_STATE(6049)] = 221017,
  [SMALL_STATE(6050)] = 221057,
  [SMALL_STATE(6051)] = 221089,
  [SMALL_STATE(6052)] = 221109,
  [SMALL_STATE(6053)] = 221129,
  [SMALL_STATE(6054)] = 221169,
  [SMALL_STATE(6055)] = 221191,
  [SMALL_STATE(6056)] = 221231,
  [SMALL_STATE(6057)] = 221261,
  [SMALL_STATE(6058)] = 221301,
  [SMALL_STATE(6059)] = 221333,
  [SMALL_STATE(6060)] = 221373,
  [SMALL_STATE(6061)] = 221411,
  [SMALL_STATE(6062)] = 221451,
  [SMALL_STATE(6063)] = 221489,
  [SMALL_STATE(6064)] = 221521,
  [SMALL_STATE(6065)] = 221553,
  [SMALL_STATE(6066)] = 221585,
  [SMALL_STATE(6067)] = 221613,
  [SMALL_STATE(6068)] = 221645,
  [SMALL_STATE(6069)] = 221665,
  [SMALL_STATE(6070)] = 221703,
  [SMALL_STATE(6071)] = 221743,
  [SMALL_STATE(6072)] = 221763,
  [SMALL_STATE(6073)] = 221783,
  [SMALL_STATE(6074)] = 221811,
  [SMALL_STATE(6075)] = 221831,
  [SMALL_STATE(6076)] = 221863,
  [SMALL_STATE(6077)] = 221883,
  [SMALL_STATE(6078)] = 221913,
  [SMALL_STATE(6079)] = 221953,
  [SMALL_STATE(6080)] = 221985,
  [SMALL_STATE(6081)] = 222025,
  [SMALL_STATE(6082)] = 222057,
  [SMALL_STATE(6083)] = 222097,
  [SMALL_STATE(6084)] = 222119,
  [SMALL_STATE(6085)] = 222149,
  [SMALL_STATE(6086)] = 222173,
  [SMALL_STATE(6087)] = 222193,
  [SMALL_STATE(6088)] = 222225,
  [SMALL_STATE(6089)] = 222255,
  [SMALL_STATE(6090)] = 222287,
  [SMALL_STATE(6091)] = 222319,
  [SMALL_STATE(6092)] = 222359,
  [SMALL_STATE(6093)] = 222391,
  [SMALL_STATE(6094)] = 222411,
  [SMALL_STATE(6095)] = 222439,
  [SMALL_STATE(6096)] = 222471,
  [SMALL_STATE(6097)] = 222503,
  [SMALL_STATE(6098)] = 222523,
  [SMALL_STATE(6099)] = 222551,
  [SMALL_STATE(6100)] = 222571,
  [SMALL_STATE(6101)] = 222591,
  [SMALL_STATE(6102)] = 222619,
  [SMALL_STATE(6103)] = 222657,
  [SMALL_STATE(6104)] = 222697,
  [SMALL_STATE(6105)] = 222717,
  [SMALL_STATE(6106)] = 222755,
  [SMALL_STATE(6107)] = 222787,
  [SMALL_STATE(6108)] = 222807,
  [SMALL_STATE(6109)] = 222832,
  [SMALL_STATE(6110)] = 222859,
  [SMALL_STATE(6111)] = 222892,
  [SMALL_STATE(6112)] = 222919,
  [SMALL_STATE(6113)] = 222944,
  [SMALL_STATE(6114)] = 222971,
  [SMALL_STATE(6115)] = 223010,
  [SMALL_STATE(6116)] = 223045,
  [SMALL_STATE(6117)] = 223078,
  [SMALL_STATE(6118)] = 223105,
  [SMALL_STATE(6119)] = 223132,
  [SMALL_STATE(6120)] = 223167,
  [SMALL_STATE(6121)] = 223200,
  [SMALL_STATE(6122)] = 223227,
  [SMALL_STATE(6123)] = 223254,
  [SMALL_STATE(6124)] = 223287,
  [SMALL_STATE(6125)] = 223308,
  [SMALL_STATE(6126)] = 223341,
  [SMALL_STATE(6127)] = 223374,
  [SMALL_STATE(6128)] = 223407,
  [SMALL_STATE(6129)] = 223434,
  [SMALL_STATE(6130)] = 223459,
  [SMALL_STATE(6131)] = 223492,
  [SMALL_STATE(6132)] = 223531,
  [SMALL_STATE(6133)] = 223564,
  [SMALL_STATE(6134)] = 223597,
  [SMALL_STATE(6135)] = 223632,
  [SMALL_STATE(6136)] = 223665,
  [SMALL_STATE(6137)] = 223698,
  [SMALL_STATE(6138)] = 223725,
  [SMALL_STATE(6139)] = 223752,
  [SMALL_STATE(6140)] = 223787,
  [SMALL_STATE(6141)] = 223820,
  [SMALL_STATE(6142)] = 223847,
  [SMALL_STATE(6143)] = 223886,
  [SMALL_STATE(6144)] = 223911,
  [SMALL_STATE(6145)] = 223938,
  [SMALL_STATE(6146)] = 223963,
  [SMALL_STATE(6147)] = 224002,
  [SMALL_STATE(6148)] = 224027,
  [SMALL_STATE(6149)] = 224060,
  [SMALL_STATE(6150)] = 224097,
  [SMALL_STATE(6151)] = 224132,
  [SMALL_STATE(6152)] = 224157,
  [SMALL_STATE(6153)] = 224194,
  [SMALL_STATE(6154)] = 224227,
  [SMALL_STATE(6155)] = 224260,
  [SMALL_STATE(6156)] = 224281,
  [SMALL_STATE(6157)] = 224306,
  [SMALL_STATE(6158)] = 224341,
  [SMALL_STATE(6159)] = 224376,
  [SMALL_STATE(6160)] = 224411,
  [SMALL_STATE(6161)] = 224444,
  [SMALL_STATE(6162)] = 224469,
  [SMALL_STATE(6163)] = 224496,
  [SMALL_STATE(6164)] = 224529,
  [SMALL_STATE(6165)] = 224554,
  [SMALL_STATE(6166)] = 224581,
  [SMALL_STATE(6167)] = 224614,
  [SMALL_STATE(6168)] = 224635,
  [SMALL_STATE(6169)] = 224662,
  [SMALL_STATE(6170)] = 224685,
  [SMALL_STATE(6171)] = 224712,
  [SMALL_STATE(6172)] = 224745,
  [SMALL_STATE(6173)] = 224772,
  [SMALL_STATE(6174)] = 224807,
  [SMALL_STATE(6175)] = 224846,
  [SMALL_STATE(6176)] = 224879,
  [SMALL_STATE(6177)] = 224906,
  [SMALL_STATE(6178)] = 224941,
  [SMALL_STATE(6179)] = 224974,
  [SMALL_STATE(6180)] = 225007,
  [SMALL_STATE(6181)] = 225040,
  [SMALL_STATE(6182)] = 225073,
  [SMALL_STATE(6183)] = 225106,
  [SMALL_STATE(6184)] = 225139,
  [SMALL_STATE(6185)] = 225172,
  [SMALL_STATE(6186)] = 225207,
  [SMALL_STATE(6187)] = 225243,
  [SMALL_STATE(6188)] = 225271,
  [SMALL_STATE(6189)] = 225299,
  [SMALL_STATE(6190)] = 225327,
  [SMALL_STATE(6191)] = 225363,
  [SMALL_STATE(6192)] = 225389,
  [SMALL_STATE(6193)] = 225425,
  [SMALL_STATE(6194)] = 225461,
  [SMALL_STATE(6195)] = 225497,
  [SMALL_STATE(6196)] = 225533,
  [SMALL_STATE(6197)] = 225569,
  [SMALL_STATE(6198)] = 225595,
  [SMALL_STATE(6199)] = 225623,
  [SMALL_STATE(6200)] = 225659,
  [SMALL_STATE(6201)] = 225695,
  [SMALL_STATE(6202)] = 225721,
  [SMALL_STATE(6203)] = 225745,
  [SMALL_STATE(6204)] = 225771,
  [SMALL_STATE(6205)] = 225797,
  [SMALL_STATE(6206)] = 225821,
  [SMALL_STATE(6207)] = 225857,
  [SMALL_STATE(6208)] = 225893,
  [SMALL_STATE(6209)] = 225917,
  [SMALL_STATE(6210)] = 225953,
  [SMALL_STATE(6211)] = 225975,
  [SMALL_STATE(6212)] = 226001,
  [SMALL_STATE(6213)] = 226037,
  [SMALL_STATE(6214)] = 226073,
  [SMALL_STATE(6215)] = 226097,
  [SMALL_STATE(6216)] = 226117,
  [SMALL_STATE(6217)] = 226153,
  [SMALL_STATE(6218)] = 226179,
  [SMALL_STATE(6219)] = 226215,
  [SMALL_STATE(6220)] = 226251,
  [SMALL_STATE(6221)] = 226273,
  [SMALL_STATE(6222)] = 226309,
  [SMALL_STATE(6223)] = 226345,
  [SMALL_STATE(6224)] = 226381,
  [SMALL_STATE(6225)] = 226417,
  [SMALL_STATE(6226)] = 226443,
  [SMALL_STATE(6227)] = 226467,
  [SMALL_STATE(6228)] = 226493,
  [SMALL_STATE(6229)] = 226521,
  [SMALL_STATE(6230)] = 226557,
  [SMALL_STATE(6231)] = 226585,
  [SMALL_STATE(6232)] = 226620,
  [SMALL_STATE(6233)] = 226639,
  [SMALL_STATE(6234)] = 226658,
  [SMALL_STATE(6235)] = 226677,
  [SMALL_STATE(6236)] = 226712,
  [SMALL_STATE(6237)] = 226747,
  [SMALL_STATE(6238)] = 226774,
  [SMALL_STATE(6239)] = 226809,
  [SMALL_STATE(6240)] = 226834,
  [SMALL_STATE(6241)] = 226853,
  [SMALL_STATE(6242)] = 226882,
  [SMALL_STATE(6243)] = 226917,
  [SMALL_STATE(6244)] = 226948,
  [SMALL_STATE(6245)] = 226967,
  [SMALL_STATE(6246)] = 226994,
  [SMALL_STATE(6247)] = 227019,
  [SMALL_STATE(6248)] = 227054,
  [SMALL_STATE(6249)] = 227089,
  [SMALL_STATE(6250)] = 227120,
  [SMALL_STATE(6251)] = 227143,
  [SMALL_STATE(6252)] = 227162,
  [SMALL_STATE(6253)] = 227197,
  [SMALL_STATE(6254)] = 227232,
  [SMALL_STATE(6255)] = 227265,
  [SMALL_STATE(6256)] = 227300,
  [SMALL_STATE(6257)] = 227335,
  [SMALL_STATE(6258)] = 227360,
  [SMALL_STATE(6259)] = 227395,
  [SMALL_STATE(6260)] = 227420,
  [SMALL_STATE(6261)] = 227455,
  [SMALL_STATE(6262)] = 227480,
  [SMALL_STATE(6263)] = 227515,
  [SMALL_STATE(6264)] = 227534,
  [SMALL_STATE(6265)] = 227567,
  [SMALL_STATE(6266)] = 227602,
  [SMALL_STATE(6267)] = 227621,
  [SMALL_STATE(6268)] = 227640,
  [SMALL_STATE(6269)] = 227675,
  [SMALL_STATE(6270)] = 227702,
  [SMALL_STATE(6271)] = 227721,
  [SMALL_STATE(6272)] = 227752,
  [SMALL_STATE(6273)] = 227771,
  [SMALL_STATE(6274)] = 227790,
  [SMALL_STATE(6275)] = 227821,
  [SMALL_STATE(6276)] = 227850,
  [SMALL_STATE(6277)] = 227879,
  [SMALL_STATE(6278)] = 227906,
  [SMALL_STATE(6279)] = 227925,
  [SMALL_STATE(6280)] = 227944,
  [SMALL_STATE(6281)] = 227971,
  [SMALL_STATE(6282)] = 227990,
  [SMALL_STATE(6283)] = 228025,
  [SMALL_STATE(6284)] = 228044,
  [SMALL_STATE(6285)] = 228079,
  [SMALL_STATE(6286)] = 228114,
  [SMALL_STATE(6287)] = 228133,
  [SMALL_STATE(6288)] = 228152,
  [SMALL_STATE(6289)] = 228187,
  [SMALL_STATE(6290)] = 228206,
  [SMALL_STATE(6291)] = 228231,
  [SMALL_STATE(6292)] = 228262,
  [SMALL_STATE(6293)] = 228287,
  [SMALL_STATE(6294)] = 228322,
  [SMALL_STATE(6295)] = 228357,
  [SMALL_STATE(6296)] = 228386,
  [SMALL_STATE(6297)] = 228421,
  [SMALL_STATE(6298)] = 228446,
  [SMALL_STATE(6299)] = 228465,
  [SMALL_STATE(6300)] = 228500,
  [SMALL_STATE(6301)] = 228535,
  [SMALL_STATE(6302)] = 228566,
  [SMALL_STATE(6303)] = 228585,
  [SMALL_STATE(6304)] = 228612,
  [SMALL_STATE(6305)] = 228635,
  [SMALL_STATE(6306)] = 228670,
  [SMALL_STATE(6307)] = 228705,
  [SMALL_STATE(6308)] = 228724,
  [SMALL_STATE(6309)] = 228743,
  [SMALL_STATE(6310)] = 228762,
  [SMALL_STATE(6311)] = 228791,
  [SMALL_STATE(6312)] = 228826,
  [SMALL_STATE(6313)] = 228845,
  [SMALL_STATE(6314)] = 228870,
  [SMALL_STATE(6315)] = 228899,
  [SMALL_STATE(6316)] = 228932,
  [SMALL_STATE(6317)] = 228951,
  [SMALL_STATE(6318)] = 228986,
  [SMALL_STATE(6319)] = 229021,
  [SMALL_STATE(6320)] = 229054,
  [SMALL_STATE(6321)] = 229083,
  [SMALL_STATE(6322)] = 229108,
  [SMALL_STATE(6323)] = 229127,
  [SMALL_STATE(6324)] = 229162,
  [SMALL_STATE(6325)] = 229193,
  [SMALL_STATE(6326)] = 229224,
  [SMALL_STATE(6327)] = 229249,
  [SMALL_STATE(6328)] = 229284,
  [SMALL_STATE(6329)] = 229319,
  [SMALL_STATE(6330)] = 229354,
  [SMALL_STATE(6331)] = 229381,
  [SMALL_STATE(6332)] = 229416,
  [SMALL_STATE(6333)] = 229451,
  [SMALL_STATE(6334)] = 229486,
  [SMALL_STATE(6335)] = 229517,
  [SMALL_STATE(6336)] = 229536,
  [SMALL_STATE(6337)] = 229571,
  [SMALL_STATE(6338)] = 229602,
  [SMALL_STATE(6339)] = 229633,
  [SMALL_STATE(6340)] = 229654,
  [SMALL_STATE(6341)] = 229689,
  [SMALL_STATE(6342)] = 229724,
  [SMALL_STATE(6343)] = 229749,
  [SMALL_STATE(6344)] = 229778,
  [SMALL_STATE(6345)] = 229813,
  [SMALL_STATE(6346)] = 229842,
  [SMALL_STATE(6347)] = 229871,
  [SMALL_STATE(6348)] = 229902,
  [SMALL_STATE(6349)] = 229933,
  [SMALL_STATE(6350)] = 229962,
  [SMALL_STATE(6351)] = 229981,
  [SMALL_STATE(6352)] = 230000,
  [SMALL_STATE(6353)] = 230019,
  [SMALL_STATE(6354)] = 230050,
  [SMALL_STATE(6355)] = 230077,
  [SMALL_STATE(6356)] = 230112,
  [SMALL_STATE(6357)] = 230131,
  [SMALL_STATE(6358)] = 230150,
  [SMALL_STATE(6359)] = 230179,
  [SMALL_STATE(6360)] = 230198,
  [SMALL_STATE(6361)] = 230217,
  [SMALL_STATE(6362)] = 230252,
  [SMALL_STATE(6363)] = 230271,
  [SMALL_STATE(6364)] = 230296,
  [SMALL_STATE(6365)] = 230315,
  [SMALL_STATE(6366)] = 230334,
  [SMALL_STATE(6367)] = 230369,
  [SMALL_STATE(6368)] = 230404,
  [SMALL_STATE(6369)] = 230429,
  [SMALL_STATE(6370)] = 230448,
  [SMALL_STATE(6371)] = 230467,
  [SMALL_STATE(6372)] = 230498,
  [SMALL_STATE(6373)] = 230523,
  [SMALL_STATE(6374)] = 230558,
  [SMALL_STATE(6375)] = 230593,
  [SMALL_STATE(6376)] = 230628,
  [SMALL_STATE(6377)] = 230653,
  [SMALL_STATE(6378)] = 230680,
  [SMALL_STATE(6379)] = 230705,
  [SMALL_STATE(6380)] = 230732,
  [SMALL_STATE(6381)] = 230767,
  [SMALL_STATE(6382)] = 230792,
  [SMALL_STATE(6383)] = 230816,
  [SMALL_STATE(6384)] = 230838,
  [SMALL_STATE(6385)] = 230860,
  [SMALL_STATE(6386)] = 230882,
  [SMALL_STATE(6387)] = 230904,
  [SMALL_STATE(6388)] = 230926,
  [SMALL_STATE(6389)] = 230948,
  [SMALL_STATE(6390)] = 230972,
  [SMALL_STATE(6391)] = 231000,
  [SMALL_STATE(6392)] = 231028,
  [SMALL_STATE(6393)] = 231058,
  [SMALL_STATE(6394)] = 231080,
  [SMALL_STATE(6395)] = 231104,
  [SMALL_STATE(6396)] = 231128,
  [SMALL_STATE(6397)] = 231150,
  [SMALL_STATE(6398)] = 231174,
  [SMALL_STATE(6399)] = 231204,
  [SMALL_STATE(6400)] = 231228,
  [SMALL_STATE(6401)] = 231246,
  [SMALL_STATE(6402)] = 231270,
  [SMALL_STATE(6403)] = 231292,
  [SMALL_STATE(6404)] = 231316,
  [SMALL_STATE(6405)] = 231334,
  [SMALL_STATE(6406)] = 231352,
  [SMALL_STATE(6407)] = 231376,
  [SMALL_STATE(6408)] = 231400,
  [SMALL_STATE(6409)] = 231424,
  [SMALL_STATE(6410)] = 231442,
  [SMALL_STATE(6411)] = 231466,
  [SMALL_STATE(6412)] = 231490,
  [SMALL_STATE(6413)] = 231514,
  [SMALL_STATE(6414)] = 231538,
  [SMALL_STATE(6415)] = 231562,
  [SMALL_STATE(6416)] = 231586,
  [SMALL_STATE(6417)] = 231610,
  [SMALL_STATE(6418)] = 231634,
  [SMALL_STATE(6419)] = 231658,
  [SMALL_STATE(6420)] = 231682,
  [SMALL_STATE(6421)] = 231706,
  [SMALL_STATE(6422)] = 231728,
  [SMALL_STATE(6423)] = 231752,
  [SMALL_STATE(6424)] = 231774,
  [SMALL_STATE(6425)] = 231798,
  [SMALL_STATE(6426)] = 231828,
  [SMALL_STATE(6427)] = 231850,
  [SMALL_STATE(6428)] = 231882,
  [SMALL_STATE(6429)] = 231912,
  [SMALL_STATE(6430)] = 231934,
  [SMALL_STATE(6431)] = 231956,
  [SMALL_STATE(6432)] = 231986,
  [SMALL_STATE(6433)] = 232008,
  [SMALL_STATE(6434)] = 232026,
  [SMALL_STATE(6435)] = 232044,
  [SMALL_STATE(6436)] = 232074,
  [SMALL_STATE(6437)] = 232092,
  [SMALL_STATE(6438)] = 232116,
  [SMALL_STATE(6439)] = 232140,
  [SMALL_STATE(6440)] = 232167,
  [SMALL_STATE(6441)] = 232188,
  [SMALL_STATE(6442)] = 232219,
  [SMALL_STATE(6443)] = 232238,
  [SMALL_STATE(6444)] = 232261,
  [SMALL_STATE(6445)] = 232288,
  [SMALL_STATE(6446)] = 232311,
  [SMALL_STATE(6447)] = 232334,
  [SMALL_STATE(6448)] = 232361,
  [SMALL_STATE(6449)] = 232384,
  [SMALL_STATE(6450)] = 232415,
  [SMALL_STATE(6451)] = 232436,
  [SMALL_STATE(6452)] = 232467,
  [SMALL_STATE(6453)] = 232490,
  [SMALL_STATE(6454)] = 232521,
  [SMALL_STATE(6455)] = 232544,
  [SMALL_STATE(6456)] = 232571,
  [SMALL_STATE(6457)] = 232602,
  [SMALL_STATE(6458)] = 232633,
  [SMALL_STATE(6459)] = 232664,
  [SMALL_STATE(6460)] = 232695,
  [SMALL_STATE(6461)] = 232718,
  [SMALL_STATE(6462)] = 232749,
  [SMALL_STATE(6463)] = 232772,
  [SMALL_STATE(6464)] = 232791,
  [SMALL_STATE(6465)] = 232822,
  [SMALL_STATE(6466)] = 232849,
  [SMALL_STATE(6467)] = 232870,
  [SMALL_STATE(6468)] = 232901,
  [SMALL_STATE(6469)] = 232924,
  [SMALL_STATE(6470)] = 232947,
  [SMALL_STATE(6471)] = 232974,
  [SMALL_STATE(6472)] = 232997,
  [SMALL_STATE(6473)] = 233028,
  [SMALL_STATE(6474)] = 233051,
  [SMALL_STATE(6475)] = 233078,
  [SMALL_STATE(6476)] = 233109,
  [SMALL_STATE(6477)] = 233140,
  [SMALL_STATE(6478)] = 233163,
  [SMALL_STATE(6479)] = 233186,
  [SMALL_STATE(6480)] = 233217,
  [SMALL_STATE(6481)] = 233244,
  [SMALL_STATE(6482)] = 233275,
  [SMALL_STATE(6483)] = 233306,
  [SMALL_STATE(6484)] = 233333,
  [SMALL_STATE(6485)] = 233364,
  [SMALL_STATE(6486)] = 233395,
  [SMALL_STATE(6487)] = 233426,
  [SMALL_STATE(6488)] = 233451,
  [SMALL_STATE(6489)] = 233482,
  [SMALL_STATE(6490)] = 233513,
  [SMALL_STATE(6491)] = 233544,
  [SMALL_STATE(6492)] = 233571,
  [SMALL_STATE(6493)] = 233602,
  [SMALL_STATE(6494)] = 233629,
  [SMALL_STATE(6495)] = 233650,
  [SMALL_STATE(6496)] = 233681,
  [SMALL_STATE(6497)] = 233708,
  [SMALL_STATE(6498)] = 233739,
  [SMALL_STATE(6499)] = 233766,
  [SMALL_STATE(6500)] = 233797,
  [SMALL_STATE(6501)] = 233824,
  [SMALL_STATE(6502)] = 233855,
  [SMALL_STATE(6503)] = 233886,
  [SMALL_STATE(6504)] = 233917,
  [SMALL_STATE(6505)] = 233948,
  [SMALL_STATE(6506)] = 233979,
  [SMALL_STATE(6507)] = 234010,
  [SMALL_STATE(6508)] = 234036,
  [SMALL_STATE(6509)] = 234062,
  [SMALL_STATE(6510)] = 234086,
  [SMALL_STATE(6511)] = 234112,
  [SMALL_STATE(6512)] = 234136,
  [SMALL_STATE(6513)] = 234160,
  [SMALL_STATE(6514)] = 234182,
  [SMALL_STATE(6515)] = 234208,
  [SMALL_STATE(6516)] = 234234,
  [SMALL_STATE(6517)] = 234260,
  [SMALL_STATE(6518)] = 234286,
  [SMALL_STATE(6519)] = 234306,
  [SMALL_STATE(6520)] = 234332,
  [SMALL_STATE(6521)] = 234358,
  [SMALL_STATE(6522)] = 234380,
  [SMALL_STATE(6523)] = 234406,
  [SMALL_STATE(6524)] = 234422,
  [SMALL_STATE(6525)] = 234448,
  [SMALL_STATE(6526)] = 234470,
  [SMALL_STATE(6527)] = 234496,
  [SMALL_STATE(6528)] = 234522,
  [SMALL_STATE(6529)] = 234548,
  [SMALL_STATE(6530)] = 234572,
  [SMALL_STATE(6531)] = 234598,
  [SMALL_STATE(6532)] = 234618,
  [SMALL_STATE(6533)] = 234640,
  [SMALL_STATE(6534)] = 234666,
  [SMALL_STATE(6535)] = 234692,
  [SMALL_STATE(6536)] = 234718,
  [SMALL_STATE(6537)] = 234742,
  [SMALL_STATE(6538)] = 234768,
  [SMALL_STATE(6539)] = 234794,
  [SMALL_STATE(6540)] = 234816,
  [SMALL_STATE(6541)] = 234842,
  [SMALL_STATE(6542)] = 234868,
  [SMALL_STATE(6543)] = 234894,
  [SMALL_STATE(6544)] = 234910,
  [SMALL_STATE(6545)] = 234928,
  [SMALL_STATE(6546)] = 234948,
  [SMALL_STATE(6547)] = 234970,
  [SMALL_STATE(6548)] = 234992,
  [SMALL_STATE(6549)] = 235018,
  [SMALL_STATE(6550)] = 235044,
  [SMALL_STATE(6551)] = 235070,
  [SMALL_STATE(6552)] = 235096,
  [SMALL_STATE(6553)] = 235122,
  [SMALL_STATE(6554)] = 235148,
  [SMALL_STATE(6555)] = 235168,
  [SMALL_STATE(6556)] = 235190,
  [SMALL_STATE(6557)] = 235216,
  [SMALL_STATE(6558)] = 235242,
  [SMALL_STATE(6559)] = 235268,
  [SMALL_STATE(6560)] = 235285,
  [SMALL_STATE(6561)] = 235304,
  [SMALL_STATE(6562)] = 235327,
  [SMALL_STATE(6563)] = 235348,
  [SMALL_STATE(6564)] = 235369,
  [SMALL_STATE(6565)] = 235390,
  [SMALL_STATE(6566)] = 235411,
  [SMALL_STATE(6567)] = 235434,
  [SMALL_STATE(6568)] = 235459,
  [SMALL_STATE(6569)] = 235482,
  [SMALL_STATE(6570)] = 235507,
  [SMALL_STATE(6571)] = 235532,
  [SMALL_STATE(6572)] = 235553,
  [SMALL_STATE(6573)] = 235578,
  [SMALL_STATE(6574)] = 235599,
  [SMALL_STATE(6575)] = 235620,
  [SMALL_STATE(6576)] = 235635,
  [SMALL_STATE(6577)] = 235656,
  [SMALL_STATE(6578)] = 235677,
  [SMALL_STATE(6579)] = 235698,
  [SMALL_STATE(6580)] = 235713,
  [SMALL_STATE(6581)] = 235736,
  [SMALL_STATE(6582)] = 235759,
  [SMALL_STATE(6583)] = 235784,
  [SMALL_STATE(6584)] = 235799,
  [SMALL_STATE(6585)] = 235822,
  [SMALL_STATE(6586)] = 235845,
  [SMALL_STATE(6587)] = 235868,
  [SMALL_STATE(6588)] = 235893,
  [SMALL_STATE(6589)] = 235908,
  [SMALL_STATE(6590)] = 235931,
  [SMALL_STATE(6591)] = 235952,
  [SMALL_STATE(6592)] = 235975,
  [SMALL_STATE(6593)] = 235996,
  [SMALL_STATE(6594)] = 236017,
  [SMALL_STATE(6595)] = 236038,
  [SMALL_STATE(6596)] = 236057,
  [SMALL_STATE(6597)] = 236080,
  [SMALL_STATE(6598)] = 236101,
  [SMALL_STATE(6599)] = 236122,
  [SMALL_STATE(6600)] = 236137,
  [SMALL_STATE(6601)] = 236158,
  [SMALL_STATE(6602)] = 236179,
  [SMALL_STATE(6603)] = 236200,
  [SMALL_STATE(6604)] = 236221,
  [SMALL_STATE(6605)] = 236240,
  [SMALL_STATE(6606)] = 236263,
  [SMALL_STATE(6607)] = 236282,
  [SMALL_STATE(6608)] = 236297,
  [SMALL_STATE(6609)] = 236318,
  [SMALL_STATE(6610)] = 236343,
  [SMALL_STATE(6611)] = 236366,
  [SMALL_STATE(6612)] = 236387,
  [SMALL_STATE(6613)] = 236402,
  [SMALL_STATE(6614)] = 236423,
  [SMALL_STATE(6615)] = 236446,
  [SMALL_STATE(6616)] = 236467,
  [SMALL_STATE(6617)] = 236492,
  [SMALL_STATE(6618)] = 236515,
  [SMALL_STATE(6619)] = 236530,
  [SMALL_STATE(6620)] = 236544,
  [SMALL_STATE(6621)] = 236562,
  [SMALL_STATE(6622)] = 236582,
  [SMALL_STATE(6623)] = 236598,
  [SMALL_STATE(6624)] = 236616,
  [SMALL_STATE(6625)] = 236632,
  [SMALL_STATE(6626)] = 236648,
  [SMALL_STATE(6627)] = 236668,
  [SMALL_STATE(6628)] = 236684,
  [SMALL_STATE(6629)] = 236704,
  [SMALL_STATE(6630)] = 236724,
  [SMALL_STATE(6631)] = 236738,
  [SMALL_STATE(6632)] = 236758,
  [SMALL_STATE(6633)] = 236774,
  [SMALL_STATE(6634)] = 236790,
  [SMALL_STATE(6635)] = 236804,
  [SMALL_STATE(6636)] = 236824,
  [SMALL_STATE(6637)] = 236844,
  [SMALL_STATE(6638)] = 236858,
  [SMALL_STATE(6639)] = 236874,
  [SMALL_STATE(6640)] = 236888,
  [SMALL_STATE(6641)] = 236906,
  [SMALL_STATE(6642)] = 236926,
  [SMALL_STATE(6643)] = 236940,
  [SMALL_STATE(6644)] = 236956,
  [SMALL_STATE(6645)] = 236970,
  [SMALL_STATE(6646)] = 236984,
  [SMALL_STATE(6647)] = 237002,
  [SMALL_STATE(6648)] = 237020,
  [SMALL_STATE(6649)] = 237036,
  [SMALL_STATE(6650)] = 237052,
  [SMALL_STATE(6651)] = 237070,
  [SMALL_STATE(6652)] = 237086,
  [SMALL_STATE(6653)] = 237104,
  [SMALL_STATE(6654)] = 237124,
  [SMALL_STATE(6655)] = 237138,
  [SMALL_STATE(6656)] = 237154,
  [SMALL_STATE(6657)] = 237174,
  [SMALL_STATE(6658)] = 237192,
  [SMALL_STATE(6659)] = 237206,
  [SMALL_STATE(6660)] = 237220,
  [SMALL_STATE(6661)] = 237240,
  [SMALL_STATE(6662)] = 237256,
  [SMALL_STATE(6663)] = 237270,
  [SMALL_STATE(6664)] = 237284,
  [SMALL_STATE(6665)] = 237304,
  [SMALL_STATE(6666)] = 237318,
  [SMALL_STATE(6667)] = 237332,
  [SMALL_STATE(6668)] = 237346,
  [SMALL_STATE(6669)] = 237366,
  [SMALL_STATE(6670)] = 237382,
  [SMALL_STATE(6671)] = 237398,
  [SMALL_STATE(6672)] = 237418,
  [SMALL_STATE(6673)] = 237437,
  [SMALL_STATE(6674)] = 237456,
  [SMALL_STATE(6675)] = 237475,
  [SMALL_STATE(6676)] = 237494,
  [SMALL_STATE(6677)] = 237513,
  [SMALL_STATE(6678)] = 237532,
  [SMALL_STATE(6679)] = 237551,
  [SMALL_STATE(6680)] = 237570,
  [SMALL_STATE(6681)] = 237589,
  [SMALL_STATE(6682)] = 237608,
  [SMALL_STATE(6683)] = 237627,
  [SMALL_STATE(6684)] = 237646,
  [SMALL_STATE(6685)] = 237663,
  [SMALL_STATE(6686)] = 237682,
  [SMALL_STATE(6687)] = 237701,
  [SMALL_STATE(6688)] = 237720,
  [SMALL_STATE(6689)] = 237739,
  [SMALL_STATE(6690)] = 237758,
  [SMALL_STATE(6691)] = 237777,
  [SMALL_STATE(6692)] = 237796,
  [SMALL_STATE(6693)] = 237815,
  [SMALL_STATE(6694)] = 237834,
  [SMALL_STATE(6695)] = 237853,
  [SMALL_STATE(6696)] = 237872,
  [SMALL_STATE(6697)] = 237889,
  [SMALL_STATE(6698)] = 237902,
  [SMALL_STATE(6699)] = 237921,
  [SMALL_STATE(6700)] = 237934,
  [SMALL_STATE(6701)] = 237953,
  [SMALL_STATE(6702)] = 237972,
  [SMALL_STATE(6703)] = 237991,
  [SMALL_STATE(6704)] = 238010,
  [SMALL_STATE(6705)] = 238029,
  [SMALL_STATE(6706)] = 238048,
  [SMALL_STATE(6707)] = 238067,
  [SMALL_STATE(6708)] = 238086,
  [SMALL_STATE(6709)] = 238105,
  [SMALL_STATE(6710)] = 238124,
  [SMALL_STATE(6711)] = 238143,
  [SMALL_STATE(6712)] = 238162,
  [SMALL_STATE(6713)] = 238181,
  [SMALL_STATE(6714)] = 238200,
  [SMALL_STATE(6715)] = 238219,
  [SMALL_STATE(6716)] = 238236,
  [SMALL_STATE(6717)] = 238255,
  [SMALL_STATE(6718)] = 238274,
  [SMALL_STATE(6719)] = 238291,
  [SMALL_STATE(6720)] = 238310,
  [SMALL_STATE(6721)] = 238327,
  [SMALL_STATE(6722)] = 238346,
  [SMALL_STATE(6723)] = 238363,
  [SMALL_STATE(6724)] = 238380,
  [SMALL_STATE(6725)] = 238399,
  [SMALL_STATE(6726)] = 238413,
  [SMALL_STATE(6727)] = 238423,
  [SMALL_STATE(6728)] = 238437,
  [SMALL_STATE(6729)] = 238453,
  [SMALL_STATE(6730)] = 238469,
  [SMALL_STATE(6731)] = 238483,
  [SMALL_STATE(6732)] = 238497,
  [SMALL_STATE(6733)] = 238513,
  [SMALL_STATE(6734)] = 238529,
  [SMALL_STATE(6735)] = 238543,
  [SMALL_STATE(6736)] = 238557,
  [SMALL_STATE(6737)] = 238571,
  [SMALL_STATE(6738)] = 238587,
  [SMALL_STATE(6739)] = 238603,
  [SMALL_STATE(6740)] = 238619,
  [SMALL_STATE(6741)] = 238635,
  [SMALL_STATE(6742)] = 238651,
  [SMALL_STATE(6743)] = 238665,
  [SMALL_STATE(6744)] = 238679,
  [SMALL_STATE(6745)] = 238695,
  [SMALL_STATE(6746)] = 238711,
  [SMALL_STATE(6747)] = 238725,
  [SMALL_STATE(6748)] = 238741,
  [SMALL_STATE(6749)] = 238755,
  [SMALL_STATE(6750)] = 238771,
  [SMALL_STATE(6751)] = 238787,
  [SMALL_STATE(6752)] = 238803,
  [SMALL_STATE(6753)] = 238817,
  [SMALL_STATE(6754)] = 238831,
  [SMALL_STATE(6755)] = 238847,
  [SMALL_STATE(6756)] = 238861,
  [SMALL_STATE(6757)] = 238877,
  [SMALL_STATE(6758)] = 238891,
  [SMALL_STATE(6759)] = 238907,
  [SMALL_STATE(6760)] = 238921,
  [SMALL_STATE(6761)] = 238937,
  [SMALL_STATE(6762)] = 238953,
  [SMALL_STATE(6763)] = 238967,
  [SMALL_STATE(6764)] = 238981,
  [SMALL_STATE(6765)] = 238995,
  [SMALL_STATE(6766)] = 239011,
  [SMALL_STATE(6767)] = 239027,
  [SMALL_STATE(6768)] = 239043,
  [SMALL_STATE(6769)] = 239057,
  [SMALL_STATE(6770)] = 239073,
  [SMALL_STATE(6771)] = 239089,
  [SMALL_STATE(6772)] = 239105,
  [SMALL_STATE(6773)] = 239121,
  [SMALL_STATE(6774)] = 239137,
  [SMALL_STATE(6775)] = 239153,
  [SMALL_STATE(6776)] = 239167,
  [SMALL_STATE(6777)] = 239183,
  [SMALL_STATE(6778)] = 239199,
  [SMALL_STATE(6779)] = 239215,
  [SMALL_STATE(6780)] = 239231,
  [SMALL_STATE(6781)] = 239247,
  [SMALL_STATE(6782)] = 239263,
  [SMALL_STATE(6783)] = 239279,
  [SMALL_STATE(6784)] = 239295,
  [SMALL_STATE(6785)] = 239311,
  [SMALL_STATE(6786)] = 239325,
  [SMALL_STATE(6787)] = 239341,
  [SMALL_STATE(6788)] = 239355,
  [SMALL_STATE(6789)] = 239371,
  [SMALL_STATE(6790)] = 239385,
  [SMALL_STATE(6791)] = 239401,
  [SMALL_STATE(6792)] = 239417,
  [SMALL_STATE(6793)] = 239433,
  [SMALL_STATE(6794)] = 239447,
  [SMALL_STATE(6795)] = 239461,
  [SMALL_STATE(6796)] = 239475,
  [SMALL_STATE(6797)] = 239491,
  [SMALL_STATE(6798)] = 239507,
  [SMALL_STATE(6799)] = 239523,
  [SMALL_STATE(6800)] = 239539,
  [SMALL_STATE(6801)] = 239555,
  [SMALL_STATE(6802)] = 239569,
  [SMALL_STATE(6803)] = 239585,
  [SMALL_STATE(6804)] = 239601,
  [SMALL_STATE(6805)] = 239615,
  [SMALL_STATE(6806)] = 239631,
  [SMALL_STATE(6807)] = 239647,
  [SMALL_STATE(6808)] = 239663,
  [SMALL_STATE(6809)] = 239677,
  [SMALL_STATE(6810)] = 239693,
  [SMALL_STATE(6811)] = 239709,
  [SMALL_STATE(6812)] = 239725,
  [SMALL_STATE(6813)] = 239741,
  [SMALL_STATE(6814)] = 239757,
  [SMALL_STATE(6815)] = 239771,
  [SMALL_STATE(6816)] = 239787,
  [SMALL_STATE(6817)] = 239803,
  [SMALL_STATE(6818)] = 239819,
  [SMALL_STATE(6819)] = 239835,
  [SMALL_STATE(6820)] = 239851,
  [SMALL_STATE(6821)] = 239867,
  [SMALL_STATE(6822)] = 239883,
  [SMALL_STATE(6823)] = 239899,
  [SMALL_STATE(6824)] = 239913,
  [SMALL_STATE(6825)] = 239929,
  [SMALL_STATE(6826)] = 239939,
  [SMALL_STATE(6827)] = 239953,
  [SMALL_STATE(6828)] = 239967,
  [SMALL_STATE(6829)] = 239981,
  [SMALL_STATE(6830)] = 239997,
  [SMALL_STATE(6831)] = 240013,
  [SMALL_STATE(6832)] = 240029,
  [SMALL_STATE(6833)] = 240045,
  [SMALL_STATE(6834)] = 240059,
  [SMALL_STATE(6835)] = 240075,
  [SMALL_STATE(6836)] = 240091,
  [SMALL_STATE(6837)] = 240107,
  [SMALL_STATE(6838)] = 240121,
  [SMALL_STATE(6839)] = 240137,
  [SMALL_STATE(6840)] = 240153,
  [SMALL_STATE(6841)] = 240169,
  [SMALL_STATE(6842)] = 240183,
  [SMALL_STATE(6843)] = 240199,
  [SMALL_STATE(6844)] = 240213,
  [SMALL_STATE(6845)] = 240229,
  [SMALL_STATE(6846)] = 240245,
  [SMALL_STATE(6847)] = 240261,
  [SMALL_STATE(6848)] = 240277,
  [SMALL_STATE(6849)] = 240291,
  [SMALL_STATE(6850)] = 240305,
  [SMALL_STATE(6851)] = 240321,
  [SMALL_STATE(6852)] = 240335,
  [SMALL_STATE(6853)] = 240351,
  [SMALL_STATE(6854)] = 240365,
  [SMALL_STATE(6855)] = 240381,
  [SMALL_STATE(6856)] = 240397,
  [SMALL_STATE(6857)] = 240411,
  [SMALL_STATE(6858)] = 240427,
  [SMALL_STATE(6859)] = 240441,
  [SMALL_STATE(6860)] = 240455,
  [SMALL_STATE(6861)] = 240471,
  [SMALL_STATE(6862)] = 240485,
  [SMALL_STATE(6863)] = 240501,
  [SMALL_STATE(6864)] = 240515,
  [SMALL_STATE(6865)] = 240529,
  [SMALL_STATE(6866)] = 240543,
  [SMALL_STATE(6867)] = 240557,
  [SMALL_STATE(6868)] = 240573,
  [SMALL_STATE(6869)] = 240589,
  [SMALL_STATE(6870)] = 240603,
  [SMALL_STATE(6871)] = 240617,
  [SMALL_STATE(6872)] = 240633,
  [SMALL_STATE(6873)] = 240649,
  [SMALL_STATE(6874)] = 240665,
  [SMALL_STATE(6875)] = 240681,
  [SMALL_STATE(6876)] = 240697,
  [SMALL_STATE(6877)] = 240711,
  [SMALL_STATE(6878)] = 240727,
  [SMALL_STATE(6879)] = 240741,
  [SMALL_STATE(6880)] = 240757,
  [SMALL_STATE(6881)] = 240773,
  [SMALL_STATE(6882)] = 240789,
  [SMALL_STATE(6883)] = 240805,
  [SMALL_STATE(6884)] = 240821,
  [SMALL_STATE(6885)] = 240835,
  [SMALL_STATE(6886)] = 240849,
  [SMALL_STATE(6887)] = 240865,
  [SMALL_STATE(6888)] = 240879,
  [SMALL_STATE(6889)] = 240893,
  [SMALL_STATE(6890)] = 240907,
  [SMALL_STATE(6891)] = 240923,
  [SMALL_STATE(6892)] = 240939,
  [SMALL_STATE(6893)] = 240953,
  [SMALL_STATE(6894)] = 240967,
  [SMALL_STATE(6895)] = 240981,
  [SMALL_STATE(6896)] = 240997,
  [SMALL_STATE(6897)] = 241011,
  [SMALL_STATE(6898)] = 241027,
  [SMALL_STATE(6899)] = 241043,
  [SMALL_STATE(6900)] = 241057,
  [SMALL_STATE(6901)] = 241073,
  [SMALL_STATE(6902)] = 241087,
  [SMALL_STATE(6903)] = 241103,
  [SMALL_STATE(6904)] = 241119,
  [SMALL_STATE(6905)] = 241135,
  [SMALL_STATE(6906)] = 241149,
  [SMALL_STATE(6907)] = 241163,
  [SMALL_STATE(6908)] = 241177,
  [SMALL_STATE(6909)] = 241193,
  [SMALL_STATE(6910)] = 241209,
  [SMALL_STATE(6911)] = 241223,
  [SMALL_STATE(6912)] = 241237,
  [SMALL_STATE(6913)] = 241251,
  [SMALL_STATE(6914)] = 241265,
  [SMALL_STATE(6915)] = 241281,
  [SMALL_STATE(6916)] = 241297,
  [SMALL_STATE(6917)] = 241313,
  [SMALL_STATE(6918)] = 241325,
  [SMALL_STATE(6919)] = 241341,
  [SMALL_STATE(6920)] = 241355,
  [SMALL_STATE(6921)] = 241369,
  [SMALL_STATE(6922)] = 241383,
  [SMALL_STATE(6923)] = 241399,
  [SMALL_STATE(6924)] = 241413,
  [SMALL_STATE(6925)] = 241427,
  [SMALL_STATE(6926)] = 241441,
  [SMALL_STATE(6927)] = 241457,
  [SMALL_STATE(6928)] = 241473,
  [SMALL_STATE(6929)] = 241489,
  [SMALL_STATE(6930)] = 241505,
  [SMALL_STATE(6931)] = 241519,
  [SMALL_STATE(6932)] = 241533,
  [SMALL_STATE(6933)] = 241549,
  [SMALL_STATE(6934)] = 241563,
  [SMALL_STATE(6935)] = 241579,
  [SMALL_STATE(6936)] = 241593,
  [SMALL_STATE(6937)] = 241607,
  [SMALL_STATE(6938)] = 241623,
  [SMALL_STATE(6939)] = 241637,
  [SMALL_STATE(6940)] = 241653,
  [SMALL_STATE(6941)] = 241667,
  [SMALL_STATE(6942)] = 241683,
  [SMALL_STATE(6943)] = 241699,
  [SMALL_STATE(6944)] = 241715,
  [SMALL_STATE(6945)] = 241729,
  [SMALL_STATE(6946)] = 241745,
  [SMALL_STATE(6947)] = 241759,
  [SMALL_STATE(6948)] = 241775,
  [SMALL_STATE(6949)] = 241789,
  [SMALL_STATE(6950)] = 241803,
  [SMALL_STATE(6951)] = 241819,
  [SMALL_STATE(6952)] = 241833,
  [SMALL_STATE(6953)] = 241849,
  [SMALL_STATE(6954)] = 241865,
  [SMALL_STATE(6955)] = 241881,
  [SMALL_STATE(6956)] = 241897,
  [SMALL_STATE(6957)] = 241911,
  [SMALL_STATE(6958)] = 241921,
  [SMALL_STATE(6959)] = 241937,
  [SMALL_STATE(6960)] = 241953,
  [SMALL_STATE(6961)] = 241969,
  [SMALL_STATE(6962)] = 241985,
  [SMALL_STATE(6963)] = 242001,
  [SMALL_STATE(6964)] = 242017,
  [SMALL_STATE(6965)] = 242031,
  [SMALL_STATE(6966)] = 242045,
  [SMALL_STATE(6967)] = 242059,
  [SMALL_STATE(6968)] = 242073,
  [SMALL_STATE(6969)] = 242087,
  [SMALL_STATE(6970)] = 242103,
  [SMALL_STATE(6971)] = 242119,
  [SMALL_STATE(6972)] = 242133,
  [SMALL_STATE(6973)] = 242149,
  [SMALL_STATE(6974)] = 242165,
  [SMALL_STATE(6975)] = 242179,
  [SMALL_STATE(6976)] = 242195,
  [SMALL_STATE(6977)] = 242209,
  [SMALL_STATE(6978)] = 242223,
  [SMALL_STATE(6979)] = 242237,
  [SMALL_STATE(6980)] = 242251,
  [SMALL_STATE(6981)] = 242267,
  [SMALL_STATE(6982)] = 242283,
  [SMALL_STATE(6983)] = 242299,
  [SMALL_STATE(6984)] = 242313,
  [SMALL_STATE(6985)] = 242327,
  [SMALL_STATE(6986)] = 242343,
  [SMALL_STATE(6987)] = 242359,
  [SMALL_STATE(6988)] = 242373,
  [SMALL_STATE(6989)] = 242387,
  [SMALL_STATE(6990)] = 242403,
  [SMALL_STATE(6991)] = 242417,
  [SMALL_STATE(6992)] = 242433,
  [SMALL_STATE(6993)] = 242449,
  [SMALL_STATE(6994)] = 242465,
  [SMALL_STATE(6995)] = 242479,
  [SMALL_STATE(6996)] = 242495,
  [SMALL_STATE(6997)] = 242509,
  [SMALL_STATE(6998)] = 242523,
  [SMALL_STATE(6999)] = 242539,
  [SMALL_STATE(7000)] = 242555,
  [SMALL_STATE(7001)] = 242571,
  [SMALL_STATE(7002)] = 242587,
  [SMALL_STATE(7003)] = 242601,
  [SMALL_STATE(7004)] = 242615,
  [SMALL_STATE(7005)] = 242629,
  [SMALL_STATE(7006)] = 242643,
  [SMALL_STATE(7007)] = 242659,
  [SMALL_STATE(7008)] = 242673,
  [SMALL_STATE(7009)] = 242687,
  [SMALL_STATE(7010)] = 242701,
  [SMALL_STATE(7011)] = 242717,
  [SMALL_STATE(7012)] = 242733,
  [SMALL_STATE(7013)] = 242749,
  [SMALL_STATE(7014)] = 242763,
  [SMALL_STATE(7015)] = 242776,
  [SMALL_STATE(7016)] = 242785,
  [SMALL_STATE(7017)] = 242798,
  [SMALL_STATE(7018)] = 242811,
  [SMALL_STATE(7019)] = 242824,
  [SMALL_STATE(7020)] = 242837,
  [SMALL_STATE(7021)] = 242850,
  [SMALL_STATE(7022)] = 242861,
  [SMALL_STATE(7023)] = 242870,
  [SMALL_STATE(7024)] = 242883,
  [SMALL_STATE(7025)] = 242894,
  [SMALL_STATE(7026)] = 242907,
  [SMALL_STATE(7027)] = 242920,
  [SMALL_STATE(7028)] = 242933,
  [SMALL_STATE(7029)] = 242946,
  [SMALL_STATE(7030)] = 242959,
  [SMALL_STATE(7031)] = 242972,
  [SMALL_STATE(7032)] = 242985,
  [SMALL_STATE(7033)] = 242998,
  [SMALL_STATE(7034)] = 243011,
  [SMALL_STATE(7035)] = 243024,
  [SMALL_STATE(7036)] = 243037,
  [SMALL_STATE(7037)] = 243046,
  [SMALL_STATE(7038)] = 243059,
  [SMALL_STATE(7039)] = 243070,
  [SMALL_STATE(7040)] = 243083,
  [SMALL_STATE(7041)] = 243096,
  [SMALL_STATE(7042)] = 243109,
  [SMALL_STATE(7043)] = 243122,
  [SMALL_STATE(7044)] = 243135,
  [SMALL_STATE(7045)] = 243148,
  [SMALL_STATE(7046)] = 243161,
  [SMALL_STATE(7047)] = 243174,
  [SMALL_STATE(7048)] = 243187,
  [SMALL_STATE(7049)] = 243200,
  [SMALL_STATE(7050)] = 243213,
  [SMALL_STATE(7051)] = 243226,
  [SMALL_STATE(7052)] = 243239,
  [SMALL_STATE(7053)] = 243252,
  [SMALL_STATE(7054)] = 243265,
  [SMALL_STATE(7055)] = 243278,
  [SMALL_STATE(7056)] = 243291,
  [SMALL_STATE(7057)] = 243304,
  [SMALL_STATE(7058)] = 243315,
  [SMALL_STATE(7059)] = 243328,
  [SMALL_STATE(7060)] = 243341,
  [SMALL_STATE(7061)] = 243354,
  [SMALL_STATE(7062)] = 243367,
  [SMALL_STATE(7063)] = 243378,
  [SMALL_STATE(7064)] = 243387,
  [SMALL_STATE(7065)] = 243400,
  [SMALL_STATE(7066)] = 243413,
  [SMALL_STATE(7067)] = 243426,
  [SMALL_STATE(7068)] = 243439,
  [SMALL_STATE(7069)] = 243452,
  [SMALL_STATE(7070)] = 243465,
  [SMALL_STATE(7071)] = 243478,
  [SMALL_STATE(7072)] = 243491,
  [SMALL_STATE(7073)] = 243504,
  [SMALL_STATE(7074)] = 243515,
  [SMALL_STATE(7075)] = 243524,
  [SMALL_STATE(7076)] = 243537,
  [SMALL_STATE(7077)] = 243550,
  [SMALL_STATE(7078)] = 243563,
  [SMALL_STATE(7079)] = 243574,
  [SMALL_STATE(7080)] = 243585,
  [SMALL_STATE(7081)] = 243598,
  [SMALL_STATE(7082)] = 243611,
  [SMALL_STATE(7083)] = 243624,
  [SMALL_STATE(7084)] = 243637,
  [SMALL_STATE(7085)] = 243650,
  [SMALL_STATE(7086)] = 243663,
  [SMALL_STATE(7087)] = 243676,
  [SMALL_STATE(7088)] = 243685,
  [SMALL_STATE(7089)] = 243694,
  [SMALL_STATE(7090)] = 243707,
  [SMALL_STATE(7091)] = 243720,
  [SMALL_STATE(7092)] = 243733,
  [SMALL_STATE(7093)] = 243746,
  [SMALL_STATE(7094)] = 243759,
  [SMALL_STATE(7095)] = 243772,
  [SMALL_STATE(7096)] = 243785,
  [SMALL_STATE(7097)] = 243798,
  [SMALL_STATE(7098)] = 243811,
  [SMALL_STATE(7099)] = 243822,
  [SMALL_STATE(7100)] = 243835,
  [SMALL_STATE(7101)] = 243848,
  [SMALL_STATE(7102)] = 243861,
  [SMALL_STATE(7103)] = 243872,
  [SMALL_STATE(7104)] = 243885,
  [SMALL_STATE(7105)] = 243898,
  [SMALL_STATE(7106)] = 243911,
  [SMALL_STATE(7107)] = 243924,
  [SMALL_STATE(7108)] = 243935,
  [SMALL_STATE(7109)] = 243948,
  [SMALL_STATE(7110)] = 243961,
  [SMALL_STATE(7111)] = 243974,
  [SMALL_STATE(7112)] = 243987,
  [SMALL_STATE(7113)] = 244000,
  [SMALL_STATE(7114)] = 244013,
  [SMALL_STATE(7115)] = 244026,
  [SMALL_STATE(7116)] = 244039,
  [SMALL_STATE(7117)] = 244052,
  [SMALL_STATE(7118)] = 244065,
  [SMALL_STATE(7119)] = 244078,
  [SMALL_STATE(7120)] = 244091,
  [SMALL_STATE(7121)] = 244104,
  [SMALL_STATE(7122)] = 244117,
  [SMALL_STATE(7123)] = 244130,
  [SMALL_STATE(7124)] = 244143,
  [SMALL_STATE(7125)] = 244154,
  [SMALL_STATE(7126)] = 244167,
  [SMALL_STATE(7127)] = 244180,
  [SMALL_STATE(7128)] = 244189,
  [SMALL_STATE(7129)] = 244202,
  [SMALL_STATE(7130)] = 244215,
  [SMALL_STATE(7131)] = 244228,
  [SMALL_STATE(7132)] = 244241,
  [SMALL_STATE(7133)] = 244252,
  [SMALL_STATE(7134)] = 244265,
  [SMALL_STATE(7135)] = 244274,
  [SMALL_STATE(7136)] = 244287,
  [SMALL_STATE(7137)] = 244300,
  [SMALL_STATE(7138)] = 244311,
  [SMALL_STATE(7139)] = 244324,
  [SMALL_STATE(7140)] = 244337,
  [SMALL_STATE(7141)] = 244350,
  [SMALL_STATE(7142)] = 244363,
  [SMALL_STATE(7143)] = 244374,
  [SMALL_STATE(7144)] = 244387,
  [SMALL_STATE(7145)] = 244400,
  [SMALL_STATE(7146)] = 244411,
  [SMALL_STATE(7147)] = 244424,
  [SMALL_STATE(7148)] = 244437,
  [SMALL_STATE(7149)] = 244448,
  [SMALL_STATE(7150)] = 244461,
  [SMALL_STATE(7151)] = 244472,
  [SMALL_STATE(7152)] = 244483,
  [SMALL_STATE(7153)] = 244496,
  [SMALL_STATE(7154)] = 244509,
  [SMALL_STATE(7155)] = 244522,
  [SMALL_STATE(7156)] = 244533,
  [SMALL_STATE(7157)] = 244546,
  [SMALL_STATE(7158)] = 244557,
  [SMALL_STATE(7159)] = 244570,
  [SMALL_STATE(7160)] = 244583,
  [SMALL_STATE(7161)] = 244596,
  [SMALL_STATE(7162)] = 244609,
  [SMALL_STATE(7163)] = 244622,
  [SMALL_STATE(7164)] = 244635,
  [SMALL_STATE(7165)] = 244648,
  [SMALL_STATE(7166)] = 244661,
  [SMALL_STATE(7167)] = 244674,
  [SMALL_STATE(7168)] = 244687,
  [SMALL_STATE(7169)] = 244700,
  [SMALL_STATE(7170)] = 244713,
  [SMALL_STATE(7171)] = 244726,
  [SMALL_STATE(7172)] = 244739,
  [SMALL_STATE(7173)] = 244752,
  [SMALL_STATE(7174)] = 244765,
  [SMALL_STATE(7175)] = 244778,
  [SMALL_STATE(7176)] = 244789,
  [SMALL_STATE(7177)] = 244802,
  [SMALL_STATE(7178)] = 244815,
  [SMALL_STATE(7179)] = 244828,
  [SMALL_STATE(7180)] = 244841,
  [SMALL_STATE(7181)] = 244852,
  [SMALL_STATE(7182)] = 244865,
  [SMALL_STATE(7183)] = 244878,
  [SMALL_STATE(7184)] = 244891,
  [SMALL_STATE(7185)] = 244904,
  [SMALL_STATE(7186)] = 244917,
  [SMALL_STATE(7187)] = 244930,
  [SMALL_STATE(7188)] = 244943,
  [SMALL_STATE(7189)] = 244956,
  [SMALL_STATE(7190)] = 244969,
  [SMALL_STATE(7191)] = 244982,
  [SMALL_STATE(7192)] = 244995,
  [SMALL_STATE(7193)] = 245008,
  [SMALL_STATE(7194)] = 245021,
  [SMALL_STATE(7195)] = 245034,
  [SMALL_STATE(7196)] = 245047,
  [SMALL_STATE(7197)] = 245060,
  [SMALL_STATE(7198)] = 245073,
  [SMALL_STATE(7199)] = 245086,
  [SMALL_STATE(7200)] = 245099,
  [SMALL_STATE(7201)] = 245112,
  [SMALL_STATE(7202)] = 245125,
  [SMALL_STATE(7203)] = 245138,
  [SMALL_STATE(7204)] = 245151,
  [SMALL_STATE(7205)] = 245160,
  [SMALL_STATE(7206)] = 245173,
  [SMALL_STATE(7207)] = 245186,
  [SMALL_STATE(7208)] = 245199,
  [SMALL_STATE(7209)] = 245212,
  [SMALL_STATE(7210)] = 245225,
  [SMALL_STATE(7211)] = 245234,
  [SMALL_STATE(7212)] = 245245,
  [SMALL_STATE(7213)] = 245258,
  [SMALL_STATE(7214)] = 245271,
  [SMALL_STATE(7215)] = 245284,
  [SMALL_STATE(7216)] = 245297,
  [SMALL_STATE(7217)] = 245310,
  [SMALL_STATE(7218)] = 245323,
  [SMALL_STATE(7219)] = 245336,
  [SMALL_STATE(7220)] = 245349,
  [SMALL_STATE(7221)] = 245362,
  [SMALL_STATE(7222)] = 245375,
  [SMALL_STATE(7223)] = 245388,
  [SMALL_STATE(7224)] = 245399,
  [SMALL_STATE(7225)] = 245412,
  [SMALL_STATE(7226)] = 245423,
  [SMALL_STATE(7227)] = 245436,
  [SMALL_STATE(7228)] = 245445,
  [SMALL_STATE(7229)] = 245458,
  [SMALL_STATE(7230)] = 245471,
  [SMALL_STATE(7231)] = 245480,
  [SMALL_STATE(7232)] = 245493,
  [SMALL_STATE(7233)] = 245506,
  [SMALL_STATE(7234)] = 245519,
  [SMALL_STATE(7235)] = 245532,
  [SMALL_STATE(7236)] = 245545,
  [SMALL_STATE(7237)] = 245558,
  [SMALL_STATE(7238)] = 245567,
  [SMALL_STATE(7239)] = 245580,
  [SMALL_STATE(7240)] = 245593,
  [SMALL_STATE(7241)] = 245606,
  [SMALL_STATE(7242)] = 245619,
  [SMALL_STATE(7243)] = 245632,
  [SMALL_STATE(7244)] = 245645,
  [SMALL_STATE(7245)] = 245658,
  [SMALL_STATE(7246)] = 245671,
  [SMALL_STATE(7247)] = 245682,
  [SMALL_STATE(7248)] = 245695,
  [SMALL_STATE(7249)] = 245708,
  [SMALL_STATE(7250)] = 245717,
  [SMALL_STATE(7251)] = 245730,
  [SMALL_STATE(7252)] = 245739,
  [SMALL_STATE(7253)] = 245752,
  [SMALL_STATE(7254)] = 245765,
  [SMALL_STATE(7255)] = 245778,
  [SMALL_STATE(7256)] = 245791,
  [SMALL_STATE(7257)] = 245800,
  [SMALL_STATE(7258)] = 245813,
  [SMALL_STATE(7259)] = 245826,
  [SMALL_STATE(7260)] = 245839,
  [SMALL_STATE(7261)] = 245852,
  [SMALL_STATE(7262)] = 245865,
  [SMALL_STATE(7263)] = 245878,
  [SMALL_STATE(7264)] = 245891,
  [SMALL_STATE(7265)] = 245904,
  [SMALL_STATE(7266)] = 245917,
  [SMALL_STATE(7267)] = 245930,
  [SMALL_STATE(7268)] = 245943,
  [SMALL_STATE(7269)] = 245956,
  [SMALL_STATE(7270)] = 245969,
  [SMALL_STATE(7271)] = 245982,
  [SMALL_STATE(7272)] = 245995,
  [SMALL_STATE(7273)] = 246006,
  [SMALL_STATE(7274)] = 246019,
  [SMALL_STATE(7275)] = 246032,
  [SMALL_STATE(7276)] = 246045,
  [SMALL_STATE(7277)] = 246058,
  [SMALL_STATE(7278)] = 246069,
  [SMALL_STATE(7279)] = 246082,
  [SMALL_STATE(7280)] = 246095,
  [SMALL_STATE(7281)] = 246108,
  [SMALL_STATE(7282)] = 246121,
  [SMALL_STATE(7283)] = 246132,
  [SMALL_STATE(7284)] = 246145,
  [SMALL_STATE(7285)] = 246158,
  [SMALL_STATE(7286)] = 246171,
  [SMALL_STATE(7287)] = 246184,
  [SMALL_STATE(7288)] = 246197,
  [SMALL_STATE(7289)] = 246210,
  [SMALL_STATE(7290)] = 246221,
  [SMALL_STATE(7291)] = 246234,
  [SMALL_STATE(7292)] = 246247,
  [SMALL_STATE(7293)] = 246260,
  [SMALL_STATE(7294)] = 246273,
  [SMALL_STATE(7295)] = 246284,
  [SMALL_STATE(7296)] = 246297,
  [SMALL_STATE(7297)] = 246310,
  [SMALL_STATE(7298)] = 246323,
  [SMALL_STATE(7299)] = 246336,
  [SMALL_STATE(7300)] = 246349,
  [SMALL_STATE(7301)] = 246362,
  [SMALL_STATE(7302)] = 246375,
  [SMALL_STATE(7303)] = 246388,
  [SMALL_STATE(7304)] = 246401,
  [SMALL_STATE(7305)] = 246414,
  [SMALL_STATE(7306)] = 246427,
  [SMALL_STATE(7307)] = 246440,
  [SMALL_STATE(7308)] = 246453,
  [SMALL_STATE(7309)] = 246466,
  [SMALL_STATE(7310)] = 246479,
  [SMALL_STATE(7311)] = 246492,
  [SMALL_STATE(7312)] = 246505,
  [SMALL_STATE(7313)] = 246518,
  [SMALL_STATE(7314)] = 246529,
  [SMALL_STATE(7315)] = 246542,
  [SMALL_STATE(7316)] = 246555,
  [SMALL_STATE(7317)] = 246568,
  [SMALL_STATE(7318)] = 246581,
  [SMALL_STATE(7319)] = 246592,
  [SMALL_STATE(7320)] = 246605,
  [SMALL_STATE(7321)] = 246618,
  [SMALL_STATE(7322)] = 246631,
  [SMALL_STATE(7323)] = 246644,
  [SMALL_STATE(7324)] = 246657,
  [SMALL_STATE(7325)] = 246670,
  [SMALL_STATE(7326)] = 246683,
  [SMALL_STATE(7327)] = 246696,
  [SMALL_STATE(7328)] = 246709,
  [SMALL_STATE(7329)] = 246722,
  [SMALL_STATE(7330)] = 246735,
  [SMALL_STATE(7331)] = 246748,
  [SMALL_STATE(7332)] = 246759,
  [SMALL_STATE(7333)] = 246772,
  [SMALL_STATE(7334)] = 246785,
  [SMALL_STATE(7335)] = 246798,
  [SMALL_STATE(7336)] = 246811,
  [SMALL_STATE(7337)] = 246822,
  [SMALL_STATE(7338)] = 246835,
  [SMALL_STATE(7339)] = 246848,
  [SMALL_STATE(7340)] = 246861,
  [SMALL_STATE(7341)] = 246874,
  [SMALL_STATE(7342)] = 246887,
  [SMALL_STATE(7343)] = 246898,
  [SMALL_STATE(7344)] = 246911,
  [SMALL_STATE(7345)] = 246924,
  [SMALL_STATE(7346)] = 246937,
  [SMALL_STATE(7347)] = 246950,
  [SMALL_STATE(7348)] = 246963,
  [SMALL_STATE(7349)] = 246976,
  [SMALL_STATE(7350)] = 246985,
  [SMALL_STATE(7351)] = 246998,
  [SMALL_STATE(7352)] = 247011,
  [SMALL_STATE(7353)] = 247024,
  [SMALL_STATE(7354)] = 247037,
  [SMALL_STATE(7355)] = 247046,
  [SMALL_STATE(7356)] = 247059,
  [SMALL_STATE(7357)] = 247068,
  [SMALL_STATE(7358)] = 247077,
  [SMALL_STATE(7359)] = 247090,
  [SMALL_STATE(7360)] = 247103,
  [SMALL_STATE(7361)] = 247116,
  [SMALL_STATE(7362)] = 247129,
  [SMALL_STATE(7363)] = 247142,
  [SMALL_STATE(7364)] = 247155,
  [SMALL_STATE(7365)] = 247166,
  [SMALL_STATE(7366)] = 247179,
  [SMALL_STATE(7367)] = 247190,
  [SMALL_STATE(7368)] = 247203,
  [SMALL_STATE(7369)] = 247214,
  [SMALL_STATE(7370)] = 247227,
  [SMALL_STATE(7371)] = 247240,
  [SMALL_STATE(7372)] = 247253,
  [SMALL_STATE(7373)] = 247266,
  [SMALL_STATE(7374)] = 247279,
  [SMALL_STATE(7375)] = 247292,
  [SMALL_STATE(7376)] = 247305,
  [SMALL_STATE(7377)] = 247318,
  [SMALL_STATE(7378)] = 247331,
  [SMALL_STATE(7379)] = 247342,
  [SMALL_STATE(7380)] = 247355,
  [SMALL_STATE(7381)] = 247368,
  [SMALL_STATE(7382)] = 247381,
  [SMALL_STATE(7383)] = 247394,
  [SMALL_STATE(7384)] = 247407,
  [SMALL_STATE(7385)] = 247420,
  [SMALL_STATE(7386)] = 247433,
  [SMALL_STATE(7387)] = 247446,
  [SMALL_STATE(7388)] = 247457,
  [SMALL_STATE(7389)] = 247470,
  [SMALL_STATE(7390)] = 247483,
  [SMALL_STATE(7391)] = 247496,
  [SMALL_STATE(7392)] = 247509,
  [SMALL_STATE(7393)] = 247522,
  [SMALL_STATE(7394)] = 247535,
  [SMALL_STATE(7395)] = 247548,
  [SMALL_STATE(7396)] = 247561,
  [SMALL_STATE(7397)] = 247574,
  [SMALL_STATE(7398)] = 247587,
  [SMALL_STATE(7399)] = 247600,
  [SMALL_STATE(7400)] = 247613,
  [SMALL_STATE(7401)] = 247626,
  [SMALL_STATE(7402)] = 247637,
  [SMALL_STATE(7403)] = 247650,
  [SMALL_STATE(7404)] = 247663,
  [SMALL_STATE(7405)] = 247672,
  [SMALL_STATE(7406)] = 247685,
  [SMALL_STATE(7407)] = 247696,
  [SMALL_STATE(7408)] = 247709,
  [SMALL_STATE(7409)] = 247722,
  [SMALL_STATE(7410)] = 247735,
  [SMALL_STATE(7411)] = 247748,
  [SMALL_STATE(7412)] = 247761,
  [SMALL_STATE(7413)] = 247772,
  [SMALL_STATE(7414)] = 247785,
  [SMALL_STATE(7415)] = 247798,
  [SMALL_STATE(7416)] = 247811,
  [SMALL_STATE(7417)] = 247824,
  [SMALL_STATE(7418)] = 247837,
  [SMALL_STATE(7419)] = 247848,
  [SMALL_STATE(7420)] = 247861,
  [SMALL_STATE(7421)] = 247874,
  [SMALL_STATE(7422)] = 247885,
  [SMALL_STATE(7423)] = 247898,
  [SMALL_STATE(7424)] = 247911,
  [SMALL_STATE(7425)] = 247922,
  [SMALL_STATE(7426)] = 247935,
  [SMALL_STATE(7427)] = 247948,
  [SMALL_STATE(7428)] = 247961,
  [SMALL_STATE(7429)] = 247974,
  [SMALL_STATE(7430)] = 247987,
  [SMALL_STATE(7431)] = 248000,
  [SMALL_STATE(7432)] = 248013,
  [SMALL_STATE(7433)] = 248026,
  [SMALL_STATE(7434)] = 248039,
  [SMALL_STATE(7435)] = 248052,
  [SMALL_STATE(7436)] = 248065,
  [SMALL_STATE(7437)] = 248078,
  [SMALL_STATE(7438)] = 248087,
  [SMALL_STATE(7439)] = 248100,
  [SMALL_STATE(7440)] = 248110,
  [SMALL_STATE(7441)] = 248120,
  [SMALL_STATE(7442)] = 248128,
  [SMALL_STATE(7443)] = 248138,
  [SMALL_STATE(7444)] = 248148,
  [SMALL_STATE(7445)] = 248156,
  [SMALL_STATE(7446)] = 248166,
  [SMALL_STATE(7447)] = 248174,
  [SMALL_STATE(7448)] = 248182,
  [SMALL_STATE(7449)] = 248190,
  [SMALL_STATE(7450)] = 248200,
  [SMALL_STATE(7451)] = 248210,
  [SMALL_STATE(7452)] = 248220,
  [SMALL_STATE(7453)] = 248230,
  [SMALL_STATE(7454)] = 248240,
  [SMALL_STATE(7455)] = 248248,
  [SMALL_STATE(7456)] = 248256,
  [SMALL_STATE(7457)] = 248266,
  [SMALL_STATE(7458)] = 248276,
  [SMALL_STATE(7459)] = 248286,
  [SMALL_STATE(7460)] = 248296,
  [SMALL_STATE(7461)] = 248306,
  [SMALL_STATE(7462)] = 248316,
  [SMALL_STATE(7463)] = 248326,
  [SMALL_STATE(7464)] = 248336,
  [SMALL_STATE(7465)] = 248346,
  [SMALL_STATE(7466)] = 248356,
  [SMALL_STATE(7467)] = 248366,
  [SMALL_STATE(7468)] = 248376,
  [SMALL_STATE(7469)] = 248386,
  [SMALL_STATE(7470)] = 248396,
  [SMALL_STATE(7471)] = 248406,
  [SMALL_STATE(7472)] = 248416,
  [SMALL_STATE(7473)] = 248426,
  [SMALL_STATE(7474)] = 248436,
  [SMALL_STATE(7475)] = 248446,
  [SMALL_STATE(7476)] = 248456,
  [SMALL_STATE(7477)] = 248464,
  [SMALL_STATE(7478)] = 248474,
  [SMALL_STATE(7479)] = 248484,
  [SMALL_STATE(7480)] = 248494,
  [SMALL_STATE(7481)] = 248504,
  [SMALL_STATE(7482)] = 248514,
  [SMALL_STATE(7483)] = 248522,
  [SMALL_STATE(7484)] = 248532,
  [SMALL_STATE(7485)] = 248542,
  [SMALL_STATE(7486)] = 248550,
  [SMALL_STATE(7487)] = 248560,
  [SMALL_STATE(7488)] = 248570,
  [SMALL_STATE(7489)] = 248580,
  [SMALL_STATE(7490)] = 248590,
  [SMALL_STATE(7491)] = 248600,
  [SMALL_STATE(7492)] = 248610,
  [SMALL_STATE(7493)] = 248620,
  [SMALL_STATE(7494)] = 248630,
  [SMALL_STATE(7495)] = 248640,
  [SMALL_STATE(7496)] = 248650,
  [SMALL_STATE(7497)] = 248658,
  [SMALL_STATE(7498)] = 248668,
  [SMALL_STATE(7499)] = 248678,
  [SMALL_STATE(7500)] = 248688,
  [SMALL_STATE(7501)] = 248698,
  [SMALL_STATE(7502)] = 248708,
  [SMALL_STATE(7503)] = 248716,
  [SMALL_STATE(7504)] = 248726,
  [SMALL_STATE(7505)] = 248736,
  [SMALL_STATE(7506)] = 248746,
  [SMALL_STATE(7507)] = 248756,
  [SMALL_STATE(7508)] = 248766,
  [SMALL_STATE(7509)] = 248776,
  [SMALL_STATE(7510)] = 248786,
  [SMALL_STATE(7511)] = 248796,
  [SMALL_STATE(7512)] = 248806,
  [SMALL_STATE(7513)] = 248816,
  [SMALL_STATE(7514)] = 248826,
  [SMALL_STATE(7515)] = 248836,
  [SMALL_STATE(7516)] = 248846,
  [SMALL_STATE(7517)] = 248856,
  [SMALL_STATE(7518)] = 248866,
  [SMALL_STATE(7519)] = 248874,
  [SMALL_STATE(7520)] = 248884,
  [SMALL_STATE(7521)] = 248894,
  [SMALL_STATE(7522)] = 248904,
  [SMALL_STATE(7523)] = 248914,
  [SMALL_STATE(7524)] = 248924,
  [SMALL_STATE(7525)] = 248934,
  [SMALL_STATE(7526)] = 248944,
  [SMALL_STATE(7527)] = 248954,
  [SMALL_STATE(7528)] = 248964,
  [SMALL_STATE(7529)] = 248974,
  [SMALL_STATE(7530)] = 248984,
  [SMALL_STATE(7531)] = 248994,
  [SMALL_STATE(7532)] = 249002,
  [SMALL_STATE(7533)] = 249012,
  [SMALL_STATE(7534)] = 249022,
  [SMALL_STATE(7535)] = 249032,
  [SMALL_STATE(7536)] = 249042,
  [SMALL_STATE(7537)] = 249052,
  [SMALL_STATE(7538)] = 249062,
  [SMALL_STATE(7539)] = 249072,
  [SMALL_STATE(7540)] = 249082,
  [SMALL_STATE(7541)] = 249092,
  [SMALL_STATE(7542)] = 249102,
  [SMALL_STATE(7543)] = 249112,
  [SMALL_STATE(7544)] = 249122,
  [SMALL_STATE(7545)] = 249132,
  [SMALL_STATE(7546)] = 249142,
  [SMALL_STATE(7547)] = 249150,
  [SMALL_STATE(7548)] = 249158,
  [SMALL_STATE(7549)] = 249168,
  [SMALL_STATE(7550)] = 249178,
  [SMALL_STATE(7551)] = 249188,
  [SMALL_STATE(7552)] = 249196,
  [SMALL_STATE(7553)] = 249206,
  [SMALL_STATE(7554)] = 249216,
  [SMALL_STATE(7555)] = 249226,
  [SMALL_STATE(7556)] = 249236,
  [SMALL_STATE(7557)] = 249246,
  [SMALL_STATE(7558)] = 249256,
  [SMALL_STATE(7559)] = 249266,
  [SMALL_STATE(7560)] = 249276,
  [SMALL_STATE(7561)] = 249286,
  [SMALL_STATE(7562)] = 249296,
  [SMALL_STATE(7563)] = 249306,
  [SMALL_STATE(7564)] = 249316,
  [SMALL_STATE(7565)] = 249326,
  [SMALL_STATE(7566)] = 249336,
  [SMALL_STATE(7567)] = 249346,
  [SMALL_STATE(7568)] = 249356,
  [SMALL_STATE(7569)] = 249366,
  [SMALL_STATE(7570)] = 249376,
  [SMALL_STATE(7571)] = 249386,
  [SMALL_STATE(7572)] = 249396,
  [SMALL_STATE(7573)] = 249406,
  [SMALL_STATE(7574)] = 249416,
  [SMALL_STATE(7575)] = 249426,
  [SMALL_STATE(7576)] = 249436,
  [SMALL_STATE(7577)] = 249446,
  [SMALL_STATE(7578)] = 249456,
  [SMALL_STATE(7579)] = 249466,
  [SMALL_STATE(7580)] = 249476,
  [SMALL_STATE(7581)] = 249486,
  [SMALL_STATE(7582)] = 249496,
  [SMALL_STATE(7583)] = 249506,
  [SMALL_STATE(7584)] = 249516,
  [SMALL_STATE(7585)] = 249526,
  [SMALL_STATE(7586)] = 249536,
  [SMALL_STATE(7587)] = 249544,
  [SMALL_STATE(7588)] = 249554,
  [SMALL_STATE(7589)] = 249564,
  [SMALL_STATE(7590)] = 249574,
  [SMALL_STATE(7591)] = 249582,
  [SMALL_STATE(7592)] = 249592,
  [SMALL_STATE(7593)] = 249602,
  [SMALL_STATE(7594)] = 249612,
  [SMALL_STATE(7595)] = 249620,
  [SMALL_STATE(7596)] = 249630,
  [SMALL_STATE(7597)] = 249640,
  [SMALL_STATE(7598)] = 249650,
  [SMALL_STATE(7599)] = 249658,
  [SMALL_STATE(7600)] = 249668,
  [SMALL_STATE(7601)] = 249676,
  [SMALL_STATE(7602)] = 249684,
  [SMALL_STATE(7603)] = 249694,
  [SMALL_STATE(7604)] = 249704,
  [SMALL_STATE(7605)] = 249714,
  [SMALL_STATE(7606)] = 249724,
  [SMALL_STATE(7607)] = 249734,
  [SMALL_STATE(7608)] = 249744,
  [SMALL_STATE(7609)] = 249752,
  [SMALL_STATE(7610)] = 249762,
  [SMALL_STATE(7611)] = 249770,
  [SMALL_STATE(7612)] = 249780,
  [SMALL_STATE(7613)] = 249788,
  [SMALL_STATE(7614)] = 249798,
  [SMALL_STATE(7615)] = 249808,
  [SMALL_STATE(7616)] = 249818,
  [SMALL_STATE(7617)] = 249826,
  [SMALL_STATE(7618)] = 249836,
  [SMALL_STATE(7619)] = 249844,
  [SMALL_STATE(7620)] = 249852,
  [SMALL_STATE(7621)] = 249862,
  [SMALL_STATE(7622)] = 249872,
  [SMALL_STATE(7623)] = 249880,
  [SMALL_STATE(7624)] = 249890,
  [SMALL_STATE(7625)] = 249900,
  [SMALL_STATE(7626)] = 249910,
  [SMALL_STATE(7627)] = 249920,
  [SMALL_STATE(7628)] = 249930,
  [SMALL_STATE(7629)] = 249940,
  [SMALL_STATE(7630)] = 249950,
  [SMALL_STATE(7631)] = 249960,
  [SMALL_STATE(7632)] = 249970,
  [SMALL_STATE(7633)] = 249980,
  [SMALL_STATE(7634)] = 249990,
  [SMALL_STATE(7635)] = 250000,
  [SMALL_STATE(7636)] = 250010,
  [SMALL_STATE(7637)] = 250020,
  [SMALL_STATE(7638)] = 250030,
  [SMALL_STATE(7639)] = 250040,
  [SMALL_STATE(7640)] = 250050,
  [SMALL_STATE(7641)] = 250060,
  [SMALL_STATE(7642)] = 250070,
  [SMALL_STATE(7643)] = 250080,
  [SMALL_STATE(7644)] = 250090,
  [SMALL_STATE(7645)] = 250100,
  [SMALL_STATE(7646)] = 250110,
  [SMALL_STATE(7647)] = 250120,
  [SMALL_STATE(7648)] = 250130,
  [SMALL_STATE(7649)] = 250140,
  [SMALL_STATE(7650)] = 250150,
  [SMALL_STATE(7651)] = 250160,
  [SMALL_STATE(7652)] = 250170,
  [SMALL_STATE(7653)] = 250180,
  [SMALL_STATE(7654)] = 250190,
  [SMALL_STATE(7655)] = 250200,
  [SMALL_STATE(7656)] = 250210,
  [SMALL_STATE(7657)] = 250220,
  [SMALL_STATE(7658)] = 250228,
  [SMALL_STATE(7659)] = 250238,
  [SMALL_STATE(7660)] = 250248,
  [SMALL_STATE(7661)] = 250258,
  [SMALL_STATE(7662)] = 250268,
  [SMALL_STATE(7663)] = 250278,
  [SMALL_STATE(7664)] = 250288,
  [SMALL_STATE(7665)] = 250296,
  [SMALL_STATE(7666)] = 250306,
  [SMALL_STATE(7667)] = 250316,
  [SMALL_STATE(7668)] = 250326,
  [SMALL_STATE(7669)] = 250336,
  [SMALL_STATE(7670)] = 250346,
  [SMALL_STATE(7671)] = 250354,
  [SMALL_STATE(7672)] = 250364,
  [SMALL_STATE(7673)] = 250374,
  [SMALL_STATE(7674)] = 250384,
  [SMALL_STATE(7675)] = 250394,
  [SMALL_STATE(7676)] = 250404,
  [SMALL_STATE(7677)] = 250414,
  [SMALL_STATE(7678)] = 250424,
  [SMALL_STATE(7679)] = 250434,
  [SMALL_STATE(7680)] = 250444,
  [SMALL_STATE(7681)] = 250454,
  [SMALL_STATE(7682)] = 250462,
  [SMALL_STATE(7683)] = 250472,
  [SMALL_STATE(7684)] = 250482,
  [SMALL_STATE(7685)] = 250490,
  [SMALL_STATE(7686)] = 250500,
  [SMALL_STATE(7687)] = 250510,
  [SMALL_STATE(7688)] = 250520,
  [SMALL_STATE(7689)] = 250530,
  [SMALL_STATE(7690)] = 250540,
  [SMALL_STATE(7691)] = 250550,
  [SMALL_STATE(7692)] = 250560,
  [SMALL_STATE(7693)] = 250570,
  [SMALL_STATE(7694)] = 250580,
  [SMALL_STATE(7695)] = 250590,
  [SMALL_STATE(7696)] = 250600,
  [SMALL_STATE(7697)] = 250610,
  [SMALL_STATE(7698)] = 250620,
  [SMALL_STATE(7699)] = 250630,
  [SMALL_STATE(7700)] = 250640,
  [SMALL_STATE(7701)] = 250650,
  [SMALL_STATE(7702)] = 250660,
  [SMALL_STATE(7703)] = 250670,
  [SMALL_STATE(7704)] = 250680,
  [SMALL_STATE(7705)] = 250690,
  [SMALL_STATE(7706)] = 250700,
  [SMALL_STATE(7707)] = 250710,
  [SMALL_STATE(7708)] = 250718,
  [SMALL_STATE(7709)] = 250726,
  [SMALL_STATE(7710)] = 250736,
  [SMALL_STATE(7711)] = 250744,
  [SMALL_STATE(7712)] = 250754,
  [SMALL_STATE(7713)] = 250764,
  [SMALL_STATE(7714)] = 250774,
  [SMALL_STATE(7715)] = 250784,
  [SMALL_STATE(7716)] = 250794,
  [SMALL_STATE(7717)] = 250804,
  [SMALL_STATE(7718)] = 250814,
  [SMALL_STATE(7719)] = 250824,
  [SMALL_STATE(7720)] = 250834,
  [SMALL_STATE(7721)] = 250844,
  [SMALL_STATE(7722)] = 250854,
  [SMALL_STATE(7723)] = 250864,
  [SMALL_STATE(7724)] = 250874,
  [SMALL_STATE(7725)] = 250884,
  [SMALL_STATE(7726)] = 250894,
  [SMALL_STATE(7727)] = 250904,
  [SMALL_STATE(7728)] = 250914,
  [SMALL_STATE(7729)] = 250924,
  [SMALL_STATE(7730)] = 250934,
  [SMALL_STATE(7731)] = 250944,
  [SMALL_STATE(7732)] = 250954,
  [SMALL_STATE(7733)] = 250964,
  [SMALL_STATE(7734)] = 250974,
  [SMALL_STATE(7735)] = 250984,
  [SMALL_STATE(7736)] = 250994,
  [SMALL_STATE(7737)] = 251004,
  [SMALL_STATE(7738)] = 251014,
  [SMALL_STATE(7739)] = 251024,
  [SMALL_STATE(7740)] = 251034,
  [SMALL_STATE(7741)] = 251044,
  [SMALL_STATE(7742)] = 251054,
  [SMALL_STATE(7743)] = 251064,
  [SMALL_STATE(7744)] = 251074,
  [SMALL_STATE(7745)] = 251084,
  [SMALL_STATE(7746)] = 251094,
  [SMALL_STATE(7747)] = 251104,
  [SMALL_STATE(7748)] = 251114,
  [SMALL_STATE(7749)] = 251124,
  [SMALL_STATE(7750)] = 251134,
  [SMALL_STATE(7751)] = 251144,
  [SMALL_STATE(7752)] = 251154,
  [SMALL_STATE(7753)] = 251164,
  [SMALL_STATE(7754)] = 251174,
  [SMALL_STATE(7755)] = 251184,
  [SMALL_STATE(7756)] = 251194,
  [SMALL_STATE(7757)] = 251204,
  [SMALL_STATE(7758)] = 251214,
  [SMALL_STATE(7759)] = 251222,
  [SMALL_STATE(7760)] = 251232,
  [SMALL_STATE(7761)] = 251242,
  [SMALL_STATE(7762)] = 251252,
  [SMALL_STATE(7763)] = 251262,
  [SMALL_STATE(7764)] = 251272,
  [SMALL_STATE(7765)] = 251282,
  [SMALL_STATE(7766)] = 251292,
  [SMALL_STATE(7767)] = 251302,
  [SMALL_STATE(7768)] = 251312,
  [SMALL_STATE(7769)] = 251322,
  [SMALL_STATE(7770)] = 251332,
  [SMALL_STATE(7771)] = 251342,
  [SMALL_STATE(7772)] = 251352,
  [SMALL_STATE(7773)] = 251362,
  [SMALL_STATE(7774)] = 251372,
  [SMALL_STATE(7775)] = 251382,
  [SMALL_STATE(7776)] = 251392,
  [SMALL_STATE(7777)] = 251402,
  [SMALL_STATE(7778)] = 251412,
  [SMALL_STATE(7779)] = 251422,
  [SMALL_STATE(7780)] = 251432,
  [SMALL_STATE(7781)] = 251440,
  [SMALL_STATE(7782)] = 251450,
  [SMALL_STATE(7783)] = 251460,
  [SMALL_STATE(7784)] = 251470,
  [SMALL_STATE(7785)] = 251480,
  [SMALL_STATE(7786)] = 251490,
  [SMALL_STATE(7787)] = 251500,
  [SMALL_STATE(7788)] = 251510,
  [SMALL_STATE(7789)] = 251520,
  [SMALL_STATE(7790)] = 251528,
  [SMALL_STATE(7791)] = 251538,
  [SMALL_STATE(7792)] = 251548,
  [SMALL_STATE(7793)] = 251558,
  [SMALL_STATE(7794)] = 251568,
  [SMALL_STATE(7795)] = 251578,
  [SMALL_STATE(7796)] = 251588,
  [SMALL_STATE(7797)] = 251598,
  [SMALL_STATE(7798)] = 251608,
  [SMALL_STATE(7799)] = 251618,
  [SMALL_STATE(7800)] = 251628,
  [SMALL_STATE(7801)] = 251638,
  [SMALL_STATE(7802)] = 251648,
  [SMALL_STATE(7803)] = 251658,
  [SMALL_STATE(7804)] = 251668,
  [SMALL_STATE(7805)] = 251678,
  [SMALL_STATE(7806)] = 251688,
  [SMALL_STATE(7807)] = 251698,
  [SMALL_STATE(7808)] = 251708,
  [SMALL_STATE(7809)] = 251718,
  [SMALL_STATE(7810)] = 251728,
  [SMALL_STATE(7811)] = 251738,
  [SMALL_STATE(7812)] = 251748,
  [SMALL_STATE(7813)] = 251758,
  [SMALL_STATE(7814)] = 251768,
  [SMALL_STATE(7815)] = 251778,
  [SMALL_STATE(7816)] = 251788,
  [SMALL_STATE(7817)] = 251798,
  [SMALL_STATE(7818)] = 251808,
  [SMALL_STATE(7819)] = 251818,
  [SMALL_STATE(7820)] = 251826,
  [SMALL_STATE(7821)] = 251836,
  [SMALL_STATE(7822)] = 251846,
  [SMALL_STATE(7823)] = 251856,
  [SMALL_STATE(7824)] = 251866,
  [SMALL_STATE(7825)] = 251876,
  [SMALL_STATE(7826)] = 251886,
  [SMALL_STATE(7827)] = 251896,
  [SMALL_STATE(7828)] = 251906,
  [SMALL_STATE(7829)] = 251916,
  [SMALL_STATE(7830)] = 251926,
  [SMALL_STATE(7831)] = 251934,
  [SMALL_STATE(7832)] = 251944,
  [SMALL_STATE(7833)] = 251954,
  [SMALL_STATE(7834)] = 251964,
  [SMALL_STATE(7835)] = 251974,
  [SMALL_STATE(7836)] = 251984,
  [SMALL_STATE(7837)] = 251994,
  [SMALL_STATE(7838)] = 252001,
  [SMALL_STATE(7839)] = 252008,
  [SMALL_STATE(7840)] = 252015,
  [SMALL_STATE(7841)] = 252022,
  [SMALL_STATE(7842)] = 252029,
  [SMALL_STATE(7843)] = 252036,
  [SMALL_STATE(7844)] = 252043,
  [SMALL_STATE(7845)] = 252050,
  [SMALL_STATE(7846)] = 252057,
  [SMALL_STATE(7847)] = 252064,
  [SMALL_STATE(7848)] = 252071,
  [SMALL_STATE(7849)] = 252078,
  [SMALL_STATE(7850)] = 252085,
  [SMALL_STATE(7851)] = 252092,
  [SMALL_STATE(7852)] = 252099,
  [SMALL_STATE(7853)] = 252106,
  [SMALL_STATE(7854)] = 252113,
  [SMALL_STATE(7855)] = 252120,
  [SMALL_STATE(7856)] = 252127,
  [SMALL_STATE(7857)] = 252134,
  [SMALL_STATE(7858)] = 252141,
  [SMALL_STATE(7859)] = 252148,
  [SMALL_STATE(7860)] = 252155,
  [SMALL_STATE(7861)] = 252162,
  [SMALL_STATE(7862)] = 252169,
  [SMALL_STATE(7863)] = 252176,
  [SMALL_STATE(7864)] = 252183,
  [SMALL_STATE(7865)] = 252190,
  [SMALL_STATE(7866)] = 252197,
  [SMALL_STATE(7867)] = 252204,
  [SMALL_STATE(7868)] = 252211,
  [SMALL_STATE(7869)] = 252218,
  [SMALL_STATE(7870)] = 252225,
  [SMALL_STATE(7871)] = 252232,
  [SMALL_STATE(7872)] = 252239,
  [SMALL_STATE(7873)] = 252246,
  [SMALL_STATE(7874)] = 252253,
  [SMALL_STATE(7875)] = 252260,
  [SMALL_STATE(7876)] = 252267,
  [SMALL_STATE(7877)] = 252274,
  [SMALL_STATE(7878)] = 252281,
  [SMALL_STATE(7879)] = 252288,
  [SMALL_STATE(7880)] = 252295,
  [SMALL_STATE(7881)] = 252302,
  [SMALL_STATE(7882)] = 252309,
  [SMALL_STATE(7883)] = 252316,
  [SMALL_STATE(7884)] = 252323,
  [SMALL_STATE(7885)] = 252330,
  [SMALL_STATE(7886)] = 252337,
  [SMALL_STATE(7887)] = 252344,
  [SMALL_STATE(7888)] = 252351,
  [SMALL_STATE(7889)] = 252358,
  [SMALL_STATE(7890)] = 252365,
  [SMALL_STATE(7891)] = 252372,
  [SMALL_STATE(7892)] = 252379,
  [SMALL_STATE(7893)] = 252386,
  [SMALL_STATE(7894)] = 252393,
  [SMALL_STATE(7895)] = 252400,
  [SMALL_STATE(7896)] = 252407,
  [SMALL_STATE(7897)] = 252414,
  [SMALL_STATE(7898)] = 252421,
  [SMALL_STATE(7899)] = 252428,
  [SMALL_STATE(7900)] = 252435,
  [SMALL_STATE(7901)] = 252442,
  [SMALL_STATE(7902)] = 252449,
  [SMALL_STATE(7903)] = 252456,
  [SMALL_STATE(7904)] = 252463,
  [SMALL_STATE(7905)] = 252470,
  [SMALL_STATE(7906)] = 252477,
  [SMALL_STATE(7907)] = 252484,
  [SMALL_STATE(7908)] = 252491,
  [SMALL_STATE(7909)] = 252498,
  [SMALL_STATE(7910)] = 252505,
  [SMALL_STATE(7911)] = 252512,
  [SMALL_STATE(7912)] = 252519,
  [SMALL_STATE(7913)] = 252526,
  [SMALL_STATE(7914)] = 252533,
  [SMALL_STATE(7915)] = 252540,
  [SMALL_STATE(7916)] = 252547,
  [SMALL_STATE(7917)] = 252554,
  [SMALL_STATE(7918)] = 252561,
  [SMALL_STATE(7919)] = 252568,
  [SMALL_STATE(7920)] = 252575,
  [SMALL_STATE(7921)] = 252582,
  [SMALL_STATE(7922)] = 252589,
  [SMALL_STATE(7923)] = 252596,
  [SMALL_STATE(7924)] = 252603,
  [SMALL_STATE(7925)] = 252610,
  [SMALL_STATE(7926)] = 252617,
  [SMALL_STATE(7927)] = 252624,
  [SMALL_STATE(7928)] = 252631,
  [SMALL_STATE(7929)] = 252638,
  [SMALL_STATE(7930)] = 252645,
  [SMALL_STATE(7931)] = 252652,
  [SMALL_STATE(7932)] = 252659,
  [SMALL_STATE(7933)] = 252666,
  [SMALL_STATE(7934)] = 252673,
  [SMALL_STATE(7935)] = 252680,
  [SMALL_STATE(7936)] = 252687,
  [SMALL_STATE(7937)] = 252694,
  [SMALL_STATE(7938)] = 252701,
  [SMALL_STATE(7939)] = 252708,
  [SMALL_STATE(7940)] = 252715,
  [SMALL_STATE(7941)] = 252722,
  [SMALL_STATE(7942)] = 252729,
  [SMALL_STATE(7943)] = 252736,
  [SMALL_STATE(7944)] = 252743,
  [SMALL_STATE(7945)] = 252750,
  [SMALL_STATE(7946)] = 252757,
  [SMALL_STATE(7947)] = 252764,
  [SMALL_STATE(7948)] = 252771,
  [SMALL_STATE(7949)] = 252778,
  [SMALL_STATE(7950)] = 252785,
  [SMALL_STATE(7951)] = 252792,
  [SMALL_STATE(7952)] = 252799,
  [SMALL_STATE(7953)] = 252806,
  [SMALL_STATE(7954)] = 252813,
  [SMALL_STATE(7955)] = 252820,
  [SMALL_STATE(7956)] = 252827,
  [SMALL_STATE(7957)] = 252834,
  [SMALL_STATE(7958)] = 252841,
  [SMALL_STATE(7959)] = 252848,
  [SMALL_STATE(7960)] = 252855,
  [SMALL_STATE(7961)] = 252862,
  [SMALL_STATE(7962)] = 252869,
  [SMALL_STATE(7963)] = 252876,
  [SMALL_STATE(7964)] = 252883,
  [SMALL_STATE(7965)] = 252890,
  [SMALL_STATE(7966)] = 252897,
  [SMALL_STATE(7967)] = 252904,
  [SMALL_STATE(7968)] = 252911,
  [SMALL_STATE(7969)] = 252918,
  [SMALL_STATE(7970)] = 252925,
  [SMALL_STATE(7971)] = 252932,
  [SMALL_STATE(7972)] = 252939,
  [SMALL_STATE(7973)] = 252946,
  [SMALL_STATE(7974)] = 252953,
  [SMALL_STATE(7975)] = 252960,
  [SMALL_STATE(7976)] = 252967,
  [SMALL_STATE(7977)] = 252974,
  [SMALL_STATE(7978)] = 252981,
  [SMALL_STATE(7979)] = 252988,
  [SMALL_STATE(7980)] = 252995,
  [SMALL_STATE(7981)] = 253002,
  [SMALL_STATE(7982)] = 253009,
  [SMALL_STATE(7983)] = 253016,
  [SMALL_STATE(7984)] = 253023,
  [SMALL_STATE(7985)] = 253030,
  [SMALL_STATE(7986)] = 253037,
  [SMALL_STATE(7987)] = 253044,
  [SMALL_STATE(7988)] = 253051,
  [SMALL_STATE(7989)] = 253058,
  [SMALL_STATE(7990)] = 253065,
  [SMALL_STATE(7991)] = 253072,
  [SMALL_STATE(7992)] = 253079,
  [SMALL_STATE(7993)] = 253086,
  [SMALL_STATE(7994)] = 253093,
  [SMALL_STATE(7995)] = 253100,
  [SMALL_STATE(7996)] = 253107,
  [SMALL_STATE(7997)] = 253114,
  [SMALL_STATE(7998)] = 253121,
  [SMALL_STATE(7999)] = 253128,
  [SMALL_STATE(8000)] = 253135,
  [SMALL_STATE(8001)] = 253142,
  [SMALL_STATE(8002)] = 253149,
  [SMALL_STATE(8003)] = 253156,
  [SMALL_STATE(8004)] = 253163,
  [SMALL_STATE(8005)] = 253170,
  [SMALL_STATE(8006)] = 253177,
  [SMALL_STATE(8007)] = 253184,
  [SMALL_STATE(8008)] = 253191,
  [SMALL_STATE(8009)] = 253198,
  [SMALL_STATE(8010)] = 253205,
  [SMALL_STATE(8011)] = 253212,
  [SMALL_STATE(8012)] = 253219,
  [SMALL_STATE(8013)] = 253226,
  [SMALL_STATE(8014)] = 253233,
  [SMALL_STATE(8015)] = 253240,
  [SMALL_STATE(8016)] = 253247,
  [SMALL_STATE(8017)] = 253254,
  [SMALL_STATE(8018)] = 253261,
  [SMALL_STATE(8019)] = 253268,
  [SMALL_STATE(8020)] = 253275,
  [SMALL_STATE(8021)] = 253282,
  [SMALL_STATE(8022)] = 253289,
  [SMALL_STATE(8023)] = 253296,
  [SMALL_STATE(8024)] = 253303,
  [SMALL_STATE(8025)] = 253310,
  [SMALL_STATE(8026)] = 253317,
  [SMALL_STATE(8027)] = 253324,
  [SMALL_STATE(8028)] = 253331,
  [SMALL_STATE(8029)] = 253338,
  [SMALL_STATE(8030)] = 253345,
  [SMALL_STATE(8031)] = 253352,
  [SMALL_STATE(8032)] = 253359,
  [SMALL_STATE(8033)] = 253366,
  [SMALL_STATE(8034)] = 253373,
  [SMALL_STATE(8035)] = 253380,
  [SMALL_STATE(8036)] = 253387,
  [SMALL_STATE(8037)] = 253394,
  [SMALL_STATE(8038)] = 253401,
  [SMALL_STATE(8039)] = 253408,
  [SMALL_STATE(8040)] = 253415,
  [SMALL_STATE(8041)] = 253422,
  [SMALL_STATE(8042)] = 253429,
  [SMALL_STATE(8043)] = 253436,
  [SMALL_STATE(8044)] = 253443,
  [SMALL_STATE(8045)] = 253450,
  [SMALL_STATE(8046)] = 253457,
  [SMALL_STATE(8047)] = 253464,
  [SMALL_STATE(8048)] = 253471,
  [SMALL_STATE(8049)] = 253478,
  [SMALL_STATE(8050)] = 253485,
  [SMALL_STATE(8051)] = 253492,
  [SMALL_STATE(8052)] = 253499,
  [SMALL_STATE(8053)] = 253506,
  [SMALL_STATE(8054)] = 253513,
  [SMALL_STATE(8055)] = 253520,
  [SMALL_STATE(8056)] = 253527,
  [SMALL_STATE(8057)] = 253534,
  [SMALL_STATE(8058)] = 253541,
  [SMALL_STATE(8059)] = 253548,
  [SMALL_STATE(8060)] = 253555,
  [SMALL_STATE(8061)] = 253562,
  [SMALL_STATE(8062)] = 253569,
  [SMALL_STATE(8063)] = 253576,
  [SMALL_STATE(8064)] = 253583,
  [SMALL_STATE(8065)] = 253590,
  [SMALL_STATE(8066)] = 253597,
  [SMALL_STATE(8067)] = 253604,
  [SMALL_STATE(8068)] = 253611,
  [SMALL_STATE(8069)] = 253618,
  [SMALL_STATE(8070)] = 253625,
  [SMALL_STATE(8071)] = 253632,
  [SMALL_STATE(8072)] = 253639,
  [SMALL_STATE(8073)] = 253646,
  [SMALL_STATE(8074)] = 253653,
  [SMALL_STATE(8075)] = 253660,
  [SMALL_STATE(8076)] = 253667,
  [SMALL_STATE(8077)] = 253674,
  [SMALL_STATE(8078)] = 253681,
  [SMALL_STATE(8079)] = 253688,
  [SMALL_STATE(8080)] = 253695,
  [SMALL_STATE(8081)] = 253702,
  [SMALL_STATE(8082)] = 253709,
  [SMALL_STATE(8083)] = 253716,
  [SMALL_STATE(8084)] = 253723,
  [SMALL_STATE(8085)] = 253730,
  [SMALL_STATE(8086)] = 253737,
  [SMALL_STATE(8087)] = 253744,
  [SMALL_STATE(8088)] = 253751,
  [SMALL_STATE(8089)] = 253758,
  [SMALL_STATE(8090)] = 253765,
  [SMALL_STATE(8091)] = 253772,
  [SMALL_STATE(8092)] = 253779,
  [SMALL_STATE(8093)] = 253786,
  [SMALL_STATE(8094)] = 253793,
  [SMALL_STATE(8095)] = 253800,
  [SMALL_STATE(8096)] = 253807,
  [SMALL_STATE(8097)] = 253814,
  [SMALL_STATE(8098)] = 253821,
  [SMALL_STATE(8099)] = 253828,
  [SMALL_STATE(8100)] = 253835,
  [SMALL_STATE(8101)] = 253842,
  [SMALL_STATE(8102)] = 253849,
  [SMALL_STATE(8103)] = 253856,
  [SMALL_STATE(8104)] = 253863,
  [SMALL_STATE(8105)] = 253870,
  [SMALL_STATE(8106)] = 253877,
  [SMALL_STATE(8107)] = 253884,
  [SMALL_STATE(8108)] = 253891,
  [SMALL_STATE(8109)] = 253898,
  [SMALL_STATE(8110)] = 253905,
  [SMALL_STATE(8111)] = 253912,
  [SMALL_STATE(8112)] = 253919,
  [SMALL_STATE(8113)] = 253926,
  [SMALL_STATE(8114)] = 253933,
  [SMALL_STATE(8115)] = 253940,
  [SMALL_STATE(8116)] = 253947,
  [SMALL_STATE(8117)] = 253954,
  [SMALL_STATE(8118)] = 253961,
  [SMALL_STATE(8119)] = 253968,
  [SMALL_STATE(8120)] = 253975,
  [SMALL_STATE(8121)] = 253982,
  [SMALL_STATE(8122)] = 253989,
  [SMALL_STATE(8123)] = 253996,
  [SMALL_STATE(8124)] = 254003,
  [SMALL_STATE(8125)] = 254010,
  [SMALL_STATE(8126)] = 254017,
  [SMALL_STATE(8127)] = 254024,
  [SMALL_STATE(8128)] = 254031,
  [SMALL_STATE(8129)] = 254038,
  [SMALL_STATE(8130)] = 254045,
  [SMALL_STATE(8131)] = 254052,
  [SMALL_STATE(8132)] = 254059,
  [SMALL_STATE(8133)] = 254066,
  [SMALL_STATE(8134)] = 254073,
  [SMALL_STATE(8135)] = 254080,
  [SMALL_STATE(8136)] = 254087,
  [SMALL_STATE(8137)] = 254094,
  [SMALL_STATE(8138)] = 254101,
  [SMALL_STATE(8139)] = 254108,
  [SMALL_STATE(8140)] = 254115,
  [SMALL_STATE(8141)] = 254122,
  [SMALL_STATE(8142)] = 254129,
  [SMALL_STATE(8143)] = 254136,
  [SMALL_STATE(8144)] = 254143,
  [SMALL_STATE(8145)] = 254150,
  [SMALL_STATE(8146)] = 254157,
  [SMALL_STATE(8147)] = 254164,
  [SMALL_STATE(8148)] = 254171,
  [SMALL_STATE(8149)] = 254178,
  [SMALL_STATE(8150)] = 254185,
  [SMALL_STATE(8151)] = 254192,
  [SMALL_STATE(8152)] = 254199,
  [SMALL_STATE(8153)] = 254206,
  [SMALL_STATE(8154)] = 254213,
  [SMALL_STATE(8155)] = 254220,
  [SMALL_STATE(8156)] = 254227,
  [SMALL_STATE(8157)] = 254234,
  [SMALL_STATE(8158)] = 254241,
  [SMALL_STATE(8159)] = 254248,
  [SMALL_STATE(8160)] = 254255,
  [SMALL_STATE(8161)] = 254262,
  [SMALL_STATE(8162)] = 254269,
  [SMALL_STATE(8163)] = 254276,
  [SMALL_STATE(8164)] = 254283,
  [SMALL_STATE(8165)] = 254290,
  [SMALL_STATE(8166)] = 254297,
  [SMALL_STATE(8167)] = 254304,
  [SMALL_STATE(8168)] = 254311,
  [SMALL_STATE(8169)] = 254318,
  [SMALL_STATE(8170)] = 254325,
  [SMALL_STATE(8171)] = 254332,
  [SMALL_STATE(8172)] = 254339,
  [SMALL_STATE(8173)] = 254346,
  [SMALL_STATE(8174)] = 254353,
  [SMALL_STATE(8175)] = 254360,
  [SMALL_STATE(8176)] = 254367,
  [SMALL_STATE(8177)] = 254374,
  [SMALL_STATE(8178)] = 254381,
  [SMALL_STATE(8179)] = 254388,
  [SMALL_STATE(8180)] = 254395,
  [SMALL_STATE(8181)] = 254402,
  [SMALL_STATE(8182)] = 254409,
  [SMALL_STATE(8183)] = 254416,
  [SMALL_STATE(8184)] = 254423,
  [SMALL_STATE(8185)] = 254430,
  [SMALL_STATE(8186)] = 254437,
  [SMALL_STATE(8187)] = 254444,
  [SMALL_STATE(8188)] = 254451,
  [SMALL_STATE(8189)] = 254458,
  [SMALL_STATE(8190)] = 254465,
  [SMALL_STATE(8191)] = 254472,
  [SMALL_STATE(8192)] = 254479,
  [SMALL_STATE(8193)] = 254486,
  [SMALL_STATE(8194)] = 254493,
  [SMALL_STATE(8195)] = 254500,
  [SMALL_STATE(8196)] = 254507,
  [SMALL_STATE(8197)] = 254514,
  [SMALL_STATE(8198)] = 254521,
  [SMALL_STATE(8199)] = 254528,
  [SMALL_STATE(8200)] = 254535,
  [SMALL_STATE(8201)] = 254542,
  [SMALL_STATE(8202)] = 254549,
  [SMALL_STATE(8203)] = 254556,
  [SMALL_STATE(8204)] = 254563,
  [SMALL_STATE(8205)] = 254570,
  [SMALL_STATE(8206)] = 254577,
  [SMALL_STATE(8207)] = 254584,
  [SMALL_STATE(8208)] = 254591,
  [SMALL_STATE(8209)] = 254598,
  [SMALL_STATE(8210)] = 254605,
  [SMALL_STATE(8211)] = 254612,
  [SMALL_STATE(8212)] = 254619,
  [SMALL_STATE(8213)] = 254626,
  [SMALL_STATE(8214)] = 254633,
  [SMALL_STATE(8215)] = 254640,
  [SMALL_STATE(8216)] = 254647,
  [SMALL_STATE(8217)] = 254654,
  [SMALL_STATE(8218)] = 254661,
  [SMALL_STATE(8219)] = 254668,
  [SMALL_STATE(8220)] = 254675,
  [SMALL_STATE(8221)] = 254682,
  [SMALL_STATE(8222)] = 254689,
  [SMALL_STATE(8223)] = 254696,
  [SMALL_STATE(8224)] = 254703,
  [SMALL_STATE(8225)] = 254710,
  [SMALL_STATE(8226)] = 254717,
  [SMALL_STATE(8227)] = 254724,
  [SMALL_STATE(8228)] = 254731,
  [SMALL_STATE(8229)] = 254738,
  [SMALL_STATE(8230)] = 254745,
  [SMALL_STATE(8231)] = 254752,
  [SMALL_STATE(8232)] = 254759,
  [SMALL_STATE(8233)] = 254766,
  [SMALL_STATE(8234)] = 254773,
  [SMALL_STATE(8235)] = 254780,
  [SMALL_STATE(8236)] = 254787,
  [SMALL_STATE(8237)] = 254794,
  [SMALL_STATE(8238)] = 254801,
  [SMALL_STATE(8239)] = 254808,
  [SMALL_STATE(8240)] = 254815,
  [SMALL_STATE(8241)] = 254822,
  [SMALL_STATE(8242)] = 254829,
  [SMALL_STATE(8243)] = 254836,
  [SMALL_STATE(8244)] = 254843,
  [SMALL_STATE(8245)] = 254850,
  [SMALL_STATE(8246)] = 254857,
  [SMALL_STATE(8247)] = 254864,
  [SMALL_STATE(8248)] = 254871,
  [SMALL_STATE(8249)] = 254878,
  [SMALL_STATE(8250)] = 254885,
  [SMALL_STATE(8251)] = 254892,
  [SMALL_STATE(8252)] = 254899,
  [SMALL_STATE(8253)] = 254906,
  [SMALL_STATE(8254)] = 254913,
  [SMALL_STATE(8255)] = 254920,
  [SMALL_STATE(8256)] = 254927,
  [SMALL_STATE(8257)] = 254934,
  [SMALL_STATE(8258)] = 254941,
  [SMALL_STATE(8259)] = 254948,
  [SMALL_STATE(8260)] = 254955,
  [SMALL_STATE(8261)] = 254962,
  [SMALL_STATE(8262)] = 254969,
  [SMALL_STATE(8263)] = 254976,
  [SMALL_STATE(8264)] = 254983,
  [SMALL_STATE(8265)] = 254990,
  [SMALL_STATE(8266)] = 254997,
  [SMALL_STATE(8267)] = 255004,
  [SMALL_STATE(8268)] = 255011,
  [SMALL_STATE(8269)] = 255018,
  [SMALL_STATE(8270)] = 255025,
  [SMALL_STATE(8271)] = 255032,
  [SMALL_STATE(8272)] = 255039,
  [SMALL_STATE(8273)] = 255046,
  [SMALL_STATE(8274)] = 255053,
  [SMALL_STATE(8275)] = 255060,
  [SMALL_STATE(8276)] = 255067,
  [SMALL_STATE(8277)] = 255074,
  [SMALL_STATE(8278)] = 255081,
  [SMALL_STATE(8279)] = 255088,
  [SMALL_STATE(8280)] = 255095,
  [SMALL_STATE(8281)] = 255102,
  [SMALL_STATE(8282)] = 255109,
  [SMALL_STATE(8283)] = 255116,
  [SMALL_STATE(8284)] = 255123,
  [SMALL_STATE(8285)] = 255130,
  [SMALL_STATE(8286)] = 255137,
  [SMALL_STATE(8287)] = 255144,
  [SMALL_STATE(8288)] = 255151,
  [SMALL_STATE(8289)] = 255158,
  [SMALL_STATE(8290)] = 255165,
  [SMALL_STATE(8291)] = 255172,
  [SMALL_STATE(8292)] = 255179,
  [SMALL_STATE(8293)] = 255186,
  [SMALL_STATE(8294)] = 255193,
  [SMALL_STATE(8295)] = 255200,
  [SMALL_STATE(8296)] = 255207,
  [SMALL_STATE(8297)] = 255214,
  [SMALL_STATE(8298)] = 255221,
  [SMALL_STATE(8299)] = 255228,
  [SMALL_STATE(8300)] = 255235,
  [SMALL_STATE(8301)] = 255242,
  [SMALL_STATE(8302)] = 255249,
  [SMALL_STATE(8303)] = 255256,
  [SMALL_STATE(8304)] = 255263,
  [SMALL_STATE(8305)] = 255270,
  [SMALL_STATE(8306)] = 255277,
  [SMALL_STATE(8307)] = 255284,
  [SMALL_STATE(8308)] = 255291,
  [SMALL_STATE(8309)] = 255298,
  [SMALL_STATE(8310)] = 255305,
  [SMALL_STATE(8311)] = 255312,
  [SMALL_STATE(8312)] = 255319,
  [SMALL_STATE(8313)] = 255326,
  [SMALL_STATE(8314)] = 255333,
  [SMALL_STATE(8315)] = 255340,
  [SMALL_STATE(8316)] = 255347,
  [SMALL_STATE(8317)] = 255354,
  [SMALL_STATE(8318)] = 255361,
  [SMALL_STATE(8319)] = 255368,
  [SMALL_STATE(8320)] = 255375,
  [SMALL_STATE(8321)] = 255382,
  [SMALL_STATE(8322)] = 255389,
  [SMALL_STATE(8323)] = 255396,
  [SMALL_STATE(8324)] = 255403,
  [SMALL_STATE(8325)] = 255410,
  [SMALL_STATE(8326)] = 255417,
  [SMALL_STATE(8327)] = 255424,
  [SMALL_STATE(8328)] = 255431,
  [SMALL_STATE(8329)] = 255438,
  [SMALL_STATE(8330)] = 255445,
  [SMALL_STATE(8331)] = 255452,
  [SMALL_STATE(8332)] = 255459,
  [SMALL_STATE(8333)] = 255466,
  [SMALL_STATE(8334)] = 255473,
  [SMALL_STATE(8335)] = 255480,
  [SMALL_STATE(8336)] = 255487,
  [SMALL_STATE(8337)] = 255494,
  [SMALL_STATE(8338)] = 255501,
  [SMALL_STATE(8339)] = 255508,
  [SMALL_STATE(8340)] = 255515,
  [SMALL_STATE(8341)] = 255522,
  [SMALL_STATE(8342)] = 255529,
  [SMALL_STATE(8343)] = 255536,
  [SMALL_STATE(8344)] = 255543,
  [SMALL_STATE(8345)] = 255550,
  [SMALL_STATE(8346)] = 255557,
  [SMALL_STATE(8347)] = 255564,
  [SMALL_STATE(8348)] = 255571,
  [SMALL_STATE(8349)] = 255578,
  [SMALL_STATE(8350)] = 255585,
  [SMALL_STATE(8351)] = 255592,
  [SMALL_STATE(8352)] = 255599,
  [SMALL_STATE(8353)] = 255606,
  [SMALL_STATE(8354)] = 255613,
  [SMALL_STATE(8355)] = 255620,
  [SMALL_STATE(8356)] = 255627,
  [SMALL_STATE(8357)] = 255634,
  [SMALL_STATE(8358)] = 255641,
  [SMALL_STATE(8359)] = 255648,
  [SMALL_STATE(8360)] = 255655,
  [SMALL_STATE(8361)] = 255662,
  [SMALL_STATE(8362)] = 255669,
  [SMALL_STATE(8363)] = 255676,
  [SMALL_STATE(8364)] = 255683,
  [SMALL_STATE(8365)] = 255690,
  [SMALL_STATE(8366)] = 255697,
  [SMALL_STATE(8367)] = 255704,
  [SMALL_STATE(8368)] = 255711,
  [SMALL_STATE(8369)] = 255718,
  [SMALL_STATE(8370)] = 255725,
  [SMALL_STATE(8371)] = 255732,
  [SMALL_STATE(8372)] = 255739,
  [SMALL_STATE(8373)] = 255746,
  [SMALL_STATE(8374)] = 255753,
  [SMALL_STATE(8375)] = 255760,
  [SMALL_STATE(8376)] = 255767,
  [SMALL_STATE(8377)] = 255774,
  [SMALL_STATE(8378)] = 255781,
  [SMALL_STATE(8379)] = 255788,
  [SMALL_STATE(8380)] = 255795,
  [SMALL_STATE(8381)] = 255802,
  [SMALL_STATE(8382)] = 255809,
  [SMALL_STATE(8383)] = 255816,
  [SMALL_STATE(8384)] = 255823,
  [SMALL_STATE(8385)] = 255830,
  [SMALL_STATE(8386)] = 255837,
  [SMALL_STATE(8387)] = 255844,
  [SMALL_STATE(8388)] = 255851,
  [SMALL_STATE(8389)] = 255858,
  [SMALL_STATE(8390)] = 255865,
  [SMALL_STATE(8391)] = 255872,
  [SMALL_STATE(8392)] = 255879,
  [SMALL_STATE(8393)] = 255886,
  [SMALL_STATE(8394)] = 255893,
  [SMALL_STATE(8395)] = 255900,
  [SMALL_STATE(8396)] = 255907,
  [SMALL_STATE(8397)] = 255914,
  [SMALL_STATE(8398)] = 255921,
  [SMALL_STATE(8399)] = 255928,
  [SMALL_STATE(8400)] = 255935,
  [SMALL_STATE(8401)] = 255942,
  [SMALL_STATE(8402)] = 255949,
  [SMALL_STATE(8403)] = 255956,
  [SMALL_STATE(8404)] = 255963,
  [SMALL_STATE(8405)] = 255970,
  [SMALL_STATE(8406)] = 255977,
  [SMALL_STATE(8407)] = 255984,
  [SMALL_STATE(8408)] = 255991,
  [SMALL_STATE(8409)] = 255998,
  [SMALL_STATE(8410)] = 256005,
  [SMALL_STATE(8411)] = 256012,
  [SMALL_STATE(8412)] = 256019,
  [SMALL_STATE(8413)] = 256026,
  [SMALL_STATE(8414)] = 256033,
  [SMALL_STATE(8415)] = 256040,
  [SMALL_STATE(8416)] = 256047,
  [SMALL_STATE(8417)] = 256054,
  [SMALL_STATE(8418)] = 256061,
  [SMALL_STATE(8419)] = 256068,
  [SMALL_STATE(8420)] = 256075,
  [SMALL_STATE(8421)] = 256082,
  [SMALL_STATE(8422)] = 256089,
  [SMALL_STATE(8423)] = 256096,
  [SMALL_STATE(8424)] = 256103,
  [SMALL_STATE(8425)] = 256110,
  [SMALL_STATE(8426)] = 256117,
  [SMALL_STATE(8427)] = 256124,
  [SMALL_STATE(8428)] = 256131,
  [SMALL_STATE(8429)] = 256138,
  [SMALL_STATE(8430)] = 256145,
  [SMALL_STATE(8431)] = 256152,
  [SMALL_STATE(8432)] = 256159,
  [SMALL_STATE(8433)] = 256166,
  [SMALL_STATE(8434)] = 256173,
  [SMALL_STATE(8435)] = 256180,
  [SMALL_STATE(8436)] = 256187,
  [SMALL_STATE(8437)] = 256194,
  [SMALL_STATE(8438)] = 256201,
  [SMALL_STATE(8439)] = 256208,
  [SMALL_STATE(8440)] = 256215,
  [SMALL_STATE(8441)] = 256222,
  [SMALL_STATE(8442)] = 256229,
  [SMALL_STATE(8443)] = 256236,
  [SMALL_STATE(8444)] = 256243,
  [SMALL_STATE(8445)] = 256250,
  [SMALL_STATE(8446)] = 256257,
  [SMALL_STATE(8447)] = 256264,
  [SMALL_STATE(8448)] = 256271,
  [SMALL_STATE(8449)] = 256278,
  [SMALL_STATE(8450)] = 256285,
  [SMALL_STATE(8451)] = 256292,
  [SMALL_STATE(8452)] = 256299,
  [SMALL_STATE(8453)] = 256306,
  [SMALL_STATE(8454)] = 256313,
  [SMALL_STATE(8455)] = 256320,
  [SMALL_STATE(8456)] = 256327,
  [SMALL_STATE(8457)] = 256334,
  [SMALL_STATE(8458)] = 256341,
  [SMALL_STATE(8459)] = 256348,
  [SMALL_STATE(8460)] = 256355,
  [SMALL_STATE(8461)] = 256362,
  [SMALL_STATE(8462)] = 256369,
  [SMALL_STATE(8463)] = 256376,
  [SMALL_STATE(8464)] = 256383,
  [SMALL_STATE(8465)] = 256390,
  [SMALL_STATE(8466)] = 256397,
  [SMALL_STATE(8467)] = 256404,
  [SMALL_STATE(8468)] = 256411,
  [SMALL_STATE(8469)] = 256418,
  [SMALL_STATE(8470)] = 256425,
  [SMALL_STATE(8471)] = 256432,
  [SMALL_STATE(8472)] = 256439,
  [SMALL_STATE(8473)] = 256446,
  [SMALL_STATE(8474)] = 256453,
  [SMALL_STATE(8475)] = 256460,
  [SMALL_STATE(8476)] = 256467,
  [SMALL_STATE(8477)] = 256474,
  [SMALL_STATE(8478)] = 256481,
  [SMALL_STATE(8479)] = 256488,
  [SMALL_STATE(8480)] = 256495,
  [SMALL_STATE(8481)] = 256502,
  [SMALL_STATE(8482)] = 256509,
  [SMALL_STATE(8483)] = 256516,
  [SMALL_STATE(8484)] = 256523,
  [SMALL_STATE(8485)] = 256530,
  [SMALL_STATE(8486)] = 256537,
  [SMALL_STATE(8487)] = 256544,
  [SMALL_STATE(8488)] = 256551,
  [SMALL_STATE(8489)] = 256558,
  [SMALL_STATE(8490)] = 256565,
  [SMALL_STATE(8491)] = 256572,
  [SMALL_STATE(8492)] = 256579,
  [SMALL_STATE(8493)] = 256586,
  [SMALL_STATE(8494)] = 256593,
  [SMALL_STATE(8495)] = 256600,
  [SMALL_STATE(8496)] = 256607,
  [SMALL_STATE(8497)] = 256614,
  [SMALL_STATE(8498)] = 256621,
  [SMALL_STATE(8499)] = 256628,
  [SMALL_STATE(8500)] = 256635,
  [SMALL_STATE(8501)] = 256642,
  [SMALL_STATE(8502)] = 256649,
  [SMALL_STATE(8503)] = 256656,
  [SMALL_STATE(8504)] = 256663,
  [SMALL_STATE(8505)] = 256670,
  [SMALL_STATE(8506)] = 256677,
  [SMALL_STATE(8507)] = 256684,
  [SMALL_STATE(8508)] = 256691,
  [SMALL_STATE(8509)] = 256698,
  [SMALL_STATE(8510)] = 256705,
  [SMALL_STATE(8511)] = 256712,
  [SMALL_STATE(8512)] = 256719,
  [SMALL_STATE(8513)] = 256726,
  [SMALL_STATE(8514)] = 256733,
  [SMALL_STATE(8515)] = 256740,
  [SMALL_STATE(8516)] = 256747,
  [SMALL_STATE(8517)] = 256754,
  [SMALL_STATE(8518)] = 256761,
  [SMALL_STATE(8519)] = 256768,
  [SMALL_STATE(8520)] = 256775,
  [SMALL_STATE(8521)] = 256782,
  [SMALL_STATE(8522)] = 256789,
  [SMALL_STATE(8523)] = 256796,
  [SMALL_STATE(8524)] = 256803,
  [SMALL_STATE(8525)] = 256810,
  [SMALL_STATE(8526)] = 256817,
  [SMALL_STATE(8527)] = 256824,
  [SMALL_STATE(8528)] = 256831,
  [SMALL_STATE(8529)] = 256838,
  [SMALL_STATE(8530)] = 256845,
  [SMALL_STATE(8531)] = 256852,
  [SMALL_STATE(8532)] = 256859,
  [SMALL_STATE(8533)] = 256866,
  [SMALL_STATE(8534)] = 256873,
  [SMALL_STATE(8535)] = 256880,
  [SMALL_STATE(8536)] = 256887,
  [SMALL_STATE(8537)] = 256894,
  [SMALL_STATE(8538)] = 256901,
  [SMALL_STATE(8539)] = 256908,
  [SMALL_STATE(8540)] = 256915,
  [SMALL_STATE(8541)] = 256922,
  [SMALL_STATE(8542)] = 256929,
  [SMALL_STATE(8543)] = 256936,
  [SMALL_STATE(8544)] = 256943,
  [SMALL_STATE(8545)] = 256950,
  [SMALL_STATE(8546)] = 256957,
  [SMALL_STATE(8547)] = 256964,
  [SMALL_STATE(8548)] = 256971,
  [SMALL_STATE(8549)] = 256978,
  [SMALL_STATE(8550)] = 256985,
  [SMALL_STATE(8551)] = 256992,
  [SMALL_STATE(8552)] = 256999,
  [SMALL_STATE(8553)] = 257006,
  [SMALL_STATE(8554)] = 257013,
  [SMALL_STATE(8555)] = 257020,
  [SMALL_STATE(8556)] = 257027,
  [SMALL_STATE(8557)] = 257034,
  [SMALL_STATE(8558)] = 257041,
  [SMALL_STATE(8559)] = 257048,
  [SMALL_STATE(8560)] = 257055,
  [SMALL_STATE(8561)] = 257062,
  [SMALL_STATE(8562)] = 257069,
  [SMALL_STATE(8563)] = 257076,
  [SMALL_STATE(8564)] = 257083,
  [SMALL_STATE(8565)] = 257090,
  [SMALL_STATE(8566)] = 257097,
  [SMALL_STATE(8567)] = 257104,
  [SMALL_STATE(8568)] = 257111,
  [SMALL_STATE(8569)] = 257118,
  [SMALL_STATE(8570)] = 257125,
  [SMALL_STATE(8571)] = 257132,
  [SMALL_STATE(8572)] = 257139,
  [SMALL_STATE(8573)] = 257146,
  [SMALL_STATE(8574)] = 257153,
  [SMALL_STATE(8575)] = 257160,
  [SMALL_STATE(8576)] = 257167,
  [SMALL_STATE(8577)] = 257174,
  [SMALL_STATE(8578)] = 257181,
  [SMALL_STATE(8579)] = 257188,
  [SMALL_STATE(8580)] = 257195,
  [SMALL_STATE(8581)] = 257202,
  [SMALL_STATE(8582)] = 257209,
  [SMALL_STATE(8583)] = 257216,
  [SMALL_STATE(8584)] = 257223,
  [SMALL_STATE(8585)] = 257230,
  [SMALL_STATE(8586)] = 257237,
  [SMALL_STATE(8587)] = 257244,
  [SMALL_STATE(8588)] = 257251,
  [SMALL_STATE(8589)] = 257258,
  [SMALL_STATE(8590)] = 257265,
  [SMALL_STATE(8591)] = 257272,
  [SMALL_STATE(8592)] = 257279,
  [SMALL_STATE(8593)] = 257286,
  [SMALL_STATE(8594)] = 257293,
  [SMALL_STATE(8595)] = 257300,
  [SMALL_STATE(8596)] = 257307,
  [SMALL_STATE(8597)] = 257314,
  [SMALL_STATE(8598)] = 257321,
  [SMALL_STATE(8599)] = 257328,
  [SMALL_STATE(8600)] = 257335,
  [SMALL_STATE(8601)] = 257342,
  [SMALL_STATE(8602)] = 257349,
  [SMALL_STATE(8603)] = 257356,
  [SMALL_STATE(8604)] = 257363,
  [SMALL_STATE(8605)] = 257370,
  [SMALL_STATE(8606)] = 257377,
  [SMALL_STATE(8607)] = 257384,
  [SMALL_STATE(8608)] = 257391,
  [SMALL_STATE(8609)] = 257398,
  [SMALL_STATE(8610)] = 257405,
  [SMALL_STATE(8611)] = 257412,
  [SMALL_STATE(8612)] = 257419,
  [SMALL_STATE(8613)] = 257426,
  [SMALL_STATE(8614)] = 257433,
  [SMALL_STATE(8615)] = 257440,
  [SMALL_STATE(8616)] = 257447,
  [SMALL_STATE(8617)] = 257454,
  [SMALL_STATE(8618)] = 257461,
  [SMALL_STATE(8619)] = 257468,
  [SMALL_STATE(8620)] = 257475,
  [SMALL_STATE(8621)] = 257482,
  [SMALL_STATE(8622)] = 257489,
  [SMALL_STATE(8623)] = 257496,
  [SMALL_STATE(8624)] = 257503,
  [SMALL_STATE(8625)] = 257510,
  [SMALL_STATE(8626)] = 257517,
  [SMALL_STATE(8627)] = 257524,
  [SMALL_STATE(8628)] = 257531,
  [SMALL_STATE(8629)] = 257538,
  [SMALL_STATE(8630)] = 257545,
  [SMALL_STATE(8631)] = 257552,
  [SMALL_STATE(8632)] = 257559,
  [SMALL_STATE(8633)] = 257566,
  [SMALL_STATE(8634)] = 257573,
  [SMALL_STATE(8635)] = 257580,
  [SMALL_STATE(8636)] = 257587,
  [SMALL_STATE(8637)] = 257594,
  [SMALL_STATE(8638)] = 257601,
  [SMALL_STATE(8639)] = 257608,
  [SMALL_STATE(8640)] = 257615,
  [SMALL_STATE(8641)] = 257622,
  [SMALL_STATE(8642)] = 257629,
  [SMALL_STATE(8643)] = 257636,
  [SMALL_STATE(8644)] = 257643,
  [SMALL_STATE(8645)] = 257650,
  [SMALL_STATE(8646)] = 257657,
  [SMALL_STATE(8647)] = 257664,
  [SMALL_STATE(8648)] = 257671,
  [SMALL_STATE(8649)] = 257678,
  [SMALL_STATE(8650)] = 257685,
  [SMALL_STATE(8651)] = 257692,
  [SMALL_STATE(8652)] = 257699,
  [SMALL_STATE(8653)] = 257706,
  [SMALL_STATE(8654)] = 257713,
  [SMALL_STATE(8655)] = 257720,
  [SMALL_STATE(8656)] = 257727,
  [SMALL_STATE(8657)] = 257734,
  [SMALL_STATE(8658)] = 257741,
  [SMALL_STATE(8659)] = 257748,
  [SMALL_STATE(8660)] = 257755,
  [SMALL_STATE(8661)] = 257762,
  [SMALL_STATE(8662)] = 257769,
  [SMALL_STATE(8663)] = 257776,
  [SMALL_STATE(8664)] = 257783,
  [SMALL_STATE(8665)] = 257790,
  [SMALL_STATE(8666)] = 257797,
  [SMALL_STATE(8667)] = 257804,
  [SMALL_STATE(8668)] = 257811,
  [SMALL_STATE(8669)] = 257818,
  [SMALL_STATE(8670)] = 257825,
  [SMALL_STATE(8671)] = 257832,
  [SMALL_STATE(8672)] = 257839,
  [SMALL_STATE(8673)] = 257846,
  [SMALL_STATE(8674)] = 257853,
  [SMALL_STATE(8675)] = 257860,
  [SMALL_STATE(8676)] = 257867,
  [SMALL_STATE(8677)] = 257874,
  [SMALL_STATE(8678)] = 257881,
  [SMALL_STATE(8679)] = 257888,
  [SMALL_STATE(8680)] = 257895,
  [SMALL_STATE(8681)] = 257902,
  [SMALL_STATE(8682)] = 257909,
  [SMALL_STATE(8683)] = 257916,
  [SMALL_STATE(8684)] = 257923,
  [SMALL_STATE(8685)] = 257930,
  [SMALL_STATE(8686)] = 257937,
  [SMALL_STATE(8687)] = 257944,
  [SMALL_STATE(8688)] = 257951,
  [SMALL_STATE(8689)] = 257958,
  [SMALL_STATE(8690)] = 257965,
  [SMALL_STATE(8691)] = 257972,
  [SMALL_STATE(8692)] = 257979,
  [SMALL_STATE(8693)] = 257986,
  [SMALL_STATE(8694)] = 257993,
  [SMALL_STATE(8695)] = 258000,
  [SMALL_STATE(8696)] = 258007,
  [SMALL_STATE(8697)] = 258014,
  [SMALL_STATE(8698)] = 258021,
  [SMALL_STATE(8699)] = 258028,
  [SMALL_STATE(8700)] = 258035,
  [SMALL_STATE(8701)] = 258042,
  [SMALL_STATE(8702)] = 258049,
  [SMALL_STATE(8703)] = 258056,
  [SMALL_STATE(8704)] = 258063,
  [SMALL_STATE(8705)] = 258070,
  [SMALL_STATE(8706)] = 258077,
  [SMALL_STATE(8707)] = 258084,
  [SMALL_STATE(8708)] = 258091,
  [SMALL_STATE(8709)] = 258098,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_translation_unit, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1023),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6466),
  [11] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8704),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5582),
  [15] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8702),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7442),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1743),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1770),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1743),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(987),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5231),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1135),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2348),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3868),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2369),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2266),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8655),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6429),
  [45] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7479),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8644),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7480),
  [51] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2418),
  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [55] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2230),
  [57] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1282),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2364),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2354),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1957),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8637),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2227),
  [69] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6026),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5126),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5204),
  [75] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5208),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7025),
  [79] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7490),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1530),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8618),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7494),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(842),
  [89] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8616),
  [91] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1216),
  [93] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8612),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8611),
  [97] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8606),
  [99] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1480),
  [101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1453),
  [103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8605),
  [105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8602),
  [107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8601),
  [109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6625),
  [111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4791),
  [113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7073),
  [115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6969),
  [117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4846),
  [119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4025),
  [121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2298),
  [123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8595),
  [125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2752),
  [127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5108),
  [129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1111),
  [131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(893),
  [133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7499),
  [135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1548),
  [137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1426),
  [139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6502),
  [141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6371),
  [143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8589),
  [145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8588),
  [147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1414),
  [149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1565),
  [151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7501),
  [153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1569),
  [155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5038),
  [157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5362),
  [159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2373),
  [161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(968),
  [163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6450),
  [165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8679),
  [167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7893),
  [169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5553),
  [171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8682),
  [173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7489),
  [175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(487),
  [177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2340),
  [179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3856),
  [181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2255),
  [183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1821),
  [187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1277),
  [189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2338),
  [191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7076),
  [193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7451),
  [195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1806),
  [197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8598),
  [199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7498),
  [201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(859),
  [203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8177),
  [205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1215),
  [207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8596),
  [209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8594),
  [211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8688),
  [213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7543),
  [215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8443),
  [217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7891),
  [219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4240),
  [221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4019),
  [223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1109),
  [225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7443),
  [227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1384),
  [229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6490),
  [231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6243),
  [233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8524),
  [235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8525),
  [237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1382),
  [239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1807),
  [241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8439),
  [243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5653),
  [245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1982),
  [249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(705),
  [251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1827),
  [253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(494),
  [255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1980),
  [259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1981),
  [261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(544),
  [263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1983),
  [265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(995),
  [267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6440),
  [269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7962),
  [271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5566),
  [273] = {.entry = {.count = 1, .reusable = false}}, SHIFT(680),
  [275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7961),
  [277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(48),
  [279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5588),
  [281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8060),
  [283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7588),
  [285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2346),
  [289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3954),
  [291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2261),
  [293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2353),
  [297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7416),
  [299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7770),
  [301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1672),
  [303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8046),
  [305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7450),
  [307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(854),
  [309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8523),
  [311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1205),
  [313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8271),
  [315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8270),
  [317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7947),
  [319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7792),
  [321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8200),
  [323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1108),
  [325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7776),
  [327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1460),
  [329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6453),
  [331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6353),
  [333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8608),
  [335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8609),
  [337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1459),
  [339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1586),
  [341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8249),
  [343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5662),
  [345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(721),
  [347] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_elifdef, 2, 0, 10),
  [349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(288),
  [351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(776),
  [353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(604),
  [355] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_elif, 4, 0, 78),
  [357] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_elifdef, 3, 0, 10),
  [359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(282),
  [361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(345),
  [363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(764),
  [365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(232),
  [367] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_elif, 3, 0, 78),
  [369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(678),
  [371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(623),
  [373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(787),
  [375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(628),
  [377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(664),
  [379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(661),
  [381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(579),
  [383] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(995),
  [386] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(6440),
  [389] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7962),
  [392] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(5566),
  [395] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0),
  [397] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7961),
  [400] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7588),
  [403] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(181),
  [406] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1743),
  [409] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1770),
  [412] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1743),
  [415] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(987),
  [418] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(5231),
  [421] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1135),
  [424] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(231),
  [427] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2346),
  [430] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(3954),
  [433] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2369),
  [436] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2261),
  [439] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8655),
  [442] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(6429),
  [445] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7479),
  [448] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8644),
  [451] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7480),
  [454] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2418),
  [457] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(52),
  [460] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2230),
  [463] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1282),
  [466] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2364),
  [469] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2353),
  [472] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1957),
  [475] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8637),
  [478] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2227),
  [481] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(6026),
  [484] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(5126),
  [487] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(5204),
  [490] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(5208),
  [493] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7416),
  [496] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7770),
  [499] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1672),
  [502] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8046),
  [505] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7450),
  [508] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(854),
  [511] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8523),
  [514] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1205),
  [517] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8271),
  [520] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8270),
  [523] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7947),
  [526] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7792),
  [529] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8200),
  [532] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1480),
  [535] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1453),
  [538] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8605),
  [541] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8602),
  [544] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8601),
  [547] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(6625),
  [550] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(4240),
  [553] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7073),
  [556] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(6969),
  [559] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(4019),
  [562] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(4025),
  [565] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2298),
  [568] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8595),
  [571] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2752),
  [574] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(5108),
  [577] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1108),
  [580] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(893),
  [583] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7776),
  [586] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1548),
  [589] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1460),
  [592] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(6453),
  [595] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(6353),
  [598] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8608),
  [601] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8609),
  [604] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1459),
  [607] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1586),
  [610] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7501),
  [613] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1569),
  [616] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(5038),
  [619] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(5362),
  [622] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8249),
  [625] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2373),
  [628] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(5662),
  [631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(986),
  [633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3560),
  [637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5782),
  [639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1986),
  [641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2831),
  [645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1992),
  [647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(997),
  [649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2843),
  [651] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(986),
  [654] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(6450),
  [657] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8679),
  [660] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(5553),
  [663] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8682),
  [666] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7489),
  [669] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(487),
  [672] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2340),
  [675] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(3856),
  [678] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2255),
  [681] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(65),
  [684] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0),
  [686] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2338),
  [689] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7076),
  [692] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7451),
  [695] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1806),
  [698] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8598),
  [701] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7498),
  [704] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(859),
  [707] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8177),
  [710] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1215),
  [713] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8596),
  [716] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8594),
  [719] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8688),
  [722] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7543),
  [725] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8443),
  [728] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1109),
  [731] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7443),
  [734] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1384),
  [737] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(6490),
  [740] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(6243),
  [743] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8524),
  [746] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8525),
  [749] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1382),
  [752] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1807),
  [755] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8439),
  [758] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(5653),
  [761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(993),
  [765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3504),
  [767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(989),
  [773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6494),
  [775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7969),
  [777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5595),
  [779] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_else, 1, 0, 0),
  [781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7889),
  [783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7815),
  [785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2349),
  [789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3904),
  [791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2260),
  [793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2339),
  [797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7274),
  [799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7813),
  [801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1752),
  [803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7877),
  [805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7772),
  [807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(884),
  [809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8607),
  [811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1209),
  [813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8044),
  [815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8043),
  [817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7898),
  [819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7806),
  [821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8017),
  [823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1110),
  [825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7811),
  [827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1450),
  [829] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6499),
  [831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6249),
  [833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8630),
  [835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8621),
  [837] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1465),
  [839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1673),
  [841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8016),
  [843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5724),
  [845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1991),
  [847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1985),
  [849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5775),
  [851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3524),
  [855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(749),
  [857] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(989),
  [860] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(6494),
  [863] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7969),
  [866] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(5595),
  [869] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7889),
  [872] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7815),
  [875] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(510),
  [878] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2349),
  [881] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(3904),
  [884] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2260),
  [887] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(43),
  [890] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(2339),
  [893] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7274),
  [896] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7813),
  [899] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1752),
  [902] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7877),
  [905] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7772),
  [908] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(884),
  [911] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8607),
  [914] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1209),
  [917] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8044),
  [920] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8043),
  [923] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7898),
  [926] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7806),
  [929] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8017),
  [932] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1110),
  [935] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(7811),
  [938] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1450),
  [941] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(6499),
  [944] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(6249),
  [947] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8630),
  [950] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8621),
  [953] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1465),
  [956] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(1673),
  [959] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(8016),
  [962] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_repeat1, 2, 0, 0), SHIFT_REPEAT(5724),
  [965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1836),
  [967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1835),
  [969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4273),
  [973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(656),
  [975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(807),
  [977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4282),
  [979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5735),
  [981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5740),
  [983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(644),
  [987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3834),
  [989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3957),
  [993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3753),
  [997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3746),
  [999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(695),
  [1001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2214),
  [1003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [1005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2207),
  [1007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3512),
  [1009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(598),
  [1011] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_else, 2, 0, 0),
  [1013] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_translation_unit, 1, 0, 0),
  [1015] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0),
  [1017] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1023),
  [1020] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(6466),
  [1023] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8704),
  [1026] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(5582),
  [1029] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8702),
  [1032] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(7442),
  [1035] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(181),
  [1038] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1743),
  [1041] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1770),
  [1044] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1743),
  [1047] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(987),
  [1050] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(5231),
  [1053] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1135),
  [1056] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2348),
  [1059] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(3868),
  [1062] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2369),
  [1065] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2266),
  [1068] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8655),
  [1071] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(6429),
  [1074] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(7479),
  [1077] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8644),
  [1080] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(7480),
  [1083] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2418),
  [1086] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(37),
  [1089] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2230),
  [1092] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1282),
  [1095] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2364),
  [1098] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2354),
  [1101] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1957),
  [1104] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8637),
  [1107] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2227),
  [1110] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(6026),
  [1113] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(5126),
  [1116] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(5204),
  [1119] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(5208),
  [1122] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(7025),
  [1125] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(7490),
  [1128] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1530),
  [1131] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8618),
  [1134] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(7494),
  [1137] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(842),
  [1140] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8616),
  [1143] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1216),
  [1146] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8612),
  [1149] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8611),
  [1152] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8606),
  [1155] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1480),
  [1158] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1453),
  [1161] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8605),
  [1164] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8602),
  [1167] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8601),
  [1170] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(6625),
  [1173] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(4791),
  [1176] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(7073),
  [1179] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(6969),
  [1182] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(4846),
  [1185] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(4025),
  [1188] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2298),
  [1191] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8595),
  [1194] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2752),
  [1197] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(5108),
  [1200] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1111),
  [1203] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(893),
  [1206] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(7499),
  [1209] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1548),
  [1212] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1426),
  [1215] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(6502),
  [1218] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(6371),
  [1221] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8589),
  [1224] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8588),
  [1227] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1414),
  [1230] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1565),
  [1233] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(7501),
  [1236] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1569),
  [1239] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(5038),
  [1242] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(5362),
  [1245] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_translation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2373),
  [1248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1066),
  [1250] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_statement, 4, 0, 14),
  [1252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(923),
  [1254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1808),
  [1256] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_statement, 4, 0, 14),
  [1258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1808),
  [1260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1979),
  [1262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7767),
  [1264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1272),
  [1266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7508),
  [1268] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_statement, 2, 0, 0),
  [1270] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_statement, 2, 0, 0),
  [1272] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1066),
  [1275] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0),
  [1277] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(923),
  [1280] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1743),
  [1283] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1743),
  [1286] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1808),
  [1289] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0),
  [1291] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1808),
  [1294] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(231),
  [1297] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2346),
  [1300] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3954),
  [1303] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1979),
  [1306] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2364),
  [1309] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8655),
  [1312] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6429),
  [1315] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7767),
  [1318] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8644),
  [1321] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(52),
  [1324] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2230),
  [1327] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1272),
  [1330] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1957),
  [1333] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8637),
  [1336] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2227),
  [1339] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6026),
  [1342] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5126),
  [1345] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5204),
  [1348] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5208),
  [1351] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7416),
  [1354] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7770),
  [1357] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7450),
  [1360] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(854),
  [1363] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8523),
  [1366] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1205),
  [1369] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8271),
  [1372] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8270),
  [1375] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7947),
  [1378] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7792),
  [1381] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8200),
  [1384] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1480),
  [1387] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1453),
  [1390] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8605),
  [1393] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8602),
  [1396] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8601),
  [1399] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6625),
  [1402] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4240),
  [1405] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7073),
  [1408] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(6969),
  [1411] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4019),
  [1414] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(4025),
  [1417] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2298),
  [1420] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8595),
  [1423] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5108),
  [1426] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7508),
  [1429] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7776),
  [1432] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1548),
  [1435] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1460),
  [1438] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1459),
  [1441] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1586),
  [1444] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7501),
  [1447] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1569),
  [1450] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5038),
  [1453] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5362),
  [1456] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8249),
  [1459] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2373),
  [1462] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5662),
  [1465] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_statement, 3, 0, 14),
  [1467] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_statement, 3, 0, 14),
  [1469] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_statement, 3, 0, 0),
  [1471] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_statement, 3, 0, 0),
  [1473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1063),
  [1475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1068),
  [1477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(445),
  [1479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7449),
  [1481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8561),
  [1483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8560),
  [1485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5693),
  [1487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1069),
  [1489] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1063),
  [1492] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(487),
  [1495] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2340),
  [1498] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3856),
  [1501] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(65),
  [1504] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7076),
  [1507] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7451),
  [1510] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7498),
  [1513] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(859),
  [1516] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8177),
  [1519] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1215),
  [1522] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8596),
  [1525] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8594),
  [1528] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8688),
  [1531] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7543),
  [1534] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8443),
  [1537] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7443),
  [1540] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1384),
  [1543] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1382),
  [1546] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1807),
  [1549] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8439),
  [1552] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5653),
  [1555] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1069),
  [1558] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(510),
  [1561] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2349),
  [1564] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3904),
  [1567] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(43),
  [1570] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7274),
  [1573] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7813),
  [1576] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7772),
  [1579] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(884),
  [1582] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8607),
  [1585] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1209),
  [1588] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8044),
  [1591] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8043),
  [1594] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7898),
  [1597] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7806),
  [1600] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8017),
  [1603] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7811),
  [1606] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1450),
  [1609] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1465),
  [1612] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1673),
  [1615] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8016),
  [1618] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5724),
  [1621] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1068),
  [1624] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(445),
  [1627] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2348),
  [1630] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3868),
  [1633] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(37),
  [1636] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7025),
  [1639] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7490),
  [1642] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7494),
  [1645] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(842),
  [1648] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8616),
  [1651] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1216),
  [1654] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8612),
  [1657] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8611),
  [1660] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8606),
  [1663] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7449),
  [1666] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8561),
  [1669] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7499),
  [1672] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1426),
  [1675] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1414),
  [1678] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1565),
  [1681] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8560),
  [1684] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5693),
  [1687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1065),
  [1689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1049),
  [1691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2584),
  [1693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3912),
  [1695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [1697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7071),
  [1699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7754),
  [1701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7812),
  [1703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(885),
  [1705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8619),
  [1707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1213),
  [1709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7875),
  [1711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7874),
  [1713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7974),
  [1715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7747),
  [1717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7852),
  [1719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7714),
  [1721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1389),
  [1723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1410),
  [1725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1792),
  [1727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7850),
  [1729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5646),
  [1731] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1065),
  [1734] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1049),
  [1737] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2584),
  [1740] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3912),
  [1743] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(40),
  [1746] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7071),
  [1749] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7754),
  [1752] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7812),
  [1755] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(885),
  [1758] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(8619),
  [1761] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1213),
  [1764] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7875),
  [1767] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7874),
  [1770] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7974),
  [1773] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7747),
  [1776] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7852),
  [1779] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7714),
  [1782] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1389),
  [1785] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1410),
  [1788] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1792),
  [1791] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7850),
  [1794] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_case_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(5646),
  [1797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1064),
  [1799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [1801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2542),
  [1803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3909),
  [1805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7814),
  [1807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1298),
  [1809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8543),
  [1811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7919),
  [1813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1062),
  [1815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4359),
  [1817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8356),
  [1819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(926),
  [1821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1631),
  [1823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1631),
  [1825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1812),
  [1827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1984),
  [1829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6385),
  [1831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2335),
  [1833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6057),
  [1835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5117),
  [1837] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5116),
  [1839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5112),
  [1841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1629),
  [1843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1388),
  [1845] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8435),
  [1847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8683),
  [1849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8708),
  [1851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6649),
  [1853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3804),
  [1855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7246),
  [1857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6915),
  [1859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3849),
  [1861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3845),
  [1863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5111),
  [1865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1615),
  [1867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7475),
  [1869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1668),
  [1871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5028),
  [1873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5355),
  [1875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1067),
  [1877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7178),
  [1879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4900),
  [1881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(703),
  [1883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [1885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1304),
  [1887] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_argument_list, 4, 3, 0),
  [1889] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_argument_list, 4, 3, 0),
  [1891] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_argument_list, 4, 1, 0),
  [1893] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_argument_list, 4, 1, 0),
  [1895] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_argument_list, 2, 0, 0),
  [1897] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_argument_list, 2, 0, 0),
  [1899] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_argument_list, 3, 3, 0),
  [1901] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_argument_list, 3, 3, 0),
  [1903] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_argument_list, 3, 1, 0),
  [1905] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_argument_list, 3, 1, 0),
  [1907] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cbuffer_specifier, 3, 0, 47),
  [1909] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cbuffer_specifier, 3, 0, 47),
  [1911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5752),
  [1913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(737),
  [1915] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5933),
  [1917] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_argument_list, 4, 2, 0),
  [1919] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_argument_list, 4, 2, 0),
  [1921] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cbuffer_specifier, 2, 0, 10),
  [1923] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cbuffer_specifier, 2, 0, 10),
  [1925] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_argument_list, 3, 2, 0),
  [1927] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_argument_list, 3, 2, 0),
  [1929] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_statement, 3, 0, 0),
  [1931] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_statement, 3, 0, 0),
  [1933] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_qualified_type_identifier, 2, 0, 35),
  [1935] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_qualified_type_identifier, 2, 0, 35),
  [1937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(965),
  [1939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6523),
  [1941] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_name, 1, 0, 1),
  [1943] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_name, 1, 0, 1),
  [1945] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_statement, 2, 0, 0),
  [1947] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_statement, 2, 0, 0),
  [1949] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dependent_type_identifier, 2, 0, 0),
  [1951] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dependent_type_identifier, 2, 0, 0),
  [1953] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_qualified_type_identifier, 2, 0, 34),
  [1955] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_qualified_type_identifier, 2, 0, 34),
  [1957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6543),
  [1959] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_type, 2, 0, 16),
  [1961] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_type, 2, 0, 16),
  [1963] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 3, 0, 9),
  [1965] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 3, 0, 9),
  [1967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7827),
  [1969] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_name, 1, 0, 0),
  [1971] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_name, 1, 0, 0),
  [1973] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_constructor_try_statement_repeat1, 2, 0, 0),
  [1975] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_constructor_try_statement_repeat1, 2, 0, 0),
  [1977] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_constructor_try_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7827),
  [1980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(720),
  [1982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(727),
  [1984] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_try_statement, 4, 0, 46),
  [1986] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_try_statement, 4, 0, 46),
  [1988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(769),
  [1990] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_try_statement, 3, 0, 9),
  [1992] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_try_statement, 3, 0, 9),
  [1994] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 3, 0, 51),
  [1996] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 3, 0, 51),
  [1998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(867),
  [2000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(969),
  [2002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [2004] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 4, 0, 103),
  [2006] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 4, 0, 103),
  [2008] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, 0, 173),
  [2010] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, 0, 173),
  [2012] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 3, 0, 159),
  [2014] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 3, 0, 159),
  [2016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(970),
  [2018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1977),
  [2020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [2022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1785),
  [2024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1784),
  [2026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1785),
  [2028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(994),
  [2030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1136),
  [2032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6393),
  [2034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6215),
  [2036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2443),
  [2038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1274),
  [2040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5207),
  [2042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6061),
  [2044] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5202),
  [2046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5201),
  [2048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5199),
  [2050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1775),
  [2052] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1387),
  [2054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8180),
  [2056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8674),
  [2058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8705),
  [2060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6632),
  [2062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3406),
  [2064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7412),
  [2066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6829),
  [2068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3609),
  [2070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3612),
  [2072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2468),
  [2074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8182),
  [2076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5219),
  [2078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3189),
  [2080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1797),
  [2082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7527),
  [2084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1798),
  [2086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5034),
  [2088] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5363),
  [2090] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 4, 0, 104),
  [2092] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 4, 0, 104),
  [2094] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_statement, 1, 0, 0),
  [2096] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_statement, 1, 0, 0),
  [2098] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 2, 0, 0),
  [2100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 2, 0, 0),
  [2102] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_statement, 2, 0, 0),
  [2104] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 2, 0, 0),
  [2106] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_continue_statement, 2, 0, 0),
  [2108] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 2, 0, 0),
  [2110] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_throw_statement, 2, 0, 0),
  [2112] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_throw_statement, 2, 0, 0),
  [2114] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_co_return_statement, 2, 0, 0),
  [2116] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_co_return_statement, 2, 0, 0),
  [2118] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_definition, 6, 0, 130),
  [2120] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 6, 0, 130),
  [2122] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_seh_except_clause, 3, 0, 178),
  [2124] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_seh_except_clause, 3, 0, 178),
  [2126] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cbuffer_specifier, 5, 0, 179),
  [2128] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cbuffer_specifier, 5, 0, 179),
  [2130] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attributed_statement, 2, 0, 0),
  [2132] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attributed_statement, 2, 0, 0),
  [2134] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_definition, 5, 0, 130),
  [2136] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 5, 0, 130),
  [2138] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_definition, 5, 0, 85),
  [2140] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 5, 0, 85),
  [2142] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration_list, 2, 0, 0),
  [2144] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration_list, 2, 0, 0),
  [2146] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_seh_finally_clause, 2, 0, 9),
  [2148] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_seh_finally_clause, 2, 0, 9),
  [2150] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_seh_leave_statement, 2, 0, 0),
  [2152] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_seh_leave_statement, 2, 0, 0),
  [2154] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cbuffer_specifier, 5, 0, 180),
  [2156] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cbuffer_specifier, 5, 0, 180),
  [2158] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cbuffer_specifier, 5, 0, 181),
  [2160] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cbuffer_specifier, 5, 0, 181),
  [2162] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_discard_statement, 2, 0, 0),
  [2164] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_discard_statement, 2, 0, 0),
  [2166] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cbuffer_specifier, 4, 0, 94),
  [2168] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cbuffer_specifier, 4, 0, 94),
  [2170] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cbuffer_specifier, 4, 0, 93),
  [2172] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cbuffer_specifier, 4, 0, 93),
  [2174] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cbuffer_specifier, 4, 0, 134),
  [2176] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cbuffer_specifier, 4, 0, 134),
  [2178] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cbuffer_specifier, 2, 0, 9),
  [2180] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cbuffer_specifier, 2, 0, 9),
  [2182] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_statement, 2, 0, 0),
  [2184] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_statement, 2, 0, 0),
  [2186] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, 0, 145),
  [2188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, 0, 145),
  [2190] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 2, 0, 0),
  [2192] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 2, 0, 0),
  [2194] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 3, 0, 52),
  [2196] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_statement, 3, 0, 52),
  [2198] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 3, 0, 52),
  [2200] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 3, 0, 52),
  [2202] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_initializer_list, 2, 0, 0),
  [2204] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration, 6, 0, 199),
  [2206] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 6, 0, 199),
  [2208] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, 0, 200),
  [2210] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 6, 0, 200),
  [2212] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 6, 0, 201),
  [2214] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 6, 0, 201),
  [2216] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 3, 0, 0),
  [2218] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 3, 0, 0),
  [2220] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_do_statement, 5, 0, 146),
  [2222] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_do_statement, 5, 0, 146),
  [2224] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_goto_statement, 3, 0, 53),
  [2226] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_goto_statement, 3, 0, 53),
  [2228] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_statement, 3, 0, 54),
  [2230] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_statement, 3, 0, 54),
  [2232] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cbuffer_specifier, 6, 0, 203),
  [2234] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cbuffer_specifier, 6, 0, 203),
  [2236] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_throw_statement, 3, 0, 0),
  [2238] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_throw_statement, 3, 0, 0),
  [2240] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_co_return_statement, 3, 0, 0),
  [2242] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_co_return_statement, 3, 0, 0),
  [2244] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_co_yield_statement, 3, 0, 0),
  [2246] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_co_yield_statement, 3, 0, 0),
  [2248] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration, 3, 0, 66),
  [2250] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 3, 0, 66),
  [2252] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 5, 0, 150),
  [2254] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 5, 0, 150),
  [2256] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_range_loop, 5, 0, 151),
  [2258] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_range_loop, 5, 0, 151),
  [2260] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration_list, 3, 0, 0),
  [2262] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration_list, 3, 0, 0),
  [2264] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration, 5, 0, 166),
  [2266] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 5, 0, 166),
  [2268] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_seh_try_statement, 3, 0, 9),
  [2270] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_seh_try_statement, 3, 0, 9),
  [2272] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_definition, 4, 0, 85),
  [2274] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_definition, 4, 0, 85),
  [2276] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration, 4, 0, 113),
  [2278] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 4, 0, 113),
  [2280] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cbuffer_specifier, 3, 0, 48),
  [2282] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cbuffer_specifier, 3, 0, 48),
  [2284] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cbuffer_specifier, 3, 0, 46),
  [2286] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cbuffer_specifier, 3, 0, 46),
  [2288] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_statement, 1, 0, 0),
  [2290] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_statement, 1, 0, 0),
  [2292] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef, 4, 0, 10),
  [2294] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef, 4, 0, 10),
  [2296] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration_list, 2, 0, 0),
  [2298] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration_list, 2, 0, 0),
  [2300] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_alias_definition, 5, 0, 160),
  [2302] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_alias_definition, 5, 0, 160),
  [2304] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_alias_definition, 5, 0, 161),
  [2306] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_alias_definition, 5, 0, 161),
  [2308] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_alias_declaration, 5, 0, 162),
  [2310] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alias_declaration, 5, 0, 162),
  [2312] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_static_assert_declaration, 5, 0, 163),
  [2314] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_static_assert_declaration, 5, 0, 163),
  [2316] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_static_assert_declaration, 7, 0, 214),
  [2318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_static_assert_declaration, 7, 0, 214),
  [2320] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_concept_definition, 5, 0, 10),
  [2322] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_concept_definition, 5, 0, 10),
  [2324] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 168),
  [2326] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 168),
  [2328] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_default_method_clause, 3, 0, 0),
  [2330] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_default_method_clause, 3, 0, 0),
  [2332] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 4, 0, 115),
  [2334] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 115),
  [2336] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 4, 0, 111),
  [2338] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 111),
  [2340] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_declaration, 4, 0, 0),
  [2342] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_declaration, 4, 0, 0),
  [2344] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration_list, 3, 0, 0),
  [2346] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration_list, 3, 0, 0),
  [2348] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_declaration, 4, 0, 57),
  [2350] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_declaration, 4, 0, 57),
  [2352] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_instantiation, 4, 0, 58),
  [2354] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_instantiation, 4, 0, 58),
  [2356] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_cast_declaration, 5, 0, 175),
  [2358] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_cast_declaration, 5, 0, 175),
  [2360] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_or_destructor_definition, 4, 0, 124),
  [2362] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_or_destructor_definition, 4, 0, 124),
  [2364] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if, 6, 0, 176),
  [2366] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if, 6, 0, 176),
  [2368] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_constructor_try_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7521),
  [2371] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_definition, 4, 0, 94),
  [2373] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_definition, 4, 0, 94),
  [2375] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_definition, 4, 0, 93),
  [2377] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_definition, 4, 0, 93),
  [2379] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_definition, 4, 0, 92),
  [2381] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_definition, 4, 0, 92),
  [2383] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__block_item, 1, 0, 0), REDUCE(sym_statement, 1, 0, 0),
  [2386] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__block_item, 1, 0, 0), REDUCE(sym_statement, 1, 0, 0),
  [2389] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_function_def, 5, 0, 125),
  [2391] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_function_def, 5, 0, 125),
  [2393] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_friend_declaration, 4, 0, 0),
  [2395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_friend_declaration, 4, 0, 0),
  [2397] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_constructor_try_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7624),
  [2400] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_call, 2, 0, 3),
  [2402] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_call, 2, 0, 3),
  [2404] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 174),
  [2406] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 174),
  [2408] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if, 5, 0, 126),
  [2410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if, 5, 0, 126),
  [2412] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef, 4, 0, 79),
  [2414] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef, 4, 0, 79),
  [2416] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if, 4, 0, 78),
  [2418] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if, 4, 0, 78),
  [2420] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_function_def, 4, 0, 77),
  [2422] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_function_def, 4, 0, 77),
  [2424] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_definition, 2, 0, 9),
  [2426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_definition, 2, 0, 9),
  [2428] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_def, 4, 0, 76),
  [2430] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_def, 4, 0, 76),
  [2432] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_cast_definition, 3, 0, 75),
  [2434] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_cast_definition, 3, 0, 75),
  [2436] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if, 5, 0, 78),
  [2438] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if, 5, 0, 78),
  [2440] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_cast_declaration, 3, 0, 5),
  [2442] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_cast_declaration, 3, 0, 5),
  [2444] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_or_destructor_definition, 3, 0, 5),
  [2446] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_or_destructor_definition, 3, 0, 5),
  [2448] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_or_destructor_definition, 3, 0, 75),
  [2450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_or_destructor_definition, 3, 0, 75),
  [2452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7777),
  [2454] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_or_destructor_definition, 3, 0, 69),
  [2456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_or_destructor_definition, 3, 0, 69),
  [2458] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_cast_declaration, 4, 0, 120),
  [2460] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_cast_declaration, 4, 0, 120),
  [2462] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 3, 0, 67),
  [2464] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 3, 0, 67),
  [2466] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_or_destructor_definition, 2, 0, 25),
  [2468] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_or_destructor_definition, 2, 0, 25),
  [2470] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_declaration, 3, 0, 0),
  [2472] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_declaration, 3, 0, 0),
  [2474] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_definition, 3, 0, 48),
  [2476] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_definition, 3, 0, 48),
  [2478] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_definition, 3, 0, 60),
  [2480] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_definition, 3, 0, 60),
  [2482] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_declaration, 3, 0, 57),
  [2484] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_declaration, 3, 0, 57),
  [2486] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_instantiation, 3, 0, 5),
  [2488] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_instantiation, 3, 0, 5),
  [2490] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_or_destructor_definition, 2, 0, 26),
  [2492] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_or_destructor_definition, 2, 0, 26),
  [2494] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__empty_declaration, 2, 0, 0),
  [2496] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__empty_declaration, 2, 0, 0),
  [2498] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 202),
  [2500] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 202),
  [2502] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_alias_declaration, 6, 0, 197),
  [2504] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alias_declaration, 6, 0, 197),
  [2506] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef, 5, 0, 127),
  [2508] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef, 5, 0, 127),
  [2510] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_friend_declaration, 2, 0, 0),
  [2512] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_friend_declaration, 2, 0, 0),
  [2514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7624),
  [2516] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_or_destructor_declaration, 2, 0, 26),
  [2518] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_or_destructor_declaration, 2, 0, 26),
  [2520] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_definition, 3, 0, 46),
  [2522] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_definition, 3, 0, 46),
  [2524] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_definition, 5, 0, 136),
  [2526] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_definition, 5, 0, 136),
  [2528] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_definition, 5, 0, 135),
  [2530] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_definition, 5, 0, 135),
  [2532] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_cast_declaration, 2, 0, 26),
  [2534] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_cast_declaration, 2, 0, 26),
  [2536] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_cast_definition, 2, 0, 25),
  [2538] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_cast_definition, 2, 0, 25),
  [2540] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delete_method_clause, 3, 0, 0),
  [2542] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_method_clause, 3, 0, 0),
  [2544] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_constructor_try_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7777),
  [2547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7521),
  [2549] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pure_virtual_clause, 3, 0, 0),
  [2551] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pure_virtual_clause, 3, 0, 0),
  [2553] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_include, 3, 0, 37),
  [2555] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_include, 3, 0, 37),
  [2557] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_linkage_specification, 3, 0, 44),
  [2559] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_linkage_specification, 3, 0, 44),
  [2561] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_or_destructor_declaration, 3, 0, 5),
  [2563] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_or_destructor_declaration, 3, 0, 5),
  [2565] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_call, 3, 0, 38),
  [2567] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_call, 3, 0, 38),
  [2569] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef, 3, 0, 10),
  [2571] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef, 3, 0, 10),
  [2573] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_def, 3, 0, 10),
  [2575] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_def, 3, 0, 10),
  [2577] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_friend_declaration, 3, 0, 0),
  [2579] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_friend_declaration, 3, 0, 0),
  [2581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(890),
  [2583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2458),
  [2585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8030),
  [2587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5547),
  [2589] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_elif_in_field_declaration_list, 3, 0, 78),
  [2591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8562),
  [2593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(747),
  [2595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5568),
  [2597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8142),
  [2599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7748),
  [2601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4735),
  [2603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8522),
  [2605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3204),
  [2607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5231),
  [2609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2350),
  [2611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3897),
  [2613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5409),
  [2615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8521),
  [2617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2250),
  [2619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6059),
  [2621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5190),
  [2623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5189),
  [2625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5187),
  [2627] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5184),
  [2629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6942),
  [2631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1193),
  [2633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8629),
  [2635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6337),
  [2637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8638),
  [2639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1913),
  [2641] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1901),
  [2643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2007),
  [2645] = {.entry = {.count = 1, .reusable = false}}, SHIFT(841),
  [2647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2035),
  [2649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2037),
  [2651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1881),
  [2653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(832),
  [2655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1905),
  [2657] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_elifdef_in_field_declaration_list, 3, 0, 10),
  [2659] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_elif_in_field_declaration_list, 4, 0, 78),
  [2661] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_elifdef_in_field_declaration_list, 2, 0, 10),
  [2663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2096),
  [2665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2109),
  [2667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2141),
  [2669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2004),
  [2671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2089),
  [2673] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression_statement, 2, 0, 0), SHIFT(2500),
  [2676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1306),
  [2678] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_expression_statement, 2, 0, 0), SHIFT(6429),
  [2681] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression_statement, 2, 0, 0), SHIFT(6805),
  [2684] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression_statement, 2, 0, 0), SHIFT(8535),
  [2687] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression_statement, 2, 0, 0), SHIFT(7508),
  [2690] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression_statement, 1, 0, 0), SHIFT(2500),
  [2693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1344),
  [2695] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_expression_statement, 1, 0, 0), SHIFT(6429),
  [2698] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression_statement, 1, 0, 0), SHIFT(6805),
  [2701] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression_statement, 1, 0, 0), SHIFT(8535),
  [2704] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression_statement, 1, 0, 0), SHIFT(7508),
  [2707] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_init_statement, 1, 0, 0), SHIFT(2500),
  [2710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1347),
  [2712] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_init_statement, 1, 0, 0),
  [2714] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_init_statement, 1, 0, 0), SHIFT(6429),
  [2717] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_statement, 1, 0, 0),
  [2719] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_init_statement, 1, 0, 0), SHIFT(6805),
  [2722] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_init_statement, 1, 0, 0), SHIFT(8535),
  [2725] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_init_statement, 1, 0, 0), SHIFT(7508),
  [2728] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2458),
  [2731] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8030),
  [2734] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(5547),
  [2737] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0),
  [2739] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8562),
  [2742] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7748),
  [2745] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(4735),
  [2748] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8522),
  [2751] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(3204),
  [2754] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(5231),
  [2757] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(5231),
  [2760] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2350),
  [2763] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(3897),
  [2766] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2369),
  [2769] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2364),
  [2772] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8655),
  [2775] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(5409),
  [2778] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7814),
  [2781] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8644),
  [2784] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7480),
  [2787] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2230),
  [2790] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8521),
  [2793] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1957),
  [2796] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8637),
  [2799] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2250),
  [2802] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(6059),
  [2805] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(5190),
  [2808] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(5189),
  [2811] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(5187),
  [2814] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2298),
  [2817] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8595),
  [2820] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2752),
  [2823] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(5184),
  [2826] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(6942),
  [2829] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(893),
  [2832] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1193),
  [2835] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8629),
  [2838] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(6337),
  [2841] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8638),
  [2844] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2373),
  [2847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2500),
  [2849] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_qualifier, 1, 0, 0),
  [2851] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_qualifier, 1, 0, 0),
  [2853] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6805),
  [2855] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8535),
  [2857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7888),
  [2859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5535),
  [2861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7868),
  [2863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7738),
  [2865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2347),
  [2867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3917),
  [2869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [2871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6871),
  [2873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1188),
  [2875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6324),
  [2877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8620),
  [2879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3142),
  [2881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2251),
  [2883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(444),
  [2885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(526),
  [2887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2593),
  [2889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [2891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [2893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2253),
  [2895] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__top_level_expression_statement, 2, 0, 0),
  [2897] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__top_level_expression_statement, 2, 0, 0),
  [2899] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8081),
  [2902] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(5533),
  [2905] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7865),
  [2908] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7639),
  [2911] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2356),
  [2914] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(3887),
  [2917] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(6836),
  [2920] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1195),
  [2923] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(6334),
  [2926] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8646),
  [2929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2592),
  [2931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8081),
  [2933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5533),
  [2935] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_else_in_field_declaration_list, 1, 0, 0),
  [2937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7865),
  [2939] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7639),
  [2941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2356),
  [2943] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3887),
  [2945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6836),
  [2947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1195),
  [2949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6334),
  [2951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8646),
  [2953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4095),
  [2955] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__top_level_item, 1, 0, 0), REDUCE(sym__top_level_statement, 1, 0, 0),
  [2958] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__top_level_item, 1, 0, 0), REDUCE(sym__top_level_statement, 1, 0, 0),
  [2961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3145),
  [2963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2946),
  [2965] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_else_in_field_declaration_list, 2, 0, 0),
  [2967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2479),
  [2969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2934),
  [2971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [2973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [2975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [2977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1059),
  [2979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2453),
  [2981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1006),
  [2983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3380),
  [2985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3387),
  [2987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4896),
  [2989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4941),
  [2991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3213),
  [2993] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7888),
  [2996] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(5535),
  [2999] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7868),
  [3002] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7738),
  [3005] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2347),
  [3008] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(3917),
  [3011] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0),
  [3013] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(6871),
  [3016] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1188),
  [3019] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(6324),
  [3022] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_field_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8620),
  [3025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3217),
  [3027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4958),
  [3029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4087),
  [3031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4951),
  [3033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2490),
  [3035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2531),
  [3037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7221),
  [3039] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1603),
  [3041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8273),
  [3043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7591),
  [3045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8377),
  [3047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7632),
  [3049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5659),
  [3051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2534),
  [3053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2517),
  [3055] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2525),
  [3057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2530),
  [3059] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(2525),
  [3062] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(923),
  [3065] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1743),
  [3068] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1743),
  [3071] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1808),
  [3074] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1049),
  [3077] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(6429),
  [3080] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7767),
  [3083] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(40),
  [3086] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1272),
  [3089] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(6805),
  [3092] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7071),
  [3095] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7754),
  [3098] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1603),
  [3101] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8273),
  [3104] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7812),
  [3107] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(885),
  [3110] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8619),
  [3113] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1213),
  [3116] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7875),
  [3119] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7874),
  [3122] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7974),
  [3125] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7747),
  [3128] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7852),
  [3131] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1480),
  [3134] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1453),
  [3137] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8605),
  [3140] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8602),
  [3143] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8601),
  [3146] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(6625),
  [3149] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(4240),
  [3152] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7073),
  [3155] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(6969),
  [3158] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(4019),
  [3161] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(4025),
  [3164] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8535),
  [3167] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7508),
  [3170] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7714),
  [3173] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1548),
  [3176] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1389),
  [3179] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1410),
  [3182] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1792),
  [3185] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7501),
  [3188] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1569),
  [3191] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(5038),
  [3194] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(5362),
  [3197] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7850),
  [3200] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(5646),
  [3203] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(2490),
  [3206] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(487),
  [3209] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(65),
  [3212] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7076),
  [3215] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7451),
  [3218] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1806),
  [3221] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8598),
  [3224] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7498),
  [3227] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(859),
  [3230] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8177),
  [3233] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1215),
  [3236] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8596),
  [3239] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8594),
  [3242] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8688),
  [3245] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7543),
  [3248] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8443),
  [3251] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7443),
  [3254] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1384),
  [3257] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1382),
  [3260] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1807),
  [3263] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8439),
  [3266] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(5653),
  [3269] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(2517),
  [3272] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(445),
  [3275] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(37),
  [3278] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7025),
  [3281] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7490),
  [3284] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1530),
  [3287] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8618),
  [3290] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7494),
  [3293] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(842),
  [3296] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8616),
  [3299] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1216),
  [3302] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8612),
  [3305] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8611),
  [3308] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8606),
  [3311] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7449),
  [3314] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8561),
  [3317] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7499),
  [3320] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1426),
  [3323] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1414),
  [3326] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1565),
  [3329] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8560),
  [3332] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(5693),
  [3335] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(2531),
  [3338] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7221),
  [3341] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7591),
  [3344] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8377),
  [3347] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7632),
  [3350] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(5659),
  [3353] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(2530),
  [3356] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(231),
  [3359] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(52),
  [3362] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7416),
  [3365] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7770),
  [3368] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1672),
  [3371] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8046),
  [3374] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7450),
  [3377] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(854),
  [3380] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8523),
  [3383] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1205),
  [3386] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8271),
  [3389] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8270),
  [3392] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7947),
  [3395] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7792),
  [3398] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8200),
  [3401] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7776),
  [3404] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1460),
  [3407] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1459),
  [3410] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1586),
  [3413] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8249),
  [3416] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(5662),
  [3419] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(2534),
  [3422] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(510),
  [3425] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(43),
  [3428] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7274),
  [3431] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7813),
  [3434] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1752),
  [3437] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7877),
  [3440] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7772),
  [3443] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(884),
  [3446] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8607),
  [3449] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1209),
  [3452] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8044),
  [3455] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8043),
  [3458] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7898),
  [3461] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7806),
  [3464] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8017),
  [3467] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(7811),
  [3470] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1450),
  [3473] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1465),
  [3476] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(1673),
  [3479] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(8016),
  [3482] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT(5724),
  [3485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2316),
  [3487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3411),
  [3489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3411),
  [3491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1976),
  [3493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6504),
  [3495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2659),
  [3497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6045),
  [3499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5177),
  [3501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3289),
  [3503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8532),
  [3505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6167),
  [3507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6167),
  [3509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6085),
  [3511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8307),
  [3513] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sizeof_expression, 4, 0, 45),
  [3515] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sizeof_expression, 4, 0, 45),
  [3517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1730),
  [3519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1730),
  [3521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6386),
  [3523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1152),
  [3525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6868),
  [3527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1371),
  [3529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8378),
  [3531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8677),
  [3533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8706),
  [3535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6643),
  [3537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3061),
  [3539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7378),
  [3541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6973),
  [3543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2844),
  [3545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2802),
  [3547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1542),
  [3549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7481),
  [3551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1539),
  [3553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5017),
  [3555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5358),
  [3557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2333),
  [3559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1479),
  [3561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1479),
  [3563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6421),
  [3565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1469),
  [3567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3120),
  [3569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7057),
  [3571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6860),
  [3573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1619),
  [3575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7495),
  [3577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1597),
  [3579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5030),
  [3581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2326),
  [3583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5415),
  [3585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1723),
  [3587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6904),
  [3589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1191),
  [3591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8642),
  [3593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5416),
  [3595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6873),
  [3597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1192),
  [3599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8625),
  [3601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8634),
  [3603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8631),
  [3605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8649),
  [3607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8639),
  [3609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8653),
  [3611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8647),
  [3613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6747),
  [3615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1190),
  [3617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8221),
  [3619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6852),
  [3621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1194),
  [3623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8614),
  [3625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2515),
  [3627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1157),
  [3629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6812),
  [3631] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attribute_declaration, 3, 0, 0),
  [3633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_declaration, 3, 0, 0),
  [3635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2522),
  [3637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1695),
  [3639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1695),
  [3641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6384),
  [3643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1368),
  [3645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3360),
  [3647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7368),
  [3649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6767),
  [3651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1533),
  [3653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7463),
  [3655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1531),
  [3657] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attribute_declaration, 4, 0, 0),
  [3659] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_declaration, 4, 0, 0),
  [3661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1989),
  [3663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(936),
  [3665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1298),
  [3667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2555),
  [3669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1529),
  [3671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1529),
  [3673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6402),
  [3675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1160),
  [3677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6927),
  [3679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1432),
  [3681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8456),
  [3683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8686),
  [3685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8709),
  [3687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6669),
  [3689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3602),
  [3691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7318),
  [3693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6831),
  [3695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3729),
  [3697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3723),
  [3699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1499),
  [3701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7472),
  [3703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1501),
  [3705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4995),
  [3707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5359),
  [3709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(772),
  [3711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1663),
  [3713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1663),
  [3715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6430),
  [3717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1404),
  [3719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1745),
  [3721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1739),
  [3723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(963),
  [3725] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__declaration_modifiers, 1, 0, 0), REDUCE(aux_sym_attributed_declarator_repeat1, 1, 0, 0),
  [3728] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declaration_modifiers, 1, 0, 0), REDUCE(aux_sym_attributed_declarator_repeat1, 1, 0, 0),
  [3731] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 1, 0, 0),
  [3733] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 1, 0, 0),
  [3735] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declaration_modifiers, 1, 0, 0),
  [3737] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declaration_modifiers, 1, 0, 0),
  [3739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2512),
  [3741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1151),
  [3743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6732),
  [3745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7693),
  [3747] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_constructor_try_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7693),
  [3750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2110),
  [3752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(940),
  [3754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1475),
  [3756] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1475),
  [3758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1754),
  [3760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6383),
  [3762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2571),
  [3764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5021),
  [3766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6022),
  [3768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5088),
  [3770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5089),
  [3772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5091),
  [3774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1541),
  [3776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1448),
  [3778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8411),
  [3780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8680),
  [3782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8707),
  [3784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6627),
  [3786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4695),
  [3788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7150),
  [3790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6972),
  [3792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4820),
  [3794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4818),
  [3796] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2980),
  [3798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8437),
  [3800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5150),
  [3802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(960),
  [3804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1532),
  [3806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7478),
  [3808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1618),
  [3810] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5003),
  [3812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5347),
  [3814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1118),
  [3816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [3818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2231),
  [3820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6400),
  [3822] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_specifier, 1, 0, 1),
  [3824] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0),
  [3826] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym__declarator, 1, 0, 0), REDUCE(sym_type_specifier, 1, 0, 1), REDUCE(sym_expression, 1, 0, 0),
  [3830] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_specifier, 1, 0, 1),
  [3832] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0),
  [3834] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_specifier, 1, 0, 1), REDUCE(sym_expression, 1, 0, 0),
  [3837] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_specifier, 1, 0, 1), REDUCE(sym_expression, 1, 0, 0),
  [3840] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(964),
  [3843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(820),
  [3845] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declarator, 1, 0, 0), REDUCE(sym_type_specifier, 1, 0, 1),
  [3848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2233),
  [3850] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym__declarator, 1, 0, 0), REDUCE(sym_type_specifier, 1, 0, 1), REDUCE(sym_expression, 1, 0, 0),
  [3854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1299),
  [3856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1299),
  [3858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6745),
  [3860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7492),
  [3862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [3864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [3866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3815),
  [3868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4685),
  [3870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1140),
  [3872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [3874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2376),
  [3876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1121),
  [3878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3690),
  [3880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3086),
  [3882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2395),
  [3884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1080),
  [3886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2424),
  [3888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2382),
  [3890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3028),
  [3892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2890),
  [3894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2211),
  [3896] = {.entry = {.count = 1, .reusable = false}}, SHIFT(886),
  [3898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2491),
  [3900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [3902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1478),
  [3904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4472),
  [3906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4205),
  [3908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4203),
  [3910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8176),
  [3912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1477),
  [3914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(883),
  [3916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(845),
  [3918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2504),
  [3920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(860),
  [3922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2203),
  [3924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5156),
  [3926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(889),
  [3928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(742),
  [3930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2352),
  [3932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4720),
  [3934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1060),
  [3936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2704),
  [3938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4540),
  [3940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4540),
  [3942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5571),
  [3944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1099),
  [3946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1667),
  [3948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1667),
  [3950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6387),
  [3952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1146),
  [3954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1362),
  [3956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4209),
  [3958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7364),
  [3960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1474),
  [3962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1472),
  [3964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5024),
  [3966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5360),
  [3968] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(973),
  [3971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1324),
  [3973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6798),
  [3975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7468),
  [3977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(834),
  [3979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2532),
  [3981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1626),
  [3983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1626),
  [3985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6426),
  [3987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1385),
  [3989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4523),
  [3991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7336),
  [3993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6774),
  [3995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1772),
  [3997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7464),
  [3999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1766),
  [4001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2566),
  [4003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1526),
  [4005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1526),
  [4007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6388),
  [4009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1435),
  [4011] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1518),
  [4013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1740),
  [4015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4997),
  [4017] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2550),
  [4019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1161),
  [4021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6879),
  [4023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2567),
  [4025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1562),
  [4027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1562),
  [4029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6423),
  [4031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1464),
  [4033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1483),
  [4035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1490),
  [4037] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_pack_expansion, 2, 0, 28),
  [4039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(935),
  [4041] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_pack_expansion, 2, 0, 28),
  [4043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1486),
  [4045] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_qualified_identifier, 2, 0, 34),
  [4047] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_qualified_identifier, 2, 0, 34), REDUCE(sym_qualified_type_identifier, 2, 0, 35),
  [4050] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_qualified_identifier, 2, 0, 34),
  [4052] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_identifier, 2, 0, 34), REDUCE(sym_qualified_type_identifier, 2, 0, 35),
  [4055] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_identifier, 2, 0, 34), SHIFT(980),
  [4058] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_function, 2, 0, 17),
  [4060] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_template_type, 2, 0, 16), REDUCE(sym_template_function, 2, 0, 17),
  [4063] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_function, 2, 0, 17),
  [4065] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_template_type, 2, 0, 16), REDUCE(sym_template_function, 2, 0, 17),
  [4068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2337),
  [4070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1086),
  [4072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4256),
  [4074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5874),
  [4076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5874),
  [4078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6449),
  [4080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1089),
  [4082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1396),
  [4084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2435),
  [4086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1095),
  [4088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3479),
  [4090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8410),
  [4092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1458),
  [4094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2399),
  [4096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6104),
  [4098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1397),
  [4100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1103),
  [4102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6012),
  [4104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1407),
  [4106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6356),
  [4108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1394),
  [4110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1096),
  [4112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5901),
  [4114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1467),
  [4116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1104),
  [4118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2622),
  [4120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1401),
  [4122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1090),
  [4124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6335),
  [4126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1367),
  [4128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1097),
  [4130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6298),
  [4132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1405),
  [4134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3441),
  [4136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1402),
  [4138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5920),
  [4140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1395),
  [4142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6316),
  [4144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1418),
  [4146] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1101),
  [4148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6308),
  [4150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2518),
  [4152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1422),
  [4154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1088),
  [4156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6107),
  [4158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1364),
  [4160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6350),
  [4162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1375),
  [4164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1105),
  [4166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3565),
  [4168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1447),
  [4170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6100),
  [4172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1449),
  [4174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2646),
  [4176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1370),
  [4178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3538),
  [4180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1365),
  [4182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1107),
  [4184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5915),
  [4186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1391),
  [4188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5899),
  [4190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2409),
  [4192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1297),
  [4194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5602),
  [4196] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_identifier, 2, 0, 34), SHIFT(976),
  [4199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3045),
  [4201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1751),
  [4203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3558),
  [4205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6428),
  [4207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2505),
  [4209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3940),
  [4211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1263),
  [4213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5705),
  [4215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3879),
  [4217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5665),
  [4219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3950),
  [4221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7856),
  [4223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3928),
  [4225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8208),
  [4227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2845),
  [4229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5773),
  [4231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3872),
  [4233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3650),
  [4235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5778),
  [4237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8460),
  [4239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3628),
  [4241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3535),
  [4243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2811),
  [4245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8032),
  [4247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3776),
  [4249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7988),
  [4251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4748),
  [4253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3691),
  [4255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2792),
  [4257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3576),
  [4259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1951),
  [4261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3744),
  [4263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4304),
  [4265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4300),
  [4267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1973),
  [4269] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(2500),
  [4272] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(923),
  [4275] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(1743),
  [4278] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(1743),
  [4281] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(1808),
  [4284] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(3045),
  [4287] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(6429),
  [4290] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(1751),
  [4293] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0),
  [4295] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(1298),
  [4298] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(6805),
  [4301] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(1480),
  [4304] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(1453),
  [4307] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(8605),
  [4310] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(8602),
  [4313] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(8601),
  [4316] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(6625),
  [4319] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(4240),
  [4322] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(7073),
  [4325] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(6969),
  [4328] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(4019),
  [4331] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(4025),
  [4334] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(8535),
  [4337] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(6428),
  [4340] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(7508),
  [4343] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(1548),
  [4346] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(7501),
  [4349] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(1569),
  [4352] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(5038),
  [4355] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_requirement_seq_repeat1, 2, 0, 0), SHIFT_REPEAT(5362),
  [4358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3591),
  [4360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2803),
  [4362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4759),
  [4364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3499),
  [4366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3860),
  [4368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2817),
  [4370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3951),
  [4372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4808),
  [4374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3863),
  [4376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3681),
  [4378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3750),
  [4380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [4382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1794),
  [4384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [4386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [4388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [4390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2323),
  [4392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5129),
  [4394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5132),
  [4396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5133),
  [4398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5114),
  [4400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5120),
  [4402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5121),
  [4404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5165),
  [4406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5161),
  [4408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5160),
  [4410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5110),
  [4412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5064),
  [4414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5113),
  [4416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5192),
  [4418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5196),
  [4420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5197),
  [4422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5193),
  [4424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5186),
  [4426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5185),
  [4428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5103),
  [4430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5101),
  [4432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5100),
  [4434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3534),
  [4436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1500),
  [4438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3050),
  [4440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1800),
  [4442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4746),
  [4444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1473),
  [4446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3755),
  [4448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1755),
  [4450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3915),
  [4452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1617),
  [4454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4179),
  [4456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1749),
  [4458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2821),
  [4460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1610),
  [4462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7428),
  [4464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8210),
  [4466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(921),
  [4468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1503),
  [4470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8041),
  [4472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1628),
  [4474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4523),
  [4476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1406),
  [4478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8050),
  [4480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [4482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7400),
  [4484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8150),
  [4486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(464),
  [4488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1549),
  [4490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1007),
  [4492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7250),
  [4494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8539),
  [4496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [4498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [4500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7196),
  [4502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8613),
  [4504] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8127),
  [4506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1411),
  [4508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8133),
  [4510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7966),
  [4512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1413),
  [4514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7959),
  [4516] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8338),
  [4519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_capture_specifier, 2, 0, 0),
  [4521] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_capture_specifier, 2, 0, 0),
  [4523] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8340),
  [4526] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8374),
  [4529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1325),
  [4531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1229),
  [4533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7546),
  [4535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2406),
  [4537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1669),
  [4539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1296),
  [4541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1254),
  [4543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1251),
  [4545] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8357),
  [4548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1247),
  [4550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1292),
  [4552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3638),
  [4554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1287),
  [4556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1264),
  [4558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1537),
  [4560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1735),
  [4562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1646),
  [4564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1284),
  [4566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1266),
  [4568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1281),
  [4570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4948),
  [4572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4947),
  [4574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6790),
  [4576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6618),
  [4578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2801),
  [4580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1252),
  [4582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1285),
  [4584] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8332),
  [4587] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8326),
  [4590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1231),
  [4592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1226),
  [4594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6583),
  [4596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1522),
  [4598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1271),
  [4600] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8192),
  [4603] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8288),
  [4606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1246),
  [4608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1283),
  [4610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1233),
  [4612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2526),
  [4614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1248),
  [4616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1294),
  [4618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1235),
  [4620] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8183),
  [4623] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8320),
  [4626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1706),
  [4628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3716),
  [4630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1238),
  [4632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1290),
  [4634] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8252),
  [4637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1232),
  [4639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1234),
  [4641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2219),
  [4643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(939),
  [4645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1796),
  [4647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_statement_body, 3, 1, 105),
  [4649] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8603),
  [4652] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1722),
  [4654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1595),
  [4656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(922),
  [4658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(931),
  [4660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1681),
  [4662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(927),
  [4664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1545),
  [4666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1657),
  [4668] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_statement_body, 4, 1, 190),
  [4670] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_default_capture, 1, 0, 0),
  [4672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(907),
  [4674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1773),
  [4676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(916),
  [4678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1767),
  [4680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1774),
  [4682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(941),
  [4684] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1553),
  [4686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1654),
  [4688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1684),
  [4690] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1768),
  [4692] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_statement_body, 2, 1, 0),
  [4694] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1497),
  [4696] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_statement_body, 2, 1, 105),
  [4698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1725),
  [4700] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_statement_body, 3, 1, 78),
  [4702] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_statement_body, 3, 1, 149),
  [4704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8350),
  [4706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(929),
  [4708] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8382),
  [4710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6359),
  [4712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5898),
  [4714] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8227),
  [4717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6240),
  [4719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8388),
  [4721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(920),
  [4723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3531),
  [4725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(909),
  [4727] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8557),
  [4730] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8554),
  [4733] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8645),
  [4735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3540),
  [4737] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8231),
  [4740] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8553),
  [4743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7897),
  [4745] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8234),
  [4748] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8237),
  [4751] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8243),
  [4754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [4756] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8248),
  [4759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(457),
  [4761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(930),
  [4763] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8279),
  [4766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8198),
  [4768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(918),
  [4770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8441),
  [4772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(925),
  [4774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1054),
  [4776] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8563),
  [4779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5917),
  [4781] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8448),
  [4784] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8583),
  [4787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5918),
  [4789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6362),
  [4791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3443),
  [4793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6099),
  [4795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5661),
  [4797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8075),
  [4799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8245),
  [4801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6370),
  [4803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5924),
  [4805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8420),
  [4807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(911),
  [4809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3426),
  [4811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1926),
  [4813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1288),
  [4815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6266),
  [4817] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8496),
  [4820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8188),
  [4822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1019),
  [4824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2083),
  [4826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8039),
  [4828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2112),
  [4830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [4832] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8486),
  [4835] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8479),
  [4838] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8477),
  [4841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6352),
  [4843] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8473),
  [4846] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8592),
  [4849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6021),
  [4851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(442),
  [4853] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8124),
  [4855] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8463),
  [4858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8461),
  [4860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [4862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(924),
  [4864] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8457),
  [4867] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8367),
  [4870] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8391),
  [4873] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8387),
  [4876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6046),
  [4878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8418),
  [4880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(937),
  [4882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2624),
  [4884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(460),
  [4886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(933),
  [4888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6068),
  [4890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [4892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [4894] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7975),
  [4896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(928),
  [4898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [4900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2647),
  [4902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(932),
  [4904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1273),
  [4906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2494),
  [4908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1261),
  [4910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1278),
  [4912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1269),
  [4914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1258),
  [4916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1249),
  [4918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1241),
  [4920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1250),
  [4922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1270),
  [4924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1276),
  [4926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1239),
  [4928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1262),
  [4930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7405),
  [4932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3475),
  [4934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1257),
  [4936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1265),
  [4938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1245),
  [4940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7081),
  [4942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3631),
  [4944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1295),
  [4946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1289),
  [4948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1244),
  [4950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7229),
  [4952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2761),
  [4954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1293),
  [4956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1275),
  [4958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1237),
  [4960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1230),
  [4962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1236),
  [4964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2507),
  [4966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2506),
  [4968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1253),
  [4970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1242),
  [4972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7672),
  [4974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7608),
  [4976] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_constructor_try_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7672),
  [4979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6477),
  [4981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2331),
  [4983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2370),
  [4985] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2334),
  [4987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8173),
  [4989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5433),
  [4991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7452),
  [4993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8175),
  [4995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8376),
  [4997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2332),
  [4999] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_initializer_list, 2, 0, 0),
  [5001] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 4, 0, 66),
  [5003] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 4, 0, 66),
  [5005] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 6, 0, 216),
  [5007] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 6, 0, 216),
  [5009] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 6, 0, 207),
  [5011] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 6, 0, 207),
  [5013] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 7, 0, 216),
  [5015] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 7, 0, 216),
  [5017] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 6, 0, 196),
  [5019] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 6, 0, 196),
  [5021] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if_in_field_declaration_list, 6, 0, 176),
  [5023] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_field_declaration_list, 6, 0, 176),
  [5025] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline_method_definition, 3, 0, 67),
  [5027] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline_method_definition, 3, 0, 67),
  [5029] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inline_method_definition, 3, 0, 66),
  [5031] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inline_method_definition, 3, 0, 66),
  [5033] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 3, 0, 66),
  [5035] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 3, 0, 66),
  [5037] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 2, 0, 56),
  [5039] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 2, 0, 56),
  [5041] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__field_declaration_list_item, 2, 0, 0),
  [5043] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__field_declaration_list_item, 2, 0, 0),
  [5045] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 3, 0, 56),
  [5047] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 3, 0, 56),
  [5049] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 5, 0, 183),
  [5051] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 5, 0, 183),
  [5053] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef_in_field_declaration_list, 3, 0, 10),
  [5055] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef_in_field_declaration_list, 3, 0, 10),
  [5057] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 5, 0, 207),
  [5059] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 5, 0, 207),
  [5061] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 5, 0, 182),
  [5063] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 5, 0, 182),
  [5065] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 5, 0, 206),
  [5067] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 5, 0, 206),
  [5069] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 5, 0, 66),
  [5071] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 5, 0, 66),
  [5073] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 5, 0, 196),
  [5075] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 5, 0, 196),
  [5077] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef_in_field_declaration_list, 5, 0, 127),
  [5079] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef_in_field_declaration_list, 5, 0, 127),
  [5081] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if_in_field_declaration_list, 4, 0, 78),
  [5083] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_field_declaration_list, 4, 0, 78),
  [5085] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if_in_field_declaration_list, 5, 0, 78),
  [5087] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_field_declaration_list, 5, 0, 78),
  [5089] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef_in_field_declaration_list, 4, 0, 79),
  [5091] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef_in_field_declaration_list, 4, 0, 79),
  [5093] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if_in_field_declaration_list, 5, 0, 126),
  [5095] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_field_declaration_list, 5, 0, 126),
  [5097] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef_in_field_declaration_list, 4, 0, 10),
  [5099] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef_in_field_declaration_list, 4, 0, 10),
  [5101] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 6, 0, 206),
  [5103] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 6, 0, 206),
  [5105] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 4, 0, 182),
  [5107] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 4, 0, 182),
  [5109] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 4, 0, 183),
  [5111] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 4, 0, 183),
  [5113] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_expression, 3, 0, 72),
  [5115] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 3, 0, 72),
  [5117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7647),
  [5119] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fold_expression, 3, 0, 40),
  [5121] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fold_expression, 3, 0, 40),
  [5123] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_requires_expression, 2, 0, 21),
  [5125] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_requires_expression, 2, 0, 21),
  [5127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7731),
  [5129] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_requires_expression, 3, 0, 65),
  [5131] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_requires_expression, 3, 0, 65),
  [5133] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attribute_specifier, 4, 0, 0),
  [5135] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_specifier, 4, 0, 0),
  [5137] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_expression, 4, 0, 123),
  [5139] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 4, 0, 123),
  [5141] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_requirement_seq, 3, 0, 0),
  [5143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_requirement_seq, 3, 0, 0),
  [5145] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_expression, 3, 0, 73),
  [5147] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 3, 0, 73),
  [5149] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constraint_conjunction, 3, 0, 55),
  [5151] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constraint_conjunction, 3, 0, 55),
  [5153] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_alignas_qualifier, 4, 0, 0),
  [5155] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alignas_qualifier, 4, 0, 0),
  [5157] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_expression, 4, 0, 122),
  [5159] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 4, 0, 122),
  [5161] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_constructor_try_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7647),
  [5164] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_expression, 2, 0, 32),
  [5166] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 2, 0, 32),
  [5168] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_expression, 5, 0, 172),
  [5170] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 5, 0, 172),
  [5172] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__requirement_clause_constraint, 3, 0, 0),
  [5174] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__requirement_clause_constraint, 3, 0, 0),
  [5176] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_requirement_seq, 2, 0, 0),
  [5178] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_requirement_seq, 2, 0, 0),
  [5180] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_constructor_try_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7731),
  [5183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2368),
  [5185] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(976),
  [5188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declarator, 1, 0, 0),
  [5190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2520),
  [5192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6810),
  [5194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7486),
  [5196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(985),
  [5198] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(975),
  [5201] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(984),
  [5204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2666),
  [5206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1310),
  [5208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1310),
  [5210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6813),
  [5212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7469),
  [5214] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declaration_specifiers, 1, 0, 2),
  [5216] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declaration_specifiers, 1, 0, 2),
  [5218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2224),
  [5220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2274),
  [5222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8199),
  [5224] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0),
  [5226] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0),
  [5228] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(2197),
  [5231] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_requires_clause, 2, 0, 22),
  [5233] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_requires_clause, 2, 0, 22),
  [5235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5429),
  [5237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5406),
  [5239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5429),
  [5241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5406),
  [5243] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(981),
  [5246] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declaration_specifiers, 2, 0, 20),
  [5248] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declaration_specifiers, 2, 0, 20),
  [5250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2218),
  [5252] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constraint_disjunction, 3, 0, 55),
  [5254] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constraint_disjunction, 3, 0, 55),
  [5256] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declaration_specifiers, 3, 0, 20),
  [5258] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declaration_specifiers, 3, 0, 20),
  [5260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2220),
  [5262] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_parameter_list, 2, 0, 0),
  [5264] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_parameter_list, 2, 0, 0),
  [5266] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0),
  [5268] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0),
  [5270] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(2331),
  [5273] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(2220),
  [5276] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(2334),
  [5279] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(8173),
  [5282] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(7452),
  [5285] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(8175),
  [5288] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(8376),
  [5291] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(2332),
  [5294] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__enum_base_clause, 2, 0, 98),
  [5296] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__enum_base_clause, 2, 0, 98),
  [5298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(964),
  [5300] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_parameter_list, 4, 0, 0),
  [5302] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_parameter_list, 4, 0, 0),
  [5304] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declaration_specifiers, 2, 0, 2),
  [5306] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__declaration_specifiers, 2, 0, 2),
  [5308] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_parameter_list, 3, 0, 0),
  [5310] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_parameter_list, 3, 0, 0),
  [5312] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 0), REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0),
  [5315] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_sized_type_specifier, 2, 0, 0), REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0),
  [5318] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_specifier, 1, 0, 0),
  [5320] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_specifier, 1, 0, 0),
  [5322] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_specifier, 1, 0, 0), SHIFT(1202),
  [5325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2240),
  [5327] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 1, 0, 6),
  [5329] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 1, 0, 6),
  [5331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(719),
  [5333] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 1, 0, 0), SHIFT(2239),
  [5336] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sized_type_specifier, 1, 0, 0),
  [5338] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sized_type_specifier, 1, 0, 0),
  [5340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2226),
  [5342] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2246),
  [5344] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(2232),
  [5347] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, -1, 18),
  [5349] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sized_type_specifier, 2, -1, 18),
  [5351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2232),
  [5353] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__enum_base_clause, 2, 0, 97),
  [5355] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__enum_base_clause, 2, 0, 97),
  [5357] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hlsl_attribute, 3, 0, 0),
  [5359] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_capture_specifier, 3, 0, 0),
  [5361] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_capture_specifier, 3, 0, 0),
  [5363] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hlsl_attribute, 3, 0, 0),
  [5365] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript_designator, 3, 0, 0),
  [5367] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, -1, 36),
  [5369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sized_type_specifier, 2, -1, 36),
  [5371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2247),
  [5373] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 2),
  [5375] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sized_type_specifier, 2, 0, 2),
  [5377] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sized_type_specifier, 3, 0, 20),
  [5379] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sized_type_specifier, 3, 0, 20),
  [5381] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 20),
  [5383] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sized_type_specifier, 2, 0, 20),
  [5385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2241),
  [5387] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sized_type_specifier, 3, -1, 36),
  [5389] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sized_type_specifier, 3, -1, 36),
  [5391] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_decltype, 4, 0, 0),
  [5393] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_decltype, 4, 0, 0),
  [5395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(675),
  [5397] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_storage_class_specifier, 1, 0, 0),
  [5399] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_storage_class_specifier, 1, 0, 0),
  [5401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6962),
  [5403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(674),
  [5405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(725),
  [5407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [5409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2002),
  [5411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2181),
  [5413] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dependent_type, 2, -1, 0),
  [5415] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dependent_type, 2, -1, 0),
  [5417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1855),
  [5419] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 4, 0, 47),
  [5421] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 4, 0, 47),
  [5423] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_specifier, 2, 0, 12),
  [5425] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_specifier, 2, 0, 12),
  [5427] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration, 4, 0, 142),
  [5429] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration, 4, 0, 142),
  [5431] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 5, 0, 141),
  [5433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 5, 0, 141),
  [5435] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ms_declspec_modifier, 4, 0, 0),
  [5437] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ms_declspec_modifier, 4, 0, 0),
  [5439] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_placeholder_type_specifier, 2, 0, 27),
  [5441] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_placeholder_type_specifier, 2, 0, 27),
  [5443] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 4, 0, 48),
  [5445] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 4, 0, 48),
  [5447] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 4, 0, 49),
  [5449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 4, 0, 49),
  [5451] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enumerator_list, 3, 0, 0),
  [5453] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerator_list, 3, 0, 0),
  [5455] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_union_specifier, 2, 0, 12),
  [5457] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_specifier, 2, 0, 12),
  [5459] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_decltype_auto, 4, 0, 0),
  [5461] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_decltype_auto, 4, 0, 0),
  [5463] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 4, 0, 46),
  [5465] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 4, 0, 46),
  [5467] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration, 2, 0, 12),
  [5469] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration, 2, 0, 12),
  [5471] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_specifier, 2, 0, 12),
  [5473] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_specifier, 2, 0, 12),
  [5475] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enumerator_list, 2, 0, 0),
  [5477] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerator_list, 2, 0, 0),
  [5479] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 2, 0, 6),
  [5481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 2, 0, 6),
  [5483] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 2, 0, 11),
  [5485] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 2, 0, 11),
  [5487] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 4, 0, 102),
  [5489] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 4, 0, 102),
  [5491] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 3, 0, 9),
  [5493] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 3, 0, 9),
  [5495] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enumerator_list, 4, 0, 0),
  [5497] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerator_list, 4, 0, 0),
  [5499] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 3, 0, 10),
  [5501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 3, 0, 10),
  [5503] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 5, 0, 94),
  [5505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 5, 0, 94),
  [5507] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 6, 0, 140),
  [5509] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 6, 0, 140),
  [5511] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 5, 0, 96),
  [5513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 5, 0, 96),
  [5515] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_placeholder_type_specifier, 1, 0, 0),
  [5517] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_placeholder_type_specifier, 1, 0, 0),
  [5519] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 3, 0, 49),
  [5521] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 3, 0, 49),
  [5523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6110),
  [5525] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration, 3, 0, 101),
  [5527] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration, 3, 0, 101),
  [5529] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 4, 0, 96),
  [5531] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 4, 0, 96),
  [5533] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 3, 0, 50),
  [5535] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 3, 0, 50),
  [5537] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 5, 0, 99),
  [5539] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 5, 0, 99),
  [5541] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration, 1, 0, 13),
  [5543] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration, 1, 0, 13),
  [5545] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 4, 0, 46),
  [5547] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 4, 0, 46),
  [5549] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 3, 0, 9),
  [5551] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 3, 0, 9),
  [5553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [5555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(698),
  [5557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1866),
  [5559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2085),
  [5561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(562),
  [5563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(755),
  [5565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2111),
  [5567] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 4, 0, 141),
  [5569] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 4, 0, 141),
  [5571] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 3, 0, 102),
  [5573] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 3, 0, 102),
  [5575] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 3, 0, 46),
  [5577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 3, 0, 46),
  [5579] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 4, 0, 99),
  [5581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 4, 0, 99),
  [5583] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 2, 0, 50),
  [5585] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 2, 0, 50),
  [5587] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 5, 0, 140),
  [5589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 5, 0, 140),
  [5591] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 4, 0, 94),
  [5593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 4, 0, 94),
  [5595] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 3, 0, 46),
  [5597] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 3, 0, 46),
  [5599] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 1, 0, 11),
  [5601] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 1, 0, 11),
  [5603] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__declarator, 1, 0, 0), REDUCE(sym_type_specifier, 1, 0, 1),
  [5606] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__class_declaration_item, 2, 0, 9),
  [5608] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__class_declaration_item, 2, 0, 9),
  [5610] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 3, 0, 48),
  [5612] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 3, 0, 48),
  [5614] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 2, 0, 9),
  [5616] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 2, 0, 9),
  [5618] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_qualifiers, 1, 0, 0),
  [5620] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_qualifiers, 1, 0, 0),
  [5622] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(966),
  [5625] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_specifier, 1, 0, 0), SHIFT(1196),
  [5628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(979),
  [5630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6503),
  [5632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6484),
  [5634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3936),
  [5636] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 2, 0, 10),
  [5638] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 2, 0, 10),
  [5640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5841),
  [5642] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_condition_clause, 3, 0, 14),
  [5644] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_condition_clause, 3, 0, 14),
  [5646] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(2343),
  [5649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0),
  [5651] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0),
  [5653] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(6973),
  [5656] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(7481),
  [5659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2345),
  [5661] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_concatenated_string, 2, 0, 0),
  [5663] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_concatenated_string, 2, 0, 0),
  [5665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2343),
  [5667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_concatenated_string, 3, 0, 0),
  [5669] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_concatenated_string, 3, 0, 0),
  [5671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3920),
  [5673] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3914),
  [5675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3898),
  [5677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3903),
  [5679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3889),
  [5681] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_condition_clause, 4, 0, 144),
  [5683] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_condition_clause, 4, 0, 144),
  [5685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6495),
  [5687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6492),
  [5689] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_specifier, 3, 0, 47),
  [5691] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_specifier, 3, 0, 47),
  [5693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3886),
  [5695] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_declaration, 2, 0, 107),
  [5697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5079),
  [5699] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(1957),
  [5702] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(2368),
  [5705] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(2364),
  [5708] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(8655),
  [5711] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(7814),
  [5714] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(8644),
  [5717] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(8637),
  [5720] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(2373),
  [5723] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__constructor_specifiers, 1, 0, 0), REDUCE(aux_sym__declaration_specifiers_repeat1, 1, 0, 0),
  [5726] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__constructor_specifiers, 1, 0, 0),
  [5728] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__constructor_specifiers, 1, 0, 0),
  [5730] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__constructor_specifiers, 1, 0, 0), REDUCE(aux_sym__declaration_specifiers_repeat1, 1, 0, 0),
  [5733] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__declaration_specifiers_repeat1, 1, 0, 0),
  [5735] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_operator_cast_definition_repeat1, 2, 0, 0),
  [5737] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_operator_cast_definition_repeat1, 2, 0, 0),
  [5739] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_operator_cast_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(2331),
  [5742] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_operator_cast_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(2370),
  [5745] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_operator_cast_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(2334),
  [5748] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_operator_cast_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8173),
  [5751] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_operator_cast_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(7452),
  [5754] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_operator_cast_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8175),
  [5757] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_operator_cast_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8376),
  [5760] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_operator_cast_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(2752),
  [5763] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_operator_cast_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(2332),
  [5766] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(2374),
  [5769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5842),
  [5771] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_literal, 2, 0, 0),
  [5773] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_literal, 2, 0, 0),
  [5775] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_literal, 3, 0, 0),
  [5777] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_literal, 3, 0, 0),
  [5779] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_raw_string_literal, 7, 0, 215),
  [5781] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_raw_string_literal, 7, 0, 215),
  [5783] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_array_declarator_repeat1, 2, 0, 0),
  [5785] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_declarator_repeat1, 2, 0, 0),
  [5787] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_array_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(2435),
  [5790] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_array_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(2399),
  [5793] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_array_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(8410),
  [5796] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_raw_string_literal, 5, 0, 0),
  [5798] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_raw_string_literal, 5, 0, 0),
  [5800] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(971),
  [5803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1329),
  [5805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1329),
  [5807] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(2408),
  [5810] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_identifier, 2, 0, 34), SHIFT(975),
  [5813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5752),
  [5815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8454),
  [5817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(734),
  [5819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2460),
  [5821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8656),
  [5823] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ms_call_modifier, 1, 0, 0),
  [5825] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ms_call_modifier, 1, 0, 0),
  [5827] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_identifier, 2, 0, 34), SHIFT(982),
  [5830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2513),
  [5832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2461),
  [5834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2536),
  [5836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2799),
  [5838] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__string, 1, 0, 0),
  [5840] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__string, 1, 0, 0),
  [5842] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__declarator, 1, 0, 0),
  [5844] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_identifier, 2, 0, 34), SHIFT(966),
  [5847] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_type_identifier, 2, 0, 35), SHIFT(966),
  [5850] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 4, 0, 90),
  [5852] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 4, 0, 90),
  [5854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1202),
  [5856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1487),
  [5858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2607),
  [5860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7926),
  [5862] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 3, 0, 45),
  [5864] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 3, 0, 45),
  [5866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(966),
  [5868] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 3, 0, 63),
  [5870] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 3, 0, 63),
  [5872] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 2, 0, 20),
  [5874] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 2, 0, 20),
  [5876] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__declarator, 1, 0, 0), REDUCE(sym_expression, 1, 0, 0),
  [5879] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(980),
  [5882] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__declarator, 1, 0, 0), REDUCE(sym_expression, 1, 0, 0),
  [5885] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_destructor_name, 2, 0, 0),
  [5887] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_destructor_name, 2, 0, 0),
  [5889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6098),
  [5891] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_pointer_declarator, 1, 1, 0),
  [5893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2499),
  [5895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4234),
  [5897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4234),
  [5899] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_pointer_declarator, 1, 1, 0),
  [5901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5644),
  [5903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1099),
  [5905] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_pointer_declarator, 2, 1, 0),
  [5907] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_pointer_declarator, 2, 1, 0),
  [5909] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1300),
  [5911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6116),
  [5913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2511),
  [5915] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(2510),
  [5918] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(6744),
  [5921] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(7457),
  [5924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2514),
  [5926] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(983),
  [5929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1324),
  [5931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2516),
  [5933] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(2514),
  [5936] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(6810),
  [5939] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(7486),
  [5942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2374),
  [5944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7927),
  [5946] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(6302),
  [5949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1308),
  [5951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1308),
  [5953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2533),
  [5955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2510),
  [5957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6744),
  [5959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7457),
  [5961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2649),
  [5963] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(7927),
  [5966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2521),
  [5968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(869),
  [5970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1332),
  [5972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1332),
  [5974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6754),
  [5976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7461),
  [5978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2535),
  [5980] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_reference_type_declarator, 2, 1, 0),
  [5982] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reference_type_declarator, 2, 1, 0),
  [5984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1718),
  [5986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7719),
  [5988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1092),
  [5990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2560),
  [5992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6784),
  [5994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7467),
  [5996] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pointer_type_declarator, 3, 1, 41),
  [5998] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_type_declarator, 3, 1, 41),
  [6000] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pointer_type_declarator, 2, 1, 5),
  [6002] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_type_declarator, 2, 1, 5),
  [6004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3907),
  [6006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2570),
  [6008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4290),
  [6010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4290),
  [6012] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 1, 0, 0), SHIFT(2587),
  [6015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2554),
  [6017] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2648),
  [6019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2689),
  [6021] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(2581),
  [6024] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pointer_type_declarator, 4, 1, 84),
  [6026] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_type_declarator, 4, 1, 84),
  [6028] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(982),
  [6031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2556),
  [6033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4270),
  [6035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4270),
  [6037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2675),
  [6039] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2582),
  [6041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2703),
  [6043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2561),
  [6045] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(2561),
  [6048] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(6784),
  [6051] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(7467),
  [6054] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1305),
  [6056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1305),
  [6058] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2701),
  [6060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2547),
  [6062] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2702),
  [6064] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pointer_type_declarator, 5, 1, 167),
  [6066] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_type_declarator, 5, 1, 167),
  [6068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3911),
  [6070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8409),
  [6072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(773),
  [6074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5933),
  [6076] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2630),
  [6078] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0),
  [6080] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0),
  [6082] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(7719),
  [6085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5841),
  [6087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3529),
  [6089] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 3, 0, 62),
  [6091] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 3, 0, 62),
  [6093] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_declarator, 1, 0, 42),
  [6095] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_declarator, 1, 0, 42),
  [6097] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_declarator, 1, 0, 0),
  [6099] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_declarator, 1, 0, 0),
  [6101] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_type_declarator, 3, 0, 26),
  [6103] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_type_declarator, 3, 0, 26),
  [6105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2653),
  [6107] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_type_declarator, 5, 0, 169),
  [6109] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_type_declarator, 5, 0, 169),
  [6111] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_type_declarator, 3, -10, 0),
  [6113] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_type_declarator, 3, -10, 0),
  [6115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2640),
  [6117] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 5, 0, 133),
  [6119] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 5, 0, 133),
  [6121] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_declarator, 1, 0, 1),
  [6123] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_declarator, 1, 0, 1),
  [6125] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_declarator, 1, 0, 43),
  [6127] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_declarator, 1, 0, 43),
  [6129] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(2640),
  [6132] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attributed_type_declarator, 2, 0, 0),
  [6134] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attributed_type_declarator, 2, 0, 0),
  [6136] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 4, 0, 89),
  [6138] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 4, 0, 89),
  [6140] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_type_declarator, 4, 0, 26),
  [6142] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_type_declarator, 4, 0, 26),
  [6144] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_type_declarator, 4, 0, 116),
  [6146] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_type_declarator, 4, 0, 116),
  [6148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2631),
  [6150] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_type_declarator, 2, 0, 86),
  [6152] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_type_declarator, 2, 0, 86),
  [6154] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_type_declarator, 4, -10, 0),
  [6156] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_type_declarator, 4, -10, 0),
  [6158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2239),
  [6160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2410),
  [6162] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 4, 0, 110),
  [6164] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 4, 0, 110),
  [6166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2408),
  [6168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2581),
  [6170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2665),
  [6172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6184),
  [6174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2697),
  [6176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2682),
  [6178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2672),
  [6180] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(2676),
  [6183] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(6798),
  [6186] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(7468),
  [6189] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_qualified_field_identifier, 2, 1, 118),
  [6191] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_qualified_field_identifier, 2, 1, 118),
  [6193] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_field_identifier, 2, 1, 118), SHIFT(966),
  [6196] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_method, 2, 0, 117),
  [6198] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_method, 2, 0, 117),
  [6200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2676),
  [6202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5875),
  [6204] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_expression, 3, 1, 70),
  [6206] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 3, 1, 70),
  [6208] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_field_expression, 3, 1, 70), SHIFT(966),
  [6211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3786),
  [6213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5718),
  [6215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2673),
  [6217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2677),
  [6219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2671),
  [6221] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_declarator, 3, 0, 164),
  [6223] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_declarator, 3, 0, 164),
  [6225] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_qualified_field_identifier, 2, 0, 34),
  [6227] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_qualified_field_identifier, 2, 0, 34),
  [6229] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_declarator, 4, 0, 164),
  [6231] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_declarator, 4, 0, 164),
  [6233] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pointer_expression, 2, 0, 4),
  [6235] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_expression, 2, 0, 4),
  [6237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1256),
  [6239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2796),
  [6241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5902),
  [6243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5902),
  [6245] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3, 0, 40),
  [6247] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3, 0, 40),
  [6249] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 4),
  [6251] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_expression, 2, 0, 4),
  [6253] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_list, 3, 0, 0),
  [6255] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_list, 3, 0, 0),
  [6257] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(2716),
  [6260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2871),
  [6262] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [6264] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [6266] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_list, 4, 0, 0),
  [6268] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_list, 4, 0, 0),
  [6270] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cast_expression, 4, 0, 83),
  [6272] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cast_expression, 4, 0, 83),
  [6274] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_explicit_function_specifier, 4, 0, 0),
  [6276] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_explicit_function_specifier, 4, 0, 0),
  [6278] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_name, 2, 0, 0),
  [6280] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_name, 2, 0, 0),
  [6282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2765),
  [6284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8474),
  [6286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(761),
  [6288] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dependent_field_identifier, 2, 0, 0),
  [6290] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dependent_field_identifier, 2, 0, 0),
  [6292] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 55),
  [6294] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 3, 0, 55),
  [6296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2861),
  [6298] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2739),
  [6300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2860),
  [6302] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_co_await_expression, 2, 0, 4),
  [6304] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_co_await_expression, 2, 0, 4),
  [6306] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_qualified_identifier, 3, 0, 74),
  [6308] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_qualified_identifier, 3, 0, 74),
  [6310] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_identifier, 3, 0, 74), SHIFT(966),
  [6313] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_explicit_function_specifier, 1, 0, 0),
  [6315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1778),
  [6317] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_explicit_function_specifier, 1, 0, 0),
  [6319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8433),
  [6321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(759),
  [6323] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_method, 2, 0, 17),
  [6325] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_method, 2, 0, 17),
  [6327] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_update_expression, 2, 0, 4),
  [6329] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_expression, 2, 0, 4),
  [6331] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sizeof_expression, 2, 0, 14),
  [6333] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sizeof_expression, 2, 0, 14),
  [6335] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameter_list, 2, 0, 0),
  [6337] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_list, 2, 0, 0),
  [6339] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dependent_identifier, 2, 0, 0),
  [6341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_dependent_identifier, 2, 0, 0),
  [6343] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_name, 3, 0, 0),
  [6345] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_name, 3, 0, 0),
  [6347] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_offsetof_expression, 6, 0, 191),
  [6349] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_offsetof_expression, 6, 0, 191),
  [6351] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 5, 0, 0),
  [6353] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 5, 0, 0),
  [6355] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_initializer_list, 3, 0, 0),
  [6357] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_initializer_list, 3, 0, 0),
  [6359] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 6, 0, 177),
  [6361] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 6, 0, 177),
  [6363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(975),
  [6365] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 3, 0, 0),
  [6367] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 3, 0, 0),
  [6369] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript_argument_list, 4, 0, 0),
  [6371] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript_argument_list, 4, 0, 0),
  [6373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5879),
  [6375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8173),
  [6377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5408),
  [6379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5410),
  [6381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5408),
  [6383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5410),
  [6385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5863),
  [6387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8454),
  [6389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2898),
  [6391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2819),
  [6393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2922),
  [6395] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript_argument_list, 3, 0, 0),
  [6397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript_argument_list, 3, 0, 0),
  [6399] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 5, 0, 131),
  [6401] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 5, 0, 131),
  [6403] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 5, 0, 132),
  [6405] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 5, 0, 132),
  [6407] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_update_expression, 2, 0, 29),
  [6409] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_expression, 2, 0, 29),
  [6411] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gnu_asm_expression, 9, 0, 224),
  [6413] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_expression, 9, 0, 224),
  [6415] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_expression, 3, 0, 71),
  [6417] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 3, 0, 71),
  [6419] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_user_defined_literal, 2, 0, 0),
  [6421] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_user_defined_literal, 2, 0, 0),
  [6423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8497),
  [6425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(794),
  [6427] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript_argument_list, 2, 0, 0),
  [6429] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript_argument_list, 2, 0, 0),
  [6431] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_null, 1, 0, 0),
  [6433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_null, 1, 0, 0),
  [6435] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_initializer_list, 4, 0, 0),
  [6437] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_initializer_list, 4, 0, 0),
  [6439] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 2, 0, 7),
  [6441] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 2, 0, 7),
  [6443] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generic_expression, 9, 0, 0),
  [6445] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generic_expression, 9, 0, 0),
  [6447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2924),
  [6449] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gnu_asm_expression, 8, 0, 221),
  [6451] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_expression, 8, 0, 221),
  [6453] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gnu_asm_expression, 8, 0, 220),
  [6455] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_expression, 8, 0, 220),
  [6457] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 3, 0, 61),
  [6459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 3, 0, 61),
  [6461] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generic_expression, 8, 0, 0),
  [6463] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generic_expression, 8, 0, 0),
  [6465] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 4, 0, 109),
  [6467] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 4, 0, 109),
  [6469] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript_expression, 2, 0, 30),
  [6471] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript_expression, 2, 0, 30),
  [6473] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_initializer_list, 5, 0, 0),
  [6475] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_initializer_list, 5, 0, 0),
  [6477] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 4, 0, 108),
  [6479] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 4, 0, 108),
  [6481] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(2825),
  [6484] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 2, 0, 0),
  [6486] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 2, 0, 0),
  [6488] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 4, 0, 0),
  [6490] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 4, 0, 0),
  [6492] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gnu_asm_expression, 7, 0, 213),
  [6494] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_expression, 7, 0, 213),
  [6496] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_expression, 3, 0, 55),
  [6498] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 3, 0, 55),
  [6500] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gnu_asm_expression, 7, 0, 212),
  [6502] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_expression, 7, 0, 212),
  [6504] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sizeof_expression, 5, 0, 152),
  [6506] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sizeof_expression, 5, 0, 152),
  [6508] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gnu_asm_expression, 5, 0, 154),
  [6510] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_expression, 5, 0, 154),
  [6512] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gnu_asm_expression, 5, 0, 155),
  [6514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_expression, 5, 0, 155),
  [6516] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gnu_asm_expression, 6, 0, 194),
  [6518] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_expression, 6, 0, 194),
  [6520] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gnu_asm_expression, 4, 0, 106),
  [6522] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_expression, 4, 0, 106),
  [6524] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_alignof_expression, 4, 0, 45),
  [6526] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alignof_expression, 4, 0, 45),
  [6528] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_literal_expression, 2, 0, 8),
  [6530] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_literal_expression, 2, 0, 8),
  [6532] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 5, 0, 165),
  [6534] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 5, 0, 165),
  [6536] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_literal_expression, 4, 0, 83),
  [6538] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_literal_expression, 4, 0, 83),
  [6540] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 4, 0, 88),
  [6542] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 4, 0, 88),
  [6544] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_gnu_asm_expression, 6, 0, 193),
  [6546] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_expression, 6, 0, 193),
  [6548] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(2856),
  [6551] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(6745),
  [6554] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(7492),
  [6557] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_type_identifier, 2, 0, 35), SHIFT(975),
  [6560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6183),
  [6562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2872),
  [6564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2873),
  [6566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2866),
  [6568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(982),
  [6570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2716),
  [6572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2870),
  [6574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2856),
  [6576] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(2904),
  [6579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2825),
  [6581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2969),
  [6583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2885),
  [6585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2964),
  [6587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2900),
  [6589] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_type_identifier, 2, 0, 35), SHIFT(982),
  [6592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8489),
  [6594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(775),
  [6596] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_pointer_declarator, 3, 1, 0),
  [6598] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_pointer_declarator, 3, 1, 0),
  [6600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5864),
  [6602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6175),
  [6604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2955),
  [6606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2903),
  [6608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2896),
  [6610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(983),
  [6612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(978),
  [6614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5854),
  [6616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6130),
  [6618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1196),
  [6620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1509),
  [6622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3198),
  [6624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7906),
  [6626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2994),
  [6628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7996),
  [6630] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_conditional_expression, 5, 0, 170),
  [6632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2786),
  [6634] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conditional_expression, 5, 0, 170),
  [6636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1484),
  [6638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1488),
  [6640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1492),
  [6642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1493),
  [6644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1498),
  [6646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1502),
  [6648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1508),
  [6650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1524),
  [6652] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1525),
  [6654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1525),
  [6656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1528),
  [6658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1345),
  [6660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1513),
  [6662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1492),
  [6664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1493),
  [6666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1524),
  [6668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2904),
  [6670] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_conditional_expression, 4, 0, 119),
  [6672] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conditional_expression, 4, 0, 119),
  [6674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2968),
  [6676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3019),
  [6678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1199),
  [6680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1515),
  [6682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3292),
  [6684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8128),
  [6686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2996),
  [6688] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delete_expression, 5, 0, 0),
  [6690] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_expression, 5, 0, 0),
  [6692] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_type_identifier, 2, 0, 35), SHIFT(983),
  [6695] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delete_expression, 3, 0, 0),
  [6697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_expression, 3, 0, 0),
  [6699] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delete_expression, 4, 0, 0),
  [6701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_expression, 4, 0, 0),
  [6703] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delete_expression, 2, 0, 0),
  [6705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_expression, 2, 0, 0),
  [6707] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__requirement, 1, 0, 64),
  [6709] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__requirement, 1, 0, 64),
  [6711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5861),
  [6713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6136),
  [6715] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_requirement, 2, 0, 0),
  [6717] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_requirement, 2, 0, 0),
  [6719] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_requirement, 5, 0, 0),
  [6721] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_requirement, 5, 0, 0),
  [6723] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_requirement, 4, 0, 0),
  [6725] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_requirement, 4, 0, 0),
  [6727] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_compound_requirement, 6, 0, 0),
  [6729] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compound_requirement, 6, 0, 0),
  [6731] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_char_literal, 3, 0, 0),
  [6733] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_char_literal, 3, 0, 0),
  [6735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1563),
  [6737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7683),
  [6739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1087),
  [6741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1200),
  [6743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1737),
  [6745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3619),
  [6747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8048),
  [6749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1710),
  [6751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1720),
  [6753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1709),
  [6755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1708),
  [6757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1703),
  [6759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1702),
  [6761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1697),
  [6763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1694),
  [6765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1693),
  [6767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1693),
  [6769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1692),
  [6771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1311),
  [6773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1634),
  [6775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1709),
  [6777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1708),
  [6779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1703),
  [6781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1697),
  [6783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3518),
  [6785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1307),
  [6787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3613),
  [6789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1463),
  [6791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1393),
  [6793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1392),
  [6795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1390),
  [6797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1372),
  [6799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1373),
  [6801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1377),
  [6803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1386),
  [6805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1408),
  [6807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1415),
  [6809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1416),
  [6811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1417),
  [6813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1419),
  [6815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1430),
  [6817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1437),
  [6819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1451),
  [6821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1454),
  [6823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1462),
  [6825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1243),
  [6827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1228),
  [6829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1340),
  [6831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1280),
  [6833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1240),
  [6835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1227),
  [6837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1225),
  [6839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1259),
  [6841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1260),
  [6843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1267),
  [6845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1268),
  [6847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1279),
  [6849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1291),
  [6851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1317),
  [6853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1691),
  [6855] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1383),
  [6857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1381),
  [6859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1380),
  [6861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1379),
  [6863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1376),
  [6865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1366),
  [6867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3515),
  [6869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5930),
  [6871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5855),
  [6873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8024),
  [6875] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23),
  [6877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5443),
  [6879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5443),
  [6881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4679),
  [6883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8375),
  [6885] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(7756),
  [6888] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_declarator_seq, 1, 0, 23),
  [6890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4679),
  [6892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8434),
  [6894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6622),
  [6896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3888),
  [6898] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(5933),
  [6901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5647),
  [6903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8597),
  [6905] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(5397),
  [6908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5397),
  [6910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2718),
  [6912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3763),
  [6914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3622),
  [6916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3622),
  [6918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3402),
  [6920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7840),
  [6922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1635),
  [6924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7651),
  [6926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1102),
  [6928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3215),
  [6930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5223),
  [6932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5223),
  [6934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8521),
  [6936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3190),
  [6938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5267),
  [6940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5267),
  [6942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5732),
  [6944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6555),
  [6946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3222),
  [6948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5296),
  [6950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5296),
  [6952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5678),
  [6954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3703),
  [6956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3703),
  [6958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3496),
  [6960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8005),
  [6962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3182),
  [6964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5291),
  [6966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5291),
  [6968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5741),
  [6970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6085),
  [6972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2832),
  [6974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2832),
  [6976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2736),
  [6978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8007),
  [6980] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(7683),
  [6983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3383),
  [6985] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3383),
  [6987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3345),
  [6989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8238),
  [6991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3289),
  [6993] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1729),
  [6995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1728),
  [6997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1727),
  [6999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1719),
  [7001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1689),
  [7003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1671),
  [7005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1655),
  [7007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1652),
  [7009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1641),
  [7011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1641),
  [7013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1639),
  [7015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1721),
  [7017] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1727),
  [7019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1719),
  [7021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1689),
  [7023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1655),
  [7025] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_identifier, 3, 0, 74), SHIFT(976),
  [7028] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(7651),
  [7031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1662),
  [7033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1676),
  [7035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1666),
  [7037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1653),
  [7039] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1649),
  [7041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1647),
  [7043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1644),
  [7045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1640),
  [7047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1638),
  [7049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1638),
  [7051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1636),
  [7053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1666),
  [7055] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1653),
  [7057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1649),
  [7059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1644),
  [7061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5930),
  [7063] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_field_expression, 3, 1, 70), SHIFT(975),
  [7066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3467),
  [7068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1328),
  [7070] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(8375),
  [7073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3926),
  [7075] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_identifier, 3, 0, 74), SHIFT(980),
  [7078] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_field_identifier, 2, 1, 118), SHIFT(975),
  [7081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3353),
  [7083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3880),
  [7085] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(5394),
  [7088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3777),
  [7090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1587),
  [7092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1585),
  [7094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1583),
  [7096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1581),
  [7098] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1561),
  [7100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1557),
  [7102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1556),
  [7104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1555),
  [7106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1552),
  [7108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1544),
  [7110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1286),
  [7112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1316),
  [7114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1779),
  [7116] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1583),
  [7118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1581),
  [7120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1561),
  [7122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1556),
  [7124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3779),
  [7126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5972),
  [7128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5972),
  [7130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3456),
  [7132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8409),
  [7134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(813),
  [7136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7756),
  [7138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3894),
  [7140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6097),
  [7142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5407),
  [7144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1369),
  [7146] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1317),
  [7148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3873),
  [7150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7880),
  [7152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3578),
  [7154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1420),
  [7156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1421),
  [7158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1423),
  [7160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1424),
  [7162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1425),
  [7164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1427),
  [7166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1429),
  [7168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1431),
  [7170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1433),
  [7172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1434),
  [7174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1436),
  [7176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1438),
  [7178] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1439),
  [7180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1440),
  [7182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1441),
  [7184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1442),
  [7186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1443),
  [7188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1444),
  [7190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7881),
  [7192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1339),
  [7194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7882),
  [7196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7883),
  [7198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7884),
  [7200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7885),
  [7202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7886),
  [7204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7887),
  [7206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7890),
  [7208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7894),
  [7210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7907),
  [7212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7909),
  [7214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1786),
  [7216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1445),
  [7218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1446),
  [7220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1452),
  [7222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1455),
  [7224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1457),
  [7226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1466),
  [7228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3875),
  [7230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2795),
  [7232] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(6097),
  [7235] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(5407),
  [7238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3495),
  [7240] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(3409),
  [7243] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(6754),
  [7246] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(7461),
  [7249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3697),
  [7251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5717),
  [7253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5816),
  [7255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3933),
  [7257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5894),
  [7259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5894),
  [7261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1810),
  [7263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1805),
  [7265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1753),
  [7267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1971),
  [7269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5394),
  [7271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3621),
  [7273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1804),
  [7275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1803),
  [7277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1789),
  [7279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1777),
  [7281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1771),
  [7283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1769),
  [7285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1765),
  [7287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1765),
  [7289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1471),
  [7291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1804),
  [7293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1803),
  [7295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1789),
  [7297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1771),
  [7299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1355),
  [7301] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_identifier, 3, 0, 74), SHIFT(975),
  [7304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4292),
  [7306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3409),
  [7308] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_field_expression, 3, 1, 70), SHIFT(982),
  [7311] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__binary_fold_operator, 3, 0, 128),
  [7313] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binary_fold_operator, 3, 0, 128),
  [7315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3696),
  [7317] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_field_identifier, 2, 1, 118), SHIFT(982),
  [7320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3733),
  [7322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3595),
  [7324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1957),
  [7326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8655),
  [7328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8637),
  [7330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3983),
  [7332] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(5411),
  [7335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(981),
  [7337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5411),
  [7339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5428),
  [7341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5405),
  [7343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5428),
  [7345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5405),
  [7347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(971),
  [7349] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 1, 0, 0), SHIFT(3717),
  [7352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3614),
  [7354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3721),
  [7356] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_identifier, 3, 0, 74), SHIFT(982),
  [7359] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(3595),
  [7362] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(6813),
  [7365] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(7469),
  [7368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3498),
  [7370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3853),
  [7372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1733),
  [7374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1738),
  [7376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1746),
  [7378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1747),
  [7380] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1748),
  [7382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1757),
  [7384] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1758),
  [7386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1759),
  [7388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1760),
  [7390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1760),
  [7392] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1762),
  [7394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1748),
  [7396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1757),
  [7398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1758),
  [7400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3728),
  [7402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3760),
  [7404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3840),
  [7406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1085),
  [7408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3715),
  [7410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5353),
  [7412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5353),
  [7414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4124),
  [7416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4124),
  [7418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4123),
  [7420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1106),
  [7422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5404),
  [7424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5404),
  [7426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3978),
  [7428] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(5390),
  [7431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3675),
  [7433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5403),
  [7435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5403),
  [7437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3676),
  [7439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3851),
  [7441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5390),
  [7443] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(3760),
  [7446] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_type_identifier, 2, 0, 35), SHIFT(971),
  [7449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1791),
  [7451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5860),
  [7453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6120),
  [7455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4693),
  [7457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5657),
  [7459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6441),
  [7461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2528),
  [7463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3823),
  [7465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5367),
  [7467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5367),
  [7469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1201),
  [7471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4118),
  [7473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8151),
  [7475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4752),
  [7477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6482),
  [7479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2738),
  [7481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4286),
  [7483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6459),
  [7485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4291),
  [7487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4722),
  [7489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5991),
  [7491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5174),
  [7493] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5175),
  [7495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5176),
  [7497] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5018),
  [7499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8498),
  [7501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5148),
  [7503] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5050),
  [7505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5080),
  [7507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5311),
  [7509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5997),
  [7511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5109),
  [7513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5102),
  [7515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5212),
  [7517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5082),
  [7519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5432),
  [7521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5422),
  [7523] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4465),
  [7525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6479),
  [7527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4236),
  [7529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4326),
  [7531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6091),
  [7533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5164),
  [7535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5166),
  [7537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5167),
  [7539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4919),
  [7541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8476),
  [7543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5127),
  [7545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4222),
  [7547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6475),
  [7549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5999),
  [7551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5105),
  [7553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5107),
  [7555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5125),
  [7557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5069),
  [7559] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(7452),
  [7562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3971),
  [7564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5418),
  [7566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4022),
  [7568] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 1, 0, 23), SHIFT(5418),
  [7571] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_type_identifier, 2, 0, 35), SHIFT(981),
  [7574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4908),
  [7576] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4678),
  [7578] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4954),
  [7580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6053),
  [7582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5155),
  [7584] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5157),
  [7586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5158),
  [7588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5172),
  [7590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3996),
  [7592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5420),
  [7594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5420),
  [7596] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_pointer_declarator_repeat1, 2, 0, 0),
  [7598] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_pointer_declarator_repeat1, 2, 0, 0),
  [7600] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_pointer_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(4124),
  [7603] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_pointer_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(4123),
  [7606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5856),
  [7608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1197),
  [7610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2460),
  [7612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8656),
  [7614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4053),
  [7616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5503),
  [7618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5503),
  [7620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5323),
  [7622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5027),
  [7624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5027),
  [7626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5015),
  [7628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1089),
  [7630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5323),
  [7632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8455),
  [7634] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_pointer_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(4205),
  [7637] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_pointer_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(4203),
  [7640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(984),
  [7642] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_descriptor, 2, 0, 20),
  [7644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4878),
  [7646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8096),
  [7648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6917),
  [7650] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 1, 0, 56),
  [7652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4126),
  [7654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4126),
  [7656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8641),
  [7658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1550),
  [7660] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_descriptor, 1, 0, 2),
  [7662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4090),
  [7664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5554),
  [7666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5554),
  [7668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4472),
  [7670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4205),
  [7672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4203),
  [7674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8176),
  [7676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4091),
  [7678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5596),
  [7680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5596),
  [7682] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_type_identifier, 2, 0, 35), SHIFT(984),
  [7685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1696),
  [7687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3548),
  [7689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5328),
  [7691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4121),
  [7693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5695),
  [7695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5695),
  [7697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4123),
  [7699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3546),
  [7701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3547),
  [7703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6278),
  [7705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5337),
  [7707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4136),
  [7709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5642),
  [7711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5642),
  [7713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6272),
  [7715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6273),
  [7717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4146),
  [7719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5683),
  [7721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5683),
  [7723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2637),
  [7725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5342),
  [7727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4173),
  [7729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5733),
  [7731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5733),
  [7733] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2620),
  [7735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2621),
  [7737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4113),
  [7739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5714),
  [7741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5714),
  [7743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4140),
  [7745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5697),
  [7747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5697),
  [7749] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ms_unaligned_ptr_modifier, 1, 0, 0),
  [7751] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ms_unaligned_ptr_modifier, 1, 0, 0),
  [7753] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ms_pointer_modifier, 1, 0, 0),
  [7755] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ms_pointer_modifier, 1, 0, 0),
  [7757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5851),
  [7759] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_reference_declarator, 1, 0, 0),
  [7761] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_reference_declarator, 1, 0, 0),
  [7763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3403),
  [7765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5327),
  [7767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4130),
  [7769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5668),
  [7771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5668),
  [7773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3352),
  [7775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3401),
  [7777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4155),
  [7779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5650),
  [7781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5650),
  [7783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4141),
  [7785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5660),
  [7787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5660),
  [7789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4167),
  [7791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5707),
  [7793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5707),
  [7795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4017),
  [7797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1580),
  [7799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1594),
  [7801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1594),
  [7803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1598),
  [7805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1600),
  [7807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1604),
  [7809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1607),
  [7811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1485),
  [7813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1622),
  [7815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1623),
  [7817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1623),
  [7819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1624),
  [7821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1333),
  [7823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1627),
  [7825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1598),
  [7827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1600),
  [7829] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1607),
  [7831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1622),
  [7833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4177),
  [7835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5757),
  [7837] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5757),
  [7839] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_attributes_start, 1, 0, 0),
  [7841] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_attributes_start, 1, 0, 0),
  [7843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1198),
  [7845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1793),
  [7847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(981),
  [7849] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enumerator, 3, 0, 139),
  [7851] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerator, 3, 0, 139),
  [7853] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6647),
  [7855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5366),
  [7857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4227),
  [7859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5767),
  [7861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5767),
  [7863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6202),
  [7865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4211),
  [7867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5815),
  [7869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5815),
  [7871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4215),
  [7873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5777),
  [7875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5777),
  [7877] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_descriptor, 3, 0, 20),
  [7879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4312),
  [7881] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_descriptor, 2, 0, 2),
  [7883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5426),
  [7885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4311),
  [7887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4247),
  [7889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4386),
  [7891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5042),
  [7893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8141),
  [7895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5423),
  [7897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4510),
  [7899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5817),
  [7901] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1717),
  [7903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1716),
  [7905] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1716),
  [7907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1715),
  [7909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1714),
  [7911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1713),
  [7913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1712),
  [7915] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1711),
  [7917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1707),
  [7919] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1705),
  [7921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1705),
  [7923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1704),
  [7925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1892),
  [7927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1320),
  [7929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1699),
  [7931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1713),
  [7933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1711),
  [7935] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(4252),
  [7938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5391),
  [7940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5392),
  [7942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5391),
  [7944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5392),
  [7946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2152),
  [7948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2005),
  [7950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4257),
  [7952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5840),
  [7954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5840),
  [7956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1616),
  [7958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1614),
  [7960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1614),
  [7962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1613),
  [7964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1612),
  [7966] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1611),
  [7968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1470),
  [7970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1601),
  [7972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1596),
  [7974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1546),
  [7976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1546),
  [7978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1588),
  [7980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1334),
  [7982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1517),
  [7984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1611),
  [7986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1601),
  [7988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5074),
  [7990] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_range_loop_body, 4, 0, 188),
  [7992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1015),
  [7994] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(4297),
  [7997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(972),
  [7999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4503),
  [8001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4272),
  [8003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4504),
  [8005] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0),
  [8007] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0),
  [8009] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(4679),
  [8012] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(4679),
  [8015] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(8434),
  [8018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1148),
  [8020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(530),
  [8022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3836),
  [8024] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1957),
  [8027] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1957),
  [8030] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(8637),
  [8033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4252),
  [8035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4309),
  [8037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1210),
  [8039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3553),
  [8041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1538),
  [8043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1687),
  [8045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1686),
  [8047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1686),
  [8049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1685),
  [8051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1682),
  [8053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1788),
  [8055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1664),
  [8057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1660),
  [8059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1658),
  [8061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1656),
  [8063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1656),
  [8065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1632),
  [8067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6599),
  [8069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1338),
  [8071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1620),
  [8073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1788),
  [8075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1660),
  [8077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1172),
  [8079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2771),
  [8081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4739),
  [8083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4840),
  [8085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(992),
  [8087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1578),
  [8089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1576),
  [8091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1576),
  [8093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1574),
  [8095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1573),
  [8097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1571),
  [8099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1570),
  [8101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1568),
  [8103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1567),
  [8105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1564),
  [8107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1560),
  [8109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1560),
  [8111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1309),
  [8113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1763),
  [8115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1571),
  [8117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1568),
  [8119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4837),
  [8121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2422),
  [8123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3973),
  [8125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3682),
  [8127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1132),
  [8129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6404),
  [8131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4320),
  [8133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [8135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1075),
  [8137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6442),
  [8139] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comma_expression, 3, 0, 81),
  [8141] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bitfield_clause, 2, 0, 0),
  [8143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1996),
  [8145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [8147] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_declarator, 3, 0, 112),
  [8149] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_condition_declaration, 4, 0, 185),
  [8151] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_attributes_start, 2, 0, 0),
  [8153] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_attributes_start, 2, 0, 0),
  [8155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1321),
  [8157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3738),
  [8159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1139),
  [8161] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_declaration_repeat1, 4, 0, 175),
  [8163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2358),
  [8165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3658),
  [8167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3704),
  [8169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4207),
  [8171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1181),
  [8173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3719),
  [8175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1173),
  [8177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4816),
  [8179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1078),
  [8181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4740),
  [8183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3611),
  [8185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4369),
  [8187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5989),
  [8189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5989),
  [8191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3986),
  [8193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6463),
  [8195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1496),
  [8197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1496),
  [8199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4176),
  [8201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2775),
  [8203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3082),
  [8205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3980),
  [8207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3046),
  [8209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1174),
  [8211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3598),
  [8213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2238),
  [8215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3901),
  [8217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2235),
  [8219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2267),
  [8221] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_initializer_list_repeat1, 2, 0, 0), SHIFT(1369),
  [8224] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_initializer_list_repeat1, 2, 0, 0),
  [8226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1131),
  [8228] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_initializer_pair, 3, 0, 137), SHIFT(1369),
  [8231] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_initializer_pair, 3, 0, 137),
  [8233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3852),
  [8235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3315),
  [8237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [8239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2189),
  [8241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2342),
  [8243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1034),
  [8245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [8247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3754),
  [8249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4354),
  [8251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2388),
  [8253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(400),
  [8255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6575),
  [8257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2392),
  [8259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2201),
  [8261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4796),
  [8263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2813),
  [8265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3517),
  [8267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [8269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3039),
  [8271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1175),
  [8273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3981),
  [8275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3666),
  [8277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3089),
  [8279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2789),
  [8281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [8283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1178),
  [8285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2878),
  [8287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(962),
  [8289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4684),
  [8291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3801),
  [8293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(527),
  [8295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2822),
  [8297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1903),
  [8299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1637),
  [8301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1637),
  [8303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5996),
  [8305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7924),
  [8307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1602),
  [8309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1593),
  [8311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1592),
  [8313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1589),
  [8315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1582),
  [8317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1579),
  [8319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1575),
  [8321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1572),
  [8323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1572),
  [8325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1566),
  [8327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1337),
  [8329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1559),
  [8331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1589),
  [8333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1579),
  [8335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1351),
  [8337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1356),
  [8339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(545),
  [8341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [8343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1468),
  [8345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1482),
  [8347] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_subscript_argument_list_repeat1, 2, 0, 0),
  [8349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1011),
  [8351] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_initializer_pair, 3, 0, 138),
  [8353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6041),
  [8355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7872),
  [8357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1731),
  [8359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6038),
  [8361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8111),
  [8363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1609),
  [8365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6010),
  [8367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8069),
  [8369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1547),
  [8371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [8373] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_generic_expression_repeat1, 4, 0, 0),
  [8375] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declaration_repeat1, 4, 0, 198),
  [8377] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_definition_repeat1, 2, 0, 0),
  [8379] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_type_definition_repeat1, 2, 0, 0),
  [8381] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8655),
  [8384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1359),
  [8386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1551),
  [8388] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optional_parameter_declaration, 4, 0, 196),
  [8390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2274),
  [8392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8199),
  [8394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [8396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1630),
  [8398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6101),
  [8400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8154),
  [8402] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optional_parameter_declaration, 3, 0, 158),
  [8404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(451),
  [8406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1776),
  [8408] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 3, 0, 0),
  [8410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4515),
  [8412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4297),
  [8414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1591),
  [8416] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, 0, 0),
  [8418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4497),
  [8420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4498),
  [8422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1698),
  [8424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2351),
  [8426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_statement_body, 5, 1, 208),
  [8428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1540),
  [8430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(477),
  [8432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1801),
  [8434] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_lambda_capture_specifier_repeat1, 2, 0, 0),
  [8436] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(8375),
  [8439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6035),
  [8441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8349),
  [8443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1813),
  [8445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4844),
  [8447] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_statement_body, 4, 1, 189),
  [8449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_statement_body, 4, 1, 187),
  [8451] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_statement_body, 4, 1, 186),
  [8453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [8455] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_statement_body, 3, 1, 147),
  [8457] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_statement_body, 3, 1, 148),
  [8459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6020),
  [8461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7945),
  [8463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(440),
  [8465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1323),
  [8467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1790),
  [8469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(784),
  [8471] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_template_argument_list_repeat1, 2, 1, 0),
  [8473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3084),
  [8475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [8477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [8479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1934),
  [8481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8503),
  [8483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(803),
  [8485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(486),
  [8487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(485),
  [8489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2291),
  [8491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1848),
  [8493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2249),
  [8495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(483),
  [8497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3121),
  [8499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1845),
  [8501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5857),
  [8503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6163),
  [8505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3412),
  [8507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(723),
  [8509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3431),
  [8511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [8513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [8515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5321),
  [8517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [8519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3854),
  [8521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [8523] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__for_range_loop_body, 5, 0, 209),
  [8525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [8527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3833),
  [8529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3837),
  [8531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4452),
  [8533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7088),
  [8535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3839),
  [8537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3846),
  [8539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2407),
  [8541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3866),
  [8543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [8545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3191),
  [8547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(796),
  [8549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2705),
  [8551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2091),
  [8553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2430),
  [8555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2144),
  [8557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(663),
  [8559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2133),
  [8561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3671),
  [8563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2151),
  [8565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5736),
  [8567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(590),
  [8569] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unary_left_fold, 3, 0, 55),
  [8571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [8573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2929),
  [8575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [8577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7227),
  [8579] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binary_fold, 3, 0, 82),
  [8581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(622),
  [8583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4691),
  [8585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1053),
  [8587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1055),
  [8589] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(8637),
  [8592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1048),
  [8594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7210),
  [8596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [8598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4956),
  [8600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [8602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(800),
  [8604] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23),
  [8606] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(7756),
  [8609] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_declarator_seq, 2, 0, 23),
  [8611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [8613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [8615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3302),
  [8617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4850),
  [8619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4849),
  [8621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3803),
  [8623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1963),
  [8625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6782),
  [8627] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__assignment_expression_lhs, 3, 0, 55),
  [8629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(514),
  [8631] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(5933),
  [8634] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(5397),
  [8637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(437),
  [8639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(434),
  [8641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2051),
  [8643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(432),
  [8645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4081),
  [8647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2733),
  [8649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4518),
  [8651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [8653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7074),
  [8655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(573),
  [8657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2088),
  [8659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2548),
  [8661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2472),
  [8663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(984),
  [8665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5395),
  [8667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5880),
  [8669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6148),
  [8671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5396),
  [8673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2197),
  [8675] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(8375),
  [8678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4859),
  [8680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4857),
  [8682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4861),
  [8684] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_pointer_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(5027),
  [8687] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_pointer_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(5027),
  [8690] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_pointer_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(5015),
  [8693] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23),
  [8695] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(7756),
  [8698] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_declarator_seq, 3, 0, 23),
  [8700] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(5933),
  [8703] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(5397),
  [8706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5844),
  [8708] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_parameter_list, 2, 0, 0), REDUCE(sym_argument_list, 2, 0, 0),
  [8711] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(4472),
  [8714] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(8176),
  [8717] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(6097),
  [8720] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(5407),
  [8723] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(5394),
  [8726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2357),
  [8728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7151),
  [8730] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_declaration, 1, 0, 0),
  [8732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5216),
  [8734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2378),
  [8736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5843),
  [8738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5848),
  [8740] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(4472),
  [8743] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(8176),
  [8746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5865),
  [8748] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(5411),
  [8751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4071),
  [8753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6505),
  [8755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6080),
  [8757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5194),
  [8759] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5198),
  [8761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5203),
  [8763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5218),
  [8765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3513),
  [8767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6489),
  [8769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6049),
  [8771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5214),
  [8773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5211),
  [8775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5210),
  [8777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5162),
  [8779] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(5390),
  [8782] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2573),
  [8784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6497),
  [8786] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2557),
  [8788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2667),
  [8790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6078),
  [8792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5145),
  [8794] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5144),
  [8796] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5065),
  [8798] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2650),
  [8800] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8413),
  [8802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5206),
  [8804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2863),
  [8806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6464),
  [8808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2785),
  [8810] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2940),
  [8812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6070),
  [8814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5163),
  [8816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5170),
  [8818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5171),
  [8820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3253),
  [8822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8490),
  [8824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5143),
  [8826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3528),
  [8828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6451),
  [8830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3545),
  [8832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3813),
  [8834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6082),
  [8836] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5179),
  [8838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5182),
  [8840] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5183),
  [8842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4106),
  [8844] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8504),
  [8846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5149),
  [8848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2774),
  [8850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6486),
  [8852] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2748),
  [8854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2919),
  [8856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6030),
  [8858] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5153),
  [8860] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5154),
  [8862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5169),
  [8864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3177),
  [8866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8380),
  [8868] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5071),
  [8870] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(8375),
  [8873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5850),
  [8875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2926),
  [8877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6485),
  [8879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2897),
  [8881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3083),
  [8883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6055),
  [8885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5152),
  [8887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5151),
  [8889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5139),
  [8891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3530),
  [8893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8458),
  [8895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5094),
  [8897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2544),
  [8899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2545),
  [8901] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2683),
  [8903] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6042),
  [8905] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5221),
  [8907] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_specifier, 1, 0, 0), SHIFT(1199),
  [8910] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(6097),
  [8913] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(5407),
  [8916] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_definition_type, 2, 0, 20),
  [8918] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_definition_type, 2, 0, 20),
  [8920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5083),
  [8922] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_definition_type, 1, 0, 2),
  [8924] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_definition_type, 1, 0, 2),
  [8926] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(5394),
  [8929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2234),
  [8931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2486),
  [8933] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 2), SHIFT(2197),
  [8936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6189),
  [8938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6461),
  [8940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6003),
  [8942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5093),
  [8944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5096),
  [8946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5097),
  [8948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5205),
  [8950] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 1, 0, 0), SHIFT(5092),
  [8953] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 1, 0, 0), SHIFT(5098),
  [8956] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 1, 0, 0), SHIFT(5085),
  [8959] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(7452),
  [8962] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, -1, 18), SHIFT(2197),
  [8965] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 20), SHIFT(5134),
  [8968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4769),
  [8970] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, -1, 36), SHIFT(5136),
  [8973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4299),
  [8975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6458),
  [8977] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_sized_type_specifier, 2, 0, 0), REDUCE(aux_sym_sized_type_specifier_repeat1, 2, 0, 0), SHIFT(2197),
  [8981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4186),
  [8983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2372),
  [8985] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(5411),
  [8988] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 3, 0, 20), SHIFT(2197),
  [8991] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_sized_type_specifier, 3, -1, 36), SHIFT(2197),
  [8994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2982),
  [8996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2867),
  [8998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2888),
  [9000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4358),
  [9002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3714),
  [9004] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 2, 0, 23), SHIFT(5418),
  [9007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4086),
  [9009] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(5323),
  [9012] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(5323),
  [9015] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__type_definition_type_repeat1, 2, 0, 0), SHIFT_REPEAT(8455),
  [9018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3871),
  [9020] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(5390),
  [9023] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23),
  [9025] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(7756),
  [9028] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_declarator_seq, 4, 0, 23),
  [9030] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(5933),
  [9033] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(5397),
  [9036] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_definition_type, 3, 0, 20),
  [9038] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_definition_type, 3, 0, 20),
  [9040] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type_specifier, 1, 0, 0), SHIFT(5075),
  [9043] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__type_definition_type, 2, 0, 2),
  [9045] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_definition_type, 2, 0, 2),
  [9047] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(8375),
  [9050] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(7452),
  [9053] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 3, 0, 23), SHIFT(5418),
  [9056] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(7452),
  [9059] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(5394),
  [9062] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(6097),
  [9065] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(5407),
  [9068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [9070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1167),
  [9072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4841),
  [9074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6909),
  [9076] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(5411),
  [9079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [9081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1150),
  [9083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3869),
  [9085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6970),
  [9087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [9089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1159),
  [9091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2783),
  [9093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6773),
  [9095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [9097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1162),
  [9099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3718),
  [9101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7001),
  [9103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [9105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1158),
  [9107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4248),
  [9109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6809),
  [9111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4241),
  [9113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [9115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1155),
  [9117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3526),
  [9119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6760),
  [9121] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(5390),
  [9124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1543),
  [9126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1736),
  [9128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2102),
  [9130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [9132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1098),
  [9134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1222),
  [9136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7650),
  [9138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1876),
  [9140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [9142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1204),
  [9144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7680),
  [9146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2014),
  [9148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [9150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1223),
  [9152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7753),
  [9154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1208),
  [9156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5849),
  [9158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1217),
  [9160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5719),
  [9162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6847),
  [9164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1219),
  [9166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6169),
  [9168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4251),
  [9170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3561),
  [9172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5893),
  [9174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4305),
  [9176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4757),
  [9178] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5700),
  [9180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1211),
  [9182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6339),
  [9184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6908),
  [9186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6124),
  [9188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5720),
  [9190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1207),
  [9192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3699),
  [9194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3700),
  [9196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1221),
  [9198] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3556),
  [9200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1987),
  [9202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6501),
  [9204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1961),
  [9206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1224),
  [9208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5762),
  [9210] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6952),
  [9212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1212),
  [9214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2791),
  [9216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2692),
  [9218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7233),
  [9220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2762),
  [9222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5876),
  [9224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5781),
  [9226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1083),
  [9228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8564),
  [9230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5413),
  [9232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7411),
  [9234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(892),
  [9236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2389),
  [9238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7301),
  [9240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2200),
  [9242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5779),
  [9244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6304),
  [9246] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(7452),
  [9249] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 4, 0, 23), SHIFT(5418),
  [9252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1218),
  [9254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3832),
  [9256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4235),
  [9258] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__preproc_expression, 1, 0, 0),
  [9260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5505),
  [9262] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__preproc_expression, 1, 0, 0),
  [9264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5934),
  [9266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3557),
  [9268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2213),
  [9270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3935),
  [9272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6478),
  [9274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7139),
  [9276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5469),
  [9278] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [9280] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ref_qualifier, 1, 0, 0),
  [9282] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ref_qualifier, 1, 0, 0),
  [9284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5425),
  [9286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5658),
  [9288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5572),
  [9290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7504),
  [9292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5604),
  [9294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5604),
  [9296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5506),
  [9298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7102),
  [9300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8666),
  [9302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5487),
  [9304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5598),
  [9306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5585),
  [9308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5640),
  [9310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5584),
  [9312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5584),
  [9314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5579),
  [9316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5583),
  [9318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5573),
  [9320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5564),
  [9322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5559),
  [9324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5558),
  [9326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5555),
  [9328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5555),
  [9330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5546),
  [9332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8035),
  [9334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5557),
  [9336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5486),
  [9338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5712),
  [9340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5441),
  [9342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5634),
  [9344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7505),
  [9346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5637),
  [9348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5637),
  [9350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5667),
  [9352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7421),
  [9354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5656),
  [9356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5734),
  [9358] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_unary_expression, 2, 0, 4),
  [9360] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_unary_expression, 2, 0, 4),
  [9362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5670),
  [9364] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declarator_seq, 5, 0, 23),
  [9366] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_declarator_seq, 5, 0, 23),
  [9368] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_defined, 2, 0, 0),
  [9370] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_defined, 2, 0, 0),
  [9372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2087),
  [9374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2173),
  [9376] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_call_expression, 2, 0, 7),
  [9378] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_call_expression, 2, 0, 7),
  [9380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5710),
  [9382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5601),
  [9384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5725),
  [9386] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_defined, 4, 0, 0),
  [9388] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_defined, 4, 0, 0),
  [9390] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_attributes_end, 2, 0, 0),
  [9392] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_attributes_end, 2, 0, 0),
  [9394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5713),
  [9396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5611),
  [9398] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_argument_list, 2, 0, 0),
  [9400] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_argument_list, 2, 0, 0),
  [9402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5618),
  [9404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5620),
  [9406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2425),
  [9408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8000),
  [9410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5560),
  [9412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7280),
  [9414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3169),
  [9416] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 5, 0, 23), SHIFT(5933),
  [9419] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 5, 0, 23), SHIFT(5397),
  [9422] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_attributes_end, 1, 0, 0),
  [9424] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_attributes_end, 1, 0, 0),
  [9426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5629),
  [9428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5671),
  [9430] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_binary_expression, 3, 0, 55),
  [9432] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_binary_expression, 3, 0, 55),
  [9434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5663),
  [9436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2413),
  [9438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7377),
  [9440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5677),
  [9442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5567),
  [9444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2464),
  [9446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8020),
  [9448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5574),
  [9450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7206),
  [9452] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3192),
  [9454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1120),
  [9456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5578),
  [9458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7258),
  [9460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5617),
  [9462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5655),
  [9464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5627),
  [9466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5591),
  [9468] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_argument_list, 3, 0, 0),
  [9470] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_argument_list, 3, 0, 0),
  [9472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5672),
  [9474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_argument_list_repeat1, 2, 0, 0),
  [9476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5694),
  [9478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2396),
  [9480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8253),
  [9482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5594),
  [9484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7426),
  [9486] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3221),
  [9488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5716),
  [9490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5592),
  [9492] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_argument_list, 4, 0, 0),
  [9494] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_argument_list, 4, 0, 0),
  [9496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2577),
  [9498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7158),
  [9500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5537),
  [9502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3160),
  [9504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7854),
  [9506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5605),
  [9508] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7029),
  [9510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3154),
  [9512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5699),
  [9514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1129),
  [9516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5607),
  [9518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7367),
  [9520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5691),
  [9522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5685),
  [9524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5701),
  [9526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5680),
  [9528] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_parenthesized_expression, 3, 0, 0),
  [9530] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_parenthesized_expression, 3, 0, 0),
  [9532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5684),
  [9534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5686),
  [9536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3317),
  [9538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5623),
  [9540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7355),
  [9542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3148),
  [9544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5624),
  [9546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7255),
  [9548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3228),
  [9550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2411),
  [9552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5625),
  [9554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7164),
  [9556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1877),
  [9558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2645),
  [9560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5628),
  [9562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7392),
  [9564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5743),
  [9566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5715),
  [9568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5703),
  [9570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5679),
  [9572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3130),
  [9574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5636),
  [9576] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7099),
  [9578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5666),
  [9580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5706),
  [9582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1114),
  [9584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5639),
  [9586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7321),
  [9588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5615),
  [9590] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6024),
  [9592] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7200),
  [9594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(945),
  [9596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6467),
  [9598] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_noexcept, 1, 0, 0),
  [9600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1398),
  [9602] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_noexcept, 1, 0, 0),
  [9604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(168),
  [9606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6457),
  [9608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [9610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5606),
  [9612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5622),
  [9614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5633),
  [9616] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5638),
  [9618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5631),
  [9620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5613),
  [9622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5609),
  [9624] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5608),
  [9626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5544),
  [9628] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5593),
  [9630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [9632] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_throw_specifier, 3, 0, 0),
  [9634] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_throw_specifier, 3, 0, 0),
  [9636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6363),
  [9638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6488),
  [9640] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_noexcept, 3, 0, 0),
  [9642] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_noexcept, 3, 0, 0),
  [9644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(139),
  [9646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6456),
  [9648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [9650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [9652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6325),
  [9654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [9656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [9658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5614),
  [9660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6525),
  [9662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7339),
  [9664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5681),
  [9666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5943),
  [9668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(175),
  [9670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6476),
  [9672] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declarator_seq, 6, 0, 23),
  [9674] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_declarator_seq, 6, 0, 23),
  [9676] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 6, 0, 23), SHIFT(5933),
  [9679] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 6, 0, 23), SHIFT(5397),
  [9682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5388),
  [9684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5401),
  [9686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6271),
  [9688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [9690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5969),
  [9692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [9694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_throw_specifier, 5, 0, 0),
  [9696] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_throw_specifier, 5, 0, 0),
  [9698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(169),
  [9700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6472),
  [9702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [9704] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_throw_specifier, 4, 0, 0),
  [9706] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_throw_specifier, 4, 0, 0),
  [9708] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6998),
  [9710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5730),
  [9712] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7436),
  [9714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6343),
  [9716] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_noexcept, 4, 0, 0),
  [9718] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_noexcept, 4, 0, 0),
  [9720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [9722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1787),
  [9724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1914),
  [9726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [9728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1094),
  [9730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1353),
  [9732] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(7756),
  [9735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6506),
  [9737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5993),
  [9739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6699),
  [9741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1476),
  [9743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [9745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [9747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7776),
  [9749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1651),
  [9751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [9753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7499),
  [9755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6009),
  [9757] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_attributes_end, 3, 0, 0),
  [9759] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_attributes_end, 3, 0, 0),
  [9761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1633),
  [9763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2025),
  [9765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [9767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1511),
  [9769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [9771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [9773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7443),
  [9775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6060),
  [9777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1521),
  [9779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2182),
  [9781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [9783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1732),
  [9785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(428),
  [9787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [9789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7811),
  [9791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6007),
  [9793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5417),
  [9795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5412),
  [9797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1255),
  [9799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [9801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [9803] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 5, 0, 23), SHIFT(6097),
  [9806] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 5, 0, 23), SHIFT(5407),
  [9809] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_postfix, 1, 0, 0),
  [9811] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_postfix, 1, 0, 0),
  [9813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [9815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6220),
  [9817] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_clobber_list, 1, 0, 0),
  [9819] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__function_postfix_repeat1, 2, 0, 0),
  [9821] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__function_postfix_repeat1, 2, 0, 0),
  [9823] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__function_postfix_repeat1, 2, 0, 0), SHIFT_REPEAT(5933),
  [9826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [9828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [9830] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(5794),
  [9833] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(6857),
  [9836] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_concatenated_string_repeat1, 2, 0, 0), SHIFT_REPEAT(7473),
  [9839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [9841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [9843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [9845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [9847] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 6, 0, 23), SHIFT(6097),
  [9850] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 6, 0, 23), SHIFT(5407),
  [9853] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5834),
  [9855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6857),
  [9857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7473),
  [9859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5794),
  [9861] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 5, 0, 23), SHIFT(5394),
  [9864] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__function_postfix_repeat1, 2, 0, 0), SHIFT_REPEAT(6097),
  [9867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2222),
  [9869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2237),
  [9871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4549),
  [9873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2669),
  [9875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4220),
  [9877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4365),
  [9879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4543),
  [9881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4869),
  [9883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4953),
  [9885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5147),
  [9887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5398),
  [9889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4020),
  [9891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2807),
  [9893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2921),
  [9895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3262),
  [9897] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8226),
  [9900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6114),
  [9902] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6706),
  [9904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3555),
  [9906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2519),
  [9908] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_descriptor, 2, 0, 39),
  [9910] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1091),
  [9912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3476),
  [9914] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3669),
  [9916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2920),
  [9918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2975),
  [9920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2546),
  [9922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2686),
  [9924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2717),
  [9926] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2862),
  [9928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4456),
  [9930] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_pointer_declarator, 2, 1, 5),
  [9932] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_reference_declarator, 2, 0, 0),
  [9934] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_pointer_declarator, 4, 1, 84),
  [9936] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__class_declaration_repeat1, 2, 0, 0),
  [9938] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__class_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(8173),
  [9941] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__class_declaration_repeat1, 2, 0, 0),
  [9943] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__class_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(8376),
  [9946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2523),
  [9948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2623),
  [9950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5387),
  [9952] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_descriptor, 4, 0, 129),
  [9954] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_descriptor, 3, 0, 80),
  [9956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4244),
  [9958] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4496),
  [9960] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_pointer_declarator, 3, 1, 41),
  [9962] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_descriptor, 3, 0, 62),
  [9964] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_declarator, 3, 1, 41),
  [9966] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_trailing_return_type, 2, 0, 0),
  [9968] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_trailing_return_type, 2, 0, 0),
  [9970] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_parenthesized_declarator, 3, 0, 0),
  [9972] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_parenthesized_declarator, 3, 0, 0),
  [9974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5427),
  [9976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5430),
  [9978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2691),
  [9980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6146),
  [9982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6673),
  [9984] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_declarator, 5, 1, 167),
  [9986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6544),
  [9988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6662),
  [9990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6714),
  [9992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5632),
  [9994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8092),
  [9996] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_array_declarator, 3, 0, 121),
  [9998] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_array_declarator, 3, 0, 121),
  [10000] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_array_declarator, 3, 0, 0),
  [10002] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_array_declarator, 3, 0, 0),
  [10004] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_array_declarator, 3, 0, 26),
  [10006] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_array_declarator, 3, 0, 26),
  [10008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6174),
  [10010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6680),
  [10012] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_function_declarator, 2, 0, 24),
  [10014] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_function_declarator, 2, 0, 24),
  [10016] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_array_declarator, 2, 0, 0),
  [10018] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_array_declarator, 2, 0, 0),
  [10020] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_parenthesized_declarator, 4, 0, 0),
  [10022] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_parenthesized_declarator, 4, 0, 0),
  [10024] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_array_declarator, 4, 0, 171),
  [10026] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_array_declarator, 4, 0, 171),
  [10028] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_array_declarator, 4, 0, 116),
  [10030] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_array_declarator, 4, 0, 116),
  [10032] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_array_declarator, 4, 0, 26),
  [10034] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_array_declarator, 4, 0, 26),
  [10036] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_array_declarator, 5, 0, 169),
  [10038] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_array_declarator, 5, 0, 169),
  [10040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1360),
  [10042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1005),
  [10044] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_virtual_specifier, 1, 0, 0),
  [10046] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_virtual_specifier, 1, 0, 0),
  [10048] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abstract_function_declarator, 1, 0, 33),
  [10050] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abstract_function_declarator, 1, 0, 33),
  [10052] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reference_declarator, 2, 1, 0),
  [10054] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__abstract_declarator, 1, 0, 0),
  [10056] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__abstract_declarator, 1, 0, 0),
  [10058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6630),
  [10060] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_declarator, 2, 1, 5),
  [10062] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_declaration_repeat1, 2, 0, 5),
  [10064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1350),
  [10066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1688),
  [10068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1645),
  [10070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3311),
  [10072] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 5, 0, 23), SHIFT(5411),
  [10075] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_enumerator_list, 3, 0, 78),
  [10077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3463),
  [10079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6131),
  [10081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6688),
  [10083] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elifdef_in_enumerator_list, 2, 0, 10),
  [10085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1349),
  [10087] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_declarator, 4, 1, 84),
  [10089] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_declarator_seq, 7, 0, 23),
  [10091] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_declarator_seq, 7, 0, 23),
  [10093] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 6, 0, 23), SHIFT(5394),
  [10096] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6194),
  [10098] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_field_declarator, 5, 1, 167),
  [10100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6192),
  [10102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6196),
  [10104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6152),
  [10106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2023),
  [10108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [10110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7042),
  [10112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6993),
  [10114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6200),
  [10116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1917),
  [10118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [10120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7195),
  [10122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6842),
  [10124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1093),
  [10126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2123),
  [10128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [10130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7269),
  [10132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6799),
  [10134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(638),
  [10136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7133),
  [10138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6926),
  [10140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(688),
  [10142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7322),
  [10144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6770),
  [10146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(648),
  [10148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(613),
  [10150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6206),
  [10152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [10154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7207),
  [10156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6845),
  [10158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6190),
  [10160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(738),
  [10162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7429),
  [10164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6975),
  [10166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6186),
  [10168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(765),
  [10170] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 5, 0, 23), SHIFT(5390),
  [10173] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_field_declarator, 4, 1, 84),
  [10175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6221),
  [10177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6224),
  [10179] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_field_declarator, 2, 1, 5),
  [10181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6193),
  [10183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6229),
  [10185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6199),
  [10187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6213),
  [10189] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reference_field_declarator, 2, 1, 0),
  [10191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6219),
  [10193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6209),
  [10195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [10197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2012),
  [10199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6195),
  [10201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6207),
  [10203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6223),
  [10205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6218),
  [10207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6155),
  [10209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6222),
  [10211] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 6, 0, 23), SHIFT(5411),
  [10214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1931),
  [10216] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declaration_repeat1, 2, 0, 5),
  [10218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1554),
  [10220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2070),
  [10222] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_field_declarator, 3, 1, 41),
  [10224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8074),
  [10226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7107),
  [10228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5619),
  [10230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7860),
  [10232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2285),
  [10234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3333),
  [10236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2616),
  [10238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4085),
  [10240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5402),
  [10242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2944),
  [10244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3227),
  [10246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4094),
  [10248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7904),
  [10250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3174),
  [10252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3477),
  [10254] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 5, 0, 23), SHIFT(5418),
  [10257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3469),
  [10259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3445),
  [10261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6696),
  [10263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6142),
  [10265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6724),
  [10267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8084),
  [10269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7976),
  [10271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2678),
  [10273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8193),
  [10275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4967),
  [10277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6610),
  [10279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8330),
  [10281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4912),
  [10283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8317),
  [10285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2459),
  [10287] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attributed_declarator, 2, 0, 0),
  [10289] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attributed_declarator, 2, 0, 0),
  [10291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4945),
  [10293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3133),
  [10295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5400),
  [10297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3108),
  [10299] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 6, 0, 23), SHIFT(5390),
  [10302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2596),
  [10304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4960),
  [10306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2278),
  [10308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2936),
  [10310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2457),
  [10312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1100),
  [10314] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__field_declarator, 1, 0, 100),
  [10316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(967),
  [10318] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__field_declarator, 1, 0, 100),
  [10320] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributed_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(7479),
  [10323] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attributed_field_declarator, 2, 0, 0),
  [10325] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attributed_field_declarator, 2, 0, 0),
  [10327] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 2, 0, 66),
  [10329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8641),
  [10331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1606),
  [10333] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__field_declarator, 1, 0, 0),
  [10335] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__field_declarator, 1, 0, 0),
  [10337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1506),
  [10339] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declarator, 2, 1, 24),
  [10341] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_function_declarator, 2, 1, 24), SHIFT(8641),
  [10344] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_declarator, 2, 1, 24),
  [10346] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_declarator, 4, -10, 0),
  [10348] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_declarator, 4, -10, 0),
  [10350] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_declarator, 4, 0, 116),
  [10352] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_declarator, 4, 0, 116),
  [10354] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enumerator_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7107),
  [10357] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enumerator_list_repeat1, 2, 0, 0), SHIFT_REPEAT(5612),
  [10360] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enumerator_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8105),
  [10363] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enumerator_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7442),
  [10366] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enumerator_list_repeat1, 2, 0, 0),
  [10368] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6552),
  [10370] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6480),
  [10372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6510),
  [10374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6455),
  [10376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6398),
  [10378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6431),
  [10380] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_semantics, 2, 0, 0),
  [10382] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_semantics, 2, 0, 0),
  [10384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6642),
  [10386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6855),
  [10388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5538),
  [10390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8283),
  [10392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6637),
  [10394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8359),
  [10396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6863),
  [10398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5536),
  [10400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8289),
  [10402] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elifdef_in_enumerator_list_no_comma, 2, 0, 10),
  [10404] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_field_declarator, 2, 1, 24),
  [10406] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_field_declarator, 2, 1, 24),
  [10408] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_declarator, 3, 0, 26),
  [10410] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_declarator, 3, 0, 26),
  [10412] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_enumerator_list, 4, 0, 78),
  [10414] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_structured_binding_declarator, 3, -1, 0),
  [10416] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_structured_binding_declarator, 3, -1, 0),
  [10418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5399),
  [10420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5431),
  [10422] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_field_declarator, 3, 0, 26),
  [10424] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_field_declarator, 3, 0, 26),
  [10426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_field_declarator, 3, -10, 0),
  [10428] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_field_declarator, 3, -10, 0),
  [10430] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_enumerator_list_no_comma, 4, 0, 78),
  [10432] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6435),
  [10434] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_declarator, 4, 0, 26),
  [10436] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_declarator, 4, 0, 26),
  [10438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6392),
  [10440] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6551),
  [10442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6470),
  [10444] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__function_declarator_seq, 6, 0, 23), SHIFT(5418),
  [10447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6558),
  [10449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6491),
  [10451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6516),
  [10453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6500),
  [10455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6666),
  [10457] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_enumerator_list_no_comma, 3, 0, 78),
  [10459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elifdef_in_enumerator_list_no_comma, 3, 0, 10),
  [10461] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elifdef_in_enumerator_list, 3, 0, 10),
  [10463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6665),
  [10465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8286),
  [10467] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_field_declarator, 4, 0, 26),
  [10469] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_field_declarator, 4, 0, 26),
  [10471] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_declarator, 3, -10, 0),
  [10473] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_declarator, 3, -10, 0),
  [10475] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_field_declarator, 4, 0, 116),
  [10477] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_field_declarator, 4, 0, 116),
  [10479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6549),
  [10481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6498),
  [10483] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declarator, 3, 1, 24),
  [10485] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_declarator, 3, 1, 24),
  [10487] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_field_declarator, 5, 0, 169),
  [10489] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_field_declarator, 5, 0, 169),
  [10491] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_structured_binding_declarator, 4, -1, 0),
  [10493] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_structured_binding_declarator, 4, -1, 0),
  [10495] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_declarator, 5, 0, 169),
  [10497] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_declarator, 5, 0, 169),
  [10499] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_field_declarator, 4, -10, 0),
  [10501] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_field_declarator, 4, -10, 0),
  [10503] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6507),
  [10505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6474),
  [10507] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__scope_resolution, 1, 0, 0),
  [10509] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__scope_resolution, 1, 0, 0),
  [10511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1659),
  [10513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4984),
  [10515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1510),
  [10517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4988),
  [10519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1700),
  [10521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5016),
  [10523] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1514),
  [10525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5022),
  [10527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1512),
  [10529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5005),
  [10531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1625),
  [10533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4985),
  [10535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5845),
  [10537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1802),
  [10539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5008),
  [10541] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_input_operand_list, 1, 0, 0),
  [10543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8322),
  [10545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1670),
  [10547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5004),
  [10549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1494),
  [10551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1764),
  [10553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5688),
  [10555] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_definition_declarators, 1, 0, 26),
  [10557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1750),
  [10559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5009),
  [10561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1577),
  [10563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2945),
  [10565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6481),
  [10567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1724),
  [10569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1734),
  [10571] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_output_operand_list, 1, 0, 0),
  [10573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8229),
  [10575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7235),
  [10577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6959),
  [10579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8267),
  [10581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4202),
  [10583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7507),
  [10585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2359),
  [10587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7783),
  [10589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7156),
  [10591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8579),
  [10593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3767),
  [10595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7477),
  [10597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6781),
  [10599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6695),
  [10601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8302),
  [10603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6844),
  [10605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(138),
  [10607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7675),
  [10609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(167),
  [10611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7821),
  [10613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6203),
  [10615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7808),
  [10617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4413),
  [10619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7484),
  [10621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2899),
  [10623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7488),
  [10625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7179),
  [10627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8569),
  [10629] = {.entry = {.count = 1, .reusable = false}}, SHIFT(944),
  [10631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7493),
  [10633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6961),
  [10635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(173),
  [10637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7500),
  [10639] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7010),
  [10641] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4285),
  [10643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(174),
  [10645] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7743),
  [10647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2242),
  [10649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7687),
  [10651] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6800),
  [10653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2927),
  [10655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7511),
  [10657] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4736),
  [10659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7628),
  [10661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7111),
  [10663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2993),
  [10665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7539),
  [10667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2857),
  [10669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7593),
  [10671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__type_definition_declarators_repeat1, 2, 0, 5),
  [10673] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6239),
  [10675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3913),
  [10677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6777),
  [10679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6886),
  [10681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7020),
  [10683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7188),
  [10685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8036),
  [10687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7431),
  [10689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2469),
  [10691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7717),
  [10693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6898),
  [10695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6902),
  [10697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6803),
  [10699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1988),
  [10701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7583),
  [10703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6916),
  [10705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7379),
  [10707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4092),
  [10709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(726),
  [10711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3975),
  [10713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(700),
  [10715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3929),
  [10717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1322),
  [10719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6351),
  [10721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1890),
  [10723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3943),
  [10725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [10727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(600),
  [10729] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_cast, 3, 0, 58),
  [10731] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__scope_resolution, 2, 0, 15),
  [10733] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__scope_resolution, 2, 0, 15),
  [10735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(792),
  [10737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [10739] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_enumerator_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7107),
  [10742] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_enumerator_list_repeat1, 2, 0, 0),
  [10744] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_enumerator_list_repeat1, 2, 0, 0),
  [10746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6233),
  [10748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6312),
  [10750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(697),
  [10752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(646),
  [10754] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__scope_resolution, 2, 0, 31),
  [10756] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__scope_resolution, 2, 0, 31),
  [10758] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumerator, 1, 0, 6),
  [10760] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enumerator, 1, 0, 6),
  [10762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1643),
  [10764] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1, 2, 0, 0), SHIFT_REPEAT(6544),
  [10767] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1, 2, 0, 0),
  [10769] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1, 2, 0, 0),
  [10771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [10773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3924),
  [10775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2156),
  [10777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3947),
  [10779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(692),
  [10781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3884),
  [10783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(788),
  [10785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(657),
  [10787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6364),
  [10789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2134),
  [10791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3916),
  [10793] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1, 1, 0, 0),
  [10795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6663),
  [10797] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_enumerator_list_no_comma_repeat1, 1, 0, 0),
  [10799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1608),
  [10801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1302),
  [10803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7891),
  [10805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2658),
  [10807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3448),
  [10809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7314),
  [10811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7332),
  [10813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3478),
  [10815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3551),
  [10817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6232),
  [10819] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_capture_specifier, 4, 0, 0),
  [10821] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_capture_specifier, 4, 0, 0),
  [10823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3543),
  [10825] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_capture_specifier, 5, 0, 0),
  [10827] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_capture_specifier, 5, 0, 0),
  [10829] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_initializer_pair_repeat1, 2, 0, 0), SHIFT_REPEAT(1608),
  [10832] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_initializer_pair_repeat1, 2, 0, 0),
  [10834] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_initializer_pair_repeat1, 2, 0, 0), SHIFT_REPEAT(7891),
  [10837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6369),
  [10839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7061),
  [10841] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_capture_specifier, 6, 0, 0),
  [10843] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_capture_specifier, 6, 0, 0),
  [10845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2627),
  [10847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7123),
  [10849] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_enumerator_list, 5, 0, 126),
  [10851] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if_in_enumerator_list, 5, 0, 126),
  [10853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2183),
  [10855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1679),
  [10857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5966),
  [10859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6957),
  [10861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5984),
  [10863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5911),
  [10865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2086),
  [10867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1809),
  [10869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5940),
  [10871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [10873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1742),
  [10875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(627),
  [10877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1527),
  [10879] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_enumerator_list, 4, 0, 78),
  [10881] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if_in_enumerator_list, 4, 0, 78),
  [10883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(795),
  [10885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1507),
  [10887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5981),
  [10889] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_gnu_asm_expression_repeat1, 2, 0, 0),
  [10891] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_gnu_asm_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(6957),
  [10894] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_enumerator_list_repeat1, 2, 0, 0),
  [10896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2186),
  [10898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1584),
  [10900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1850),
  [10902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1523),
  [10904] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_enumerator_list, 5, 0, 78),
  [10906] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if_in_enumerator_list, 5, 0, 78),
  [10908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5935),
  [10910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1599),
  [10912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [10914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1495),
  [10916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5908),
  [10918] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_enumerator_list, 6, 0, 176),
  [10920] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if_in_enumerator_list, 6, 0, 176),
  [10922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1505),
  [10924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5937),
  [10926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5913),
  [10928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5978),
  [10930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(809),
  [10932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1782),
  [10934] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef_in_enumerator_list, 5, 0, 127),
  [10936] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef_in_enumerator_list, 5, 0, 127),
  [10938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5963),
  [10940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2063),
  [10942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1675),
  [10944] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef_in_enumerator_list, 4, 0, 79),
  [10946] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef_in_enumerator_list, 4, 0, 79),
  [10948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(684),
  [10950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1690),
  [10952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5910),
  [10954] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef_in_enumerator_list, 3, 0, 10),
  [10956] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef_in_enumerator_list, 3, 0, 10),
  [10958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1838),
  [10960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1535),
  [10962] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef_in_enumerator_list, 4, 0, 10),
  [10964] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_ifdef_in_enumerator_list, 4, 0, 10),
  [10966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(631),
  [10968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1756),
  [10970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5938),
  [10972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5922),
  [10974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(639),
  [10976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1674),
  [10978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2168),
  [10980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7735),
  [10982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1929),
  [10984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1927),
  [10986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7022),
  [10988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7822),
  [10990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1932),
  [10992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7786),
  [10994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6086),
  [10996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6093),
  [10998] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optional_type_parameter_declaration, 4, 0, 195),
  [11000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5916),
  [11002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7788),
  [11004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1891),
  [11006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1888),
  [11008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1884),
  [11010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1853),
  [11012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1842),
  [11014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6718),
  [11016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5892),
  [11018] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_access_specifier, 1, 0, 0),
  [11020] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_access_specifier, 1, 0, 0),
  [11022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2163),
  [11024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1995),
  [11026] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7658),
  [11028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2153),
  [11030] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7572),
  [11032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2124),
  [11034] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7573),
  [11036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2032),
  [11038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2027),
  [11040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2155),
  [11042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2121),
  [11044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2000),
  [11046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2120),
  [11048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2003),
  [11050] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_else_in_enumerator_list, 1, 0, 0),
  [11052] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optional_type_parameter_declaration, 3, 0, 157),
  [11054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2019),
  [11056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2020),
  [11058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7062),
  [11060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2176),
  [11062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2030),
  [11064] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 1, 0, 6),
  [11066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7968),
  [11068] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7671),
  [11070] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__type_definition_declarators_repeat1, 2, 0, 114), SHIFT_REPEAT(5688),
  [11073] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__type_definition_declarators_repeat1, 2, 0, 114),
  [11075] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_qualified_operator_cast_identifier, 2, 0, 34),
  [11077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7830),
  [11079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [11081] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_char_literal_repeat1, 2, 0, 0),
  [11083] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_char_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(6731),
  [11086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [11088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2629),
  [11090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2628),
  [11092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2688),
  [11094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6738),
  [11096] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6738),
  [11098] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0),
  [11100] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(6738),
  [11103] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(6738),
  [11106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1909),
  [11108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7331),
  [11110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8087),
  [11112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3922),
  [11114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2681),
  [11116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6737),
  [11118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6737),
  [11120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2995),
  [11122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7011),
  [11124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7011),
  [11126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7704),
  [11128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3966),
  [11130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1126),
  [11132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3087),
  [11134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3829),
  [11136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [11138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [11140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3830),
  [11142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6751),
  [11144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6751),
  [11146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [11148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3977),
  [11150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3043),
  [11152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3892),
  [11154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1816),
  [11156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3949),
  [11158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2714),
  [11160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2734),
  [11162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6765),
  [11164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6765),
  [11166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2609),
  [11168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2208),
  [11170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3857),
  [11172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3858),
  [11174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6772),
  [11176] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6772),
  [11178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2383),
  [11180] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__namespace_specifier, 1, 0, 19),
  [11182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6704),
  [11184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7181),
  [11186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5761),
  [11188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_base_class_clause, 4, 0, 0),
  [11190] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2707),
  [11192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1123),
  [11194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6702),
  [11196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3058),
  [11198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3885),
  [11200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7035),
  [11202] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2715),
  [11204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6779),
  [11206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6779),
  [11208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3956),
  [11210] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2728),
  [11212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3468),
  [11214] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6731),
  [11216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3664),
  [11218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1037),
  [11220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2855),
  [11222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [11224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2859),
  [11226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6792),
  [11228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6792),
  [11230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(643),
  [11232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5682),
  [11234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6405),
  [11236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1857),
  [11238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3925),
  [11240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5962),
  [11242] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_clobber_list, 2, 0, 211),
  [11244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2690),
  [11246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6838),
  [11248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6838),
  [11250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3878),
  [11252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6806),
  [11254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6806),
  [11256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6518),
  [11258] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_input_operand_list, 3, 0, 192),
  [11260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4683),
  [11262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2162),
  [11264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8114),
  [11266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [11268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8220),
  [11270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [11272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2804),
  [11274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3081),
  [11276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3800),
  [11278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1032),
  [11280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1033),
  [11282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2747),
  [11284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6786),
  [11286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6786),
  [11288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2767),
  [11290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6822),
  [11292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6822),
  [11294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3809),
  [11296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2680),
  [11298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [11300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7563),
  [11302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7582),
  [11304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1902),
  [11306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(549),
  [11308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6008),
  [11310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1147),
  [11312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3407),
  [11314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7665),
  [11316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7666),
  [11318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_else_in_enumerator_list, 2, 0, 0),
  [11320] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_else_in_enumerator_list_no_comma, 2, 0, 0),
  [11322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [11324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3937),
  [11326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5994),
  [11328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6846),
  [11330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6846),
  [11332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(401),
  [11334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4662),
  [11336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2558),
  [11338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6895),
  [11340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6895),
  [11342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(465),
  [11344] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_else_in_enumerator_list_no_comma, 1, 0, 0),
  [11346] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_gnu_asm_input_operand_list_repeat1, 2, 0, 210), SHIFT_REPEAT(6518),
  [11349] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_gnu_asm_input_operand_list_repeat1, 2, 0, 210),
  [11351] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 3, 0, 91),
  [11353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2105),
  [11355] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7940),
  [11357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7824),
  [11359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7637),
  [11361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(756),
  [11363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8131),
  [11365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1137),
  [11367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7690),
  [11369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7703),
  [11371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2244),
  [11373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7014),
  [11375] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_base_class_clause, 5, 0, 0),
  [11377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3859),
  [11379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2050),
  [11381] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__type_definition_declarators, 2, 0, 87),
  [11383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3093),
  [11385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2879),
  [11387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4228),
  [11389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1017),
  [11391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(415),
  [11393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2565),
  [11395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [11397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(619),
  [11399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8480),
  [11401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6681),
  [11403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7414),
  [11405] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_base_class_clause, 2, 0, 0),
  [11407] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_declaration_repeat1, 2, 0, 184), SHIFT_REPEAT(5817),
  [11410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_declaration_repeat1, 2, 0, 184),
  [11412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3952),
  [11414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1169),
  [11416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [11418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [11420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(446),
  [11422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2366),
  [11424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2918),
  [11426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6891),
  [11428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6891),
  [11430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6677),
  [11432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7357),
  [11434] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variadic_declarator, 1, 0, 0),
  [11436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2380),
  [11438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5586),
  [11440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [11442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3927),
  [11444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2426),
  [11446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2187),
  [11448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2129),
  [11450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2128),
  [11452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2142),
  [11454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8576),
  [11456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7720),
  [11458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7799),
  [11460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(505),
  [11462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2400),
  [11464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7427),
  [11466] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_base_class_clause, 3, 0, 0),
  [11468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [11470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4237),
  [11472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6531),
  [11474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_output_operand_list, 3, 0, 192),
  [11476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2043),
  [11478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1079),
  [11480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1153),
  [11482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3552),
  [11484] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4037),
  [11486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(652),
  [11488] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7845),
  [11490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4489),
  [11492] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_qualifier, 1, 0, 0),
  [11494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8628),
  [11496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6937),
  [11498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6937),
  [11500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2130),
  [11502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2379),
  [11504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6918),
  [11506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6918),
  [11508] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_input_operand_list, 2, 0, 153),
  [11510] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_gnu_asm_output_operand_list_repeat1, 2, 0, 210), SHIFT_REPEAT(6531),
  [11513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_gnu_asm_output_operand_list_repeat1, 2, 0, 210),
  [11515] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_gnu_asm_clobber_list_repeat1, 2, 0, 222), SHIFT_REPEAT(5962),
  [11518] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_gnu_asm_clobber_list_repeat1, 2, 0, 222),
  [11520] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3511),
  [11522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6953),
  [11524] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6953),
  [11526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(417),
  [11528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4014),
  [11530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6954),
  [11532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6954),
  [11534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2394),
  [11536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6995),
  [11538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6995),
  [11540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2068),
  [11542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2067),
  [11544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3969),
  [11546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7762),
  [11548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7769),
  [11550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2048),
  [11552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(493),
  [11554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [11556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3519),
  [11558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2393),
  [11560] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_clobber_list, 3, 0, 218),
  [11562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2874),
  [11564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2662),
  [11566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1882),
  [11568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1916),
  [11570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1846),
  [11572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [11574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2979),
  [11576] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_output_operand_list, 2, 0, 153),
  [11578] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_base_class_clause, 6, 0, 0),
  [11580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7761),
  [11582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3490),
  [11584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4790),
  [11586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5788),
  [11588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4789),
  [11590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7532),
  [11592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1010),
  [11594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7647),
  [11596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4776),
  [11598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6394),
  [11600] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_nested_namespace_specifier, 2, 0, 0),
  [11602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6676),
  [11604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [11606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7556),
  [11608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1928),
  [11610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4775),
  [11612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3972),
  [11614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5722),
  [11616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3457),
  [11618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2770),
  [11620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6588),
  [11622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6360),
  [11624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3632),
  [11626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4181),
  [11628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3047),
  [11630] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__namespace_specifier, 2, 0, 59),
  [11632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2881),
  [11634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7731),
  [11636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1815),
  [11638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3533),
  [11640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1840),
  [11642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1841),
  [11644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7966),
  [11646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7964),
  [11648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7959),
  [11650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7765),
  [11652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1081),
  [11654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1082),
  [11656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1077),
  [11658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2923),
  [11660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2875),
  [11662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2915),
  [11664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4763),
  [11666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6438),
  [11668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4762),
  [11670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3599),
  [11672] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_repeat1, 2, 0, 114), SHIFT_REPEAT(5074),
  [11675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declaration_repeat1, 2, 0, 114),
  [11677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1893),
  [11679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5738),
  [11681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6889),
  [11683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1179),
  [11685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3501),
  [11687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(906),
  [11689] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_output_operand, 7, 0, 226),
  [11691] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_gnu_asm_goto_list_repeat1, 2, 0, 225), SHIFT_REPEAT(8599),
  [11694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_gnu_asm_goto_list_repeat1, 2, 0, 225),
  [11696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4798),
  [11698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4799),
  [11700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(540),
  [11702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4625),
  [11704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7804),
  [11706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8599),
  [11708] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_goto_list, 3, 0, 223),
  [11710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6946),
  [11712] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript_range_designator, 5, 0, 204),
  [11714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3523),
  [11716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7512),
  [11718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4038),
  [11720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7521),
  [11722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1825),
  [11724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8235),
  [11726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3492),
  [11728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1030),
  [11730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(999),
  [11732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2721),
  [11734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1330),
  [11736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6607),
  [11738] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_gnu_asm_clobber_list_repeat1, 2, 0, 211),
  [11740] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_input_operand, 4, 0, 217),
  [11742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1124),
  [11744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1127),
  [11746] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_generic_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(3973),
  [11749] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_generic_expression_repeat1, 2, 0, 0),
  [11751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7878),
  [11753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3773),
  [11755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1119),
  [11757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1076),
  [11759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2033),
  [11761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3510),
  [11763] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_nested_namespace_specifier, 3, 0, 0),
  [11765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3245),
  [11767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4807),
  [11769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3734),
  [11771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6919),
  [11773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3629),
  [11775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3640),
  [11777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3707),
  [11779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3506),
  [11781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1605),
  [11783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3331),
  [11785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(876),
  [11787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3740),
  [11789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3737),
  [11791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2401),
  [11793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3960),
  [11795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1171),
  [11797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5858),
  [11799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2125),
  [11801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2126),
  [11803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2361),
  [11805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2223),
  [11807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3635),
  [11809] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 2, 0, 56),
  [11811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3481),
  [11813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2402),
  [11815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2398),
  [11817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2397),
  [11819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7601),
  [11821] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_initializer, 2, 0, 100),
  [11823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7913),
  [11825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7914),
  [11827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7915),
  [11829] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variadic_parameter_declaration, 2, 0, 66),
  [11831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4034),
  [11833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2236),
  [11835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7624),
  [11837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2167),
  [11839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6554),
  [11841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2243),
  [11843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2248),
  [11845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7598),
  [11847] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_initializer, 2, 0, 0),
  [11849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3710),
  [11851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3712),
  [11853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2776),
  [11855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1004),
  [11857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6859),
  [11859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7619),
  [11861] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variadic_type_parameter_declaration, 2, 0, 0),
  [11863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [11865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1117),
  [11867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1128),
  [11869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7777),
  [11871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(618),
  [11873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5478),
  [11875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6650),
  [11877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1116),
  [11879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3288),
  [11881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3287),
  [11883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4036),
  [11885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3442),
  [11887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6302),
  [11889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(436),
  [11891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5852),
  [11893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(435),
  [11895] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_goto_list, 2, 0, 219),
  [11897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4033),
  [11899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2362),
  [11901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2245),
  [11903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7551),
  [11905] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_base_class_clause_repeat1, 3, 0, 0),
  [11907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3757),
  [11909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1138),
  [11911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4721),
  [11913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(715),
  [11915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7518),
  [11917] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_base_class_clause_repeat1, 4, 0, 0),
  [11919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3057),
  [11921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [11923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1142),
  [11925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1144),
  [11927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1143),
  [11929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(662),
  [11931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8269),
  [11933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7710),
  [11935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7589),
  [11937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3471),
  [11939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2746),
  [11941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6579),
  [11943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8041),
  [11945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8049),
  [11947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8050),
  [11949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7836),
  [11951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3962),
  [11953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6149),
  [11955] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_initializer_list, 3, 0, 0),
  [11957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6164),
  [11959] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attribute_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(7761),
  [11962] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_attribute_declaration_repeat1, 2, 0, 0),
  [11964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [11966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3305),
  [11968] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_gnu_asm_input_operand_list_repeat1, 2, 0, 153),
  [11970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3761),
  [11972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8181),
  [11974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8178),
  [11976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8174),
  [11978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2829),
  [11980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7672),
  [11982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [11984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [11986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [11988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [11990] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1210),
  [11993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(449),
  [11995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(450),
  [11997] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_params_repeat1, 2, 0, 0), SHIFT_REPEAT(7710),
  [12000] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_params_repeat1, 2, 0, 0),
  [12002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6612),
  [12004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7604),
  [12006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2806),
  [12008] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_argument_list_repeat1, 2, 0, 0), SHIFT_REPEAT(5598),
  [12011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2808),
  [12013] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_input_operand, 7, 0, 226),
  [12015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3437),
  [12017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2713),
  [12019] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_output_operand, 4, 0, 217),
  [12021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2216),
  [12023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2823),
  [12025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6722),
  [12027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2827),
  [12029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [12031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4008),
  [12033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [12035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [12037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [12039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [12041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(501),
  [12043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1177),
  [12045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [12047] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_subscript_argument_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1321),
  [12050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6837),
  [12052] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_initializer_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1185),
  [12055] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_initializer_list_repeat1, 2, 0, 0), SHIFT_REPEAT(6149),
  [12058] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_initializer_list_repeat1, 2, 0, 0),
  [12060] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_declaration_repeat1, 3, 0, 5),
  [12062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7555),
  [12064] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_declaration_repeat1, 3, 0, 205),
  [12066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [12068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3923),
  [12070] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_structured_binding_declarator_repeat1, 2, 0, 0), SHIFT_REPEAT(7927),
  [12073] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_structured_binding_declarator_repeat1, 2, 0, 0),
  [12075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3337),
  [12077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2833),
  [12079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3474),
  [12081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2852),
  [12083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3932),
  [12085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [12087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3945),
  [12089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6409),
  [12091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6436),
  [12093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6434),
  [12095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6433),
  [12097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [12099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1002),
  [12101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8127),
  [12103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8130),
  [12105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8133),
  [12107] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_base_class_clause, 7, 0, 0),
  [12109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7502),
  [12111] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_base_class_clause_repeat1, 5, 0, 0),
  [12113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3641),
  [12115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7795),
  [12117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5599),
  [12119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5727),
  [12121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2225),
  [12123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3685),
  [12125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3575),
  [12127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3722),
  [12129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7827),
  [12131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3418),
  [12133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7441),
  [12135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3674),
  [12137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3677),
  [12139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3678),
  [12141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3730),
  [12143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3769),
  [12145] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_parameter_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1815),
  [12148] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameter_list_repeat1, 2, 0, 0),
  [12150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7446),
  [12152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7447),
  [12154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(422),
  [12156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1125),
  [12158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1122),
  [12160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2045),
  [12162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7448),
  [12164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6720),
  [12166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2420),
  [12168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2421),
  [12170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2423),
  [12172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7454),
  [12174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2384),
  [12176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2381),
  [12178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2385),
  [12180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2387),
  [12182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2830),
  [12184] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_initializer_list, 2, 0, 0),
  [12186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7586),
  [12188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_base_class_clause_repeat1, 2, 0, 0),
  [12190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3994),
  [12192] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_requires_parameter_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1825),
  [12195] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_requires_parameter_list_repeat1, 2, 0, 0),
  [12197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3944),
  [12199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6994),
  [12201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(504),
  [12203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3918),
  [12205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3473),
  [12207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8407),
  [12209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8406),
  [12211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8403),
  [12213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [12215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3910),
  [12217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2192),
  [12219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2210),
  [12221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2191),
  [12223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2202),
  [12225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1176),
  [12227] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_base_class_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(5761),
  [12230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7335),
  [12232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7471),
  [12234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4794),
  [12236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3564),
  [12238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7709),
  [12240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6956),
  [12242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3899),
  [12244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3896),
  [12246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6606),
  [12248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(506),
  [12250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3049),
  [12252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3051),
  [12254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3053),
  [12256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3054),
  [12258] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_template_parameter_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1330),
  [12261] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_template_parameter_list_repeat1, 2, 0, 0),
  [12263] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_declaration, 3, 0, 66),
  [12265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [12267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2365),
  [12269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2367),
  [12271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2371),
  [12273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3586),
  [12275] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variadic_reference_declarator, 2, 0, 0),
  [12277] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variadic_declarator, 2, 0, 0),
  [12279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7455),
  [12281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3069),
  [12283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3062),
  [12285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3027),
  [12287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3060),
  [12289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7476),
  [12291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6892),
  [12293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1182),
  [12295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3585),
  [12297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6848),
  [12299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [12301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [12303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [12305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [12307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(904),
  [12309] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_throw_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(3972),
  [12312] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_throw_specifier_repeat1, 2, 0, 0),
  [12314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6640),
  [12316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6823),
  [12318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(959),
  [12320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(961),
  [12322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(957),
  [12324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(948),
  [12326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2730),
  [12328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3999),
  [12330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4682),
  [12332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4681),
  [12334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4676),
  [12336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4675),
  [12338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2750),
  [12340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2217),
  [12342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3817),
  [12344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3816),
  [12346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3820),
  [12348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3825),
  [12350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7453),
  [12352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2010),
  [12354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2047),
  [12356] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_designator, 2, 0, 95),
  [12358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3444),
  [12360] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_declarator, 2, 0, 68),
  [12362] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_condition_declaration, 3, 0, 143),
  [12364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [12366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [12368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1180),
  [12370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7634),
  [12372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3322),
  [12374] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6787),
  [12376] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_template_argument_list_repeat1, 2, 0, 0), SHIFT_REPEAT(992),
  [12379] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_template_argument_list_repeat1, 2, 0, 0),
  [12381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2414),
  [12383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7456),
  [12385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7693),
  [12387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2375),
  [12389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3993),
  [12391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6801),
  [12393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2834),
  [12395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7482),
  [12397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_template_argument_list_repeat1, 2, 3, 0),
  [12399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4024),
  [12401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3240),
  [12403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7552),
  [12405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8668),
  [12407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8670),
  [12409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8672),
  [12411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2171),
  [12413] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_lambda_capture_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(1538),
  [12416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7197),
  [12418] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_gnu_asm_output_operand_list_repeat1, 2, 0, 153),
  [12420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1031),
  [12422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6634),
  [12424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(707),
  [12426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8559),
  [12428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6723),
  [12430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8519),
  [12432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8699),
  [12434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7400),
  [12436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8150),
  [12438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(971),
  [12440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8517),
  [12442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8698),
  [12444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8515),
  [12446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8697),
  [12448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8513),
  [12450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8696),
  [12452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8511),
  [12454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8695),
  [12456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8509),
  [12458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8694),
  [12460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8507),
  [12462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8693),
  [12464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(982),
  [12466] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_params, 2, 0, 0),
  [12468] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_params, 2, 0, 0),
  [12470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8505),
  [12472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8692),
  [12474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8500),
  [12476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8691),
  [12478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8492),
  [12480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8690),
  [12482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7460),
  [12484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8482),
  [12486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8689),
  [12488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8465),
  [12490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8687),
  [12492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7465),
  [12494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8445),
  [12496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8684),
  [12498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7470),
  [12500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(659),
  [12502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8577),
  [12504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8422),
  [12506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8681),
  [12508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7474),
  [12510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8393),
  [12512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8678),
  [12514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_gnu_asm_goto_list_repeat1, 2, 0, 219),
  [12516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(983),
  [12518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7483),
  [12520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8260),
  [12522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8264),
  [12524] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_base_class_clause_repeat1, 6, 0, 0),
  [12526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5540),
  [12528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8622),
  [12530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5674),
  [12532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8116),
  [12534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7536),
  [12536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7491),
  [12538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1346),
  [12540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4083),
  [12542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4974),
  [12544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8205),
  [12546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8675),
  [12548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7169),
  [12550] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_gnu_asm_goto_list, 1, 0, 0),
  [12552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(681),
  [12554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8390),
  [12556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7497),
  [12558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1780),
  [12560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [12562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2467),
  [12564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7410),
  [12566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8395),
  [12568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(589),
  [12570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(975),
  [12572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7506),
  [12574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [12576] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8266),
  [12578] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_params, 4, 0, 0),
  [12580] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_params, 4, 0, 0),
  [12582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7740),
  [12584] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_initializer, 3, 0, 0),
  [12586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3202),
  [12588] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_initializer, 3, 0, 100),
  [12590] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_template_parameter_declaration, 3, 0, 57),
  [12592] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variadic_type_parameter_declaration, 3, 0, 156),
  [12594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [12596] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8148),
  [12598] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_template_argument_list_repeat1, 2, 2, 0),
  [12600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7533),
  [12602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2064),
  [12604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8099),
  [12606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4911),
  [12608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3107),
  [12610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(817),
  [12612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8652),
  [12614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [12616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2057),
  [12618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8138),
  [12620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7566),
  [12622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7623),
  [12624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(977),
  [12626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3417),
  [12628] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 4, 0, 91),
  [12630] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_params, 3, 0, 0),
  [12632] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_params, 3, 0, 0),
  [12634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7590),
  [12636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7196),
  [12638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8613),
  [12640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7828),
  [12642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2292),
  [12644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1922),
  [12646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8053),
  [12648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2042),
  [12650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8034),
  [12652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2165),
  [12654] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7954),
  [12656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7615),
  [12658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7043),
  [12660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8624),
  [12662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1856),
  [12664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7990),
  [12666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 2, 0, 6),
  [12668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2601),
  [12670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7659),
  [12672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [12674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2951),
  [12676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7428),
  [12678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8210),
  [12680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7250),
  [12682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8539),
  [12684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7487),
  [12686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(608),
  [12688] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7866),
  [12690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7725),
  [12692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(812),
  [12694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(629),
  [12696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7918),
  [12698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_pack_expansion, 2, 0, 28),
  [12700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8082),
  [12702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2906),
  [12704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(881),
  [12706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1016),
  [12708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2990),
  [12710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(630),
  [12712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8110),
  [12714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(880),
  [12716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1027),
  [12718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3151),
  [12720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1043),
  [12722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3906),
  [12724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3544),
  [12726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3893),
  [12728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8090),
  [12730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3883),
  [12732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5897),
  [12734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3881),
  [12736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1326),
  [12738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(804),
  [12740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(844),
  [12742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [12744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(658),
  [12746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [12748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8072),
  [12750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(810),
  [12752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(801),
  [12754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8232),
  [12756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1050),
  [12758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1045),
  [12760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3489),
  [12762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [12764] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_requires_parameter_list, 3, 0, 0),
  [12766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8195),
  [12768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6867),
  [12770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [12772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7404),
  [12774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(947),
  [12776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3831),
  [12778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2991),
  [12780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8008),
  [12782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4802),
  [12784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4797),
  [12786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2066),
  [12788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3004),
  [12790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4003),
  [12792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2024),
  [12794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3220),
  [12796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8172),
  [12798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2039),
  [12800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4774),
  [12802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(564),
  [12804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(565),
  [12806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(567),
  [12808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7897),
  [12810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(612),
  [12812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6757),
  [12814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(551),
  [12816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [12818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2058),
  [12820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2061),
  [12822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7958),
  [12824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7670),
  [12826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(574),
  [12828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1925),
  [12830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4760),
  [12832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1319),
  [12834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1012),
  [12836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [12838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3166),
  [12840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [12842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(882),
  [12844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(878),
  [12846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7931),
  [12848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2170),
  [12850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1113),
  [12852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(847),
  [12854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(655),
  [12856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7844),
  [12858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8240),
  [12860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2360),
  [12862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2670),
  [12864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(578),
  [12866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(580),
  [12868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2081),
  [12870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(855),
  [12872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7903),
  [12874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7975),
  [12876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2108),
  [12878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7911),
  [12880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [12882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6817),
  [12884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(829),
  [12886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2116),
  [12888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7902),
  [12890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6866),
  [12892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6955),
  [12894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [12896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3946),
  [12898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1112),
  [12900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7842),
  [12902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2656),
  [12904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(667),
  [12906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4773),
  [12908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1946),
  [12910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1073),
  [12912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3164),
  [12914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2695),
  [12916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3900),
  [12918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3895),
  [12920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4214),
  [12922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2011),
  [12924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1862),
  [12926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2008),
  [12928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2501),
  [12930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1313),
  [12932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [12934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3796),
  [12936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7916),
  [12938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3797),
  [12940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4110),
  [12942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3798),
  [12944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3743),
  [12946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1070),
  [12948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7853),
  [12950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3989),
  [12952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(439),
  [12954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7949),
  [12956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7879),
  [12958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(852),
  [12960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2586),
  [12962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(447),
  [12964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(448),
  [12966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4129),
  [12968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2814),
  [12970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4278),
  [12972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7971),
  [12974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8219),
  [12976] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__fold_operator, 1, 0, 0), SHIFT(8224),
  [12979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4277),
  [12981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4268),
  [12983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7981),
  [12985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1301),
  [12987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6740),
  [12989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2107),
  [12991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(913),
  [12993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3711),
  [12995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3596),
  [12997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1843),
  [12999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [13001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [13003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [13005] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elifdef, 3, 0, 79),
  [13007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [13009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2809),
  [13011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8051),
  [13013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1864),
  [13015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8039),
  [13017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1867),
  [13019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8057),
  [13021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2618),
  [13023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3670),
  [13025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [13027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2797),
  [13029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [13031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8073),
  [13033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2041),
  [13035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2040),
  [13037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(595),
  [13039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2038),
  [13041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2034),
  [13043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2028),
  [13045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1886),
  [13047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2026),
  [13049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2021),
  [13051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2538),
  [13053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2403),
  [13055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [13057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2281),
  [13059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2013),
  [13061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1998),
  [13063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8098),
  [13065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2001),
  [13067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6816),
  [13069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3672),
  [13071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2606),
  [13073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1868),
  [13075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2006),
  [13077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2009),
  [13079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1921),
  [13081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7444),
  [13083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [13085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2766),
  [13087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2031),
  [13089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5974),
  [13091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2036),
  [13093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6659),
  [13095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8282),
  [13097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8135),
  [13099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7485),
  [13101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2391),
  [13103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2161),
  [13105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1315),
  [13107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [13109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1949),
  [13111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(866),
  [13113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1937),
  [13115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6338),
  [13117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8157),
  [13119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(870),
  [13121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1956),
  [13123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2576),
  [13125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [13127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [13129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [13131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2059),
  [13133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2984),
  [13135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8651),
  [13137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2828),
  [13139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [13141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8197),
  [13143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1061),
  [13145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2103),
  [13147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4939),
  [13149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(687),
  [13151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2080),
  [13153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8254),
  [13155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [13157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8265),
  [13159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2084),
  [13161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8124),
  [13163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7838),
  [13165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2118),
  [13167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2122),
  [13169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8396),
  [13171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [13173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [13175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8436),
  [13177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2095),
  [13179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [13181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8446),
  [13183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [13185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(673),
  [13187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [13189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8530),
  [13191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8534),
  [13193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8548),
  [13195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2143),
  [13197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8585),
  [13199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8587),
  [13201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4015),
  [13203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8610),
  [13205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8617),
  [13207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8627),
  [13209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8632),
  [13211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8633),
  [13213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8636),
  [13215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8700),
  [13217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8648),
  [13219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8658),
  [13221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8660),
  [13223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8662),
  [13225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8664),
  [13227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2119),
  [13229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8188),
  [13231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7445),
  [13233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [13235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8685),
  [13237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1036),
  [13239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [13241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [13243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4133),
  [13245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3882),
  [13247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [13249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1403),
  [13251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3472),
  [13253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1352),
  [13255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3152),
  [13257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2836),
  [13259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(895),
  [13261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2056),
  [13263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(874),
  [13265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3998),
  [13267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7514),
  [13269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4027),
  [13271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8542),
  [13273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8676),
  [13275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [13277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3772),
  [13279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1590),
  [13281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2185),
  [13283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1504),
  [13285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8527),
  [13287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3781),
  [13289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4122),
  [13291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [13293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1335),
  [13295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5654),
  [13297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8321),
  [13299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4347),
  [13301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5745),
  [13303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5744),
  [13305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [13307] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__unary_right_fold, 3, 0, 55),
  [13309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [13311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6964),
  [13313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1074),
  [13315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8345),
  [13317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4099),
  [13319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8305),
  [13321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8331),
  [13323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3497),
  [13325] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_requires_parameter_list, 4, 0, 0),
  [13327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [13329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8272),
  [13331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(905),
  [13333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3283),
  [13335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1650),
  [13337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [13339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(717),
  [13341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3365),
  [13343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8245),
  [13345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3764),
  [13347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2788),
  [13349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2779),
  [13351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2778),
  [13353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8343),
  [13355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1343),
  [13357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8339),
  [13359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2917),
  [13361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [13363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1899),
  [13365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [13367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [13369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8316),
  [13371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [13373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8117),
  [13375] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif, 4, 0, 126),
  [13377] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elifdef, 4, 0, 127),
  [13379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6619),
  [13381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8347),
  [13383] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef_in_enumerator_list_no_comma, 4, 0, 79),
  [13385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6291),
  [13387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6654),
  [13389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1889),
  [13391] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef_in_enumerator_list_no_comma, 4, 0, 10),
  [13393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8414),
  [13395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6276),
  [13397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2140),
  [13399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2148),
  [13401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2154),
  [13403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1795),
  [13405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2160),
  [13407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2164),
  [13409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(843),
  [13411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7036),
  [13413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6667),
  [13415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3550),
  [13417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1854),
  [13419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1852),
  [13421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3642),
  [13423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1847),
  [13425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1920),
  [13427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1923),
  [13429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1859),
  [13431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1861),
  [13433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2759),
  [13435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(554),
  [13437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1880),
  [13439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1885),
  [13441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8484),
  [13443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8485),
  [13445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1895),
  [13447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1701),
  [13449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1912),
  [13451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [13453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3597),
  [13455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1837),
  [13457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(767),
  [13459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3649),
  [13461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1910),
  [13463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5818),
  [13465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5810),
  [13467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5808),
  [13469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7873),
  [13471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(563),
  [13473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(861),
  [13475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7876),
  [13477] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif, 5, 0, 176),
  [13479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8328),
  [13481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ms_based_modifier, 2, 0, 0),
  [13483] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_enumerator_list_no_comma, 5, 0, 126),
  [13485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2722),
  [13487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [13489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7956),
  [13491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(535),
  [13493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(934),
  [13495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [13497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(588),
  [13499] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_requires_parameter_list, 2, 0, 0),
  [13501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6644),
  [13503] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_enumerator_list_no_comma, 5, 0, 78),
  [13505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3500),
  [13507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8494),
  [13509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [13511] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elifdef_in_enumerator_list, 3, 0, 79),
  [13513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4210),
  [13515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1879),
  [13517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(736),
  [13519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elifdef_in_enumerator_list_no_comma, 3, 0, 79),
  [13521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3247),
  [13523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7781),
  [13525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7791),
  [13527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1051),
  [13529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [13531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3919),
  [13533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1878),
  [13535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1409),
  [13537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(894),
  [13539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4996),
  [13541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1318),
  [13543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(603),
  [13545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(605),
  [13547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7825),
  [13549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8274),
  [13551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5550),
  [13553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(606),
  [13555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1489),
  [13557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7846),
  [13559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4172),
  [13561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [13563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8382),
  [13565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1930),
  [13567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1072),
  [13569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7858),
  [13571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2180),
  [13573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8420),
  [13575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(624),
  [13577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7869),
  [13579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1519),
  [13581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(625),
  [13583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(626),
  [13585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7807),
  [13587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1035),
  [13589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3921),
  [13591] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elifdef_in_field_declaration_list, 3, 0, 79),
  [13593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1461),
  [13595] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_ifdef_in_enumerator_list_no_comma, 5, 0, 127),
  [13597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7778),
  [13599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7939),
  [13601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2177),
  [13603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2463),
  [13605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1799),
  [13607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7946),
  [13609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2190),
  [13611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7960),
  [13613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3568),
  [13615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(903),
  [13617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(835),
  [13619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(837),
  [13621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7967),
  [13623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1665),
  [13625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2175),
  [13627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7750),
  [13629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1008),
  [13631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3974),
  [13633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6054),
  [13635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1378),
  [13637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2178),
  [13639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [13641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7733),
  [13643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8004),
  [13645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2169),
  [13647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(522),
  [13649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1744),
  [13651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8010),
  [13653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6083),
  [13655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8022),
  [13657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2076),
  [13659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8028),
  [13661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1726),
  [13663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7713),
  [13665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1029),
  [13667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3958),
  [13669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1412),
  [13671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7948),
  [13673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8055),
  [13675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1491),
  [13677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8061),
  [13679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8591),
  [13681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7837),
  [13683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2273),
  [13685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2268),
  [13687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8079),
  [13689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1558),
  [13691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7678),
  [13693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1428),
  [13695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(679),
  [13697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(682),
  [13699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1811),
  [13701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8106),
  [13703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4132),
  [13705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7230),
  [13707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6658),
  [13709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8121),
  [13711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3992),
  [13713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7649),
  [13715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1400),
  [13717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3077),
  [13719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8132),
  [13721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5026),
  [13723] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_enumerator_list_no_comma, 6, 0, 176),
  [13725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8136),
  [13727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7640),
  [13729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1363),
  [13731] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_enumerator_list, 4, 0, 126),
  [13733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8144),
  [13735] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_enumerator_list_no_comma, 4, 0, 126),
  [13737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8147),
  [13739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7636),
  [13741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1374),
  [13743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8152),
  [13745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8153),
  [13747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8155),
  [13749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8156),
  [13751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8158),
  [13753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8159),
  [13755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8160),
  [13757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8161),
  [13759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8162),
  [13761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8163),
  [13763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8164),
  [13765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8165),
  [13767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8166),
  [13769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8167),
  [13771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8168),
  [13773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8169),
  [13775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7165),
  [13777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6309),
  [13779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [13781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1642),
  [13783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8204),
  [13785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8348),
  [13787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elifdef_in_enumerator_list, 4, 0, 127),
  [13789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8645),
  [13791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elifdef_in_enumerator_list_no_comma, 4, 0, 127),
  [13793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2838),
  [13795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1741),
  [13797] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_field_declaration_list, 4, 0, 126),
  [13799] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elifdef_in_field_declaration_list, 4, 0, 127),
  [13801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(481),
  [13803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [13805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1071),
  [13807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8360),
  [13809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6785),
  [13811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8241),
  [13813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(862),
  [13815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2711),
  [13817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(864),
  [13819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2846),
  [13821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3654),
  [13823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3655),
  [13825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3656),
  [13827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1341),
  [13829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2158),
  [13831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2157),
  [13833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(708),
  [13835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(475),
  [13837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(474),
  [13839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [13841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3472),
  [13843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3454),
  [13845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3618),
  [13847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3617),
  [13849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3616),
  [13851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1331),
  [13853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3615),
  [13855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1348),
  [13857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4012),
  [13859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(665),
  [13861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1342),
  [13863] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_enumerator_list, 5, 0, 176),
  [13865] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_enumerator_list_no_comma, 5, 0, 176),
  [13867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3207),
  [13869] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [13871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3862),
  [13873] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_field_declaration_list, 5, 0, 176),
  [13875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3865),
  [13877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8293),
  [13879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1661),
  [13881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1781),
  [13883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8600),
  [13885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1783),
  [13887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [13889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1399),
  [13891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [13893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3818),
  [13895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [13897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7496),
  [13899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7063),
  [13901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1678),
  [13903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3942),
  [13905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3941),
  [13907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8351),
  [13909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [13911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1481),
  [13913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8392),
  [13915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2865),
  [13917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [13919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(472),
  [13921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [13923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6833),
  [13925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8404),
  [13927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [13929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2869),
  [13931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [13933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [13935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1520),
  [13937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8421),
  [13939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8389),
  [13941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(760),
  [13943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [13945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6762),
  [13947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8429),
  [13949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2745),
  [13951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1677),
  [13953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8444),
  [13955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2744),
  [13957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3955),
  [13959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6742),
  [13961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8451),
  [13963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3970),
  [13965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1057),
  [13967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1680),
  [13969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8464),
  [13971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(739),
  [13973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6267),
  [13975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6974),
  [13977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8471),
  [13979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8459),
  [13981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4117),
  [13983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1761),
  [13985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8481),
  [13987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2758),
  [13989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6804),
  [13991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8487),
  [13993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5737),
  [13995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(741),
  [13997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6746),
  [13999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8495),
  [14001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7538),
  [14003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8402),
  [14005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8502),
  [14007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3827),
  [14009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8506),
  [14011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3828),
  [14013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8508),
  [14015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2694),
  [14017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8510),
  [14019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2693),
  [14021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8512),
  [14023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8514),
  [14025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(781),
  [14027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8516),
  [14029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(778),
  [14031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8518),
  [14033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(768),
  [14035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8520),
  [14037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3867),
  [14039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8544),
  [14041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8075),
  [14043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3847),
  [14045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8615),
  [14047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6900),
  [14049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3844),
  [14051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8626),
  [14053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [14055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3838),
  [14057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8635),
  [14059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8468),
  [14061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3835),
  [14063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8643),
  [14065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8538),
  [14067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8650),
  [14069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8654),
  [14071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8657),
  [14073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8659),
  [14075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8661),
  [14077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8663),
  [14079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8665),
  [14081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8667),
  [14083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8669),
  [14085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8671),
  [14087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8673),
  [14089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2757),
  [14091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [14093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3181),
  [14095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6872),
  [14097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1648),
  [14099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1621),
  [14101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1536),
  [14103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1534),
  [14105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1516),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token_raw_string_delimiter = 0,
  ts_external_token_raw_string_content = 1,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token_raw_string_delimiter] = sym_raw_string_delimiter,
  [ts_external_token_raw_string_content] = sym_raw_string_content,
};

static const bool ts_external_scanner_states[4][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token_raw_string_delimiter] = true,
    [ts_external_token_raw_string_content] = true,
  },
  [2] = {
    [ts_external_token_raw_string_delimiter] = true,
  },
  [3] = {
    [ts_external_token_raw_string_content] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_hlsl_external_scanner_create(void);
void tree_sitter_hlsl_external_scanner_destroy(void *);
bool tree_sitter_hlsl_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_hlsl_external_scanner_serialize(void *, char *);
void tree_sitter_hlsl_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_hlsl(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_identifier,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_hlsl_external_scanner_create,
      tree_sitter_hlsl_external_scanner_destroy,
      tree_sitter_hlsl_external_scanner_scan,
      tree_sitter_hlsl_external_scanner_serialize,
      tree_sitter_hlsl_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
